/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 18290
#define LARGE_STATE_COUNT 5933
#define SYMBOL_COUNT 802
#define ALIAS_COUNT 2
#define TOKEN_COUNT 396
#define EXTERNAL_TOKEN_COUNT 9
#define FIELD_COUNT 73
#define MAX_ALIAS_SEQUENCE_LENGTH 18
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 362
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_SEMI = 2,
  anon_sym_DOT = 3,
  anon_sym_LBRACE = 4,
  anon_sym_RBRACE = 5,
  aux_sym_interface_declaration_token1 = 6,
  anon_sym_EQ = 7,
  aux_sym_interface_declaration_token2 = 8,
  anon_sym_COMMA = 9,
  anon_sym_COLON = 10,
  anon_sym_DASH = 11,
  aux_sym_boolean_token1 = 12,
  aux_sym_boolean_token2 = 13,
  sym_decimal = 14,
  aux_sym_ml_value_list_token1 = 15,
  aux_sym_lookup_formula_token1 = 16,
  anon_sym_LPAREN = 17,
  anon_sym_RPAREN = 18,
  aux_sym_where_clause_token1 = 19,
  aux_sym_where_condition_token1 = 20,
  aux_sym_where_condition_token2 = 21,
  aux_sym_where_condition_token3 = 22,
  anon_sym_DOT_DOT = 23,
  aux_sym_filter_value_token1 = 24,
  aux_sym_sorting_value_token1 = 25,
  aux_sym_sorting_value_token2 = 26,
  aux_sym_sorting_value_token3 = 27,
  aux_sym_sorting_value_token4 = 28,
  aux_sym_else_table_relation_fragment_token1 = 29,
  aux_sym_if_table_relation_token1 = 30,
  aux_sym_tabledata_permission_token1 = 31,
  aux_sym_tabledata_permission_token2 = 32,
  anon_sym_STAR = 33,
  sym_permission_type = 34,
  aux_sym_order_by_item_token1 = 35,
  aux_sym_order_by_item_token2 = 36,
  aux_sym_addlast_fieldgroup_modification_token1 = 37,
  aux_sym_addfirst_fieldgroup_modification_token1 = 38,
  aux_sym_text_type_token1 = 39,
  anon_sym_LBRACK = 40,
  anon_sym_RBRACK = 41,
  aux_sym_code_type_token1 = 42,
  aux_sym_option_type_token1 = 43,
  aux_sym_record_type_token1 = 44,
  aux_sym_object_reference_type_token1 = 45,
  aux_sym_object_reference_type_token2 = 46,
  aux_sym_array_type_token1 = 47,
  aux_sym_array_type_token2 = 48,
  aux_sym_list_type_token1 = 49,
  aux_sym_dictionary_type_token1 = 50,
  aux_sym_basic_type_token1 = 51,
  aux_sym_basic_type_token2 = 52,
  aux_sym_basic_type_token3 = 53,
  aux_sym_basic_type_token4 = 54,
  aux_sym_basic_type_token5 = 55,
  aux_sym_basic_type_token6 = 56,
  aux_sym_basic_type_token7 = 57,
  aux_sym_basic_type_token8 = 58,
  aux_sym_basic_type_token9 = 59,
  aux_sym_basic_type_token10 = 60,
  aux_sym_basic_type_token11 = 61,
  aux_sym_basic_type_token12 = 62,
  aux_sym_basic_type_token13 = 63,
  aux_sym_basic_type_token14 = 64,
  aux_sym_basic_type_token15 = 65,
  aux_sym_basic_type_token16 = 66,
  aux_sym_basic_type_token17 = 67,
  aux_sym_basic_type_token18 = 68,
  aux_sym_basic_type_token19 = 69,
  aux_sym_basic_type_token20 = 70,
  aux_sym_basic_type_token21 = 71,
  aux_sym_basic_type_token22 = 72,
  aux_sym_basic_type_token23 = 73,
  aux_sym_basic_type_token24 = 74,
  aux_sym_basic_type_token25 = 75,
  aux_sym_basic_type_token26 = 76,
  aux_sym_basic_type_token27 = 77,
  aux_sym_basic_type_token28 = 78,
  aux_sym_basic_type_token29 = 79,
  aux_sym_basic_type_token30 = 80,
  aux_sym_basic_type_token31 = 81,
  aux_sym_basic_type_token32 = 82,
  aux_sym_basic_type_token33 = 83,
  aux_sym_basic_type_token34 = 84,
  aux_sym_basic_type_token35 = 85,
  aux_sym_basic_type_token36 = 86,
  aux_sym_basic_type_token37 = 87,
  aux_sym_basic_type_token38 = 88,
  aux_sym_basic_type_token39 = 89,
  aux_sym_basic_type_token40 = 90,
  aux_sym_basic_type_token41 = 91,
  aux_sym_basic_type_token42 = 92,
  aux_sym_basic_type_token43 = 93,
  aux_sym_basic_type_token44 = 94,
  aux_sym_basic_type_token45 = 95,
  aux_sym_basic_type_token46 = 96,
  aux_sym_basic_type_token47 = 97,
  aux_sym_basic_type_token48 = 98,
  aux_sym_basic_type_token49 = 99,
  aux_sym_basic_type_token50 = 100,
  aux_sym_basic_type_token51 = 101,
  aux_sym_basic_type_token52 = 102,
  aux_sym_basic_type_token53 = 103,
  aux_sym_basic_type_token54 = 104,
  aux_sym_enum_value_declaration_token1 = 105,
  aux_sym_label_declaration_token1 = 106,
  aux_sym_label_declaration_token2 = 107,
  aux_sym_area_section_token1 = 108,
  aux_sym_area_section_token2 = 109,
  aux_sym_area_section_token3 = 110,
  aux_sym_area_section_token4 = 111,
  aux_sym_area_section_token5 = 112,
  aux_sym_area_section_token6 = 113,
  aux_sym_area_section_token7 = 114,
  aux_sym_area_section_token8 = 115,
  aux_sym_addafter_modification_token1 = 116,
  aux_sym_addbefore_modification_token1 = 117,
  aux_sym_modify_modification_token1 = 118,
  aux_sym_movefirst_modification_token1 = 119,
  aux_sym_movelast_modification_token1 = 120,
  aux_sym_moveafter_modification_token1 = 121,
  aux_sym_movebefore_modification_token1 = 122,
  aux_sym_action_area_section_token1 = 123,
  aux_sym_action_area_section_token2 = 124,
  aux_sym_action_area_section_token3 = 125,
  aux_sym_action_area_section_token4 = 126,
  aux_sym_action_area_section_token5 = 127,
  aux_sym_action_area_section_token6 = 128,
  aux_sym_action_area_section_token7 = 129,
  aux_sym_separator_action_token1 = 130,
  aux_sym_actionref_declaration_token1 = 131,
  aux_sym_systemaction_declaration_token1 = 132,
  aux_sym_fileuploadaction_declaration_token1 = 133,
  aux_sym_customaction_declaration_token1 = 134,
  aux_sym_add_dataset_modification_token1 = 135,
  aux_sym_xmlport_element_token1 = 136,
  aux_sym_xmlport_element_token2 = 137,
  aux_sym_xmlport_element_token3 = 138,
  aux_sym_xmlport_attribute_token1 = 139,
  aux_sym_xmlport_attribute_token2 = 140,
  aux_sym_assembly_declaration_token1 = 141,
  sym_dotnet_assembly_name = 142,
  aux_sym_type_declaration_token1 = 143,
  aux_sym_preproc_split_procedure_body_token1 = 144,
  aux_sym_preproc_split_procedure_body_token2 = 145,
  anon_sym_COLON_COLON = 146,
  anon_sym_POUNDif = 147,
  anon_sym_POUNDIF = 148,
  anon_sym_POUNDIf = 149,
  aux_sym_preproc_or_expression_token1 = 150,
  anon_sym_PIPE_PIPE = 151,
  aux_sym_preproc_and_expression_token1 = 152,
  anon_sym_AMP_AMP = 153,
  anon_sym_not = 154,
  anon_sym_NOT = 155,
  anon_sym_Not = 156,
  anon_sym_POUNDelif = 157,
  anon_sym_POUNDELIF = 158,
  anon_sym_POUNDElif = 159,
  anon_sym_POUNDelse = 160,
  anon_sym_POUNDELSE = 161,
  anon_sym_POUNDElse = 162,
  anon_sym_POUNDelse2 = 163,
  anon_sym_POUNDELSE2 = 164,
  anon_sym_POUNDElse2 = 165,
  anon_sym_POUNDendif = 166,
  anon_sym_POUNDENDIF = 167,
  anon_sym_POUNDEndif = 168,
  anon_sym_POUNDendif2 = 169,
  anon_sym_POUNDENDIF2 = 170,
  anon_sym_POUNDEndif2 = 171,
  sym_pragma = 172,
  sym_preproc_region = 173,
  sym_preproc_endregion = 174,
  sym__assignment_operator = 175,
  anon_sym_COLON_EQ = 176,
  anon_sym_LPAREN2 = 177,
  aux_sym__expression_token1 = 178,
  aux_sym__expression_token2 = 179,
  aux_sym_keyword_identifier_token1 = 180,
  aux_sym_keyword_identifier_token2 = 181,
  anon_sym_SLASH = 182,
  anon_sym_div = 183,
  anon_sym_DIV = 184,
  anon_sym_Div = 185,
  anon_sym_mod = 186,
  anon_sym_MOD = 187,
  anon_sym_Mod = 188,
  anon_sym_PLUS = 189,
  anon_sym_GT_EQ = 190,
  anon_sym_LT_EQ = 191,
  anon_sym_GT = 192,
  anon_sym_LT = 193,
  anon_sym_LT_GT = 194,
  anon_sym_and = 195,
  anon_sym_AND = 196,
  anon_sym_And = 197,
  anon_sym_or = 198,
  anon_sym_OR = 199,
  anon_sym_Or = 200,
  anon_sym_xor = 201,
  anon_sym_XOR = 202,
  anon_sym_Xor = 203,
  anon_sym_QMARK = 204,
  sym_datetime_literal = 205,
  sym_date_literal = 206,
  sym_time_literal = 207,
  sym_biginteger_literal = 208,
  anon_sym_if = 209,
  anon_sym_IF = 210,
  anon_sym_If = 211,
  anon_sym_then = 212,
  anon_sym_THEN = 213,
  anon_sym_Then = 214,
  anon_sym_else = 215,
  anon_sym_ELSE = 216,
  anon_sym_Else = 217,
  anon_sym_case = 218,
  anon_sym_CASE = 219,
  anon_sym_Case = 220,
  anon_sym_of = 221,
  anon_sym_OF = 222,
  anon_sym_Of = 223,
  anon_sym_for = 224,
  anon_sym_FOR = 225,
  anon_sym_For = 226,
  anon_sym_foreach = 227,
  anon_sym_FOREACH = 228,
  anon_sym_Foreach = 229,
  anon_sym_while = 230,
  anon_sym_WHILE = 231,
  anon_sym_While = 232,
  anon_sym_do = 233,
  anon_sym_DO = 234,
  anon_sym_Do = 235,
  anon_sym_repeat = 236,
  anon_sym_REPEAT = 237,
  anon_sym_Repeat = 238,
  anon_sym_until = 239,
  anon_sym_UNTIL = 240,
  anon_sym_Until = 241,
  anon_sym_exit = 242,
  anon_sym_EXIT = 243,
  anon_sym_Exit = 244,
  anon_sym_continue = 245,
  anon_sym_CONTINUE = 246,
  anon_sym_Continue = 247,
  anon_sym_break = 248,
  anon_sym_BREAK = 249,
  anon_sym_Break = 250,
  anon_sym_with = 251,
  anon_sym_WITH = 252,
  anon_sym_With = 253,
  sym_asserterror_keyword = 254,
  anon_sym_in = 255,
  anon_sym_IN = 256,
  anon_sym_In = 257,
  anon_sym_to = 258,
  anon_sym_TO = 259,
  anon_sym_To = 260,
  anon_sym_downto = 261,
  anon_sym_DOWNTO = 262,
  anon_sym_Downto = 263,
  sym_table_keyword = 264,
  anon_sym_tableextension = 265,
  anon_sym_TABLEEXTENSION = 266,
  anon_sym_Tableextension = 267,
  anon_sym_TableExtension = 268,
  anon_sym_tableExtension = 269,
  sym_page_keyword = 270,
  anon_sym_pageextension = 271,
  anon_sym_PAGEEXTENSION = 272,
  anon_sym_Pageextension = 273,
  anon_sym_PageExtension = 274,
  anon_sym_pageExtension = 275,
  anon_sym_codeunit = 276,
  anon_sym_CODEUNIT = 277,
  anon_sym_Codeunit = 278,
  anon_sym_CodeUnit = 279,
  anon_sym_COdeunit = 280,
  anon_sym_codeUnit = 281,
  sym_report_keyword = 282,
  anon_sym_reportextension = 283,
  anon_sym_REPORTEXTENSION = 284,
  anon_sym_Reportextension = 285,
  anon_sym_ReportExtension = 286,
  anon_sym_reportExtension = 287,
  sym_query_keyword = 288,
  anon_sym_xmlport = 289,
  anon_sym_XMLPORT = 290,
  anon_sym_Xmlport = 291,
  anon_sym_XMLport = 292,
  anon_sym_XMLPort = 293,
  anon_sym_XmlPort = 294,
  anon_sym_enum = 295,
  anon_sym_ENUM = 296,
  anon_sym_Enum = 297,
  anon_sym_eNUM = 298,
  anon_sym_eNum = 299,
  anon_sym_ENum = 300,
  anon_sym_enumextension = 301,
  anon_sym_ENUMEXTENSION = 302,
  anon_sym_Enumextension = 303,
  anon_sym_EnumExtension = 304,
  anon_sym_enumExtension = 305,
  sym_interface_keyword = 306,
  anon_sym_controladdin = 307,
  anon_sym_CONTROLADDIN = 308,
  anon_sym_Controladdin = 309,
  anon_sym_ControlAddIn = 310,
  anon_sym_ControlAddin = 311,
  anon_sym_controlAddIn = 312,
  anon_sym_controlAddin = 313,
  anon_sym_dotnet = 314,
  anon_sym_DOTNET = 315,
  anon_sym_Dotnet = 316,
  anon_sym_DotNet = 317,
  anon_sym_dotNet = 318,
  sym_profile_keyword = 319,
  anon_sym_profileextension = 320,
  anon_sym_PROFILEEXTENSION = 321,
  anon_sym_Profileextension = 322,
  anon_sym_ProfileExtension = 323,
  anon_sym_profileExtension = 324,
  anon_sym_permissionset = 325,
  anon_sym_PERMISSIONSET = 326,
  anon_sym_Permissionset = 327,
  anon_sym_PermissionSet = 328,
  anon_sym_permissionSet = 329,
  anon_sym_permissionsetextension = 330,
  anon_sym_PERMISSIONSETEXTENSION = 331,
  anon_sym_Permissionsetextension = 332,
  anon_sym_PermissionSetExtension = 333,
  anon_sym_permissionSetExtension = 334,
  sym_entitlement_keyword = 335,
  anon_sym_pagecustomization = 336,
  anon_sym_PAGECUSTOMIZATION = 337,
  anon_sym_Pagecustomization = 338,
  anon_sym_PageCustomization = 339,
  anon_sym_pageCustomization = 340,
  sym_namespace_keyword = 341,
  sym_using_keyword = 342,
  sym_implements_keyword = 343,
  sym_extends_keyword = 344,
  sym_customizes_keyword = 345,
  sym_procedure_keyword = 346,
  sym_trigger_keyword = 347,
  sym_var_keyword = 348,
  sym_local_keyword = 349,
  sym_internal_keyword = 350,
  sym_protected_keyword = 351,
  sym_event_keyword = 352,
  sym_temporary_keyword = 353,
  sym_fields_keyword = 354,
  sym_keys_keyword = 355,
  sym_key_keyword = 356,
  sym_fieldgroups_keyword = 357,
  sym_fieldgroup_keyword = 358,
  sym_actions_keyword = 359,
  sym_layout_keyword = 360,
  sym_area_keyword = 361,
  sym_group_keyword = 362,
  sym_repeater_keyword = 363,
  sym_cuegroup_keyword = 364,
  sym_fixed_keyword = 365,
  sym_grid_keyword = 366,
  sym_part_keyword = 367,
  sym_systempart_keyword = 368,
  sym_usercontrol_keyword = 369,
  sym_dataset_keyword = 370,
  sym_elements_keyword = 371,
  sym_dataitem_keyword = 372,
  sym_column_keyword = 373,
  sym_filter_keyword = 374,
  sym_labels_keyword = 375,
  sym_rendering_keyword = 376,
  sym_requestpage_keyword = 377,
  sym_schema_keyword = 378,
  sym_views_keyword = 379,
  sym_view_keyword = 380,
  sym_quoted_identifier = 381,
  sym_comment = 382,
  sym_multiline_comment = 383,
  sym_string_literal = 384,
  sym_verbatim_string = 385,
  sym_integer = 386,
  sym_property_name = 387,
  sym_continue_as_identifier = 388,
  sym_preproc_open = 389,
  sym_preproc_close = 390,
  sym_begin_keyword = 391,
  sym_end_keyword = 392,
  sym_preproc_split_begin = 393,
  sym_preproc_split_end = 394,
  sym_var_attribute_open = 395,
  sym_source_file = 396,
  sym_preproc_conditional_object = 397,
  sym_namespace_declaration = 398,
  sym_using_statement = 399,
  sym_namespace_name = 400,
  sym__object = 401,
  sym_preproc_split_declaration = 402,
  sym__object_header = 403,
  sym_table_declaration = 404,
  sym_page_declaration = 405,
  sym_report_declaration = 406,
  sym_query_declaration = 407,
  sym_xmlport_declaration = 408,
  sym_permissionset_declaration = 409,
  sym_codeunit_declaration = 410,
  sym_enum_declaration = 411,
  sym_tableextension_declaration = 412,
  sym_pageextension_declaration = 413,
  sym_reportextension_declaration = 414,
  sym_enumextension_declaration = 415,
  sym_permissionsetextension_declaration = 416,
  sym_controladdin_declaration = 417,
  sym_preproc_conditional_controladdin = 418,
  sym_profile_declaration = 419,
  sym_entitlement_declaration = 420,
  sym_profileextension_declaration = 421,
  sym_interface_declaration = 422,
  sym_pagecustomization_declaration = 423,
  sym_dotnet_declaration = 424,
  sym_implements_clause = 425,
  sym__body_element = 426,
  sym_empty_statement = 427,
  sym_property = 428,
  sym_permissions_property = 429,
  sym_table_relation_property = 430,
  sym__property_value = 431,
  sym_decimal_range_value = 432,
  sym_signed_integer_list = 433,
  sym__signed_integer = 434,
  sym_object_reference_value = 435,
  sym_property_expression = 436,
  sym_boolean = 437,
  sym_caption_value = 438,
  sym_ml_value_list = 439,
  sym_ml_value_pair = 440,
  sym__calc_formula_expression = 441,
  sym_lookup_formula = 442,
  sym_aggregate_formula = 443,
  sym_calc_field_reference = 444,
  sym_where_clause = 445,
  sym_where_conditions = 446,
  sym_preproc_conditional_where = 447,
  sym_where_condition = 448,
  sym_filter_value = 449,
  sym_sorting_value = 450,
  sym_link_value_list = 451,
  sym_preproc_conditional_link_values = 452,
  sym_link_value = 453,
  sym_table_relation_value = 454,
  sym_preproc_conditional_table_relation = 455,
  sym__table_relation_branch_content = 456,
  sym_else_table_relation_fragment = 457,
  sym_table_relation_expression = 458,
  sym_if_table_relation = 459,
  sym_simple_table_relation = 460,
  sym_tabledata_permission_list = 461,
  sym_preproc_conditional_permissions = 462,
  sym_tabledata_permission = 463,
  sym_order_by_list = 464,
  sym_order_by_item = 465,
  sym_implementation_value_list = 466,
  sym_preproc_conditional_impl_values = 467,
  sym_implementation_value = 468,
  sym_option_member_list = 469,
  sym_option_member = 470,
  sym_fields_section = 471,
  sym_preproc_conditional_fields = 472,
  sym_field_declaration = 473,
  sym_keys_section = 474,
  sym_preproc_conditional_keys = 475,
  sym_key_declaration = 476,
  sym_field_list = 477,
  sym_fieldgroups_section = 478,
  sym_addlast_fieldgroup_modification = 479,
  sym_addfirst_fieldgroup_modification = 480,
  sym_preproc_conditional_fieldgroups = 481,
  sym_fieldgroup_declaration = 482,
  sym_type_specification = 483,
  sym_text_type = 484,
  sym_code_type = 485,
  sym_option_type = 486,
  sym_record_type = 487,
  sym_dotnet_type = 488,
  sym_object_reference_type = 489,
  sym__namespaced_or_simple_ref = 490,
  sym_array_type = 491,
  sym_list_type = 492,
  sym_dictionary_type = 493,
  sym_basic_type = 494,
  sym_enum_value_declaration = 495,
  sym_labels_section = 496,
  sym_label_declaration = 497,
  sym_layout_section = 498,
  sym__layout_element = 499,
  sym_area_section = 500,
  sym_preproc_split_brace_close = 501,
  sym_preproc_split_brace_close_if_only = 502,
  sym_group_section = 503,
  sym_repeater_section = 504,
  sym_cuegroup_section = 505,
  sym_fixed_section = 506,
  sym_grid_section = 507,
  sym_page_field = 508,
  sym__field_source = 509,
  sym_part_section = 510,
  sym_systempart_section = 511,
  sym_usercontrol_section = 512,
  sym_preproc_split_field = 513,
  sym_preproc_split_table_field = 514,
  sym__field_header = 515,
  sym__table_field_header = 516,
  sym_label_section = 517,
  sym_addfirst_modification = 518,
  sym_addlast_modification = 519,
  sym_addafter_modification = 520,
  sym_addbefore_modification = 521,
  sym_modify_modification = 522,
  sym_movefirst_modification = 523,
  sym_movelast_modification = 524,
  sym_moveafter_modification = 525,
  sym_movebefore_modification = 526,
  sym_actions_section = 527,
  sym__action_element = 528,
  sym_action_area_section = 529,
  sym_action_group_section = 530,
  sym_action_declaration = 531,
  sym_separator_action = 532,
  sym_actionref_declaration = 533,
  sym_systemaction_declaration = 534,
  sym_fileuploadaction_declaration = 535,
  sym_customaction_declaration = 536,
  sym_addfirst_action_modification = 537,
  sym_addlast_action_modification = 538,
  sym_addafter_action_modification = 539,
  sym_addbefore_action_modification = 540,
  sym_modify_action_modification = 541,
  sym_views_section = 542,
  sym_addfirst_views_modification = 543,
  sym_addlast_views_modification = 544,
  sym_addafter_views_modification = 545,
  sym_addbefore_views_modification = 546,
  sym_view_definition = 547,
  sym_dataset_section = 548,
  sym_preproc_conditional_dataset = 549,
  sym_report_dataitem = 550,
  sym__report_body_element = 551,
  sym_preproc_conditional_report = 552,
  sym_report_column = 553,
  sym_add_dataset_modification = 554,
  sym_addfirst_dataset_modification = 555,
  sym_addlast_dataset_modification = 556,
  sym_addafter_dataset_modification = 557,
  sym_addbefore_dataset_modification = 558,
  sym_requestpage_section = 559,
  sym_rendering_section = 560,
  sym_rendering_layout = 561,
  sym_elements_section = 562,
  sym_query_dataitem = 563,
  sym__query_body_element = 564,
  sym_preproc_conditional_query = 565,
  sym_query_column = 566,
  sym_query_filter = 567,
  sym_schema_section = 568,
  sym_xmlport_element = 569,
  sym__xmlport_body_element = 570,
  sym_preproc_conditional_xmlport = 571,
  sym_xmlport_attribute = 572,
  sym_assembly_declaration = 573,
  sym_type_declaration = 574,
  sym_event_declaration = 575,
  sym_procedure = 576,
  sym_preproc_split_procedure_body = 577,
  sym_preproc_split_complete_body = 578,
  sym_preproc_split_procedure = 579,
  sym__procedure_preamble = 580,
  sym_preproc_split_procedure_preamble = 581,
  sym__procedure_header = 582,
  sym_interface_procedure = 583,
  sym_interface_procedure_suffix = 584,
  sym_procedure_modifier = 585,
  sym__procedure_return_specification = 586,
  sym__procedure_named_return = 587,
  sym_parameter_list = 588,
  sym_parameter = 589,
  sym_code_block = 590,
  sym_trigger_declaration = 591,
  sym_preproc_conditional_var_block = 592,
  sym__trigger_name = 593,
  sym_var_section = 594,
  sym_var_attribute_item = 595,
  sym_preproc_conditional_var = 596,
  sym_variable_declaration = 597,
  sym_label_attribute = 598,
  sym_attribute_item = 599,
  sym_attribute_content = 600,
  sym_attribute_arguments = 601,
  sym_attribute_argument_list = 602,
  sym__attribute_argument = 603,
  sym_preproc_conditional = 604,
  sym_preproc_if = 605,
  sym__preproc_expression = 606,
  sym_preproc_or_expression = 607,
  sym_preproc_and_expression = 608,
  sym_preproc_not_expression = 609,
  sym_preproc_elif = 610,
  sym_preproc_else = 611,
  sym_preproc_endif = 612,
  sym_preproc_split_if_statement = 613,
  sym__preproc_if_header = 614,
  sym_preproc_guarded_statement = 615,
  sym__preproc_guard_block = 616,
  sym_preproc_split_if_else_statement = 617,
  sym_preproc_split_if_then_begin = 618,
  sym_preproc_split_if_begin_asymmetric = 619,
  sym_preproc_split_if_begin_else = 620,
  sym_preproc_split_call_statement = 621,
  sym__preproc_call_prefix = 622,
  sym_preproc_split_code_block_end = 623,
  sym_preproc_fragmented_else_tail = 624,
  sym_preproc_conditional_statement = 625,
  sym_preproc_conditional_actions = 626,
  sym_preproc_conditional_layout = 627,
  sym_preproc_conditional_layout_mixed = 628,
  sym__statement = 629,
  sym__expression_statement = 630,
  sym_assignment_statement = 631,
  sym_assignment_expression = 632,
  sym_if_statement = 633,
  sym__if_statement_no_else = 634,
  sym_case_statement = 635,
  sym_preproc_conditional_case = 636,
  sym_case_branch = 637,
  sym_preproc_split_case_branch = 638,
  sym_preproc_split_case_extended = 639,
  aux_sym__case_pattern = 640,
  sym_preproc_conditional_case_patterns = 641,
  sym__single_pattern = 642,
  sym_case_else_branch = 643,
  sym_for_statement = 644,
  sym_foreach_statement = 645,
  sym_while_statement = 646,
  sym_repeat_statement = 647,
  sym_with_statement = 648,
  sym_exit_statement = 649,
  sym_continue_statement = 650,
  sym_break_statement = 651,
  sym_asserterror_statement = 652,
  sym__expression = 653,
  sym_keyword_identifier = 654,
  sym_range_expression = 655,
  sym_multiplicative_expression = 656,
  sym_additive_expression = 657,
  sym_comparison_expression = 658,
  sym_comparison_operator = 659,
  sym_logical_expression = 660,
  sym_ternary_expression = 661,
  sym_unary_expression = 662,
  sym_call_expression = 663,
  sym_argument_list = 664,
  sym_member_expression = 665,
  sym_subscript_expression = 666,
  sym_parenthesized_expression = 667,
  sym_list_literal = 668,
  sym_qualified_enum_value = 669,
  sym_database_reference = 670,
  sym__literal_value = 671,
  sym_if_keyword = 672,
  sym_then_keyword = 673,
  sym_else_keyword = 674,
  sym_case_keyword = 675,
  sym_of_keyword = 676,
  sym_for_keyword = 677,
  sym_foreach_keyword = 678,
  sym_while_keyword = 679,
  sym_do_keyword = 680,
  sym_repeat_keyword = 681,
  sym_until_keyword = 682,
  sym_exit_keyword = 683,
  sym_continue_keyword = 684,
  sym_break_keyword = 685,
  sym_with_keyword = 686,
  sym_in_keyword = 687,
  sym_to_keyword = 688,
  sym_downto_keyword = 689,
  sym_tableextension_keyword = 690,
  sym_pageextension_keyword = 691,
  sym_codeunit_keyword = 692,
  sym_reportextension_keyword = 693,
  sym_xmlport_keyword = 694,
  sym_enum_keyword = 695,
  sym_enumextension_keyword = 696,
  sym_controladdin_keyword = 697,
  sym_dotnet_keyword = 698,
  sym_profileextension_keyword = 699,
  sym_permissionset_keyword = 700,
  sym_permissionsetextension_keyword = 701,
  sym_pagecustomization_keyword = 702,
  sym__identifier_or_quoted = 703,
  sym_keyword_as_identifier = 704,
  aux_sym_source_file_repeat1 = 705,
  aux_sym_preproc_conditional_object_repeat1 = 706,
  aux_sym_namespace_name_repeat1 = 707,
  aux_sym_preproc_split_declaration_repeat1 = 708,
  aux_sym_preproc_split_declaration_repeat2 = 709,
  aux_sym_controladdin_declaration_repeat1 = 710,
  aux_sym_preproc_conditional_controladdin_repeat1 = 711,
  aux_sym_interface_declaration_repeat1 = 712,
  aux_sym_dotnet_declaration_repeat1 = 713,
  aux_sym_implements_clause_repeat1 = 714,
  aux_sym_signed_integer_list_repeat1 = 715,
  aux_sym_caption_value_repeat1 = 716,
  aux_sym_ml_value_list_repeat1 = 717,
  aux_sym_calc_field_reference_repeat1 = 718,
  aux_sym_where_conditions_repeat1 = 719,
  aux_sym_preproc_conditional_where_repeat1 = 720,
  aux_sym_preproc_conditional_where_repeat2 = 721,
  aux_sym_filter_value_repeat1 = 722,
  aux_sym_sorting_value_repeat1 = 723,
  aux_sym_link_value_list_repeat1 = 724,
  aux_sym_preproc_conditional_link_values_repeat1 = 725,
  aux_sym_preproc_conditional_link_values_repeat2 = 726,
  aux_sym_preproc_conditional_table_relation_repeat1 = 727,
  aux_sym_tabledata_permission_list_repeat1 = 728,
  aux_sym_preproc_conditional_permissions_repeat1 = 729,
  aux_sym_preproc_conditional_permissions_repeat2 = 730,
  aux_sym_order_by_list_repeat1 = 731,
  aux_sym_implementation_value_list_repeat1 = 732,
  aux_sym_preproc_conditional_impl_values_repeat1 = 733,
  aux_sym_preproc_conditional_impl_values_repeat2 = 734,
  aux_sym_option_member_list_repeat1 = 735,
  aux_sym_option_member_list_repeat2 = 736,
  aux_sym_fields_section_repeat1 = 737,
  aux_sym_preproc_conditional_fields_repeat1 = 738,
  aux_sym_preproc_conditional_fields_repeat2 = 739,
  aux_sym_keys_section_repeat1 = 740,
  aux_sym_preproc_conditional_keys_repeat1 = 741,
  aux_sym_preproc_conditional_keys_repeat2 = 742,
  aux_sym_fieldgroups_section_repeat1 = 743,
  aux_sym_preproc_conditional_fieldgroups_repeat1 = 744,
  aux_sym_preproc_conditional_fieldgroups_repeat2 = 745,
  aux_sym__namespaced_or_simple_ref_repeat1 = 746,
  aux_sym_array_type_repeat1 = 747,
  aux_sym_labels_section_repeat1 = 748,
  aux_sym_label_declaration_repeat1 = 749,
  aux_sym_layout_section_repeat1 = 750,
  aux_sym_group_section_repeat1 = 751,
  aux_sym_preproc_split_field_repeat1 = 752,
  aux_sym_preproc_split_table_field_repeat1 = 753,
  aux_sym_actions_section_repeat1 = 754,
  aux_sym_action_group_section_repeat1 = 755,
  aux_sym_views_section_repeat1 = 756,
  aux_sym_addfirst_views_modification_repeat1 = 757,
  aux_sym_dataset_section_repeat1 = 758,
  aux_sym_preproc_conditional_dataset_repeat1 = 759,
  aux_sym_preproc_conditional_dataset_repeat2 = 760,
  aux_sym_report_dataitem_repeat1 = 761,
  aux_sym_preproc_conditional_report_repeat1 = 762,
  aux_sym_add_dataset_modification_repeat1 = 763,
  aux_sym_rendering_section_repeat1 = 764,
  aux_sym_elements_section_repeat1 = 765,
  aux_sym_query_dataitem_repeat1 = 766,
  aux_sym_preproc_conditional_query_repeat1 = 767,
  aux_sym_schema_section_repeat1 = 768,
  aux_sym_xmlport_element_repeat1 = 769,
  aux_sym_preproc_conditional_xmlport_repeat1 = 770,
  aux_sym_assembly_declaration_repeat1 = 771,
  aux_sym_preproc_split_procedure_body_repeat1 = 772,
  aux_sym_preproc_split_complete_body_repeat1 = 773,
  aux_sym_preproc_split_procedure_repeat1 = 774,
  aux_sym_preproc_split_procedure_preamble_repeat1 = 775,
  aux_sym__procedure_header_repeat1 = 776,
  aux_sym_parameter_list_repeat1 = 777,
  aux_sym_preproc_conditional_var_block_repeat1 = 778,
  aux_sym_var_section_repeat1 = 779,
  aux_sym_preproc_conditional_var_repeat1 = 780,
  aux_sym_preproc_conditional_var_repeat2 = 781,
  aux_sym_variable_declaration_repeat1 = 782,
  aux_sym_variable_declaration_repeat2 = 783,
  aux_sym_attribute_argument_list_repeat1 = 784,
  aux_sym_preproc_conditional_repeat1 = 785,
  aux_sym_preproc_split_if_statement_repeat1 = 786,
  aux_sym__preproc_guard_block_repeat1 = 787,
  aux_sym_preproc_split_if_else_statement_repeat1 = 788,
  aux_sym_preproc_split_call_statement_repeat1 = 789,
  aux_sym_preproc_split_call_statement_repeat2 = 790,
  aux_sym_preproc_conditional_statement_repeat1 = 791,
  aux_sym_preproc_conditional_actions_repeat1 = 792,
  aux_sym_preproc_conditional_layout_repeat1 = 793,
  aux_sym_preproc_conditional_layout_mixed_repeat1 = 794,
  aux_sym_preproc_conditional_layout_mixed_repeat2 = 795,
  aux_sym_case_statement_repeat1 = 796,
  aux_sym_preproc_conditional_case_repeat1 = 797,
  aux_sym_preproc_conditional_case_repeat2 = 798,
  aux_sym_preproc_split_case_branch_repeat1 = 799,
  aux_sym_preproc_split_case_branch_repeat2 = 800,
  aux_sym_preproc_split_case_extended_repeat1 = 801,
  alias_sym_aggregate_function = 802,
  alias_sym_object_type_keyword = 803,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_SEMI] = ";",
  [anon_sym_DOT] = ".",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_interface_declaration_token1] = "interface_declaration_token1",
  [anon_sym_EQ] = "=",
  [aux_sym_interface_declaration_token2] = "interface_declaration_token2",
  [anon_sym_COMMA] = ",",
  [anon_sym_COLON] = ":",
  [anon_sym_DASH] = "-",
  [aux_sym_boolean_token1] = "boolean_token1",
  [aux_sym_boolean_token2] = "boolean_token2",
  [sym_decimal] = "decimal",
  [aux_sym_ml_value_list_token1] = "ml_value_list_token1",
  [aux_sym_lookup_formula_token1] = "lookup_formula_token1",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [aux_sym_where_clause_token1] = "where_clause_token1",
  [aux_sym_where_condition_token1] = "where_condition_token1",
  [aux_sym_where_condition_token2] = "where_condition_token2",
  [aux_sym_where_condition_token3] = "where_condition_token3",
  [anon_sym_DOT_DOT] = "..",
  [aux_sym_filter_value_token1] = "filter_value_token1",
  [aux_sym_sorting_value_token1] = "sorting_value_token1",
  [aux_sym_sorting_value_token2] = "sorting_value_token2",
  [aux_sym_sorting_value_token3] = "sorting_value_token3",
  [aux_sym_sorting_value_token4] = "sorting_value_token4",
  [aux_sym_else_table_relation_fragment_token1] = "else_table_relation_fragment_token1",
  [aux_sym_if_table_relation_token1] = "if_table_relation_token1",
  [aux_sym_tabledata_permission_token1] = "tabledata_permission_token1",
  [aux_sym_tabledata_permission_token2] = "tabledata_permission_token2",
  [anon_sym_STAR] = "*",
  [sym_permission_type] = "permission_type",
  [aux_sym_order_by_item_token1] = "order_by_item_token1",
  [aux_sym_order_by_item_token2] = "order_by_item_token2",
  [aux_sym_addlast_fieldgroup_modification_token1] = "addlast_fieldgroup_modification_token1",
  [aux_sym_addfirst_fieldgroup_modification_token1] = "addfirst_fieldgroup_modification_token1",
  [aux_sym_text_type_token1] = "text_type_token1",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [aux_sym_code_type_token1] = "code_type_token1",
  [aux_sym_option_type_token1] = "option_type_token1",
  [aux_sym_record_type_token1] = "record_type_token1",
  [aux_sym_object_reference_type_token1] = "object_reference_type_token1",
  [aux_sym_object_reference_type_token2] = "object_reference_type_token2",
  [aux_sym_array_type_token1] = "array_type_token1",
  [aux_sym_array_type_token2] = "array_type_token2",
  [aux_sym_list_type_token1] = "list_type_token1",
  [aux_sym_dictionary_type_token1] = "dictionary_type_token1",
  [aux_sym_basic_type_token1] = "basic_type_token1",
  [aux_sym_basic_type_token2] = "basic_type_token2",
  [aux_sym_basic_type_token3] = "basic_type_token3",
  [aux_sym_basic_type_token4] = "basic_type_token4",
  [aux_sym_basic_type_token5] = "basic_type_token5",
  [aux_sym_basic_type_token6] = "basic_type_token6",
  [aux_sym_basic_type_token7] = "basic_type_token7",
  [aux_sym_basic_type_token8] = "basic_type_token8",
  [aux_sym_basic_type_token9] = "basic_type_token9",
  [aux_sym_basic_type_token10] = "basic_type_token10",
  [aux_sym_basic_type_token11] = "basic_type_token11",
  [aux_sym_basic_type_token12] = "basic_type_token12",
  [aux_sym_basic_type_token13] = "basic_type_token13",
  [aux_sym_basic_type_token14] = "basic_type_token14",
  [aux_sym_basic_type_token15] = "basic_type_token15",
  [aux_sym_basic_type_token16] = "basic_type_token16",
  [aux_sym_basic_type_token17] = "basic_type_token17",
  [aux_sym_basic_type_token18] = "basic_type_token18",
  [aux_sym_basic_type_token19] = "basic_type_token19",
  [aux_sym_basic_type_token20] = "basic_type_token20",
  [aux_sym_basic_type_token21] = "basic_type_token21",
  [aux_sym_basic_type_token22] = "basic_type_token22",
  [aux_sym_basic_type_token23] = "basic_type_token23",
  [aux_sym_basic_type_token24] = "basic_type_token24",
  [aux_sym_basic_type_token25] = "basic_type_token25",
  [aux_sym_basic_type_token26] = "basic_type_token26",
  [aux_sym_basic_type_token27] = "basic_type_token27",
  [aux_sym_basic_type_token28] = "basic_type_token28",
  [aux_sym_basic_type_token29] = "basic_type_token29",
  [aux_sym_basic_type_token30] = "basic_type_token30",
  [aux_sym_basic_type_token31] = "basic_type_token31",
  [aux_sym_basic_type_token32] = "basic_type_token32",
  [aux_sym_basic_type_token33] = "basic_type_token33",
  [aux_sym_basic_type_token34] = "basic_type_token34",
  [aux_sym_basic_type_token35] = "basic_type_token35",
  [aux_sym_basic_type_token36] = "basic_type_token36",
  [aux_sym_basic_type_token37] = "basic_type_token37",
  [aux_sym_basic_type_token38] = "basic_type_token38",
  [aux_sym_basic_type_token39] = "basic_type_token39",
  [aux_sym_basic_type_token40] = "basic_type_token40",
  [aux_sym_basic_type_token41] = "basic_type_token41",
  [aux_sym_basic_type_token42] = "basic_type_token42",
  [aux_sym_basic_type_token43] = "basic_type_token43",
  [aux_sym_basic_type_token44] = "basic_type_token44",
  [aux_sym_basic_type_token45] = "basic_type_token45",
  [aux_sym_basic_type_token46] = "basic_type_token46",
  [aux_sym_basic_type_token47] = "basic_type_token47",
  [aux_sym_basic_type_token48] = "basic_type_token48",
  [aux_sym_basic_type_token49] = "basic_type_token49",
  [aux_sym_basic_type_token50] = "basic_type_token50",
  [aux_sym_basic_type_token51] = "basic_type_token51",
  [aux_sym_basic_type_token52] = "basic_type_token52",
  [aux_sym_basic_type_token53] = "basic_type_token53",
  [aux_sym_basic_type_token54] = "basic_type_token54",
  [aux_sym_enum_value_declaration_token1] = "enum_value_declaration_token1",
  [aux_sym_label_declaration_token1] = "label_declaration_token1",
  [aux_sym_label_declaration_token2] = "label_declaration_token2",
  [aux_sym_area_section_token1] = "area_section_token1",
  [aux_sym_area_section_token2] = "area_section_token2",
  [aux_sym_area_section_token3] = "area_section_token3",
  [aux_sym_area_section_token4] = "area_section_token4",
  [aux_sym_area_section_token5] = "area_section_token5",
  [aux_sym_area_section_token6] = "area_section_token6",
  [aux_sym_area_section_token7] = "area_section_token7",
  [aux_sym_area_section_token8] = "area_section_token8",
  [aux_sym_addafter_modification_token1] = "addafter_modification_token1",
  [aux_sym_addbefore_modification_token1] = "addbefore_modification_token1",
  [aux_sym_modify_modification_token1] = "modify_modification_token1",
  [aux_sym_movefirst_modification_token1] = "movefirst_modification_token1",
  [aux_sym_movelast_modification_token1] = "movelast_modification_token1",
  [aux_sym_moveafter_modification_token1] = "moveafter_modification_token1",
  [aux_sym_movebefore_modification_token1] = "movebefore_modification_token1",
  [aux_sym_action_area_section_token1] = "action_area_section_token1",
  [aux_sym_action_area_section_token2] = "action_area_section_token2",
  [aux_sym_action_area_section_token3] = "action_area_section_token3",
  [aux_sym_action_area_section_token4] = "action_area_section_token4",
  [aux_sym_action_area_section_token5] = "action_area_section_token5",
  [aux_sym_action_area_section_token6] = "action_area_section_token6",
  [aux_sym_action_area_section_token7] = "action_area_section_token7",
  [aux_sym_separator_action_token1] = "separator_action_token1",
  [aux_sym_actionref_declaration_token1] = "actionref_declaration_token1",
  [aux_sym_systemaction_declaration_token1] = "systemaction_declaration_token1",
  [aux_sym_fileuploadaction_declaration_token1] = "fileuploadaction_declaration_token1",
  [aux_sym_customaction_declaration_token1] = "customaction_declaration_token1",
  [aux_sym_add_dataset_modification_token1] = "add_dataset_modification_token1",
  [aux_sym_xmlport_element_token1] = "xmlport_element_token1",
  [aux_sym_xmlport_element_token2] = "xmlport_element_token2",
  [aux_sym_xmlport_element_token3] = "xmlport_element_token3",
  [aux_sym_xmlport_attribute_token1] = "xmlport_attribute_token1",
  [aux_sym_xmlport_attribute_token2] = "xmlport_attribute_token2",
  [aux_sym_assembly_declaration_token1] = "assembly_declaration_token1",
  [sym_dotnet_assembly_name] = "dotnet_assembly_name",
  [aux_sym_type_declaration_token1] = "type_declaration_token1",
  [aux_sym_preproc_split_procedure_body_token1] = "preproc_split_procedure_body_token1",
  [aux_sym_preproc_split_procedure_body_token2] = "preproc_split_procedure_body_token2",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_POUNDif] = "#if",
  [anon_sym_POUNDIF] = "#IF",
  [anon_sym_POUNDIf] = "#If",
  [aux_sym_preproc_or_expression_token1] = "preproc_or_expression_token1",
  [anon_sym_PIPE_PIPE] = "||",
  [aux_sym_preproc_and_expression_token1] = "preproc_and_expression_token1",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_not] = "not",
  [anon_sym_NOT] = "NOT",
  [anon_sym_Not] = "Not",
  [anon_sym_POUNDelif] = "#elif",
  [anon_sym_POUNDELIF] = "#ELIF",
  [anon_sym_POUNDElif] = "#Elif",
  [anon_sym_POUNDelse] = "#else",
  [anon_sym_POUNDELSE] = "#ELSE",
  [anon_sym_POUNDElse] = "#Else",
  [anon_sym_POUNDelse2] = "# else",
  [anon_sym_POUNDELSE2] = "# ELSE",
  [anon_sym_POUNDElse2] = "# Else",
  [anon_sym_POUNDendif] = "#endif",
  [anon_sym_POUNDENDIF] = "#ENDIF",
  [anon_sym_POUNDEndif] = "#Endif",
  [anon_sym_POUNDendif2] = "# endif",
  [anon_sym_POUNDENDIF2] = "# ENDIF",
  [anon_sym_POUNDEndif2] = "# Endif",
  [sym_pragma] = "pragma",
  [sym_preproc_region] = "preproc_region",
  [sym_preproc_endregion] = "preproc_endregion",
  [sym__assignment_operator] = "_assignment_operator",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_LPAREN2] = "(",
  [aux_sym__expression_token1] = "_expression_token1",
  [aux_sym__expression_token2] = "_expression_token2",
  [aux_sym_keyword_identifier_token1] = "keyword_identifier_token1",
  [aux_sym_keyword_identifier_token2] = "keyword_identifier_token2",
  [anon_sym_SLASH] = "/",
  [anon_sym_div] = "div",
  [anon_sym_DIV] = "DIV",
  [anon_sym_Div] = "Div",
  [anon_sym_mod] = "mod",
  [anon_sym_MOD] = "MOD",
  [anon_sym_Mod] = "Mod",
  [anon_sym_PLUS] = "+",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT] = ">",
  [anon_sym_LT] = "<",
  [anon_sym_LT_GT] = "<>",
  [anon_sym_and] = "and",
  [anon_sym_AND] = "AND",
  [anon_sym_And] = "And",
  [anon_sym_or] = "or",
  [anon_sym_OR] = "OR",
  [anon_sym_Or] = "Or",
  [anon_sym_xor] = "xor",
  [anon_sym_XOR] = "XOR",
  [anon_sym_Xor] = "Xor",
  [anon_sym_QMARK] = "\?",
  [sym_datetime_literal] = "datetime_literal",
  [sym_date_literal] = "date_literal",
  [sym_time_literal] = "time_literal",
  [sym_biginteger_literal] = "biginteger_literal",
  [anon_sym_if] = "if",
  [anon_sym_IF] = "IF",
  [anon_sym_If] = "If",
  [anon_sym_then] = "then",
  [anon_sym_THEN] = "THEN",
  [anon_sym_Then] = "Then",
  [anon_sym_else] = "else",
  [anon_sym_ELSE] = "ELSE",
  [anon_sym_Else] = "Else",
  [anon_sym_case] = "case",
  [anon_sym_CASE] = "CASE",
  [anon_sym_Case] = "Case",
  [anon_sym_of] = "of",
  [anon_sym_OF] = "OF",
  [anon_sym_Of] = "Of",
  [anon_sym_for] = "for",
  [anon_sym_FOR] = "FOR",
  [anon_sym_For] = "For",
  [anon_sym_foreach] = "foreach",
  [anon_sym_FOREACH] = "FOREACH",
  [anon_sym_Foreach] = "Foreach",
  [anon_sym_while] = "while",
  [anon_sym_WHILE] = "WHILE",
  [anon_sym_While] = "While",
  [anon_sym_do] = "do",
  [anon_sym_DO] = "DO",
  [anon_sym_Do] = "Do",
  [anon_sym_repeat] = "repeat",
  [anon_sym_REPEAT] = "REPEAT",
  [anon_sym_Repeat] = "Repeat",
  [anon_sym_until] = "until",
  [anon_sym_UNTIL] = "UNTIL",
  [anon_sym_Until] = "Until",
  [anon_sym_exit] = "exit",
  [anon_sym_EXIT] = "EXIT",
  [anon_sym_Exit] = "Exit",
  [anon_sym_continue] = "continue",
  [anon_sym_CONTINUE] = "CONTINUE",
  [anon_sym_Continue] = "Continue",
  [anon_sym_break] = "break",
  [anon_sym_BREAK] = "BREAK",
  [anon_sym_Break] = "Break",
  [anon_sym_with] = "with",
  [anon_sym_WITH] = "WITH",
  [anon_sym_With] = "With",
  [sym_asserterror_keyword] = "asserterror_keyword",
  [anon_sym_in] = "in",
  [anon_sym_IN] = "IN",
  [anon_sym_In] = "In",
  [anon_sym_to] = "to",
  [anon_sym_TO] = "TO",
  [anon_sym_To] = "To",
  [anon_sym_downto] = "downto",
  [anon_sym_DOWNTO] = "DOWNTO",
  [anon_sym_Downto] = "Downto",
  [sym_table_keyword] = "table_keyword",
  [anon_sym_tableextension] = "tableextension",
  [anon_sym_TABLEEXTENSION] = "TABLEEXTENSION",
  [anon_sym_Tableextension] = "Tableextension",
  [anon_sym_TableExtension] = "TableExtension",
  [anon_sym_tableExtension] = "tableExtension",
  [sym_page_keyword] = "page_keyword",
  [anon_sym_pageextension] = "pageextension",
  [anon_sym_PAGEEXTENSION] = "PAGEEXTENSION",
  [anon_sym_Pageextension] = "Pageextension",
  [anon_sym_PageExtension] = "PageExtension",
  [anon_sym_pageExtension] = "pageExtension",
  [anon_sym_codeunit] = "codeunit",
  [anon_sym_CODEUNIT] = "CODEUNIT",
  [anon_sym_Codeunit] = "Codeunit",
  [anon_sym_CodeUnit] = "CodeUnit",
  [anon_sym_COdeunit] = "COdeunit",
  [anon_sym_codeUnit] = "codeUnit",
  [sym_report_keyword] = "report_keyword",
  [anon_sym_reportextension] = "reportextension",
  [anon_sym_REPORTEXTENSION] = "REPORTEXTENSION",
  [anon_sym_Reportextension] = "Reportextension",
  [anon_sym_ReportExtension] = "ReportExtension",
  [anon_sym_reportExtension] = "reportExtension",
  [sym_query_keyword] = "query_keyword",
  [anon_sym_xmlport] = "xmlport",
  [anon_sym_XMLPORT] = "XMLPORT",
  [anon_sym_Xmlport] = "Xmlport",
  [anon_sym_XMLport] = "XMLport",
  [anon_sym_XMLPort] = "XMLPort",
  [anon_sym_XmlPort] = "XmlPort",
  [anon_sym_enum] = "enum",
  [anon_sym_ENUM] = "ENUM",
  [anon_sym_Enum] = "Enum",
  [anon_sym_eNUM] = "eNUM",
  [anon_sym_eNum] = "eNum",
  [anon_sym_ENum] = "ENum",
  [anon_sym_enumextension] = "enumextension",
  [anon_sym_ENUMEXTENSION] = "ENUMEXTENSION",
  [anon_sym_Enumextension] = "Enumextension",
  [anon_sym_EnumExtension] = "EnumExtension",
  [anon_sym_enumExtension] = "enumExtension",
  [sym_interface_keyword] = "interface_keyword",
  [anon_sym_controladdin] = "controladdin",
  [anon_sym_CONTROLADDIN] = "CONTROLADDIN",
  [anon_sym_Controladdin] = "Controladdin",
  [anon_sym_ControlAddIn] = "ControlAddIn",
  [anon_sym_ControlAddin] = "ControlAddin",
  [anon_sym_controlAddIn] = "controlAddIn",
  [anon_sym_controlAddin] = "controlAddin",
  [anon_sym_dotnet] = "dotnet",
  [anon_sym_DOTNET] = "DOTNET",
  [anon_sym_Dotnet] = "Dotnet",
  [anon_sym_DotNet] = "DotNet",
  [anon_sym_dotNet] = "dotNet",
  [sym_profile_keyword] = "profile_keyword",
  [anon_sym_profileextension] = "profileextension",
  [anon_sym_PROFILEEXTENSION] = "PROFILEEXTENSION",
  [anon_sym_Profileextension] = "Profileextension",
  [anon_sym_ProfileExtension] = "ProfileExtension",
  [anon_sym_profileExtension] = "profileExtension",
  [anon_sym_permissionset] = "permissionset",
  [anon_sym_PERMISSIONSET] = "PERMISSIONSET",
  [anon_sym_Permissionset] = "Permissionset",
  [anon_sym_PermissionSet] = "PermissionSet",
  [anon_sym_permissionSet] = "permissionSet",
  [anon_sym_permissionsetextension] = "permissionsetextension",
  [anon_sym_PERMISSIONSETEXTENSION] = "PERMISSIONSETEXTENSION",
  [anon_sym_Permissionsetextension] = "Permissionsetextension",
  [anon_sym_PermissionSetExtension] = "PermissionSetExtension",
  [anon_sym_permissionSetExtension] = "permissionSetExtension",
  [sym_entitlement_keyword] = "entitlement_keyword",
  [anon_sym_pagecustomization] = "pagecustomization",
  [anon_sym_PAGECUSTOMIZATION] = "PAGECUSTOMIZATION",
  [anon_sym_Pagecustomization] = "Pagecustomization",
  [anon_sym_PageCustomization] = "PageCustomization",
  [anon_sym_pageCustomization] = "pageCustomization",
  [sym_namespace_keyword] = "namespace_keyword",
  [sym_using_keyword] = "using_keyword",
  [sym_implements_keyword] = "implements_keyword",
  [sym_extends_keyword] = "extends_keyword",
  [sym_customizes_keyword] = "customizes_keyword",
  [sym_procedure_keyword] = "procedure_keyword",
  [sym_trigger_keyword] = "trigger_keyword",
  [sym_var_keyword] = "var_keyword",
  [sym_local_keyword] = "local_keyword",
  [sym_internal_keyword] = "internal_keyword",
  [sym_protected_keyword] = "protected_keyword",
  [sym_event_keyword] = "event_keyword",
  [sym_temporary_keyword] = "temporary_keyword",
  [sym_fields_keyword] = "fields_keyword",
  [sym_keys_keyword] = "keys_keyword",
  [sym_key_keyword] = "key_keyword",
  [sym_fieldgroups_keyword] = "fieldgroups_keyword",
  [sym_fieldgroup_keyword] = "fieldgroup_keyword",
  [sym_actions_keyword] = "actions_keyword",
  [sym_layout_keyword] = "layout_keyword",
  [sym_area_keyword] = "area_keyword",
  [sym_group_keyword] = "group_keyword",
  [sym_repeater_keyword] = "repeater_keyword",
  [sym_cuegroup_keyword] = "cuegroup_keyword",
  [sym_fixed_keyword] = "fixed_keyword",
  [sym_grid_keyword] = "grid_keyword",
  [sym_part_keyword] = "part_keyword",
  [sym_systempart_keyword] = "systempart_keyword",
  [sym_usercontrol_keyword] = "usercontrol_keyword",
  [sym_dataset_keyword] = "dataset_keyword",
  [sym_elements_keyword] = "elements_keyword",
  [sym_dataitem_keyword] = "dataitem_keyword",
  [sym_column_keyword] = "column_keyword",
  [sym_filter_keyword] = "filter_keyword",
  [sym_labels_keyword] = "labels_keyword",
  [sym_rendering_keyword] = "rendering_keyword",
  [sym_requestpage_keyword] = "requestpage_keyword",
  [sym_schema_keyword] = "schema_keyword",
  [sym_views_keyword] = "views_keyword",
  [sym_view_keyword] = "view_keyword",
  [sym_quoted_identifier] = "quoted_identifier",
  [sym_comment] = "comment",
  [sym_multiline_comment] = "multiline_comment",
  [sym_string_literal] = "string_literal",
  [sym_verbatim_string] = "verbatim_string",
  [sym_integer] = "integer",
  [sym_property_name] = "property_name",
  [sym_continue_as_identifier] = "identifier",
  [sym_preproc_open] = "preproc_open",
  [sym_preproc_close] = "preproc_close",
  [sym_begin_keyword] = "begin_keyword",
  [sym_end_keyword] = "end_keyword",
  [sym_preproc_split_begin] = "preproc_split_begin",
  [sym_preproc_split_end] = "preproc_split_end",
  [sym_var_attribute_open] = "var_attribute_open",
  [sym_source_file] = "source_file",
  [sym_preproc_conditional_object] = "preproc_conditional_object",
  [sym_namespace_declaration] = "namespace_declaration",
  [sym_using_statement] = "using_statement",
  [sym_namespace_name] = "namespace_name",
  [sym__object] = "_object",
  [sym_preproc_split_declaration] = "preproc_split_declaration",
  [sym__object_header] = "_object_header",
  [sym_table_declaration] = "table_declaration",
  [sym_page_declaration] = "page_declaration",
  [sym_report_declaration] = "report_declaration",
  [sym_query_declaration] = "query_declaration",
  [sym_xmlport_declaration] = "xmlport_declaration",
  [sym_permissionset_declaration] = "permissionset_declaration",
  [sym_codeunit_declaration] = "codeunit_declaration",
  [sym_enum_declaration] = "enum_declaration",
  [sym_tableextension_declaration] = "tableextension_declaration",
  [sym_pageextension_declaration] = "pageextension_declaration",
  [sym_reportextension_declaration] = "reportextension_declaration",
  [sym_enumextension_declaration] = "enumextension_declaration",
  [sym_permissionsetextension_declaration] = "permissionsetextension_declaration",
  [sym_controladdin_declaration] = "controladdin_declaration",
  [sym_preproc_conditional_controladdin] = "preproc_conditional_controladdin",
  [sym_profile_declaration] = "profile_declaration",
  [sym_entitlement_declaration] = "entitlement_declaration",
  [sym_profileextension_declaration] = "profileextension_declaration",
  [sym_interface_declaration] = "interface_declaration",
  [sym_pagecustomization_declaration] = "pagecustomization_declaration",
  [sym_dotnet_declaration] = "dotnet_declaration",
  [sym_implements_clause] = "implements_clause",
  [sym__body_element] = "_body_element",
  [sym_empty_statement] = "empty_statement",
  [sym_property] = "property",
  [sym_permissions_property] = "property",
  [sym_table_relation_property] = "property",
  [sym__property_value] = "_property_value",
  [sym_decimal_range_value] = "decimal_range_value",
  [sym_signed_integer_list] = "signed_integer_list",
  [sym__signed_integer] = "_signed_integer",
  [sym_object_reference_value] = "object_reference_value",
  [sym_property_expression] = "property_expression",
  [sym_boolean] = "boolean",
  [sym_caption_value] = "caption_value",
  [sym_ml_value_list] = "ml_value_list",
  [sym_ml_value_pair] = "ml_value_pair",
  [sym__calc_formula_expression] = "_calc_formula_expression",
  [sym_lookup_formula] = "lookup_formula",
  [sym_aggregate_formula] = "aggregate_formula",
  [sym_calc_field_reference] = "calc_field_reference",
  [sym_where_clause] = "where_clause",
  [sym_where_conditions] = "where_conditions",
  [sym_preproc_conditional_where] = "preproc_conditional_where",
  [sym_where_condition] = "where_condition",
  [sym_filter_value] = "filter_value",
  [sym_sorting_value] = "sorting_value",
  [sym_link_value_list] = "link_value_list",
  [sym_preproc_conditional_link_values] = "preproc_conditional_link_values",
  [sym_link_value] = "link_value",
  [sym_table_relation_value] = "table_relation_value",
  [sym_preproc_conditional_table_relation] = "preproc_conditional_table_relation",
  [sym__table_relation_branch_content] = "_table_relation_branch_content",
  [sym_else_table_relation_fragment] = "else_table_relation_fragment",
  [sym_table_relation_expression] = "table_relation_expression",
  [sym_if_table_relation] = "if_table_relation",
  [sym_simple_table_relation] = "simple_table_relation",
  [sym_tabledata_permission_list] = "tabledata_permission_list",
  [sym_preproc_conditional_permissions] = "preproc_conditional_permissions",
  [sym_tabledata_permission] = "tabledata_permission",
  [sym_order_by_list] = "order_by_list",
  [sym_order_by_item] = "order_by_item",
  [sym_implementation_value_list] = "implementation_value_list",
  [sym_preproc_conditional_impl_values] = "preproc_conditional_impl_values",
  [sym_implementation_value] = "implementation_value",
  [sym_option_member_list] = "option_member_list",
  [sym_option_member] = "option_member",
  [sym_fields_section] = "fields_section",
  [sym_preproc_conditional_fields] = "preproc_conditional_fields",
  [sym_field_declaration] = "field_declaration",
  [sym_keys_section] = "keys_section",
  [sym_preproc_conditional_keys] = "preproc_conditional_keys",
  [sym_key_declaration] = "key_declaration",
  [sym_field_list] = "field_list",
  [sym_fieldgroups_section] = "fieldgroups_section",
  [sym_addlast_fieldgroup_modification] = "addlast_fieldgroup_modification",
  [sym_addfirst_fieldgroup_modification] = "addfirst_fieldgroup_modification",
  [sym_preproc_conditional_fieldgroups] = "preproc_conditional_fieldgroups",
  [sym_fieldgroup_declaration] = "fieldgroup_declaration",
  [sym_type_specification] = "type_specification",
  [sym_text_type] = "text_type",
  [sym_code_type] = "code_type",
  [sym_option_type] = "option_type",
  [sym_record_type] = "record_type",
  [sym_dotnet_type] = "dotnet_type",
  [sym_object_reference_type] = "object_reference_type",
  [sym__namespaced_or_simple_ref] = "_namespaced_or_simple_ref",
  [sym_array_type] = "array_type",
  [sym_list_type] = "list_type",
  [sym_dictionary_type] = "dictionary_type",
  [sym_basic_type] = "basic_type",
  [sym_enum_value_declaration] = "enum_value_declaration",
  [sym_labels_section] = "labels_section",
  [sym_label_declaration] = "label_declaration",
  [sym_layout_section] = "layout_section",
  [sym__layout_element] = "_layout_element",
  [sym_area_section] = "area_section",
  [sym_preproc_split_brace_close] = "preproc_split_brace_close",
  [sym_preproc_split_brace_close_if_only] = "preproc_split_brace_close_if_only",
  [sym_group_section] = "group_section",
  [sym_repeater_section] = "repeater_section",
  [sym_cuegroup_section] = "cuegroup_section",
  [sym_fixed_section] = "fixed_section",
  [sym_grid_section] = "grid_section",
  [sym_page_field] = "page_field",
  [sym__field_source] = "_field_source",
  [sym_part_section] = "part_section",
  [sym_systempart_section] = "systempart_section",
  [sym_usercontrol_section] = "usercontrol_section",
  [sym_preproc_split_field] = "preproc_split_field",
  [sym_preproc_split_table_field] = "preproc_split_table_field",
  [sym__field_header] = "_field_header",
  [sym__table_field_header] = "_table_field_header",
  [sym_label_section] = "label_section",
  [sym_addfirst_modification] = "addfirst_modification",
  [sym_addlast_modification] = "addlast_modification",
  [sym_addafter_modification] = "addafter_modification",
  [sym_addbefore_modification] = "addbefore_modification",
  [sym_modify_modification] = "modify_modification",
  [sym_movefirst_modification] = "movefirst_modification",
  [sym_movelast_modification] = "movelast_modification",
  [sym_moveafter_modification] = "moveafter_modification",
  [sym_movebefore_modification] = "movebefore_modification",
  [sym_actions_section] = "actions_section",
  [sym__action_element] = "_action_element",
  [sym_action_area_section] = "action_area_section",
  [sym_action_group_section] = "action_group_section",
  [sym_action_declaration] = "action_declaration",
  [sym_separator_action] = "separator_action",
  [sym_actionref_declaration] = "actionref_declaration",
  [sym_systemaction_declaration] = "systemaction_declaration",
  [sym_fileuploadaction_declaration] = "fileuploadaction_declaration",
  [sym_customaction_declaration] = "customaction_declaration",
  [sym_addfirst_action_modification] = "addfirst_action_modification",
  [sym_addlast_action_modification] = "addlast_action_modification",
  [sym_addafter_action_modification] = "addafter_action_modification",
  [sym_addbefore_action_modification] = "addbefore_action_modification",
  [sym_modify_action_modification] = "modify_action_modification",
  [sym_views_section] = "views_section",
  [sym_addfirst_views_modification] = "addfirst_views_modification",
  [sym_addlast_views_modification] = "addlast_views_modification",
  [sym_addafter_views_modification] = "addafter_views_modification",
  [sym_addbefore_views_modification] = "addbefore_views_modification",
  [sym_view_definition] = "view_definition",
  [sym_dataset_section] = "dataset_section",
  [sym_preproc_conditional_dataset] = "preproc_conditional_dataset",
  [sym_report_dataitem] = "report_dataitem",
  [sym__report_body_element] = "_report_body_element",
  [sym_preproc_conditional_report] = "preproc_conditional_report",
  [sym_report_column] = "report_column",
  [sym_add_dataset_modification] = "add_dataset_modification",
  [sym_addfirst_dataset_modification] = "addfirst_dataset_modification",
  [sym_addlast_dataset_modification] = "addlast_dataset_modification",
  [sym_addafter_dataset_modification] = "addafter_dataset_modification",
  [sym_addbefore_dataset_modification] = "addbefore_dataset_modification",
  [sym_requestpage_section] = "requestpage_section",
  [sym_rendering_section] = "rendering_section",
  [sym_rendering_layout] = "rendering_layout",
  [sym_elements_section] = "elements_section",
  [sym_query_dataitem] = "query_dataitem",
  [sym__query_body_element] = "_query_body_element",
  [sym_preproc_conditional_query] = "preproc_conditional_query",
  [sym_query_column] = "query_column",
  [sym_query_filter] = "query_filter",
  [sym_schema_section] = "schema_section",
  [sym_xmlport_element] = "xmlport_element",
  [sym__xmlport_body_element] = "_xmlport_body_element",
  [sym_preproc_conditional_xmlport] = "preproc_conditional_xmlport",
  [sym_xmlport_attribute] = "xmlport_attribute",
  [sym_assembly_declaration] = "assembly_declaration",
  [sym_type_declaration] = "type_declaration",
  [sym_event_declaration] = "event_declaration",
  [sym_procedure] = "procedure",
  [sym_preproc_split_procedure_body] = "preproc_split_procedure_body",
  [sym_preproc_split_complete_body] = "preproc_split_complete_body",
  [sym_preproc_split_procedure] = "preproc_split_procedure",
  [sym__procedure_preamble] = "_procedure_preamble",
  [sym_preproc_split_procedure_preamble] = "preproc_split_procedure_preamble",
  [sym__procedure_header] = "_procedure_header",
  [sym_interface_procedure] = "interface_procedure",
  [sym_interface_procedure_suffix] = "interface_procedure_suffix",
  [sym_procedure_modifier] = "procedure_modifier",
  [sym__procedure_return_specification] = "_procedure_return_specification",
  [sym__procedure_named_return] = "_procedure_named_return",
  [sym_parameter_list] = "parameter_list",
  [sym_parameter] = "parameter",
  [sym_code_block] = "code_block",
  [sym_trigger_declaration] = "trigger_declaration",
  [sym_preproc_conditional_var_block] = "preproc_conditional_var_block",
  [sym__trigger_name] = "_trigger_name",
  [sym_var_section] = "var_section",
  [sym_var_attribute_item] = "var_attribute_item",
  [sym_preproc_conditional_var] = "preproc_conditional_var",
  [sym_variable_declaration] = "variable_declaration",
  [sym_label_attribute] = "label_attribute",
  [sym_attribute_item] = "attribute_item",
  [sym_attribute_content] = "attribute_content",
  [sym_attribute_arguments] = "attribute_arguments",
  [sym_attribute_argument_list] = "attribute_argument_list",
  [sym__attribute_argument] = "_attribute_argument",
  [sym_preproc_conditional] = "preproc_conditional",
  [sym_preproc_if] = "preproc_if",
  [sym__preproc_expression] = "_preproc_expression",
  [sym_preproc_or_expression] = "preproc_or_expression",
  [sym_preproc_and_expression] = "preproc_and_expression",
  [sym_preproc_not_expression] = "preproc_not_expression",
  [sym_preproc_elif] = "preproc_elif",
  [sym_preproc_else] = "preproc_else",
  [sym_preproc_endif] = "preproc_endif",
  [sym_preproc_split_if_statement] = "preproc_split_if_statement",
  [sym__preproc_if_header] = "_preproc_if_header",
  [sym_preproc_guarded_statement] = "preproc_guarded_statement",
  [sym__preproc_guard_block] = "_preproc_guard_block",
  [sym_preproc_split_if_else_statement] = "preproc_split_if_else_statement",
  [sym_preproc_split_if_then_begin] = "preproc_split_if_then_begin",
  [sym_preproc_split_if_begin_asymmetric] = "preproc_split_if_begin_asymmetric",
  [sym_preproc_split_if_begin_else] = "preproc_split_if_begin_else",
  [sym_preproc_split_call_statement] = "preproc_split_call_statement",
  [sym__preproc_call_prefix] = "_preproc_call_prefix",
  [sym_preproc_split_code_block_end] = "preproc_split_code_block_end",
  [sym_preproc_fragmented_else_tail] = "preproc_fragmented_else_tail",
  [sym_preproc_conditional_statement] = "preproc_conditional_statement",
  [sym_preproc_conditional_actions] = "preproc_conditional_actions",
  [sym_preproc_conditional_layout] = "preproc_conditional_layout",
  [sym_preproc_conditional_layout_mixed] = "preproc_conditional_layout_mixed",
  [sym__statement] = "_statement",
  [sym__expression_statement] = "_expression_statement",
  [sym_assignment_statement] = "assignment_statement",
  [sym_assignment_expression] = "assignment_expression",
  [sym_if_statement] = "if_statement",
  [sym__if_statement_no_else] = "if_statement",
  [sym_case_statement] = "case_statement",
  [sym_preproc_conditional_case] = "preproc_conditional_case",
  [sym_case_branch] = "case_branch",
  [sym_preproc_split_case_branch] = "preproc_split_case_branch",
  [sym_preproc_split_case_extended] = "preproc_split_case_extended",
  [aux_sym__case_pattern] = "_case_pattern",
  [sym_preproc_conditional_case_patterns] = "preproc_conditional_case_patterns",
  [sym__single_pattern] = "_single_pattern",
  [sym_case_else_branch] = "case_else_branch",
  [sym_for_statement] = "for_statement",
  [sym_foreach_statement] = "foreach_statement",
  [sym_while_statement] = "while_statement",
  [sym_repeat_statement] = "repeat_statement",
  [sym_with_statement] = "with_statement",
  [sym_exit_statement] = "exit_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [sym_asserterror_statement] = "asserterror_statement",
  [sym__expression] = "_expression",
  [sym_keyword_identifier] = "keyword_identifier",
  [sym_range_expression] = "range_expression",
  [sym_multiplicative_expression] = "multiplicative_expression",
  [sym_additive_expression] = "additive_expression",
  [sym_comparison_expression] = "comparison_expression",
  [sym_comparison_operator] = "comparison_operator",
  [sym_logical_expression] = "logical_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_call_expression] = "call_expression",
  [sym_argument_list] = "argument_list",
  [sym_member_expression] = "member_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_list_literal] = "list_literal",
  [sym_qualified_enum_value] = "qualified_enum_value",
  [sym_database_reference] = "database_reference",
  [sym__literal_value] = "_literal_value",
  [sym_if_keyword] = "if_keyword",
  [sym_then_keyword] = "then_keyword",
  [sym_else_keyword] = "else_keyword",
  [sym_case_keyword] = "case_keyword",
  [sym_of_keyword] = "of_keyword",
  [sym_for_keyword] = "for_keyword",
  [sym_foreach_keyword] = "foreach_keyword",
  [sym_while_keyword] = "while_keyword",
  [sym_do_keyword] = "do_keyword",
  [sym_repeat_keyword] = "repeat_keyword",
  [sym_until_keyword] = "until_keyword",
  [sym_exit_keyword] = "exit_keyword",
  [sym_continue_keyword] = "continue_keyword",
  [sym_break_keyword] = "break_keyword",
  [sym_with_keyword] = "with_keyword",
  [sym_in_keyword] = "in_keyword",
  [sym_to_keyword] = "to_keyword",
  [sym_downto_keyword] = "downto_keyword",
  [sym_tableextension_keyword] = "tableextension_keyword",
  [sym_pageextension_keyword] = "pageextension_keyword",
  [sym_codeunit_keyword] = "codeunit_keyword",
  [sym_reportextension_keyword] = "reportextension_keyword",
  [sym_xmlport_keyword] = "xmlport_keyword",
  [sym_enum_keyword] = "enum_keyword",
  [sym_enumextension_keyword] = "enumextension_keyword",
  [sym_controladdin_keyword] = "controladdin_keyword",
  [sym_dotnet_keyword] = "dotnet_keyword",
  [sym_profileextension_keyword] = "profileextension_keyword",
  [sym_permissionset_keyword] = "permissionset_keyword",
  [sym_permissionsetextension_keyword] = "permissionsetextension_keyword",
  [sym_pagecustomization_keyword] = "pagecustomization_keyword",
  [sym__identifier_or_quoted] = "_identifier_or_quoted",
  [sym_keyword_as_identifier] = "identifier",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_preproc_conditional_object_repeat1] = "preproc_conditional_object_repeat1",
  [aux_sym_namespace_name_repeat1] = "namespace_name_repeat1",
  [aux_sym_preproc_split_declaration_repeat1] = "preproc_split_declaration_repeat1",
  [aux_sym_preproc_split_declaration_repeat2] = "preproc_split_declaration_repeat2",
  [aux_sym_controladdin_declaration_repeat1] = "controladdin_declaration_repeat1",
  [aux_sym_preproc_conditional_controladdin_repeat1] = "preproc_conditional_controladdin_repeat1",
  [aux_sym_interface_declaration_repeat1] = "interface_declaration_repeat1",
  [aux_sym_dotnet_declaration_repeat1] = "dotnet_declaration_repeat1",
  [aux_sym_implements_clause_repeat1] = "implements_clause_repeat1",
  [aux_sym_signed_integer_list_repeat1] = "signed_integer_list_repeat1",
  [aux_sym_caption_value_repeat1] = "caption_value_repeat1",
  [aux_sym_ml_value_list_repeat1] = "ml_value_list_repeat1",
  [aux_sym_calc_field_reference_repeat1] = "calc_field_reference_repeat1",
  [aux_sym_where_conditions_repeat1] = "where_conditions_repeat1",
  [aux_sym_preproc_conditional_where_repeat1] = "preproc_conditional_where_repeat1",
  [aux_sym_preproc_conditional_where_repeat2] = "preproc_conditional_where_repeat2",
  [aux_sym_filter_value_repeat1] = "filter_value_repeat1",
  [aux_sym_sorting_value_repeat1] = "sorting_value_repeat1",
  [aux_sym_link_value_list_repeat1] = "link_value_list_repeat1",
  [aux_sym_preproc_conditional_link_values_repeat1] = "preproc_conditional_link_values_repeat1",
  [aux_sym_preproc_conditional_link_values_repeat2] = "preproc_conditional_link_values_repeat2",
  [aux_sym_preproc_conditional_table_relation_repeat1] = "preproc_conditional_table_relation_repeat1",
  [aux_sym_tabledata_permission_list_repeat1] = "tabledata_permission_list_repeat1",
  [aux_sym_preproc_conditional_permissions_repeat1] = "preproc_conditional_permissions_repeat1",
  [aux_sym_preproc_conditional_permissions_repeat2] = "preproc_conditional_permissions_repeat2",
  [aux_sym_order_by_list_repeat1] = "order_by_list_repeat1",
  [aux_sym_implementation_value_list_repeat1] = "implementation_value_list_repeat1",
  [aux_sym_preproc_conditional_impl_values_repeat1] = "preproc_conditional_impl_values_repeat1",
  [aux_sym_preproc_conditional_impl_values_repeat2] = "preproc_conditional_impl_values_repeat2",
  [aux_sym_option_member_list_repeat1] = "option_member_list_repeat1",
  [aux_sym_option_member_list_repeat2] = "option_member_list_repeat2",
  [aux_sym_fields_section_repeat1] = "fields_section_repeat1",
  [aux_sym_preproc_conditional_fields_repeat1] = "preproc_conditional_fields_repeat1",
  [aux_sym_preproc_conditional_fields_repeat2] = "preproc_conditional_fields_repeat2",
  [aux_sym_keys_section_repeat1] = "keys_section_repeat1",
  [aux_sym_preproc_conditional_keys_repeat1] = "preproc_conditional_keys_repeat1",
  [aux_sym_preproc_conditional_keys_repeat2] = "preproc_conditional_keys_repeat2",
  [aux_sym_fieldgroups_section_repeat1] = "fieldgroups_section_repeat1",
  [aux_sym_preproc_conditional_fieldgroups_repeat1] = "preproc_conditional_fieldgroups_repeat1",
  [aux_sym_preproc_conditional_fieldgroups_repeat2] = "preproc_conditional_fieldgroups_repeat2",
  [aux_sym__namespaced_or_simple_ref_repeat1] = "_namespaced_or_simple_ref_repeat1",
  [aux_sym_array_type_repeat1] = "array_type_repeat1",
  [aux_sym_labels_section_repeat1] = "labels_section_repeat1",
  [aux_sym_label_declaration_repeat1] = "label_declaration_repeat1",
  [aux_sym_layout_section_repeat1] = "layout_section_repeat1",
  [aux_sym_group_section_repeat1] = "group_section_repeat1",
  [aux_sym_preproc_split_field_repeat1] = "preproc_split_field_repeat1",
  [aux_sym_preproc_split_table_field_repeat1] = "preproc_split_table_field_repeat1",
  [aux_sym_actions_section_repeat1] = "actions_section_repeat1",
  [aux_sym_action_group_section_repeat1] = "action_group_section_repeat1",
  [aux_sym_views_section_repeat1] = "views_section_repeat1",
  [aux_sym_addfirst_views_modification_repeat1] = "addfirst_views_modification_repeat1",
  [aux_sym_dataset_section_repeat1] = "dataset_section_repeat1",
  [aux_sym_preproc_conditional_dataset_repeat1] = "preproc_conditional_dataset_repeat1",
  [aux_sym_preproc_conditional_dataset_repeat2] = "preproc_conditional_dataset_repeat2",
  [aux_sym_report_dataitem_repeat1] = "report_dataitem_repeat1",
  [aux_sym_preproc_conditional_report_repeat1] = "preproc_conditional_report_repeat1",
  [aux_sym_add_dataset_modification_repeat1] = "add_dataset_modification_repeat1",
  [aux_sym_rendering_section_repeat1] = "rendering_section_repeat1",
  [aux_sym_elements_section_repeat1] = "elements_section_repeat1",
  [aux_sym_query_dataitem_repeat1] = "query_dataitem_repeat1",
  [aux_sym_preproc_conditional_query_repeat1] = "preproc_conditional_query_repeat1",
  [aux_sym_schema_section_repeat1] = "schema_section_repeat1",
  [aux_sym_xmlport_element_repeat1] = "xmlport_element_repeat1",
  [aux_sym_preproc_conditional_xmlport_repeat1] = "preproc_conditional_xmlport_repeat1",
  [aux_sym_assembly_declaration_repeat1] = "assembly_declaration_repeat1",
  [aux_sym_preproc_split_procedure_body_repeat1] = "preproc_split_procedure_body_repeat1",
  [aux_sym_preproc_split_complete_body_repeat1] = "preproc_split_complete_body_repeat1",
  [aux_sym_preproc_split_procedure_repeat1] = "preproc_split_procedure_repeat1",
  [aux_sym_preproc_split_procedure_preamble_repeat1] = "preproc_split_procedure_preamble_repeat1",
  [aux_sym__procedure_header_repeat1] = "_procedure_header_repeat1",
  [aux_sym_parameter_list_repeat1] = "parameter_list_repeat1",
  [aux_sym_preproc_conditional_var_block_repeat1] = "preproc_conditional_var_block_repeat1",
  [aux_sym_var_section_repeat1] = "var_section_repeat1",
  [aux_sym_preproc_conditional_var_repeat1] = "preproc_conditional_var_repeat1",
  [aux_sym_preproc_conditional_var_repeat2] = "preproc_conditional_var_repeat2",
  [aux_sym_variable_declaration_repeat1] = "variable_declaration_repeat1",
  [aux_sym_variable_declaration_repeat2] = "variable_declaration_repeat2",
  [aux_sym_attribute_argument_list_repeat1] = "attribute_argument_list_repeat1",
  [aux_sym_preproc_conditional_repeat1] = "preproc_conditional_repeat1",
  [aux_sym_preproc_split_if_statement_repeat1] = "preproc_split_if_statement_repeat1",
  [aux_sym__preproc_guard_block_repeat1] = "_preproc_guard_block_repeat1",
  [aux_sym_preproc_split_if_else_statement_repeat1] = "preproc_split_if_else_statement_repeat1",
  [aux_sym_preproc_split_call_statement_repeat1] = "preproc_split_call_statement_repeat1",
  [aux_sym_preproc_split_call_statement_repeat2] = "preproc_split_call_statement_repeat2",
  [aux_sym_preproc_conditional_statement_repeat1] = "preproc_conditional_statement_repeat1",
  [aux_sym_preproc_conditional_actions_repeat1] = "preproc_conditional_actions_repeat1",
  [aux_sym_preproc_conditional_layout_repeat1] = "preproc_conditional_layout_repeat1",
  [aux_sym_preproc_conditional_layout_mixed_repeat1] = "preproc_conditional_layout_mixed_repeat1",
  [aux_sym_preproc_conditional_layout_mixed_repeat2] = "preproc_conditional_layout_mixed_repeat2",
  [aux_sym_case_statement_repeat1] = "case_statement_repeat1",
  [aux_sym_preproc_conditional_case_repeat1] = "preproc_conditional_case_repeat1",
  [aux_sym_preproc_conditional_case_repeat2] = "preproc_conditional_case_repeat2",
  [aux_sym_preproc_split_case_branch_repeat1] = "preproc_split_case_branch_repeat1",
  [aux_sym_preproc_split_case_branch_repeat2] = "preproc_split_case_branch_repeat2",
  [aux_sym_preproc_split_case_extended_repeat1] = "preproc_split_case_extended_repeat1",
  [alias_sym_aggregate_function] = "aggregate_function",
  [alias_sym_object_type_keyword] = "object_type_keyword",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_interface_declaration_token1] = aux_sym_interface_declaration_token1,
  [anon_sym_EQ] = anon_sym_EQ,
  [aux_sym_interface_declaration_token2] = aux_sym_interface_declaration_token2,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_DASH] = anon_sym_DASH,
  [aux_sym_boolean_token1] = aux_sym_boolean_token1,
  [aux_sym_boolean_token2] = aux_sym_boolean_token2,
  [sym_decimal] = sym_decimal,
  [aux_sym_ml_value_list_token1] = aux_sym_ml_value_list_token1,
  [aux_sym_lookup_formula_token1] = aux_sym_lookup_formula_token1,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [aux_sym_where_clause_token1] = aux_sym_where_clause_token1,
  [aux_sym_where_condition_token1] = aux_sym_where_condition_token1,
  [aux_sym_where_condition_token2] = aux_sym_where_condition_token2,
  [aux_sym_where_condition_token3] = aux_sym_where_condition_token3,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [aux_sym_filter_value_token1] = aux_sym_filter_value_token1,
  [aux_sym_sorting_value_token1] = aux_sym_sorting_value_token1,
  [aux_sym_sorting_value_token2] = aux_sym_sorting_value_token2,
  [aux_sym_sorting_value_token3] = aux_sym_sorting_value_token3,
  [aux_sym_sorting_value_token4] = aux_sym_sorting_value_token4,
  [aux_sym_else_table_relation_fragment_token1] = aux_sym_else_table_relation_fragment_token1,
  [aux_sym_if_table_relation_token1] = aux_sym_if_table_relation_token1,
  [aux_sym_tabledata_permission_token1] = aux_sym_tabledata_permission_token1,
  [aux_sym_tabledata_permission_token2] = aux_sym_tabledata_permission_token2,
  [anon_sym_STAR] = anon_sym_STAR,
  [sym_permission_type] = sym_permission_type,
  [aux_sym_order_by_item_token1] = aux_sym_order_by_item_token1,
  [aux_sym_order_by_item_token2] = aux_sym_order_by_item_token2,
  [aux_sym_addlast_fieldgroup_modification_token1] = aux_sym_addlast_fieldgroup_modification_token1,
  [aux_sym_addfirst_fieldgroup_modification_token1] = aux_sym_addfirst_fieldgroup_modification_token1,
  [aux_sym_text_type_token1] = aux_sym_text_type_token1,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [aux_sym_code_type_token1] = aux_sym_code_type_token1,
  [aux_sym_option_type_token1] = aux_sym_option_type_token1,
  [aux_sym_record_type_token1] = aux_sym_record_type_token1,
  [aux_sym_object_reference_type_token1] = aux_sym_object_reference_type_token1,
  [aux_sym_object_reference_type_token2] = aux_sym_object_reference_type_token2,
  [aux_sym_array_type_token1] = aux_sym_array_type_token1,
  [aux_sym_array_type_token2] = aux_sym_array_type_token2,
  [aux_sym_list_type_token1] = aux_sym_list_type_token1,
  [aux_sym_dictionary_type_token1] = aux_sym_dictionary_type_token1,
  [aux_sym_basic_type_token1] = aux_sym_basic_type_token1,
  [aux_sym_basic_type_token2] = aux_sym_basic_type_token2,
  [aux_sym_basic_type_token3] = aux_sym_basic_type_token3,
  [aux_sym_basic_type_token4] = aux_sym_basic_type_token4,
  [aux_sym_basic_type_token5] = aux_sym_basic_type_token5,
  [aux_sym_basic_type_token6] = aux_sym_basic_type_token6,
  [aux_sym_basic_type_token7] = aux_sym_basic_type_token7,
  [aux_sym_basic_type_token8] = aux_sym_basic_type_token8,
  [aux_sym_basic_type_token9] = aux_sym_basic_type_token9,
  [aux_sym_basic_type_token10] = aux_sym_basic_type_token10,
  [aux_sym_basic_type_token11] = aux_sym_basic_type_token11,
  [aux_sym_basic_type_token12] = aux_sym_basic_type_token12,
  [aux_sym_basic_type_token13] = aux_sym_basic_type_token13,
  [aux_sym_basic_type_token14] = aux_sym_basic_type_token14,
  [aux_sym_basic_type_token15] = aux_sym_basic_type_token15,
  [aux_sym_basic_type_token16] = aux_sym_basic_type_token16,
  [aux_sym_basic_type_token17] = aux_sym_basic_type_token17,
  [aux_sym_basic_type_token18] = aux_sym_basic_type_token18,
  [aux_sym_basic_type_token19] = aux_sym_basic_type_token19,
  [aux_sym_basic_type_token20] = aux_sym_basic_type_token20,
  [aux_sym_basic_type_token21] = aux_sym_basic_type_token21,
  [aux_sym_basic_type_token22] = aux_sym_basic_type_token22,
  [aux_sym_basic_type_token23] = aux_sym_basic_type_token23,
  [aux_sym_basic_type_token24] = aux_sym_basic_type_token24,
  [aux_sym_basic_type_token25] = aux_sym_basic_type_token25,
  [aux_sym_basic_type_token26] = aux_sym_basic_type_token26,
  [aux_sym_basic_type_token27] = aux_sym_basic_type_token27,
  [aux_sym_basic_type_token28] = aux_sym_basic_type_token28,
  [aux_sym_basic_type_token29] = aux_sym_basic_type_token29,
  [aux_sym_basic_type_token30] = aux_sym_basic_type_token30,
  [aux_sym_basic_type_token31] = aux_sym_basic_type_token31,
  [aux_sym_basic_type_token32] = aux_sym_basic_type_token32,
  [aux_sym_basic_type_token33] = aux_sym_basic_type_token33,
  [aux_sym_basic_type_token34] = aux_sym_basic_type_token34,
  [aux_sym_basic_type_token35] = aux_sym_basic_type_token35,
  [aux_sym_basic_type_token36] = aux_sym_basic_type_token36,
  [aux_sym_basic_type_token37] = aux_sym_basic_type_token37,
  [aux_sym_basic_type_token38] = aux_sym_basic_type_token38,
  [aux_sym_basic_type_token39] = aux_sym_basic_type_token39,
  [aux_sym_basic_type_token40] = aux_sym_basic_type_token40,
  [aux_sym_basic_type_token41] = aux_sym_basic_type_token41,
  [aux_sym_basic_type_token42] = aux_sym_basic_type_token42,
  [aux_sym_basic_type_token43] = aux_sym_basic_type_token43,
  [aux_sym_basic_type_token44] = aux_sym_basic_type_token44,
  [aux_sym_basic_type_token45] = aux_sym_basic_type_token45,
  [aux_sym_basic_type_token46] = aux_sym_basic_type_token46,
  [aux_sym_basic_type_token47] = aux_sym_basic_type_token47,
  [aux_sym_basic_type_token48] = aux_sym_basic_type_token48,
  [aux_sym_basic_type_token49] = aux_sym_basic_type_token49,
  [aux_sym_basic_type_token50] = aux_sym_basic_type_token50,
  [aux_sym_basic_type_token51] = aux_sym_basic_type_token51,
  [aux_sym_basic_type_token52] = aux_sym_basic_type_token52,
  [aux_sym_basic_type_token53] = aux_sym_basic_type_token53,
  [aux_sym_basic_type_token54] = aux_sym_basic_type_token54,
  [aux_sym_enum_value_declaration_token1] = aux_sym_enum_value_declaration_token1,
  [aux_sym_label_declaration_token1] = aux_sym_label_declaration_token1,
  [aux_sym_label_declaration_token2] = aux_sym_label_declaration_token2,
  [aux_sym_area_section_token1] = aux_sym_area_section_token1,
  [aux_sym_area_section_token2] = aux_sym_area_section_token2,
  [aux_sym_area_section_token3] = aux_sym_area_section_token3,
  [aux_sym_area_section_token4] = aux_sym_area_section_token4,
  [aux_sym_area_section_token5] = aux_sym_area_section_token5,
  [aux_sym_area_section_token6] = aux_sym_area_section_token6,
  [aux_sym_area_section_token7] = aux_sym_area_section_token7,
  [aux_sym_area_section_token8] = aux_sym_area_section_token8,
  [aux_sym_addafter_modification_token1] = aux_sym_addafter_modification_token1,
  [aux_sym_addbefore_modification_token1] = aux_sym_addbefore_modification_token1,
  [aux_sym_modify_modification_token1] = aux_sym_modify_modification_token1,
  [aux_sym_movefirst_modification_token1] = aux_sym_movefirst_modification_token1,
  [aux_sym_movelast_modification_token1] = aux_sym_movelast_modification_token1,
  [aux_sym_moveafter_modification_token1] = aux_sym_moveafter_modification_token1,
  [aux_sym_movebefore_modification_token1] = aux_sym_movebefore_modification_token1,
  [aux_sym_action_area_section_token1] = aux_sym_action_area_section_token1,
  [aux_sym_action_area_section_token2] = aux_sym_action_area_section_token2,
  [aux_sym_action_area_section_token3] = aux_sym_action_area_section_token3,
  [aux_sym_action_area_section_token4] = aux_sym_action_area_section_token4,
  [aux_sym_action_area_section_token5] = aux_sym_action_area_section_token5,
  [aux_sym_action_area_section_token6] = aux_sym_action_area_section_token6,
  [aux_sym_action_area_section_token7] = aux_sym_action_area_section_token7,
  [aux_sym_separator_action_token1] = aux_sym_separator_action_token1,
  [aux_sym_actionref_declaration_token1] = aux_sym_actionref_declaration_token1,
  [aux_sym_systemaction_declaration_token1] = aux_sym_systemaction_declaration_token1,
  [aux_sym_fileuploadaction_declaration_token1] = aux_sym_fileuploadaction_declaration_token1,
  [aux_sym_customaction_declaration_token1] = aux_sym_customaction_declaration_token1,
  [aux_sym_add_dataset_modification_token1] = aux_sym_add_dataset_modification_token1,
  [aux_sym_xmlport_element_token1] = aux_sym_xmlport_element_token1,
  [aux_sym_xmlport_element_token2] = aux_sym_xmlport_element_token2,
  [aux_sym_xmlport_element_token3] = aux_sym_xmlport_element_token3,
  [aux_sym_xmlport_attribute_token1] = aux_sym_xmlport_attribute_token1,
  [aux_sym_xmlport_attribute_token2] = aux_sym_xmlport_attribute_token2,
  [aux_sym_assembly_declaration_token1] = aux_sym_assembly_declaration_token1,
  [sym_dotnet_assembly_name] = sym_dotnet_assembly_name,
  [aux_sym_type_declaration_token1] = aux_sym_type_declaration_token1,
  [aux_sym_preproc_split_procedure_body_token1] = aux_sym_preproc_split_procedure_body_token1,
  [aux_sym_preproc_split_procedure_body_token2] = aux_sym_preproc_split_procedure_body_token2,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_POUNDif] = anon_sym_POUNDif,
  [anon_sym_POUNDIF] = anon_sym_POUNDIF,
  [anon_sym_POUNDIf] = anon_sym_POUNDIf,
  [aux_sym_preproc_or_expression_token1] = aux_sym_preproc_or_expression_token1,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [aux_sym_preproc_and_expression_token1] = aux_sym_preproc_and_expression_token1,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_NOT] = anon_sym_NOT,
  [anon_sym_Not] = anon_sym_Not,
  [anon_sym_POUNDelif] = anon_sym_POUNDelif,
  [anon_sym_POUNDELIF] = anon_sym_POUNDELIF,
  [anon_sym_POUNDElif] = anon_sym_POUNDElif,
  [anon_sym_POUNDelse] = anon_sym_POUNDelse,
  [anon_sym_POUNDELSE] = anon_sym_POUNDELSE,
  [anon_sym_POUNDElse] = anon_sym_POUNDElse,
  [anon_sym_POUNDelse2] = anon_sym_POUNDelse2,
  [anon_sym_POUNDELSE2] = anon_sym_POUNDELSE2,
  [anon_sym_POUNDElse2] = anon_sym_POUNDElse2,
  [anon_sym_POUNDendif] = anon_sym_POUNDendif,
  [anon_sym_POUNDENDIF] = anon_sym_POUNDENDIF,
  [anon_sym_POUNDEndif] = anon_sym_POUNDEndif,
  [anon_sym_POUNDendif2] = anon_sym_POUNDendif2,
  [anon_sym_POUNDENDIF2] = anon_sym_POUNDENDIF2,
  [anon_sym_POUNDEndif2] = anon_sym_POUNDEndif2,
  [sym_pragma] = sym_pragma,
  [sym_preproc_region] = sym_preproc_region,
  [sym_preproc_endregion] = sym_preproc_endregion,
  [sym__assignment_operator] = sym__assignment_operator,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [aux_sym__expression_token1] = aux_sym__expression_token1,
  [aux_sym__expression_token2] = aux_sym__expression_token2,
  [aux_sym_keyword_identifier_token1] = aux_sym_keyword_identifier_token1,
  [aux_sym_keyword_identifier_token2] = aux_sym_keyword_identifier_token2,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_div] = anon_sym_div,
  [anon_sym_DIV] = anon_sym_DIV,
  [anon_sym_Div] = anon_sym_Div,
  [anon_sym_mod] = anon_sym_mod,
  [anon_sym_MOD] = anon_sym_MOD,
  [anon_sym_Mod] = anon_sym_Mod,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_GT] = anon_sym_LT_GT,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_AND] = anon_sym_AND,
  [anon_sym_And] = anon_sym_And,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_OR] = anon_sym_OR,
  [anon_sym_Or] = anon_sym_Or,
  [anon_sym_xor] = anon_sym_xor,
  [anon_sym_XOR] = anon_sym_XOR,
  [anon_sym_Xor] = anon_sym_Xor,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [sym_datetime_literal] = sym_datetime_literal,
  [sym_date_literal] = sym_date_literal,
  [sym_time_literal] = sym_time_literal,
  [sym_biginteger_literal] = sym_biginteger_literal,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_IF] = anon_sym_IF,
  [anon_sym_If] = anon_sym_If,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_THEN] = anon_sym_THEN,
  [anon_sym_Then] = anon_sym_Then,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_ELSE] = anon_sym_ELSE,
  [anon_sym_Else] = anon_sym_Else,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_CASE] = anon_sym_CASE,
  [anon_sym_Case] = anon_sym_Case,
  [anon_sym_of] = anon_sym_of,
  [anon_sym_OF] = anon_sym_OF,
  [anon_sym_Of] = anon_sym_Of,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_FOR] = anon_sym_FOR,
  [anon_sym_For] = anon_sym_For,
  [anon_sym_foreach] = anon_sym_foreach,
  [anon_sym_FOREACH] = anon_sym_FOREACH,
  [anon_sym_Foreach] = anon_sym_Foreach,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_WHILE] = anon_sym_WHILE,
  [anon_sym_While] = anon_sym_While,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_DO] = anon_sym_DO,
  [anon_sym_Do] = anon_sym_Do,
  [anon_sym_repeat] = anon_sym_repeat,
  [anon_sym_REPEAT] = anon_sym_REPEAT,
  [anon_sym_Repeat] = anon_sym_Repeat,
  [anon_sym_until] = anon_sym_until,
  [anon_sym_UNTIL] = anon_sym_UNTIL,
  [anon_sym_Until] = anon_sym_Until,
  [anon_sym_exit] = anon_sym_exit,
  [anon_sym_EXIT] = anon_sym_EXIT,
  [anon_sym_Exit] = anon_sym_Exit,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_CONTINUE] = anon_sym_CONTINUE,
  [anon_sym_Continue] = anon_sym_Continue,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_BREAK] = anon_sym_BREAK,
  [anon_sym_Break] = anon_sym_Break,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_WITH] = anon_sym_WITH,
  [anon_sym_With] = anon_sym_With,
  [sym_asserterror_keyword] = sym_asserterror_keyword,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_IN] = anon_sym_IN,
  [anon_sym_In] = anon_sym_In,
  [anon_sym_to] = anon_sym_to,
  [anon_sym_TO] = anon_sym_TO,
  [anon_sym_To] = anon_sym_To,
  [anon_sym_downto] = anon_sym_downto,
  [anon_sym_DOWNTO] = anon_sym_DOWNTO,
  [anon_sym_Downto] = anon_sym_Downto,
  [sym_table_keyword] = sym_table_keyword,
  [anon_sym_tableextension] = anon_sym_tableextension,
  [anon_sym_TABLEEXTENSION] = anon_sym_TABLEEXTENSION,
  [anon_sym_Tableextension] = anon_sym_Tableextension,
  [anon_sym_TableExtension] = anon_sym_TableExtension,
  [anon_sym_tableExtension] = anon_sym_tableExtension,
  [sym_page_keyword] = sym_page_keyword,
  [anon_sym_pageextension] = anon_sym_pageextension,
  [anon_sym_PAGEEXTENSION] = anon_sym_PAGEEXTENSION,
  [anon_sym_Pageextension] = anon_sym_Pageextension,
  [anon_sym_PageExtension] = anon_sym_PageExtension,
  [anon_sym_pageExtension] = anon_sym_pageExtension,
  [anon_sym_codeunit] = anon_sym_codeunit,
  [anon_sym_CODEUNIT] = anon_sym_CODEUNIT,
  [anon_sym_Codeunit] = anon_sym_Codeunit,
  [anon_sym_CodeUnit] = anon_sym_CodeUnit,
  [anon_sym_COdeunit] = anon_sym_COdeunit,
  [anon_sym_codeUnit] = anon_sym_codeUnit,
  [sym_report_keyword] = sym_report_keyword,
  [anon_sym_reportextension] = anon_sym_reportextension,
  [anon_sym_REPORTEXTENSION] = anon_sym_REPORTEXTENSION,
  [anon_sym_Reportextension] = anon_sym_Reportextension,
  [anon_sym_ReportExtension] = anon_sym_ReportExtension,
  [anon_sym_reportExtension] = anon_sym_reportExtension,
  [sym_query_keyword] = sym_query_keyword,
  [anon_sym_xmlport] = anon_sym_xmlport,
  [anon_sym_XMLPORT] = anon_sym_XMLPORT,
  [anon_sym_Xmlport] = anon_sym_Xmlport,
  [anon_sym_XMLport] = anon_sym_XMLport,
  [anon_sym_XMLPort] = anon_sym_XMLPort,
  [anon_sym_XmlPort] = anon_sym_XmlPort,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_ENUM] = anon_sym_ENUM,
  [anon_sym_Enum] = anon_sym_Enum,
  [anon_sym_eNUM] = anon_sym_eNUM,
  [anon_sym_eNum] = anon_sym_eNum,
  [anon_sym_ENum] = anon_sym_ENum,
  [anon_sym_enumextension] = anon_sym_enumextension,
  [anon_sym_ENUMEXTENSION] = anon_sym_ENUMEXTENSION,
  [anon_sym_Enumextension] = anon_sym_Enumextension,
  [anon_sym_EnumExtension] = anon_sym_EnumExtension,
  [anon_sym_enumExtension] = anon_sym_enumExtension,
  [sym_interface_keyword] = sym_interface_keyword,
  [anon_sym_controladdin] = anon_sym_controladdin,
  [anon_sym_CONTROLADDIN] = anon_sym_CONTROLADDIN,
  [anon_sym_Controladdin] = anon_sym_Controladdin,
  [anon_sym_ControlAddIn] = anon_sym_ControlAddIn,
  [anon_sym_ControlAddin] = anon_sym_ControlAddin,
  [anon_sym_controlAddIn] = anon_sym_controlAddIn,
  [anon_sym_controlAddin] = anon_sym_controlAddin,
  [anon_sym_dotnet] = anon_sym_dotnet,
  [anon_sym_DOTNET] = anon_sym_DOTNET,
  [anon_sym_Dotnet] = anon_sym_Dotnet,
  [anon_sym_DotNet] = anon_sym_DotNet,
  [anon_sym_dotNet] = anon_sym_dotNet,
  [sym_profile_keyword] = sym_profile_keyword,
  [anon_sym_profileextension] = anon_sym_profileextension,
  [anon_sym_PROFILEEXTENSION] = anon_sym_PROFILEEXTENSION,
  [anon_sym_Profileextension] = anon_sym_Profileextension,
  [anon_sym_ProfileExtension] = anon_sym_ProfileExtension,
  [anon_sym_profileExtension] = anon_sym_profileExtension,
  [anon_sym_permissionset] = anon_sym_permissionset,
  [anon_sym_PERMISSIONSET] = anon_sym_PERMISSIONSET,
  [anon_sym_Permissionset] = anon_sym_Permissionset,
  [anon_sym_PermissionSet] = anon_sym_PermissionSet,
  [anon_sym_permissionSet] = anon_sym_permissionSet,
  [anon_sym_permissionsetextension] = anon_sym_permissionsetextension,
  [anon_sym_PERMISSIONSETEXTENSION] = anon_sym_PERMISSIONSETEXTENSION,
  [anon_sym_Permissionsetextension] = anon_sym_Permissionsetextension,
  [anon_sym_PermissionSetExtension] = anon_sym_PermissionSetExtension,
  [anon_sym_permissionSetExtension] = anon_sym_permissionSetExtension,
  [sym_entitlement_keyword] = sym_entitlement_keyword,
  [anon_sym_pagecustomization] = anon_sym_pagecustomization,
  [anon_sym_PAGECUSTOMIZATION] = anon_sym_PAGECUSTOMIZATION,
  [anon_sym_Pagecustomization] = anon_sym_Pagecustomization,
  [anon_sym_PageCustomization] = anon_sym_PageCustomization,
  [anon_sym_pageCustomization] = anon_sym_pageCustomization,
  [sym_namespace_keyword] = sym_namespace_keyword,
  [sym_using_keyword] = sym_using_keyword,
  [sym_implements_keyword] = sym_implements_keyword,
  [sym_extends_keyword] = sym_extends_keyword,
  [sym_customizes_keyword] = sym_customizes_keyword,
  [sym_procedure_keyword] = sym_procedure_keyword,
  [sym_trigger_keyword] = sym_trigger_keyword,
  [sym_var_keyword] = sym_var_keyword,
  [sym_local_keyword] = sym_local_keyword,
  [sym_internal_keyword] = sym_internal_keyword,
  [sym_protected_keyword] = sym_protected_keyword,
  [sym_event_keyword] = sym_event_keyword,
  [sym_temporary_keyword] = sym_temporary_keyword,
  [sym_fields_keyword] = sym_fields_keyword,
  [sym_keys_keyword] = sym_keys_keyword,
  [sym_key_keyword] = sym_key_keyword,
  [sym_fieldgroups_keyword] = sym_fieldgroups_keyword,
  [sym_fieldgroup_keyword] = sym_fieldgroup_keyword,
  [sym_actions_keyword] = sym_actions_keyword,
  [sym_layout_keyword] = sym_layout_keyword,
  [sym_area_keyword] = sym_area_keyword,
  [sym_group_keyword] = sym_group_keyword,
  [sym_repeater_keyword] = sym_repeater_keyword,
  [sym_cuegroup_keyword] = sym_cuegroup_keyword,
  [sym_fixed_keyword] = sym_fixed_keyword,
  [sym_grid_keyword] = sym_grid_keyword,
  [sym_part_keyword] = sym_part_keyword,
  [sym_systempart_keyword] = sym_systempart_keyword,
  [sym_usercontrol_keyword] = sym_usercontrol_keyword,
  [sym_dataset_keyword] = sym_dataset_keyword,
  [sym_elements_keyword] = sym_elements_keyword,
  [sym_dataitem_keyword] = sym_dataitem_keyword,
  [sym_column_keyword] = sym_column_keyword,
  [sym_filter_keyword] = sym_filter_keyword,
  [sym_labels_keyword] = sym_labels_keyword,
  [sym_rendering_keyword] = sym_rendering_keyword,
  [sym_requestpage_keyword] = sym_requestpage_keyword,
  [sym_schema_keyword] = sym_schema_keyword,
  [sym_views_keyword] = sym_views_keyword,
  [sym_view_keyword] = sym_view_keyword,
  [sym_quoted_identifier] = sym_quoted_identifier,
  [sym_comment] = sym_comment,
  [sym_multiline_comment] = sym_multiline_comment,
  [sym_string_literal] = sym_string_literal,
  [sym_verbatim_string] = sym_verbatim_string,
  [sym_integer] = sym_integer,
  [sym_property_name] = sym_property_name,
  [sym_continue_as_identifier] = sym_identifier,
  [sym_preproc_open] = sym_preproc_open,
  [sym_preproc_close] = sym_preproc_close,
  [sym_begin_keyword] = sym_begin_keyword,
  [sym_end_keyword] = sym_end_keyword,
  [sym_preproc_split_begin] = sym_preproc_split_begin,
  [sym_preproc_split_end] = sym_preproc_split_end,
  [sym_var_attribute_open] = sym_var_attribute_open,
  [sym_source_file] = sym_source_file,
  [sym_preproc_conditional_object] = sym_preproc_conditional_object,
  [sym_namespace_declaration] = sym_namespace_declaration,
  [sym_using_statement] = sym_using_statement,
  [sym_namespace_name] = sym_namespace_name,
  [sym__object] = sym__object,
  [sym_preproc_split_declaration] = sym_preproc_split_declaration,
  [sym__object_header] = sym__object_header,
  [sym_table_declaration] = sym_table_declaration,
  [sym_page_declaration] = sym_page_declaration,
  [sym_report_declaration] = sym_report_declaration,
  [sym_query_declaration] = sym_query_declaration,
  [sym_xmlport_declaration] = sym_xmlport_declaration,
  [sym_permissionset_declaration] = sym_permissionset_declaration,
  [sym_codeunit_declaration] = sym_codeunit_declaration,
  [sym_enum_declaration] = sym_enum_declaration,
  [sym_tableextension_declaration] = sym_tableextension_declaration,
  [sym_pageextension_declaration] = sym_pageextension_declaration,
  [sym_reportextension_declaration] = sym_reportextension_declaration,
  [sym_enumextension_declaration] = sym_enumextension_declaration,
  [sym_permissionsetextension_declaration] = sym_permissionsetextension_declaration,
  [sym_controladdin_declaration] = sym_controladdin_declaration,
  [sym_preproc_conditional_controladdin] = sym_preproc_conditional_controladdin,
  [sym_profile_declaration] = sym_profile_declaration,
  [sym_entitlement_declaration] = sym_entitlement_declaration,
  [sym_profileextension_declaration] = sym_profileextension_declaration,
  [sym_interface_declaration] = sym_interface_declaration,
  [sym_pagecustomization_declaration] = sym_pagecustomization_declaration,
  [sym_dotnet_declaration] = sym_dotnet_declaration,
  [sym_implements_clause] = sym_implements_clause,
  [sym__body_element] = sym__body_element,
  [sym_empty_statement] = sym_empty_statement,
  [sym_property] = sym_property,
  [sym_permissions_property] = sym_property,
  [sym_table_relation_property] = sym_property,
  [sym__property_value] = sym__property_value,
  [sym_decimal_range_value] = sym_decimal_range_value,
  [sym_signed_integer_list] = sym_signed_integer_list,
  [sym__signed_integer] = sym__signed_integer,
  [sym_object_reference_value] = sym_object_reference_value,
  [sym_property_expression] = sym_property_expression,
  [sym_boolean] = sym_boolean,
  [sym_caption_value] = sym_caption_value,
  [sym_ml_value_list] = sym_ml_value_list,
  [sym_ml_value_pair] = sym_ml_value_pair,
  [sym__calc_formula_expression] = sym__calc_formula_expression,
  [sym_lookup_formula] = sym_lookup_formula,
  [sym_aggregate_formula] = sym_aggregate_formula,
  [sym_calc_field_reference] = sym_calc_field_reference,
  [sym_where_clause] = sym_where_clause,
  [sym_where_conditions] = sym_where_conditions,
  [sym_preproc_conditional_where] = sym_preproc_conditional_where,
  [sym_where_condition] = sym_where_condition,
  [sym_filter_value] = sym_filter_value,
  [sym_sorting_value] = sym_sorting_value,
  [sym_link_value_list] = sym_link_value_list,
  [sym_preproc_conditional_link_values] = sym_preproc_conditional_link_values,
  [sym_link_value] = sym_link_value,
  [sym_table_relation_value] = sym_table_relation_value,
  [sym_preproc_conditional_table_relation] = sym_preproc_conditional_table_relation,
  [sym__table_relation_branch_content] = sym__table_relation_branch_content,
  [sym_else_table_relation_fragment] = sym_else_table_relation_fragment,
  [sym_table_relation_expression] = sym_table_relation_expression,
  [sym_if_table_relation] = sym_if_table_relation,
  [sym_simple_table_relation] = sym_simple_table_relation,
  [sym_tabledata_permission_list] = sym_tabledata_permission_list,
  [sym_preproc_conditional_permissions] = sym_preproc_conditional_permissions,
  [sym_tabledata_permission] = sym_tabledata_permission,
  [sym_order_by_list] = sym_order_by_list,
  [sym_order_by_item] = sym_order_by_item,
  [sym_implementation_value_list] = sym_implementation_value_list,
  [sym_preproc_conditional_impl_values] = sym_preproc_conditional_impl_values,
  [sym_implementation_value] = sym_implementation_value,
  [sym_option_member_list] = sym_option_member_list,
  [sym_option_member] = sym_option_member,
  [sym_fields_section] = sym_fields_section,
  [sym_preproc_conditional_fields] = sym_preproc_conditional_fields,
  [sym_field_declaration] = sym_field_declaration,
  [sym_keys_section] = sym_keys_section,
  [sym_preproc_conditional_keys] = sym_preproc_conditional_keys,
  [sym_key_declaration] = sym_key_declaration,
  [sym_field_list] = sym_field_list,
  [sym_fieldgroups_section] = sym_fieldgroups_section,
  [sym_addlast_fieldgroup_modification] = sym_addlast_fieldgroup_modification,
  [sym_addfirst_fieldgroup_modification] = sym_addfirst_fieldgroup_modification,
  [sym_preproc_conditional_fieldgroups] = sym_preproc_conditional_fieldgroups,
  [sym_fieldgroup_declaration] = sym_fieldgroup_declaration,
  [sym_type_specification] = sym_type_specification,
  [sym_text_type] = sym_text_type,
  [sym_code_type] = sym_code_type,
  [sym_option_type] = sym_option_type,
  [sym_record_type] = sym_record_type,
  [sym_dotnet_type] = sym_dotnet_type,
  [sym_object_reference_type] = sym_object_reference_type,
  [sym__namespaced_or_simple_ref] = sym__namespaced_or_simple_ref,
  [sym_array_type] = sym_array_type,
  [sym_list_type] = sym_list_type,
  [sym_dictionary_type] = sym_dictionary_type,
  [sym_basic_type] = sym_basic_type,
  [sym_enum_value_declaration] = sym_enum_value_declaration,
  [sym_labels_section] = sym_labels_section,
  [sym_label_declaration] = sym_label_declaration,
  [sym_layout_section] = sym_layout_section,
  [sym__layout_element] = sym__layout_element,
  [sym_area_section] = sym_area_section,
  [sym_preproc_split_brace_close] = sym_preproc_split_brace_close,
  [sym_preproc_split_brace_close_if_only] = sym_preproc_split_brace_close_if_only,
  [sym_group_section] = sym_group_section,
  [sym_repeater_section] = sym_repeater_section,
  [sym_cuegroup_section] = sym_cuegroup_section,
  [sym_fixed_section] = sym_fixed_section,
  [sym_grid_section] = sym_grid_section,
  [sym_page_field] = sym_page_field,
  [sym__field_source] = sym__field_source,
  [sym_part_section] = sym_part_section,
  [sym_systempart_section] = sym_systempart_section,
  [sym_usercontrol_section] = sym_usercontrol_section,
  [sym_preproc_split_field] = sym_preproc_split_field,
  [sym_preproc_split_table_field] = sym_preproc_split_table_field,
  [sym__field_header] = sym__field_header,
  [sym__table_field_header] = sym__table_field_header,
  [sym_label_section] = sym_label_section,
  [sym_addfirst_modification] = sym_addfirst_modification,
  [sym_addlast_modification] = sym_addlast_modification,
  [sym_addafter_modification] = sym_addafter_modification,
  [sym_addbefore_modification] = sym_addbefore_modification,
  [sym_modify_modification] = sym_modify_modification,
  [sym_movefirst_modification] = sym_movefirst_modification,
  [sym_movelast_modification] = sym_movelast_modification,
  [sym_moveafter_modification] = sym_moveafter_modification,
  [sym_movebefore_modification] = sym_movebefore_modification,
  [sym_actions_section] = sym_actions_section,
  [sym__action_element] = sym__action_element,
  [sym_action_area_section] = sym_action_area_section,
  [sym_action_group_section] = sym_action_group_section,
  [sym_action_declaration] = sym_action_declaration,
  [sym_separator_action] = sym_separator_action,
  [sym_actionref_declaration] = sym_actionref_declaration,
  [sym_systemaction_declaration] = sym_systemaction_declaration,
  [sym_fileuploadaction_declaration] = sym_fileuploadaction_declaration,
  [sym_customaction_declaration] = sym_customaction_declaration,
  [sym_addfirst_action_modification] = sym_addfirst_action_modification,
  [sym_addlast_action_modification] = sym_addlast_action_modification,
  [sym_addafter_action_modification] = sym_addafter_action_modification,
  [sym_addbefore_action_modification] = sym_addbefore_action_modification,
  [sym_modify_action_modification] = sym_modify_action_modification,
  [sym_views_section] = sym_views_section,
  [sym_addfirst_views_modification] = sym_addfirst_views_modification,
  [sym_addlast_views_modification] = sym_addlast_views_modification,
  [sym_addafter_views_modification] = sym_addafter_views_modification,
  [sym_addbefore_views_modification] = sym_addbefore_views_modification,
  [sym_view_definition] = sym_view_definition,
  [sym_dataset_section] = sym_dataset_section,
  [sym_preproc_conditional_dataset] = sym_preproc_conditional_dataset,
  [sym_report_dataitem] = sym_report_dataitem,
  [sym__report_body_element] = sym__report_body_element,
  [sym_preproc_conditional_report] = sym_preproc_conditional_report,
  [sym_report_column] = sym_report_column,
  [sym_add_dataset_modification] = sym_add_dataset_modification,
  [sym_addfirst_dataset_modification] = sym_addfirst_dataset_modification,
  [sym_addlast_dataset_modification] = sym_addlast_dataset_modification,
  [sym_addafter_dataset_modification] = sym_addafter_dataset_modification,
  [sym_addbefore_dataset_modification] = sym_addbefore_dataset_modification,
  [sym_requestpage_section] = sym_requestpage_section,
  [sym_rendering_section] = sym_rendering_section,
  [sym_rendering_layout] = sym_rendering_layout,
  [sym_elements_section] = sym_elements_section,
  [sym_query_dataitem] = sym_query_dataitem,
  [sym__query_body_element] = sym__query_body_element,
  [sym_preproc_conditional_query] = sym_preproc_conditional_query,
  [sym_query_column] = sym_query_column,
  [sym_query_filter] = sym_query_filter,
  [sym_schema_section] = sym_schema_section,
  [sym_xmlport_element] = sym_xmlport_element,
  [sym__xmlport_body_element] = sym__xmlport_body_element,
  [sym_preproc_conditional_xmlport] = sym_preproc_conditional_xmlport,
  [sym_xmlport_attribute] = sym_xmlport_attribute,
  [sym_assembly_declaration] = sym_assembly_declaration,
  [sym_type_declaration] = sym_type_declaration,
  [sym_event_declaration] = sym_event_declaration,
  [sym_procedure] = sym_procedure,
  [sym_preproc_split_procedure_body] = sym_preproc_split_procedure_body,
  [sym_preproc_split_complete_body] = sym_preproc_split_complete_body,
  [sym_preproc_split_procedure] = sym_preproc_split_procedure,
  [sym__procedure_preamble] = sym__procedure_preamble,
  [sym_preproc_split_procedure_preamble] = sym_preproc_split_procedure_preamble,
  [sym__procedure_header] = sym__procedure_header,
  [sym_interface_procedure] = sym_interface_procedure,
  [sym_interface_procedure_suffix] = sym_interface_procedure_suffix,
  [sym_procedure_modifier] = sym_procedure_modifier,
  [sym__procedure_return_specification] = sym__procedure_return_specification,
  [sym__procedure_named_return] = sym__procedure_named_return,
  [sym_parameter_list] = sym_parameter_list,
  [sym_parameter] = sym_parameter,
  [sym_code_block] = sym_code_block,
  [sym_trigger_declaration] = sym_trigger_declaration,
  [sym_preproc_conditional_var_block] = sym_preproc_conditional_var_block,
  [sym__trigger_name] = sym__trigger_name,
  [sym_var_section] = sym_var_section,
  [sym_var_attribute_item] = sym_var_attribute_item,
  [sym_preproc_conditional_var] = sym_preproc_conditional_var,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_label_attribute] = sym_label_attribute,
  [sym_attribute_item] = sym_attribute_item,
  [sym_attribute_content] = sym_attribute_content,
  [sym_attribute_arguments] = sym_attribute_arguments,
  [sym_attribute_argument_list] = sym_attribute_argument_list,
  [sym__attribute_argument] = sym__attribute_argument,
  [sym_preproc_conditional] = sym_preproc_conditional,
  [sym_preproc_if] = sym_preproc_if,
  [sym__preproc_expression] = sym__preproc_expression,
  [sym_preproc_or_expression] = sym_preproc_or_expression,
  [sym_preproc_and_expression] = sym_preproc_and_expression,
  [sym_preproc_not_expression] = sym_preproc_not_expression,
  [sym_preproc_elif] = sym_preproc_elif,
  [sym_preproc_else] = sym_preproc_else,
  [sym_preproc_endif] = sym_preproc_endif,
  [sym_preproc_split_if_statement] = sym_preproc_split_if_statement,
  [sym__preproc_if_header] = sym__preproc_if_header,
  [sym_preproc_guarded_statement] = sym_preproc_guarded_statement,
  [sym__preproc_guard_block] = sym__preproc_guard_block,
  [sym_preproc_split_if_else_statement] = sym_preproc_split_if_else_statement,
  [sym_preproc_split_if_then_begin] = sym_preproc_split_if_then_begin,
  [sym_preproc_split_if_begin_asymmetric] = sym_preproc_split_if_begin_asymmetric,
  [sym_preproc_split_if_begin_else] = sym_preproc_split_if_begin_else,
  [sym_preproc_split_call_statement] = sym_preproc_split_call_statement,
  [sym__preproc_call_prefix] = sym__preproc_call_prefix,
  [sym_preproc_split_code_block_end] = sym_preproc_split_code_block_end,
  [sym_preproc_fragmented_else_tail] = sym_preproc_fragmented_else_tail,
  [sym_preproc_conditional_statement] = sym_preproc_conditional_statement,
  [sym_preproc_conditional_actions] = sym_preproc_conditional_actions,
  [sym_preproc_conditional_layout] = sym_preproc_conditional_layout,
  [sym_preproc_conditional_layout_mixed] = sym_preproc_conditional_layout_mixed,
  [sym__statement] = sym__statement,
  [sym__expression_statement] = sym__expression_statement,
  [sym_assignment_statement] = sym_assignment_statement,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_if_statement] = sym_if_statement,
  [sym__if_statement_no_else] = sym_if_statement,
  [sym_case_statement] = sym_case_statement,
  [sym_preproc_conditional_case] = sym_preproc_conditional_case,
  [sym_case_branch] = sym_case_branch,
  [sym_preproc_split_case_branch] = sym_preproc_split_case_branch,
  [sym_preproc_split_case_extended] = sym_preproc_split_case_extended,
  [aux_sym__case_pattern] = aux_sym__case_pattern,
  [sym_preproc_conditional_case_patterns] = sym_preproc_conditional_case_patterns,
  [sym__single_pattern] = sym__single_pattern,
  [sym_case_else_branch] = sym_case_else_branch,
  [sym_for_statement] = sym_for_statement,
  [sym_foreach_statement] = sym_foreach_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_repeat_statement] = sym_repeat_statement,
  [sym_with_statement] = sym_with_statement,
  [sym_exit_statement] = sym_exit_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_asserterror_statement] = sym_asserterror_statement,
  [sym__expression] = sym__expression,
  [sym_keyword_identifier] = sym_keyword_identifier,
  [sym_range_expression] = sym_range_expression,
  [sym_multiplicative_expression] = sym_multiplicative_expression,
  [sym_additive_expression] = sym_additive_expression,
  [sym_comparison_expression] = sym_comparison_expression,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_logical_expression] = sym_logical_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_argument_list] = sym_argument_list,
  [sym_member_expression] = sym_member_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_list_literal] = sym_list_literal,
  [sym_qualified_enum_value] = sym_qualified_enum_value,
  [sym_database_reference] = sym_database_reference,
  [sym__literal_value] = sym__literal_value,
  [sym_if_keyword] = sym_if_keyword,
  [sym_then_keyword] = sym_then_keyword,
  [sym_else_keyword] = sym_else_keyword,
  [sym_case_keyword] = sym_case_keyword,
  [sym_of_keyword] = sym_of_keyword,
  [sym_for_keyword] = sym_for_keyword,
  [sym_foreach_keyword] = sym_foreach_keyword,
  [sym_while_keyword] = sym_while_keyword,
  [sym_do_keyword] = sym_do_keyword,
  [sym_repeat_keyword] = sym_repeat_keyword,
  [sym_until_keyword] = sym_until_keyword,
  [sym_exit_keyword] = sym_exit_keyword,
  [sym_continue_keyword] = sym_continue_keyword,
  [sym_break_keyword] = sym_break_keyword,
  [sym_with_keyword] = sym_with_keyword,
  [sym_in_keyword] = sym_in_keyword,
  [sym_to_keyword] = sym_to_keyword,
  [sym_downto_keyword] = sym_downto_keyword,
  [sym_tableextension_keyword] = sym_tableextension_keyword,
  [sym_pageextension_keyword] = sym_pageextension_keyword,
  [sym_codeunit_keyword] = sym_codeunit_keyword,
  [sym_reportextension_keyword] = sym_reportextension_keyword,
  [sym_xmlport_keyword] = sym_xmlport_keyword,
  [sym_enum_keyword] = sym_enum_keyword,
  [sym_enumextension_keyword] = sym_enumextension_keyword,
  [sym_controladdin_keyword] = sym_controladdin_keyword,
  [sym_dotnet_keyword] = sym_dotnet_keyword,
  [sym_profileextension_keyword] = sym_profileextension_keyword,
  [sym_permissionset_keyword] = sym_permissionset_keyword,
  [sym_permissionsetextension_keyword] = sym_permissionsetextension_keyword,
  [sym_pagecustomization_keyword] = sym_pagecustomization_keyword,
  [sym__identifier_or_quoted] = sym__identifier_or_quoted,
  [sym_keyword_as_identifier] = sym_identifier,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_preproc_conditional_object_repeat1] = aux_sym_preproc_conditional_object_repeat1,
  [aux_sym_namespace_name_repeat1] = aux_sym_namespace_name_repeat1,
  [aux_sym_preproc_split_declaration_repeat1] = aux_sym_preproc_split_declaration_repeat1,
  [aux_sym_preproc_split_declaration_repeat2] = aux_sym_preproc_split_declaration_repeat2,
  [aux_sym_controladdin_declaration_repeat1] = aux_sym_controladdin_declaration_repeat1,
  [aux_sym_preproc_conditional_controladdin_repeat1] = aux_sym_preproc_conditional_controladdin_repeat1,
  [aux_sym_interface_declaration_repeat1] = aux_sym_interface_declaration_repeat1,
  [aux_sym_dotnet_declaration_repeat1] = aux_sym_dotnet_declaration_repeat1,
  [aux_sym_implements_clause_repeat1] = aux_sym_implements_clause_repeat1,
  [aux_sym_signed_integer_list_repeat1] = aux_sym_signed_integer_list_repeat1,
  [aux_sym_caption_value_repeat1] = aux_sym_caption_value_repeat1,
  [aux_sym_ml_value_list_repeat1] = aux_sym_ml_value_list_repeat1,
  [aux_sym_calc_field_reference_repeat1] = aux_sym_calc_field_reference_repeat1,
  [aux_sym_where_conditions_repeat1] = aux_sym_where_conditions_repeat1,
  [aux_sym_preproc_conditional_where_repeat1] = aux_sym_preproc_conditional_where_repeat1,
  [aux_sym_preproc_conditional_where_repeat2] = aux_sym_preproc_conditional_where_repeat2,
  [aux_sym_filter_value_repeat1] = aux_sym_filter_value_repeat1,
  [aux_sym_sorting_value_repeat1] = aux_sym_sorting_value_repeat1,
  [aux_sym_link_value_list_repeat1] = aux_sym_link_value_list_repeat1,
  [aux_sym_preproc_conditional_link_values_repeat1] = aux_sym_preproc_conditional_link_values_repeat1,
  [aux_sym_preproc_conditional_link_values_repeat2] = aux_sym_preproc_conditional_link_values_repeat2,
  [aux_sym_preproc_conditional_table_relation_repeat1] = aux_sym_preproc_conditional_table_relation_repeat1,
  [aux_sym_tabledata_permission_list_repeat1] = aux_sym_tabledata_permission_list_repeat1,
  [aux_sym_preproc_conditional_permissions_repeat1] = aux_sym_preproc_conditional_permissions_repeat1,
  [aux_sym_preproc_conditional_permissions_repeat2] = aux_sym_preproc_conditional_permissions_repeat2,
  [aux_sym_order_by_list_repeat1] = aux_sym_order_by_list_repeat1,
  [aux_sym_implementation_value_list_repeat1] = aux_sym_implementation_value_list_repeat1,
  [aux_sym_preproc_conditional_impl_values_repeat1] = aux_sym_preproc_conditional_impl_values_repeat1,
  [aux_sym_preproc_conditional_impl_values_repeat2] = aux_sym_preproc_conditional_impl_values_repeat2,
  [aux_sym_option_member_list_repeat1] = aux_sym_option_member_list_repeat1,
  [aux_sym_option_member_list_repeat2] = aux_sym_option_member_list_repeat2,
  [aux_sym_fields_section_repeat1] = aux_sym_fields_section_repeat1,
  [aux_sym_preproc_conditional_fields_repeat1] = aux_sym_preproc_conditional_fields_repeat1,
  [aux_sym_preproc_conditional_fields_repeat2] = aux_sym_preproc_conditional_fields_repeat2,
  [aux_sym_keys_section_repeat1] = aux_sym_keys_section_repeat1,
  [aux_sym_preproc_conditional_keys_repeat1] = aux_sym_preproc_conditional_keys_repeat1,
  [aux_sym_preproc_conditional_keys_repeat2] = aux_sym_preproc_conditional_keys_repeat2,
  [aux_sym_fieldgroups_section_repeat1] = aux_sym_fieldgroups_section_repeat1,
  [aux_sym_preproc_conditional_fieldgroups_repeat1] = aux_sym_preproc_conditional_fieldgroups_repeat1,
  [aux_sym_preproc_conditional_fieldgroups_repeat2] = aux_sym_preproc_conditional_fieldgroups_repeat2,
  [aux_sym__namespaced_or_simple_ref_repeat1] = aux_sym__namespaced_or_simple_ref_repeat1,
  [aux_sym_array_type_repeat1] = aux_sym_array_type_repeat1,
  [aux_sym_labels_section_repeat1] = aux_sym_labels_section_repeat1,
  [aux_sym_label_declaration_repeat1] = aux_sym_label_declaration_repeat1,
  [aux_sym_layout_section_repeat1] = aux_sym_layout_section_repeat1,
  [aux_sym_group_section_repeat1] = aux_sym_group_section_repeat1,
  [aux_sym_preproc_split_field_repeat1] = aux_sym_preproc_split_field_repeat1,
  [aux_sym_preproc_split_table_field_repeat1] = aux_sym_preproc_split_table_field_repeat1,
  [aux_sym_actions_section_repeat1] = aux_sym_actions_section_repeat1,
  [aux_sym_action_group_section_repeat1] = aux_sym_action_group_section_repeat1,
  [aux_sym_views_section_repeat1] = aux_sym_views_section_repeat1,
  [aux_sym_addfirst_views_modification_repeat1] = aux_sym_addfirst_views_modification_repeat1,
  [aux_sym_dataset_section_repeat1] = aux_sym_dataset_section_repeat1,
  [aux_sym_preproc_conditional_dataset_repeat1] = aux_sym_preproc_conditional_dataset_repeat1,
  [aux_sym_preproc_conditional_dataset_repeat2] = aux_sym_preproc_conditional_dataset_repeat2,
  [aux_sym_report_dataitem_repeat1] = aux_sym_report_dataitem_repeat1,
  [aux_sym_preproc_conditional_report_repeat1] = aux_sym_preproc_conditional_report_repeat1,
  [aux_sym_add_dataset_modification_repeat1] = aux_sym_add_dataset_modification_repeat1,
  [aux_sym_rendering_section_repeat1] = aux_sym_rendering_section_repeat1,
  [aux_sym_elements_section_repeat1] = aux_sym_elements_section_repeat1,
  [aux_sym_query_dataitem_repeat1] = aux_sym_query_dataitem_repeat1,
  [aux_sym_preproc_conditional_query_repeat1] = aux_sym_preproc_conditional_query_repeat1,
  [aux_sym_schema_section_repeat1] = aux_sym_schema_section_repeat1,
  [aux_sym_xmlport_element_repeat1] = aux_sym_xmlport_element_repeat1,
  [aux_sym_preproc_conditional_xmlport_repeat1] = aux_sym_preproc_conditional_xmlport_repeat1,
  [aux_sym_assembly_declaration_repeat1] = aux_sym_assembly_declaration_repeat1,
  [aux_sym_preproc_split_procedure_body_repeat1] = aux_sym_preproc_split_procedure_body_repeat1,
  [aux_sym_preproc_split_complete_body_repeat1] = aux_sym_preproc_split_complete_body_repeat1,
  [aux_sym_preproc_split_procedure_repeat1] = aux_sym_preproc_split_procedure_repeat1,
  [aux_sym_preproc_split_procedure_preamble_repeat1] = aux_sym_preproc_split_procedure_preamble_repeat1,
  [aux_sym__procedure_header_repeat1] = aux_sym__procedure_header_repeat1,
  [aux_sym_parameter_list_repeat1] = aux_sym_parameter_list_repeat1,
  [aux_sym_preproc_conditional_var_block_repeat1] = aux_sym_preproc_conditional_var_block_repeat1,
  [aux_sym_var_section_repeat1] = aux_sym_var_section_repeat1,
  [aux_sym_preproc_conditional_var_repeat1] = aux_sym_preproc_conditional_var_repeat1,
  [aux_sym_preproc_conditional_var_repeat2] = aux_sym_preproc_conditional_var_repeat2,
  [aux_sym_variable_declaration_repeat1] = aux_sym_variable_declaration_repeat1,
  [aux_sym_variable_declaration_repeat2] = aux_sym_variable_declaration_repeat2,
  [aux_sym_attribute_argument_list_repeat1] = aux_sym_attribute_argument_list_repeat1,
  [aux_sym_preproc_conditional_repeat1] = aux_sym_preproc_conditional_repeat1,
  [aux_sym_preproc_split_if_statement_repeat1] = aux_sym_preproc_split_if_statement_repeat1,
  [aux_sym__preproc_guard_block_repeat1] = aux_sym__preproc_guard_block_repeat1,
  [aux_sym_preproc_split_if_else_statement_repeat1] = aux_sym_preproc_split_if_else_statement_repeat1,
  [aux_sym_preproc_split_call_statement_repeat1] = aux_sym_preproc_split_call_statement_repeat1,
  [aux_sym_preproc_split_call_statement_repeat2] = aux_sym_preproc_split_call_statement_repeat2,
  [aux_sym_preproc_conditional_statement_repeat1] = aux_sym_preproc_conditional_statement_repeat1,
  [aux_sym_preproc_conditional_actions_repeat1] = aux_sym_preproc_conditional_actions_repeat1,
  [aux_sym_preproc_conditional_layout_repeat1] = aux_sym_preproc_conditional_layout_repeat1,
  [aux_sym_preproc_conditional_layout_mixed_repeat1] = aux_sym_preproc_conditional_layout_mixed_repeat1,
  [aux_sym_preproc_conditional_layout_mixed_repeat2] = aux_sym_preproc_conditional_layout_mixed_repeat2,
  [aux_sym_case_statement_repeat1] = aux_sym_case_statement_repeat1,
  [aux_sym_preproc_conditional_case_repeat1] = aux_sym_preproc_conditional_case_repeat1,
  [aux_sym_preproc_conditional_case_repeat2] = aux_sym_preproc_conditional_case_repeat2,
  [aux_sym_preproc_split_case_branch_repeat1] = aux_sym_preproc_split_case_branch_repeat1,
  [aux_sym_preproc_split_case_branch_repeat2] = aux_sym_preproc_split_case_branch_repeat2,
  [aux_sym_preproc_split_case_extended_repeat1] = aux_sym_preproc_split_case_extended_repeat1,
  [alias_sym_aggregate_function] = alias_sym_aggregate_function,
  [alias_sym_object_type_keyword] = alias_sym_object_type_keyword,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_interface_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_interface_declaration_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_boolean_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_boolean_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_decimal] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_ml_value_list_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_lookup_formula_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_where_clause_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_condition_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_condition_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_condition_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_filter_value_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_else_table_relation_fragment_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_table_relation_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tabledata_permission_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tabledata_permission_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [sym_permission_type] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_order_by_item_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_order_by_item_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addlast_fieldgroup_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addfirst_fieldgroup_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_text_type_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_code_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_option_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_reference_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_reference_type_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_type_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dictionary_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token8] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token9] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token10] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token11] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token12] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token13] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token14] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token15] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token16] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token17] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token18] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token19] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token20] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token21] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token22] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token23] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token24] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token25] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token26] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token27] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token28] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token29] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token30] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token31] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token32] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token33] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token34] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token35] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token36] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token37] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token38] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token39] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token40] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token41] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token42] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token43] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token44] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token45] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token46] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token47] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token48] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token49] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token50] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token51] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token52] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token53] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_basic_type_token54] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_value_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_label_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_label_declaration_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_area_section_token8] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addafter_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addbefore_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modify_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_movefirst_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_movelast_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_moveafter_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_movebefore_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_area_section_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_separator_action_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_actionref_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_systemaction_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fileuploadaction_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_customaction_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_add_dataset_modification_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_element_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_element_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_element_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_attribute_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_attribute_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assembly_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_dotnet_assembly_name] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_type_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_body_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_body_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDIF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDIf] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_or_expression_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_and_expression_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDelif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDELIF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDElif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDelse] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDELSE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDElse] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDelse2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDELSE2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDElse2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDendif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDENDIF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDEndif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDendif2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDENDIF2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDEndif2] = {
    .visible = true,
    .named = false,
  },
  [sym_pragma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_region] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_endregion] = {
    .visible = true,
    .named = true,
  },
  [sym__assignment_operator] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__expression_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__expression_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keyword_identifier_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keyword_identifier_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_div] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DIV] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Div] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_MOD] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Mod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_And] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_OR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XOR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [sym_datetime_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_date_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_time_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_biginteger_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_IF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_If] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_THEN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ELSE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CASE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_OF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FOR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_For] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreach] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FOREACH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Foreach] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_WHILE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_While] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DO] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_repeat] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_REPEAT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Repeat] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_until] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_UNTIL] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Until] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EXIT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Exit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CONTINUE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BREAK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_WITH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_With] = {
    .visible = true,
    .named = false,
  },
  [sym_asserterror_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_IN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_In] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_to] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TO] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_To] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_downto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOWNTO] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Downto] = {
    .visible = true,
    .named = false,
  },
  [sym_table_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_tableextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TABLEEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Tableextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TableExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tableExtension] = {
    .visible = true,
    .named = false,
  },
  [sym_page_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_pageextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PAGEEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Pageextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PageExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pageExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_codeunit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CODEUNIT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Codeunit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CodeUnit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COdeunit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_codeUnit] = {
    .visible = true,
    .named = false,
  },
  [sym_report_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_reportextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_REPORTEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Reportextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ReportExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_reportExtension] = {
    .visible = true,
    .named = false,
  },
  [sym_query_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_xmlport] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XMLPORT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Xmlport] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XMLport] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XMLPort] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_XmlPort] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENUM] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_eNUM] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_eNum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENUMEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Enumextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EnumExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumExtension] = {
    .visible = true,
    .named = false,
  },
  [sym_interface_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_controladdin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CONTROLADDIN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Controladdin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ControlAddIn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ControlAddin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_controlAddIn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_controlAddin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dotnet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOTNET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Dotnet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DotNet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dotNet] = {
    .visible = true,
    .named = false,
  },
  [sym_profile_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_profileextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PROFILEEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Profileextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ProfileExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_profileExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permissionset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERMISSIONSET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Permissionset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PermissionSet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permissionSet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permissionsetextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERMISSIONSETEXTENSION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Permissionsetextension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PermissionSetExtension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permissionSetExtension] = {
    .visible = true,
    .named = false,
  },
  [sym_entitlement_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_pagecustomization] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PAGECUSTOMIZATION] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Pagecustomization] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PageCustomization] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pageCustomization] = {
    .visible = true,
    .named = false,
  },
  [sym_namespace_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_using_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_implements_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_extends_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_customizes_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_procedure_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_trigger_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_var_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_local_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_internal_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_protected_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_event_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_temporary_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_fields_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_keys_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_key_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_fieldgroups_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_fieldgroup_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_actions_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_layout_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_area_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_group_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_repeater_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_cuegroup_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_fixed_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_grid_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_part_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_systempart_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_usercontrol_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_dataset_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_elements_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_dataitem_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_column_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_filter_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_labels_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_rendering_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_requestpage_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_schema_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_views_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_view_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_multiline_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_verbatim_string] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_as_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_open] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_close] = {
    .visible = true,
    .named = true,
  },
  [sym_begin_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_end_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_begin] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_end] = {
    .visible = true,
    .named = true,
  },
  [sym_var_attribute_open] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_object] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_using_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_name] = {
    .visible = true,
    .named = true,
  },
  [sym__object] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_split_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__object_header] = {
    .visible = false,
    .named = true,
  },
  [sym_table_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_page_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_report_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_query_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_xmlport_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_permissionset_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_codeunit_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_tableextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_pageextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_reportextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enumextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_permissionsetextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_controladdin_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_controladdin] = {
    .visible = true,
    .named = true,
  },
  [sym_profile_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_entitlement_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_profileextension_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_pagecustomization_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_dotnet_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_implements_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__body_element] = {
    .visible = false,
    .named = true,
  },
  [sym_empty_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym_permissions_property] = {
    .visible = true,
    .named = true,
  },
  [sym_table_relation_property] = {
    .visible = true,
    .named = true,
  },
  [sym__property_value] = {
    .visible = false,
    .named = true,
  },
  [sym_decimal_range_value] = {
    .visible = true,
    .named = true,
  },
  [sym_signed_integer_list] = {
    .visible = true,
    .named = true,
  },
  [sym__signed_integer] = {
    .visible = false,
    .named = true,
  },
  [sym_object_reference_value] = {
    .visible = true,
    .named = true,
  },
  [sym_property_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_caption_value] = {
    .visible = true,
    .named = true,
  },
  [sym_ml_value_list] = {
    .visible = true,
    .named = true,
  },
  [sym_ml_value_pair] = {
    .visible = true,
    .named = true,
  },
  [sym__calc_formula_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_lookup_formula] = {
    .visible = true,
    .named = true,
  },
  [sym_aggregate_formula] = {
    .visible = true,
    .named = true,
  },
  [sym_calc_field_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_where_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_where_conditions] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_where] = {
    .visible = true,
    .named = true,
  },
  [sym_where_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_filter_value] = {
    .visible = true,
    .named = true,
  },
  [sym_sorting_value] = {
    .visible = true,
    .named = true,
  },
  [sym_link_value_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_link_values] = {
    .visible = true,
    .named = true,
  },
  [sym_link_value] = {
    .visible = true,
    .named = true,
  },
  [sym_table_relation_value] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_table_relation] = {
    .visible = true,
    .named = true,
  },
  [sym__table_relation_branch_content] = {
    .visible = false,
    .named = true,
  },
  [sym_else_table_relation_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym_table_relation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_if_table_relation] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_table_relation] = {
    .visible = true,
    .named = true,
  },
  [sym_tabledata_permission_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_permissions] = {
    .visible = true,
    .named = true,
  },
  [sym_tabledata_permission] = {
    .visible = true,
    .named = true,
  },
  [sym_order_by_list] = {
    .visible = true,
    .named = true,
  },
  [sym_order_by_item] = {
    .visible = true,
    .named = true,
  },
  [sym_implementation_value_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_impl_values] = {
    .visible = true,
    .named = true,
  },
  [sym_implementation_value] = {
    .visible = true,
    .named = true,
  },
  [sym_option_member_list] = {
    .visible = true,
    .named = true,
  },
  [sym_option_member] = {
    .visible = true,
    .named = true,
  },
  [sym_fields_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_fields] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_keys_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_keys] = {
    .visible = true,
    .named = true,
  },
  [sym_key_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_field_list] = {
    .visible = true,
    .named = true,
  },
  [sym_fieldgroups_section] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_fieldgroup_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_fieldgroup_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_fieldgroups] = {
    .visible = true,
    .named = true,
  },
  [sym_fieldgroup_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_text_type] = {
    .visible = true,
    .named = true,
  },
  [sym_code_type] = {
    .visible = true,
    .named = true,
  },
  [sym_option_type] = {
    .visible = true,
    .named = true,
  },
  [sym_record_type] = {
    .visible = true,
    .named = true,
  },
  [sym_dotnet_type] = {
    .visible = true,
    .named = true,
  },
  [sym_object_reference_type] = {
    .visible = true,
    .named = true,
  },
  [sym__namespaced_or_simple_ref] = {
    .visible = false,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_list_type] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary_type] = {
    .visible = true,
    .named = true,
  },
  [sym_basic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_value_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_labels_section] = {
    .visible = true,
    .named = true,
  },
  [sym_label_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_layout_section] = {
    .visible = true,
    .named = true,
  },
  [sym__layout_element] = {
    .visible = false,
    .named = true,
  },
  [sym_area_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_brace_close] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_brace_close_if_only] = {
    .visible = true,
    .named = true,
  },
  [sym_group_section] = {
    .visible = true,
    .named = true,
  },
  [sym_repeater_section] = {
    .visible = true,
    .named = true,
  },
  [sym_cuegroup_section] = {
    .visible = true,
    .named = true,
  },
  [sym_fixed_section] = {
    .visible = true,
    .named = true,
  },
  [sym_grid_section] = {
    .visible = true,
    .named = true,
  },
  [sym_page_field] = {
    .visible = true,
    .named = true,
  },
  [sym__field_source] = {
    .visible = false,
    .named = true,
  },
  [sym_part_section] = {
    .visible = true,
    .named = true,
  },
  [sym_systempart_section] = {
    .visible = true,
    .named = true,
  },
  [sym_usercontrol_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_field] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_table_field] = {
    .visible = true,
    .named = true,
  },
  [sym__field_header] = {
    .visible = false,
    .named = true,
  },
  [sym__table_field_header] = {
    .visible = false,
    .named = true,
  },
  [sym_label_section] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addafter_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addbefore_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_modify_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_movefirst_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_movelast_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_moveafter_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_movebefore_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_actions_section] = {
    .visible = true,
    .named = true,
  },
  [sym__action_element] = {
    .visible = false,
    .named = true,
  },
  [sym_action_area_section] = {
    .visible = true,
    .named = true,
  },
  [sym_action_group_section] = {
    .visible = true,
    .named = true,
  },
  [sym_action_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_separator_action] = {
    .visible = true,
    .named = true,
  },
  [sym_actionref_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_systemaction_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_fileuploadaction_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_customaction_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addafter_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addbefore_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_modify_action_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_views_section] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_views_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_views_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addafter_views_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addbefore_views_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_view_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_dataset_section] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_dataset] = {
    .visible = true,
    .named = true,
  },
  [sym_report_dataitem] = {
    .visible = true,
    .named = true,
  },
  [sym__report_body_element] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_conditional_report] = {
    .visible = true,
    .named = true,
  },
  [sym_report_column] = {
    .visible = true,
    .named = true,
  },
  [sym_add_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addfirst_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addlast_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addafter_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_addbefore_dataset_modification] = {
    .visible = true,
    .named = true,
  },
  [sym_requestpage_section] = {
    .visible = true,
    .named = true,
  },
  [sym_rendering_section] = {
    .visible = true,
    .named = true,
  },
  [sym_rendering_layout] = {
    .visible = true,
    .named = true,
  },
  [sym_elements_section] = {
    .visible = true,
    .named = true,
  },
  [sym_query_dataitem] = {
    .visible = true,
    .named = true,
  },
  [sym__query_body_element] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_conditional_query] = {
    .visible = true,
    .named = true,
  },
  [sym_query_column] = {
    .visible = true,
    .named = true,
  },
  [sym_query_filter] = {
    .visible = true,
    .named = true,
  },
  [sym_schema_section] = {
    .visible = true,
    .named = true,
  },
  [sym_xmlport_element] = {
    .visible = true,
    .named = true,
  },
  [sym__xmlport_body_element] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_conditional_xmlport] = {
    .visible = true,
    .named = true,
  },
  [sym_xmlport_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_assembly_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_event_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_procedure] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_procedure_body] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_complete_body] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_procedure] = {
    .visible = true,
    .named = true,
  },
  [sym__procedure_preamble] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_split_procedure_preamble] = {
    .visible = true,
    .named = true,
  },
  [sym__procedure_header] = {
    .visible = false,
    .named = true,
  },
  [sym_interface_procedure] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_procedure_suffix] = {
    .visible = true,
    .named = true,
  },
  [sym_procedure_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym__procedure_return_specification] = {
    .visible = false,
    .named = true,
  },
  [sym__procedure_named_return] = {
    .visible = false,
    .named = true,
  },
  [sym_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_code_block] = {
    .visible = true,
    .named = true,
  },
  [sym_trigger_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_var_block] = {
    .visible = true,
    .named = true,
  },
  [sym__trigger_name] = {
    .visible = false,
    .named = true,
  },
  [sym_var_section] = {
    .visible = true,
    .named = true,
  },
  [sym_var_attribute_item] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_var] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_label_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_item] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_content] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym__attribute_argument] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_conditional] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_or_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_and_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_not_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_endif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_if_header] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_guarded_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_guard_block] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_split_if_else_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_if_then_begin] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_if_begin_asymmetric] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_if_begin_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_call_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_call_prefix] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_split_code_block_end] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_fragmented_else_tail] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_actions] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_layout] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_layout_mixed] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__if_statement_no_else] = {
    .visible = true,
    .named = true,
  },
  [sym_case_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_conditional_case] = {
    .visible = true,
    .named = true,
  },
  [sym_case_branch] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_case_branch] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_split_case_extended] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__case_pattern] = {
    .visible = false,
    .named = false,
  },
  [sym_preproc_conditional_case_patterns] = {
    .visible = true,
    .named = true,
  },
  [sym__single_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_case_else_branch] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_with_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_exit_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_asserterror_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym_keyword_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_multiplicative_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_additive_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_list_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_enum_value] = {
    .visible = true,
    .named = true,
  },
  [sym_database_reference] = {
    .visible = true,
    .named = true,
  },
  [sym__literal_value] = {
    .visible = false,
    .named = true,
  },
  [sym_if_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_then_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_else_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_case_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_of_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_for_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_while_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_do_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_until_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_exit_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_break_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_with_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_in_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_to_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_downto_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_tableextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_pageextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_codeunit_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_reportextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_xmlport_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_enumextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_controladdin_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_dotnet_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_profileextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_permissionset_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_permissionsetextension_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_pagecustomization_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym__identifier_or_quoted] = {
    .visible = false,
    .named = true,
  },
  [sym_keyword_as_identifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_object_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_namespace_name_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_controladdin_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_controladdin_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interface_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dotnet_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_implements_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_signed_integer_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_caption_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_ml_value_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_calc_field_reference_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_conditions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_where_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_where_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filter_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sorting_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_link_value_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_link_values_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_link_values_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_table_relation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tabledata_permission_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_permissions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_permissions_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_order_by_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_implementation_value_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_impl_values_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_impl_values_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_option_member_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_option_member_list_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fields_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_fields_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_fields_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keys_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_keys_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_keys_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fieldgroups_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_fieldgroups_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_fieldgroups_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__namespaced_or_simple_ref_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_labels_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_label_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_layout_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_group_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_field_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_table_field_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_actions_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_action_group_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_views_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_addfirst_views_modification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dataset_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_dataset_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_dataset_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_report_dataitem_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_report_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_add_dataset_modification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_rendering_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elements_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_query_dataitem_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_query_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_schema_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_xmlport_element_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_xmlport_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assembly_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_complete_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_procedure_preamble_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__procedure_header_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_var_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_var_section_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_var_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_var_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__preproc_guard_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_if_else_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_call_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_call_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_actions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_layout_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_layout_mixed_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_layout_mixed_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_case_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_conditional_case_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_case_branch_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_case_branch_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_split_case_extended_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_aggregate_function] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_object_type_keyword] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_access_value = 1,
  field_action_name = 2,
  field_al_name = 3,
  field_arguments = 4,
  field_attribute = 5,
  field_attribute_type = 6,
  field_base_object = 7,
  field_body = 8,
  field_comment = 9,
  field_condition = 10,
  field_direction = 11,
  field_dotnet_type = 12,
  field_element = 13,
  field_element_type = 14,
  field_else_branch = 15,
  field_else_relation = 16,
  field_else_value = 17,
  field_end = 18,
  field_enum_type = 19,
  field_expression = 20,
  field_extends_interface = 21,
  field_field = 22,
  field_field_name = 23,
  field_fields = 24,
  field_function = 25,
  field_id = 26,
  field_implementation = 27,
  field_index = 28,
  field_interface = 29,
  field_iterable = 30,
  field_key_type = 31,
  field_keyword = 32,
  field_language = 33,
  field_left = 34,
  field_length = 35,
  field_locked = 36,
  field_max = 37,
  field_maxlength = 38,
  field_member = 39,
  field_min = 40,
  field_modifier = 41,
  field_name = 42,
  field_namespace = 43,
  field_object = 44,
  field_object_id = 45,
  field_object_name = 46,
  field_object_type = 47,
  field_operand = 48,
  field_operator = 49,
  field_pattern = 50,
  field_permission = 51,
  field_promoted_name = 52,
  field_record = 53,
  field_reference = 54,
  field_return_type = 55,
  field_return_value = 56,
  field_right = 57,
  field_sizes = 58,
  field_source = 59,
  field_start = 60,
  field_table = 61,
  field_table_name = 62,
  field_target = 63,
  field_target_page = 64,
  field_then_branch = 65,
  field_then_relation = 66,
  field_then_value = 67,
  field_type = 68,
  field_value = 69,
  field_value_id = 70,
  field_value_name = 71,
  field_value_type = 72,
  field_variable = 73,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_access_value] = "access_value",
  [field_action_name] = "action_name",
  [field_al_name] = "al_name",
  [field_arguments] = "arguments",
  [field_attribute] = "attribute",
  [field_attribute_type] = "attribute_type",
  [field_base_object] = "base_object",
  [field_body] = "body",
  [field_comment] = "comment",
  [field_condition] = "condition",
  [field_direction] = "direction",
  [field_dotnet_type] = "dotnet_type",
  [field_element] = "element",
  [field_element_type] = "element_type",
  [field_else_branch] = "else_branch",
  [field_else_relation] = "else_relation",
  [field_else_value] = "else_value",
  [field_end] = "end",
  [field_enum_type] = "enum_type",
  [field_expression] = "expression",
  [field_extends_interface] = "extends_interface",
  [field_field] = "field",
  [field_field_name] = "field_name",
  [field_fields] = "fields",
  [field_function] = "function",
  [field_id] = "id",
  [field_implementation] = "implementation",
  [field_index] = "index",
  [field_interface] = "interface",
  [field_iterable] = "iterable",
  [field_key_type] = "key_type",
  [field_keyword] = "keyword",
  [field_language] = "language",
  [field_left] = "left",
  [field_length] = "length",
  [field_locked] = "locked",
  [field_max] = "max",
  [field_maxlength] = "maxlength",
  [field_member] = "member",
  [field_min] = "min",
  [field_modifier] = "modifier",
  [field_name] = "name",
  [field_namespace] = "namespace",
  [field_object] = "object",
  [field_object_id] = "object_id",
  [field_object_name] = "object_name",
  [field_object_type] = "object_type",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_pattern] = "pattern",
  [field_permission] = "permission",
  [field_promoted_name] = "promoted_name",
  [field_record] = "record",
  [field_reference] = "reference",
  [field_return_type] = "return_type",
  [field_return_value] = "return_value",
  [field_right] = "right",
  [field_sizes] = "sizes",
  [field_source] = "source",
  [field_start] = "start",
  [field_table] = "table",
  [field_table_name] = "table_name",
  [field_target] = "target",
  [field_target_page] = "target_page",
  [field_then_branch] = "then_branch",
  [field_then_relation] = "then_relation",
  [field_then_value] = "then_value",
  [field_type] = "type",
  [field_value] = "value",
  [field_value_id] = "value_id",
  [field_value_name] = "value_name",
  [field_value_type] = "value_type",
  [field_variable] = "variable",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [5] = {.index = 4, .length = 2},
  [6] = {.index = 6, .length = 3},
  [7] = {.index = 9, .length = 6},
  [8] = {.index = 15, .length = 1},
  [9] = {.index = 16, .length = 4},
  [10] = {.index = 20, .length = 1},
  [11] = {.index = 21, .length = 2},
  [12] = {.index = 23, .length = 1},
  [13] = {.index = 24, .length = 2},
  [14] = {.index = 26, .length = 1},
  [15] = {.index = 27, .length = 2},
  [16] = {.index = 29, .length = 6},
  [17] = {.index = 35, .length = 3},
  [18] = {.index = 38, .length = 2},
  [19] = {.index = 40, .length = 2},
  [20] = {.index = 42, .length = 2},
  [21] = {.index = 44, .length = 5},
  [22] = {.index = 49, .length = 2},
  [23] = {.index = 51, .length = 1},
  [24] = {.index = 52, .length = 3},
  [25] = {.index = 55, .length = 2},
  [26] = {.index = 57, .length = 4},
  [27] = {.index = 61, .length = 8},
  [28] = {.index = 69, .length = 2},
  [29] = {.index = 71, .length = 6},
  [30] = {.index = 77, .length = 2},
  [31] = {.index = 79, .length = 3},
  [32] = {.index = 82, .length = 2},
  [33] = {.index = 84, .length = 2},
  [34] = {.index = 86, .length = 2},
  [35] = {.index = 88, .length = 1},
  [36] = {.index = 89, .length = 5},
  [37] = {.index = 94, .length = 9},
  [38] = {.index = 103, .length = 8},
  [39] = {.index = 111, .length = 6},
  [40] = {.index = 117, .length = 2},
  [41] = {.index = 119, .length = 2},
  [42] = {.index = 121, .length = 2},
  [43] = {.index = 123, .length = 1},
  [44] = {.index = 124, .length = 2},
  [45] = {.index = 126, .length = 1},
  [46] = {.index = 127, .length = 2},
  [47] = {.index = 129, .length = 2},
  [48] = {.index = 131, .length = 3},
  [49] = {.index = 134, .length = 5},
  [50] = {.index = 139, .length = 3},
  [51] = {.index = 142, .length = 8},
  [52] = {.index = 150, .length = 9},
  [53] = {.index = 159, .length = 1},
  [54] = {.index = 160, .length = 1},
  [55] = {.index = 161, .length = 2},
  [56] = {.index = 163, .length = 6},
  [57] = {.index = 169, .length = 6},
  [58] = {.index = 175, .length = 2},
  [59] = {.index = 177, .length = 8},
  [60] = {.index = 185, .length = 1},
  [61] = {.index = 186, .length = 2},
  [62] = {.index = 188, .length = 3},
  [63] = {.index = 191, .length = 2},
  [64] = {.index = 129, .length = 2},
  [65] = {.index = 193, .length = 3},
  [66] = {.index = 196, .length = 3},
  [67] = {.index = 199, .length = 6},
  [68] = {.index = 205, .length = 6},
  [69] = {.index = 211, .length = 10},
  [70] = {.index = 221, .length = 10},
  [71] = {.index = 231, .length = 2},
  [72] = {.index = 233, .length = 8},
  [73] = {.index = 241, .length = 1},
  [74] = {.index = 242, .length = 4},
  [75] = {.index = 246, .length = 3},
  [76] = {.index = 249, .length = 6},
  [77] = {.index = 255, .length = 1},
  [78] = {.index = 256, .length = 11},
  [79] = {.index = 267, .length = 12},
  [80] = {.index = 279, .length = 1},
  [81] = {.index = 280, .length = 4},
  [82] = {.index = 284, .length = 3},
  [83] = {.index = 287, .length = 2},
  [84] = {.index = 289, .length = 3},
  [85] = {.index = 292, .length = 1},
  [86] = {.index = 293, .length = 6},
  [87] = {.index = 299, .length = 10},
  [88] = {.index = 309, .length = 5},
  [89] = {.index = 314, .length = 6},
  [90] = {.index = 320, .length = 3},
  [91] = {.index = 323, .length = 4},
  [92] = {.index = 327, .length = 7},
  [93] = {.index = 334, .length = 4},
  [94] = {.index = 338, .length = 12},
  [95] = {.index = 350, .length = 2},
  [96] = {.index = 352, .length = 3},
  [97] = {.index = 355, .length = 2},
  [98] = {.index = 357, .length = 9},
  [99] = {.index = 366, .length = 9},
  [100] = {.index = 375, .length = 2},
  [101] = {.index = 377, .length = 2},
  [102] = {.index = 379, .length = 1},
  [103] = {.index = 380, .length = 9},
  [104] = {.index = 389, .length = 2},
  [105] = {.index = 391, .length = 2},
  [106] = {.index = 393, .length = 1},
  [107] = {.index = 394, .length = 5},
  [108] = {.index = 399, .length = 2},
  [109] = {.index = 401, .length = 15},
  [110] = {.index = 416, .length = 2},
  [111] = {.index = 418, .length = 3},
  [112] = {.index = 421, .length = 4},
  [113] = {.index = 425, .length = 3},
  [114] = {.index = 428, .length = 4},
  [115] = {.index = 432, .length = 5},
  [116] = {.index = 437, .length = 8},
  [117] = {.index = 445, .length = 8},
  [118] = {.index = 453, .length = 4},
  [119] = {.index = 457, .length = 5},
  [120] = {.index = 462, .length = 8},
  [121] = {.index = 470, .length = 4},
  [122] = {.index = 474, .length = 5},
  [123] = {.index = 479, .length = 8},
  [124] = {.index = 487, .length = 7},
  [125] = {.index = 494, .length = 4},
  [126] = {.index = 498, .length = 5},
  [127] = {.index = 503, .length = 8},
  [128] = {.index = 511, .length = 2},
  [129] = {.index = 513, .length = 3},
  [130] = {.index = 516, .length = 3},
  [131] = {.index = 519, .length = 4},
  [132] = {.index = 523, .length = 9},
  [133] = {.index = 532, .length = 12},
  [134] = {.index = 544, .length = 2},
  [135] = {.index = 546, .length = 3},
  [136] = {.index = 549, .length = 2},
  [137] = {.index = 551, .length = 1},
  [138] = {.index = 552, .length = 1},
  [139] = {.index = 553, .length = 1},
  [140] = {.index = 554, .length = 9},
  [141] = {.index = 563, .length = 12},
  [142] = {.index = 575, .length = 6},
  [143] = {.index = 581, .length = 3},
  [144] = {.index = 584, .length = 4},
  [145] = {.index = 588, .length = 12},
  [146] = {.index = 600, .length = 12},
  [147] = {.index = 612, .length = 3},
  [148] = {.index = 615, .length = 6},
  [149] = {.index = 621, .length = 3},
  [150] = {.index = 624, .length = 2},
  [151] = {.index = 626, .length = 3},
  [152] = {.index = 629, .length = 2},
  [153] = {.index = 631, .length = 2},
  [154] = {.index = 633, .length = 2},
  [155] = {.index = 635, .length = 6},
  [156] = {.index = 641, .length = 6},
  [157] = {.index = 647, .length = 9},
  [158] = {.index = 656, .length = 12},
  [159] = {.index = 668, .length = 6},
  [160] = {.index = 674, .length = 9},
  [161] = {.index = 683, .length = 9},
  [162] = {.index = 692, .length = 12},
  [163] = {.index = 704, .length = 9},
  [164] = {.index = 713, .length = 6},
  [165] = {.index = 719, .length = 9},
  [166] = {.index = 728, .length = 9},
  [167] = {.index = 737, .length = 12},
  [168] = {.index = 749, .length = 5},
  [169] = {.index = 754, .length = 8},
  [170] = {.index = 762, .length = 10},
  [171] = {.index = 772, .length = 6},
  [172] = {.index = 778, .length = 9},
  [173] = {.index = 787, .length = 15},
  [174] = {.index = 802, .length = 2},
  [175] = {.index = 804, .length = 3},
  [176] = {.index = 807, .length = 4},
  [177] = {.index = 811, .length = 6},
  [178] = {.index = 817, .length = 6},
  [179] = {.index = 823, .length = 13},
  [180] = {.index = 836, .length = 16},
  [181] = {.index = 852, .length = 10},
  [182] = {.index = 862, .length = 13},
  [183] = {.index = 875, .length = 13},
  [184] = {.index = 888, .length = 16},
  [185] = {.index = 904, .length = 9},
  [186] = {.index = 913, .length = 5},
  [187] = {.index = 918, .length = 8},
  [188] = {.index = 926, .length = 3},
  [189] = {.index = 929, .length = 7},
  [190] = {.index = 936, .length = 6},
  [191] = {.index = 942, .length = 7},
  [192] = {.index = 949, .length = 4},
  [193] = {.index = 953, .length = 6},
  [194] = {.index = 959, .length = 10},
  [195] = {.index = 969, .length = 13},
  [196] = {.index = 982, .length = 13},
  [197] = {.index = 995, .length = 16},
  [198] = {.index = 1011, .length = 9},
  [199] = {.index = 1020, .length = 12},
  [200] = {.index = 1032, .length = 7},
  [201] = {.index = 1039, .length = 6},
  [202] = {.index = 1045, .length = 9},
  [203] = {.index = 1054, .length = 10},
  [204] = {.index = 1064, .length = 9},
  [205] = {.index = 1073, .length = 12},
  [206] = {.index = 1085, .length = 5},
  [207] = {.index = 1090, .length = 8},
  [208] = {.index = 1098, .length = 10},
  [209] = {.index = 1108, .length = 5},
  [210] = {.index = 1113, .length = 8},
  [211] = {.index = 1121, .length = 10},
  [212] = {.index = 1131, .length = 8},
  [213] = {.index = 1139, .length = 11},
  [214] = {.index = 1150, .length = 14},
  [215] = {.index = 1164, .length = 2},
  [216] = {.index = 1166, .length = 7},
  [217] = {.index = 1173, .length = 6},
  [218] = {.index = 1179, .length = 10},
  [219] = {.index = 1189, .length = 3},
  [220] = {.index = 1192, .length = 7},
  [221] = {.index = 1199, .length = 6},
  [222] = {.index = 1205, .length = 7},
  [223] = {.index = 1212, .length = 2},
  [224] = {.index = 1214, .length = 14},
  [225] = {.index = 1228, .length = 17},
  [226] = {.index = 1245, .length = 17},
  [227] = {.index = 1262, .length = 20},
  [228] = {.index = 1282, .length = 12},
  [229] = {.index = 1294, .length = 12},
  [230] = {.index = 1306, .length = 11},
  [231] = {.index = 1317, .length = 14},
  [232] = {.index = 1331, .length = 14},
  [233] = {.index = 1345, .length = 17},
  [234] = {.index = 1362, .length = 10},
  [235] = {.index = 1372, .length = 5},
  [236] = {.index = 1377, .length = 8},
  [237] = {.index = 1385, .length = 10},
  [238] = {.index = 1395, .length = 4},
  [239] = {.index = 1399, .length = 9},
  [240] = {.index = 1408, .length = 12},
  [241] = {.index = 1420, .length = 14},
  [242] = {.index = 1434, .length = 5},
  [243] = {.index = 1439, .length = 8},
  [244] = {.index = 1447, .length = 10},
  [245] = {.index = 1457, .length = 8},
  [246] = {.index = 1465, .length = 11},
  [247] = {.index = 1476, .length = 13},
  [248] = {.index = 1489, .length = 2},
  [249] = {.index = 1491, .length = 6},
  [250] = {.index = 1497, .length = 9},
  [251] = {.index = 1506, .length = 10},
  [252] = {.index = 1516, .length = 7},
  [253] = {.index = 1523, .length = 6},
  [254] = {.index = 1529, .length = 10},
  [255] = {.index = 1539, .length = 15},
  [256] = {.index = 1554, .length = 7},
  [257] = {.index = 1561, .length = 8},
  [258] = {.index = 1569, .length = 11},
  [259] = {.index = 1580, .length = 13},
  [260] = {.index = 1593, .length = 4},
  [261] = {.index = 1597, .length = 9},
  [262] = {.index = 1606, .length = 12},
  [263] = {.index = 1618, .length = 14},
  [264] = {.index = 1632, .length = 8},
  [265] = {.index = 1640, .length = 11},
  [266] = {.index = 1651, .length = 13},
  [267] = {.index = 1664, .length = 11},
  [268] = {.index = 1675, .length = 14},
  [269] = {.index = 1689, .length = 16},
  [270] = {.index = 1705, .length = 6},
  [271] = {.index = 1711, .length = 6},
  [272] = {.index = 1717, .length = 9},
  [273] = {.index = 1726, .length = 9},
  [274] = {.index = 1735, .length = 3},
  [275] = {.index = 1738, .length = 6},
  [276] = {.index = 1744, .length = 9},
  [277] = {.index = 1753, .length = 10},
  [278] = {.index = 1763, .length = 6},
  [279] = {.index = 1769, .length = 10},
  [280] = {.index = 1779, .length = 10},
  [281] = {.index = 1789, .length = 9},
  [282] = {.index = 1798, .length = 12},
  [283] = {.index = 1810, .length = 14},
  [284] = {.index = 1824, .length = 11},
  [285] = {.index = 1835, .length = 14},
  [286] = {.index = 1849, .length = 16},
  [287] = {.index = 1865, .length = 11},
  [288] = {.index = 1876, .length = 14},
  [289] = {.index = 1890, .length = 16},
  [290] = {.index = 1906, .length = 9},
  [291] = {.index = 1915, .length = 6},
  [292] = {.index = 1921, .length = 6},
  [293] = {.index = 1927, .length = 9},
  [294] = {.index = 1936, .length = 9},
  [295] = {.index = 1945, .length = 13},
  [296] = {.index = 1958, .length = 9},
  [297] = {.index = 1967, .length = 12},
  [298] = {.index = 1979, .length = 14},
  [299] = {.index = 1993, .length = 13},
  [300] = {.index = 2006, .length = 16},
  [301] = {.index = 2022, .length = 18},
  [302] = {.index = 2040, .length = 9},
  [303] = {.index = 2049, .length = 12},
  [304] = {.index = 2061, .length = 14},
  [305] = {.index = 2075, .length = 14},
  [306] = {.index = 2089, .length = 17},
  [307] = {.index = 2106, .length = 19},
  [308] = {.index = 2125, .length = 9},
  [309] = {.index = 2134, .length = 2},
  [310] = {.index = 2136, .length = 7},
  [311] = {.index = 2143, .length = 8},
  [312] = {.index = 2151, .length = 13},
  [313] = {.index = 2164, .length = 16},
  [314] = {.index = 2180, .length = 18},
  [315] = {.index = 2198, .length = 9},
  [316] = {.index = 2207, .length = 12},
  [317] = {.index = 2219, .length = 14},
  [318] = {.index = 2233, .length = 13},
  [319] = {.index = 2246, .length = 16},
  [320] = {.index = 2262, .length = 18},
  [321] = {.index = 2280, .length = 10},
  [322] = {.index = 2290, .length = 10},
  [323] = {.index = 2300, .length = 11},
  [324] = {.index = 2311, .length = 11},
  [325] = {.index = 2322, .length = 11},
  [326] = {.index = 2333, .length = 11},
  [327] = {.index = 2344, .length = 14},
  [328] = {.index = 2358, .length = 14},
  [329] = {.index = 2372, .length = 17},
  [330] = {.index = 2389, .length = 14},
  [331] = {.index = 2403, .length = 17},
  [332] = {.index = 2420, .length = 17},
  [333] = {.index = 2437, .length = 20},
  [334] = {.index = 2457, .length = 10},
  [335] = {.index = 2467, .length = 11},
  [336] = {.index = 2478, .length = 13},
  [337] = {.index = 2491, .length = 16},
  [338] = {.index = 2507, .length = 18},
  [339] = {.index = 2525, .length = 13},
  [340] = {.index = 2538, .length = 14},
  [341] = {.index = 2552, .length = 14},
  [342] = {.index = 2566, .length = 14},
  [343] = {.index = 2580, .length = 16},
  [344] = {.index = 2596, .length = 19},
  [345] = {.index = 2615, .length = 19},
  [346] = {.index = 2634, .length = 22},
  [347] = {.index = 2656, .length = 19},
  [348] = {.index = 2675, .length = 22},
  [349] = {.index = 2697, .length = 22},
  [350] = {.index = 2719, .length = 25},
  [351] = {.index = 2744, .length = 13},
  [352] = {.index = 2757, .length = 13},
  [353] = {.index = 2770, .length = 14},
  [354] = {.index = 2784, .length = 14},
  [355] = {.index = 2798, .length = 14},
  [356] = {.index = 2812, .length = 17},
  [357] = {.index = 2829, .length = 16},
  [358] = {.index = 2845, .length = 17},
  [359] = {.index = 2862, .length = 17},
  [360] = {.index = 2879, .length = 17},
  [361] = {.index = 2896, .length = 20},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_condition, 1},
  [1] =
    {field_name, 1},
  [2] =
    {field_namespace, 1},
  [3] =
    {field_object_name, 1},
  [4] =
    {field_object_id, 1},
    {field_object_name, 2},
  [6] =
    {field_base_object, 1, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_name, 1, .inherited = true},
  [9] =
    {field_base_object, 0, .inherited = true},
    {field_base_object, 1, .inherited = true},
    {field_object_id, 0, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_name, 0, .inherited = true},
    {field_object_name, 1, .inherited = true},
  [15] =
    {field_name, 0},
  [16] =
    {field_modifier, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_return_value, 0, .inherited = true},
  [20] =
    {field_interface, 1},
  [21] =
    {field_name, 0},
    {field_value, 2},
  [23] =
    {field_table, 0},
  [24] =
    {field_arguments, 1},
    {field_name, 0},
  [26] =
    {field_attribute, 1},
  [27] =
    {field_extends_interface, 3},
    {field_object_name, 1},
  [29] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
  [35] =
    {field_base_object, 4},
    {field_object_id, 1},
    {field_object_name, 2},
  [38] =
    {field_interface, 1},
    {field_interface, 2, .inherited = true},
  [40] =
    {field_base_object, 3},
    {field_object_name, 1},
  [42] =
    {field_object_name, 1},
    {field_target_page, 3},
  [44] =
    {field_left, 1, .inherited = true},
    {field_operand, 1},
    {field_operator, 0},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [49] =
    {field_arguments, 1},
    {field_function, 0},
  [51] =
    {field_min, 0},
  [52] =
    {field_name, 0},
    {field_value, 2},
    {field_value, 3},
  [55] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [57] =
    {field_modifier, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_value, 1, .inherited = true},
  [61] =
    {field_modifier, 0, .inherited = true},
    {field_modifier, 1, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_value, 0, .inherited = true},
    {field_return_value, 1, .inherited = true},
  [69] =
    {field_access_value, 4},
    {field_object_name, 1},
  [71] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 3, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 3, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 3, .inherited = true},
  [77] =
    {field_interface, 0, .inherited = true},
    {field_interface, 1, .inherited = true},
  [79] =
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [82] =
    {field_keyword, 0},
    {field_table_name, 2},
  [84] =
    {field_enum_type, 0},
    {field_value, 2},
  [86] =
    {field_max, 2},
    {field_min, 0},
  [88] =
    {field_else_relation, 1},
  [89] =
    {field_left, 0, .inherited = true},
    {field_member, 2},
    {field_object, 0},
    {field_operator, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [94] =
    {field_left, 0},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1},
    {field_operator, 2, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2},
    {field_right, 2, .inherited = true},
  [103] =
    {field_left, 0},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2},
    {field_right, 2, .inherited = true},
  [111] =
    {field_left, 0},
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1},
    {field_right, 0, .inherited = true},
    {field_right, 2},
  [117] =
    {field_language, 0},
    {field_value, 2},
  [119] =
    {field_field, 0},
    {field_value, 2},
  [121] =
    {field_implementation, 2},
    {field_interface, 0},
  [123] =
    {field_return_type, 0, .inherited = true},
  [124] =
    {field_return_type, 0, .inherited = true},
    {field_return_value, 0, .inherited = true},
  [126] =
    {field_reference, 1},
  [127] =
    {field_object_type, 0},
    {field_reference, 1},
  [129] =
    {field_name, 0},
    {field_type, 2},
  [131] =
    {field_id, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 1, .inherited = true},
  [134] =
    {field_left, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_source, 1, .inherited = true},
  [139] =
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [142] =
    {field_modifier, 1, .inherited = true},
    {field_modifier, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_return_value, 1, .inherited = true},
    {field_return_value, 2, .inherited = true},
  [150] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 4, .inherited = true},
  [159] =
    {field_name, 2},
  [160] =
    {field_target, 2},
  [161] =
    {field_permission, 3},
    {field_table_name, 1},
  [163] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
  [169] =
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
  [175] =
    {field_function, 0},
    {field_target, 2},
  [177] =
    {field_index, 2},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_object, 0},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
  [185] =
    {field_return_type, 1},
  [186] =
    {field_name, 1},
    {field_return_type, 4, .inherited = true},
  [188] =
    {field_name, 1},
    {field_return_type, 4, .inherited = true},
    {field_return_value, 4, .inherited = true},
  [191] =
    {field_return_type, 1, .inherited = true},
    {field_return_value, 0},
  [193] =
    {field_name, 0},
    {field_type, 2},
    {field_value, 3},
  [196] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
    {field_type, 3},
  [199] =
    {field_id, 1, .inherited = true},
    {field_id, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type, 1, .inherited = true},
    {field_type, 2, .inherited = true},
  [205] =
    {field_id, 0, .inherited = true},
    {field_id, 1, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 0, .inherited = true},
    {field_type, 1, .inherited = true},
  [211] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_source, 1, .inherited = true},
    {field_source, 2, .inherited = true},
  [221] =
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_source, 0, .inherited = true},
    {field_source, 1, .inherited = true},
  [231] =
    {field_modifier, 0},
    {field_name, 2},
  [233] =
    {field_modifier, 1, .inherited = true},
    {field_modifier, 3, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_type, 3, .inherited = true},
    {field_return_value, 1, .inherited = true},
    {field_return_value, 3, .inherited = true},
  [241] =
    {field_body, 1},
  [242] =
    {field_body, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [246] =
    {field_access_value, 6},
    {field_extends_interface, 3},
    {field_object_name, 1},
  [249] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 4, .inherited = true},
  [255] =
    {field_then_relation, 4},
  [256] =
    {field_index, 2},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_object, 0},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
  [267] =
    {field_condition, 0},
    {field_else_value, 4},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_value, 2},
  [279] =
    {field_field, 0},
  [280] =
    {field_field, 0},
    {field_value, 2},
    {field_value, 3},
    {field_value, 4},
  [284] =
    {field_modifier, 0},
    {field_name, 1},
    {field_type, 3},
  [287] =
    {field_name, 1},
    {field_return_type, 5, .inherited = true},
  [289] =
    {field_name, 1},
    {field_return_type, 5, .inherited = true},
    {field_return_value, 5, .inherited = true},
  [292] =
    {field_length, 2},
  [293] =
    {field_id, 1, .inherited = true},
    {field_id, 3, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_type, 1, .inherited = true},
    {field_type, 3, .inherited = true},
  [299] =
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_source, 1, .inherited = true},
    {field_source, 3, .inherited = true},
  [309] =
    {field_comment, 3, .inherited = true},
    {field_locked, 3, .inherited = true},
    {field_maxlength, 3, .inherited = true},
    {field_name, 0},
    {field_value, 2},
  [314] =
    {field_comment, 0, .inherited = true},
    {field_comment, 1, .inherited = true},
    {field_locked, 0, .inherited = true},
    {field_locked, 1, .inherited = true},
    {field_maxlength, 0, .inherited = true},
    {field_maxlength, 1, .inherited = true},
  [320] =
    {field_modifier, 0},
    {field_name, 2},
    {field_return_type, 5, .inherited = true},
  [323] =
    {field_modifier, 0},
    {field_name, 2},
    {field_return_type, 5, .inherited = true},
    {field_return_value, 5, .inherited = true},
  [327] =
    {field_condition, 1, .inherited = true},
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
  [334] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
  [338] =
    {field_modifier, 1, .inherited = true},
    {field_modifier, 2, .inherited = true},
    {field_modifier, 4, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_return_type, 4, .inherited = true},
    {field_return_value, 1, .inherited = true},
    {field_return_value, 2, .inherited = true},
    {field_return_value, 4, .inherited = true},
  [350] =
    {field_name, 2},
    {field_return_type, 5, .inherited = true},
  [352] =
    {field_name, 2},
    {field_return_type, 5, .inherited = true},
    {field_return_value, 5, .inherited = true},
  [355] =
    {field_modifier, 1},
    {field_name, 3},
  [357] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 4, .inherited = true},
    {field_object_name, 5, .inherited = true},
  [366] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 5, .inherited = true},
  [375] =
    {field_field, 0},
    {field_value, 4},
  [377] =
    {field_value_id, 2},
    {field_value_name, 4},
  [379] =
    {field_element_type, 3},
  [380] =
    {field_id, 1, .inherited = true},
    {field_id, 2, .inherited = true},
    {field_id, 4, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_type, 1, .inherited = true},
    {field_type, 2, .inherited = true},
    {field_type, 4, .inherited = true},
  [389] =
    {field_fields, 4},
    {field_name, 2},
  [391] =
    {field_fields, 4},
    {field_target, 2},
  [393] =
    {field_type, 2},
  [394] =
    {field_left, 4, .inherited = true},
    {field_name, 2},
    {field_operator, 4, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_source, 4},
  [399] =
    {field_element, 4},
    {field_target, 2},
  [401] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_source, 1, .inherited = true},
    {field_source, 2, .inherited = true},
    {field_source, 4, .inherited = true},
  [416] =
    {field_element_type, 0},
    {field_name, 2},
  [418] =
    {field_modifier, 0},
    {field_name, 2},
    {field_return_type, 6, .inherited = true},
  [421] =
    {field_modifier, 0},
    {field_name, 2},
    {field_return_type, 6, .inherited = true},
    {field_return_value, 6, .inherited = true},
  [425] =
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
  [428] =
    {field_condition, 1, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [432] =
    {field_condition, 1, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 3},
  [437] =
    {field_condition, 1, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 3},
  [445] =
    {field_condition, 0, .inherited = true},
    {field_condition, 1, .inherited = true},
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
  [453] =
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [457] =
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 3},
  [462] =
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 3},
  [470] =
    {field_expression, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [474] =
    {field_body, 3},
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [479] =
    {field_body, 3},
    {field_condition, 1},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [487] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [494] =
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_return_value, 2},
    {field_right, 2, .inherited = true},
  [498] =
    {field_body, 3},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_record, 1},
    {field_right, 1, .inherited = true},
  [503] =
    {field_body, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_record, 1},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [511] =
    {field_name, 2},
    {field_return_type, 6, .inherited = true},
  [513] =
    {field_name, 2},
    {field_return_type, 6, .inherited = true},
    {field_return_value, 6, .inherited = true},
  [516] =
    {field_modifier, 1},
    {field_name, 3},
    {field_return_type, 6, .inherited = true},
  [519] =
    {field_modifier, 1},
    {field_name, 3},
    {field_return_type, 6, .inherited = true},
    {field_return_value, 6, .inherited = true},
  [523] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_base_object, 6, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_id, 6, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 4, .inherited = true},
    {field_object_name, 6, .inherited = true},
  [532] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_base_object, 6, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_id, 6, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 5, .inherited = true},
    {field_object_name, 6, .inherited = true},
  [544] =
    {field_else_relation, 6},
    {field_then_relation, 4},
  [546] =
    {field_left, 3, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 3, .inherited = true},
  [549] =
    {field_element_type, 5},
    {field_sizes, 2},
  [551] =
    {field_locked, 3},
  [552] =
    {field_comment, 3},
  [553] =
    {field_maxlength, 3},
  [554] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 4},
  [563] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4},
  [575] =
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [581] =
    {field_modifier, 1},
    {field_name, 3},
    {field_return_type, 7, .inherited = true},
  [584] =
    {field_modifier, 1},
    {field_name, 3},
    {field_return_type, 7, .inherited = true},
    {field_return_value, 7, .inherited = true},
  [588] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 4, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_base_object, 7, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 4, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_id, 7, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 4, .inherited = true},
    {field_object_name, 5, .inherited = true},
    {field_object_name, 7, .inherited = true},
  [600] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_base_object, 7, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_id, 7, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 5, .inherited = true},
    {field_object_name, 7, .inherited = true},
  [612] =
    {field_left, 4, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 4, .inherited = true},
  [615] =
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [621] =
    {field_element_type, 6},
    {field_sizes, 2},
    {field_sizes, 3},
  [624] =
    {field_key_type, 3},
    {field_value_type, 5},
  [626] =
    {field_id, 2},
    {field_name, 4},
    {field_type, 6},
  [629] =
    {field_action_name, 4},
    {field_promoted_name, 2},
  [631] =
    {field_name, 2},
    {field_source, 4},
  [633] =
    {field_name, 2},
    {field_table_name, 4},
  [635] =
    {field_element_type, 0},
    {field_left, 4, .inherited = true},
    {field_name, 2},
    {field_operator, 4, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_source, 4},
  [641] =
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
  [647] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 5},
  [656] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5},
  [668] =
    {field_condition, 1, .inherited = true},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 3},
  [674] =
    {field_condition, 1, .inherited = true},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 3},
  [683] =
    {field_condition, 1, .inherited = true},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 3},
  [692] =
    {field_condition, 1, .inherited = true},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 3},
  [704] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [713] =
    {field_condition, 1},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 3},
  [719] =
    {field_condition, 1},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 3},
  [728] =
    {field_condition, 1},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 3},
  [737] =
    {field_condition, 1},
    {field_else_branch, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 3},
  [749] =
    {field_body, 2},
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_pattern, 0},
    {field_right, 0, .inherited = true},
  [754] =
    {field_body, 2},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_pattern, 0},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
  [762] =
    {field_body, 2},
    {field_condition, 2, .inherited = true},
    {field_left, 0, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_pattern, 0},
    {field_right, 0, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 2, .inherited = true},
  [772] =
    {field_body, 5},
    {field_iterable, 3},
    {field_left, 3, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_variable, 1},
  [778] =
    {field_body, 5},
    {field_iterable, 3},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_variable, 1},
  [787] =
    {field_base_object, 1, .inherited = true},
    {field_base_object, 2, .inherited = true},
    {field_base_object, 5, .inherited = true},
    {field_base_object, 6, .inherited = true},
    {field_base_object, 8, .inherited = true},
    {field_object_id, 1, .inherited = true},
    {field_object_id, 2, .inherited = true},
    {field_object_id, 5, .inherited = true},
    {field_object_id, 6, .inherited = true},
    {field_object_id, 8, .inherited = true},
    {field_object_name, 1, .inherited = true},
    {field_object_name, 2, .inherited = true},
    {field_object_name, 5, .inherited = true},
    {field_object_name, 6, .inherited = true},
    {field_object_name, 8, .inherited = true},
  [802] =
    {field_field, 0},
    {field_value, 6},
  [804] =
    {field_left, 5, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 5, .inherited = true},
  [807] =
    {field_condition, 2, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
  [811] =
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
  [817] =
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [823] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 6},
  [836] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6},
  [852] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_else_branch, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 4},
  [862] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_else_branch, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 4},
  [875] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_else_branch, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4},
  [888] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_else_branch, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 4},
  [904] =
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 4, .inherited = true},
  [913] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 4},
  [918] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4},
  [926] =
    {field_left, 6, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 6, .inherited = true},
  [929] =
    {field_condition, 2, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
  [936] =
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
  [942] =
    {field_condition, 3, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
  [949] =
    {field_condition, 3, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 3, .inherited = true},
  [953] =
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
  [959] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_else_branch, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_then_branch, 5},
  [969] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_else_branch, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 5},
  [982] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_else_branch, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5},
  [995] =
    {field_condition, 1, .inherited = true},
    {field_condition, 3, .inherited = true},
    {field_else_branch, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 5},
  [1011] =
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [1020] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 5, .inherited = true},
  [1032] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
  [1039] =
    {field_condition, 2},
    {field_else_branch, 7},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_then_branch, 4},
  [1045] =
    {field_condition, 2},
    {field_else_branch, 7},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 4},
  [1054] =
    {field_condition, 0, .inherited = true},
    {field_condition, 1, .inherited = true},
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_then_branch, 0, .inherited = true},
    {field_then_branch, 1, .inherited = true},
  [1064] =
    {field_condition, 2},
    {field_else_branch, 7},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4},
  [1073] =
    {field_condition, 2},
    {field_else_branch, 7},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 4},
  [1085] =
    {field_body, 4},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
  [1090] =
    {field_body, 4},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [1098] =
    {field_body, 4},
    {field_condition, 4, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4, .inherited = true},
  [1108] =
    {field_body, 4},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_pattern, 1},
    {field_right, 1, .inherited = true},
  [1113] =
    {field_body, 4},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 1},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
  [1121] =
    {field_body, 4},
    {field_condition, 4, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 1},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 4, .inherited = true},
  [1131] =
    {field_left, 0, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_pattern, 0, .inherited = true},
    {field_pattern, 1, .inherited = true},
    {field_right, 0, .inherited = true},
    {field_right, 1, .inherited = true},
  [1139] =
    {field_body, 7},
    {field_direction, 4},
    {field_end, 5},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_start, 3},
    {field_variable, 1},
  [1150] =
    {field_body, 7},
    {field_direction, 4},
    {field_end, 5},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_start, 3},
    {field_variable, 1},
  [1164] =
    {field_al_name, 4},
    {field_dotnet_type, 2},
  [1166] =
    {field_condition, 2, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
  [1173] =
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
  [1179] =
    {field_condition, 3, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
  [1189] =
    {field_left, 7, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 7, .inherited = true},
  [1192] =
    {field_condition, 3, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
  [1199] =
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
  [1205] =
    {field_condition, 4, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 4, .inherited = true},
  [1212] =
    {field_attribute_type, 0},
    {field_name, 2},
  [1214] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_else_branch, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_then_branch, 6},
  [1228] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_else_branch, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 6},
  [1245] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_else_branch, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6},
  [1262] =
    {field_condition, 1, .inherited = true},
    {field_condition, 2, .inherited = true},
    {field_condition, 4, .inherited = true},
    {field_else_branch, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 6},
  [1282] =
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 6, .inherited = true},
  [1294] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1306] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_else_branch, 8},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
  [1317] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_else_branch, 8},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
  [1331] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_else_branch, 8},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
  [1345] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_else_branch, 8},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
  [1362] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
  [1372] =
    {field_body, 5},
    {field_left, 3, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_pattern, 3},
    {field_right, 3, .inherited = true},
  [1377] =
    {field_body, 5},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 3},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [1385] =
    {field_body, 5},
    {field_condition, 5, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 3},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5, .inherited = true},
  [1395] =
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_pattern, 1},
    {field_right, 1, .inherited = true},
  [1399] =
    {field_body, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [1408] =
    {field_body, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [1420] =
    {field_body, 5},
    {field_condition, 5, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5, .inherited = true},
  [1434] =
    {field_body, 5},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
  [1439] =
    {field_body, 5},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
  [1447] =
    {field_body, 5},
    {field_condition, 5, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5, .inherited = true},
  [1457] =
    {field_body, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_pattern, 3},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
  [1465] =
    {field_body, 5},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 3},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [1476] =
    {field_body, 5},
    {field_condition, 5, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 3},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_then_branch, 5, .inherited = true},
  [1489] =
    {field_field, 0},
    {field_value, 8},
  [1491] =
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
  [1497] =
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
  [1506] =
    {field_condition, 3, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [1516] =
    {field_condition, 3, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [1523] =
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [1529] =
    {field_condition, 4, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
  [1539] =
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 7, .inherited = true},
  [1554] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
  [1561] =
    {field_body, 6},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 4},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [1569] =
    {field_body, 6},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1580] =
    {field_body, 6},
    {field_condition, 6, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6, .inherited = true},
  [1593] =
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_pattern, 2},
    {field_right, 2, .inherited = true},
  [1597] =
    {field_body, 6},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [1606] =
    {field_body, 6},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1618] =
    {field_body, 6},
    {field_condition, 6, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6, .inherited = true},
  [1632] =
    {field_body, 6},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
  [1640] =
    {field_body, 6},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1651] =
    {field_body, 6},
    {field_condition, 6, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6, .inherited = true},
  [1664] =
    {field_body, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
  [1675] =
    {field_body, 6},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [1689] =
    {field_body, 6},
    {field_condition, 6, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_then_branch, 6, .inherited = true},
  [1705] =
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
  [1711] =
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
  [1717] =
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
  [1726] =
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
  [1735] =
    {field_left, 8, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 8, .inherited = true},
  [1738] =
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
  [1744] =
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
  [1753] =
    {field_condition, 4, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 9, .inherited = true},
  [1763] =
    {field_attribute_type, 0},
    {field_left, 4, .inherited = true},
    {field_name, 2},
    {field_operator, 4, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_source, 4},
  [1769] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
  [1779] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [1789] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
  [1798] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
  [1810] =
    {field_body, 7},
    {field_condition, 7, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 4},
    {field_right, 1, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 7, .inherited = true},
  [1824] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [1835] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
  [1849] =
    {field_body, 7},
    {field_condition, 7, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 7, .inherited = true},
  [1865] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
  [1876] =
    {field_body, 7},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
  [1890] =
    {field_body, 7},
    {field_condition, 7, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_then_branch, 7, .inherited = true},
  [1906] =
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 9, .inherited = true},
  [1915] =
    {field_left, 5, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 9, .inherited = true},
  [1921] =
    {field_left, 3, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 9, .inherited = true},
  [1927] =
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
  [1936] =
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 9, .inherited = true},
  [1945] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 9, .inherited = true},
  [1958] =
    {field_body, 8},
    {field_left, 1, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 5, .inherited = true},
  [1967] =
    {field_body, 8},
    {field_left, 1, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
  [1979] =
    {field_body, 8},
    {field_condition, 8, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 8, .inherited = true},
  [1993] =
    {field_body, 8},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
  [2006] =
    {field_body, 8},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
  [2022] =
    {field_body, 8},
    {field_condition, 8, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_pattern, 5},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 8, .inherited = true},
  [2040] =
    {field_body, 8},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 5},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
  [2049] =
    {field_body, 8},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 5},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
  [2061] =
    {field_body, 8},
    {field_condition, 8, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 5},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 8, .inherited = true},
  [2075] =
    {field_body, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [2089] =
    {field_body, 8},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
  [2106] =
    {field_body, 8},
    {field_condition, 8, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 8, .inherited = true},
  [2125] =
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 10, .inherited = true},
  [2134] =
    {field_field_name, 4},
    {field_name, 2},
  [2136] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 10, .inherited = true},
  [2143] =
    {field_condition, 2},
    {field_condition, 7},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
  [2151] =
    {field_body, 9},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
  [2164] =
    {field_body, 9},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
  [2180] =
    {field_body, 9},
    {field_condition, 9, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_pattern, 1},
    {field_pattern, 3, .inherited = true},
    {field_pattern, 6},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_then_branch, 9, .inherited = true},
  [2198] =
    {field_body, 9},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 6},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
  [2207] =
    {field_body, 9},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 6},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
  [2219] =
    {field_body, 9},
    {field_condition, 9, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 6},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_then_branch, 9, .inherited = true},
  [2233] =
    {field_body, 9},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_pattern, 6},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
  [2246] =
    {field_body, 9},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_pattern, 6},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
  [2262] =
    {field_body, 9},
    {field_condition, 9, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_pattern, 6},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_then_branch, 9, .inherited = true},
  [2280] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 11, .inherited = true},
  [2290] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 11, .inherited = true},
  [2300] =
    {field_condition, 2},
    {field_condition, 7},
    {field_left, 2, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 10, .inherited = true},
  [2311] =
    {field_condition, 2},
    {field_condition, 8},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
  [2322] =
    {field_condition, 2},
    {field_condition, 8},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
  [2333] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [2344] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 13, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [2358] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [2372] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_right, 13, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [2389] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [2403] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 13, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [2420] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [2437] =
    {field_condition, 2},
    {field_condition, 8},
    {field_else_branch, 13},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_right, 13, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 10},
  [2457] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 11, .inherited = true},
  [2467] =
    {field_condition, 3},
    {field_condition, 8},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
  [2478] =
    {field_body, 10},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_pattern, 7},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
  [2491] =
    {field_body, 10},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_pattern, 7},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 10, .inherited = true},
  [2507] =
    {field_body, 10},
    {field_condition, 10, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_pattern, 2},
    {field_pattern, 4, .inherited = true},
    {field_pattern, 7},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_then_branch, 10, .inherited = true},
  [2525] =
    {field_condition, 2},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 12, .inherited = true},
  [2538] =
    {field_condition, 2},
    {field_condition, 8},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 11, .inherited = true},
  [2552] =
    {field_condition, 2},
    {field_condition, 8},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 11, .inherited = true},
  [2566] =
    {field_condition, 2},
    {field_condition, 9},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 9, .inherited = true},
  [2580] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [2596] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 14, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 14, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 14, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [2615] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 11, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [2634] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_left, 14, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_operator, 14, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 11, .inherited = true},
    {field_right, 14, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [2656] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [2675] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 14, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 14, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 14, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [2697] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 11, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [2719] =
    {field_condition, 2},
    {field_condition, 6, .inherited = true},
    {field_condition, 9},
    {field_else_branch, 14},
    {field_left, 2, .inherited = true},
    {field_left, 4, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_left, 14, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 4, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_operator, 14, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 4, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 11, .inherited = true},
    {field_right, 14, .inherited = true},
    {field_then_branch, 4},
    {field_then_branch, 6, .inherited = true},
    {field_then_branch, 11},
  [2744] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 12, .inherited = true},
  [2757] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 12, .inherited = true},
  [2770] =
    {field_condition, 3},
    {field_condition, 8},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 11, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 11, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 11, .inherited = true},
  [2784] =
    {field_condition, 3},
    {field_condition, 9},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 9, .inherited = true},
  [2798] =
    {field_condition, 3},
    {field_condition, 9},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
  [2812] =
    {field_condition, 2},
    {field_condition, 9},
    {field_left, 2, .inherited = true},
    {field_left, 5, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_operator, 5, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_right, 5, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 12, .inherited = true},
  [2829] =
    {field_condition, 3},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 13, .inherited = true},
  [2845] =
    {field_condition, 3},
    {field_condition, 9},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 7, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 7, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 7, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 12, .inherited = true},
  [2862] =
    {field_condition, 3},
    {field_condition, 9},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 9, .inherited = true},
    {field_left, 12, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 9, .inherited = true},
    {field_operator, 12, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 9, .inherited = true},
    {field_right, 12, .inherited = true},
  [2879] =
    {field_condition, 3},
    {field_condition, 10},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
  [2896] =
    {field_condition, 3},
    {field_condition, 10},
    {field_left, 1, .inherited = true},
    {field_left, 3, .inherited = true},
    {field_left, 6, .inherited = true},
    {field_left, 8, .inherited = true},
    {field_left, 10, .inherited = true},
    {field_left, 13, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_operator, 3, .inherited = true},
    {field_operator, 6, .inherited = true},
    {field_operator, 8, .inherited = true},
    {field_operator, 10, .inherited = true},
    {field_operator, 13, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_right, 3, .inherited = true},
    {field_right, 6, .inherited = true},
    {field_right, 8, .inherited = true},
    {field_right, 10, .inherited = true},
    {field_right, 13, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [32] = {
    [0] = alias_sym_object_type_keyword,
  },
  [58] = {
    [0] = alias_sym_aggregate_function,
  },
  [64] = {
    [2] = sym_basic_type,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_codeunit_keyword, 2,
    sym_codeunit_keyword,
    alias_sym_object_type_keyword,
  sym_xmlport_keyword, 2,
    sym_xmlport_keyword,
    alias_sym_object_type_keyword,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 2,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 4,
  [27] = 5,
  [28] = 6,
  [29] = 7,
  [30] = 8,
  [31] = 9,
  [32] = 2,
  [33] = 11,
  [34] = 12,
  [35] = 13,
  [36] = 14,
  [37] = 15,
  [38] = 16,
  [39] = 17,
  [40] = 18,
  [41] = 19,
  [42] = 20,
  [43] = 21,
  [44] = 22,
  [45] = 23,
  [46] = 24,
  [47] = 25,
  [48] = 4,
  [49] = 5,
  [50] = 6,
  [51] = 7,
  [52] = 8,
  [53] = 9,
  [54] = 3,
  [55] = 11,
  [56] = 12,
  [57] = 14,
  [58] = 15,
  [59] = 16,
  [60] = 17,
  [61] = 18,
  [62] = 19,
  [63] = 20,
  [64] = 21,
  [65] = 22,
  [66] = 23,
  [67] = 24,
  [68] = 25,
  [69] = 4,
  [70] = 5,
  [71] = 6,
  [72] = 7,
  [73] = 8,
  [74] = 9,
  [75] = 2,
  [76] = 11,
  [77] = 12,
  [78] = 13,
  [79] = 14,
  [80] = 15,
  [81] = 16,
  [82] = 17,
  [83] = 18,
  [84] = 19,
  [85] = 20,
  [86] = 21,
  [87] = 22,
  [88] = 23,
  [89] = 24,
  [90] = 25,
  [91] = 3,
  [92] = 3,
  [93] = 3,
  [94] = 3,
  [95] = 3,
  [96] = 3,
  [97] = 3,
  [98] = 3,
  [99] = 3,
  [100] = 3,
  [101] = 3,
  [102] = 3,
  [103] = 3,
  [104] = 3,
  [105] = 3,
  [106] = 3,
  [107] = 3,
  [108] = 3,
  [109] = 3,
  [110] = 13,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 112,
  [115] = 112,
  [116] = 111,
  [117] = 112,
  [118] = 113,
  [119] = 111,
  [120] = 112,
  [121] = 113,
  [122] = 111,
  [123] = 113,
  [124] = 111,
  [125] = 113,
  [126] = 111,
  [127] = 112,
  [128] = 113,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 131,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 131,
  [137] = 135,
  [138] = 133,
  [139] = 134,
  [140] = 135,
  [141] = 133,
  [142] = 134,
  [143] = 131,
  [144] = 135,
  [145] = 133,
  [146] = 134,
  [147] = 147,
  [148] = 147,
  [149] = 147,
  [150] = 147,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 152,
  [155] = 155,
  [156] = 152,
  [157] = 152,
  [158] = 152,
  [159] = 152,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 160,
  [180] = 180,
  [181] = 175,
  [182] = 176,
  [183] = 161,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 177,
  [192] = 184,
  [193] = 185,
  [194] = 186,
  [195] = 187,
  [196] = 188,
  [197] = 189,
  [198] = 190,
  [199] = 185,
  [200] = 184,
  [201] = 185,
  [202] = 186,
  [203] = 187,
  [204] = 188,
  [205] = 189,
  [206] = 190,
  [207] = 175,
  [208] = 187,
  [209] = 188,
  [210] = 186,
  [211] = 189,
  [212] = 184,
  [213] = 178,
  [214] = 180,
  [215] = 176,
  [216] = 177,
  [217] = 190,
  [218] = 178,
  [219] = 180,
  [220] = 176,
  [221] = 177,
  [222] = 178,
  [223] = 180,
  [224] = 175,
  [225] = 225,
  [226] = 226,
  [227] = 225,
  [228] = 228,
  [229] = 229,
  [230] = 226,
  [231] = 225,
  [232] = 228,
  [233] = 229,
  [234] = 226,
  [235] = 164,
  [236] = 225,
  [237] = 228,
  [238] = 228,
  [239] = 229,
  [240] = 226,
  [241] = 229,
  [242] = 225,
  [243] = 229,
  [244] = 228,
  [245] = 226,
  [246] = 229,
  [247] = 228,
  [248] = 226,
  [249] = 226,
  [250] = 250,
  [251] = 225,
  [252] = 225,
  [253] = 228,
  [254] = 229,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 161,
  [261] = 257,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 255,
  [267] = 259,
  [268] = 255,
  [269] = 256,
  [270] = 257,
  [271] = 255,
  [272] = 259,
  [273] = 160,
  [274] = 262,
  [275] = 264,
  [276] = 264,
  [277] = 265,
  [278] = 256,
  [279] = 257,
  [280] = 258,
  [281] = 259,
  [282] = 265,
  [283] = 166,
  [284] = 256,
  [285] = 258,
  [286] = 265,
  [287] = 262,
  [288] = 262,
  [289] = 264,
  [290] = 258,
  [291] = 164,
  [292] = 166,
  [293] = 293,
  [294] = 293,
  [295] = 293,
  [296] = 293,
  [297] = 153,
  [298] = 298,
  [299] = 298,
  [300] = 293,
  [301] = 298,
  [302] = 298,
  [303] = 298,
  [304] = 298,
  [305] = 293,
  [306] = 306,
  [307] = 307,
  [308] = 307,
  [309] = 309,
  [310] = 306,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 312,
  [320] = 315,
  [321] = 316,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 309,
  [331] = 306,
  [332] = 317,
  [333] = 322,
  [334] = 334,
  [335] = 323,
  [336] = 324,
  [337] = 325,
  [338] = 309,
  [339] = 306,
  [340] = 340,
  [341] = 309,
  [342] = 306,
  [343] = 309,
  [344] = 306,
  [345] = 326,
  [346] = 327,
  [347] = 309,
  [348] = 306,
  [349] = 309,
  [350] = 306,
  [351] = 309,
  [352] = 306,
  [353] = 309,
  [354] = 306,
  [355] = 309,
  [356] = 306,
  [357] = 309,
  [358] = 306,
  [359] = 309,
  [360] = 306,
  [361] = 309,
  [362] = 306,
  [363] = 309,
  [364] = 306,
  [365] = 309,
  [366] = 306,
  [367] = 309,
  [368] = 306,
  [369] = 309,
  [370] = 306,
  [371] = 309,
  [372] = 306,
  [373] = 328,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 329,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 318,
  [383] = 383,
  [384] = 311,
  [385] = 318,
  [386] = 312,
  [387] = 315,
  [388] = 316,
  [389] = 322,
  [390] = 323,
  [391] = 324,
  [392] = 325,
  [393] = 326,
  [394] = 327,
  [395] = 328,
  [396] = 329,
  [397] = 311,
  [398] = 311,
  [399] = 317,
  [400] = 309,
  [401] = 306,
  [402] = 309,
  [403] = 309,
  [404] = 306,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 413,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 405,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 423,
  [424] = 424,
  [425] = 425,
  [426] = 426,
  [427] = 427,
  [428] = 428,
  [429] = 429,
  [430] = 430,
  [431] = 431,
  [432] = 432,
  [433] = 433,
  [434] = 434,
  [435] = 435,
  [436] = 431,
  [437] = 432,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 423,
  [459] = 424,
  [460] = 428,
  [461] = 430,
  [462] = 433,
  [463] = 463,
  [464] = 464,
  [465] = 435,
  [466] = 441,
  [467] = 442,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 434,
  [473] = 468,
  [474] = 471,
  [475] = 438,
  [476] = 439,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 434,
  [484] = 440,
  [485] = 431,
  [486] = 432,
  [487] = 438,
  [488] = 439,
  [489] = 440,
  [490] = 463,
  [491] = 491,
  [492] = 443,
  [493] = 444,
  [494] = 445,
  [495] = 446,
  [496] = 447,
  [497] = 448,
  [498] = 449,
  [499] = 450,
  [500] = 451,
  [501] = 452,
  [502] = 453,
  [503] = 454,
  [504] = 455,
  [505] = 456,
  [506] = 457,
  [507] = 423,
  [508] = 424,
  [509] = 428,
  [510] = 430,
  [511] = 433,
  [512] = 463,
  [513] = 464,
  [514] = 441,
  [515] = 442,
  [516] = 468,
  [517] = 469,
  [518] = 470,
  [519] = 471,
  [520] = 431,
  [521] = 432,
  [522] = 434,
  [523] = 431,
  [524] = 432,
  [525] = 438,
  [526] = 439,
  [527] = 527,
  [528] = 528,
  [529] = 443,
  [530] = 444,
  [531] = 445,
  [532] = 446,
  [533] = 447,
  [534] = 448,
  [535] = 449,
  [536] = 450,
  [537] = 451,
  [538] = 454,
  [539] = 455,
  [540] = 456,
  [541] = 457,
  [542] = 423,
  [543] = 424,
  [544] = 428,
  [545] = 430,
  [546] = 433,
  [547] = 463,
  [548] = 441,
  [549] = 442,
  [550] = 468,
  [551] = 469,
  [552] = 470,
  [553] = 471,
  [554] = 438,
  [555] = 439,
  [556] = 440,
  [557] = 469,
  [558] = 470,
  [559] = 443,
  [560] = 444,
  [561] = 445,
  [562] = 446,
  [563] = 447,
  [564] = 448,
  [565] = 449,
  [566] = 450,
  [567] = 451,
  [568] = 452,
  [569] = 453,
  [570] = 411,
  [571] = 454,
  [572] = 455,
  [573] = 456,
  [574] = 457,
  [575] = 423,
  [576] = 424,
  [577] = 428,
  [578] = 430,
  [579] = 433,
  [580] = 463,
  [581] = 464,
  [582] = 412,
  [583] = 583,
  [584] = 250,
  [585] = 585,
  [586] = 434,
  [587] = 587,
  [588] = 588,
  [589] = 443,
  [590] = 444,
  [591] = 435,
  [592] = 441,
  [593] = 445,
  [594] = 442,
  [595] = 446,
  [596] = 447,
  [597] = 468,
  [598] = 448,
  [599] = 449,
  [600] = 450,
  [601] = 451,
  [602] = 602,
  [603] = 469,
  [604] = 470,
  [605] = 405,
  [606] = 406,
  [607] = 607,
  [608] = 452,
  [609] = 407,
  [610] = 415,
  [611] = 416,
  [612] = 417,
  [613] = 405,
  [614] = 408,
  [615] = 453,
  [616] = 616,
  [617] = 413,
  [618] = 419,
  [619] = 419,
  [620] = 420,
  [621] = 421,
  [622] = 422,
  [623] = 420,
  [624] = 624,
  [625] = 417,
  [626] = 410,
  [627] = 454,
  [628] = 425,
  [629] = 585,
  [630] = 491,
  [631] = 527,
  [632] = 528,
  [633] = 607,
  [634] = 455,
  [635] = 616,
  [636] = 624,
  [637] = 583,
  [638] = 426,
  [639] = 427,
  [640] = 456,
  [641] = 429,
  [642] = 477,
  [643] = 481,
  [644] = 482,
  [645] = 602,
  [646] = 406,
  [647] = 407,
  [648] = 408,
  [649] = 409,
  [650] = 410,
  [651] = 411,
  [652] = 412,
  [653] = 413,
  [654] = 414,
  [655] = 415,
  [656] = 416,
  [657] = 417,
  [658] = 405,
  [659] = 419,
  [660] = 420,
  [661] = 421,
  [662] = 422,
  [663] = 457,
  [664] = 425,
  [665] = 585,
  [666] = 491,
  [667] = 527,
  [668] = 528,
  [669] = 607,
  [670] = 616,
  [671] = 624,
  [672] = 583,
  [673] = 426,
  [674] = 427,
  [675] = 429,
  [676] = 477,
  [677] = 481,
  [678] = 482,
  [679] = 602,
  [680] = 406,
  [681] = 407,
  [682] = 408,
  [683] = 409,
  [684] = 410,
  [685] = 411,
  [686] = 412,
  [687] = 413,
  [688] = 414,
  [689] = 415,
  [690] = 416,
  [691] = 417,
  [692] = 405,
  [693] = 419,
  [694] = 420,
  [695] = 421,
  [696] = 422,
  [697] = 471,
  [698] = 414,
  [699] = 421,
  [700] = 422,
  [701] = 464,
  [702] = 425,
  [703] = 585,
  [704] = 491,
  [705] = 527,
  [706] = 479,
  [707] = 480,
  [708] = 528,
  [709] = 607,
  [710] = 616,
  [711] = 587,
  [712] = 588,
  [713] = 624,
  [714] = 425,
  [715] = 583,
  [716] = 479,
  [717] = 480,
  [718] = 587,
  [719] = 588,
  [720] = 585,
  [721] = 426,
  [722] = 479,
  [723] = 480,
  [724] = 587,
  [725] = 588,
  [726] = 491,
  [727] = 479,
  [728] = 480,
  [729] = 587,
  [730] = 588,
  [731] = 527,
  [732] = 479,
  [733] = 480,
  [734] = 587,
  [735] = 588,
  [736] = 427,
  [737] = 528,
  [738] = 607,
  [739] = 616,
  [740] = 624,
  [741] = 583,
  [742] = 426,
  [743] = 427,
  [744] = 429,
  [745] = 477,
  [746] = 481,
  [747] = 482,
  [748] = 602,
  [749] = 406,
  [750] = 407,
  [751] = 408,
  [752] = 409,
  [753] = 410,
  [754] = 411,
  [755] = 412,
  [756] = 413,
  [757] = 414,
  [758] = 415,
  [759] = 416,
  [760] = 417,
  [761] = 429,
  [762] = 477,
  [763] = 419,
  [764] = 420,
  [765] = 421,
  [766] = 422,
  [767] = 425,
  [768] = 585,
  [769] = 491,
  [770] = 527,
  [771] = 528,
  [772] = 607,
  [773] = 616,
  [774] = 624,
  [775] = 583,
  [776] = 426,
  [777] = 427,
  [778] = 429,
  [779] = 477,
  [780] = 481,
  [781] = 482,
  [782] = 481,
  [783] = 602,
  [784] = 406,
  [785] = 407,
  [786] = 408,
  [787] = 482,
  [788] = 602,
  [789] = 409,
  [790] = 410,
  [791] = 411,
  [792] = 412,
  [793] = 413,
  [794] = 414,
  [795] = 415,
  [796] = 416,
  [797] = 409,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 163,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 804,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 832,
  [850] = 833,
  [851] = 851,
  [852] = 852,
  [853] = 809,
  [854] = 812,
  [855] = 813,
  [856] = 819,
  [857] = 831,
  [858] = 841,
  [859] = 843,
  [860] = 845,
  [861] = 847,
  [862] = 848,
  [863] = 863,
  [864] = 864,
  [865] = 865,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 798,
  [873] = 873,
  [874] = 874,
  [875] = 875,
  [876] = 876,
  [877] = 877,
  [878] = 878,
  [879] = 879,
  [880] = 880,
  [881] = 881,
  [882] = 882,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 800,
  [887] = 801,
  [888] = 802,
  [889] = 803,
  [890] = 805,
  [891] = 806,
  [892] = 807,
  [893] = 863,
  [894] = 864,
  [895] = 814,
  [896] = 815,
  [897] = 816,
  [898] = 817,
  [899] = 818,
  [900] = 820,
  [901] = 821,
  [902] = 822,
  [903] = 823,
  [904] = 824,
  [905] = 825,
  [906] = 826,
  [907] = 827,
  [908] = 828,
  [909] = 829,
  [910] = 830,
  [911] = 865,
  [912] = 866,
  [913] = 835,
  [914] = 836,
  [915] = 837,
  [916] = 838,
  [917] = 839,
  [918] = 840,
  [919] = 842,
  [920] = 867,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 921,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 922,
  [931] = 923,
  [932] = 924,
  [933] = 933,
  [934] = 934,
  [935] = 935,
  [936] = 936,
  [937] = 937,
  [938] = 938,
  [939] = 939,
  [940] = 851,
  [941] = 868,
  [942] = 926,
  [943] = 943,
  [944] = 804,
  [945] = 832,
  [946] = 833,
  [947] = 851,
  [948] = 852,
  [949] = 809,
  [950] = 812,
  [951] = 813,
  [952] = 819,
  [953] = 831,
  [954] = 841,
  [955] = 843,
  [956] = 845,
  [957] = 847,
  [958] = 848,
  [959] = 863,
  [960] = 864,
  [961] = 865,
  [962] = 866,
  [963] = 867,
  [964] = 868,
  [965] = 869,
  [966] = 870,
  [967] = 871,
  [968] = 873,
  [969] = 874,
  [970] = 875,
  [971] = 876,
  [972] = 877,
  [973] = 878,
  [974] = 879,
  [975] = 880,
  [976] = 881,
  [977] = 882,
  [978] = 883,
  [979] = 884,
  [980] = 885,
  [981] = 800,
  [982] = 801,
  [983] = 802,
  [984] = 803,
  [985] = 805,
  [986] = 806,
  [987] = 807,
  [988] = 814,
  [989] = 815,
  [990] = 816,
  [991] = 817,
  [992] = 818,
  [993] = 820,
  [994] = 821,
  [995] = 822,
  [996] = 823,
  [997] = 824,
  [998] = 825,
  [999] = 826,
  [1000] = 827,
  [1001] = 828,
  [1002] = 829,
  [1003] = 830,
  [1004] = 835,
  [1005] = 836,
  [1006] = 837,
  [1007] = 838,
  [1008] = 839,
  [1009] = 840,
  [1010] = 842,
  [1011] = 921,
  [1012] = 922,
  [1013] = 923,
  [1014] = 924,
  [1015] = 869,
  [1016] = 926,
  [1017] = 927,
  [1018] = 928,
  [1019] = 929,
  [1020] = 870,
  [1021] = 871,
  [1022] = 1022,
  [1023] = 933,
  [1024] = 934,
  [1025] = 935,
  [1026] = 1026,
  [1027] = 936,
  [1028] = 937,
  [1029] = 938,
  [1030] = 939,
  [1031] = 927,
  [1032] = 943,
  [1033] = 928,
  [1034] = 929,
  [1035] = 804,
  [1036] = 832,
  [1037] = 833,
  [1038] = 851,
  [1039] = 852,
  [1040] = 809,
  [1041] = 812,
  [1042] = 813,
  [1043] = 819,
  [1044] = 831,
  [1045] = 841,
  [1046] = 843,
  [1047] = 845,
  [1048] = 847,
  [1049] = 848,
  [1050] = 863,
  [1051] = 864,
  [1052] = 865,
  [1053] = 866,
  [1054] = 867,
  [1055] = 868,
  [1056] = 869,
  [1057] = 870,
  [1058] = 871,
  [1059] = 933,
  [1060] = 798,
  [1061] = 873,
  [1062] = 874,
  [1063] = 875,
  [1064] = 876,
  [1065] = 877,
  [1066] = 878,
  [1067] = 879,
  [1068] = 880,
  [1069] = 881,
  [1070] = 882,
  [1071] = 883,
  [1072] = 884,
  [1073] = 885,
  [1074] = 800,
  [1075] = 801,
  [1076] = 802,
  [1077] = 803,
  [1078] = 805,
  [1079] = 806,
  [1080] = 807,
  [1081] = 934,
  [1082] = 935,
  [1083] = 814,
  [1084] = 815,
  [1085] = 816,
  [1086] = 817,
  [1087] = 818,
  [1088] = 820,
  [1089] = 821,
  [1090] = 822,
  [1091] = 823,
  [1092] = 824,
  [1093] = 825,
  [1094] = 826,
  [1095] = 827,
  [1096] = 828,
  [1097] = 829,
  [1098] = 830,
  [1099] = 835,
  [1100] = 836,
  [1101] = 837,
  [1102] = 838,
  [1103] = 839,
  [1104] = 840,
  [1105] = 842,
  [1106] = 921,
  [1107] = 922,
  [1108] = 923,
  [1109] = 924,
  [1110] = 1110,
  [1111] = 926,
  [1112] = 927,
  [1113] = 928,
  [1114] = 929,
  [1115] = 852,
  [1116] = 936,
  [1117] = 933,
  [1118] = 934,
  [1119] = 935,
  [1120] = 798,
  [1121] = 936,
  [1122] = 873,
  [1123] = 937,
  [1124] = 938,
  [1125] = 939,
  [1126] = 874,
  [1127] = 943,
  [1128] = 804,
  [1129] = 832,
  [1130] = 833,
  [1131] = 851,
  [1132] = 852,
  [1133] = 809,
  [1134] = 812,
  [1135] = 813,
  [1136] = 819,
  [1137] = 831,
  [1138] = 841,
  [1139] = 843,
  [1140] = 845,
  [1141] = 847,
  [1142] = 848,
  [1143] = 863,
  [1144] = 864,
  [1145] = 865,
  [1146] = 866,
  [1147] = 867,
  [1148] = 868,
  [1149] = 869,
  [1150] = 870,
  [1151] = 871,
  [1152] = 798,
  [1153] = 873,
  [1154] = 874,
  [1155] = 875,
  [1156] = 876,
  [1157] = 877,
  [1158] = 878,
  [1159] = 879,
  [1160] = 880,
  [1161] = 881,
  [1162] = 882,
  [1163] = 883,
  [1164] = 884,
  [1165] = 885,
  [1166] = 800,
  [1167] = 801,
  [1168] = 802,
  [1169] = 803,
  [1170] = 805,
  [1171] = 806,
  [1172] = 807,
  [1173] = 814,
  [1174] = 815,
  [1175] = 816,
  [1176] = 817,
  [1177] = 818,
  [1178] = 820,
  [1179] = 821,
  [1180] = 822,
  [1181] = 823,
  [1182] = 824,
  [1183] = 825,
  [1184] = 826,
  [1185] = 827,
  [1186] = 828,
  [1187] = 829,
  [1188] = 830,
  [1189] = 835,
  [1190] = 836,
  [1191] = 837,
  [1192] = 838,
  [1193] = 839,
  [1194] = 840,
  [1195] = 921,
  [1196] = 804,
  [1197] = 832,
  [1198] = 833,
  [1199] = 851,
  [1200] = 852,
  [1201] = 809,
  [1202] = 812,
  [1203] = 813,
  [1204] = 819,
  [1205] = 831,
  [1206] = 841,
  [1207] = 843,
  [1208] = 845,
  [1209] = 847,
  [1210] = 848,
  [1211] = 863,
  [1212] = 864,
  [1213] = 865,
  [1214] = 866,
  [1215] = 867,
  [1216] = 868,
  [1217] = 869,
  [1218] = 870,
  [1219] = 871,
  [1220] = 798,
  [1221] = 873,
  [1222] = 874,
  [1223] = 875,
  [1224] = 876,
  [1225] = 877,
  [1226] = 878,
  [1227] = 879,
  [1228] = 880,
  [1229] = 881,
  [1230] = 882,
  [1231] = 883,
  [1232] = 884,
  [1233] = 885,
  [1234] = 800,
  [1235] = 801,
  [1236] = 802,
  [1237] = 803,
  [1238] = 805,
  [1239] = 806,
  [1240] = 807,
  [1241] = 814,
  [1242] = 815,
  [1243] = 816,
  [1244] = 817,
  [1245] = 818,
  [1246] = 820,
  [1247] = 821,
  [1248] = 822,
  [1249] = 823,
  [1250] = 824,
  [1251] = 825,
  [1252] = 827,
  [1253] = 828,
  [1254] = 829,
  [1255] = 830,
  [1256] = 835,
  [1257] = 836,
  [1258] = 837,
  [1259] = 838,
  [1260] = 839,
  [1261] = 840,
  [1262] = 921,
  [1263] = 804,
  [1264] = 832,
  [1265] = 833,
  [1266] = 851,
  [1267] = 852,
  [1268] = 809,
  [1269] = 812,
  [1270] = 813,
  [1271] = 819,
  [1272] = 831,
  [1273] = 841,
  [1274] = 843,
  [1275] = 845,
  [1276] = 847,
  [1277] = 848,
  [1278] = 863,
  [1279] = 864,
  [1280] = 865,
  [1281] = 866,
  [1282] = 867,
  [1283] = 868,
  [1284] = 869,
  [1285] = 870,
  [1286] = 871,
  [1287] = 798,
  [1288] = 873,
  [1289] = 874,
  [1290] = 875,
  [1291] = 876,
  [1292] = 877,
  [1293] = 878,
  [1294] = 879,
  [1295] = 880,
  [1296] = 881,
  [1297] = 882,
  [1298] = 883,
  [1299] = 884,
  [1300] = 885,
  [1301] = 800,
  [1302] = 801,
  [1303] = 802,
  [1304] = 803,
  [1305] = 805,
  [1306] = 806,
  [1307] = 807,
  [1308] = 814,
  [1309] = 815,
  [1310] = 816,
  [1311] = 817,
  [1312] = 818,
  [1313] = 820,
  [1314] = 821,
  [1315] = 822,
  [1316] = 823,
  [1317] = 824,
  [1318] = 825,
  [1319] = 826,
  [1320] = 827,
  [1321] = 828,
  [1322] = 829,
  [1323] = 830,
  [1324] = 835,
  [1325] = 836,
  [1326] = 837,
  [1327] = 838,
  [1328] = 839,
  [1329] = 840,
  [1330] = 921,
  [1331] = 804,
  [1332] = 832,
  [1333] = 833,
  [1334] = 851,
  [1335] = 852,
  [1336] = 809,
  [1337] = 812,
  [1338] = 813,
  [1339] = 819,
  [1340] = 831,
  [1341] = 841,
  [1342] = 843,
  [1343] = 845,
  [1344] = 847,
  [1345] = 848,
  [1346] = 863,
  [1347] = 864,
  [1348] = 865,
  [1349] = 866,
  [1350] = 867,
  [1351] = 868,
  [1352] = 869,
  [1353] = 870,
  [1354] = 871,
  [1355] = 798,
  [1356] = 873,
  [1357] = 874,
  [1358] = 875,
  [1359] = 876,
  [1360] = 877,
  [1361] = 878,
  [1362] = 879,
  [1363] = 880,
  [1364] = 881,
  [1365] = 882,
  [1366] = 883,
  [1367] = 884,
  [1368] = 885,
  [1369] = 800,
  [1370] = 801,
  [1371] = 802,
  [1372] = 803,
  [1373] = 805,
  [1374] = 806,
  [1375] = 807,
  [1376] = 814,
  [1377] = 815,
  [1378] = 816,
  [1379] = 817,
  [1380] = 818,
  [1381] = 820,
  [1382] = 821,
  [1383] = 822,
  [1384] = 823,
  [1385] = 824,
  [1386] = 825,
  [1387] = 826,
  [1388] = 827,
  [1389] = 828,
  [1390] = 829,
  [1391] = 830,
  [1392] = 835,
  [1393] = 836,
  [1394] = 837,
  [1395] = 838,
  [1396] = 839,
  [1397] = 840,
  [1398] = 921,
  [1399] = 804,
  [1400] = 832,
  [1401] = 833,
  [1402] = 851,
  [1403] = 852,
  [1404] = 809,
  [1405] = 812,
  [1406] = 813,
  [1407] = 819,
  [1408] = 831,
  [1409] = 841,
  [1410] = 843,
  [1411] = 845,
  [1412] = 847,
  [1413] = 848,
  [1414] = 863,
  [1415] = 864,
  [1416] = 865,
  [1417] = 866,
  [1418] = 867,
  [1419] = 868,
  [1420] = 869,
  [1421] = 870,
  [1422] = 871,
  [1423] = 798,
  [1424] = 873,
  [1425] = 874,
  [1426] = 875,
  [1427] = 876,
  [1428] = 877,
  [1429] = 878,
  [1430] = 879,
  [1431] = 880,
  [1432] = 881,
  [1433] = 882,
  [1434] = 883,
  [1435] = 884,
  [1436] = 885,
  [1437] = 800,
  [1438] = 801,
  [1439] = 802,
  [1440] = 803,
  [1441] = 805,
  [1442] = 806,
  [1443] = 807,
  [1444] = 814,
  [1445] = 815,
  [1446] = 816,
  [1447] = 817,
  [1448] = 818,
  [1449] = 820,
  [1450] = 821,
  [1451] = 822,
  [1452] = 823,
  [1453] = 824,
  [1454] = 825,
  [1455] = 826,
  [1456] = 827,
  [1457] = 828,
  [1458] = 829,
  [1459] = 830,
  [1460] = 835,
  [1461] = 836,
  [1462] = 837,
  [1463] = 838,
  [1464] = 839,
  [1465] = 840,
  [1466] = 921,
  [1467] = 831,
  [1468] = 869,
  [1469] = 870,
  [1470] = 871,
  [1471] = 805,
  [1472] = 806,
  [1473] = 807,
  [1474] = 830,
  [1475] = 831,
  [1476] = 869,
  [1477] = 870,
  [1478] = 871,
  [1479] = 805,
  [1480] = 806,
  [1481] = 807,
  [1482] = 830,
  [1483] = 831,
  [1484] = 869,
  [1485] = 870,
  [1486] = 871,
  [1487] = 805,
  [1488] = 806,
  [1489] = 807,
  [1490] = 830,
  [1491] = 831,
  [1492] = 869,
  [1493] = 870,
  [1494] = 871,
  [1495] = 805,
  [1496] = 806,
  [1497] = 807,
  [1498] = 830,
  [1499] = 831,
  [1500] = 869,
  [1501] = 870,
  [1502] = 871,
  [1503] = 805,
  [1504] = 806,
  [1505] = 807,
  [1506] = 830,
  [1507] = 831,
  [1508] = 869,
  [1509] = 870,
  [1510] = 871,
  [1511] = 805,
  [1512] = 806,
  [1513] = 807,
  [1514] = 830,
  [1515] = 831,
  [1516] = 869,
  [1517] = 870,
  [1518] = 871,
  [1519] = 805,
  [1520] = 806,
  [1521] = 807,
  [1522] = 830,
  [1523] = 831,
  [1524] = 869,
  [1525] = 870,
  [1526] = 871,
  [1527] = 805,
  [1528] = 806,
  [1529] = 807,
  [1530] = 830,
  [1531] = 831,
  [1532] = 869,
  [1533] = 870,
  [1534] = 871,
  [1535] = 805,
  [1536] = 806,
  [1537] = 807,
  [1538] = 830,
  [1539] = 831,
  [1540] = 869,
  [1541] = 870,
  [1542] = 871,
  [1543] = 805,
  [1544] = 806,
  [1545] = 807,
  [1546] = 830,
  [1547] = 831,
  [1548] = 869,
  [1549] = 870,
  [1550] = 871,
  [1551] = 805,
  [1552] = 806,
  [1553] = 807,
  [1554] = 830,
  [1555] = 831,
  [1556] = 869,
  [1557] = 870,
  [1558] = 871,
  [1559] = 805,
  [1560] = 806,
  [1561] = 807,
  [1562] = 830,
  [1563] = 875,
  [1564] = 876,
  [1565] = 937,
  [1566] = 938,
  [1567] = 939,
  [1568] = 877,
  [1569] = 878,
  [1570] = 834,
  [1571] = 1022,
  [1572] = 1026,
  [1573] = 799,
  [1574] = 834,
  [1575] = 1022,
  [1576] = 1026,
  [1577] = 799,
  [1578] = 834,
  [1579] = 1022,
  [1580] = 1026,
  [1581] = 799,
  [1582] = 834,
  [1583] = 1022,
  [1584] = 1026,
  [1585] = 799,
  [1586] = 834,
  [1587] = 1022,
  [1588] = 1026,
  [1589] = 799,
  [1590] = 834,
  [1591] = 1022,
  [1592] = 1026,
  [1593] = 799,
  [1594] = 834,
  [1595] = 1022,
  [1596] = 1026,
  [1597] = 799,
  [1598] = 834,
  [1599] = 1022,
  [1600] = 1026,
  [1601] = 799,
  [1602] = 834,
  [1603] = 1022,
  [1604] = 1026,
  [1605] = 799,
  [1606] = 834,
  [1607] = 1022,
  [1608] = 1026,
  [1609] = 799,
  [1610] = 834,
  [1611] = 1022,
  [1612] = 1026,
  [1613] = 799,
  [1614] = 834,
  [1615] = 1022,
  [1616] = 1026,
  [1617] = 799,
  [1618] = 834,
  [1619] = 1022,
  [1620] = 1026,
  [1621] = 799,
  [1622] = 834,
  [1623] = 1022,
  [1624] = 1026,
  [1625] = 799,
  [1626] = 834,
  [1627] = 1022,
  [1628] = 1026,
  [1629] = 799,
  [1630] = 834,
  [1631] = 1022,
  [1632] = 1026,
  [1633] = 799,
  [1634] = 834,
  [1635] = 1022,
  [1636] = 1026,
  [1637] = 799,
  [1638] = 834,
  [1639] = 1022,
  [1640] = 1026,
  [1641] = 799,
  [1642] = 834,
  [1643] = 1022,
  [1644] = 1026,
  [1645] = 799,
  [1646] = 834,
  [1647] = 1022,
  [1648] = 1026,
  [1649] = 799,
  [1650] = 879,
  [1651] = 880,
  [1652] = 881,
  [1653] = 882,
  [1654] = 943,
  [1655] = 883,
  [1656] = 884,
  [1657] = 885,
  [1658] = 826,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 250,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1665,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 1668,
  [1669] = 1669,
  [1670] = 1670,
  [1671] = 1671,
  [1672] = 1666,
  [1673] = 1673,
  [1674] = 1662,
  [1675] = 1663,
  [1676] = 1664,
  [1677] = 1665,
  [1678] = 1659,
  [1679] = 1679,
  [1680] = 1680,
  [1681] = 1681,
  [1682] = 1682,
  [1683] = 1683,
  [1684] = 1660,
  [1685] = 1685,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1671,
  [1690] = 1666,
  [1691] = 1673,
  [1692] = 1662,
  [1693] = 1663,
  [1694] = 1664,
  [1695] = 1665,
  [1696] = 1659,
  [1697] = 1679,
  [1698] = 1680,
  [1699] = 1681,
  [1700] = 1682,
  [1701] = 1683,
  [1702] = 1660,
  [1703] = 1685,
  [1704] = 1686,
  [1705] = 1687,
  [1706] = 1688,
  [1707] = 1671,
  [1708] = 1666,
  [1709] = 1673,
  [1710] = 1662,
  [1711] = 1663,
  [1712] = 1664,
  [1713] = 1665,
  [1714] = 1714,
  [1715] = 1680,
  [1716] = 1681,
  [1717] = 1682,
  [1718] = 1683,
  [1719] = 1660,
  [1720] = 1685,
  [1721] = 1686,
  [1722] = 1687,
  [1723] = 1688,
  [1724] = 1659,
  [1725] = 1679,
  [1726] = 1685,
  [1727] = 1680,
  [1728] = 1673,
  [1729] = 1729,
  [1730] = 1730,
  [1731] = 1731,
  [1732] = 1732,
  [1733] = 1671,
  [1734] = 1734,
  [1735] = 1735,
  [1736] = 1714,
  [1737] = 1681,
  [1738] = 1682,
  [1739] = 1683,
  [1740] = 1668,
  [1741] = 1669,
  [1742] = 1670,
  [1743] = 1731,
  [1744] = 1732,
  [1745] = 1734,
  [1746] = 1735,
  [1747] = 1667,
  [1748] = 1668,
  [1749] = 1669,
  [1750] = 1670,
  [1751] = 1731,
  [1752] = 1732,
  [1753] = 1734,
  [1754] = 1735,
  [1755] = 1667,
  [1756] = 1668,
  [1757] = 1669,
  [1758] = 1670,
  [1759] = 1731,
  [1760] = 1732,
  [1761] = 1734,
  [1762] = 1735,
  [1763] = 1667,
  [1764] = 1686,
  [1765] = 1687,
  [1766] = 1688,
  [1767] = 1729,
  [1768] = 1730,
  [1769] = 1679,
  [1770] = 1770,
  [1771] = 1771,
  [1772] = 1772,
  [1773] = 1773,
  [1774] = 1774,
  [1775] = 1775,
  [1776] = 1776,
  [1777] = 1777,
  [1778] = 1778,
  [1779] = 1779,
  [1780] = 1780,
  [1781] = 1781,
  [1782] = 1782,
  [1783] = 1783,
  [1784] = 1784,
  [1785] = 1785,
  [1786] = 1786,
  [1787] = 1787,
  [1788] = 1788,
  [1789] = 1789,
  [1790] = 1790,
  [1791] = 1791,
  [1792] = 1792,
  [1793] = 1793,
  [1794] = 1794,
  [1795] = 1795,
  [1796] = 1796,
  [1797] = 1797,
  [1798] = 1798,
  [1799] = 1799,
  [1800] = 1800,
  [1801] = 1801,
  [1802] = 1802,
  [1803] = 1803,
  [1804] = 1804,
  [1805] = 1805,
  [1806] = 1806,
  [1807] = 1807,
  [1808] = 1808,
  [1809] = 1809,
  [1810] = 1810,
  [1811] = 1811,
  [1812] = 1812,
  [1813] = 1813,
  [1814] = 1814,
  [1815] = 1815,
  [1816] = 1816,
  [1817] = 1817,
  [1818] = 1818,
  [1819] = 1819,
  [1820] = 1820,
  [1821] = 1821,
  [1822] = 1822,
  [1823] = 1823,
  [1824] = 1824,
  [1825] = 1825,
  [1826] = 1826,
  [1827] = 1827,
  [1828] = 1828,
  [1829] = 1829,
  [1830] = 1830,
  [1831] = 1831,
  [1832] = 1832,
  [1833] = 1833,
  [1834] = 1834,
  [1835] = 1835,
  [1836] = 1836,
  [1837] = 1837,
  [1838] = 1838,
  [1839] = 1839,
  [1840] = 1840,
  [1841] = 1841,
  [1842] = 1842,
  [1843] = 1843,
  [1844] = 1844,
  [1845] = 1845,
  [1846] = 1846,
  [1847] = 1847,
  [1848] = 1848,
  [1849] = 1849,
  [1850] = 1850,
  [1851] = 1851,
  [1852] = 1852,
  [1853] = 1853,
  [1854] = 1854,
  [1855] = 1855,
  [1856] = 1856,
  [1857] = 1857,
  [1858] = 1858,
  [1859] = 1859,
  [1860] = 1860,
  [1861] = 1861,
  [1862] = 1861,
  [1863] = 1861,
  [1864] = 1861,
  [1865] = 1865,
  [1866] = 1861,
  [1867] = 1865,
  [1868] = 1868,
  [1869] = 1865,
  [1870] = 1861,
  [1871] = 1861,
  [1872] = 1861,
  [1873] = 1771,
  [1874] = 1811,
  [1875] = 1793,
  [1876] = 1805,
  [1877] = 1792,
  [1878] = 1798,
  [1879] = 1778,
  [1880] = 1777,
  [1881] = 1806,
  [1882] = 1808,
  [1883] = 1810,
  [1884] = 1812,
  [1885] = 1794,
  [1886] = 1796,
  [1887] = 1797,
  [1888] = 1795,
  [1889] = 1775,
  [1890] = 1783,
  [1891] = 1791,
  [1892] = 1799,
  [1893] = 1802,
  [1894] = 1772,
  [1895] = 1800,
  [1896] = 1801,
  [1897] = 1785,
  [1898] = 1803,
  [1899] = 1899,
  [1900] = 1900,
  [1901] = 1901,
  [1902] = 1902,
  [1903] = 1784,
  [1904] = 1813,
  [1905] = 1899,
  [1906] = 1779,
  [1907] = 1780,
  [1908] = 1781,
  [1909] = 1782,
  [1910] = 1809,
  [1911] = 1786,
  [1912] = 1776,
  [1913] = 1773,
  [1914] = 1774,
  [1915] = 1902,
  [1916] = 1804,
  [1917] = 1790,
  [1918] = 1807,
  [1919] = 1789,
  [1920] = 1787,
  [1921] = 1788,
  [1922] = 1900,
  [1923] = 1901,
  [1924] = 1831,
  [1925] = 1832,
  [1926] = 1815,
  [1927] = 1833,
  [1928] = 1819,
  [1929] = 1826,
  [1930] = 1824,
  [1931] = 1823,
  [1932] = 1825,
  [1933] = 1817,
  [1934] = 1818,
  [1935] = 1820,
  [1936] = 1821,
  [1937] = 1822,
  [1938] = 1816,
  [1939] = 1771,
  [1940] = 1814,
  [1941] = 1830,
  [1942] = 1784,
  [1943] = 1943,
  [1944] = 1800,
  [1945] = 1836,
  [1946] = 1837,
  [1947] = 1844,
  [1948] = 1801,
  [1949] = 1949,
  [1950] = 1783,
  [1951] = 1951,
  [1952] = 1793,
  [1953] = 1838,
  [1954] = 1794,
  [1955] = 1797,
  [1956] = 1786,
  [1957] = 1845,
  [1958] = 1856,
  [1959] = 1776,
  [1960] = 1792,
  [1961] = 1798,
  [1962] = 1811,
  [1963] = 1777,
  [1964] = 1778,
  [1965] = 1965,
  [1966] = 1966,
  [1967] = 1805,
  [1968] = 1785,
  [1969] = 1795,
  [1970] = 1970,
  [1971] = 1773,
  [1972] = 1943,
  [1973] = 1966,
  [1974] = 1974,
  [1975] = 1975,
  [1976] = 1970,
  [1977] = 1774,
  [1978] = 1782,
  [1979] = 1806,
  [1980] = 1808,
  [1981] = 1858,
  [1982] = 1852,
  [1983] = 1802,
  [1984] = 1803,
  [1985] = 1985,
  [1986] = 1986,
  [1987] = 1804,
  [1988] = 1807,
  [1989] = 1809,
  [1990] = 1790,
  [1991] = 1789,
  [1992] = 1799,
  [1993] = 1993,
  [1994] = 1796,
  [1995] = 1993,
  [1996] = 1975,
  [1997] = 1787,
  [1998] = 1788,
  [1999] = 1812,
  [2000] = 1772,
  [2001] = 1974,
  [2002] = 1791,
  [2003] = 1986,
  [2004] = 1857,
  [2005] = 1859,
  [2006] = 1860,
  [2007] = 1841,
  [2008] = 1835,
  [2009] = 1839,
  [2010] = 1842,
  [2011] = 1843,
  [2012] = 1846,
  [2013] = 1985,
  [2014] = 1847,
  [2015] = 1854,
  [2016] = 1853,
  [2017] = 1840,
  [2018] = 1848,
  [2019] = 1849,
  [2020] = 1855,
  [2021] = 1850,
  [2022] = 1851,
  [2023] = 1779,
  [2024] = 1780,
  [2025] = 1781,
  [2026] = 1813,
  [2027] = 1951,
  [2028] = 1810,
  [2029] = 1775,
  [2030] = 1815,
  [2031] = 1819,
  [2032] = 1824,
  [2033] = 1817,
  [2034] = 1814,
  [2035] = 1831,
  [2036] = 1823,
  [2037] = 1816,
  [2038] = 1830,
  [2039] = 1818,
  [2040] = 1820,
  [2041] = 1832,
  [2042] = 1821,
  [2043] = 1822,
  [2044] = 1825,
  [2045] = 1833,
  [2046] = 1826,
  [2047] = 2047,
  [2048] = 1837,
  [2049] = 1860,
  [2050] = 1856,
  [2051] = 1841,
  [2052] = 1848,
  [2053] = 2047,
  [2054] = 2047,
  [2055] = 1854,
  [2056] = 1852,
  [2057] = 1839,
  [2058] = 1842,
  [2059] = 1843,
  [2060] = 161,
  [2061] = 1850,
  [2062] = 1853,
  [2063] = 1838,
  [2064] = 1855,
  [2065] = 1849,
  [2066] = 2047,
  [2067] = 1846,
  [2068] = 2047,
  [2069] = 2047,
  [2070] = 1858,
  [2071] = 1847,
  [2072] = 2047,
  [2073] = 1840,
  [2074] = 1835,
  [2075] = 2075,
  [2076] = 1851,
  [2077] = 1859,
  [2078] = 1836,
  [2079] = 1844,
  [2080] = 2075,
  [2081] = 1857,
  [2082] = 2047,
  [2083] = 2047,
  [2084] = 1845,
  [2085] = 164,
  [2086] = 166,
  [2087] = 2087,
  [2088] = 1965,
  [2089] = 2089,
  [2090] = 2090,
  [2091] = 1834,
  [2092] = 2092,
  [2093] = 2093,
  [2094] = 1965,
  [2095] = 2095,
  [2096] = 250,
  [2097] = 2097,
  [2098] = 161,
  [2099] = 2099,
  [2100] = 2100,
  [2101] = 2101,
  [2102] = 2102,
  [2103] = 164,
  [2104] = 166,
  [2105] = 2105,
  [2106] = 2106,
  [2107] = 2107,
  [2108] = 2106,
  [2109] = 2107,
  [2110] = 2106,
  [2111] = 2107,
  [2112] = 2106,
  [2113] = 2113,
  [2114] = 2114,
  [2115] = 2115,
  [2116] = 2116,
  [2117] = 2113,
  [2118] = 2114,
  [2119] = 2115,
  [2120] = 2116,
  [2121] = 2121,
  [2122] = 2122,
  [2123] = 2123,
  [2124] = 2124,
  [2125] = 2113,
  [2126] = 2114,
  [2127] = 2115,
  [2128] = 2116,
  [2129] = 2107,
  [2130] = 2106,
  [2131] = 2113,
  [2132] = 2114,
  [2133] = 2115,
  [2134] = 2116,
  [2135] = 2113,
  [2136] = 2114,
  [2137] = 2115,
  [2138] = 2116,
  [2139] = 2113,
  [2140] = 2114,
  [2141] = 2115,
  [2142] = 2113,
  [2143] = 2114,
  [2144] = 2115,
  [2145] = 2113,
  [2146] = 2114,
  [2147] = 2115,
  [2148] = 2148,
  [2149] = 2149,
  [2150] = 2123,
  [2151] = 2151,
  [2152] = 2152,
  [2153] = 2148,
  [2154] = 2149,
  [2155] = 2123,
  [2156] = 2151,
  [2157] = 2107,
  [2158] = 2151,
  [2159] = 2152,
  [2160] = 2148,
  [2161] = 2107,
  [2162] = 2148,
  [2163] = 2149,
  [2164] = 2123,
  [2165] = 2151,
  [2166] = 2106,
  [2167] = 2148,
  [2168] = 2149,
  [2169] = 2123,
  [2170] = 2151,
  [2171] = 2148,
  [2172] = 2149,
  [2173] = 2151,
  [2174] = 2148,
  [2175] = 2149,
  [2176] = 2123,
  [2177] = 2151,
  [2178] = 2113,
  [2179] = 2106,
  [2180] = 2180,
  [2181] = 2107,
  [2182] = 2106,
  [2183] = 2114,
  [2184] = 2115,
  [2185] = 2149,
  [2186] = 2148,
  [2187] = 2149,
  [2188] = 2123,
  [2189] = 2151,
  [2190] = 2123,
  [2191] = 2151,
  [2192] = 2107,
  [2193] = 2106,
  [2194] = 2123,
  [2195] = 2151,
  [2196] = 2107,
  [2197] = 2123,
  [2198] = 2151,
  [2199] = 2123,
  [2200] = 2151,
  [2201] = 2123,
  [2202] = 2151,
  [2203] = 2123,
  [2204] = 2151,
  [2205] = 2107,
  [2206] = 2106,
  [2207] = 2116,
  [2208] = 2208,
  [2209] = 2107,
  [2210] = 2106,
  [2211] = 2124,
  [2212] = 2124,
  [2213] = 2124,
  [2214] = 2107,
  [2215] = 2106,
  [2216] = 2124,
  [2217] = 2124,
  [2218] = 2124,
  [2219] = 2124,
  [2220] = 2124,
  [2221] = 2124,
  [2222] = 2124,
  [2223] = 2124,
  [2224] = 2124,
  [2225] = 2124,
  [2226] = 2107,
  [2227] = 2106,
  [2228] = 2107,
  [2229] = 2106,
  [2230] = 2107,
  [2231] = 2106,
  [2232] = 2107,
  [2233] = 2106,
  [2234] = 2123,
  [2235] = 2235,
  [2236] = 2235,
  [2237] = 2237,
  [2238] = 2237,
  [2239] = 2235,
  [2240] = 2235,
  [2241] = 2235,
  [2242] = 2235,
  [2243] = 2235,
  [2244] = 161,
  [2245] = 2235,
  [2246] = 2235,
  [2247] = 2247,
  [2248] = 2248,
  [2249] = 164,
  [2250] = 166,
  [2251] = 2251,
  [2252] = 250,
  [2253] = 2251,
  [2254] = 2254,
  [2255] = 2255,
  [2256] = 2256,
  [2257] = 2257,
  [2258] = 2258,
  [2259] = 2259,
  [2260] = 1809,
  [2261] = 2261,
  [2262] = 1786,
  [2263] = 1776,
  [2264] = 1773,
  [2265] = 1774,
  [2266] = 1787,
  [2267] = 1788,
  [2268] = 1772,
  [2269] = 1791,
  [2270] = 1813,
  [2271] = 1793,
  [2272] = 1794,
  [2273] = 1795,
  [2274] = 1802,
  [2275] = 1803,
  [2276] = 1799,
  [2277] = 1807,
  [2278] = 1789,
  [2279] = 1792,
  [2280] = 1798,
  [2281] = 1811,
  [2282] = 1777,
  [2283] = 1778,
  [2284] = 1771,
  [2285] = 1785,
  [2286] = 1800,
  [2287] = 1801,
  [2288] = 2288,
  [2289] = 1790,
  [2290] = 2290,
  [2291] = 2291,
  [2292] = 2292,
  [2293] = 2293,
  [2294] = 1804,
  [2295] = 1796,
  [2296] = 1821,
  [2297] = 1822,
  [2298] = 1824,
  [2299] = 1831,
  [2300] = 1826,
  [2301] = 1819,
  [2302] = 2302,
  [2303] = 1832,
  [2304] = 1775,
  [2305] = 1779,
  [2306] = 1780,
  [2307] = 1781,
  [2308] = 1782,
  [2309] = 1818,
  [2310] = 2310,
  [2311] = 1820,
  [2312] = 1784,
  [2313] = 1830,
  [2314] = 1816,
  [2315] = 1783,
  [2316] = 1797,
  [2317] = 1833,
  [2318] = 1849,
  [2319] = 1854,
  [2320] = 1812,
  [2321] = 1859,
  [2322] = 1840,
  [2323] = 1825,
  [2324] = 1841,
  [2325] = 1860,
  [2326] = 1814,
  [2327] = 1837,
  [2328] = 1857,
  [2329] = 1838,
  [2330] = 1817,
  [2331] = 2331,
  [2332] = 1853,
  [2333] = 1855,
  [2334] = 1810,
  [2335] = 1858,
  [2336] = 1835,
  [2337] = 1836,
  [2338] = 1844,
  [2339] = 1845,
  [2340] = 1823,
  [2341] = 2341,
  [2342] = 1815,
  [2343] = 1852,
  [2344] = 1805,
  [2345] = 1839,
  [2346] = 1842,
  [2347] = 1843,
  [2348] = 1846,
  [2349] = 1847,
  [2350] = 1808,
  [2351] = 1848,
  [2352] = 1850,
  [2353] = 1851,
  [2354] = 1806,
  [2355] = 1856,
  [2356] = 2356,
  [2357] = 2357,
  [2358] = 2358,
  [2359] = 2359,
  [2360] = 2360,
  [2361] = 2361,
  [2362] = 2293,
  [2363] = 1771,
  [2364] = 1825,
  [2365] = 2365,
  [2366] = 2366,
  [2367] = 2367,
  [2368] = 2290,
  [2369] = 2291,
  [2370] = 2370,
  [2371] = 2371,
  [2372] = 2292,
  [2373] = 1830,
  [2374] = 2374,
  [2375] = 2375,
  [2376] = 2376,
  [2377] = 2377,
  [2378] = 2378,
  [2379] = 2379,
  [2380] = 2380,
  [2381] = 2381,
  [2382] = 2382,
  [2383] = 2383,
  [2384] = 2384,
  [2385] = 2385,
  [2386] = 2386,
  [2387] = 2387,
  [2388] = 2388,
  [2389] = 2389,
  [2390] = 2390,
  [2391] = 2391,
  [2392] = 2392,
  [2393] = 2393,
  [2394] = 2394,
  [2395] = 2395,
  [2396] = 2396,
  [2397] = 2397,
  [2398] = 2398,
  [2399] = 2399,
  [2400] = 2400,
  [2401] = 2401,
  [2402] = 2402,
  [2403] = 2403,
  [2404] = 2404,
  [2405] = 2405,
  [2406] = 2406,
  [2407] = 2407,
  [2408] = 2408,
  [2409] = 2409,
  [2410] = 2410,
  [2411] = 2411,
  [2412] = 2412,
  [2413] = 2413,
  [2414] = 2414,
  [2415] = 2415,
  [2416] = 2416,
  [2417] = 2417,
  [2418] = 2418,
  [2419] = 2419,
  [2420] = 2420,
  [2421] = 2421,
  [2422] = 2422,
  [2423] = 2423,
  [2424] = 2424,
  [2425] = 2425,
  [2426] = 2426,
  [2427] = 2427,
  [2428] = 2291,
  [2429] = 2429,
  [2430] = 2430,
  [2431] = 2431,
  [2432] = 2432,
  [2433] = 2433,
  [2434] = 2434,
  [2435] = 2435,
  [2436] = 2436,
  [2437] = 2437,
  [2438] = 2438,
  [2439] = 2439,
  [2440] = 2440,
  [2441] = 2441,
  [2442] = 2442,
  [2443] = 2443,
  [2444] = 2444,
  [2445] = 2445,
  [2446] = 2446,
  [2447] = 2447,
  [2448] = 2448,
  [2449] = 2449,
  [2450] = 2450,
  [2451] = 2451,
  [2452] = 2452,
  [2453] = 2453,
  [2454] = 2454,
  [2455] = 2455,
  [2456] = 2456,
  [2457] = 2457,
  [2458] = 2458,
  [2459] = 2459,
  [2460] = 2460,
  [2461] = 2461,
  [2462] = 2462,
  [2463] = 2463,
  [2464] = 2464,
  [2465] = 2376,
  [2466] = 2366,
  [2467] = 2467,
  [2468] = 2468,
  [2469] = 2469,
  [2470] = 2470,
  [2471] = 2471,
  [2472] = 2472,
  [2473] = 2473,
  [2474] = 2474,
  [2475] = 2475,
  [2476] = 2476,
  [2477] = 2477,
  [2478] = 2478,
  [2479] = 2479,
  [2480] = 2480,
  [2481] = 2481,
  [2482] = 2482,
  [2483] = 2483,
  [2484] = 2484,
  [2485] = 2485,
  [2486] = 2486,
  [2487] = 2487,
  [2488] = 2488,
  [2489] = 2489,
  [2490] = 2490,
  [2491] = 2491,
  [2492] = 2492,
  [2493] = 2493,
  [2494] = 2494,
  [2495] = 2495,
  [2496] = 2496,
  [2497] = 2497,
  [2498] = 2376,
  [2499] = 2366,
  [2500] = 2293,
  [2501] = 2376,
  [2502] = 2366,
  [2503] = 2376,
  [2504] = 2366,
  [2505] = 2505,
  [2506] = 2506,
  [2507] = 2507,
  [2508] = 2508,
  [2509] = 2509,
  [2510] = 2292,
  [2511] = 2310,
  [2512] = 2512,
  [2513] = 2513,
  [2514] = 2514,
  [2515] = 2515,
  [2516] = 2516,
  [2517] = 2517,
  [2518] = 2518,
  [2519] = 2519,
  [2520] = 2520,
  [2521] = 2521,
  [2522] = 2522,
  [2523] = 2523,
  [2524] = 2524,
  [2525] = 2525,
  [2526] = 161,
  [2527] = 2527,
  [2528] = 2528,
  [2529] = 2529,
  [2530] = 2530,
  [2531] = 2531,
  [2532] = 2532,
  [2533] = 2533,
  [2534] = 2534,
  [2535] = 2535,
  [2536] = 2536,
  [2537] = 2537,
  [2538] = 2538,
  [2539] = 2539,
  [2540] = 2540,
  [2541] = 2541,
  [2542] = 2542,
  [2543] = 2543,
  [2544] = 2544,
  [2545] = 2545,
  [2546] = 2546,
  [2547] = 2547,
  [2548] = 2548,
  [2549] = 2258,
  [2550] = 2550,
  [2551] = 2551,
  [2552] = 2552,
  [2553] = 2553,
  [2554] = 2554,
  [2555] = 2555,
  [2556] = 2556,
  [2557] = 2557,
  [2558] = 2558,
  [2559] = 2559,
  [2560] = 2560,
  [2561] = 2561,
  [2562] = 2562,
  [2563] = 2563,
  [2564] = 2564,
  [2565] = 2565,
  [2566] = 2566,
  [2567] = 2567,
  [2568] = 2568,
  [2569] = 2569,
  [2570] = 2570,
  [2571] = 2571,
  [2572] = 2572,
  [2573] = 2573,
  [2574] = 2574,
  [2575] = 2575,
  [2576] = 2576,
  [2577] = 2577,
  [2578] = 2578,
  [2579] = 2579,
  [2580] = 2580,
  [2581] = 2581,
  [2582] = 2582,
  [2583] = 2583,
  [2584] = 2584,
  [2585] = 2585,
  [2586] = 2586,
  [2587] = 2587,
  [2588] = 2588,
  [2589] = 2589,
  [2590] = 2590,
  [2591] = 2591,
  [2592] = 2592,
  [2593] = 2593,
  [2594] = 2594,
  [2595] = 2595,
  [2596] = 2596,
  [2597] = 2597,
  [2598] = 2598,
  [2599] = 2599,
  [2600] = 2600,
  [2601] = 2601,
  [2602] = 2602,
  [2603] = 2603,
  [2604] = 2604,
  [2605] = 2376,
  [2606] = 2366,
  [2607] = 2607,
  [2608] = 2608,
  [2609] = 2290,
  [2610] = 2610,
  [2611] = 2611,
  [2612] = 2612,
  [2613] = 2613,
  [2614] = 2614,
  [2615] = 2615,
  [2616] = 2616,
  [2617] = 2617,
  [2618] = 2618,
  [2619] = 2619,
  [2620] = 2620,
  [2621] = 2621,
  [2622] = 2622,
  [2623] = 2623,
  [2624] = 2624,
  [2625] = 2625,
  [2626] = 2626,
  [2627] = 2627,
  [2628] = 2628,
  [2629] = 2629,
  [2630] = 2630,
  [2631] = 2631,
  [2632] = 250,
  [2633] = 2633,
  [2634] = 2634,
  [2635] = 2635,
  [2636] = 2636,
  [2637] = 2637,
  [2638] = 2638,
  [2639] = 2634,
  [2640] = 2640,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2641,
  [2644] = 2644,
  [2645] = 2645,
  [2646] = 2646,
  [2647] = 2635,
  [2648] = 2648,
  [2649] = 2649,
  [2650] = 2650,
  [2651] = 2650,
  [2652] = 2644,
  [2653] = 2653,
  [2654] = 2654,
  [2655] = 2642,
  [2656] = 2656,
  [2657] = 164,
  [2658] = 2637,
  [2659] = 2638,
  [2660] = 2654,
  [2661] = 2642,
  [2662] = 2662,
  [2663] = 2638,
  [2664] = 2634,
  [2665] = 2646,
  [2666] = 2644,
  [2667] = 2638,
  [2668] = 2662,
  [2669] = 2634,
  [2670] = 2641,
  [2671] = 2644,
  [2672] = 2646,
  [2673] = 2635,
  [2674] = 2636,
  [2675] = 2636,
  [2676] = 2644,
  [2677] = 2637,
  [2678] = 2637,
  [2679] = 2638,
  [2680] = 2634,
  [2681] = 2681,
  [2682] = 2656,
  [2683] = 2646,
  [2684] = 2649,
  [2685] = 2635,
  [2686] = 2650,
  [2687] = 2662,
  [2688] = 2654,
  [2689] = 2642,
  [2690] = 2656,
  [2691] = 2649,
  [2692] = 2636,
  [2693] = 2650,
  [2694] = 2656,
  [2695] = 2654,
  [2696] = 2638,
  [2697] = 2641,
  [2698] = 2638,
  [2699] = 2634,
  [2700] = 2634,
  [2701] = 2701,
  [2702] = 2638,
  [2703] = 2634,
  [2704] = 2641,
  [2705] = 2641,
  [2706] = 2644,
  [2707] = 2649,
  [2708] = 2641,
  [2709] = 2644,
  [2710] = 2662,
  [2711] = 2638,
  [2712] = 2634,
  [2713] = 2641,
  [2714] = 2644,
  [2715] = 2644,
  [2716] = 2641,
  [2717] = 2717,
  [2718] = 2718,
  [2719] = 2719,
  [2720] = 2701,
  [2721] = 166,
  [2722] = 2722,
  [2723] = 2723,
  [2724] = 2724,
  [2725] = 2725,
  [2726] = 2726,
  [2727] = 250,
  [2728] = 1803,
  [2729] = 1778,
  [2730] = 1807,
  [2731] = 1785,
  [2732] = 1789,
  [2733] = 2258,
  [2734] = 1804,
  [2735] = 1792,
  [2736] = 1801,
  [2737] = 1802,
  [2738] = 2518,
  [2739] = 1800,
  [2740] = 1798,
  [2741] = 1809,
  [2742] = 1790,
  [2743] = 1799,
  [2744] = 1786,
  [2745] = 1776,
  [2746] = 1811,
  [2747] = 1773,
  [2748] = 1774,
  [2749] = 1787,
  [2750] = 1788,
  [2751] = 1771,
  [2752] = 1772,
  [2753] = 1777,
  [2754] = 1791,
  [2755] = 1813,
  [2756] = 1793,
  [2757] = 1794,
  [2758] = 1795,
  [2759] = 2759,
  [2760] = 2760,
  [2761] = 2761,
  [2762] = 2762,
  [2763] = 2763,
  [2764] = 2764,
  [2765] = 2765,
  [2766] = 2766,
  [2767] = 2767,
  [2768] = 2768,
  [2769] = 2769,
  [2770] = 2359,
  [2771] = 2365,
  [2772] = 2772,
  [2773] = 2773,
  [2774] = 2774,
  [2775] = 2775,
  [2776] = 2367,
  [2777] = 2360,
  [2778] = 2778,
  [2779] = 2779,
  [2780] = 2780,
  [2781] = 2781,
  [2782] = 1775,
  [2783] = 2648,
  [2784] = 2784,
  [2785] = 2785,
  [2786] = 2786,
  [2787] = 2370,
  [2788] = 2358,
  [2789] = 2356,
  [2790] = 2371,
  [2791] = 2375,
  [2792] = 2357,
  [2793] = 2793,
  [2794] = 2794,
  [2795] = 2795,
  [2796] = 2796,
  [2797] = 2797,
  [2798] = 2798,
  [2799] = 2799,
  [2800] = 1783,
  [2801] = 2801,
  [2802] = 2802,
  [2803] = 2803,
  [2804] = 2804,
  [2805] = 2805,
  [2806] = 2806,
  [2807] = 2807,
  [2808] = 2808,
  [2809] = 2809,
  [2810] = 2810,
  [2811] = 2811,
  [2812] = 2812,
  [2813] = 2302,
  [2814] = 2814,
  [2815] = 2815,
  [2816] = 2816,
  [2817] = 2817,
  [2818] = 2818,
  [2819] = 2819,
  [2820] = 2820,
  [2821] = 2821,
  [2822] = 2822,
  [2823] = 2823,
  [2824] = 2824,
  [2825] = 2825,
  [2826] = 2826,
  [2827] = 2827,
  [2828] = 2828,
  [2829] = 1816,
  [2830] = 1832,
  [2831] = 1833,
  [2832] = 161,
  [2833] = 1819,
  [2834] = 1824,
  [2835] = 1818,
  [2836] = 1820,
  [2837] = 1821,
  [2838] = 1822,
  [2839] = 1779,
  [2840] = 2258,
  [2841] = 2841,
  [2842] = 2842,
  [2843] = 2843,
  [2844] = 1831,
  [2845] = 1826,
  [2846] = 2846,
  [2847] = 2847,
  [2848] = 2848,
  [2849] = 2849,
  [2850] = 2850,
  [2851] = 2851,
  [2852] = 2852,
  [2853] = 2853,
  [2854] = 2854,
  [2855] = 1780,
  [2856] = 1781,
  [2857] = 2857,
  [2858] = 1782,
  [2859] = 2859,
  [2860] = 2860,
  [2861] = 2861,
  [2862] = 1830,
  [2863] = 2863,
  [2864] = 2864,
  [2865] = 2865,
  [2866] = 2866,
  [2867] = 2867,
  [2868] = 2374,
  [2869] = 2361,
  [2870] = 1796,
  [2871] = 2871,
  [2872] = 2872,
  [2873] = 1784,
  [2874] = 2874,
  [2875] = 1797,
  [2876] = 2876,
  [2877] = 2452,
  [2878] = 2520,
  [2879] = 2521,
  [2880] = 2523,
  [2881] = 2524,
  [2882] = 2525,
  [2883] = 2527,
  [2884] = 2529,
  [2885] = 2530,
  [2886] = 2531,
  [2887] = 2532,
  [2888] = 2533,
  [2889] = 2534,
  [2890] = 2535,
  [2891] = 2536,
  [2892] = 2537,
  [2893] = 2538,
  [2894] = 2539,
  [2895] = 2540,
  [2896] = 2541,
  [2897] = 2542,
  [2898] = 2543,
  [2899] = 2544,
  [2900] = 2545,
  [2901] = 2546,
  [2902] = 2547,
  [2903] = 2548,
  [2904] = 2719,
  [2905] = 2550,
  [2906] = 2551,
  [2907] = 2552,
  [2908] = 2553,
  [2909] = 2560,
  [2910] = 2578,
  [2911] = 2579,
  [2912] = 2580,
  [2913] = 2581,
  [2914] = 2582,
  [2915] = 2583,
  [2916] = 2584,
  [2917] = 2585,
  [2918] = 2586,
  [2919] = 2587,
  [2920] = 2588,
  [2921] = 2589,
  [2922] = 2590,
  [2923] = 2591,
  [2924] = 2592,
  [2925] = 2593,
  [2926] = 2594,
  [2927] = 2595,
  [2928] = 2596,
  [2929] = 2597,
  [2930] = 2598,
  [2931] = 2599,
  [2932] = 2600,
  [2933] = 2601,
  [2934] = 2602,
  [2935] = 2603,
  [2936] = 2607,
  [2937] = 2608,
  [2938] = 2610,
  [2939] = 2611,
  [2940] = 2612,
  [2941] = 2613,
  [2942] = 2614,
  [2943] = 2615,
  [2944] = 2616,
  [2945] = 2617,
  [2946] = 2618,
  [2947] = 2619,
  [2948] = 2620,
  [2949] = 2621,
  [2950] = 2622,
  [2951] = 2623,
  [2952] = 2624,
  [2953] = 2625,
  [2954] = 2626,
  [2955] = 2627,
  [2956] = 2628,
  [2957] = 2629,
  [2958] = 2630,
  [2959] = 2631,
  [2960] = 2528,
  [2961] = 2378,
  [2962] = 2379,
  [2963] = 2380,
  [2964] = 2381,
  [2965] = 2382,
  [2966] = 2383,
  [2967] = 2384,
  [2968] = 2385,
  [2969] = 2386,
  [2970] = 2387,
  [2971] = 2388,
  [2972] = 2389,
  [2973] = 2390,
  [2974] = 2391,
  [2975] = 2392,
  [2976] = 2393,
  [2977] = 2394,
  [2978] = 2395,
  [2979] = 2396,
  [2980] = 2397,
  [2981] = 2398,
  [2982] = 2399,
  [2983] = 2400,
  [2984] = 2401,
  [2985] = 2402,
  [2986] = 2403,
  [2987] = 2404,
  [2988] = 2405,
  [2989] = 2406,
  [2990] = 2408,
  [2991] = 2409,
  [2992] = 2410,
  [2993] = 2411,
  [2994] = 2412,
  [2995] = 2413,
  [2996] = 2414,
  [2997] = 2415,
  [2998] = 2416,
  [2999] = 2417,
  [3000] = 2418,
  [3001] = 2419,
  [3002] = 2420,
  [3003] = 2421,
  [3004] = 2422,
  [3005] = 2423,
  [3006] = 2424,
  [3007] = 2425,
  [3008] = 2426,
  [3009] = 2427,
  [3010] = 2429,
  [3011] = 2430,
  [3012] = 2431,
  [3013] = 2432,
  [3014] = 2433,
  [3015] = 2434,
  [3016] = 2435,
  [3017] = 2436,
  [3018] = 2437,
  [3019] = 2438,
  [3020] = 2439,
  [3021] = 2440,
  [3022] = 2441,
  [3023] = 2442,
  [3024] = 2443,
  [3025] = 2444,
  [3026] = 2445,
  [3027] = 2446,
  [3028] = 2447,
  [3029] = 2448,
  [3030] = 2449,
  [3031] = 2450,
  [3032] = 2717,
  [3033] = 2453,
  [3034] = 2454,
  [3035] = 2455,
  [3036] = 2456,
  [3037] = 2457,
  [3038] = 2458,
  [3039] = 2459,
  [3040] = 2460,
  [3041] = 2461,
  [3042] = 2462,
  [3043] = 2464,
  [3044] = 2467,
  [3045] = 2468,
  [3046] = 2469,
  [3047] = 2377,
  [3048] = 2471,
  [3049] = 2472,
  [3050] = 2473,
  [3051] = 2474,
  [3052] = 2475,
  [3053] = 2476,
  [3054] = 2477,
  [3055] = 2478,
  [3056] = 2479,
  [3057] = 2480,
  [3058] = 2481,
  [3059] = 2482,
  [3060] = 2483,
  [3061] = 2484,
  [3062] = 2485,
  [3063] = 2486,
  [3064] = 2487,
  [3065] = 2331,
  [3066] = 1835,
  [3067] = 1965,
  [3068] = 1852,
  [3069] = 2604,
  [3070] = 2407,
  [3071] = 1836,
  [3072] = 2633,
  [3073] = 1815,
  [3074] = 164,
  [3075] = 2463,
  [3076] = 1857,
  [3077] = 2470,
  [3078] = 1859,
  [3079] = 1860,
  [3080] = 1839,
  [3081] = 1842,
  [3082] = 1854,
  [3083] = 1840,
  [3084] = 1843,
  [3085] = 1846,
  [3086] = 1847,
  [3087] = 1844,
  [3088] = 1837,
  [3089] = 1848,
  [3090] = 1838,
  [3091] = 2488,
  [3092] = 1849,
  [3093] = 1850,
  [3094] = 1851,
  [3095] = 2489,
  [3096] = 2494,
  [3097] = 1825,
  [3098] = 2492,
  [3099] = 1841,
  [3100] = 2495,
  [3101] = 2496,
  [3102] = 2497,
  [3103] = 2493,
  [3104] = 2554,
  [3105] = 2555,
  [3106] = 2556,
  [3107] = 2557,
  [3108] = 2558,
  [3109] = 2559,
  [3110] = 2561,
  [3111] = 2562,
  [3112] = 2506,
  [3113] = 1814,
  [3114] = 2563,
  [3115] = 2564,
  [3116] = 2565,
  [3117] = 2566,
  [3118] = 2567,
  [3119] = 2568,
  [3120] = 2569,
  [3121] = 2570,
  [3122] = 2571,
  [3123] = 2572,
  [3124] = 2573,
  [3125] = 2574,
  [3126] = 2575,
  [3127] = 2576,
  [3128] = 2577,
  [3129] = 2508,
  [3130] = 1845,
  [3131] = 1823,
  [3132] = 161,
  [3133] = 2512,
  [3134] = 2513,
  [3135] = 2514,
  [3136] = 2515,
  [3137] = 1858,
  [3138] = 2516,
  [3139] = 1817,
  [3140] = 2517,
  [3141] = 1853,
  [3142] = 1855,
  [3143] = 1856,
  [3144] = 2451,
  [3145] = 2359,
  [3146] = 3146,
  [3147] = 2361,
  [3148] = 1830,
  [3149] = 1771,
  [3150] = 1825,
  [3151] = 3146,
  [3152] = 3146,
  [3153] = 2365,
  [3154] = 3146,
  [3155] = 2356,
  [3156] = 2371,
  [3157] = 3146,
  [3158] = 164,
  [3159] = 3146,
  [3160] = 3160,
  [3161] = 3146,
  [3162] = 2370,
  [3163] = 2358,
  [3164] = 2367,
  [3165] = 166,
  [3166] = 2360,
  [3167] = 3146,
  [3168] = 3160,
  [3169] = 2375,
  [3170] = 2357,
  [3171] = 2374,
  [3172] = 2543,
  [3173] = 2559,
  [3174] = 2396,
  [3175] = 2561,
  [3176] = 2562,
  [3177] = 2612,
  [3178] = 2397,
  [3179] = 2398,
  [3180] = 2600,
  [3181] = 2399,
  [3182] = 2400,
  [3183] = 2601,
  [3184] = 2401,
  [3185] = 2402,
  [3186] = 2403,
  [3187] = 2404,
  [3188] = 2563,
  [3189] = 2405,
  [3190] = 2613,
  [3191] = 2564,
  [3192] = 2565,
  [3193] = 2566,
  [3194] = 2567,
  [3195] = 2568,
  [3196] = 2569,
  [3197] = 2570,
  [3198] = 2571,
  [3199] = 2572,
  [3200] = 2573,
  [3201] = 2574,
  [3202] = 2575,
  [3203] = 2576,
  [3204] = 2577,
  [3205] = 2406,
  [3206] = 2408,
  [3207] = 2515,
  [3208] = 2516,
  [3209] = 2602,
  [3210] = 2550,
  [3211] = 2614,
  [3212] = 2463,
  [3213] = 2514,
  [3214] = 2409,
  [3215] = 2508,
  [3216] = 2470,
  [3217] = 2534,
  [3218] = 2535,
  [3219] = 2536,
  [3220] = 2537,
  [3221] = 2603,
  [3222] = 2615,
  [3223] = 2538,
  [3224] = 2513,
  [3225] = 2539,
  [3226] = 2617,
  [3227] = 2618,
  [3228] = 2619,
  [3229] = 2517,
  [3230] = 2633,
  [3231] = 2410,
  [3232] = 2411,
  [3233] = 2412,
  [3234] = 2413,
  [3235] = 2414,
  [3236] = 2415,
  [3237] = 2416,
  [3238] = 2417,
  [3239] = 2620,
  [3240] = 2621,
  [3241] = 161,
  [3242] = 2418,
  [3243] = 2419,
  [3244] = 2616,
  [3245] = 2622,
  [3246] = 2623,
  [3247] = 2624,
  [3248] = 2625,
  [3249] = 2626,
  [3250] = 2551,
  [3251] = 2258,
  [3252] = 2522,
  [3253] = 2607,
  [3254] = 2302,
  [3255] = 2420,
  [3256] = 2421,
  [3257] = 2422,
  [3258] = 2423,
  [3259] = 2589,
  [3260] = 2627,
  [3261] = 2608,
  [3262] = 2628,
  [3263] = 2629,
  [3264] = 2481,
  [3265] = 2630,
  [3266] = 2631,
  [3267] = 2528,
  [3268] = 2540,
  [3269] = 2424,
  [3270] = 2590,
  [3271] = 2378,
  [3272] = 2425,
  [3273] = 2426,
  [3274] = 2488,
  [3275] = 2427,
  [3276] = 2541,
  [3277] = 2379,
  [3278] = 2520,
  [3279] = 2591,
  [3280] = 2553,
  [3281] = 2545,
  [3282] = 2610,
  [3283] = 2611,
  [3284] = 2429,
  [3285] = 2430,
  [3286] = 2431,
  [3287] = 2432,
  [3288] = 2521,
  [3289] = 2433,
  [3290] = 2604,
  [3291] = 2407,
  [3292] = 2452,
  [3293] = 2434,
  [3294] = 2435,
  [3295] = 2436,
  [3296] = 2437,
  [3297] = 2438,
  [3298] = 2439,
  [3299] = 2523,
  [3300] = 2440,
  [3301] = 2441,
  [3302] = 2524,
  [3303] = 2525,
  [3304] = 2380,
  [3305] = 2558,
  [3306] = 2560,
  [3307] = 2578,
  [3308] = 2579,
  [3309] = 2546,
  [3310] = 2580,
  [3311] = 2552,
  [3312] = 2547,
  [3313] = 2382,
  [3314] = 2581,
  [3315] = 2587,
  [3316] = 2582,
  [3317] = 2583,
  [3318] = 2383,
  [3319] = 2442,
  [3320] = 2443,
  [3321] = 2444,
  [3322] = 2445,
  [3323] = 2446,
  [3324] = 2447,
  [3325] = 2584,
  [3326] = 2592,
  [3327] = 2593,
  [3328] = 2448,
  [3329] = 2594,
  [3330] = 2384,
  [3331] = 2506,
  [3332] = 2449,
  [3333] = 2450,
  [3334] = 2385,
  [3335] = 2386,
  [3336] = 2595,
  [3337] = 2451,
  [3338] = 2453,
  [3339] = 2596,
  [3340] = 2548,
  [3341] = 2493,
  [3342] = 2585,
  [3343] = 2482,
  [3344] = 2586,
  [3345] = 2483,
  [3346] = 2454,
  [3347] = 2455,
  [3348] = 2496,
  [3349] = 2597,
  [3350] = 2497,
  [3351] = 2387,
  [3352] = 2527,
  [3353] = 2388,
  [3354] = 2389,
  [3355] = 2598,
  [3356] = 2599,
  [3357] = 2529,
  [3358] = 2530,
  [3359] = 2390,
  [3360] = 2456,
  [3361] = 2457,
  [3362] = 2458,
  [3363] = 2459,
  [3364] = 2460,
  [3365] = 2461,
  [3366] = 2462,
  [3367] = 2542,
  [3368] = 2464,
  [3369] = 2467,
  [3370] = 2468,
  [3371] = 2469,
  [3372] = 2531,
  [3373] = 2377,
  [3374] = 2484,
  [3375] = 2494,
  [3376] = 2391,
  [3377] = 2489,
  [3378] = 2471,
  [3379] = 2392,
  [3380] = 2472,
  [3381] = 2485,
  [3382] = 2486,
  [3383] = 2492,
  [3384] = 2473,
  [3385] = 166,
  [3386] = 2474,
  [3387] = 2495,
  [3388] = 2393,
  [3389] = 2544,
  [3390] = 2512,
  [3391] = 3391,
  [3392] = 2475,
  [3393] = 2476,
  [3394] = 2479,
  [3395] = 2480,
  [3396] = 2487,
  [3397] = 2532,
  [3398] = 2394,
  [3399] = 2533,
  [3400] = 2395,
  [3401] = 2477,
  [3402] = 2554,
  [3403] = 2555,
  [3404] = 2478,
  [3405] = 2588,
  [3406] = 2556,
  [3407] = 2557,
  [3408] = 2381,
  [3409] = 3409,
  [3410] = 2331,
  [3411] = 3411,
  [3412] = 3412,
  [3413] = 3413,
  [3414] = 2302,
  [3415] = 164,
  [3416] = 3416,
  [3417] = 3417,
  [3418] = 3418,
  [3419] = 2645,
  [3420] = 3420,
  [3421] = 2723,
  [3422] = 3416,
  [3423] = 3417,
  [3424] = 3416,
  [3425] = 3425,
  [3426] = 3416,
  [3427] = 3416,
  [3428] = 3416,
  [3429] = 3416,
  [3430] = 3416,
  [3431] = 3431,
  [3432] = 1771,
  [3433] = 1786,
  [3434] = 1776,
  [3435] = 1773,
  [3436] = 1800,
  [3437] = 1787,
  [3438] = 1801,
  [3439] = 1788,
  [3440] = 1772,
  [3441] = 1791,
  [3442] = 1813,
  [3443] = 1793,
  [3444] = 1794,
  [3445] = 1795,
  [3446] = 1802,
  [3447] = 1803,
  [3448] = 2331,
  [3449] = 1807,
  [3450] = 1789,
  [3451] = 1792,
  [3452] = 1798,
  [3453] = 1811,
  [3454] = 1777,
  [3455] = 1778,
  [3456] = 2681,
  [3457] = 3457,
  [3458] = 1771,
  [3459] = 1774,
  [3460] = 1825,
  [3461] = 1830,
  [3462] = 1785,
  [3463] = 3457,
  [3464] = 1809,
  [3465] = 1790,
  [3466] = 166,
  [3467] = 1799,
  [3468] = 1804,
  [3469] = 3469,
  [3470] = 1818,
  [3471] = 1820,
  [3472] = 1783,
  [3473] = 1821,
  [3474] = 1822,
  [3475] = 3475,
  [3476] = 3476,
  [3477] = 3477,
  [3478] = 3478,
  [3479] = 3469,
  [3480] = 3480,
  [3481] = 1771,
  [3482] = 3469,
  [3483] = 1831,
  [3484] = 2681,
  [3485] = 3469,
  [3486] = 2522,
  [3487] = 1779,
  [3488] = 1780,
  [3489] = 3478,
  [3490] = 1782,
  [3491] = 2723,
  [3492] = 1826,
  [3493] = 1830,
  [3494] = 3469,
  [3495] = 3469,
  [3496] = 1784,
  [3497] = 1816,
  [3498] = 3478,
  [3499] = 1775,
  [3500] = 1830,
  [3501] = 1832,
  [3502] = 1825,
  [3503] = 1819,
  [3504] = 1833,
  [3505] = 3469,
  [3506] = 3469,
  [3507] = 1824,
  [3508] = 3469,
  [3509] = 3477,
  [3510] = 1796,
  [3511] = 1797,
  [3512] = 1781,
  [3513] = 1856,
  [3514] = 1853,
  [3515] = 1855,
  [3516] = 1860,
  [3517] = 1858,
  [3518] = 1835,
  [3519] = 1836,
  [3520] = 1844,
  [3521] = 1845,
  [3522] = 1823,
  [3523] = 1815,
  [3524] = 1852,
  [3525] = 1806,
  [3526] = 1839,
  [3527] = 1842,
  [3528] = 1843,
  [3529] = 1846,
  [3530] = 1847,
  [3531] = 1848,
  [3532] = 1810,
  [3533] = 3420,
  [3534] = 1850,
  [3535] = 1851,
  [3536] = 1854,
  [3537] = 1838,
  [3538] = 1825,
  [3539] = 1837,
  [3540] = 1805,
  [3541] = 1840,
  [3542] = 1812,
  [3543] = 1857,
  [3544] = 1814,
  [3545] = 1841,
  [3546] = 3546,
  [3547] = 2522,
  [3548] = 3546,
  [3549] = 2645,
  [3550] = 1808,
  [3551] = 1817,
  [3552] = 1859,
  [3553] = 1849,
  [3554] = 3554,
  [3555] = 2645,
  [3556] = 3556,
  [3557] = 3557,
  [3558] = 250,
  [3559] = 2302,
  [3560] = 3560,
  [3561] = 3561,
  [3562] = 2258,
  [3563] = 2331,
  [3564] = 3564,
  [3565] = 3560,
  [3566] = 3561,
  [3567] = 250,
  [3568] = 3568,
  [3569] = 3568,
  [3570] = 3561,
  [3571] = 3560,
  [3572] = 3560,
  [3573] = 3561,
  [3574] = 3574,
  [3575] = 3575,
  [3576] = 3576,
  [3577] = 3576,
  [3578] = 3578,
  [3579] = 3579,
  [3580] = 1825,
  [3581] = 3581,
  [3582] = 1830,
  [3583] = 3576,
  [3584] = 3584,
  [3585] = 3585,
  [3586] = 3578,
  [3587] = 3587,
  [3588] = 1771,
  [3589] = 3581,
  [3590] = 3578,
  [3591] = 2518,
  [3592] = 3592,
  [3593] = 3593,
  [3594] = 2701,
  [3595] = 3595,
  [3596] = 2522,
  [3597] = 2648,
  [3598] = 2681,
  [3599] = 3593,
  [3600] = 3600,
  [3601] = 3601,
  [3602] = 3602,
  [3603] = 2258,
  [3604] = 3604,
  [3605] = 3601,
  [3606] = 2719,
  [3607] = 2645,
  [3608] = 2717,
  [3609] = 3609,
  [3610] = 3610,
  [3611] = 2290,
  [3612] = 2291,
  [3613] = 3613,
  [3614] = 2292,
  [3615] = 2310,
  [3616] = 2293,
  [3617] = 3617,
  [3618] = 3618,
  [3619] = 3420,
  [3620] = 3620,
  [3621] = 3621,
  [3622] = 3622,
  [3623] = 3623,
  [3624] = 3624,
  [3625] = 3625,
  [3626] = 3626,
  [3627] = 3627,
  [3628] = 3628,
  [3629] = 3629,
  [3630] = 2759,
  [3631] = 2842,
  [3632] = 3632,
  [3633] = 2843,
  [3634] = 2797,
  [3635] = 1779,
  [3636] = 2765,
  [3637] = 2846,
  [3638] = 2854,
  [3639] = 2818,
  [3640] = 3640,
  [3641] = 2847,
  [3642] = 3632,
  [3643] = 2828,
  [3644] = 2811,
  [3645] = 2848,
  [3646] = 2809,
  [3647] = 2849,
  [3648] = 2772,
  [3649] = 161,
  [3650] = 1780,
  [3651] = 2779,
  [3652] = 2850,
  [3653] = 2767,
  [3654] = 3632,
  [3655] = 2780,
  [3656] = 3656,
  [3657] = 2812,
  [3658] = 2876,
  [3659] = 3656,
  [3660] = 2851,
  [3661] = 2816,
  [3662] = 3632,
  [3663] = 2820,
  [3664] = 2799,
  [3665] = 2821,
  [3666] = 2822,
  [3667] = 2823,
  [3668] = 2824,
  [3669] = 2825,
  [3670] = 2826,
  [3671] = 2827,
  [3672] = 2810,
  [3673] = 2798,
  [3674] = 1781,
  [3675] = 2864,
  [3676] = 2290,
  [3677] = 1826,
  [3678] = 2291,
  [3679] = 2292,
  [3680] = 2859,
  [3681] = 3656,
  [3682] = 3632,
  [3683] = 1782,
  [3684] = 2861,
  [3685] = 2871,
  [3686] = 3686,
  [3687] = 2763,
  [3688] = 3688,
  [3689] = 2768,
  [3690] = 2794,
  [3691] = 2784,
  [3692] = 2807,
  [3693] = 3693,
  [3694] = 3632,
  [3695] = 1831,
  [3696] = 2872,
  [3697] = 2310,
  [3698] = 2293,
  [3699] = 2781,
  [3700] = 2785,
  [3701] = 2867,
  [3702] = 2801,
  [3703] = 3703,
  [3704] = 2795,
  [3705] = 2817,
  [3706] = 2764,
  [3707] = 2804,
  [3708] = 2773,
  [3709] = 2808,
  [3710] = 2774,
  [3711] = 2806,
  [3712] = 2769,
  [3713] = 2852,
  [3714] = 2865,
  [3715] = 2819,
  [3716] = 2760,
  [3717] = 2775,
  [3718] = 3632,
  [3719] = 2874,
  [3720] = 2778,
  [3721] = 2814,
  [3722] = 2863,
  [3723] = 2786,
  [3724] = 2841,
  [3725] = 2793,
  [3726] = 1771,
  [3727] = 2766,
  [3728] = 3632,
  [3729] = 2761,
  [3730] = 3730,
  [3731] = 2857,
  [3732] = 2762,
  [3733] = 2860,
  [3734] = 3734,
  [3735] = 2866,
  [3736] = 2853,
  [3737] = 3632,
  [3738] = 2796,
  [3739] = 2805,
  [3740] = 2802,
  [3741] = 2815,
  [3742] = 2803,
  [3743] = 3743,
  [3744] = 3744,
  [3745] = 1965,
  [3746] = 1814,
  [3747] = 1841,
  [3748] = 3748,
  [3749] = 3749,
  [3750] = 3750,
  [3751] = 3751,
  [3752] = 3752,
  [3753] = 3753,
  [3754] = 3754,
  [3755] = 3755,
  [3756] = 3756,
  [3757] = 3757,
  [3758] = 3758,
  [3759] = 3759,
  [3760] = 3749,
  [3761] = 3750,
  [3762] = 3762,
  [3763] = 3763,
  [3764] = 3764,
  [3765] = 3758,
  [3766] = 3759,
  [3767] = 3749,
  [3768] = 3750,
  [3769] = 3762,
  [3770] = 3763,
  [3771] = 3764,
  [3772] = 3759,
  [3773] = 3749,
  [3774] = 3750,
  [3775] = 3762,
  [3776] = 3763,
  [3777] = 3764,
  [3778] = 3762,
  [3779] = 3763,
  [3780] = 3759,
  [3781] = 3749,
  [3782] = 3750,
  [3783] = 3762,
  [3784] = 3763,
  [3785] = 3764,
  [3786] = 3759,
  [3787] = 3749,
  [3788] = 3750,
  [3789] = 3762,
  [3790] = 3763,
  [3791] = 3764,
  [3792] = 3759,
  [3793] = 3749,
  [3794] = 3750,
  [3795] = 3762,
  [3796] = 3763,
  [3797] = 3764,
  [3798] = 3759,
  [3799] = 3749,
  [3800] = 3750,
  [3801] = 3762,
  [3802] = 3763,
  [3803] = 3764,
  [3804] = 3759,
  [3805] = 3764,
  [3806] = 164,
  [3807] = 3807,
  [3808] = 3808,
  [3809] = 3809,
  [3810] = 3810,
  [3811] = 3811,
  [3812] = 3812,
  [3813] = 3813,
  [3814] = 161,
  [3815] = 166,
  [3816] = 3816,
  [3817] = 2726,
  [3818] = 3818,
  [3819] = 3819,
  [3820] = 3820,
  [3821] = 3821,
  [3822] = 3822,
  [3823] = 3823,
  [3824] = 3824,
  [3825] = 3825,
  [3826] = 3825,
  [3827] = 3824,
  [3828] = 3828,
  [3829] = 3829,
  [3830] = 3830,
  [3831] = 3831,
  [3832] = 3832,
  [3833] = 3833,
  [3834] = 3825,
  [3835] = 3835,
  [3836] = 3836,
  [3837] = 3837,
  [3838] = 3825,
  [3839] = 3839,
  [3840] = 3840,
  [3841] = 3825,
  [3842] = 164,
  [3843] = 3825,
  [3844] = 3844,
  [3845] = 3845,
  [3846] = 3846,
  [3847] = 3847,
  [3848] = 3844,
  [3849] = 3839,
  [3850] = 3835,
  [3851] = 3836,
  [3852] = 3828,
  [3853] = 3829,
  [3854] = 3830,
  [3855] = 3844,
  [3856] = 3839,
  [3857] = 3835,
  [3858] = 3836,
  [3859] = 3828,
  [3860] = 3829,
  [3861] = 3830,
  [3862] = 3825,
  [3863] = 3863,
  [3864] = 3864,
  [3865] = 3865,
  [3866] = 3866,
  [3867] = 3867,
  [3868] = 3868,
  [3869] = 3869,
  [3870] = 3870,
  [3871] = 3871,
  [3872] = 3872,
  [3873] = 3873,
  [3874] = 3874,
  [3875] = 3875,
  [3876] = 3876,
  [3877] = 3877,
  [3878] = 3878,
  [3879] = 3879,
  [3880] = 3880,
  [3881] = 3881,
  [3882] = 3876,
  [3883] = 3883,
  [3884] = 3884,
  [3885] = 3885,
  [3886] = 3886,
  [3887] = 3868,
  [3888] = 3866,
  [3889] = 3889,
  [3890] = 3890,
  [3891] = 3869,
  [3892] = 3865,
  [3893] = 3893,
  [3894] = 3894,
  [3895] = 3870,
  [3896] = 3896,
  [3897] = 3897,
  [3898] = 3898,
  [3899] = 3899,
  [3900] = 3863,
  [3901] = 3901,
  [3902] = 3902,
  [3903] = 3872,
  [3904] = 3873,
  [3905] = 3905,
  [3906] = 3906,
  [3907] = 3883,
  [3908] = 3897,
  [3909] = 3899,
  [3910] = 3879,
  [3911] = 3881,
  [3912] = 3885,
  [3913] = 3889,
  [3914] = 3890,
  [3915] = 3901,
  [3916] = 3902,
  [3917] = 3905,
  [3918] = 3918,
  [3919] = 3919,
  [3920] = 3866,
  [3921] = 3880,
  [3922] = 3868,
  [3923] = 3923,
  [3924] = 3924,
  [3925] = 3869,
  [3926] = 3870,
  [3927] = 3863,
  [3928] = 3874,
  [3929] = 3872,
  [3930] = 3873,
  [3931] = 3874,
  [3932] = 3875,
  [3933] = 3876,
  [3934] = 3877,
  [3935] = 3865,
  [3936] = 3897,
  [3937] = 3899,
  [3938] = 3881,
  [3939] = 3885,
  [3940] = 3889,
  [3941] = 3890,
  [3942] = 3901,
  [3943] = 3902,
  [3944] = 3905,
  [3945] = 3918,
  [3946] = 3877,
  [3947] = 3875,
  [3948] = 3918,
  [3949] = 166,
  [3950] = 161,
  [3951] = 3880,
  [3952] = 3584,
  [3953] = 3575,
  [3954] = 3954,
  [3955] = 3420,
  [3956] = 3956,
  [3957] = 3957,
  [3958] = 3954,
  [3959] = 3959,
  [3960] = 164,
  [3961] = 3961,
  [3962] = 3962,
  [3963] = 2290,
  [3964] = 3964,
  [3965] = 3965,
  [3966] = 3961,
  [3967] = 3967,
  [3968] = 1965,
  [3969] = 3969,
  [3970] = 3967,
  [3971] = 3969,
  [3972] = 2291,
  [3973] = 3964,
  [3974] = 3965,
  [3975] = 2293,
  [3976] = 3976,
  [3977] = 2310,
  [3978] = 2292,
  [3979] = 166,
  [3980] = 3976,
  [3981] = 2569,
  [3982] = 3982,
  [3983] = 3983,
  [3984] = 3984,
  [3985] = 2563,
  [3986] = 2564,
  [3987] = 2565,
  [3988] = 2566,
  [3989] = 2567,
  [3990] = 2568,
  [3991] = 3991,
  [3992] = 2570,
  [3993] = 2571,
  [3994] = 2572,
  [3995] = 2573,
  [3996] = 2574,
  [3997] = 2575,
  [3998] = 2576,
  [3999] = 2577,
  [4000] = 4000,
  [4001] = 2554,
  [4002] = 4002,
  [4003] = 4003,
  [4004] = 2555,
  [4005] = 4005,
  [4006] = 4006,
  [4007] = 4007,
  [4008] = 4008,
  [4009] = 4009,
  [4010] = 2556,
  [4011] = 4011,
  [4012] = 3564,
  [4013] = 2557,
  [4014] = 3574,
  [4015] = 2558,
  [4016] = 2559,
  [4017] = 4017,
  [4018] = 4018,
  [4019] = 4019,
  [4020] = 4020,
  [4021] = 4000,
  [4022] = 4022,
  [4023] = 4023,
  [4024] = 4024,
  [4025] = 4025,
  [4026] = 4026,
  [4027] = 4027,
  [4028] = 4028,
  [4029] = 4029,
  [4030] = 4030,
  [4031] = 4031,
  [4032] = 4032,
  [4033] = 4033,
  [4034] = 4034,
  [4035] = 2258,
  [4036] = 2561,
  [4037] = 2562,
  [4038] = 4038,
  [4039] = 4039,
  [4040] = 4040,
  [4041] = 4041,
  [4042] = 4042,
  [4043] = 4043,
  [4044] = 4044,
  [4045] = 4045,
  [4046] = 4046,
  [4047] = 4047,
  [4048] = 4048,
  [4049] = 4049,
  [4050] = 4050,
  [4051] = 4051,
  [4052] = 4052,
  [4053] = 4030,
  [4054] = 4031,
  [4055] = 4044,
  [4056] = 4045,
  [4057] = 2258,
  [4058] = 4058,
  [4059] = 4059,
  [4060] = 2302,
  [4061] = 250,
  [4062] = 4059,
  [4063] = 3564,
  [4064] = 4064,
  [4065] = 3574,
  [4066] = 4066,
  [4067] = 3584,
  [4068] = 3564,
  [4069] = 161,
  [4070] = 3574,
  [4071] = 4071,
  [4072] = 4072,
  [4073] = 2258,
  [4074] = 3575,
  [4075] = 4075,
  [4076] = 4064,
  [4077] = 4077,
  [4078] = 4078,
  [4079] = 2258,
  [4080] = 4075,
  [4081] = 4077,
  [4082] = 2331,
  [4083] = 4083,
  [4084] = 4071,
  [4085] = 4072,
  [4086] = 4066,
  [4087] = 4087,
  [4088] = 4078,
  [4089] = 4089,
  [4090] = 2576,
  [4091] = 4091,
  [4092] = 4092,
  [4093] = 4093,
  [4094] = 4094,
  [4095] = 4095,
  [4096] = 4096,
  [4097] = 4097,
  [4098] = 4098,
  [4099] = 4099,
  [4100] = 4100,
  [4101] = 4101,
  [4102] = 4102,
  [4103] = 4103,
  [4104] = 4104,
  [4105] = 4105,
  [4106] = 4106,
  [4107] = 4107,
  [4108] = 4108,
  [4109] = 2577,
  [4110] = 4110,
  [4111] = 4111,
  [4112] = 4112,
  [4113] = 4113,
  [4114] = 4114,
  [4115] = 4115,
  [4116] = 4116,
  [4117] = 4117,
  [4118] = 4118,
  [4119] = 4119,
  [4120] = 4120,
  [4121] = 4121,
  [4122] = 4122,
  [4123] = 4123,
  [4124] = 4124,
  [4125] = 4125,
  [4126] = 4126,
  [4127] = 4127,
  [4128] = 4128,
  [4129] = 4129,
  [4130] = 4130,
  [4131] = 4131,
  [4132] = 4132,
  [4133] = 4133,
  [4134] = 4134,
  [4135] = 4135,
  [4136] = 4136,
  [4137] = 4137,
  [4138] = 4138,
  [4139] = 4139,
  [4140] = 4140,
  [4141] = 4141,
  [4142] = 4142,
  [4143] = 4143,
  [4144] = 4144,
  [4145] = 4145,
  [4146] = 2367,
  [4147] = 2360,
  [4148] = 2370,
  [4149] = 2358,
  [4150] = 2356,
  [4151] = 2371,
  [4152] = 2375,
  [4153] = 2357,
  [4154] = 4154,
  [4155] = 250,
  [4156] = 4156,
  [4157] = 4157,
  [4158] = 4158,
  [4159] = 4159,
  [4160] = 4160,
  [4161] = 4161,
  [4162] = 4162,
  [4163] = 4163,
  [4164] = 4164,
  [4165] = 4165,
  [4166] = 4166,
  [4167] = 4167,
  [4168] = 4168,
  [4169] = 4169,
  [4170] = 4170,
  [4171] = 4171,
  [4172] = 4172,
  [4173] = 4173,
  [4174] = 4174,
  [4175] = 4175,
  [4176] = 4176,
  [4177] = 4177,
  [4178] = 4178,
  [4179] = 4179,
  [4180] = 4180,
  [4181] = 4181,
  [4182] = 4182,
  [4183] = 4183,
  [4184] = 4184,
  [4185] = 4185,
  [4186] = 4186,
  [4187] = 4187,
  [4188] = 4188,
  [4189] = 4189,
  [4190] = 4190,
  [4191] = 4191,
  [4192] = 4192,
  [4193] = 4193,
  [4194] = 4194,
  [4195] = 4195,
  [4196] = 4196,
  [4197] = 4197,
  [4198] = 4198,
  [4199] = 4199,
  [4200] = 4200,
  [4201] = 4201,
  [4202] = 4202,
  [4203] = 4203,
  [4204] = 4204,
  [4205] = 4205,
  [4206] = 4206,
  [4207] = 4207,
  [4208] = 4208,
  [4209] = 4209,
  [4210] = 4210,
  [4211] = 4211,
  [4212] = 4212,
  [4213] = 4213,
  [4214] = 4214,
  [4215] = 4215,
  [4216] = 4216,
  [4217] = 4217,
  [4218] = 4218,
  [4219] = 4219,
  [4220] = 4220,
  [4221] = 4221,
  [4222] = 164,
  [4223] = 4223,
  [4224] = 4224,
  [4225] = 4225,
  [4226] = 4226,
  [4227] = 4227,
  [4228] = 3688,
  [4229] = 4229,
  [4230] = 4230,
  [4231] = 4231,
  [4232] = 4232,
  [4233] = 4233,
  [4234] = 4234,
  [4235] = 4235,
  [4236] = 2374,
  [4237] = 2361,
  [4238] = 3584,
  [4239] = 2554,
  [4240] = 2555,
  [4241] = 4241,
  [4242] = 2556,
  [4243] = 2557,
  [4244] = 2558,
  [4245] = 2559,
  [4246] = 1830,
  [4247] = 1825,
  [4248] = 2561,
  [4249] = 2562,
  [4250] = 1771,
  [4251] = 3575,
  [4252] = 4252,
  [4253] = 4253,
  [4254] = 4254,
  [4255] = 4255,
  [4256] = 4256,
  [4257] = 4257,
  [4258] = 4258,
  [4259] = 4259,
  [4260] = 4260,
  [4261] = 4261,
  [4262] = 4262,
  [4263] = 4263,
  [4264] = 4264,
  [4265] = 4265,
  [4266] = 2563,
  [4267] = 4267,
  [4268] = 2564,
  [4269] = 2565,
  [4270] = 2566,
  [4271] = 4271,
  [4272] = 4272,
  [4273] = 4273,
  [4274] = 4274,
  [4275] = 4275,
  [4276] = 1771,
  [4277] = 4277,
  [4278] = 3640,
  [4279] = 4279,
  [4280] = 4280,
  [4281] = 4281,
  [4282] = 4282,
  [4283] = 2567,
  [4284] = 2568,
  [4285] = 2569,
  [4286] = 2570,
  [4287] = 2571,
  [4288] = 2572,
  [4289] = 4289,
  [4290] = 4290,
  [4291] = 4291,
  [4292] = 4292,
  [4293] = 4293,
  [4294] = 4294,
  [4295] = 2573,
  [4296] = 2574,
  [4297] = 2575,
  [4298] = 4298,
  [4299] = 3754,
  [4300] = 3743,
  [4301] = 3564,
  [4302] = 3574,
  [4303] = 2258,
  [4304] = 3420,
  [4305] = 3753,
  [4306] = 3757,
  [4307] = 2522,
  [4308] = 3584,
  [4309] = 3755,
  [4310] = 3756,
  [4311] = 3751,
  [4312] = 3752,
  [4313] = 3575,
  [4314] = 166,
  [4315] = 4315,
  [4316] = 4316,
  [4317] = 4317,
  [4318] = 4318,
  [4319] = 4319,
  [4320] = 4320,
  [4321] = 4321,
  [4322] = 4322,
  [4323] = 4323,
  [4324] = 4324,
  [4325] = 4325,
  [4326] = 4326,
  [4327] = 4327,
  [4328] = 4328,
  [4329] = 4329,
  [4330] = 1799,
  [4331] = 4331,
  [4332] = 4332,
  [4333] = 4333,
  [4334] = 4334,
  [4335] = 4335,
  [4336] = 4336,
  [4337] = 4337,
  [4338] = 4338,
  [4339] = 4339,
  [4340] = 4340,
  [4341] = 2258,
  [4342] = 4342,
  [4343] = 4342,
  [4344] = 4344,
  [4345] = 4345,
  [4346] = 4335,
  [4347] = 4335,
  [4348] = 4342,
  [4349] = 4349,
  [4350] = 4350,
  [4351] = 4351,
  [4352] = 4315,
  [4353] = 4353,
  [4354] = 4326,
  [4355] = 4319,
  [4356] = 4316,
  [4357] = 4316,
  [4358] = 4326,
  [4359] = 4316,
  [4360] = 4360,
  [4361] = 4338,
  [4362] = 4362,
  [4363] = 4363,
  [4364] = 4364,
  [4365] = 4365,
  [4366] = 4366,
  [4367] = 4367,
  [4368] = 4335,
  [4369] = 2645,
  [4370] = 4370,
  [4371] = 4350,
  [4372] = 4372,
  [4373] = 4342,
  [4374] = 4374,
  [4375] = 4375,
  [4376] = 4364,
  [4377] = 4377,
  [4378] = 4378,
  [4379] = 4363,
  [4380] = 4380,
  [4381] = 4381,
  [4382] = 1800,
  [4383] = 4377,
  [4384] = 4384,
  [4385] = 4326,
  [4386] = 4386,
  [4387] = 4387,
  [4388] = 4338,
  [4389] = 1801,
  [4390] = 4390,
  [4391] = 4378,
  [4392] = 4344,
  [4393] = 4350,
  [4394] = 4335,
  [4395] = 4335,
  [4396] = 4396,
  [4397] = 4342,
  [4398] = 4342,
  [4399] = 4399,
  [4400] = 4317,
  [4401] = 4364,
  [4402] = 4378,
  [4403] = 4364,
  [4404] = 4378,
  [4405] = 4353,
  [4406] = 4406,
  [4407] = 4407,
  [4408] = 4319,
  [4409] = 4363,
  [4410] = 4335,
  [4411] = 4411,
  [4412] = 4384,
  [4413] = 4338,
  [4414] = 4350,
  [4415] = 4315,
  [4416] = 4416,
  [4417] = 4363,
  [4418] = 4418,
  [4419] = 4326,
  [4420] = 4386,
  [4421] = 4421,
  [4422] = 250,
  [4423] = 4342,
  [4424] = 4424,
  [4425] = 4319,
  [4426] = 4426,
  [4427] = 4335,
  [4428] = 4428,
  [4429] = 4342,
  [4430] = 4380,
  [4431] = 4431,
  [4432] = 4315,
  [4433] = 4360,
  [4434] = 4317,
  [4435] = 4435,
  [4436] = 4436,
  [4437] = 4437,
  [4438] = 4438,
  [4439] = 4439,
  [4440] = 4440,
  [4441] = 4441,
  [4442] = 4442,
  [4443] = 4443,
  [4444] = 4444,
  [4445] = 4445,
  [4446] = 4446,
  [4447] = 4447,
  [4448] = 4448,
  [4449] = 4449,
  [4450] = 4450,
  [4451] = 4451,
  [4452] = 4452,
  [4453] = 4453,
  [4454] = 4454,
  [4455] = 4455,
  [4456] = 4456,
  [4457] = 4457,
  [4458] = 4458,
  [4459] = 4459,
  [4460] = 4460,
  [4461] = 4461,
  [4462] = 4462,
  [4463] = 4463,
  [4464] = 4435,
  [4465] = 4465,
  [4466] = 4466,
  [4467] = 4438,
  [4468] = 4468,
  [4469] = 4442,
  [4470] = 4470,
  [4471] = 4471,
  [4472] = 4436,
  [4473] = 4437,
  [4474] = 4440,
  [4475] = 4440,
  [4476] = 4476,
  [4477] = 4477,
  [4478] = 4478,
  [4479] = 4444,
  [4480] = 4445,
  [4481] = 4481,
  [4482] = 4446,
  [4483] = 4468,
  [4484] = 4484,
  [4485] = 4485,
  [4486] = 4447,
  [4487] = 4478,
  [4488] = 4488,
  [4489] = 4448,
  [4490] = 4449,
  [4491] = 4450,
  [4492] = 4451,
  [4493] = 4452,
  [4494] = 4453,
  [4495] = 4454,
  [4496] = 4455,
  [4497] = 4456,
  [4498] = 4457,
  [4499] = 4458,
  [4500] = 4459,
  [4501] = 4460,
  [4502] = 4461,
  [4503] = 4462,
  [4504] = 4463,
  [4505] = 4435,
  [4506] = 4465,
  [4507] = 4443,
  [4508] = 4478,
  [4509] = 4509,
  [4510] = 4447,
  [4511] = 4471,
  [4512] = 4440,
  [4513] = 4444,
  [4514] = 4445,
  [4515] = 4446,
  [4516] = 4448,
  [4517] = 4449,
  [4518] = 4450,
  [4519] = 4451,
  [4520] = 4452,
  [4521] = 4453,
  [4522] = 4454,
  [4523] = 4455,
  [4524] = 4456,
  [4525] = 4457,
  [4526] = 4458,
  [4527] = 4459,
  [4528] = 4460,
  [4529] = 4461,
  [4530] = 4462,
  [4531] = 4463,
  [4532] = 4435,
  [4533] = 4465,
  [4534] = 4440,
  [4535] = 4488,
  [4536] = 4471,
  [4537] = 4444,
  [4538] = 4445,
  [4539] = 4446,
  [4540] = 4447,
  [4541] = 4448,
  [4542] = 4449,
  [4543] = 4450,
  [4544] = 4451,
  [4545] = 4452,
  [4546] = 4453,
  [4547] = 4454,
  [4548] = 4455,
  [4549] = 4456,
  [4550] = 4457,
  [4551] = 4458,
  [4552] = 4459,
  [4553] = 4460,
  [4554] = 4461,
  [4555] = 4462,
  [4556] = 4463,
  [4557] = 4465,
  [4558] = 4471,
  [4559] = 4436,
  [4560] = 4437,
  [4561] = 4476,
  [4562] = 4444,
  [4563] = 4445,
  [4564] = 4478,
  [4565] = 4481,
  [4566] = 4484,
  [4567] = 4485,
  [4568] = 4488,
  [4569] = 4447,
  [4570] = 4471,
  [4571] = 4446,
  [4572] = 4440,
  [4573] = 4471,
  [4574] = 4444,
  [4575] = 4445,
  [4576] = 4446,
  [4577] = 4447,
  [4578] = 4448,
  [4579] = 4449,
  [4580] = 4450,
  [4581] = 4451,
  [4582] = 4436,
  [4583] = 4437,
  [4584] = 4452,
  [4585] = 4478,
  [4586] = 4453,
  [4587] = 4484,
  [4588] = 4454,
  [4589] = 4455,
  [4590] = 4456,
  [4591] = 4457,
  [4592] = 4458,
  [4593] = 4459,
  [4594] = 4460,
  [4595] = 4461,
  [4596] = 4462,
  [4597] = 4463,
  [4598] = 4435,
  [4599] = 4465,
  [4600] = 4447,
  [4601] = 4448,
  [4602] = 4449,
  [4603] = 4471,
  [4604] = 4436,
  [4605] = 4437,
  [4606] = 4478,
  [4607] = 4484,
  [4608] = 4608,
  [4609] = 4440,
  [4610] = 4610,
  [4611] = 4450,
  [4612] = 4451,
  [4613] = 4452,
  [4614] = 4444,
  [4615] = 4445,
  [4616] = 4446,
  [4617] = 4448,
  [4618] = 4449,
  [4619] = 4450,
  [4620] = 4451,
  [4621] = 4452,
  [4622] = 4622,
  [4623] = 4453,
  [4624] = 4454,
  [4625] = 4625,
  [4626] = 4455,
  [4627] = 4627,
  [4628] = 4628,
  [4629] = 4440,
  [4630] = 4456,
  [4631] = 4457,
  [4632] = 4458,
  [4633] = 4459,
  [4634] = 4460,
  [4635] = 4461,
  [4636] = 4462,
  [4637] = 4637,
  [4638] = 4463,
  [4639] = 4435,
  [4640] = 4465,
  [4641] = 4453,
  [4642] = 4454,
  [4643] = 4481,
  [4644] = 4610,
  [4645] = 4645,
  [4646] = 4646,
  [4647] = 4622,
  [4648] = 4628,
  [4649] = 4637,
  [4650] = 1824,
  [4651] = 4455,
  [4652] = 4444,
  [4653] = 4653,
  [4654] = 4445,
  [4655] = 4446,
  [4656] = 4645,
  [4657] = 4447,
  [4658] = 4658,
  [4659] = 4659,
  [4660] = 4660,
  [4661] = 4456,
  [4662] = 4457,
  [4663] = 4449,
  [4664] = 4450,
  [4665] = 4451,
  [4666] = 4452,
  [4667] = 4453,
  [4668] = 4454,
  [4669] = 4455,
  [4670] = 4456,
  [4671] = 4457,
  [4672] = 4458,
  [4673] = 4459,
  [4674] = 4460,
  [4675] = 4461,
  [4676] = 4462,
  [4677] = 4458,
  [4678] = 4463,
  [4679] = 4435,
  [4680] = 4646,
  [4681] = 4465,
  [4682] = 4459,
  [4683] = 4460,
  [4684] = 4684,
  [4685] = 4461,
  [4686] = 4462,
  [4687] = 4463,
  [4688] = 4435,
  [4689] = 4610,
  [4690] = 4645,
  [4691] = 4646,
  [4692] = 4622,
  [4693] = 4628,
  [4694] = 4637,
  [4695] = 4465,
  [4696] = 4440,
  [4697] = 4653,
  [4698] = 4658,
  [4699] = 4659,
  [4700] = 4700,
  [4701] = 4484,
  [4702] = 3420,
  [4703] = 4470,
  [4704] = 4485,
  [4705] = 4476,
  [4706] = 4444,
  [4707] = 4445,
  [4708] = 4446,
  [4709] = 4447,
  [4710] = 4448,
  [4711] = 4449,
  [4712] = 4450,
  [4713] = 4451,
  [4714] = 4452,
  [4715] = 4453,
  [4716] = 4454,
  [4717] = 4455,
  [4718] = 4456,
  [4719] = 4471,
  [4720] = 4610,
  [4721] = 4645,
  [4722] = 4646,
  [4723] = 4622,
  [4724] = 4628,
  [4725] = 4637,
  [4726] = 4726,
  [4727] = 4653,
  [4728] = 4658,
  [4729] = 4659,
  [4730] = 4457,
  [4731] = 4700,
  [4732] = 4458,
  [4733] = 4440,
  [4734] = 4459,
  [4735] = 4460,
  [4736] = 4610,
  [4737] = 4645,
  [4738] = 4646,
  [4739] = 4622,
  [4740] = 4628,
  [4741] = 4637,
  [4742] = 4742,
  [4743] = 4653,
  [4744] = 4461,
  [4745] = 4462,
  [4746] = 4463,
  [4747] = 4658,
  [4748] = 4659,
  [4749] = 4435,
  [4750] = 4444,
  [4751] = 4445,
  [4752] = 4446,
  [4753] = 4447,
  [4754] = 4448,
  [4755] = 4449,
  [4756] = 4450,
  [4757] = 4451,
  [4758] = 4452,
  [4759] = 4453,
  [4760] = 4454,
  [4761] = 4455,
  [4762] = 4456,
  [4763] = 4457,
  [4764] = 4458,
  [4765] = 4459,
  [4766] = 4460,
  [4767] = 4461,
  [4768] = 4462,
  [4769] = 4463,
  [4770] = 4435,
  [4771] = 4465,
  [4772] = 4465,
  [4773] = 4436,
  [4774] = 4437,
  [4775] = 3613,
  [4776] = 4610,
  [4777] = 4645,
  [4778] = 4646,
  [4779] = 4622,
  [4780] = 4628,
  [4781] = 4637,
  [4782] = 4653,
  [4783] = 4658,
  [4784] = 4659,
  [4785] = 4785,
  [4786] = 4786,
  [4787] = 4471,
  [4788] = 4788,
  [4789] = 4789,
  [4790] = 4610,
  [4791] = 4645,
  [4792] = 4646,
  [4793] = 4793,
  [4794] = 4794,
  [4795] = 4610,
  [4796] = 4645,
  [4797] = 4646,
  [4798] = 4798,
  [4799] = 4646,
  [4800] = 4625,
  [4801] = 4801,
  [4802] = 4608,
  [4803] = 4646,
  [4804] = 4625,
  [4805] = 4608,
  [4806] = 4625,
  [4807] = 4658,
  [4808] = 4684,
  [4809] = 4659,
  [4810] = 4471,
  [4811] = 4684,
  [4812] = 4684,
  [4813] = 4653,
  [4814] = 4684,
  [4815] = 4684,
  [4816] = 4742,
  [4817] = 4439,
  [4818] = 4789,
  [4819] = 4793,
  [4820] = 4820,
  [4821] = 4821,
  [4822] = 4742,
  [4823] = 4439,
  [4824] = 4789,
  [4825] = 4793,
  [4826] = 4820,
  [4827] = 4821,
  [4828] = 4742,
  [4829] = 4439,
  [4830] = 4789,
  [4831] = 4793,
  [4832] = 4820,
  [4833] = 4821,
  [4834] = 4742,
  [4835] = 4789,
  [4836] = 4793,
  [4837] = 4820,
  [4838] = 4821,
  [4839] = 4742,
  [4840] = 4789,
  [4841] = 4793,
  [4842] = 4820,
  [4843] = 4821,
  [4844] = 4844,
  [4845] = 4820,
  [4846] = 4627,
  [4847] = 4726,
  [4848] = 4785,
  [4849] = 4786,
  [4850] = 4794,
  [4851] = 4844,
  [4852] = 4852,
  [4853] = 4660,
  [4854] = 4466,
  [4855] = 4627,
  [4856] = 4726,
  [4857] = 4785,
  [4858] = 4786,
  [4859] = 4794,
  [4860] = 4844,
  [4861] = 4852,
  [4862] = 4660,
  [4863] = 4466,
  [4864] = 4627,
  [4865] = 4726,
  [4866] = 4785,
  [4867] = 4786,
  [4868] = 4794,
  [4869] = 4844,
  [4870] = 4852,
  [4871] = 4660,
  [4872] = 4466,
  [4873] = 4627,
  [4874] = 4627,
  [4875] = 4821,
  [4876] = 4852,
  [4877] = 4448,
  [4878] = 4878,
  [4879] = 3628,
  [4880] = 3626,
  [4881] = 3627,
  [4882] = 3629,
  [4883] = 3622,
  [4884] = 4884,
  [4885] = 3623,
  [4886] = 4886,
  [4887] = 4886,
  [4888] = 4884,
  [4889] = 4878,
  [4890] = 4886,
  [4891] = 3688,
  [4892] = 4884,
  [4893] = 4893,
  [4894] = 4878,
  [4895] = 4878,
  [4896] = 3640,
  [4897] = 4897,
  [4898] = 2291,
  [4899] = 2292,
  [4900] = 4900,
  [4901] = 3628,
  [4902] = 4902,
  [4903] = 2310,
  [4904] = 3626,
  [4905] = 2310,
  [4906] = 1779,
  [4907] = 4907,
  [4908] = 4897,
  [4909] = 4909,
  [4910] = 4910,
  [4911] = 2293,
  [4912] = 2293,
  [4913] = 2292,
  [4914] = 4907,
  [4915] = 4915,
  [4916] = 4916,
  [4917] = 4917,
  [4918] = 3755,
  [4919] = 4907,
  [4920] = 4915,
  [4921] = 4921,
  [4922] = 4897,
  [4923] = 4909,
  [4924] = 4897,
  [4925] = 1780,
  [4926] = 4909,
  [4927] = 4915,
  [4928] = 4902,
  [4929] = 1781,
  [4930] = 3629,
  [4931] = 3756,
  [4932] = 4932,
  [4933] = 4933,
  [4934] = 4907,
  [4935] = 3640,
  [4936] = 3623,
  [4937] = 2290,
  [4938] = 4907,
  [4939] = 4902,
  [4940] = 3627,
  [4941] = 4916,
  [4942] = 3688,
  [4943] = 4897,
  [4944] = 4944,
  [4945] = 4909,
  [4946] = 4910,
  [4947] = 4900,
  [4948] = 4897,
  [4949] = 4909,
  [4950] = 4915,
  [4951] = 3751,
  [4952] = 4902,
  [4953] = 4915,
  [4954] = 4954,
  [4955] = 3752,
  [4956] = 4897,
  [4957] = 4909,
  [4958] = 3757,
  [4959] = 4915,
  [4960] = 4902,
  [4961] = 3754,
  [4962] = 4909,
  [4963] = 4916,
  [4964] = 4902,
  [4965] = 4907,
  [4966] = 4915,
  [4967] = 2291,
  [4968] = 3753,
  [4969] = 4902,
  [4970] = 4907,
  [4971] = 3743,
  [4972] = 4972,
  [4973] = 4973,
  [4974] = 4974,
  [4975] = 4975,
  [4976] = 4976,
  [4977] = 4977,
  [4978] = 4978,
  [4979] = 4979,
  [4980] = 4980,
  [4981] = 4981,
  [4982] = 4982,
  [4983] = 4983,
  [4984] = 4984,
  [4985] = 4985,
  [4986] = 4986,
  [4987] = 3743,
  [4988] = 4988,
  [4989] = 4989,
  [4990] = 4990,
  [4991] = 4991,
  [4992] = 4992,
  [4993] = 4993,
  [4994] = 4994,
  [4995] = 4995,
  [4996] = 4996,
  [4997] = 4997,
  [4998] = 4998,
  [4999] = 4999,
  [5000] = 5000,
  [5001] = 5001,
  [5002] = 5002,
  [5003] = 5003,
  [5004] = 5004,
  [5005] = 5005,
  [5006] = 5006,
  [5007] = 5007,
  [5008] = 5008,
  [5009] = 5009,
  [5010] = 5010,
  [5011] = 5011,
  [5012] = 5012,
  [5013] = 5013,
  [5014] = 5014,
  [5015] = 5015,
  [5016] = 5016,
  [5017] = 5017,
  [5018] = 5018,
  [5019] = 5019,
  [5020] = 5020,
  [5021] = 5021,
  [5022] = 5022,
  [5023] = 5023,
  [5024] = 5024,
  [5025] = 5025,
  [5026] = 5026,
  [5027] = 5027,
  [5028] = 5028,
  [5029] = 5029,
  [5030] = 5030,
  [5031] = 5031,
  [5032] = 5032,
  [5033] = 5033,
  [5034] = 5034,
  [5035] = 5035,
  [5036] = 5036,
  [5037] = 5037,
  [5038] = 5038,
  [5039] = 5039,
  [5040] = 5040,
  [5041] = 5041,
  [5042] = 5042,
  [5043] = 5043,
  [5044] = 5044,
  [5045] = 5045,
  [5046] = 5046,
  [5047] = 5047,
  [5048] = 5048,
  [5049] = 5049,
  [5050] = 5050,
  [5051] = 5051,
  [5052] = 5052,
  [5053] = 5053,
  [5054] = 5007,
  [5055] = 5055,
  [5056] = 3751,
  [5057] = 5057,
  [5058] = 5058,
  [5059] = 5059,
  [5060] = 5060,
  [5061] = 5061,
  [5062] = 5062,
  [5063] = 5063,
  [5064] = 5064,
  [5065] = 5065,
  [5066] = 5066,
  [5067] = 5067,
  [5068] = 5068,
  [5069] = 5069,
  [5070] = 5070,
  [5071] = 5071,
  [5072] = 5072,
  [5073] = 5073,
  [5074] = 5074,
  [5075] = 5075,
  [5076] = 5076,
  [5077] = 5008,
  [5078] = 5078,
  [5079] = 5079,
  [5080] = 5080,
  [5081] = 5081,
  [5082] = 5082,
  [5083] = 5083,
  [5084] = 5084,
  [5085] = 5085,
  [5086] = 5086,
  [5087] = 3752,
  [5088] = 5088,
  [5089] = 5089,
  [5090] = 5090,
  [5091] = 5091,
  [5092] = 5092,
  [5093] = 5093,
  [5094] = 5094,
  [5095] = 5095,
  [5096] = 3753,
  [5097] = 3810,
  [5098] = 3754,
  [5099] = 5099,
  [5100] = 5100,
  [5101] = 5101,
  [5102] = 3755,
  [5103] = 5103,
  [5104] = 5104,
  [5105] = 3756,
  [5106] = 5106,
  [5107] = 3757,
  [5108] = 5108,
  [5109] = 5109,
  [5110] = 5110,
  [5111] = 5111,
  [5112] = 5112,
  [5113] = 5113,
  [5114] = 5114,
  [5115] = 5115,
  [5116] = 5116,
  [5117] = 5117,
  [5118] = 5118,
  [5119] = 5119,
  [5120] = 5120,
  [5121] = 5121,
  [5122] = 5122,
  [5123] = 5123,
  [5124] = 5124,
  [5125] = 5125,
  [5126] = 5126,
  [5127] = 5127,
  [5128] = 5128,
  [5129] = 5129,
  [5130] = 5130,
  [5131] = 5131,
  [5132] = 5132,
  [5133] = 5133,
  [5134] = 5134,
  [5135] = 5135,
  [5136] = 5136,
  [5137] = 5137,
  [5138] = 5138,
  [5139] = 5139,
  [5140] = 5140,
  [5141] = 5141,
  [5142] = 5142,
  [5143] = 5143,
  [5144] = 5144,
  [5145] = 5145,
  [5146] = 5146,
  [5147] = 5147,
  [5148] = 5148,
  [5149] = 5149,
  [5150] = 2633,
  [5151] = 5151,
  [5152] = 5152,
  [5153] = 5153,
  [5154] = 5154,
  [5155] = 5155,
  [5156] = 5156,
  [5157] = 5157,
  [5158] = 5158,
  [5159] = 5159,
  [5160] = 3688,
  [5161] = 5161,
  [5162] = 5162,
  [5163] = 5163,
  [5164] = 5164,
  [5165] = 5165,
  [5166] = 5166,
  [5167] = 5167,
  [5168] = 5168,
  [5169] = 5169,
  [5170] = 5170,
  [5171] = 5171,
  [5172] = 5172,
  [5173] = 5173,
  [5174] = 5174,
  [5175] = 5175,
  [5176] = 5176,
  [5177] = 5177,
  [5178] = 5007,
  [5179] = 5179,
  [5180] = 5180,
  [5181] = 5181,
  [5182] = 5182,
  [5183] = 5183,
  [5184] = 5184,
  [5185] = 5185,
  [5186] = 5186,
  [5187] = 5187,
  [5188] = 5188,
  [5189] = 5189,
  [5190] = 5190,
  [5191] = 5191,
  [5192] = 5192,
  [5193] = 5193,
  [5194] = 5194,
  [5195] = 5195,
  [5196] = 5196,
  [5197] = 5197,
  [5198] = 5198,
  [5199] = 5199,
  [5200] = 5200,
  [5201] = 5201,
  [5202] = 5202,
  [5203] = 5203,
  [5204] = 5204,
  [5205] = 5205,
  [5206] = 5206,
  [5207] = 5207,
  [5208] = 5208,
  [5209] = 5209,
  [5210] = 5210,
  [5211] = 5211,
  [5212] = 5008,
  [5213] = 5213,
  [5214] = 4003,
  [5215] = 5215,
  [5216] = 5216,
  [5217] = 5217,
  [5218] = 5218,
  [5219] = 5219,
  [5220] = 5220,
  [5221] = 4005,
  [5222] = 4006,
  [5223] = 4007,
  [5224] = 4008,
  [5225] = 5225,
  [5226] = 3640,
  [5227] = 5227,
  [5228] = 5228,
  [5229] = 5229,
  [5230] = 5230,
  [5231] = 5231,
  [5232] = 5232,
  [5233] = 4017,
  [5234] = 4018,
  [5235] = 4019,
  [5236] = 4020,
  [5237] = 4022,
  [5238] = 4023,
  [5239] = 5239,
  [5240] = 5240,
  [5241] = 5241,
  [5242] = 5242,
  [5243] = 5243,
  [5244] = 5244,
  [5245] = 4038,
  [5246] = 4039,
  [5247] = 4040,
  [5248] = 4041,
  [5249] = 4042,
  [5250] = 4043,
  [5251] = 5251,
  [5252] = 5252,
  [5253] = 5253,
  [5254] = 5254,
  [5255] = 5255,
  [5256] = 4048,
  [5257] = 4049,
  [5258] = 4050,
  [5259] = 4051,
  [5260] = 4052,
  [5261] = 5261,
  [5262] = 5262,
  [5263] = 3983,
  [5264] = 3984,
  [5265] = 5265,
  [5266] = 5266,
  [5267] = 5267,
  [5268] = 5268,
  [5269] = 5269,
  [5270] = 5270,
  [5271] = 5271,
  [5272] = 5272,
  [5273] = 5273,
  [5274] = 5274,
  [5275] = 5275,
  [5276] = 5276,
  [5277] = 5277,
  [5278] = 5278,
  [5279] = 5279,
  [5280] = 5280,
  [5281] = 5281,
  [5282] = 5282,
  [5283] = 5283,
  [5284] = 5284,
  [5285] = 5285,
  [5286] = 5286,
  [5287] = 5287,
  [5288] = 5288,
  [5289] = 5289,
  [5290] = 5290,
  [5291] = 5291,
  [5292] = 5292,
  [5293] = 5293,
  [5294] = 5294,
  [5295] = 5295,
  [5296] = 5296,
  [5297] = 5297,
  [5298] = 5298,
  [5299] = 5299,
  [5300] = 5007,
  [5301] = 5301,
  [5302] = 5008,
  [5303] = 5303,
  [5304] = 5304,
  [5305] = 5305,
  [5306] = 5306,
  [5307] = 5307,
  [5308] = 5308,
  [5309] = 5309,
  [5310] = 5310,
  [5311] = 5311,
  [5312] = 5312,
  [5313] = 5313,
  [5314] = 3756,
  [5315] = 3753,
  [5316] = 5316,
  [5317] = 3743,
  [5318] = 3754,
  [5319] = 3755,
  [5320] = 3575,
  [5321] = 3574,
  [5322] = 3757,
  [5323] = 3564,
  [5324] = 3751,
  [5325] = 3584,
  [5326] = 250,
  [5327] = 2258,
  [5328] = 3752,
  [5329] = 5329,
  [5330] = 5330,
  [5331] = 5331,
  [5332] = 5332,
  [5333] = 5333,
  [5334] = 5334,
  [5335] = 5335,
  [5336] = 5336,
  [5337] = 5337,
  [5338] = 5338,
  [5339] = 5339,
  [5340] = 5340,
  [5341] = 5341,
  [5342] = 5342,
  [5343] = 5343,
  [5344] = 5344,
  [5345] = 5345,
  [5346] = 161,
  [5347] = 5347,
  [5348] = 5348,
  [5349] = 5349,
  [5350] = 5350,
  [5351] = 5351,
  [5352] = 5352,
  [5353] = 5353,
  [5354] = 5354,
  [5355] = 5355,
  [5356] = 5356,
  [5357] = 5357,
  [5358] = 164,
  [5359] = 5359,
  [5360] = 5360,
  [5361] = 5361,
  [5362] = 5362,
  [5363] = 5363,
  [5364] = 5364,
  [5365] = 5365,
  [5366] = 5366,
  [5367] = 5367,
  [5368] = 5368,
  [5369] = 5369,
  [5370] = 5370,
  [5371] = 5371,
  [5372] = 5372,
  [5373] = 5373,
  [5374] = 3420,
  [5375] = 5375,
  [5376] = 5376,
  [5377] = 5377,
  [5378] = 5378,
  [5379] = 5379,
  [5380] = 5380,
  [5381] = 5381,
  [5382] = 5382,
  [5383] = 5383,
  [5384] = 5384,
  [5385] = 5385,
  [5386] = 5386,
  [5387] = 5387,
  [5388] = 5388,
  [5389] = 5377,
  [5390] = 5390,
  [5391] = 5391,
  [5392] = 5392,
  [5393] = 5393,
  [5394] = 5394,
  [5395] = 5395,
  [5396] = 5396,
  [5397] = 5397,
  [5398] = 5398,
  [5399] = 5399,
  [5400] = 5400,
  [5401] = 5401,
  [5402] = 5402,
  [5403] = 5403,
  [5404] = 5404,
  [5405] = 5405,
  [5406] = 5406,
  [5407] = 5407,
  [5408] = 5408,
  [5409] = 5409,
  [5410] = 5402,
  [5411] = 5411,
  [5412] = 3420,
  [5413] = 5354,
  [5414] = 5414,
  [5415] = 5415,
  [5416] = 5416,
  [5417] = 5417,
  [5418] = 5418,
  [5419] = 5419,
  [5420] = 3959,
  [5421] = 166,
  [5422] = 5422,
  [5423] = 5422,
  [5424] = 5424,
  [5425] = 5425,
  [5426] = 5418,
  [5427] = 5417,
  [5428] = 5428,
  [5429] = 5424,
  [5430] = 5419,
  [5431] = 5431,
  [5432] = 5425,
  [5433] = 5431,
  [5434] = 5416,
  [5435] = 5435,
  [5436] = 5436,
  [5437] = 5437,
  [5438] = 5438,
  [5439] = 1799,
  [5440] = 5440,
  [5441] = 5440,
  [5442] = 5437,
  [5443] = 5443,
  [5444] = 5438,
  [5445] = 5445,
  [5446] = 5446,
  [5447] = 1801,
  [5448] = 5435,
  [5449] = 5436,
  [5450] = 5450,
  [5451] = 5450,
  [5452] = 1800,
  [5453] = 5445,
  [5454] = 5443,
  [5455] = 5455,
  [5456] = 5456,
  [5457] = 5457,
  [5458] = 5458,
  [5459] = 5459,
  [5460] = 5460,
  [5461] = 5461,
  [5462] = 5462,
  [5463] = 5463,
  [5464] = 5464,
  [5465] = 5465,
  [5466] = 5466,
  [5467] = 5467,
  [5468] = 5468,
  [5469] = 5469,
  [5470] = 5470,
  [5471] = 5471,
  [5472] = 5472,
  [5473] = 5473,
  [5474] = 5474,
  [5475] = 5475,
  [5476] = 5476,
  [5477] = 5477,
  [5478] = 5457,
  [5479] = 5479,
  [5480] = 5480,
  [5481] = 2573,
  [5482] = 2574,
  [5483] = 2575,
  [5484] = 2576,
  [5485] = 5485,
  [5486] = 5486,
  [5487] = 5487,
  [5488] = 5470,
  [5489] = 5489,
  [5490] = 5490,
  [5491] = 5491,
  [5492] = 5492,
  [5493] = 5493,
  [5494] = 5475,
  [5495] = 5495,
  [5496] = 3688,
  [5497] = 5457,
  [5498] = 5498,
  [5499] = 5462,
  [5500] = 5466,
  [5501] = 5501,
  [5502] = 5502,
  [5503] = 5503,
  [5504] = 5504,
  [5505] = 5505,
  [5506] = 5506,
  [5507] = 5507,
  [5508] = 5508,
  [5509] = 2258,
  [5510] = 5510,
  [5511] = 5511,
  [5512] = 3574,
  [5513] = 5513,
  [5514] = 5514,
  [5515] = 5515,
  [5516] = 5516,
  [5517] = 5517,
  [5518] = 2577,
  [5519] = 5519,
  [5520] = 5520,
  [5521] = 5521,
  [5522] = 5513,
  [5523] = 5476,
  [5524] = 1824,
  [5525] = 5525,
  [5526] = 5485,
  [5527] = 5527,
  [5528] = 5489,
  [5529] = 3983,
  [5530] = 5530,
  [5531] = 3984,
  [5532] = 5532,
  [5533] = 5533,
  [5534] = 5457,
  [5535] = 5521,
  [5536] = 5461,
  [5537] = 5537,
  [5538] = 4011,
  [5539] = 5539,
  [5540] = 2561,
  [5541] = 5510,
  [5542] = 5514,
  [5543] = 5543,
  [5544] = 3982,
  [5545] = 4028,
  [5546] = 5546,
  [5547] = 5503,
  [5548] = 5548,
  [5549] = 5549,
  [5550] = 4029,
  [5551] = 4032,
  [5552] = 4034,
  [5553] = 5553,
  [5554] = 5554,
  [5555] = 5489,
  [5556] = 5527,
  [5557] = 3640,
  [5558] = 5558,
  [5559] = 5517,
  [5560] = 5530,
  [5561] = 5532,
  [5562] = 5533,
  [5563] = 5563,
  [5564] = 5486,
  [5565] = 5565,
  [5566] = 5525,
  [5567] = 5567,
  [5568] = 5568,
  [5569] = 5569,
  [5570] = 5570,
  [5571] = 5571,
  [5572] = 5549,
  [5573] = 5573,
  [5574] = 5492,
  [5575] = 5487,
  [5576] = 5501,
  [5577] = 4477,
  [5578] = 5578,
  [5579] = 2557,
  [5580] = 2558,
  [5581] = 2559,
  [5582] = 5582,
  [5583] = 2562,
  [5584] = 4017,
  [5585] = 4018,
  [5586] = 4019,
  [5587] = 5504,
  [5588] = 4020,
  [5589] = 5485,
  [5590] = 4022,
  [5591] = 5591,
  [5592] = 4023,
  [5593] = 5475,
  [5594] = 5511,
  [5595] = 5521,
  [5596] = 5596,
  [5597] = 5597,
  [5598] = 5567,
  [5599] = 4038,
  [5600] = 5600,
  [5601] = 5601,
  [5602] = 5602,
  [5603] = 5603,
  [5604] = 5604,
  [5605] = 5506,
  [5606] = 5606,
  [5607] = 5607,
  [5608] = 5608,
  [5609] = 5568,
  [5610] = 4039,
  [5611] = 5569,
  [5612] = 4040,
  [5613] = 2258,
  [5614] = 5508,
  [5615] = 5507,
  [5616] = 5457,
  [5617] = 2564,
  [5618] = 2565,
  [5619] = 5619,
  [5620] = 4009,
  [5621] = 5521,
  [5622] = 4041,
  [5623] = 5573,
  [5624] = 2566,
  [5625] = 4042,
  [5626] = 5626,
  [5627] = 5477,
  [5628] = 5495,
  [5629] = 5629,
  [5630] = 5498,
  [5631] = 5602,
  [5632] = 5632,
  [5633] = 5633,
  [5634] = 5634,
  [5635] = 5635,
  [5636] = 4043,
  [5637] = 5463,
  [5638] = 5638,
  [5639] = 5604,
  [5640] = 5464,
  [5641] = 5638,
  [5642] = 5513,
  [5643] = 5465,
  [5644] = 5644,
  [5645] = 5460,
  [5646] = 5603,
  [5647] = 5629,
  [5648] = 5648,
  [5649] = 5649,
  [5650] = 5635,
  [5651] = 5455,
  [5652] = 5596,
  [5653] = 5653,
  [5654] = 5654,
  [5655] = 5655,
  [5656] = 5571,
  [5657] = 5626,
  [5658] = 5658,
  [5659] = 5653,
  [5660] = 5660,
  [5661] = 5660,
  [5662] = 5662,
  [5663] = 5513,
  [5664] = 5664,
  [5665] = 5665,
  [5666] = 5666,
  [5667] = 5634,
  [5668] = 5664,
  [5669] = 4024,
  [5670] = 5670,
  [5671] = 5666,
  [5672] = 5519,
  [5673] = 5626,
  [5674] = 5633,
  [5675] = 5675,
  [5676] = 5676,
  [5677] = 5677,
  [5678] = 5473,
  [5679] = 4003,
  [5680] = 5606,
  [5681] = 5670,
  [5682] = 5633,
  [5683] = 5683,
  [5684] = 5475,
  [5685] = 5601,
  [5686] = 5686,
  [5687] = 5475,
  [5688] = 5475,
  [5689] = 5479,
  [5690] = 5480,
  [5691] = 5691,
  [5692] = 5692,
  [5693] = 4025,
  [5694] = 5485,
  [5695] = 5607,
  [5696] = 5608,
  [5697] = 4048,
  [5698] = 5698,
  [5699] = 5699,
  [5700] = 5543,
  [5701] = 3564,
  [5702] = 5473,
  [5703] = 5474,
  [5704] = 5491,
  [5705] = 4049,
  [5706] = 5686,
  [5707] = 4050,
  [5708] = 4051,
  [5709] = 5709,
  [5710] = 5710,
  [5711] = 5709,
  [5712] = 2554,
  [5713] = 5619,
  [5714] = 5714,
  [5715] = 5546,
  [5716] = 5716,
  [5717] = 5467,
  [5718] = 5718,
  [5719] = 4046,
  [5720] = 5720,
  [5721] = 5468,
  [5722] = 5469,
  [5723] = 5471,
  [5724] = 5457,
  [5725] = 5479,
  [5726] = 5489,
  [5727] = 4052,
  [5728] = 2555,
  [5729] = 5578,
  [5730] = 5493,
  [5731] = 5648,
  [5732] = 5480,
  [5733] = 5733,
  [5734] = 5548,
  [5735] = 5472,
  [5736] = 4047,
  [5737] = 5502,
  [5738] = 5691,
  [5739] = 5513,
  [5740] = 4005,
  [5741] = 4006,
  [5742] = 5742,
  [5743] = 4007,
  [5744] = 4008,
  [5745] = 5718,
  [5746] = 5515,
  [5747] = 5649,
  [5748] = 5537,
  [5749] = 5582,
  [5750] = 5456,
  [5751] = 5644,
  [5752] = 5665,
  [5753] = 5677,
  [5754] = 5458,
  [5755] = 5459,
  [5756] = 5655,
  [5757] = 5714,
  [5758] = 5758,
  [5759] = 4026,
  [5760] = 5760,
  [5761] = 5475,
  [5762] = 2567,
  [5763] = 2568,
  [5764] = 5515,
  [5765] = 5520,
  [5766] = 5665,
  [5767] = 2569,
  [5768] = 5677,
  [5769] = 5714,
  [5770] = 5758,
  [5771] = 5476,
  [5772] = 2570,
  [5773] = 2571,
  [5774] = 2572,
  [5775] = 5465,
  [5776] = 5476,
  [5777] = 5517,
  [5778] = 5530,
  [5779] = 5532,
  [5780] = 5503,
  [5781] = 5781,
  [5782] = 5782,
  [5783] = 5457,
  [5784] = 5504,
  [5785] = 3991,
  [5786] = 5570,
  [5787] = 5675,
  [5788] = 5788,
  [5789] = 5533,
  [5790] = 5505,
  [5791] = 5475,
  [5792] = 5457,
  [5793] = 2563,
  [5794] = 5794,
  [5795] = 5654,
  [5796] = 5720,
  [5797] = 5797,
  [5798] = 5626,
  [5799] = 5602,
  [5800] = 5653,
  [5801] = 5660,
  [5802] = 5664,
  [5803] = 5666,
  [5804] = 5600,
  [5805] = 5805,
  [5806] = 5473,
  [5807] = 5807,
  [5808] = 5521,
  [5809] = 5479,
  [5810] = 5480,
  [5811] = 5491,
  [5812] = 5676,
  [5813] = 5692,
  [5814] = 5626,
  [5815] = 5698,
  [5816] = 5797,
  [5817] = 5805,
  [5818] = 2556,
  [5819] = 5658,
  [5820] = 5807,
  [5821] = 5781,
  [5822] = 5565,
  [5823] = 5710,
  [5824] = 5716,
  [5825] = 5683,
  [5826] = 5467,
  [5827] = 5468,
  [5828] = 5469,
  [5829] = 5471,
  [5830] = 5472,
  [5831] = 5807,
  [5832] = 5662,
  [5833] = 5710,
  [5834] = 5834,
  [5835] = 5464,
  [5836] = 5465,
  [5837] = 5517,
  [5838] = 5530,
  [5839] = 5532,
  [5840] = 5533,
  [5841] = 5733,
  [5842] = 5758,
  [5843] = 5632,
  [5844] = 5710,
  [5845] = 5467,
  [5846] = 5468,
  [5847] = 5469,
  [5848] = 5471,
  [5849] = 5472,
  [5850] = 5457,
  [5851] = 4027,
  [5852] = 5782,
  [5853] = 5503,
  [5854] = 5504,
  [5855] = 5475,
  [5856] = 5485,
  [5857] = 5597,
  [5858] = 2557,
  [5859] = 5859,
  [5860] = 4022,
  [5861] = 4023,
  [5862] = 2574,
  [5863] = 3752,
  [5864] = 4006,
  [5865] = 5859,
  [5866] = 5859,
  [5867] = 3751,
  [5868] = 2258,
  [5869] = 4038,
  [5870] = 4039,
  [5871] = 4040,
  [5872] = 4041,
  [5873] = 4042,
  [5874] = 5874,
  [5875] = 4043,
  [5876] = 4026,
  [5877] = 2577,
  [5878] = 4027,
  [5879] = 2567,
  [5880] = 4007,
  [5881] = 4008,
  [5882] = 4048,
  [5883] = 4028,
  [5884] = 4011,
  [5885] = 2570,
  [5886] = 4049,
  [5887] = 2571,
  [5888] = 2566,
  [5889] = 4029,
  [5890] = 4050,
  [5891] = 2568,
  [5892] = 3743,
  [5893] = 3754,
  [5894] = 2569,
  [5895] = 2554,
  [5896] = 4020,
  [5897] = 2555,
  [5898] = 2556,
  [5899] = 3753,
  [5900] = 4005,
  [5901] = 2558,
  [5902] = 2575,
  [5903] = 4034,
  [5904] = 3755,
  [5905] = 2572,
  [5906] = 2573,
  [5907] = 4051,
  [5908] = 4046,
  [5909] = 3756,
  [5910] = 3757,
  [5911] = 2576,
  [5912] = 4003,
  [5913] = 4052,
  [5914] = 4024,
  [5915] = 4025,
  [5916] = 5874,
  [5917] = 4047,
  [5918] = 4017,
  [5919] = 161,
  [5920] = 4018,
  [5921] = 2559,
  [5922] = 2561,
  [5923] = 2562,
  [5924] = 2563,
  [5925] = 3982,
  [5926] = 4019,
  [5927] = 3983,
  [5928] = 2564,
  [5929] = 3984,
  [5930] = 2565,
  [5931] = 3991,
  [5932] = 4032,
  [5933] = 2293,
  [5934] = 3564,
  [5935] = 164,
  [5936] = 4933,
  [5937] = 1799,
  [5938] = 1800,
  [5939] = 3584,
  [5940] = 3574,
  [5941] = 2292,
  [5942] = 2290,
  [5943] = 2291,
  [5944] = 2258,
  [5945] = 1801,
  [5946] = 1771,
  [5947] = 2310,
  [5948] = 3575,
  [5949] = 4917,
  [5950] = 5083,
  [5951] = 5241,
  [5952] = 5242,
  [5953] = 5243,
  [5954] = 5244,
  [5955] = 5252,
  [5956] = 5253,
  [5957] = 4170,
  [5958] = 5254,
  [5959] = 4003,
  [5960] = 5255,
  [5961] = 5128,
  [5962] = 5129,
  [5963] = 5130,
  [5964] = 2367,
  [5965] = 2360,
  [5966] = 5131,
  [5967] = 2370,
  [5968] = 2358,
  [5969] = 2356,
  [5970] = 2371,
  [5971] = 2375,
  [5972] = 2357,
  [5973] = 5132,
  [5974] = 4140,
  [5975] = 5037,
  [5976] = 4218,
  [5977] = 5042,
  [5978] = 5044,
  [5979] = 3983,
  [5980] = 3984,
  [5981] = 4141,
  [5982] = 4142,
  [5983] = 4143,
  [5984] = 4144,
  [5985] = 5048,
  [5986] = 5168,
  [5987] = 5225,
  [5988] = 5169,
  [5989] = 4171,
  [5990] = 4172,
  [5991] = 1799,
  [5992] = 5265,
  [5993] = 4173,
  [5994] = 4174,
  [5995] = 4175,
  [5996] = 4176,
  [5997] = 4177,
  [5998] = 4178,
  [5999] = 5176,
  [6000] = 2374,
  [6001] = 2361,
  [6002] = 5177,
  [6003] = 5134,
  [6004] = 4179,
  [6005] = 4993,
  [6006] = 1800,
  [6007] = 5018,
  [6008] = 4994,
  [6009] = 4995,
  [6010] = 4996,
  [6011] = 4180,
  [6012] = 4181,
  [6013] = 1801,
  [6014] = 4182,
  [6015] = 5135,
  [6016] = 4183,
  [6017] = 4997,
  [6018] = 4998,
  [6019] = 4184,
  [6020] = 4999,
  [6021] = 5000,
  [6022] = 4185,
  [6023] = 4290,
  [6024] = 4186,
  [6025] = 4187,
  [6026] = 4188,
  [6027] = 5179,
  [6028] = 5180,
  [6029] = 5136,
  [6030] = 2302,
  [6031] = 5181,
  [6032] = 5182,
  [6033] = 5191,
  [6034] = 5192,
  [6035] = 5193,
  [6036] = 5194,
  [6037] = 5195,
  [6038] = 5196,
  [6039] = 5197,
  [6040] = 5198,
  [6041] = 5199,
  [6042] = 5200,
  [6043] = 5201,
  [6044] = 5202,
  [6045] = 5203,
  [6046] = 5019,
  [6047] = 5020,
  [6048] = 5021,
  [6049] = 5204,
  [6050] = 4108,
  [6051] = 5205,
  [6052] = 4988,
  [6053] = 5206,
  [6054] = 5207,
  [6055] = 5137,
  [6056] = 5138,
  [6057] = 5139,
  [6058] = 5140,
  [6059] = 5009,
  [6060] = 5001,
  [6061] = 5141,
  [6062] = 5142,
  [6063] = 5143,
  [6064] = 5239,
  [6065] = 5144,
  [6066] = 5145,
  [6067] = 5002,
  [6068] = 4104,
  [6069] = 5049,
  [6070] = 5227,
  [6071] = 5183,
  [6072] = 5184,
  [6073] = 5185,
  [6074] = 5186,
  [6075] = 4105,
  [6076] = 2573,
  [6077] = 5003,
  [6078] = 5004,
  [6079] = 5005,
  [6080] = 5006,
  [6081] = 2574,
  [6082] = 5215,
  [6083] = 5273,
  [6084] = 5274,
  [6085] = 5275,
  [6086] = 5276,
  [6087] = 5278,
  [6088] = 5216,
  [6089] = 5280,
  [6090] = 2575,
  [6091] = 2576,
  [6092] = 5281,
  [6093] = 2633,
  [6094] = 4227,
  [6095] = 4229,
  [6096] = 4230,
  [6097] = 4231,
  [6098] = 4232,
  [6099] = 4111,
  [6100] = 4112,
  [6101] = 4048,
  [6102] = 4049,
  [6103] = 4050,
  [6104] = 4051,
  [6105] = 4052,
  [6106] = 2561,
  [6107] = 2562,
  [6108] = 5088,
  [6109] = 4038,
  [6110] = 4039,
  [6111] = 4040,
  [6112] = 4041,
  [6113] = 4252,
  [6114] = 5287,
  [6115] = 4042,
  [6116] = 4043,
  [6117] = 4253,
  [6118] = 4254,
  [6119] = 5022,
  [6120] = 5023,
  [6121] = 5024,
  [6122] = 5025,
  [6123] = 5026,
  [6124] = 5027,
  [6125] = 5028,
  [6126] = 5029,
  [6127] = 5030,
  [6128] = 5031,
  [6129] = 5032,
  [6130] = 4113,
  [6131] = 4255,
  [6132] = 5297,
  [6133] = 5298,
  [6134] = 2556,
  [6135] = 5033,
  [6136] = 5035,
  [6137] = 5038,
  [6138] = 5039,
  [6139] = 5040,
  [6140] = 5041,
  [6141] = 5161,
  [6142] = 5043,
  [6143] = 5045,
  [6144] = 5162,
  [6145] = 5163,
  [6146] = 5164,
  [6147] = 5165,
  [6148] = 4114,
  [6149] = 4115,
  [6150] = 5046,
  [6151] = 5166,
  [6152] = 5047,
  [6153] = 5261,
  [6154] = 4116,
  [6155] = 5262,
  [6156] = 5277,
  [6157] = 5050,
  [6158] = 5167,
  [6159] = 5170,
  [6160] = 4274,
  [6161] = 4117,
  [6162] = 5279,
  [6163] = 5282,
  [6164] = 5171,
  [6165] = 5283,
  [6166] = 5284,
  [6167] = 4139,
  [6168] = 4118,
  [6169] = 4145,
  [6170] = 4154,
  [6171] = 5286,
  [6172] = 5288,
  [6173] = 5289,
  [6174] = 5290,
  [6175] = 5291,
  [6176] = 5292,
  [6177] = 5293,
  [6178] = 5294,
  [6179] = 5295,
  [6180] = 5296,
  [6181] = 5051,
  [6182] = 5052,
  [6183] = 4221,
  [6184] = 5172,
  [6185] = 4233,
  [6186] = 4234,
  [6187] = 4235,
  [6188] = 5266,
  [6189] = 2557,
  [6190] = 4119,
  [6191] = 4224,
  [6192] = 2558,
  [6193] = 4120,
  [6194] = 2559,
  [6195] = 4124,
  [6196] = 5113,
  [6197] = 4017,
  [6198] = 2563,
  [6199] = 4018,
  [6200] = 4019,
  [6201] = 4020,
  [6202] = 4022,
  [6203] = 4023,
  [6204] = 5213,
  [6205] = 5313,
  [6206] = 5232,
  [6207] = 5268,
  [6208] = 5174,
  [6209] = 4190,
  [6210] = 4191,
  [6211] = 5240,
  [6212] = 4192,
  [6213] = 4193,
  [6214] = 5175,
  [6215] = 4194,
  [6216] = 4195,
  [6217] = 4196,
  [6218] = 4197,
  [6219] = 4198,
  [6220] = 4199,
  [6221] = 4200,
  [6222] = 4201,
  [6223] = 4202,
  [6224] = 4203,
  [6225] = 4204,
  [6226] = 4205,
  [6227] = 4206,
  [6228] = 4207,
  [6229] = 4208,
  [6230] = 5114,
  [6231] = 4125,
  [6232] = 4126,
  [6233] = 4127,
  [6234] = 4209,
  [6235] = 4210,
  [6236] = 2554,
  [6237] = 5055,
  [6238] = 5133,
  [6239] = 5156,
  [6240] = 5208,
  [6241] = 5189,
  [6242] = 5209,
  [6243] = 5210,
  [6244] = 5211,
  [6245] = 5190,
  [6246] = 4128,
  [6247] = 5034,
  [6248] = 4129,
  [6249] = 4130,
  [6250] = 5217,
  [6251] = 5218,
  [6252] = 5219,
  [6253] = 2577,
  [6254] = 5220,
  [6255] = 5229,
  [6256] = 5269,
  [6257] = 5285,
  [6258] = 5251,
  [6259] = 5099,
  [6260] = 4131,
  [6261] = 2567,
  [6262] = 5100,
  [6263] = 5101,
  [6264] = 4107,
  [6265] = 2568,
  [6266] = 5103,
  [6267] = 2555,
  [6268] = 5299,
  [6269] = 5301,
  [6270] = 4983,
  [6271] = 4984,
  [6272] = 5104,
  [6273] = 4091,
  [6274] = 4092,
  [6275] = 5106,
  [6276] = 5108,
  [6277] = 5109,
  [6278] = 5228,
  [6279] = 4093,
  [6280] = 4985,
  [6281] = 4094,
  [6282] = 4095,
  [6283] = 4096,
  [6284] = 4097,
  [6285] = 5057,
  [6286] = 5058,
  [6287] = 5059,
  [6288] = 5060,
  [6289] = 5061,
  [6290] = 5062,
  [6291] = 5063,
  [6292] = 5064,
  [6293] = 4098,
  [6294] = 4986,
  [6295] = 4256,
  [6296] = 4257,
  [6297] = 4099,
  [6298] = 4100,
  [6299] = 4101,
  [6300] = 4102,
  [6301] = 4258,
  [6302] = 5065,
  [6303] = 5066,
  [6304] = 5067,
  [6305] = 5068,
  [6306] = 5069,
  [6307] = 5070,
  [6308] = 5071,
  [6309] = 5072,
  [6310] = 5073,
  [6311] = 5074,
  [6312] = 5075,
  [6313] = 5076,
  [6314] = 4259,
  [6315] = 4260,
  [6316] = 4261,
  [6317] = 4262,
  [6318] = 4298,
  [6319] = 4263,
  [6320] = 5078,
  [6321] = 5079,
  [6322] = 5080,
  [6323] = 5081,
  [6324] = 5110,
  [6325] = 2569,
  [6326] = 5111,
  [6327] = 5112,
  [6328] = 4275,
  [6329] = 4121,
  [6330] = 5115,
  [6331] = 2570,
  [6332] = 5116,
  [6333] = 5146,
  [6334] = 5082,
  [6335] = 5147,
  [6336] = 5084,
  [6337] = 5085,
  [6338] = 5086,
  [6339] = 4264,
  [6340] = 5148,
  [6341] = 4265,
  [6342] = 4106,
  [6343] = 4267,
  [6344] = 4272,
  [6345] = 4273,
  [6346] = 5089,
  [6347] = 5090,
  [6348] = 5091,
  [6349] = 5092,
  [6350] = 4972,
  [6351] = 5093,
  [6352] = 5149,
  [6353] = 5094,
  [6354] = 5095,
  [6355] = 4110,
  [6356] = 4122,
  [6357] = 5151,
  [6358] = 4123,
  [6359] = 5152,
  [6360] = 2564,
  [6361] = 5153,
  [6362] = 5154,
  [6363] = 4211,
  [6364] = 4989,
  [6365] = 4990,
  [6366] = 2565,
  [6367] = 2566,
  [6368] = 4991,
  [6369] = 4212,
  [6370] = 3629,
  [6371] = 4992,
  [6372] = 3623,
  [6373] = 4219,
  [6374] = 3627,
  [6375] = 5010,
  [6376] = 4213,
  [6377] = 5011,
  [6378] = 4477,
  [6379] = 4132,
  [6380] = 5012,
  [6381] = 5013,
  [6382] = 4214,
  [6383] = 3628,
  [6384] = 3626,
  [6385] = 4215,
  [6386] = 5014,
  [6387] = 4216,
  [6388] = 4217,
  [6389] = 5015,
  [6390] = 2571,
  [6391] = 2572,
  [6392] = 4220,
  [6393] = 5157,
  [6394] = 5270,
  [6395] = 4005,
  [6396] = 5016,
  [6397] = 4133,
  [6398] = 5155,
  [6399] = 4277,
  [6400] = 4279,
  [6401] = 4280,
  [6402] = 4281,
  [6403] = 4134,
  [6404] = 5187,
  [6405] = 5017,
  [6406] = 4006,
  [6407] = 5117,
  [6408] = 5118,
  [6409] = 4007,
  [6410] = 4008,
  [6411] = 5119,
  [6412] = 5120,
  [6413] = 4156,
  [6414] = 4157,
  [6415] = 5121,
  [6416] = 5122,
  [6417] = 5123,
  [6418] = 5124,
  [6419] = 4135,
  [6420] = 5036,
  [6421] = 4136,
  [6422] = 4137,
  [6423] = 4138,
  [6424] = 5303,
  [6425] = 4158,
  [6426] = 4159,
  [6427] = 4160,
  [6428] = 5125,
  [6429] = 4282,
  [6430] = 4089,
  [6431] = 4291,
  [6432] = 4292,
  [6433] = 4293,
  [6434] = 4294,
  [6435] = 4289,
  [6436] = 4103,
  [6437] = 1824,
  [6438] = 4271,
  [6439] = 5126,
  [6440] = 5127,
  [6441] = 166,
  [6442] = 4161,
  [6443] = 4162,
  [6444] = 4163,
  [6445] = 5304,
  [6446] = 5305,
  [6447] = 5306,
  [6448] = 5307,
  [6449] = 5308,
  [6450] = 5309,
  [6451] = 5310,
  [6452] = 5311,
  [6453] = 5312,
  [6454] = 5173,
  [6455] = 4973,
  [6456] = 4974,
  [6457] = 4975,
  [6458] = 4976,
  [6459] = 4977,
  [6460] = 4978,
  [6461] = 4979,
  [6462] = 4980,
  [6463] = 4981,
  [6464] = 4982,
  [6465] = 4164,
  [6466] = 4165,
  [6467] = 4166,
  [6468] = 4223,
  [6469] = 5271,
  [6470] = 5230,
  [6471] = 5158,
  [6472] = 4225,
  [6473] = 4226,
  [6474] = 5159,
  [6475] = 4167,
  [6476] = 4168,
  [6477] = 5231,
  [6478] = 4169,
  [6479] = 5267,
  [6480] = 6480,
  [6481] = 6481,
  [6482] = 6482,
  [6483] = 6483,
  [6484] = 2290,
  [6485] = 6485,
  [6486] = 6486,
  [6487] = 6481,
  [6488] = 4111,
  [6489] = 4112,
  [6490] = 6482,
  [6491] = 6491,
  [6492] = 4477,
  [6493] = 3584,
  [6494] = 3575,
  [6495] = 6495,
  [6496] = 1824,
  [6497] = 6491,
  [6498] = 6483,
  [6499] = 6486,
  [6500] = 250,
  [6501] = 6501,
  [6502] = 6483,
  [6503] = 6486,
  [6504] = 6481,
  [6505] = 6482,
  [6506] = 6506,
  [6507] = 6483,
  [6508] = 6486,
  [6509] = 6491,
  [6510] = 6510,
  [6511] = 6481,
  [6512] = 6501,
  [6513] = 6513,
  [6514] = 6491,
  [6515] = 6482,
  [6516] = 2331,
  [6517] = 2293,
  [6518] = 6518,
  [6519] = 5335,
  [6520] = 2310,
  [6521] = 6521,
  [6522] = 1771,
  [6523] = 6523,
  [6524] = 6524,
  [6525] = 6525,
  [6526] = 6526,
  [6527] = 4339,
  [6528] = 4340,
  [6529] = 6529,
  [6530] = 6530,
  [6531] = 6531,
  [6532] = 6532,
  [6533] = 6533,
  [6534] = 2292,
  [6535] = 6535,
  [6536] = 6536,
  [6537] = 6537,
  [6538] = 4418,
  [6539] = 4375,
  [6540] = 4329,
  [6541] = 4331,
  [6542] = 6542,
  [6543] = 4332,
  [6544] = 6544,
  [6545] = 4396,
  [6546] = 1771,
  [6547] = 4320,
  [6548] = 6548,
  [6549] = 6549,
  [6550] = 4323,
  [6551] = 6551,
  [6552] = 6552,
  [6553] = 4374,
  [6554] = 4426,
  [6555] = 4318,
  [6556] = 4333,
  [6557] = 4362,
  [6558] = 4349,
  [6559] = 4390,
  [6560] = 4381,
  [6561] = 6561,
  [6562] = 4387,
  [6563] = 6563,
  [6564] = 6564,
  [6565] = 4917,
  [6566] = 6566,
  [6567] = 6567,
  [6568] = 2331,
  [6569] = 4328,
  [6570] = 5335,
  [6571] = 6571,
  [6572] = 1830,
  [6573] = 4321,
  [6574] = 4334,
  [6575] = 4336,
  [6576] = 4337,
  [6577] = 6577,
  [6578] = 6578,
  [6579] = 6579,
  [6580] = 6580,
  [6581] = 6581,
  [6582] = 6582,
  [6583] = 6583,
  [6584] = 4365,
  [6585] = 4407,
  [6586] = 6586,
  [6587] = 4416,
  [6588] = 6588,
  [6589] = 6589,
  [6590] = 4372,
  [6591] = 6591,
  [6592] = 6592,
  [6593] = 6593,
  [6594] = 6594,
  [6595] = 6595,
  [6596] = 6596,
  [6597] = 2291,
  [6598] = 6598,
  [6599] = 4322,
  [6600] = 6600,
  [6601] = 4366,
  [6602] = 4367,
  [6603] = 4411,
  [6604] = 4370,
  [6605] = 4324,
  [6606] = 4351,
  [6607] = 4406,
  [6608] = 4933,
  [6609] = 2258,
  [6610] = 1825,
  [6611] = 6611,
  [6612] = 4325,
  [6613] = 4327,
  [6614] = 4428,
  [6615] = 4431,
  [6616] = 6616,
  [6617] = 4205,
  [6618] = 4271,
  [6619] = 5191,
  [6620] = 5192,
  [6621] = 5193,
  [6622] = 5194,
  [6623] = 5195,
  [6624] = 5196,
  [6625] = 5197,
  [6626] = 5198,
  [6627] = 5199,
  [6628] = 5200,
  [6629] = 5201,
  [6630] = 5202,
  [6631] = 5203,
  [6632] = 5204,
  [6633] = 5205,
  [6634] = 5206,
  [6635] = 5207,
  [6636] = 4121,
  [6637] = 5187,
  [6638] = 2522,
  [6639] = 5277,
  [6640] = 5279,
  [6641] = 5282,
  [6642] = 5283,
  [6643] = 5284,
  [6644] = 4139,
  [6645] = 4145,
  [6646] = 4154,
  [6647] = 5286,
  [6648] = 5288,
  [6649] = 5289,
  [6650] = 5290,
  [6651] = 5291,
  [6652] = 5292,
  [6653] = 5293,
  [6654] = 5294,
  [6655] = 5295,
  [6656] = 5296,
  [6657] = 4221,
  [6658] = 4233,
  [6659] = 4234,
  [6660] = 4235,
  [6661] = 5303,
  [6662] = 5304,
  [6663] = 5305,
  [6664] = 5306,
  [6665] = 5307,
  [6666] = 5308,
  [6667] = 5309,
  [6668] = 5310,
  [6669] = 5311,
  [6670] = 5312,
  [6671] = 5173,
  [6672] = 4973,
  [6673] = 4974,
  [6674] = 4975,
  [6675] = 4976,
  [6676] = 4977,
  [6677] = 4978,
  [6678] = 4979,
  [6679] = 4980,
  [6680] = 4981,
  [6681] = 4982,
  [6682] = 6682,
  [6683] = 4917,
  [6684] = 5227,
  [6685] = 5239,
  [6686] = 6686,
  [6687] = 4290,
  [6688] = 4988,
  [6689] = 4104,
  [6690] = 4105,
  [6691] = 4110,
  [6692] = 4122,
  [6693] = 4123,
  [6694] = 4989,
  [6695] = 4990,
  [6696] = 4991,
  [6697] = 4992,
  [6698] = 4993,
  [6699] = 4994,
  [6700] = 4995,
  [6701] = 4996,
  [6702] = 4997,
  [6703] = 4998,
  [6704] = 4999,
  [6705] = 5000,
  [6706] = 5001,
  [6707] = 5002,
  [6708] = 5003,
  [6709] = 5004,
  [6710] = 5005,
  [6711] = 5006,
  [6712] = 5217,
  [6713] = 5218,
  [6714] = 5219,
  [6715] = 5228,
  [6716] = 5230,
  [6717] = 5231,
  [6718] = 5232,
  [6719] = 5241,
  [6720] = 5242,
  [6721] = 5243,
  [6722] = 5244,
  [6723] = 5252,
  [6724] = 5253,
  [6725] = 5254,
  [6726] = 5255,
  [6727] = 4219,
  [6728] = 5010,
  [6729] = 5011,
  [6730] = 5012,
  [6731] = 5013,
  [6732] = 5014,
  [6733] = 5015,
  [6734] = 4220,
  [6735] = 5016,
  [6736] = 5017,
  [6737] = 4223,
  [6738] = 4225,
  [6739] = 4226,
  [6740] = 5018,
  [6741] = 5019,
  [6742] = 5020,
  [6743] = 5021,
  [6744] = 5240,
  [6745] = 6745,
  [6746] = 3420,
  [6747] = 6747,
  [6748] = 4252,
  [6749] = 4253,
  [6750] = 4254,
  [6751] = 5022,
  [6752] = 5023,
  [6753] = 5024,
  [6754] = 5025,
  [6755] = 5026,
  [6756] = 5027,
  [6757] = 5028,
  [6758] = 5029,
  [6759] = 5030,
  [6760] = 5031,
  [6761] = 5032,
  [6762] = 4255,
  [6763] = 5033,
  [6764] = 5035,
  [6765] = 5038,
  [6766] = 5039,
  [6767] = 6767,
  [6768] = 5040,
  [6769] = 5041,
  [6770] = 5043,
  [6771] = 5045,
  [6772] = 5046,
  [6773] = 5047,
  [6774] = 5050,
  [6775] = 4274,
  [6776] = 5051,
  [6777] = 5052,
  [6778] = 5261,
  [6779] = 5225,
  [6780] = 4218,
  [6781] = 5266,
  [6782] = 4224,
  [6783] = 5267,
  [6784] = 5268,
  [6785] = 6682,
  [6786] = 6767,
  [6787] = 4091,
  [6788] = 4092,
  [6789] = 5270,
  [6790] = 4093,
  [6791] = 4094,
  [6792] = 4095,
  [6793] = 4096,
  [6794] = 4097,
  [6795] = 5057,
  [6796] = 5058,
  [6797] = 5059,
  [6798] = 5060,
  [6799] = 5061,
  [6800] = 5062,
  [6801] = 5063,
  [6802] = 5064,
  [6803] = 4098,
  [6804] = 4099,
  [6805] = 4100,
  [6806] = 4101,
  [6807] = 4102,
  [6808] = 5065,
  [6809] = 5066,
  [6810] = 5067,
  [6811] = 5068,
  [6812] = 6682,
  [6813] = 6767,
  [6814] = 5069,
  [6815] = 5070,
  [6816] = 5071,
  [6817] = 5072,
  [6818] = 5073,
  [6819] = 5074,
  [6820] = 5075,
  [6821] = 5076,
  [6822] = 4298,
  [6823] = 5078,
  [6824] = 5079,
  [6825] = 5080,
  [6826] = 5081,
  [6827] = 5082,
  [6828] = 5083,
  [6829] = 5084,
  [6830] = 5085,
  [6831] = 5086,
  [6832] = 4106,
  [6833] = 5089,
  [6834] = 5090,
  [6835] = 4103,
  [6836] = 5092,
  [6837] = 4972,
  [6838] = 6682,
  [6839] = 6767,
  [6840] = 5093,
  [6841] = 5094,
  [6842] = 5095,
  [6843] = 6682,
  [6844] = 6767,
  [6845] = 5271,
  [6846] = 6682,
  [6847] = 6767,
  [6848] = 6682,
  [6849] = 6767,
  [6850] = 6682,
  [6851] = 6767,
  [6852] = 6682,
  [6853] = 5251,
  [6854] = 5272,
  [6855] = 5273,
  [6856] = 5274,
  [6857] = 5275,
  [6858] = 1782,
  [6859] = 5276,
  [6860] = 5215,
  [6861] = 5278,
  [6862] = 5280,
  [6863] = 5281,
  [6864] = 4227,
  [6865] = 4229,
  [6866] = 4230,
  [6867] = 5262,
  [6868] = 4231,
  [6869] = 4232,
  [6870] = 5009,
  [6871] = 5287,
  [6872] = 5297,
  [6873] = 5298,
  [6874] = 2633,
  [6875] = 6875,
  [6876] = 4107,
  [6877] = 6877,
  [6878] = 4933,
  [6879] = 6767,
  [6880] = 5216,
  [6881] = 1825,
  [6882] = 4113,
  [6883] = 4114,
  [6884] = 4115,
  [6885] = 4116,
  [6886] = 4117,
  [6887] = 5157,
  [6888] = 5158,
  [6889] = 5159,
  [6890] = 4118,
  [6891] = 4119,
  [6892] = 4120,
  [6893] = 4124,
  [6894] = 5113,
  [6895] = 5114,
  [6896] = 4125,
  [6897] = 4126,
  [6898] = 4127,
  [6899] = 4128,
  [6900] = 5213,
  [6901] = 4129,
  [6902] = 4130,
  [6903] = 4131,
  [6904] = 4132,
  [6905] = 4133,
  [6906] = 4134,
  [6907] = 5117,
  [6908] = 5118,
  [6909] = 4108,
  [6910] = 5053,
  [6911] = 5119,
  [6912] = 5055,
  [6913] = 5120,
  [6914] = 5121,
  [6915] = 5133,
  [6916] = 5122,
  [6917] = 5156,
  [6918] = 5208,
  [6919] = 5209,
  [6920] = 5210,
  [6921] = 5211,
  [6922] = 5220,
  [6923] = 5229,
  [6924] = 5269,
  [6925] = 5285,
  [6926] = 5299,
  [6927] = 5301,
  [6928] = 4983,
  [6929] = 4984,
  [6930] = 4985,
  [6931] = 5123,
  [6932] = 4986,
  [6933] = 5124,
  [6934] = 4135,
  [6935] = 4136,
  [6936] = 5265,
  [6937] = 4256,
  [6938] = 4257,
  [6939] = 4258,
  [6940] = 4137,
  [6941] = 4259,
  [6942] = 4138,
  [6943] = 5125,
  [6944] = 5126,
  [6945] = 4260,
  [6946] = 4261,
  [6947] = 4262,
  [6948] = 4263,
  [6949] = 4264,
  [6950] = 5127,
  [6951] = 5128,
  [6952] = 5129,
  [6953] = 5130,
  [6954] = 4265,
  [6955] = 4267,
  [6956] = 4272,
  [6957] = 4273,
  [6958] = 5034,
  [6959] = 5131,
  [6960] = 5132,
  [6961] = 4140,
  [6962] = 4141,
  [6963] = 5036,
  [6964] = 5037,
  [6965] = 5042,
  [6966] = 5044,
  [6967] = 4142,
  [6968] = 4143,
  [6969] = 4144,
  [6970] = 5134,
  [6971] = 5135,
  [6972] = 5136,
  [6973] = 5137,
  [6974] = 5138,
  [6975] = 5139,
  [6976] = 5140,
  [6977] = 5141,
  [6978] = 5142,
  [6979] = 5143,
  [6980] = 5144,
  [6981] = 5145,
  [6982] = 5048,
  [6983] = 5049,
  [6984] = 5161,
  [6985] = 5162,
  [6986] = 5163,
  [6987] = 5164,
  [6988] = 5165,
  [6989] = 5166,
  [6990] = 4156,
  [6991] = 4157,
  [6992] = 4158,
  [6993] = 4159,
  [6994] = 4160,
  [6995] = 4161,
  [6996] = 4162,
  [6997] = 4163,
  [6998] = 4164,
  [6999] = 4165,
  [7000] = 4166,
  [7001] = 4167,
  [7002] = 4168,
  [7003] = 4169,
  [7004] = 4170,
  [7005] = 5168,
  [7006] = 5169,
  [7007] = 4171,
  [7008] = 4172,
  [7009] = 4173,
  [7010] = 4174,
  [7011] = 4175,
  [7012] = 4176,
  [7013] = 4177,
  [7014] = 4178,
  [7015] = 5176,
  [7016] = 5177,
  [7017] = 4179,
  [7018] = 4180,
  [7019] = 4181,
  [7020] = 4182,
  [7021] = 4183,
  [7022] = 5167,
  [7023] = 4184,
  [7024] = 5170,
  [7025] = 5171,
  [7026] = 5088,
  [7027] = 5172,
  [7028] = 5313,
  [7029] = 5174,
  [7030] = 5099,
  [7031] = 5100,
  [7032] = 5101,
  [7033] = 5103,
  [7034] = 5104,
  [7035] = 5175,
  [7036] = 5106,
  [7037] = 5108,
  [7038] = 5109,
  [7039] = 5110,
  [7040] = 5111,
  [7041] = 5112,
  [7042] = 4275,
  [7043] = 5115,
  [7044] = 5116,
  [7045] = 5146,
  [7046] = 4185,
  [7047] = 4186,
  [7048] = 4187,
  [7049] = 4188,
  [7050] = 5179,
  [7051] = 5180,
  [7052] = 5181,
  [7053] = 5182,
  [7054] = 5183,
  [7055] = 5184,
  [7056] = 5185,
  [7057] = 5186,
  [7058] = 5147,
  [7059] = 5148,
  [7060] = 5149,
  [7061] = 5151,
  [7062] = 5152,
  [7063] = 5153,
  [7064] = 5154,
  [7065] = 5155,
  [7066] = 4277,
  [7067] = 4279,
  [7068] = 4190,
  [7069] = 4191,
  [7070] = 4192,
  [7071] = 4193,
  [7072] = 4194,
  [7073] = 4195,
  [7074] = 4196,
  [7075] = 4197,
  [7076] = 4198,
  [7077] = 4199,
  [7078] = 4200,
  [7079] = 4201,
  [7080] = 4202,
  [7081] = 4203,
  [7082] = 4204,
  [7083] = 4280,
  [7084] = 4206,
  [7085] = 4207,
  [7086] = 4208,
  [7087] = 4209,
  [7088] = 4210,
  [7089] = 5189,
  [7090] = 5190,
  [7091] = 4281,
  [7092] = 4282,
  [7093] = 4089,
  [7094] = 4291,
  [7095] = 4292,
  [7096] = 4293,
  [7097] = 4294,
  [7098] = 4289,
  [7099] = 4211,
  [7100] = 4212,
  [7101] = 4213,
  [7102] = 4214,
  [7103] = 4215,
  [7104] = 4216,
  [7105] = 4217,
  [7106] = 5091,
  [7107] = 2645,
  [7108] = 1822,
  [7109] = 1820,
  [7110] = 1835,
  [7111] = 2291,
  [7112] = 1800,
  [7113] = 2522,
  [7114] = 3640,
  [7115] = 3688,
  [7116] = 1826,
  [7117] = 2292,
  [7118] = 1799,
  [7119] = 2290,
  [7120] = 1856,
  [7121] = 1858,
  [7122] = 2310,
  [7123] = 1801,
  [7124] = 2293,
  [7125] = 7125,
  [7126] = 7126,
  [7127] = 3755,
  [7128] = 7128,
  [7129] = 3629,
  [7130] = 7130,
  [7131] = 7131,
  [7132] = 7132,
  [7133] = 3756,
  [7134] = 3623,
  [7135] = 7135,
  [7136] = 7136,
  [7137] = 3743,
  [7138] = 3751,
  [7139] = 1821,
  [7140] = 1824,
  [7141] = 7141,
  [7142] = 1801,
  [7143] = 7143,
  [7144] = 3757,
  [7145] = 1830,
  [7146] = 7146,
  [7147] = 3628,
  [7148] = 7148,
  [7149] = 3626,
  [7150] = 1816,
  [7151] = 1799,
  [7152] = 7152,
  [7153] = 7153,
  [7154] = 7154,
  [7155] = 4921,
  [7156] = 7156,
  [7157] = 1818,
  [7158] = 7158,
  [7159] = 7159,
  [7160] = 7160,
  [7161] = 7161,
  [7162] = 7162,
  [7163] = 3754,
  [7164] = 7164,
  [7165] = 1833,
  [7166] = 7166,
  [7167] = 7167,
  [7168] = 7168,
  [7169] = 1800,
  [7170] = 7170,
  [7171] = 7171,
  [7172] = 7172,
  [7173] = 7173,
  [7174] = 7174,
  [7175] = 4477,
  [7176] = 6682,
  [7177] = 7177,
  [7178] = 3753,
  [7179] = 4944,
  [7180] = 3752,
  [7181] = 1819,
  [7182] = 7182,
  [7183] = 3627,
  [7184] = 7184,
  [7185] = 1814,
  [7186] = 2292,
  [7187] = 7187,
  [7188] = 1845,
  [7189] = 1839,
  [7190] = 250,
  [7191] = 1840,
  [7192] = 2310,
  [7193] = 1853,
  [7194] = 7194,
  [7195] = 1843,
  [7196] = 7196,
  [7197] = 7197,
  [7198] = 1855,
  [7199] = 1860,
  [7200] = 7200,
  [7201] = 7201,
  [7202] = 7197,
  [7203] = 7201,
  [7204] = 1837,
  [7205] = 1844,
  [7206] = 7201,
  [7207] = 7196,
  [7208] = 1852,
  [7209] = 5272,
  [7210] = 1831,
  [7211] = 1849,
  [7212] = 7196,
  [7213] = 7197,
  [7214] = 1815,
  [7215] = 1841,
  [7216] = 7194,
  [7217] = 7194,
  [7218] = 1859,
  [7219] = 1854,
  [7220] = 3640,
  [7221] = 1838,
  [7222] = 5053,
  [7223] = 1790,
  [7224] = 7196,
  [7225] = 1836,
  [7226] = 1817,
  [7227] = 1823,
  [7228] = 1850,
  [7229] = 7229,
  [7230] = 3688,
  [7231] = 1851,
  [7232] = 7197,
  [7233] = 7229,
  [7234] = 1842,
  [7235] = 7235,
  [7236] = 7229,
  [7237] = 7187,
  [7238] = 7238,
  [7239] = 7187,
  [7240] = 7240,
  [7241] = 7235,
  [7242] = 7238,
  [7243] = 7200,
  [7244] = 1846,
  [7245] = 1824,
  [7246] = 1847,
  [7247] = 7240,
  [7248] = 7194,
  [7249] = 7240,
  [7250] = 1848,
  [7251] = 7229,
  [7252] = 2291,
  [7253] = 7187,
  [7254] = 7240,
  [7255] = 7201,
  [7256] = 7194,
  [7257] = 7235,
  [7258] = 7238,
  [7259] = 7200,
  [7260] = 7235,
  [7261] = 7238,
  [7262] = 7196,
  [7263] = 7235,
  [7264] = 1857,
  [7265] = 7238,
  [7266] = 7197,
  [7267] = 7201,
  [7268] = 7200,
  [7269] = 2293,
  [7270] = 3756,
  [7271] = 5335,
  [7272] = 3751,
  [7273] = 4933,
  [7274] = 4917,
  [7275] = 3752,
  [7276] = 7276,
  [7277] = 3743,
  [7278] = 3753,
  [7279] = 3757,
  [7280] = 3754,
  [7281] = 3755,
  [7282] = 5170,
  [7283] = 4235,
  [7284] = 5265,
  [7285] = 4290,
  [7286] = 4104,
  [7287] = 4105,
  [7288] = 4110,
  [7289] = 4122,
  [7290] = 4123,
  [7291] = 4219,
  [7292] = 4220,
  [7293] = 4223,
  [7294] = 4225,
  [7295] = 4226,
  [7296] = 4252,
  [7297] = 4253,
  [7298] = 4254,
  [7299] = 4255,
  [7300] = 4274,
  [7301] = 4289,
  [7302] = 4091,
  [7303] = 4092,
  [7304] = 4093,
  [7305] = 4094,
  [7306] = 4095,
  [7307] = 4096,
  [7308] = 4097,
  [7309] = 4098,
  [7310] = 4099,
  [7311] = 4100,
  [7312] = 4101,
  [7313] = 4102,
  [7314] = 4298,
  [7315] = 4106,
  [7316] = 4113,
  [7317] = 4114,
  [7318] = 4115,
  [7319] = 4116,
  [7320] = 4117,
  [7321] = 4118,
  [7322] = 4119,
  [7323] = 4120,
  [7324] = 4124,
  [7325] = 4125,
  [7326] = 4126,
  [7327] = 4127,
  [7328] = 4128,
  [7329] = 4129,
  [7330] = 4130,
  [7331] = 4131,
  [7332] = 4132,
  [7333] = 4133,
  [7334] = 4134,
  [7335] = 4135,
  [7336] = 4136,
  [7337] = 4137,
  [7338] = 4138,
  [7339] = 4140,
  [7340] = 4141,
  [7341] = 4142,
  [7342] = 4143,
  [7343] = 4144,
  [7344] = 4156,
  [7345] = 4157,
  [7346] = 4158,
  [7347] = 4159,
  [7348] = 4160,
  [7349] = 4161,
  [7350] = 4162,
  [7351] = 4163,
  [7352] = 4164,
  [7353] = 4165,
  [7354] = 4166,
  [7355] = 4167,
  [7356] = 4168,
  [7357] = 4169,
  [7358] = 4170,
  [7359] = 4171,
  [7360] = 4172,
  [7361] = 4173,
  [7362] = 4174,
  [7363] = 4175,
  [7364] = 4176,
  [7365] = 4177,
  [7366] = 4178,
  [7367] = 4179,
  [7368] = 4180,
  [7369] = 4181,
  [7370] = 4182,
  [7371] = 4183,
  [7372] = 4184,
  [7373] = 4185,
  [7374] = 4186,
  [7375] = 4187,
  [7376] = 4188,
  [7377] = 4190,
  [7378] = 4191,
  [7379] = 4192,
  [7380] = 4193,
  [7381] = 4194,
  [7382] = 4195,
  [7383] = 4196,
  [7384] = 4197,
  [7385] = 4198,
  [7386] = 4199,
  [7387] = 4200,
  [7388] = 4201,
  [7389] = 4202,
  [7390] = 4203,
  [7391] = 4204,
  [7392] = 4205,
  [7393] = 4206,
  [7394] = 4207,
  [7395] = 4208,
  [7396] = 4209,
  [7397] = 4210,
  [7398] = 4211,
  [7399] = 4212,
  [7400] = 4213,
  [7401] = 4214,
  [7402] = 4215,
  [7403] = 4216,
  [7404] = 4217,
  [7405] = 4218,
  [7406] = 4107,
  [7407] = 5009,
  [7408] = 4121,
  [7409] = 5331,
  [7410] = 4003,
  [7411] = 5352,
  [7412] = 7412,
  [7413] = 4005,
  [7414] = 4006,
  [7415] = 4007,
  [7416] = 4008,
  [7417] = 1776,
  [7418] = 4017,
  [7419] = 4018,
  [7420] = 4019,
  [7421] = 4020,
  [7422] = 4022,
  [7423] = 4023,
  [7424] = 4291,
  [7425] = 4038,
  [7426] = 4039,
  [7427] = 4040,
  [7428] = 4041,
  [7429] = 4042,
  [7430] = 4043,
  [7431] = 4048,
  [7432] = 4049,
  [7433] = 4050,
  [7434] = 4051,
  [7435] = 4052,
  [7436] = 1774,
  [7437] = 3983,
  [7438] = 3984,
  [7439] = 1799,
  [7440] = 4103,
  [7441] = 7441,
  [7442] = 4271,
  [7443] = 5272,
  [7444] = 5053,
  [7445] = 2633,
  [7446] = 4108,
  [7447] = 1800,
  [7448] = 1801,
  [7449] = 7449,
  [7450] = 1771,
  [7451] = 5261,
  [7452] = 4003,
  [7453] = 7453,
  [7454] = 4005,
  [7455] = 4006,
  [7456] = 4007,
  [7457] = 4008,
  [7458] = 4017,
  [7459] = 4018,
  [7460] = 4019,
  [7461] = 4020,
  [7462] = 4022,
  [7463] = 4023,
  [7464] = 4038,
  [7465] = 4039,
  [7466] = 4040,
  [7467] = 4041,
  [7468] = 4042,
  [7469] = 4043,
  [7470] = 4048,
  [7471] = 4049,
  [7472] = 4050,
  [7473] = 4051,
  [7474] = 4052,
  [7475] = 3983,
  [7476] = 3984,
  [7477] = 5262,
  [7478] = 2554,
  [7479] = 2555,
  [7480] = 2556,
  [7481] = 2557,
  [7482] = 2558,
  [7483] = 2559,
  [7484] = 2561,
  [7485] = 2562,
  [7486] = 2563,
  [7487] = 2564,
  [7488] = 2565,
  [7489] = 2566,
  [7490] = 2567,
  [7491] = 2568,
  [7492] = 2569,
  [7493] = 2570,
  [7494] = 2571,
  [7495] = 2572,
  [7496] = 2573,
  [7497] = 2574,
  [7498] = 2575,
  [7499] = 2576,
  [7500] = 2577,
  [7501] = 7501,
  [7502] = 1832,
  [7503] = 2554,
  [7504] = 2555,
  [7505] = 2556,
  [7506] = 2557,
  [7507] = 2558,
  [7508] = 2559,
  [7509] = 2561,
  [7510] = 2562,
  [7511] = 2563,
  [7512] = 2564,
  [7513] = 2565,
  [7514] = 2566,
  [7515] = 2567,
  [7516] = 2568,
  [7517] = 2569,
  [7518] = 2570,
  [7519] = 2571,
  [7520] = 2572,
  [7521] = 2573,
  [7522] = 2574,
  [7523] = 2575,
  [7524] = 2576,
  [7525] = 2577,
  [7526] = 2258,
  [7527] = 7527,
  [7528] = 7528,
  [7529] = 7529,
  [7530] = 1784,
  [7531] = 7531,
  [7532] = 4139,
  [7533] = 7533,
  [7534] = 1786,
  [7535] = 1773,
  [7536] = 1787,
  [7537] = 1788,
  [7538] = 1772,
  [7539] = 1791,
  [7540] = 1813,
  [7541] = 1793,
  [7542] = 1794,
  [7543] = 1795,
  [7544] = 1802,
  [7545] = 1803,
  [7546] = 1804,
  [7547] = 1807,
  [7548] = 1789,
  [7549] = 1792,
  [7550] = 1798,
  [7551] = 1811,
  [7552] = 1777,
  [7553] = 1778,
  [7554] = 7554,
  [7555] = 7555,
  [7556] = 4145,
  [7557] = 7557,
  [7558] = 7558,
  [7559] = 7559,
  [7560] = 7560,
  [7561] = 7561,
  [7562] = 7562,
  [7563] = 4154,
  [7564] = 7557,
  [7565] = 7529,
  [7566] = 7531,
  [7567] = 7567,
  [7568] = 7557,
  [7569] = 7558,
  [7570] = 7559,
  [7571] = 7560,
  [7572] = 7529,
  [7573] = 7531,
  [7574] = 7574,
  [7575] = 7557,
  [7576] = 7558,
  [7577] = 7559,
  [7578] = 7560,
  [7579] = 7529,
  [7580] = 7531,
  [7581] = 7557,
  [7582] = 7558,
  [7583] = 7559,
  [7584] = 7560,
  [7585] = 1809,
  [7586] = 7586,
  [7587] = 4221,
  [7588] = 1785,
  [7589] = 5157,
  [7590] = 5158,
  [7591] = 5159,
  [7592] = 5161,
  [7593] = 5162,
  [7594] = 5163,
  [7595] = 5164,
  [7596] = 5165,
  [7597] = 5166,
  [7598] = 5167,
  [7599] = 4294,
  [7600] = 5171,
  [7601] = 5172,
  [7602] = 5313,
  [7603] = 5174,
  [7604] = 5175,
  [7605] = 5187,
  [7606] = 5188,
  [7607] = 7558,
  [7608] = 7559,
  [7609] = 5217,
  [7610] = 5218,
  [7611] = 5219,
  [7612] = 5228,
  [7613] = 5230,
  [7614] = 5231,
  [7615] = 5232,
  [7616] = 5241,
  [7617] = 5242,
  [7618] = 5243,
  [7619] = 5244,
  [7620] = 5252,
  [7621] = 5253,
  [7622] = 5254,
  [7623] = 5255,
  [7624] = 5266,
  [7625] = 5267,
  [7626] = 5268,
  [7627] = 5270,
  [7628] = 5271,
  [7629] = 5273,
  [7630] = 5274,
  [7631] = 5275,
  [7632] = 5276,
  [7633] = 5278,
  [7634] = 5280,
  [7635] = 5281,
  [7636] = 5287,
  [7637] = 5297,
  [7638] = 5298,
  [7639] = 5213,
  [7640] = 5055,
  [7641] = 5133,
  [7642] = 5156,
  [7643] = 5208,
  [7644] = 5209,
  [7645] = 5210,
  [7646] = 5211,
  [7647] = 5220,
  [7648] = 5229,
  [7649] = 5269,
  [7650] = 5285,
  [7651] = 5299,
  [7652] = 5301,
  [7653] = 4983,
  [7654] = 4984,
  [7655] = 4985,
  [7656] = 4986,
  [7657] = 5034,
  [7658] = 5036,
  [7659] = 5037,
  [7660] = 5042,
  [7661] = 5044,
  [7662] = 5048,
  [7663] = 5049,
  [7664] = 7529,
  [7665] = 1796,
  [7666] = 5088,
  [7667] = 5099,
  [7668] = 5100,
  [7669] = 5101,
  [7670] = 5103,
  [7671] = 5104,
  [7672] = 5106,
  [7673] = 5108,
  [7674] = 5109,
  [7675] = 5110,
  [7676] = 5111,
  [7677] = 5112,
  [7678] = 5115,
  [7679] = 5116,
  [7680] = 5146,
  [7681] = 5147,
  [7682] = 5148,
  [7683] = 5149,
  [7684] = 5151,
  [7685] = 5152,
  [7686] = 5153,
  [7687] = 5154,
  [7688] = 5155,
  [7689] = 5191,
  [7690] = 5192,
  [7691] = 5193,
  [7692] = 5194,
  [7693] = 5195,
  [7694] = 5196,
  [7695] = 5197,
  [7696] = 5198,
  [7697] = 5199,
  [7698] = 5200,
  [7699] = 5201,
  [7700] = 5202,
  [7701] = 5203,
  [7702] = 5204,
  [7703] = 5205,
  [7704] = 5206,
  [7705] = 5207,
  [7706] = 5277,
  [7707] = 5279,
  [7708] = 5282,
  [7709] = 5283,
  [7710] = 5284,
  [7711] = 5286,
  [7712] = 5288,
  [7713] = 5289,
  [7714] = 5290,
  [7715] = 5291,
  [7716] = 5292,
  [7717] = 5293,
  [7718] = 5294,
  [7719] = 5295,
  [7720] = 5296,
  [7721] = 5303,
  [7722] = 5304,
  [7723] = 5305,
  [7724] = 5306,
  [7725] = 5307,
  [7726] = 5308,
  [7727] = 5309,
  [7728] = 5310,
  [7729] = 5311,
  [7730] = 5312,
  [7731] = 5173,
  [7732] = 4973,
  [7733] = 4974,
  [7734] = 4975,
  [7735] = 4976,
  [7736] = 4977,
  [7737] = 4978,
  [7738] = 4979,
  [7739] = 4980,
  [7740] = 4981,
  [7741] = 4982,
  [7742] = 5316,
  [7743] = 4988,
  [7744] = 4989,
  [7745] = 4990,
  [7746] = 4991,
  [7747] = 4992,
  [7748] = 4993,
  [7749] = 4994,
  [7750] = 4995,
  [7751] = 4996,
  [7752] = 4997,
  [7753] = 4998,
  [7754] = 4999,
  [7755] = 5000,
  [7756] = 5001,
  [7757] = 5002,
  [7758] = 5003,
  [7759] = 5004,
  [7760] = 5005,
  [7761] = 5006,
  [7762] = 5010,
  [7763] = 5011,
  [7764] = 5012,
  [7765] = 5013,
  [7766] = 5014,
  [7767] = 5015,
  [7768] = 5016,
  [7769] = 5017,
  [7770] = 5018,
  [7771] = 5019,
  [7772] = 5020,
  [7773] = 5021,
  [7774] = 1797,
  [7775] = 5022,
  [7776] = 5023,
  [7777] = 5024,
  [7778] = 5025,
  [7779] = 5026,
  [7780] = 5027,
  [7781] = 5028,
  [7782] = 5029,
  [7783] = 5030,
  [7784] = 5031,
  [7785] = 5032,
  [7786] = 5033,
  [7787] = 5035,
  [7788] = 5038,
  [7789] = 5039,
  [7790] = 5040,
  [7791] = 5041,
  [7792] = 5043,
  [7793] = 5045,
  [7794] = 5046,
  [7795] = 5047,
  [7796] = 5050,
  [7797] = 5051,
  [7798] = 5052,
  [7799] = 5057,
  [7800] = 5058,
  [7801] = 5059,
  [7802] = 5060,
  [7803] = 5061,
  [7804] = 5062,
  [7805] = 5063,
  [7806] = 5064,
  [7807] = 5065,
  [7808] = 5066,
  [7809] = 5067,
  [7810] = 5068,
  [7811] = 5069,
  [7812] = 5070,
  [7813] = 5071,
  [7814] = 5072,
  [7815] = 5073,
  [7816] = 5074,
  [7817] = 5075,
  [7818] = 5076,
  [7819] = 5078,
  [7820] = 5079,
  [7821] = 5080,
  [7822] = 5081,
  [7823] = 5082,
  [7824] = 5083,
  [7825] = 5084,
  [7826] = 5085,
  [7827] = 5086,
  [7828] = 5089,
  [7829] = 5090,
  [7830] = 5091,
  [7831] = 5092,
  [7832] = 4972,
  [7833] = 5093,
  [7834] = 5094,
  [7835] = 5095,
  [7836] = 5113,
  [7837] = 5114,
  [7838] = 5117,
  [7839] = 5118,
  [7840] = 5119,
  [7841] = 5120,
  [7842] = 5121,
  [7843] = 5122,
  [7844] = 5123,
  [7845] = 5124,
  [7846] = 5125,
  [7847] = 5126,
  [7848] = 5127,
  [7849] = 5128,
  [7850] = 5129,
  [7851] = 5130,
  [7852] = 5131,
  [7853] = 5132,
  [7854] = 5134,
  [7855] = 5135,
  [7856] = 5136,
  [7857] = 5137,
  [7858] = 5138,
  [7859] = 5139,
  [7860] = 5140,
  [7861] = 5141,
  [7862] = 5142,
  [7863] = 5143,
  [7864] = 5144,
  [7865] = 5145,
  [7866] = 5168,
  [7867] = 5169,
  [7868] = 5176,
  [7869] = 5177,
  [7870] = 5179,
  [7871] = 5180,
  [7872] = 5181,
  [7873] = 5182,
  [7874] = 5183,
  [7875] = 5184,
  [7876] = 5185,
  [7877] = 5186,
  [7878] = 5189,
  [7879] = 5190,
  [7880] = 7531,
  [7881] = 4011,
  [7882] = 1775,
  [7883] = 4024,
  [7884] = 4025,
  [7885] = 4292,
  [7886] = 4026,
  [7887] = 4027,
  [7888] = 5225,
  [7889] = 5351,
  [7890] = 4028,
  [7891] = 4029,
  [7892] = 4032,
  [7893] = 4034,
  [7894] = 5239,
  [7895] = 4046,
  [7896] = 4047,
  [7897] = 3982,
  [7898] = 3991,
  [7899] = 1783,
  [7900] = 7560,
  [7901] = 5340,
  [7902] = 5215,
  [7903] = 5216,
  [7904] = 4224,
  [7905] = 5348,
  [7906] = 4233,
  [7907] = 5227,
  [7908] = 4227,
  [7909] = 4229,
  [7910] = 4230,
  [7911] = 4231,
  [7912] = 4232,
  [7913] = 4234,
  [7914] = 5240,
  [7915] = 4256,
  [7916] = 4257,
  [7917] = 4258,
  [7918] = 4259,
  [7919] = 4260,
  [7920] = 4261,
  [7921] = 4262,
  [7922] = 4263,
  [7923] = 4264,
  [7924] = 4265,
  [7925] = 4267,
  [7926] = 4272,
  [7927] = 4273,
  [7928] = 5251,
  [7929] = 4275,
  [7930] = 4277,
  [7931] = 4279,
  [7932] = 4280,
  [7933] = 4281,
  [7934] = 4282,
  [7935] = 4089,
  [7936] = 4293,
  [7937] = 1784,
  [7938] = 5373,
  [7939] = 5376,
  [7940] = 5393,
  [7941] = 5407,
  [7942] = 5414,
  [7943] = 5379,
  [7944] = 5362,
  [7945] = 5364,
  [7946] = 5365,
  [7947] = 7947,
  [7948] = 5366,
  [7949] = 7949,
  [7950] = 5369,
  [7951] = 7951,
  [7952] = 7947,
  [7953] = 5399,
  [7954] = 7954,
  [7955] = 5405,
  [7956] = 5357,
  [7957] = 5387,
  [7958] = 5394,
  [7959] = 5356,
  [7960] = 5363,
  [7961] = 7961,
  [7962] = 7947,
  [7963] = 5400,
  [7964] = 5359,
  [7965] = 5360,
  [7966] = 5370,
  [7967] = 7961,
  [7968] = 5390,
  [7969] = 1771,
  [7970] = 2258,
  [7971] = 7971,
  [7972] = 7947,
  [7973] = 5397,
  [7974] = 5391,
  [7975] = 5401,
  [7976] = 5395,
  [7977] = 7947,
  [7978] = 5403,
  [7979] = 7947,
  [7980] = 7947,
  [7981] = 7947,
  [7982] = 7947,
  [7983] = 5404,
  [7984] = 7984,
  [7985] = 7984,
  [7986] = 5381,
  [7987] = 5402,
  [7988] = 5411,
  [7989] = 7989,
  [7990] = 7947,
  [7991] = 5415,
  [7992] = 7971,
  [7993] = 7954,
  [7994] = 7961,
  [7995] = 7984,
  [7996] = 5382,
  [7997] = 1796,
  [7998] = 7998,
  [7999] = 5383,
  [8000] = 5375,
  [8001] = 7971,
  [8002] = 1797,
  [8003] = 5335,
  [8004] = 5384,
  [8005] = 1775,
  [8006] = 5385,
  [8007] = 7984,
  [8008] = 1783,
  [8009] = 5386,
  [8010] = 5408,
  [8011] = 5409,
  [8012] = 5353,
  [8013] = 5355,
  [8014] = 5361,
  [8015] = 8015,
  [8016] = 5398,
  [8017] = 5378,
  [8018] = 5380,
  [8019] = 5392,
  [8020] = 5396,
  [8021] = 5367,
  [8022] = 5368,
  [8023] = 5372,
  [8024] = 7971,
  [8025] = 7954,
  [8026] = 7954,
  [8027] = 8027,
  [8028] = 7961,
  [8029] = 1824,
  [8030] = 8030,
  [8031] = 8031,
  [8032] = 8032,
  [8033] = 8031,
  [8034] = 1817,
  [8035] = 8035,
  [8036] = 8036,
  [8037] = 8037,
  [8038] = 8038,
  [8039] = 8039,
  [8040] = 8040,
  [8041] = 8041,
  [8042] = 1823,
  [8043] = 1815,
  [8044] = 8044,
  [8045] = 1816,
  [8046] = 8046,
  [8047] = 8036,
  [8048] = 8036,
  [8049] = 8049,
  [8050] = 8050,
  [8051] = 8032,
  [8052] = 8031,
  [8053] = 8032,
  [8054] = 8054,
  [8055] = 8055,
  [8056] = 8056,
  [8057] = 8057,
  [8058] = 8036,
  [8059] = 8059,
  [8060] = 8060,
  [8061] = 1814,
  [8062] = 1782,
  [8063] = 8063,
  [8064] = 8064,
  [8065] = 3420,
  [8066] = 8066,
  [8067] = 8064,
  [8068] = 1825,
  [8069] = 8069,
  [8070] = 8032,
  [8071] = 8031,
  [8072] = 8063,
  [8073] = 8073,
  [8074] = 8074,
  [8075] = 1779,
  [8076] = 8066,
  [8077] = 8077,
  [8078] = 8078,
  [8079] = 8079,
  [8080] = 8080,
  [8081] = 8081,
  [8082] = 8082,
  [8083] = 8032,
  [8084] = 8031,
  [8085] = 8036,
  [8086] = 8036,
  [8087] = 1780,
  [8088] = 8032,
  [8089] = 8031,
  [8090] = 8032,
  [8091] = 8036,
  [8092] = 8032,
  [8093] = 8093,
  [8094] = 8031,
  [8095] = 8054,
  [8096] = 8057,
  [8097] = 1781,
  [8098] = 8098,
  [8099] = 8054,
  [8100] = 8057,
  [8101] = 8036,
  [8102] = 8063,
  [8103] = 8032,
  [8104] = 8031,
  [8105] = 8055,
  [8106] = 8066,
  [8107] = 8031,
  [8108] = 8031,
  [8109] = 8036,
  [8110] = 8064,
  [8111] = 8032,
  [8112] = 8036,
  [8113] = 1845,
  [8114] = 8114,
  [8115] = 8115,
  [8116] = 8116,
  [8117] = 8117,
  [8118] = 8118,
  [8119] = 8119,
  [8120] = 1825,
  [8121] = 8121,
  [8122] = 1830,
  [8123] = 1800,
  [8124] = 1801,
  [8125] = 1799,
  [8126] = 8126,
  [8127] = 8127,
  [8128] = 1855,
  [8129] = 1856,
  [8130] = 1858,
  [8131] = 1835,
  [8132] = 1836,
  [8133] = 1844,
  [8134] = 1852,
  [8135] = 1839,
  [8136] = 8136,
  [8137] = 1842,
  [8138] = 8138,
  [8139] = 8139,
  [8140] = 1843,
  [8141] = 1846,
  [8142] = 1847,
  [8143] = 1848,
  [8144] = 1849,
  [8145] = 1850,
  [8146] = 1851,
  [8147] = 8147,
  [8148] = 1853,
  [8149] = 1824,
  [8150] = 3420,
  [8151] = 8151,
  [8152] = 4043,
  [8153] = 2290,
  [8154] = 8154,
  [8155] = 8155,
  [8156] = 3991,
  [8157] = 8157,
  [8158] = 2293,
  [8159] = 2291,
  [8160] = 2292,
  [8161] = 3982,
  [8162] = 2554,
  [8163] = 2555,
  [8164] = 2556,
  [8165] = 2557,
  [8166] = 2558,
  [8167] = 2559,
  [8168] = 2561,
  [8169] = 2562,
  [8170] = 2563,
  [8171] = 2564,
  [8172] = 2565,
  [8173] = 2566,
  [8174] = 2567,
  [8175] = 2568,
  [8176] = 2569,
  [8177] = 2570,
  [8178] = 2571,
  [8179] = 2572,
  [8180] = 2573,
  [8181] = 2574,
  [8182] = 2575,
  [8183] = 2576,
  [8184] = 2577,
  [8185] = 8185,
  [8186] = 4003,
  [8187] = 2258,
  [8188] = 4005,
  [8189] = 4006,
  [8190] = 4007,
  [8191] = 4008,
  [8192] = 4017,
  [8193] = 4018,
  [8194] = 4047,
  [8195] = 4020,
  [8196] = 8196,
  [8197] = 4022,
  [8198] = 4023,
  [8199] = 4038,
  [8200] = 4039,
  [8201] = 8201,
  [8202] = 4040,
  [8203] = 4041,
  [8204] = 4042,
  [8205] = 4048,
  [8206] = 4049,
  [8207] = 4050,
  [8208] = 4051,
  [8209] = 4052,
  [8210] = 3983,
  [8211] = 3984,
  [8212] = 8212,
  [8213] = 8213,
  [8214] = 8214,
  [8215] = 8185,
  [8216] = 8185,
  [8217] = 8185,
  [8218] = 8185,
  [8219] = 8185,
  [8220] = 8220,
  [8221] = 4011,
  [8222] = 4024,
  [8223] = 4025,
  [8224] = 8224,
  [8225] = 8225,
  [8226] = 4026,
  [8227] = 4027,
  [8228] = 8228,
  [8229] = 6875,
  [8230] = 4028,
  [8231] = 4029,
  [8232] = 4032,
  [8233] = 4034,
  [8234] = 8234,
  [8235] = 4046,
  [8236] = 4019,
  [8237] = 8237,
  [8238] = 1790,
  [8239] = 1825,
  [8240] = 8240,
  [8241] = 1782,
  [8242] = 8242,
  [8243] = 2310,
  [8244] = 1781,
  [8245] = 8245,
  [8246] = 1779,
  [8247] = 1780,
  [8248] = 2291,
  [8249] = 1784,
  [8250] = 1774,
  [8251] = 2290,
  [8252] = 2310,
  [8253] = 2292,
  [8254] = 1785,
  [8255] = 1830,
  [8256] = 1826,
  [8257] = 1796,
  [8258] = 1797,
  [8259] = 1786,
  [8260] = 1776,
  [8261] = 1773,
  [8262] = 1787,
  [8263] = 1788,
  [8264] = 1772,
  [8265] = 1791,
  [8266] = 1813,
  [8267] = 1793,
  [8268] = 8268,
  [8269] = 1795,
  [8270] = 1802,
  [8271] = 1803,
  [8272] = 1804,
  [8273] = 1807,
  [8274] = 1789,
  [8275] = 1792,
  [8276] = 1798,
  [8277] = 1811,
  [8278] = 1777,
  [8279] = 1778,
  [8280] = 1775,
  [8281] = 1822,
  [8282] = 1783,
  [8283] = 1820,
  [8284] = 1809,
  [8285] = 8285,
  [8286] = 1831,
  [8287] = 2293,
  [8288] = 2331,
  [8289] = 1794,
  [8290] = 6510,
  [8291] = 8291,
  [8292] = 8292,
  [8293] = 8293,
  [8294] = 8294,
  [8295] = 8295,
  [8296] = 8296,
  [8297] = 1815,
  [8298] = 8298,
  [8299] = 8299,
  [8300] = 8300,
  [8301] = 5352,
  [8302] = 1821,
  [8303] = 1817,
  [8304] = 6485,
  [8305] = 8305,
  [8306] = 8306,
  [8307] = 1816,
  [8308] = 8308,
  [8309] = 5348,
  [8310] = 8310,
  [8311] = 8311,
  [8312] = 1818,
  [8313] = 8313,
  [8314] = 8314,
  [8315] = 2258,
  [8316] = 6513,
  [8317] = 2302,
  [8318] = 8318,
  [8319] = 8319,
  [8320] = 1833,
  [8321] = 3629,
  [8322] = 5351,
  [8323] = 8323,
  [8324] = 8324,
  [8325] = 3623,
  [8326] = 1819,
  [8327] = 1832,
  [8328] = 8328,
  [8329] = 8329,
  [8330] = 8330,
  [8331] = 8331,
  [8332] = 8332,
  [8333] = 8333,
  [8334] = 3628,
  [8335] = 3626,
  [8336] = 1790,
  [8337] = 8337,
  [8338] = 1814,
  [8339] = 3627,
  [8340] = 8340,
  [8341] = 1823,
  [8342] = 5340,
  [8343] = 5347,
  [8344] = 6480,
  [8345] = 6506,
  [8346] = 8346,
  [8347] = 8347,
  [8348] = 8348,
  [8349] = 5331,
  [8350] = 5415,
  [8351] = 8351,
  [8352] = 8352,
  [8353] = 8353,
  [8354] = 8354,
  [8355] = 8355,
  [8356] = 5387,
  [8357] = 5394,
  [8358] = 5356,
  [8359] = 8359,
  [8360] = 1859,
  [8361] = 8361,
  [8362] = 1860,
  [8363] = 5363,
  [8364] = 8364,
  [8365] = 8365,
  [8366] = 8366,
  [8367] = 8367,
  [8368] = 8368,
  [8369] = 8369,
  [8370] = 8228,
  [8371] = 5401,
  [8372] = 8353,
  [8373] = 8373,
  [8374] = 8374,
  [8375] = 8375,
  [8376] = 1853,
  [8377] = 1855,
  [8378] = 1856,
  [8379] = 1858,
  [8380] = 1835,
  [8381] = 1836,
  [8382] = 8201,
  [8383] = 8383,
  [8384] = 8352,
  [8385] = 1844,
  [8386] = 8354,
  [8387] = 6551,
  [8388] = 1845,
  [8389] = 8389,
  [8390] = 1852,
  [8391] = 8391,
  [8392] = 1839,
  [8393] = 1842,
  [8394] = 1843,
  [8395] = 1846,
  [8396] = 1847,
  [8397] = 1848,
  [8398] = 1849,
  [8399] = 1850,
  [8400] = 1851,
  [8401] = 8401,
  [8402] = 8402,
  [8403] = 8403,
  [8404] = 8404,
  [8405] = 5393,
  [8406] = 8353,
  [8407] = 5407,
  [8408] = 5414,
  [8409] = 5379,
  [8410] = 8410,
  [8411] = 8411,
  [8412] = 8351,
  [8413] = 8355,
  [8414] = 8364,
  [8415] = 8415,
  [8416] = 2522,
  [8417] = 5362,
  [8418] = 5364,
  [8419] = 8419,
  [8420] = 8420,
  [8421] = 5400,
  [8422] = 5359,
  [8423] = 5360,
  [8424] = 5370,
  [8425] = 5408,
  [8426] = 5365,
  [8427] = 3420,
  [8428] = 5409,
  [8429] = 5366,
  [8430] = 8391,
  [8431] = 8401,
  [8432] = 5369,
  [8433] = 8410,
  [8434] = 1796,
  [8435] = 1797,
  [8436] = 1775,
  [8437] = 8374,
  [8438] = 1783,
  [8439] = 8352,
  [8440] = 8440,
  [8441] = 8353,
  [8442] = 8383,
  [8443] = 8389,
  [8444] = 8402,
  [8445] = 8403,
  [8446] = 8415,
  [8447] = 8374,
  [8448] = 1841,
  [8449] = 5403,
  [8450] = 8383,
  [8451] = 8389,
  [8452] = 1854,
  [8453] = 1840,
  [8454] = 1786,
  [8455] = 1773,
  [8456] = 1774,
  [8457] = 1787,
  [8458] = 8404,
  [8459] = 1788,
  [8460] = 1772,
  [8461] = 1791,
  [8462] = 1813,
  [8463] = 1793,
  [8464] = 1794,
  [8465] = 1795,
  [8466] = 1802,
  [8467] = 1803,
  [8468] = 1804,
  [8469] = 1807,
  [8470] = 1789,
  [8471] = 1792,
  [8472] = 1798,
  [8473] = 1811,
  [8474] = 1777,
  [8475] = 1778,
  [8476] = 5382,
  [8477] = 5383,
  [8478] = 5384,
  [8479] = 5385,
  [8480] = 5386,
  [8481] = 8352,
  [8482] = 8415,
  [8483] = 5404,
  [8484] = 1831,
  [8485] = 1784,
  [8486] = 8440,
  [8487] = 5357,
  [8488] = 5391,
  [8489] = 1809,
  [8490] = 1785,
  [8491] = 5395,
  [8492] = 8492,
  [8493] = 8493,
  [8494] = 8494,
  [8495] = 8495,
  [8496] = 8496,
  [8497] = 8419,
  [8498] = 1838,
  [8499] = 8420,
  [8500] = 5378,
  [8501] = 5380,
  [8502] = 5392,
  [8503] = 5396,
  [8504] = 5381,
  [8505] = 5353,
  [8506] = 5355,
  [8507] = 8440,
  [8508] = 5361,
  [8509] = 8352,
  [8510] = 5367,
  [8511] = 8440,
  [8512] = 5368,
  [8513] = 5372,
  [8514] = 5373,
  [8515] = 1857,
  [8516] = 5376,
  [8517] = 1837,
  [8518] = 5399,
  [8519] = 8374,
  [8520] = 8383,
  [8521] = 8389,
  [8522] = 8354,
  [8523] = 8440,
  [8524] = 8524,
  [8525] = 8391,
  [8526] = 8401,
  [8527] = 8402,
  [8528] = 8403,
  [8529] = 8404,
  [8530] = 8374,
  [8531] = 8383,
  [8532] = 8389,
  [8533] = 8415,
  [8534] = 5405,
  [8535] = 8419,
  [8536] = 8420,
  [8537] = 8419,
  [8538] = 8420,
  [8539] = 1776,
  [8540] = 5390,
  [8541] = 1805,
  [8542] = 8542,
  [8543] = 8374,
  [8544] = 1806,
  [8545] = 8383,
  [8546] = 8389,
  [8547] = 1808,
  [8548] = 1810,
  [8549] = 8410,
  [8550] = 1812,
  [8551] = 8411,
  [8552] = 8415,
  [8553] = 8419,
  [8554] = 8420,
  [8555] = 8351,
  [8556] = 8355,
  [8557] = 8542,
  [8558] = 8364,
  [8559] = 8373,
  [8560] = 8367,
  [8561] = 8368,
  [8562] = 8493,
  [8563] = 8494,
  [8564] = 8542,
  [8565] = 8373,
  [8566] = 8367,
  [8567] = 8368,
  [8568] = 8493,
  [8569] = 8494,
  [8570] = 8542,
  [8571] = 8373,
  [8572] = 8367,
  [8573] = 8368,
  [8574] = 8493,
  [8575] = 8494,
  [8576] = 8542,
  [8577] = 8367,
  [8578] = 8368,
  [8579] = 8493,
  [8580] = 8494,
  [8581] = 8542,
  [8582] = 8367,
  [8583] = 8368,
  [8584] = 8493,
  [8585] = 8494,
  [8586] = 8586,
  [8587] = 8361,
  [8588] = 8365,
  [8589] = 8369,
  [8590] = 8492,
  [8591] = 8495,
  [8592] = 8496,
  [8593] = 8593,
  [8594] = 8586,
  [8595] = 8361,
  [8596] = 8365,
  [8597] = 8369,
  [8598] = 8492,
  [8599] = 8495,
  [8600] = 8496,
  [8601] = 8593,
  [8602] = 8586,
  [8603] = 8361,
  [8604] = 8365,
  [8605] = 8369,
  [8606] = 8492,
  [8607] = 8495,
  [8608] = 8496,
  [8609] = 8593,
  [8610] = 5411,
  [8611] = 5397,
  [8612] = 8415,
  [8613] = 8586,
  [8614] = 8593,
  [8615] = 5272,
  [8616] = 5375,
  [8617] = 5053,
  [8618] = 8419,
  [8619] = 8420,
  [8620] = 8411,
  [8621] = 5398,
  [8622] = 8622,
  [8623] = 8623,
  [8624] = 8624,
  [8625] = 8625,
  [8626] = 8626,
  [8627] = 8624,
  [8628] = 1825,
  [8629] = 8626,
  [8630] = 8630,
  [8631] = 8631,
  [8632] = 8624,
  [8633] = 8633,
  [8634] = 8634,
  [8635] = 1832,
  [8636] = 8636,
  [8637] = 8637,
  [8638] = 8624,
  [8639] = 8637,
  [8640] = 8640,
  [8641] = 8626,
  [8642] = 8626,
  [8643] = 8626,
  [8644] = 8644,
  [8645] = 8636,
  [8646] = 8631,
  [8647] = 8624,
  [8648] = 8630,
  [8649] = 8637,
  [8650] = 8631,
  [8651] = 8640,
  [8652] = 8652,
  [8653] = 8636,
  [8654] = 8631,
  [8655] = 2290,
  [8656] = 2291,
  [8657] = 2310,
  [8658] = 2293,
  [8659] = 2292,
  [8660] = 8624,
  [8661] = 8661,
  [8662] = 8640,
  [8663] = 8663,
  [8664] = 8626,
  [8665] = 8636,
  [8666] = 8631,
  [8667] = 8630,
  [8668] = 8626,
  [8669] = 8624,
  [8670] = 8631,
  [8671] = 8671,
  [8672] = 8631,
  [8673] = 8673,
  [8674] = 3640,
  [8675] = 8675,
  [8676] = 8634,
  [8677] = 8631,
  [8678] = 8624,
  [8679] = 8640,
  [8680] = 8680,
  [8681] = 8630,
  [8682] = 8626,
  [8683] = 8637,
  [8684] = 8684,
  [8685] = 8685,
  [8686] = 8686,
  [8687] = 8687,
  [8688] = 8688,
  [8689] = 8689,
  [8690] = 1799,
  [8691] = 1800,
  [8692] = 8689,
  [8693] = 1801,
  [8694] = 8285,
  [8695] = 8268,
  [8696] = 8689,
  [8697] = 2258,
  [8698] = 8689,
  [8699] = 8689,
  [8700] = 8700,
  [8701] = 8688,
  [8702] = 8685,
  [8703] = 8689,
  [8704] = 8704,
  [8705] = 8705,
  [8706] = 1824,
  [8707] = 1776,
  [8708] = 1794,
  [8709] = 8709,
  [8710] = 3752,
  [8711] = 1774,
  [8712] = 4477,
  [8713] = 1773,
  [8714] = 8714,
  [8715] = 1804,
  [8716] = 8709,
  [8717] = 1788,
  [8718] = 8718,
  [8719] = 3755,
  [8720] = 8714,
  [8721] = 8714,
  [8722] = 1772,
  [8723] = 8718,
  [8724] = 7161,
  [8725] = 8709,
  [8726] = 8718,
  [8727] = 1795,
  [8728] = 8709,
  [8729] = 1771,
  [8730] = 8709,
  [8731] = 7173,
  [8732] = 8718,
  [8733] = 1786,
  [8734] = 1802,
  [8735] = 1807,
  [8736] = 1809,
  [8737] = 3756,
  [8738] = 3754,
  [8739] = 7131,
  [8740] = 1803,
  [8741] = 8718,
  [8742] = 8714,
  [8743] = 8718,
  [8744] = 1830,
  [8745] = 8709,
  [8746] = 1789,
  [8747] = 8747,
  [8748] = 2645,
  [8749] = 1790,
  [8750] = 3753,
  [8751] = 8718,
  [8752] = 1868,
  [8753] = 3757,
  [8754] = 1793,
  [8755] = 8709,
  [8756] = 1787,
  [8757] = 7128,
  [8758] = 7130,
  [8759] = 7132,
  [8760] = 3751,
  [8761] = 1792,
  [8762] = 1785,
  [8763] = 1798,
  [8764] = 8764,
  [8765] = 8765,
  [8766] = 8709,
  [8767] = 8767,
  [8768] = 7153,
  [8769] = 1811,
  [8770] = 1777,
  [8771] = 8718,
  [8772] = 1813,
  [8773] = 8773,
  [8774] = 1791,
  [8775] = 7159,
  [8776] = 7160,
  [8777] = 7156,
  [8778] = 8709,
  [8779] = 1778,
  [8780] = 8709,
  [8781] = 8781,
  [8782] = 8781,
  [8783] = 8783,
  [8784] = 8784,
  [8785] = 8785,
  [8786] = 8781,
  [8787] = 8787,
  [8788] = 8781,
  [8789] = 8781,
  [8790] = 8790,
  [8791] = 8784,
  [8792] = 8792,
  [8793] = 8793,
  [8794] = 8784,
  [8795] = 8783,
  [8796] = 8787,
  [8797] = 8792,
  [8798] = 8783,
  [8799] = 8790,
  [8800] = 8784,
  [8801] = 8801,
  [8802] = 8783,
  [8803] = 8792,
  [8804] = 8787,
  [8805] = 8781,
  [8806] = 8783,
  [8807] = 2554,
  [8808] = 8787,
  [8809] = 8787,
  [8810] = 8784,
  [8811] = 8784,
  [8812] = 8781,
  [8813] = 8792,
  [8814] = 8784,
  [8815] = 8784,
  [8816] = 8792,
  [8817] = 8817,
  [8818] = 8787,
  [8819] = 8781,
  [8820] = 8783,
  [8821] = 8783,
  [8822] = 8801,
  [8823] = 8787,
  [8824] = 8783,
  [8825] = 8825,
  [8826] = 8801,
  [8827] = 8792,
  [8828] = 8792,
  [8829] = 8801,
  [8830] = 8801,
  [8831] = 2557,
  [8832] = 8801,
  [8833] = 8783,
  [8834] = 8787,
  [8835] = 2558,
  [8836] = 8783,
  [8837] = 8783,
  [8838] = 8792,
  [8839] = 8839,
  [8840] = 8793,
  [8841] = 8781,
  [8842] = 8781,
  [8843] = 8825,
  [8844] = 8793,
  [8845] = 8784,
  [8846] = 8783,
  [8847] = 8792,
  [8848] = 8792,
  [8849] = 8787,
  [8850] = 8850,
  [8851] = 8851,
  [8852] = 8787,
  [8853] = 8853,
  [8854] = 8784,
  [8855] = 8855,
  [8856] = 8856,
  [8857] = 4277,
  [8858] = 4156,
  [8859] = 4157,
  [8860] = 4158,
  [8861] = 4159,
  [8862] = 4160,
  [8863] = 4161,
  [8864] = 4162,
  [8865] = 4163,
  [8866] = 4164,
  [8867] = 4165,
  [8868] = 4166,
  [8869] = 4167,
  [8870] = 4168,
  [8871] = 4169,
  [8872] = 4170,
  [8873] = 8873,
  [8874] = 8874,
  [8875] = 4171,
  [8876] = 4172,
  [8877] = 4173,
  [8878] = 4174,
  [8879] = 4175,
  [8880] = 4176,
  [8881] = 4177,
  [8882] = 4178,
  [8883] = 8346,
  [8884] = 8884,
  [8885] = 4179,
  [8886] = 4180,
  [8887] = 4181,
  [8888] = 4182,
  [8889] = 4183,
  [8890] = 4184,
  [8891] = 4185,
  [8892] = 4186,
  [8893] = 4187,
  [8894] = 4188,
  [8895] = 8293,
  [8896] = 4933,
  [8897] = 4224,
  [8898] = 8856,
  [8899] = 8899,
  [8900] = 4279,
  [8901] = 4280,
  [8902] = 8902,
  [8903] = 8294,
  [8904] = 8295,
  [8905] = 4190,
  [8906] = 4191,
  [8907] = 4192,
  [8908] = 4193,
  [8909] = 4194,
  [8910] = 4195,
  [8911] = 4196,
  [8912] = 4197,
  [8913] = 4198,
  [8914] = 4199,
  [8915] = 4200,
  [8916] = 4201,
  [8917] = 4202,
  [8918] = 4203,
  [8919] = 4204,
  [8920] = 4205,
  [8921] = 4206,
  [8922] = 4207,
  [8923] = 4208,
  [8924] = 4209,
  [8925] = 4210,
  [8926] = 4113,
  [8927] = 8927,
  [8928] = 4114,
  [8929] = 8929,
  [8930] = 4211,
  [8931] = 4212,
  [8932] = 4213,
  [8933] = 4214,
  [8934] = 4215,
  [8935] = 4216,
  [8936] = 4217,
  [8937] = 4218,
  [8938] = 8856,
  [8939] = 8873,
  [8940] = 4115,
  [8941] = 8899,
  [8942] = 4116,
  [8943] = 8874,
  [8944] = 4117,
  [8945] = 8856,
  [8946] = 8300,
  [8947] = 4139,
  [8948] = 4145,
  [8949] = 4154,
  [8950] = 8884,
  [8951] = 4118,
  [8952] = 4119,
  [8953] = 4120,
  [8954] = 4124,
  [8955] = 8856,
  [8956] = 8899,
  [8957] = 4281,
  [8958] = 2555,
  [8959] = 8305,
  [8960] = 4282,
  [8961] = 8961,
  [8962] = 8855,
  [8963] = 8963,
  [8964] = 8964,
  [8965] = 8965,
  [8966] = 8899,
  [8967] = 4125,
  [8968] = 4126,
  [8969] = 8961,
  [8970] = 4127,
  [8971] = 8874,
  [8972] = 4221,
  [8973] = 2567,
  [8974] = 4233,
  [8975] = 4234,
  [8976] = 2568,
  [8977] = 4235,
  [8978] = 2574,
  [8979] = 8855,
  [8980] = 4128,
  [8981] = 8981,
  [8982] = 8884,
  [8983] = 4917,
  [8984] = 8963,
  [8985] = 8965,
  [8986] = 4129,
  [8987] = 8964,
  [8988] = 4130,
  [8989] = 4131,
  [8990] = 8874,
  [8991] = 8884,
  [8992] = 4132,
  [8993] = 8874,
  [8994] = 2571,
  [8995] = 4227,
  [8996] = 4229,
  [8997] = 4230,
  [8998] = 4231,
  [8999] = 2556,
  [9000] = 4133,
  [9001] = 4232,
  [9002] = 8961,
  [9003] = 5335,
  [9004] = 8328,
  [9005] = 8855,
  [9006] = 8856,
  [9007] = 8856,
  [9008] = 9008,
  [9009] = 2572,
  [9010] = 4108,
  [9011] = 8899,
  [9012] = 4134,
  [9013] = 4121,
  [9014] = 4089,
  [9015] = 8961,
  [9016] = 8884,
  [9017] = 8855,
  [9018] = 8330,
  [9019] = 8964,
  [9020] = 8331,
  [9021] = 4291,
  [9022] = 8332,
  [9023] = 4290,
  [9024] = 9024,
  [9025] = 8337,
  [9026] = 4104,
  [9027] = 4105,
  [9028] = 4110,
  [9029] = 4122,
  [9030] = 4123,
  [9031] = 9031,
  [9032] = 8963,
  [9033] = 8965,
  [9034] = 8340,
  [9035] = 8964,
  [9036] = 8318,
  [9037] = 8348,
  [9038] = 8291,
  [9039] = 8298,
  [9040] = 8874,
  [9041] = 4292,
  [9042] = 2577,
  [9043] = 8884,
  [9044] = 8874,
  [9045] = 4256,
  [9046] = 4257,
  [9047] = 4258,
  [9048] = 4259,
  [9049] = 4260,
  [9050] = 4261,
  [9051] = 4219,
  [9052] = 4262,
  [9053] = 8884,
  [9054] = 4263,
  [9055] = 4293,
  [9056] = 4264,
  [9057] = 8899,
  [9058] = 4294,
  [9059] = 4220,
  [9060] = 9060,
  [9061] = 4289,
  [9062] = 4265,
  [9063] = 4223,
  [9064] = 4225,
  [9065] = 4226,
  [9066] = 4103,
  [9067] = 9067,
  [9068] = 8964,
  [9069] = 8308,
  [9070] = 8296,
  [9071] = 4271,
  [9072] = 4135,
  [9073] = 4252,
  [9074] = 2569,
  [9075] = 4253,
  [9076] = 4254,
  [9077] = 8310,
  [9078] = 4267,
  [9079] = 4272,
  [9080] = 4273,
  [9081] = 4136,
  [9082] = 8961,
  [9083] = 4137,
  [9084] = 8311,
  [9085] = 8313,
  [9086] = 8856,
  [9087] = 8961,
  [9088] = 8855,
  [9089] = 4255,
  [9090] = 8855,
  [9091] = 8899,
  [9092] = 8964,
  [9093] = 2575,
  [9094] = 4138,
  [9095] = 9095,
  [9096] = 8874,
  [9097] = 8299,
  [9098] = 8306,
  [9099] = 8314,
  [9100] = 8965,
  [9101] = 4107,
  [9102] = 8902,
  [9103] = 2566,
  [9104] = 8961,
  [9105] = 8963,
  [9106] = 4106,
  [9107] = 8884,
  [9108] = 8319,
  [9109] = 4140,
  [9110] = 4141,
  [9111] = 4142,
  [9112] = 4274,
  [9113] = 8855,
  [9114] = 9114,
  [9115] = 2563,
  [9116] = 9060,
  [9117] = 4091,
  [9118] = 4143,
  [9119] = 4092,
  [9120] = 4093,
  [9121] = 4094,
  [9122] = 4095,
  [9123] = 9123,
  [9124] = 4096,
  [9125] = 2570,
  [9126] = 4097,
  [9127] = 8963,
  [9128] = 4144,
  [9129] = 9067,
  [9130] = 8965,
  [9131] = 8964,
  [9132] = 2565,
  [9133] = 8964,
  [9134] = 1832,
  [9135] = 8965,
  [9136] = 8899,
  [9137] = 8874,
  [9138] = 2573,
  [9139] = 8963,
  [9140] = 2576,
  [9141] = 2559,
  [9142] = 8884,
  [9143] = 8963,
  [9144] = 8856,
  [9145] = 8961,
  [9146] = 8899,
  [9147] = 8965,
  [9148] = 8961,
  [9149] = 8855,
  [9150] = 8323,
  [9151] = 8324,
  [9152] = 8855,
  [9153] = 8964,
  [9154] = 8964,
  [9155] = 4098,
  [9156] = 4099,
  [9157] = 4100,
  [9158] = 4101,
  [9159] = 4102,
  [9160] = 8965,
  [9161] = 8963,
  [9162] = 2258,
  [9163] = 8856,
  [9164] = 8329,
  [9165] = 8874,
  [9166] = 2561,
  [9167] = 2564,
  [9168] = 2562,
  [9169] = 8963,
  [9170] = 8965,
  [9171] = 8899,
  [9172] = 9172,
  [9173] = 8292,
  [9174] = 4275,
  [9175] = 8884,
  [9176] = 8963,
  [9177] = 4298,
  [9178] = 8965,
  [9179] = 9179,
  [9180] = 8961,
  [9181] = 8347,
  [9182] = 5053,
  [9183] = 7527,
  [9184] = 7528,
  [9185] = 5213,
  [9186] = 5055,
  [9187] = 5133,
  [9188] = 5156,
  [9189] = 5208,
  [9190] = 5209,
  [9191] = 5210,
  [9192] = 5211,
  [9193] = 5220,
  [9194] = 5229,
  [9195] = 5269,
  [9196] = 5285,
  [9197] = 5299,
  [9198] = 5301,
  [9199] = 4983,
  [9200] = 4984,
  [9201] = 4985,
  [9202] = 4986,
  [9203] = 5034,
  [9204] = 5036,
  [9205] = 5042,
  [9206] = 5044,
  [9207] = 5048,
  [9208] = 5049,
  [9209] = 5088,
  [9210] = 5099,
  [9211] = 5100,
  [9212] = 5101,
  [9213] = 5103,
  [9214] = 5104,
  [9215] = 5106,
  [9216] = 5108,
  [9217] = 5109,
  [9218] = 5110,
  [9219] = 5111,
  [9220] = 5112,
  [9221] = 5115,
  [9222] = 5116,
  [9223] = 5146,
  [9224] = 5147,
  [9225] = 5148,
  [9226] = 5149,
  [9227] = 5151,
  [9228] = 5152,
  [9229] = 5153,
  [9230] = 5154,
  [9231] = 5155,
  [9232] = 5191,
  [9233] = 5192,
  [9234] = 5193,
  [9235] = 5194,
  [9236] = 5195,
  [9237] = 5196,
  [9238] = 5197,
  [9239] = 5198,
  [9240] = 5199,
  [9241] = 5200,
  [9242] = 5201,
  [9243] = 5202,
  [9244] = 5203,
  [9245] = 5204,
  [9246] = 5205,
  [9247] = 5206,
  [9248] = 5207,
  [9249] = 5277,
  [9250] = 5279,
  [9251] = 5282,
  [9252] = 5283,
  [9253] = 5284,
  [9254] = 5286,
  [9255] = 5288,
  [9256] = 5289,
  [9257] = 5290,
  [9258] = 5291,
  [9259] = 5292,
  [9260] = 5293,
  [9261] = 5294,
  [9262] = 5295,
  [9263] = 5296,
  [9264] = 5303,
  [9265] = 5304,
  [9266] = 5305,
  [9267] = 5306,
  [9268] = 5307,
  [9269] = 5308,
  [9270] = 5309,
  [9271] = 5310,
  [9272] = 5311,
  [9273] = 5312,
  [9274] = 5173,
  [9275] = 4973,
  [9276] = 4974,
  [9277] = 4975,
  [9278] = 4976,
  [9279] = 4977,
  [9280] = 4978,
  [9281] = 4979,
  [9282] = 4980,
  [9283] = 4981,
  [9284] = 4982,
  [9285] = 4988,
  [9286] = 4989,
  [9287] = 4990,
  [9288] = 4991,
  [9289] = 4992,
  [9290] = 4993,
  [9291] = 4994,
  [9292] = 4995,
  [9293] = 4996,
  [9294] = 4997,
  [9295] = 4998,
  [9296] = 4999,
  [9297] = 5000,
  [9298] = 5001,
  [9299] = 5002,
  [9300] = 5003,
  [9301] = 5004,
  [9302] = 5005,
  [9303] = 5006,
  [9304] = 5010,
  [9305] = 5011,
  [9306] = 5012,
  [9307] = 5013,
  [9308] = 5014,
  [9309] = 5015,
  [9310] = 5016,
  [9311] = 5017,
  [9312] = 5018,
  [9313] = 5019,
  [9314] = 5020,
  [9315] = 5021,
  [9316] = 5022,
  [9317] = 5023,
  [9318] = 5024,
  [9319] = 5025,
  [9320] = 5026,
  [9321] = 2633,
  [9322] = 5027,
  [9323] = 5028,
  [9324] = 5029,
  [9325] = 5030,
  [9326] = 5031,
  [9327] = 5032,
  [9328] = 5033,
  [9329] = 5035,
  [9330] = 5038,
  [9331] = 5039,
  [9332] = 5040,
  [9333] = 5041,
  [9334] = 5043,
  [9335] = 7441,
  [9336] = 5045,
  [9337] = 5046,
  [9338] = 5047,
  [9339] = 5050,
  [9340] = 5051,
  [9341] = 5052,
  [9342] = 5057,
  [9343] = 5058,
  [9344] = 5059,
  [9345] = 5060,
  [9346] = 5061,
  [9347] = 5062,
  [9348] = 5063,
  [9349] = 5064,
  [9350] = 5065,
  [9351] = 5066,
  [9352] = 5067,
  [9353] = 5068,
  [9354] = 5069,
  [9355] = 5070,
  [9356] = 5071,
  [9357] = 5072,
  [9358] = 5073,
  [9359] = 5074,
  [9360] = 5075,
  [9361] = 5076,
  [9362] = 5078,
  [9363] = 5079,
  [9364] = 5080,
  [9365] = 5081,
  [9366] = 5082,
  [9367] = 5083,
  [9368] = 5084,
  [9369] = 5085,
  [9370] = 5086,
  [9371] = 5089,
  [9372] = 4108,
  [9373] = 5090,
  [9374] = 5091,
  [9375] = 5092,
  [9376] = 4972,
  [9377] = 5093,
  [9378] = 5094,
  [9379] = 5095,
  [9380] = 5113,
  [9381] = 5114,
  [9382] = 5117,
  [9383] = 5118,
  [9384] = 5119,
  [9385] = 5120,
  [9386] = 5121,
  [9387] = 5122,
  [9388] = 5123,
  [9389] = 5124,
  [9390] = 5125,
  [9391] = 5126,
  [9392] = 5127,
  [9393] = 5128,
  [9394] = 5129,
  [9395] = 5130,
  [9396] = 5131,
  [9397] = 5132,
  [9398] = 2554,
  [9399] = 2555,
  [9400] = 2556,
  [9401] = 5134,
  [9402] = 2557,
  [9403] = 5135,
  [9404] = 2558,
  [9405] = 5136,
  [9406] = 5137,
  [9407] = 2559,
  [9408] = 5138,
  [9409] = 5139,
  [9410] = 2561,
  [9411] = 2562,
  [9412] = 5140,
  [9413] = 2563,
  [9414] = 2564,
  [9415] = 2565,
  [9416] = 5141,
  [9417] = 5142,
  [9418] = 2566,
  [9419] = 2567,
  [9420] = 2568,
  [9421] = 5143,
  [9422] = 5144,
  [9423] = 2569,
  [9424] = 2570,
  [9425] = 2571,
  [9426] = 5145,
  [9427] = 2572,
  [9428] = 2573,
  [9429] = 2574,
  [9430] = 2575,
  [9431] = 2576,
  [9432] = 2577,
  [9433] = 5168,
  [9434] = 5169,
  [9435] = 5176,
  [9436] = 5177,
  [9437] = 5179,
  [9438] = 5180,
  [9439] = 5181,
  [9440] = 5182,
  [9441] = 5183,
  [9442] = 5184,
  [9443] = 5185,
  [9444] = 5186,
  [9445] = 5189,
  [9446] = 5190,
  [9447] = 1771,
  [9448] = 5272,
  [9449] = 7561,
  [9450] = 4003,
  [9451] = 1800,
  [9452] = 7449,
  [9453] = 4005,
  [9454] = 4006,
  [9455] = 4007,
  [9456] = 4008,
  [9457] = 7533,
  [9458] = 1801,
  [9459] = 5225,
  [9460] = 4017,
  [9461] = 4018,
  [9462] = 4019,
  [9463] = 4020,
  [9464] = 4022,
  [9465] = 5239,
  [9466] = 4023,
  [9467] = 7567,
  [9468] = 4038,
  [9469] = 4039,
  [9470] = 4040,
  [9471] = 4041,
  [9472] = 4042,
  [9473] = 4043,
  [9474] = 4048,
  [9475] = 4049,
  [9476] = 4050,
  [9477] = 4051,
  [9478] = 4052,
  [9479] = 3983,
  [9480] = 3984,
  [9481] = 7412,
  [9482] = 7453,
  [9483] = 7562,
  [9484] = 2554,
  [9485] = 2557,
  [9486] = 2558,
  [9487] = 7501,
  [9488] = 7574,
  [9489] = 5157,
  [9490] = 5158,
  [9491] = 5159,
  [9492] = 5161,
  [9493] = 5162,
  [9494] = 5163,
  [9495] = 5164,
  [9496] = 5215,
  [9497] = 5165,
  [9498] = 5216,
  [9499] = 5166,
  [9500] = 5167,
  [9501] = 5170,
  [9502] = 5171,
  [9503] = 5172,
  [9504] = 5313,
  [9505] = 5174,
  [9506] = 5175,
  [9507] = 1799,
  [9508] = 5187,
  [9509] = 4224,
  [9510] = 5227,
  [9511] = 4227,
  [9512] = 4229,
  [9513] = 4230,
  [9514] = 4231,
  [9515] = 4232,
  [9516] = 7586,
  [9517] = 5240,
  [9518] = 4256,
  [9519] = 4257,
  [9520] = 4258,
  [9521] = 4259,
  [9522] = 4260,
  [9523] = 4261,
  [9524] = 4262,
  [9525] = 4263,
  [9526] = 4264,
  [9527] = 4265,
  [9528] = 4267,
  [9529] = 4272,
  [9530] = 4273,
  [9531] = 5251,
  [9532] = 4275,
  [9533] = 4277,
  [9534] = 4279,
  [9535] = 4280,
  [9536] = 4281,
  [9537] = 4282,
  [9538] = 4089,
  [9539] = 4291,
  [9540] = 4292,
  [9541] = 4293,
  [9542] = 4294,
  [9543] = 4289,
  [9544] = 4103,
  [9545] = 4271,
  [9546] = 5261,
  [9547] = 5262,
  [9548] = 4139,
  [9549] = 4145,
  [9550] = 4154,
  [9551] = 4221,
  [9552] = 4233,
  [9553] = 4234,
  [9554] = 4235,
  [9555] = 5265,
  [9556] = 4290,
  [9557] = 4104,
  [9558] = 4105,
  [9559] = 4110,
  [9560] = 4122,
  [9561] = 4123,
  [9562] = 4219,
  [9563] = 4220,
  [9564] = 4223,
  [9565] = 4225,
  [9566] = 4226,
  [9567] = 4252,
  [9568] = 4253,
  [9569] = 4254,
  [9570] = 4255,
  [9571] = 4274,
  [9572] = 4091,
  [9573] = 4092,
  [9574] = 4093,
  [9575] = 4094,
  [9576] = 4095,
  [9577] = 4096,
  [9578] = 4097,
  [9579] = 4098,
  [9580] = 4099,
  [9581] = 4100,
  [9582] = 4101,
  [9583] = 4102,
  [9584] = 4298,
  [9585] = 4106,
  [9586] = 4113,
  [9587] = 4114,
  [9588] = 4115,
  [9589] = 4116,
  [9590] = 4117,
  [9591] = 4118,
  [9592] = 4119,
  [9593] = 4120,
  [9594] = 4124,
  [9595] = 4125,
  [9596] = 4126,
  [9597] = 4127,
  [9598] = 4128,
  [9599] = 4129,
  [9600] = 4130,
  [9601] = 4131,
  [9602] = 4132,
  [9603] = 4133,
  [9604] = 4134,
  [9605] = 4135,
  [9606] = 4136,
  [9607] = 4137,
  [9608] = 4138,
  [9609] = 4140,
  [9610] = 4141,
  [9611] = 4142,
  [9612] = 4143,
  [9613] = 4144,
  [9614] = 4156,
  [9615] = 4157,
  [9616] = 4158,
  [9617] = 4159,
  [9618] = 4160,
  [9619] = 4161,
  [9620] = 4162,
  [9621] = 5217,
  [9622] = 4163,
  [9623] = 4164,
  [9624] = 4165,
  [9625] = 4166,
  [9626] = 4167,
  [9627] = 4168,
  [9628] = 4169,
  [9629] = 4170,
  [9630] = 4171,
  [9631] = 5218,
  [9632] = 4172,
  [9633] = 4173,
  [9634] = 5219,
  [9635] = 4174,
  [9636] = 5228,
  [9637] = 5230,
  [9638] = 4175,
  [9639] = 4176,
  [9640] = 5231,
  [9641] = 5232,
  [9642] = 4177,
  [9643] = 4178,
  [9644] = 4179,
  [9645] = 4180,
  [9646] = 4181,
  [9647] = 4182,
  [9648] = 4183,
  [9649] = 5241,
  [9650] = 4184,
  [9651] = 4185,
  [9652] = 5242,
  [9653] = 4186,
  [9654] = 5243,
  [9655] = 5244,
  [9656] = 4187,
  [9657] = 4188,
  [9658] = 5252,
  [9659] = 5253,
  [9660] = 4190,
  [9661] = 4191,
  [9662] = 5254,
  [9663] = 4192,
  [9664] = 5255,
  [9665] = 4193,
  [9666] = 4194,
  [9667] = 4195,
  [9668] = 4196,
  [9669] = 4197,
  [9670] = 4198,
  [9671] = 4199,
  [9672] = 4200,
  [9673] = 4201,
  [9674] = 4202,
  [9675] = 4203,
  [9676] = 4204,
  [9677] = 4205,
  [9678] = 4206,
  [9679] = 4207,
  [9680] = 4208,
  [9681] = 4209,
  [9682] = 4210,
  [9683] = 4211,
  [9684] = 4212,
  [9685] = 4213,
  [9686] = 4214,
  [9687] = 4215,
  [9688] = 4216,
  [9689] = 4217,
  [9690] = 4218,
  [9691] = 4107,
  [9692] = 5009,
  [9693] = 5266,
  [9694] = 4121,
  [9695] = 5267,
  [9696] = 5268,
  [9697] = 7555,
  [9698] = 5270,
  [9699] = 5271,
  [9700] = 5273,
  [9701] = 5274,
  [9702] = 5275,
  [9703] = 5276,
  [9704] = 5278,
  [9705] = 5280,
  [9706] = 5281,
  [9707] = 5287,
  [9708] = 5297,
  [9709] = 5298,
  [9710] = 5037,
  [9711] = 4051,
  [9712] = 4027,
  [9713] = 1824,
  [9714] = 4005,
  [9715] = 4006,
  [9716] = 4007,
  [9717] = 4008,
  [9718] = 3564,
  [9719] = 2563,
  [9720] = 2566,
  [9721] = 4017,
  [9722] = 4018,
  [9723] = 4019,
  [9724] = 4020,
  [9725] = 4022,
  [9726] = 4023,
  [9727] = 2567,
  [9728] = 2564,
  [9729] = 2577,
  [9730] = 2565,
  [9731] = 2568,
  [9732] = 4038,
  [9733] = 4039,
  [9734] = 4040,
  [9735] = 4041,
  [9736] = 4042,
  [9737] = 4043,
  [9738] = 2569,
  [9739] = 3982,
  [9740] = 3991,
  [9741] = 4011,
  [9742] = 2570,
  [9743] = 4048,
  [9744] = 4049,
  [9745] = 4050,
  [9746] = 1784,
  [9747] = 4026,
  [9748] = 2571,
  [9749] = 3983,
  [9750] = 3984,
  [9751] = 5335,
  [9752] = 2555,
  [9753] = 1796,
  [9754] = 2556,
  [9755] = 2258,
  [9756] = 2559,
  [9757] = 2572,
  [9758] = 2561,
  [9759] = 2562,
  [9760] = 2258,
  [9761] = 3574,
  [9762] = 1797,
  [9763] = 4024,
  [9764] = 4025,
  [9765] = 4028,
  [9766] = 4029,
  [9767] = 4032,
  [9768] = 4034,
  [9769] = 4046,
  [9770] = 4047,
  [9771] = 1775,
  [9772] = 2576,
  [9773] = 2573,
  [9774] = 2574,
  [9775] = 4003,
  [9776] = 1783,
  [9777] = 2575,
  [9778] = 4052,
  [9779] = 8078,
  [9780] = 9780,
  [9781] = 9781,
  [9782] = 9780,
  [9783] = 8056,
  [9784] = 8038,
  [9785] = 9781,
  [9786] = 9781,
  [9787] = 8675,
  [9788] = 9780,
  [9789] = 9789,
  [9790] = 8050,
  [9791] = 1825,
  [9792] = 9780,
  [9793] = 8625,
  [9794] = 9781,
  [9795] = 8622,
  [9796] = 8623,
  [9797] = 9797,
  [9798] = 8671,
  [9799] = 8059,
  [9800] = 8060,
  [9801] = 9789,
  [9802] = 8644,
  [9803] = 9789,
  [9804] = 9780,
  [9805] = 9797,
  [9806] = 8652,
  [9807] = 9789,
  [9808] = 9789,
  [9809] = 1779,
  [9810] = 1816,
  [9811] = 8044,
  [9812] = 1780,
  [9813] = 1781,
  [9814] = 9780,
  [9815] = 9781,
  [9816] = 8046,
  [9817] = 9797,
  [9818] = 9781,
  [9819] = 9797,
  [9820] = 8093,
  [9821] = 8074,
  [9822] = 8073,
  [9823] = 1814,
  [9824] = 1782,
  [9825] = 9789,
  [9826] = 9780,
  [9827] = 9797,
  [9828] = 1823,
  [9829] = 1817,
  [9830] = 9797,
  [9831] = 9781,
  [9832] = 9797,
  [9833] = 8049,
  [9834] = 9789,
  [9835] = 8081,
  [9836] = 8082,
  [9837] = 8673,
  [9838] = 1815,
  [9839] = 9839,
  [9840] = 9840,
  [9841] = 9841,
  [9842] = 8115,
  [9843] = 9843,
  [9844] = 8118,
  [9845] = 9845,
  [9846] = 2310,
  [9847] = 8147,
  [9848] = 8127,
  [9849] = 9849,
  [9850] = 9849,
  [9851] = 9851,
  [9852] = 9852,
  [9853] = 9853,
  [9854] = 9854,
  [9855] = 1849,
  [9856] = 9856,
  [9857] = 2291,
  [9858] = 1846,
  [9859] = 9845,
  [9860] = 9860,
  [9861] = 1847,
  [9862] = 9862,
  [9863] = 9863,
  [9864] = 9864,
  [9865] = 6875,
  [9866] = 1848,
  [9867] = 9849,
  [9868] = 2292,
  [9869] = 1850,
  [9870] = 1851,
  [9871] = 8126,
  [9872] = 9872,
  [9873] = 9873,
  [9874] = 9874,
  [9875] = 9872,
  [9876] = 9876,
  [9877] = 9877,
  [9878] = 9849,
  [9879] = 9860,
  [9880] = 9862,
  [9881] = 9863,
  [9882] = 9882,
  [9883] = 9864,
  [9884] = 9872,
  [9885] = 8116,
  [9886] = 9849,
  [9887] = 9887,
  [9888] = 9872,
  [9889] = 9872,
  [9890] = 9890,
  [9891] = 9839,
  [9892] = 9851,
  [9893] = 9852,
  [9894] = 9853,
  [9895] = 9854,
  [9896] = 9896,
  [9897] = 9897,
  [9898] = 9849,
  [9899] = 9840,
  [9900] = 9841,
  [9901] = 9860,
  [9902] = 9862,
  [9903] = 9863,
  [9904] = 9864,
  [9905] = 9890,
  [9906] = 9843,
  [9907] = 9845,
  [9908] = 9839,
  [9909] = 9845,
  [9910] = 9897,
  [9911] = 9849,
  [9912] = 9872,
  [9913] = 9872,
  [9914] = 9849,
  [9915] = 9872,
  [9916] = 9890,
  [9917] = 9839,
  [9918] = 9851,
  [9919] = 2290,
  [9920] = 2293,
  [9921] = 8119,
  [9922] = 9852,
  [9923] = 9840,
  [9924] = 9841,
  [9925] = 1853,
  [9926] = 1855,
  [9927] = 9853,
  [9928] = 9843,
  [9929] = 9851,
  [9930] = 9852,
  [9931] = 9853,
  [9932] = 9854,
  [9933] = 9854,
  [9934] = 9896,
  [9935] = 9897,
  [9936] = 1856,
  [9937] = 9937,
  [9938] = 8117,
  [9939] = 9849,
  [9940] = 1852,
  [9941] = 1839,
  [9942] = 9942,
  [9943] = 1842,
  [9944] = 8114,
  [9945] = 9840,
  [9946] = 9841,
  [9947] = 9860,
  [9948] = 8136,
  [9949] = 8138,
  [9950] = 8139,
  [9951] = 9862,
  [9952] = 9863,
  [9953] = 9864,
  [9954] = 9896,
  [9955] = 9897,
  [9956] = 1858,
  [9957] = 1835,
  [9958] = 1836,
  [9959] = 1844,
  [9960] = 1843,
  [9961] = 1845,
  [9962] = 9890,
  [9963] = 9872,
  [9964] = 9843,
  [9965] = 9896,
  [9966] = 9966,
  [9967] = 3420,
  [9968] = 9968,
  [9969] = 9968,
  [9970] = 9968,
  [9971] = 9968,
  [9972] = 8225,
  [9973] = 8224,
  [9974] = 8234,
  [9975] = 8157,
  [9976] = 9976,
  [9977] = 8220,
  [9978] = 8154,
  [9979] = 9968,
  [9980] = 8213,
  [9981] = 9968,
  [9982] = 9982,
  [9983] = 3420,
  [9984] = 8155,
  [9985] = 9968,
  [9986] = 9986,
  [9987] = 1801,
  [9988] = 9988,
  [9989] = 2292,
  [9990] = 9990,
  [9991] = 9991,
  [9992] = 9992,
  [9993] = 9993,
  [9994] = 1799,
  [9995] = 9995,
  [9996] = 9992,
  [9997] = 9997,
  [9998] = 9998,
  [9999] = 2293,
  [10000] = 3575,
  [10001] = 1771,
  [10002] = 10002,
  [10003] = 1800,
  [10004] = 2291,
  [10005] = 10005,
  [10006] = 10006,
  [10007] = 10007,
  [10008] = 10008,
  [10009] = 10009,
  [10010] = 10007,
  [10011] = 2290,
  [10012] = 3584,
  [10013] = 1796,
  [10014] = 10014,
  [10015] = 10015,
  [10016] = 1797,
  [10017] = 1784,
  [10018] = 10018,
  [10019] = 10019,
  [10020] = 5053,
  [10021] = 2310,
  [10022] = 1783,
  [10023] = 1824,
  [10024] = 1775,
  [10025] = 5272,
  [10026] = 1817,
  [10027] = 1815,
  [10028] = 3420,
  [10029] = 1801,
  [10030] = 1779,
  [10031] = 1782,
  [10032] = 1799,
  [10033] = 3629,
  [10034] = 1800,
  [10035] = 3623,
  [10036] = 10036,
  [10037] = 3628,
  [10038] = 1823,
  [10039] = 1814,
  [10040] = 1780,
  [10041] = 3626,
  [10042] = 1853,
  [10043] = 1855,
  [10044] = 1825,
  [10045] = 3627,
  [10046] = 1781,
  [10047] = 1816,
  [10048] = 1771,
  [10049] = 1842,
  [10050] = 5348,
  [10051] = 1835,
  [10052] = 1848,
  [10053] = 1836,
  [10054] = 10054,
  [10055] = 1775,
  [10056] = 1846,
  [10057] = 1844,
  [10058] = 1845,
  [10059] = 3628,
  [10060] = 10060,
  [10061] = 3626,
  [10062] = 5351,
  [10063] = 5352,
  [10064] = 1850,
  [10065] = 1851,
  [10066] = 1783,
  [10067] = 1797,
  [10068] = 1849,
  [10069] = 10054,
  [10070] = 1784,
  [10071] = 1796,
  [10072] = 10054,
  [10073] = 10054,
  [10074] = 5331,
  [10075] = 8114,
  [10076] = 10054,
  [10077] = 1852,
  [10078] = 1839,
  [10079] = 8115,
  [10080] = 10054,
  [10081] = 10054,
  [10082] = 1824,
  [10083] = 1847,
  [10084] = 3629,
  [10085] = 1856,
  [10086] = 3623,
  [10087] = 1843,
  [10088] = 3627,
  [10089] = 5340,
  [10090] = 1858,
  [10091] = 10054,
  [10092] = 10092,
  [10093] = 10093,
  [10094] = 5400,
  [10095] = 5367,
  [10096] = 5359,
  [10097] = 5393,
  [10098] = 5360,
  [10099] = 5370,
  [10100] = 1825,
  [10101] = 5407,
  [10102] = 10102,
  [10103] = 10103,
  [10104] = 5355,
  [10105] = 5414,
  [10106] = 5405,
  [10107] = 5363,
  [10108] = 5379,
  [10109] = 5408,
  [10110] = 5362,
  [10111] = 10102,
  [10112] = 5364,
  [10113] = 5365,
  [10114] = 10103,
  [10115] = 10115,
  [10116] = 5394,
  [10117] = 5387,
  [10118] = 5375,
  [10119] = 1823,
  [10120] = 10120,
  [10121] = 5372,
  [10122] = 5391,
  [10123] = 5399,
  [10124] = 5409,
  [10125] = 5403,
  [10126] = 1855,
  [10127] = 5366,
  [10128] = 5369,
  [10129] = 5395,
  [10130] = 1817,
  [10131] = 10102,
  [10132] = 10103,
  [10133] = 5404,
  [10134] = 5368,
  [10135] = 1779,
  [10136] = 10136,
  [10137] = 10103,
  [10138] = 3420,
  [10139] = 5357,
  [10140] = 1780,
  [10141] = 5415,
  [10142] = 5373,
  [10143] = 5390,
  [10144] = 5398,
  [10145] = 5397,
  [10146] = 1781,
  [10147] = 5378,
  [10148] = 10102,
  [10149] = 10103,
  [10150] = 5401,
  [10151] = 10151,
  [10152] = 10103,
  [10153] = 5380,
  [10154] = 5411,
  [10155] = 8524,
  [10156] = 10102,
  [10157] = 10103,
  [10158] = 1853,
  [10159] = 1815,
  [10160] = 1814,
  [10161] = 10103,
  [10162] = 5353,
  [10163] = 10103,
  [10164] = 1782,
  [10165] = 5382,
  [10166] = 10166,
  [10167] = 5392,
  [10168] = 5376,
  [10169] = 5396,
  [10170] = 5383,
  [10171] = 5384,
  [10172] = 5385,
  [10173] = 5386,
  [10174] = 5361,
  [10175] = 5356,
  [10176] = 10102,
  [10177] = 1816,
  [10178] = 5381,
  [10179] = 10102,
  [10180] = 1848,
  [10181] = 10181,
  [10182] = 10182,
  [10183] = 10183,
  [10184] = 1842,
  [10185] = 10185,
  [10186] = 10186,
  [10187] = 10187,
  [10188] = 1858,
  [10189] = 10189,
  [10190] = 10190,
  [10191] = 1835,
  [10192] = 10192,
  [10193] = 10193,
  [10194] = 10194,
  [10195] = 8115,
  [10196] = 10196,
  [10197] = 1846,
  [10198] = 1847,
  [10199] = 1836,
  [10200] = 10200,
  [10201] = 10201,
  [10202] = 10185,
  [10203] = 10203,
  [10204] = 1839,
  [10205] = 10205,
  [10206] = 10200,
  [10207] = 1844,
  [10208] = 3640,
  [10209] = 10200,
  [10210] = 10210,
  [10211] = 10211,
  [10212] = 10212,
  [10213] = 10213,
  [10214] = 10214,
  [10215] = 8114,
  [10216] = 1845,
  [10217] = 10185,
  [10218] = 10218,
  [10219] = 10219,
  [10220] = 10220,
  [10221] = 10221,
  [10222] = 1850,
  [10223] = 10223,
  [10224] = 1851,
  [10225] = 10225,
  [10226] = 1856,
  [10227] = 10227,
  [10228] = 1843,
  [10229] = 1852,
  [10230] = 10230,
  [10231] = 10231,
  [10232] = 10185,
  [10233] = 1849,
  [10234] = 10234,
  [10235] = 10235,
  [10236] = 10236,
  [10237] = 10237,
  [10238] = 10200,
  [10239] = 10239,
  [10240] = 3688,
  [10241] = 10241,
  [10242] = 10185,
  [10243] = 10243,
  [10244] = 10200,
  [10245] = 10245,
  [10246] = 10182,
  [10247] = 10247,
  [10248] = 10248,
  [10249] = 10249,
  [10250] = 10248,
  [10251] = 10249,
  [10252] = 10252,
  [10253] = 3751,
  [10254] = 10248,
  [10255] = 10249,
  [10256] = 10256,
  [10257] = 10257,
  [10258] = 10258,
  [10259] = 3752,
  [10260] = 10260,
  [10261] = 3753,
  [10262] = 3754,
  [10263] = 10263,
  [10264] = 10248,
  [10265] = 10265,
  [10266] = 3755,
  [10267] = 3756,
  [10268] = 10248,
  [10269] = 3757,
  [10270] = 10248,
  [10271] = 10248,
  [10272] = 10272,
  [10273] = 10273,
  [10274] = 10274,
  [10275] = 10248,
  [10276] = 10248,
  [10277] = 10277,
  [10278] = 10278,
  [10279] = 10279,
  [10280] = 10280,
  [10281] = 10281,
  [10282] = 10282,
  [10283] = 3743,
  [10284] = 10284,
  [10285] = 10249,
  [10286] = 10249,
  [10287] = 10249,
  [10288] = 10249,
  [10289] = 10249,
  [10290] = 10290,
  [10291] = 10291,
  [10292] = 10249,
  [10293] = 10293,
  [10294] = 10294,
  [10295] = 10295,
  [10296] = 10296,
  [10297] = 10297,
  [10298] = 2554,
  [10299] = 10054,
  [10300] = 2557,
  [10301] = 2558,
  [10302] = 10302,
  [10303] = 8305,
  [10304] = 4193,
  [10305] = 4194,
  [10306] = 4195,
  [10307] = 4196,
  [10308] = 4197,
  [10309] = 4198,
  [10310] = 4199,
  [10311] = 4200,
  [10312] = 4201,
  [10313] = 4202,
  [10314] = 4203,
  [10315] = 4204,
  [10316] = 4205,
  [10317] = 4206,
  [10318] = 4207,
  [10319] = 4208,
  [10320] = 4209,
  [10321] = 4210,
  [10322] = 10322,
  [10323] = 4211,
  [10324] = 4212,
  [10325] = 10325,
  [10326] = 4213,
  [10327] = 4214,
  [10328] = 4215,
  [10329] = 4216,
  [10330] = 4217,
  [10331] = 4218,
  [10332] = 10332,
  [10333] = 4108,
  [10334] = 10322,
  [10335] = 10335,
  [10336] = 10336,
  [10337] = 10337,
  [10338] = 10332,
  [10339] = 8292,
  [10340] = 10340,
  [10341] = 1799,
  [10342] = 1800,
  [10343] = 1801,
  [10344] = 10344,
  [10345] = 10345,
  [10346] = 10346,
  [10347] = 10332,
  [10348] = 10348,
  [10349] = 10349,
  [10350] = 10322,
  [10351] = 8319,
  [10352] = 10322,
  [10353] = 8346,
  [10354] = 10354,
  [10355] = 2258,
  [10356] = 10346,
  [10357] = 10357,
  [10358] = 10357,
  [10359] = 8929,
  [10360] = 4156,
  [10361] = 4157,
  [10362] = 4158,
  [10363] = 4159,
  [10364] = 4160,
  [10365] = 4161,
  [10366] = 4162,
  [10367] = 4163,
  [10368] = 10368,
  [10369] = 10346,
  [10370] = 10340,
  [10371] = 1799,
  [10372] = 10372,
  [10373] = 4290,
  [10374] = 8308,
  [10375] = 4104,
  [10376] = 4105,
  [10377] = 4110,
  [10378] = 4122,
  [10379] = 4164,
  [10380] = 4123,
  [10381] = 10344,
  [10382] = 4165,
  [10383] = 10345,
  [10384] = 4166,
  [10385] = 10348,
  [10386] = 4167,
  [10387] = 10387,
  [10388] = 8328,
  [10389] = 10346,
  [10390] = 4168,
  [10391] = 8330,
  [10392] = 8331,
  [10393] = 8332,
  [10394] = 8337,
  [10395] = 9031,
  [10396] = 8340,
  [10397] = 8347,
  [10398] = 10398,
  [10399] = 8318,
  [10400] = 8293,
  [10401] = 10401,
  [10402] = 8348,
  [10403] = 8291,
  [10404] = 4169,
  [10405] = 4219,
  [10406] = 10344,
  [10407] = 10345,
  [10408] = 10344,
  [10409] = 10348,
  [10410] = 10340,
  [10411] = 8298,
  [10412] = 10412,
  [10413] = 10412,
  [10414] = 10414,
  [10415] = 4220,
  [10416] = 4170,
  [10417] = 4275,
  [10418] = 10387,
  [10419] = 8329,
  [10420] = 10414,
  [10421] = 10387,
  [10422] = 4223,
  [10423] = 4225,
  [10424] = 10354,
  [10425] = 8294,
  [10426] = 10344,
  [10427] = 10345,
  [10428] = 4226,
  [10429] = 10372,
  [10430] = 10357,
  [10431] = 10431,
  [10432] = 10357,
  [10433] = 10433,
  [10434] = 8310,
  [10435] = 4277,
  [10436] = 4279,
  [10437] = 10437,
  [10438] = 10344,
  [10439] = 10357,
  [10440] = 4280,
  [10441] = 4281,
  [10442] = 4282,
  [10443] = 4089,
  [10444] = 4291,
  [10445] = 10445,
  [10446] = 8295,
  [10447] = 10332,
  [10448] = 10322,
  [10449] = 10332,
  [10450] = 4292,
  [10451] = 8927,
  [10452] = 4221,
  [10453] = 4233,
  [10454] = 4252,
  [10455] = 4293,
  [10456] = 4253,
  [10457] = 8300,
  [10458] = 10458,
  [10459] = 4171,
  [10460] = 4254,
  [10461] = 4294,
  [10462] = 10346,
  [10463] = 10357,
  [10464] = 10464,
  [10465] = 4289,
  [10466] = 4103,
  [10467] = 4271,
  [10468] = 4107,
  [10469] = 10469,
  [10470] = 10348,
  [10471] = 4154,
  [10472] = 10332,
  [10473] = 10322,
  [10474] = 1800,
  [10475] = 8311,
  [10476] = 10401,
  [10477] = 4255,
  [10478] = 10346,
  [10479] = 4234,
  [10480] = 10348,
  [10481] = 10401,
  [10482] = 4172,
  [10483] = 4173,
  [10484] = 4174,
  [10485] = 10437,
  [10486] = 1824,
  [10487] = 1801,
  [10488] = 4274,
  [10489] = 4175,
  [10490] = 4121,
  [10491] = 4091,
  [10492] = 10412,
  [10493] = 4092,
  [10494] = 4176,
  [10495] = 4192,
  [10496] = 4094,
  [10497] = 4095,
  [10498] = 4096,
  [10499] = 4097,
  [10500] = 4177,
  [10501] = 2555,
  [10502] = 10368,
  [10503] = 4178,
  [10504] = 2556,
  [10505] = 4098,
  [10506] = 4099,
  [10507] = 4100,
  [10508] = 4101,
  [10509] = 4235,
  [10510] = 10469,
  [10511] = 10511,
  [10512] = 4179,
  [10513] = 2559,
  [10514] = 4102,
  [10515] = 10387,
  [10516] = 10511,
  [10517] = 8313,
  [10518] = 2561,
  [10519] = 2562,
  [10520] = 4180,
  [10521] = 10469,
  [10522] = 10511,
  [10523] = 4298,
  [10524] = 10340,
  [10525] = 4256,
  [10526] = 4181,
  [10527] = 4257,
  [10528] = 10469,
  [10529] = 10511,
  [10530] = 4258,
  [10531] = 10531,
  [10532] = 4259,
  [10533] = 4260,
  [10534] = 2563,
  [10535] = 10387,
  [10536] = 4261,
  [10537] = 4106,
  [10538] = 4182,
  [10539] = 10357,
  [10540] = 10469,
  [10541] = 10511,
  [10542] = 10332,
  [10543] = 4183,
  [10544] = 10322,
  [10545] = 10469,
  [10546] = 10511,
  [10547] = 2564,
  [10548] = 2565,
  [10549] = 2566,
  [10550] = 10346,
  [10551] = 10469,
  [10552] = 10511,
  [10553] = 10511,
  [10554] = 4262,
  [10555] = 10511,
  [10556] = 10348,
  [10557] = 4263,
  [10558] = 4184,
  [10559] = 4185,
  [10560] = 8314,
  [10561] = 4113,
  [10562] = 10387,
  [10563] = 4114,
  [10564] = 4115,
  [10565] = 4116,
  [10566] = 4117,
  [10567] = 4118,
  [10568] = 4119,
  [10569] = 4120,
  [10570] = 4124,
  [10571] = 8299,
  [10572] = 2567,
  [10573] = 2568,
  [10574] = 2569,
  [10575] = 2570,
  [10576] = 2571,
  [10577] = 2572,
  [10578] = 4125,
  [10579] = 8306,
  [10580] = 4126,
  [10581] = 4127,
  [10582] = 4128,
  [10583] = 4129,
  [10584] = 4130,
  [10585] = 10344,
  [10586] = 10345,
  [10587] = 10348,
  [10588] = 10344,
  [10589] = 4131,
  [10590] = 4132,
  [10591] = 4133,
  [10592] = 4134,
  [10593] = 10357,
  [10594] = 10332,
  [10595] = 10322,
  [10596] = 2573,
  [10597] = 2574,
  [10598] = 2575,
  [10599] = 2576,
  [10600] = 10346,
  [10601] = 10344,
  [10602] = 10345,
  [10603] = 4186,
  [10604] = 10401,
  [10605] = 10387,
  [10606] = 10412,
  [10607] = 2577,
  [10608] = 4135,
  [10609] = 4136,
  [10610] = 4137,
  [10611] = 4138,
  [10612] = 4187,
  [10613] = 4188,
  [10614] = 4190,
  [10615] = 8296,
  [10616] = 4264,
  [10617] = 8323,
  [10618] = 4108,
  [10619] = 8324,
  [10620] = 4265,
  [10621] = 4224,
  [10622] = 4140,
  [10623] = 10623,
  [10624] = 4141,
  [10625] = 4142,
  [10626] = 4267,
  [10627] = 4272,
  [10628] = 4143,
  [10629] = 10357,
  [10630] = 10332,
  [10631] = 10631,
  [10632] = 10322,
  [10633] = 10345,
  [10634] = 10346,
  [10635] = 10340,
  [10636] = 4191,
  [10637] = 4144,
  [10638] = 4273,
  [10639] = 10387,
  [10640] = 10387,
  [10641] = 10641,
  [10642] = 4139,
  [10643] = 4227,
  [10644] = 4229,
  [10645] = 4230,
  [10646] = 4231,
  [10647] = 4232,
  [10648] = 4145,
  [10649] = 4093,
  [10650] = 10650,
  [10651] = 10651,
  [10652] = 10652,
  [10653] = 10653,
  [10654] = 10654,
  [10655] = 10655,
  [10656] = 10656,
  [10657] = 10657,
  [10658] = 10658,
  [10659] = 10659,
  [10660] = 10654,
  [10661] = 10661,
  [10662] = 10662,
  [10663] = 10663,
  [10664] = 10656,
  [10665] = 10665,
  [10666] = 10666,
  [10667] = 10667,
  [10668] = 10668,
  [10669] = 10669,
  [10670] = 10670,
  [10671] = 10671,
  [10672] = 10672,
  [10673] = 10673,
  [10674] = 10674,
  [10675] = 10675,
  [10676] = 10676,
  [10677] = 10677,
  [10678] = 10653,
  [10679] = 10679,
  [10680] = 10662,
  [10681] = 10681,
  [10682] = 10666,
  [10683] = 10683,
  [10684] = 10684,
  [10685] = 10685,
  [10686] = 10686,
  [10687] = 10651,
  [10688] = 10652,
  [10689] = 10661,
  [10690] = 10690,
  [10691] = 10691,
  [10692] = 10692,
  [10693] = 10693,
  [10694] = 10693,
  [10695] = 10695,
  [10696] = 10696,
  [10697] = 10697,
  [10698] = 10698,
  [10699] = 10699,
  [10700] = 10700,
  [10701] = 10684,
  [10702] = 10702,
  [10703] = 10692,
  [10704] = 10704,
  [10705] = 10705,
  [10706] = 10706,
  [10707] = 10707,
  [10708] = 10668,
  [10709] = 10709,
  [10710] = 10669,
  [10711] = 10670,
  [10712] = 10671,
  [10713] = 10663,
  [10714] = 10686,
  [10715] = 10715,
  [10716] = 10658,
  [10717] = 10717,
  [10718] = 10718,
  [10719] = 10685,
  [10720] = 10659,
  [10721] = 10707,
  [10722] = 10673,
  [10723] = 10654,
  [10724] = 10656,
  [10725] = 10725,
  [10726] = 10707,
  [10727] = 10727,
  [10728] = 10727,
  [10729] = 10681,
  [10730] = 10730,
  [10731] = 10666,
  [10732] = 10669,
  [10733] = 10671,
  [10734] = 10690,
  [10735] = 10735,
  [10736] = 10697,
  [10737] = 10737,
  [10738] = 10738,
  [10739] = 10695,
  [10740] = 10740,
  [10741] = 10692,
  [10742] = 10704,
  [10743] = 10743,
  [10744] = 10705,
  [10745] = 10745,
  [10746] = 10746,
  [10747] = 10747,
  [10748] = 10681,
  [10749] = 10666,
  [10750] = 10669,
  [10751] = 10751,
  [10752] = 10671,
  [10753] = 10753,
  [10754] = 10727,
  [10755] = 10751,
  [10756] = 10707,
  [10757] = 10727,
  [10758] = 10758,
  [10759] = 10759,
  [10760] = 10693,
  [10761] = 10725,
  [10762] = 10762,
  [10763] = 10763,
  [10764] = 10764,
  [10765] = 10662,
  [10766] = 10690,
  [10767] = 10705,
  [10768] = 10692,
  [10769] = 10707,
  [10770] = 10669,
  [10771] = 10671,
  [10772] = 10725,
  [10773] = 10727,
  [10774] = 10675,
  [10775] = 10676,
  [10776] = 10651,
  [10777] = 10652,
  [10778] = 10661,
  [10779] = 10702,
  [10780] = 10753,
  [10781] = 10781,
  [10782] = 10764,
  [10783] = 10747,
  [10784] = 10684,
  [10785] = 10686,
  [10786] = 10786,
  [10787] = 10787,
  [10788] = 10650,
  [10789] = 10658,
  [10790] = 10659,
  [10791] = 10654,
  [10792] = 10656,
  [10793] = 10751,
  [10794] = 10794,
  [10795] = 10671,
  [10796] = 10693,
  [10797] = 10725,
  [10798] = 10667,
  [10799] = 10799,
  [10800] = 10800,
  [10801] = 10675,
  [10802] = 10676,
  [10803] = 10715,
  [10804] = 10651,
  [10805] = 10652,
  [10806] = 10661,
  [10807] = 10662,
  [10808] = 10693,
  [10809] = 10677,
  [10810] = 10668,
  [10811] = 10699,
  [10812] = 10812,
  [10813] = 10671,
  [10814] = 10658,
  [10815] = 10725,
  [10816] = 10671,
  [10817] = 10659,
  [10818] = 10654,
  [10819] = 10700,
  [10820] = 10820,
  [10821] = 10656,
  [10822] = 10671,
  [10823] = 10823,
  [10824] = 10690,
  [10825] = 10825,
  [10826] = 10684,
  [10827] = 10686,
  [10828] = 10751,
  [10829] = 10696,
  [10830] = 10667,
  [10831] = 10674,
  [10832] = 10715,
  [10833] = 10833,
  [10834] = 10695,
  [10835] = 10662,
  [10836] = 10836,
  [10837] = 10684,
  [10838] = 10686,
  [10839] = 10691,
  [10840] = 10697,
  [10841] = 10841,
  [10842] = 10842,
  [10843] = 10843,
  [10844] = 10709,
  [10845] = 10845,
  [10846] = 10781,
  [10847] = 10709,
  [10848] = 10663,
  [10849] = 10825,
  [10850] = 10843,
  [10851] = 10662,
  [10852] = 10753,
  [10853] = 10673,
  [10854] = 10718,
  [10855] = 10681,
  [10856] = 10666,
  [10857] = 10670,
  [10858] = 10695,
  [10859] = 10709,
  [10860] = 10794,
  [10861] = 10663,
  [10862] = 10825,
  [10863] = 10843,
  [10864] = 10692,
  [10865] = 10704,
  [10866] = 10668,
  [10867] = 10705,
  [10868] = 10692,
  [10869] = 10704,
  [10870] = 10870,
  [10871] = 10825,
  [10872] = 10843,
  [10873] = 10717,
  [10874] = 10673,
  [10875] = 10707,
  [10876] = 10727,
  [10877] = 10667,
  [10878] = 10690,
  [10879] = 10693,
  [10880] = 10715,
  [10881] = 10751,
  [10882] = 10681,
  [10883] = 10704,
  [10884] = 10666,
  [10885] = 10693,
  [10886] = 10725,
  [10887] = 10833,
  [10888] = 10675,
  [10889] = 10676,
  [10890] = 10651,
  [10891] = 10652,
  [10892] = 10661,
  [10893] = 10725,
  [10894] = 10894,
  [10895] = 10658,
  [10896] = 10659,
  [10897] = 10654,
  [10898] = 10656,
  [10899] = 10668,
  [10900] = 10662,
  [10901] = 10684,
  [10902] = 10683,
  [10903] = 10903,
  [10904] = 10904,
  [10905] = 10686,
  [10906] = 10906,
  [10907] = 10709,
  [10908] = 10691,
  [10909] = 10663,
  [10910] = 10697,
  [10911] = 10669,
  [10912] = 10673,
  [10913] = 10695,
  [10914] = 10670,
  [10915] = 10671,
  [10916] = 10681,
  [10917] = 10666,
  [10918] = 10707,
  [10919] = 10650,
  [10920] = 10695,
  [10921] = 10706,
  [10922] = 10675,
  [10923] = 10820,
  [10924] = 10676,
  [10925] = 10845,
  [10926] = 10692,
  [10927] = 10704,
  [10928] = 10705,
  [10929] = 10718,
  [10930] = 10668,
  [10931] = 10707,
  [10932] = 10727,
  [10933] = 9966,
  [10934] = 10693,
  [10935] = 10725,
  [10936] = 2554,
  [10937] = 10937,
  [10938] = 10675,
  [10939] = 10676,
  [10940] = 10651,
  [10941] = 10652,
  [10942] = 10661,
  [10943] = 10675,
  [10944] = 10651,
  [10945] = 10658,
  [10946] = 10659,
  [10947] = 10654,
  [10948] = 10656,
  [10949] = 10662,
  [10950] = 10658,
  [10951] = 10692,
  [10952] = 10704,
  [10953] = 10705,
  [10954] = 10663,
  [10955] = 10676,
  [10956] = 10651,
  [10957] = 10652,
  [10958] = 10681,
  [10959] = 10666,
  [10960] = 10661,
  [10961] = 10652,
  [10962] = 10695,
  [10963] = 10659,
  [10964] = 10654,
  [10965] = 10656,
  [10966] = 4477,
  [10967] = 10692,
  [10968] = 10669,
  [10969] = 10671,
  [10970] = 10704,
  [10971] = 10705,
  [10972] = 10906,
  [10973] = 10675,
  [10974] = 10669,
  [10975] = 10751,
  [10976] = 10823,
  [10977] = 10753,
  [10978] = 10709,
  [10979] = 10833,
  [10980] = 10705,
  [10981] = 10707,
  [10982] = 2557,
  [10983] = 10727,
  [10984] = 10661,
  [10985] = 10833,
  [10986] = 10670,
  [10987] = 10698,
  [10988] = 10691,
  [10989] = 10673,
  [10990] = 10990,
  [10991] = 10693,
  [10992] = 10841,
  [10993] = 10725,
  [10994] = 10842,
  [10995] = 10671,
  [10996] = 10690,
  [10997] = 10709,
  [10998] = 10675,
  [10999] = 10676,
  [11000] = 10651,
  [11001] = 10652,
  [11002] = 11002,
  [11003] = 10661,
  [11004] = 10658,
  [11005] = 10663,
  [11006] = 10659,
  [11007] = 10654,
  [11008] = 10706,
  [11009] = 10903,
  [11010] = 10656,
  [11011] = 10662,
  [11012] = 10673,
  [11013] = 10707,
  [11014] = 10904,
  [11015] = 10727,
  [11016] = 10681,
  [11017] = 10681,
  [11018] = 10666,
  [11019] = 10666,
  [11020] = 10658,
  [11021] = 10663,
  [11022] = 10659,
  [11023] = 10676,
  [11024] = 2558,
  [11025] = 10692,
  [11026] = 10704,
  [11027] = 10671,
  [11028] = 10705,
  [11029] = 10695,
  [11030] = 10698,
  [11031] = 10670,
  [11032] = 10671,
  [11033] = 10668,
  [11034] = 10670,
  [11035] = 11035,
  [11036] = 2565,
  [11037] = 11037,
  [11038] = 2562,
  [11039] = 11039,
  [11040] = 11039,
  [11041] = 1796,
  [11042] = 1797,
  [11043] = 11039,
  [11044] = 9982,
  [11045] = 11045,
  [11046] = 4047,
  [11047] = 3982,
  [11048] = 2554,
  [11049] = 2559,
  [11050] = 11050,
  [11051] = 11051,
  [11052] = 4011,
  [11053] = 2563,
  [11054] = 2564,
  [11055] = 2557,
  [11056] = 11039,
  [11057] = 4003,
  [11058] = 2566,
  [11059] = 3991,
  [11060] = 2567,
  [11061] = 11061,
  [11062] = 2568,
  [11063] = 2569,
  [11064] = 2570,
  [11065] = 2571,
  [11066] = 4046,
  [11067] = 11067,
  [11068] = 4005,
  [11069] = 4006,
  [11070] = 4007,
  [11071] = 4008,
  [11072] = 5272,
  [11073] = 2558,
  [11074] = 2572,
  [11075] = 2573,
  [11076] = 2574,
  [11077] = 4017,
  [11078] = 4018,
  [11079] = 4019,
  [11080] = 4020,
  [11081] = 4022,
  [11082] = 4023,
  [11083] = 2575,
  [11084] = 4034,
  [11085] = 5053,
  [11086] = 2577,
  [11087] = 4038,
  [11088] = 4039,
  [11089] = 4040,
  [11090] = 4041,
  [11091] = 4042,
  [11092] = 4043,
  [11093] = 4024,
  [11094] = 9976,
  [11095] = 4025,
  [11096] = 4048,
  [11097] = 4049,
  [11098] = 4050,
  [11099] = 4051,
  [11100] = 4052,
  [11101] = 3983,
  [11102] = 3984,
  [11103] = 1775,
  [11104] = 1784,
  [11105] = 11105,
  [11106] = 11039,
  [11107] = 11107,
  [11108] = 11039,
  [11109] = 2258,
  [11110] = 1783,
  [11111] = 11111,
  [11112] = 11039,
  [11113] = 2555,
  [11114] = 11114,
  [11115] = 2556,
  [11116] = 2561,
  [11117] = 4026,
  [11118] = 11039,
  [11119] = 4027,
  [11120] = 11120,
  [11121] = 11121,
  [11122] = 4028,
  [11123] = 4029,
  [11124] = 4032,
  [11125] = 2576,
  [11126] = 4018,
  [11127] = 3983,
  [11128] = 8119,
  [11129] = 3984,
  [11130] = 4047,
  [11131] = 11131,
  [11132] = 1817,
  [11133] = 3982,
  [11134] = 4049,
  [11135] = 11135,
  [11136] = 11136,
  [11137] = 1853,
  [11138] = 11138,
  [11139] = 4011,
  [11140] = 11140,
  [11141] = 4050,
  [11142] = 1779,
  [11143] = 1780,
  [11144] = 1781,
  [11145] = 11145,
  [11146] = 2258,
  [11147] = 9993,
  [11148] = 11148,
  [11149] = 11149,
  [11150] = 10009,
  [11151] = 2258,
  [11152] = 11152,
  [11153] = 4933,
  [11154] = 1814,
  [11155] = 1782,
  [11156] = 11156,
  [11157] = 9986,
  [11158] = 9997,
  [11159] = 2559,
  [11160] = 10002,
  [11161] = 11161,
  [11162] = 4028,
  [11163] = 11163,
  [11164] = 4029,
  [11165] = 4032,
  [11166] = 11163,
  [11167] = 11163,
  [11168] = 10006,
  [11169] = 4034,
  [11170] = 1855,
  [11171] = 10008,
  [11172] = 11172,
  [11173] = 11173,
  [11174] = 2561,
  [11175] = 11175,
  [11176] = 11156,
  [11177] = 11177,
  [11178] = 11178,
  [11179] = 2562,
  [11180] = 2555,
  [11181] = 11181,
  [11182] = 4051,
  [11183] = 11183,
  [11184] = 11184,
  [11185] = 4027,
  [11186] = 3991,
  [11187] = 4024,
  [11188] = 4025,
  [11189] = 1823,
  [11190] = 11190,
  [11191] = 11156,
  [11192] = 11192,
  [11193] = 2563,
  [11194] = 11156,
  [11195] = 9998,
  [11196] = 11196,
  [11197] = 2565,
  [11198] = 2566,
  [11199] = 11199,
  [11200] = 4108,
  [11201] = 2567,
  [11202] = 8118,
  [11203] = 10005,
  [11204] = 11204,
  [11205] = 2568,
  [11206] = 2569,
  [11207] = 2570,
  [11208] = 2571,
  [11209] = 2572,
  [11210] = 2573,
  [11211] = 11211,
  [11212] = 4052,
  [11213] = 2574,
  [11214] = 11214,
  [11215] = 11215,
  [11216] = 4917,
  [11217] = 11163,
  [11218] = 11218,
  [11219] = 11219,
  [11220] = 5335,
  [11221] = 11221,
  [11222] = 9988,
  [11223] = 2556,
  [11224] = 11224,
  [11225] = 11225,
  [11226] = 2575,
  [11227] = 2576,
  [11228] = 11228,
  [11229] = 1815,
  [11230] = 11230,
  [11231] = 11231,
  [11232] = 11163,
  [11233] = 11233,
  [11234] = 4003,
  [11235] = 2577,
  [11236] = 11236,
  [11237] = 11237,
  [11238] = 11238,
  [11239] = 11239,
  [11240] = 11156,
  [11241] = 1816,
  [11242] = 4005,
  [11243] = 4006,
  [11244] = 4007,
  [11245] = 4008,
  [11246] = 11246,
  [11247] = 11247,
  [11248] = 4017,
  [11249] = 4046,
  [11250] = 4019,
  [11251] = 4020,
  [11252] = 4022,
  [11253] = 4023,
  [11254] = 4026,
  [11255] = 1825,
  [11256] = 4048,
  [11257] = 4038,
  [11258] = 4039,
  [11259] = 4040,
  [11260] = 4041,
  [11261] = 4042,
  [11262] = 4043,
  [11263] = 11263,
  [11264] = 2564,
  [11265] = 11265,
  [11266] = 11266,
  [11267] = 11266,
  [11268] = 11268,
  [11269] = 11266,
  [11270] = 11270,
  [11271] = 11266,
  [11272] = 11272,
  [11273] = 11266,
  [11274] = 11274,
  [11275] = 11266,
  [11276] = 11276,
  [11277] = 11277,
  [11278] = 11278,
  [11279] = 11279,
  [11280] = 11280,
  [11281] = 10239,
  [11282] = 8114,
  [11283] = 10187,
  [11284] = 10190,
  [11285] = 11266,
  [11286] = 11286,
  [11287] = 11287,
  [11288] = 11288,
  [11289] = 8115,
  [11290] = 10194,
  [11291] = 11266,
  [11292] = 11292,
  [11293] = 10192,
  [11294] = 10193,
  [11295] = 11295,
  [11296] = 11296,
  [11297] = 11297,
  [11298] = 11266,
  [11299] = 11299,
  [11300] = 10210,
  [11301] = 5009,
  [11302] = 11302,
  [11303] = 10211,
  [11304] = 11304,
  [11305] = 11305,
  [11306] = 11292,
  [11307] = 10203,
  [11308] = 10214,
  [11309] = 11309,
  [11310] = 10189,
  [11311] = 10231,
  [11312] = 1835,
  [11313] = 1845,
  [11314] = 5265,
  [11315] = 11296,
  [11316] = 11297,
  [11317] = 11317,
  [11318] = 11318,
  [11319] = 2554,
  [11320] = 11266,
  [11321] = 11292,
  [11322] = 11322,
  [11323] = 1836,
  [11324] = 5215,
  [11325] = 5216,
  [11326] = 11266,
  [11327] = 11327,
  [11328] = 11328,
  [11329] = 1843,
  [11330] = 11309,
  [11331] = 11331,
  [11332] = 1848,
  [11333] = 10225,
  [11334] = 11266,
  [11335] = 11335,
  [11336] = 2558,
  [11337] = 11337,
  [11338] = 1846,
  [11339] = 11339,
  [11340] = 11340,
  [11341] = 11266,
  [11342] = 11292,
  [11343] = 1849,
  [11344] = 11344,
  [11345] = 11345,
  [11346] = 5227,
  [11347] = 5240,
  [11348] = 11292,
  [11349] = 11349,
  [11350] = 1852,
  [11351] = 5261,
  [11352] = 11352,
  [11353] = 11353,
  [11354] = 11354,
  [11355] = 11355,
  [11356] = 11292,
  [11357] = 11357,
  [11358] = 10223,
  [11359] = 11292,
  [11360] = 5262,
  [11361] = 11292,
  [11362] = 11304,
  [11363] = 1858,
  [11364] = 11266,
  [11365] = 11292,
  [11366] = 11366,
  [11367] = 1850,
  [11368] = 1856,
  [11369] = 11369,
  [11370] = 11370,
  [11371] = 11280,
  [11372] = 11292,
  [11373] = 1851,
  [11374] = 11266,
  [11375] = 11375,
  [11376] = 1839,
  [11377] = 10181,
  [11378] = 1847,
  [11379] = 11366,
  [11380] = 11380,
  [11381] = 11380,
  [11382] = 1844,
  [11383] = 11383,
  [11384] = 10245,
  [11385] = 5251,
  [11386] = 1842,
  [11387] = 2258,
  [11388] = 2557,
  [11389] = 10256,
  [11390] = 11390,
  [11391] = 11391,
  [11392] = 11392,
  [11393] = 2565,
  [11394] = 11394,
  [11395] = 11395,
  [11396] = 11396,
  [11397] = 11394,
  [11398] = 11398,
  [11399] = 11394,
  [11400] = 11400,
  [11401] = 11392,
  [11402] = 11402,
  [11403] = 2571,
  [11404] = 11404,
  [11405] = 10284,
  [11406] = 11406,
  [11407] = 11407,
  [11408] = 2574,
  [11409] = 10258,
  [11410] = 11407,
  [11411] = 11411,
  [11412] = 11412,
  [11413] = 11413,
  [11414] = 11391,
  [11415] = 11415,
  [11416] = 11416,
  [11417] = 11417,
  [11418] = 11395,
  [11419] = 11404,
  [11420] = 11420,
  [11421] = 11394,
  [11422] = 11407,
  [11423] = 11400,
  [11424] = 11394,
  [11425] = 11425,
  [11426] = 11426,
  [11427] = 11427,
  [11428] = 11412,
  [11429] = 11391,
  [11430] = 11395,
  [11431] = 11431,
  [11432] = 11404,
  [11433] = 10257,
  [11434] = 11434,
  [11435] = 2572,
  [11436] = 11402,
  [11437] = 11437,
  [11438] = 11437,
  [11439] = 11394,
  [11440] = 11417,
  [11441] = 11426,
  [11442] = 11391,
  [11443] = 11395,
  [11444] = 11400,
  [11445] = 11445,
  [11446] = 11446,
  [11447] = 11437,
  [11448] = 11448,
  [11449] = 2681,
  [11450] = 11407,
  [11451] = 11391,
  [11452] = 11452,
  [11453] = 11453,
  [11454] = 11394,
  [11455] = 11455,
  [11456] = 11456,
  [11457] = 11445,
  [11458] = 11448,
  [11459] = 11459,
  [11460] = 11431,
  [11461] = 10252,
  [11462] = 11462,
  [11463] = 11463,
  [11464] = 11392,
  [11465] = 11395,
  [11466] = 10294,
  [11467] = 11452,
  [11468] = 11453,
  [11469] = 11445,
  [11470] = 11448,
  [11471] = 11404,
  [11472] = 11437,
  [11473] = 11473,
  [11474] = 11406,
  [11475] = 11391,
  [11476] = 11395,
  [11477] = 11400,
  [11478] = 11392,
  [11479] = 11463,
  [11480] = 11480,
  [11481] = 11412,
  [11482] = 11431,
  [11483] = 11400,
  [11484] = 11417,
  [11485] = 11426,
  [11486] = 11452,
  [11487] = 11407,
  [11488] = 11453,
  [11489] = 11394,
  [11490] = 11392,
  [11491] = 10273,
  [11492] = 10274,
  [11493] = 10295,
  [11494] = 2569,
  [11495] = 11417,
  [11496] = 11412,
  [11497] = 11473,
  [11498] = 11407,
  [11499] = 11394,
  [11500] = 11406,
  [11501] = 11501,
  [11502] = 10260,
  [11503] = 11463,
  [11504] = 11480,
  [11505] = 11505,
  [11506] = 11407,
  [11507] = 11431,
  [11508] = 11508,
  [11509] = 11407,
  [11510] = 11394,
  [11511] = 11480,
  [11512] = 11473,
  [11513] = 10282,
  [11514] = 2575,
  [11515] = 2576,
  [11516] = 11463,
  [11517] = 11452,
  [11518] = 11394,
  [11519] = 11453,
  [11520] = 11407,
  [11521] = 11445,
  [11522] = 11407,
  [11523] = 11448,
  [11524] = 11524,
  [11525] = 11448,
  [11526] = 11526,
  [11527] = 11527,
  [11528] = 11445,
  [11529] = 11448,
  [11530] = 11530,
  [11531] = 2570,
  [11532] = 11404,
  [11533] = 10263,
  [11534] = 11437,
  [11535] = 11452,
  [11536] = 11473,
  [11537] = 11406,
  [11538] = 11452,
  [11539] = 11391,
  [11540] = 11453,
  [11541] = 11395,
  [11542] = 11412,
  [11543] = 11453,
  [11544] = 2555,
  [11545] = 11407,
  [11546] = 11394,
  [11547] = 11400,
  [11548] = 11431,
  [11549] = 11549,
  [11550] = 11392,
  [11551] = 11480,
  [11552] = 2556,
  [11553] = 11463,
  [11554] = 11480,
  [11555] = 11412,
  [11556] = 11431,
  [11557] = 2568,
  [11558] = 2559,
  [11559] = 11559,
  [11560] = 11407,
  [11561] = 11394,
  [11562] = 11406,
  [11563] = 11394,
  [11564] = 11404,
  [11565] = 11437,
  [11566] = 11473,
  [11567] = 11406,
  [11568] = 2561,
  [11569] = 11400,
  [11570] = 2577,
  [11571] = 11463,
  [11572] = 11480,
  [11573] = 11573,
  [11574] = 10278,
  [11575] = 10281,
  [11576] = 11480,
  [11577] = 11577,
  [11578] = 11578,
  [11579] = 2562,
  [11580] = 11392,
  [11581] = 11581,
  [11582] = 11412,
  [11583] = 11411,
  [11584] = 2701,
  [11585] = 11431,
  [11586] = 11445,
  [11587] = 2566,
  [11588] = 11588,
  [11589] = 11404,
  [11590] = 11407,
  [11591] = 11394,
  [11592] = 11437,
  [11593] = 11473,
  [11594] = 11406,
  [11595] = 2563,
  [11596] = 11596,
  [11597] = 11597,
  [11598] = 2567,
  [11599] = 2564,
  [11600] = 11600,
  [11601] = 10290,
  [11602] = 10291,
  [11603] = 11603,
  [11604] = 11452,
  [11605] = 11453,
  [11606] = 2573,
  [11607] = 11607,
  [11608] = 11445,
  [11609] = 11448,
  [11610] = 11473,
  [11611] = 11407,
  [11612] = 11463,
  [11613] = 11407,
  [11614] = 11614,
  [11615] = 11615,
  [11616] = 11616,
  [11617] = 11617,
  [11618] = 11618,
  [11619] = 11619,
  [11620] = 11616,
  [11621] = 11621,
  [11622] = 11622,
  [11623] = 11617,
  [11624] = 11624,
  [11625] = 11616,
  [11626] = 11621,
  [11627] = 11627,
  [11628] = 11628,
  [11629] = 11614,
  [11630] = 11624,
  [11631] = 11631,
  [11632] = 11632,
  [11633] = 11624,
  [11634] = 11631,
  [11635] = 11624,
  [11636] = 11632,
  [11637] = 11614,
  [11638] = 11638,
  [11639] = 11639,
  [11640] = 11631,
  [11641] = 11641,
  [11642] = 11642,
  [11643] = 11615,
  [11644] = 11644,
  [11645] = 11616,
  [11646] = 11627,
  [11647] = 11624,
  [11648] = 11648,
  [11649] = 11649,
  [11650] = 11650,
  [11651] = 11614,
  [11652] = 11622,
  [11653] = 11615,
  [11654] = 11639,
  [11655] = 11627,
  [11656] = 11622,
  [11657] = 11657,
  [11658] = 11617,
  [11659] = 11659,
  [11660] = 11660,
  [11661] = 11661,
  [11662] = 11662,
  [11663] = 11616,
  [11664] = 11664,
  [11665] = 11622,
  [11666] = 11660,
  [11667] = 11624,
  [11668] = 11631,
  [11669] = 11664,
  [11670] = 11622,
  [11671] = 11659,
  [11672] = 11664,
  [11673] = 11618,
  [11674] = 11659,
  [11675] = 11615,
  [11676] = 11627,
  [11677] = 11627,
  [11678] = 11678,
  [11679] = 11624,
  [11680] = 11680,
  [11681] = 11621,
  [11682] = 11619,
  [11683] = 11628,
  [11684] = 11657,
  [11685] = 11631,
  [11686] = 11686,
  [11687] = 11680,
  [11688] = 11621,
  [11689] = 11628,
  [11690] = 11657,
  [11691] = 11639,
  [11692] = 11678,
  [11693] = 11617,
  [11694] = 11639,
  [11695] = 11662,
  [11696] = 4108,
  [11697] = 11662,
  [11698] = 11618,
  [11699] = 11699,
  [11700] = 11700,
  [11701] = 11678,
  [11702] = 11617,
  [11703] = 11703,
  [11704] = 11680,
  [11705] = 11631,
  [11706] = 11659,
  [11707] = 11621,
  [11708] = 11631,
  [11709] = 11617,
  [11710] = 11660,
  [11711] = 11678,
  [11712] = 11659,
  [11713] = 11614,
  [11714] = 11615,
  [11715] = 11624,
  [11716] = 11628,
  [11717] = 11632,
  [11718] = 11616,
  [11719] = 11631,
  [11720] = 11627,
  [11721] = 11659,
  [11722] = 11660,
  [11723] = 11662,
  [11724] = 11618,
  [11725] = 11700,
  [11726] = 11700,
  [11727] = 11657,
  [11728] = 11657,
  [11729] = 11659,
  [11730] = 11642,
  [11731] = 11628,
  [11732] = 11657,
  [11733] = 11650,
  [11734] = 11680,
  [11735] = 11632,
  [11736] = 11680,
  [11737] = 11631,
  [11738] = 11700,
  [11739] = 11632,
  [11740] = 11703,
  [11741] = 11664,
  [11742] = 11619,
  [11743] = 11639,
  [11744] = 11662,
  [11745] = 11622,
  [11746] = 11660,
  [11747] = 11747,
  [11748] = 11617,
  [11749] = 11619,
  [11750] = 11614,
  [11751] = 11662,
  [11752] = 11615,
  [11753] = 11660,
  [11754] = 11618,
  [11755] = 11660,
  [11756] = 11624,
  [11757] = 11615,
  [11758] = 11614,
  [11759] = 11759,
  [11760] = 11678,
  [11761] = 11678,
  [11762] = 11628,
  [11763] = 11619,
  [11764] = 11764,
  [11765] = 11662,
  [11766] = 11766,
  [11767] = 11615,
  [11768] = 11627,
  [11769] = 11662,
  [11770] = 11662,
  [11771] = 11616,
  [11772] = 11664,
  [11773] = 11614,
  [11774] = 11628,
  [11775] = 11686,
  [11776] = 11615,
  [11777] = 11657,
  [11778] = 11678,
  [11779] = 11664,
  [11780] = 11664,
  [11781] = 11614,
  [11782] = 11622,
  [11783] = 11621,
  [11784] = 11680,
  [11785] = 11700,
  [11786] = 11680,
  [11787] = 11621,
  [11788] = 11788,
  [11789] = 11789,
  [11790] = 11790,
  [11791] = 11791,
  [11792] = 11792,
  [11793] = 11793,
  [11794] = 11794,
  [11795] = 11795,
  [11796] = 11796,
  [11797] = 11797,
  [11798] = 11795,
  [11799] = 11799,
  [11800] = 11800,
  [11801] = 11801,
  [11802] = 11802,
  [11803] = 11803,
  [11804] = 11803,
  [11805] = 11805,
  [11806] = 11800,
  [11807] = 11805,
  [11808] = 11808,
  [11809] = 11803,
  [11810] = 11810,
  [11811] = 11811,
  [11812] = 11800,
  [11813] = 11813,
  [11814] = 11814,
  [11815] = 11815,
  [11816] = 11795,
  [11817] = 11817,
  [11818] = 11818,
  [11819] = 11814,
  [11820] = 11788,
  [11821] = 11802,
  [11822] = 11822,
  [11823] = 11814,
  [11824] = 11824,
  [11825] = 11825,
  [11826] = 11826,
  [11827] = 11827,
  [11828] = 11805,
  [11829] = 11829,
  [11830] = 11791,
  [11831] = 11831,
  [11832] = 11832,
  [11833] = 11833,
  [11834] = 11834,
  [11835] = 11835,
  [11836] = 11805,
  [11837] = 11837,
  [11838] = 11838,
  [11839] = 11839,
  [11840] = 11840,
  [11841] = 11841,
  [11842] = 11795,
  [11843] = 11813,
  [11844] = 11824,
  [11845] = 11845,
  [11846] = 11803,
  [11847] = 11847,
  [11848] = 11805,
  [11849] = 11788,
  [11850] = 11850,
  [11851] = 11851,
  [11852] = 11824,
  [11853] = 11853,
  [11854] = 11854,
  [11855] = 11805,
  [11856] = 11822,
  [11857] = 11805,
  [11858] = 11858,
  [11859] = 11859,
  [11860] = 11831,
  [11861] = 11861,
  [11862] = 11862,
  [11863] = 11827,
  [11864] = 11864,
  [11865] = 11865,
  [11866] = 11866,
  [11867] = 11867,
  [11868] = 11868,
  [11869] = 11869,
  [11870] = 11870,
  [11871] = 11871,
  [11872] = 11872,
  [11873] = 11873,
  [11874] = 11874,
  [11875] = 11875,
  [11876] = 11876,
  [11877] = 11877,
  [11878] = 11878,
  [11879] = 11879,
  [11880] = 11880,
  [11881] = 11881,
  [11882] = 11882,
  [11883] = 11883,
  [11884] = 11884,
  [11885] = 11885,
  [11886] = 11841,
  [11887] = 11840,
  [11888] = 11888,
  [11889] = 11889,
  [11890] = 11890,
  [11891] = 11891,
  [11892] = 11892,
  [11893] = 11803,
  [11894] = 11894,
  [11895] = 11885,
  [11896] = 11896,
  [11897] = 11802,
  [11898] = 11898,
  [11899] = 11837,
  [11900] = 11802,
  [11901] = 11822,
  [11902] = 11814,
  [11903] = 11903,
  [11904] = 11805,
  [11905] = 11864,
  [11906] = 11824,
  [11907] = 11907,
  [11908] = 11908,
  [11909] = 11909,
  [11910] = 11910,
  [11911] = 11911,
  [11912] = 11837,
  [11913] = 11913,
  [11914] = 11858,
  [11915] = 11859,
  [11916] = 11831,
  [11917] = 11811,
  [11918] = 11872,
  [11919] = 11873,
  [11920] = 11874,
  [11921] = 11875,
  [11922] = 11876,
  [11923] = 11877,
  [11924] = 11878,
  [11925] = 11879,
  [11926] = 11880,
  [11927] = 11881,
  [11928] = 11882,
  [11929] = 11883,
  [11930] = 11884,
  [11931] = 11885,
  [11932] = 11841,
  [11933] = 11838,
  [11934] = 11890,
  [11935] = 11891,
  [11936] = 11892,
  [11937] = 11800,
  [11938] = 11791,
  [11939] = 11939,
  [11940] = 11940,
  [11941] = 11790,
  [11942] = 11800,
  [11943] = 11824,
  [11944] = 11802,
  [11945] = 11818,
  [11946] = 11946,
  [11947] = 11865,
  [11948] = 11838,
  [11949] = 11949,
  [11950] = 11845,
  [11951] = 11951,
  [11952] = 11808,
  [11953] = 11940,
  [11954] = 11813,
  [11955] = 11955,
  [11956] = 11858,
  [11957] = 11859,
  [11958] = 11831,
  [11959] = 11898,
  [11960] = 11873,
  [11961] = 11874,
  [11962] = 11962,
  [11963] = 1779,
  [11964] = 11964,
  [11965] = 11818,
  [11966] = 11866,
  [11967] = 11967,
  [11968] = 11968,
  [11969] = 11969,
  [11970] = 11858,
  [11971] = 11859,
  [11972] = 11831,
  [11973] = 11802,
  [11974] = 11974,
  [11975] = 11940,
  [11976] = 11790,
  [11977] = 11822,
  [11978] = 11814,
  [11979] = 11979,
  [11980] = 11894,
  [11981] = 11859,
  [11982] = 11814,
  [11983] = 11795,
  [11984] = 11859,
  [11985] = 11790,
  [11986] = 11859,
  [11987] = 11910,
  [11988] = 11988,
  [11989] = 11822,
  [11990] = 11913,
  [11991] = 11818,
  [11992] = 11832,
  [11993] = 11993,
  [11994] = 11994,
  [11995] = 11834,
  [11996] = 11909,
  [11997] = 11997,
  [11998] = 11998,
  [11999] = 11999,
  [12000] = 12000,
  [12001] = 12001,
  [12002] = 12002,
  [12003] = 12003,
  [12004] = 12004,
  [12005] = 11802,
  [12006] = 11870,
  [12007] = 12007,
  [12008] = 11822,
  [12009] = 11814,
  [12010] = 12010,
  [12011] = 12011,
  [12012] = 11805,
  [12013] = 11845,
  [12014] = 11838,
  [12015] = 12015,
  [12016] = 11803,
  [12017] = 12017,
  [12018] = 12018,
  [12019] = 12019,
  [12020] = 11805,
  [12021] = 11792,
  [12022] = 12022,
  [12023] = 12023,
  [12024] = 11793,
  [12025] = 11800,
  [12026] = 11824,
  [12027] = 11847,
  [12028] = 12028,
  [12029] = 11845,
  [12030] = 11801,
  [12031] = 11789,
  [12032] = 11835,
  [12033] = 12033,
  [12034] = 11790,
  [12035] = 11803,
  [12036] = 12010,
  [12037] = 11837,
  [12038] = 11882,
  [12039] = 12039,
  [12040] = 11838,
  [12041] = 12041,
  [12042] = 11824,
  [12043] = 12043,
  [12044] = 12004,
  [12045] = 11803,
  [12046] = 11908,
  [12047] = 11833,
  [12048] = 11803,
  [12049] = 11826,
  [12050] = 11962,
  [12051] = 11803,
  [12052] = 12052,
  [12053] = 11797,
  [12054] = 12054,
  [12055] = 11818,
  [12056] = 11824,
  [12057] = 11867,
  [12058] = 12058,
  [12059] = 11871,
  [12060] = 11818,
  [12061] = 12061,
  [12062] = 11803,
  [12063] = 11997,
  [12064] = 12064,
  [12065] = 12041,
  [12066] = 11940,
  [12067] = 11889,
  [12068] = 11988,
  [12069] = 12069,
  [12070] = 11805,
  [12071] = 11813,
  [12072] = 12072,
  [12073] = 11805,
  [12074] = 11802,
  [12075] = 12075,
  [12076] = 11795,
  [12077] = 11883,
  [12078] = 12072,
  [12079] = 11822,
  [12080] = 12018,
  [12081] = 11791,
  [12082] = 11955,
  [12083] = 11795,
  [12084] = 11814,
  [12085] = 11838,
  [12086] = 11940,
  [12087] = 1780,
  [12088] = 12088,
  [12089] = 11805,
  [12090] = 12090,
  [12091] = 11800,
  [12092] = 11818,
  [12093] = 12093,
  [12094] = 11803,
  [12095] = 11818,
  [12096] = 12096,
  [12097] = 12097,
  [12098] = 11803,
  [12099] = 11824,
  [12100] = 11940,
  [12101] = 12101,
  [12102] = 11805,
  [12103] = 11803,
  [12104] = 12002,
  [12105] = 11790,
  [12106] = 11858,
  [12107] = 11813,
  [12108] = 11847,
  [12109] = 11810,
  [12110] = 11859,
  [12111] = 12111,
  [12112] = 12011,
  [12113] = 12113,
  [12114] = 11831,
  [12115] = 11835,
  [12116] = 12043,
  [12117] = 11805,
  [12118] = 12041,
  [12119] = 11837,
  [12120] = 12120,
  [12121] = 11838,
  [12122] = 12023,
  [12123] = 12096,
  [12124] = 12058,
  [12125] = 11824,
  [12126] = 11862,
  [12127] = 11827,
  [12128] = 11864,
  [12129] = 11865,
  [12130] = 11866,
  [12131] = 12019,
  [12132] = 11811,
  [12133] = 11867,
  [12134] = 11868,
  [12135] = 11847,
  [12136] = 11869,
  [12137] = 11870,
  [12138] = 11871,
  [12139] = 11872,
  [12140] = 11845,
  [12141] = 11873,
  [12142] = 11968,
  [12143] = 11874,
  [12144] = 11875,
  [12145] = 11810,
  [12146] = 11876,
  [12147] = 11877,
  [12148] = 11878,
  [12149] = 11847,
  [12150] = 11800,
  [12151] = 11872,
  [12152] = 11879,
  [12153] = 11880,
  [12154] = 11815,
  [12155] = 11993,
  [12156] = 11881,
  [12157] = 11882,
  [12158] = 11883,
  [12159] = 11884,
  [12160] = 11885,
  [12161] = 12161,
  [12162] = 12162,
  [12163] = 11841,
  [12164] = 11831,
  [12165] = 12165,
  [12166] = 12003,
  [12167] = 12090,
  [12168] = 11979,
  [12169] = 12113,
  [12170] = 11907,
  [12171] = 11840,
  [12172] = 12172,
  [12173] = 11859,
  [12174] = 11940,
  [12175] = 11873,
  [12176] = 11874,
  [12177] = 11795,
  [12178] = 12178,
  [12179] = 12015,
  [12180] = 11800,
  [12181] = 11837,
  [12182] = 12182,
  [12183] = 12183,
  [12184] = 11791,
  [12185] = 11888,
  [12186] = 12186,
  [12187] = 12187,
  [12188] = 11790,
  [12189] = 12033,
  [12190] = 11940,
  [12191] = 11811,
  [12192] = 12165,
  [12193] = 12003,
  [12194] = 12090,
  [12195] = 11979,
  [12196] = 12113,
  [12197] = 11907,
  [12198] = 11889,
  [12199] = 11818,
  [12200] = 11790,
  [12201] = 11875,
  [12202] = 11890,
  [12203] = 11818,
  [12204] = 11788,
  [12205] = 11891,
  [12206] = 11892,
  [12207] = 12003,
  [12208] = 12090,
  [12209] = 11979,
  [12210] = 12113,
  [12211] = 12211,
  [12212] = 11838,
  [12213] = 12165,
  [12214] = 11876,
  [12215] = 12028,
  [12216] = 11805,
  [12217] = 11877,
  [12218] = 12218,
  [12219] = 11815,
  [12220] = 12218,
  [12221] = 11940,
  [12222] = 11810,
  [12223] = 11858,
  [12224] = 11835,
  [12225] = 12041,
  [12226] = 11878,
  [12227] = 11795,
  [12228] = 11837,
  [12229] = 11847,
  [12230] = 11837,
  [12231] = 11803,
  [12232] = 11881,
  [12233] = 11969,
  [12234] = 11838,
  [12235] = 11890,
  [12236] = 11891,
  [12237] = 11818,
  [12238] = 11892,
  [12239] = 11803,
  [12240] = 12240,
  [12241] = 11994,
  [12242] = 11847,
  [12243] = 12172,
  [12244] = 11822,
  [12245] = 11868,
  [12246] = 11802,
  [12247] = 11822,
  [12248] = 11805,
  [12249] = 11814,
  [12250] = 12250,
  [12251] = 11858,
  [12252] = 11803,
  [12253] = 11847,
  [12254] = 12254,
  [12255] = 11795,
  [12256] = 11862,
  [12257] = 12257,
  [12258] = 11879,
  [12259] = 11790,
  [12260] = 11790,
  [12261] = 12000,
  [12262] = 11884,
  [12263] = 11803,
  [12264] = 11799,
  [12265] = 11911,
  [12266] = 11805,
  [12267] = 11805,
  [12268] = 11795,
  [12269] = 11949,
  [12270] = 11847,
  [12271] = 11805,
  [12272] = 11847,
  [12273] = 11795,
  [12274] = 11824,
  [12275] = 11998,
  [12276] = 12054,
  [12277] = 11847,
  [12278] = 12278,
  [12279] = 11964,
  [12280] = 11847,
  [12281] = 12001,
  [12282] = 11795,
  [12283] = 11824,
  [12284] = 11824,
  [12285] = 12285,
  [12286] = 12007,
  [12287] = 11847,
  [12288] = 11815,
  [12289] = 11940,
  [12290] = 11847,
  [12291] = 11805,
  [12292] = 11805,
  [12293] = 11818,
  [12294] = 11824,
  [12295] = 11818,
  [12296] = 11869,
  [12297] = 11818,
  [12298] = 11851,
  [12299] = 11999,
  [12300] = 12300,
  [12301] = 11837,
  [12302] = 11880,
  [12303] = 11795,
  [12304] = 12304,
  [12305] = 12305,
  [12306] = 12306,
  [12307] = 12307,
  [12308] = 12308,
  [12309] = 12309,
  [12310] = 12310,
  [12311] = 12311,
  [12312] = 12312,
  [12313] = 12313,
  [12314] = 2258,
  [12315] = 12305,
  [12316] = 12316,
  [12317] = 12317,
  [12318] = 1771,
  [12319] = 8119,
  [12320] = 12304,
  [12321] = 12317,
  [12322] = 12305,
  [12323] = 12323,
  [12324] = 12324,
  [12325] = 1800,
  [12326] = 1801,
  [12327] = 12316,
  [12328] = 12328,
  [12329] = 12317,
  [12330] = 12304,
  [12331] = 12305,
  [12332] = 12316,
  [12333] = 12316,
  [12334] = 12317,
  [12335] = 12304,
  [12336] = 12336,
  [12337] = 12305,
  [12338] = 12338,
  [12339] = 12339,
  [12340] = 12340,
  [12341] = 12341,
  [12342] = 12306,
  [12343] = 12343,
  [12344] = 12316,
  [12345] = 12317,
  [12346] = 12304,
  [12347] = 12305,
  [12348] = 12316,
  [12349] = 12316,
  [12350] = 12317,
  [12351] = 12304,
  [12352] = 12305,
  [12353] = 12316,
  [12354] = 12317,
  [12355] = 12304,
  [12356] = 12317,
  [12357] = 12305,
  [12358] = 12316,
  [12359] = 12317,
  [12360] = 12304,
  [12361] = 12305,
  [12362] = 12316,
  [12363] = 12317,
  [12364] = 12304,
  [12365] = 12305,
  [12366] = 12366,
  [12367] = 12304,
  [12368] = 12305,
  [12369] = 12369,
  [12370] = 12370,
  [12371] = 12371,
  [12372] = 12372,
  [12373] = 12307,
  [12374] = 12308,
  [12375] = 12309,
  [12376] = 12306,
  [12377] = 12307,
  [12378] = 12308,
  [12379] = 12309,
  [12380] = 12310,
  [12381] = 12311,
  [12382] = 12312,
  [12383] = 12313,
  [12384] = 12304,
  [12385] = 1799,
  [12386] = 12386,
  [12387] = 12387,
  [12388] = 12388,
  [12389] = 12389,
  [12390] = 12390,
  [12391] = 12316,
  [12392] = 12310,
  [12393] = 12311,
  [12394] = 12317,
  [12395] = 12312,
  [12396] = 12304,
  [12397] = 12305,
  [12398] = 12313,
  [12399] = 12306,
  [12400] = 12307,
  [12401] = 12308,
  [12402] = 12309,
  [12403] = 12310,
  [12404] = 12311,
  [12405] = 12312,
  [12406] = 12313,
  [12407] = 12407,
  [12408] = 12408,
  [12409] = 12409,
  [12410] = 8118,
  [12411] = 12411,
  [12412] = 12316,
  [12413] = 12317,
  [12414] = 12414,
  [12415] = 12415,
  [12416] = 12304,
  [12417] = 12305,
  [12418] = 12418,
  [12419] = 12419,
  [12420] = 12420,
  [12421] = 12421,
  [12422] = 12316,
  [12423] = 12317,
  [12424] = 12304,
  [12425] = 12305,
  [12426] = 12316,
  [12427] = 12317,
  [12428] = 12428,
  [12429] = 1796,
  [12430] = 12430,
  [12431] = 12431,
  [12432] = 12432,
  [12433] = 12433,
  [12434] = 12433,
  [12435] = 12435,
  [12436] = 12435,
  [12437] = 12435,
  [12438] = 12438,
  [12439] = 12439,
  [12440] = 12431,
  [12441] = 1783,
  [12442] = 12433,
  [12443] = 1797,
  [12444] = 12433,
  [12445] = 12433,
  [12446] = 1775,
  [12447] = 12435,
  [12448] = 12435,
  [12449] = 12449,
  [12450] = 12432,
  [12451] = 1784,
  [12452] = 1824,
  [12453] = 12439,
  [12454] = 12454,
  [12455] = 1855,
  [12456] = 1780,
  [12457] = 1781,
  [12458] = 1815,
  [12459] = 1816,
  [12460] = 12454,
  [12461] = 1817,
  [12462] = 1814,
  [12463] = 1782,
  [12464] = 1823,
  [12465] = 12454,
  [12466] = 1779,
  [12467] = 1825,
  [12468] = 1853,
  [12469] = 1850,
  [12470] = 12470,
  [12471] = 1852,
  [12472] = 12472,
  [12473] = 1839,
  [12474] = 1842,
  [12475] = 12470,
  [12476] = 12470,
  [12477] = 8115,
  [12478] = 1835,
  [12479] = 12472,
  [12480] = 12472,
  [12481] = 12470,
  [12482] = 12470,
  [12483] = 12472,
  [12484] = 1851,
  [12485] = 12470,
  [12486] = 1848,
  [12487] = 12472,
  [12488] = 12472,
  [12489] = 1845,
  [12490] = 1846,
  [12491] = 1847,
  [12492] = 12492,
  [12493] = 1836,
  [12494] = 2258,
  [12495] = 1856,
  [12496] = 1849,
  [12497] = 1843,
  [12498] = 8114,
  [12499] = 1858,
  [12500] = 12470,
  [12501] = 12472,
  [12502] = 1844,
  [12503] = 12503,
  [12504] = 12504,
  [12505] = 12505,
  [12506] = 12506,
  [12507] = 12507,
  [12508] = 10302,
  [12509] = 12509,
  [12510] = 12510,
  [12511] = 12511,
  [12512] = 12512,
  [12513] = 12513,
  [12514] = 12514,
  [12515] = 12515,
  [12516] = 12516,
  [12517] = 12517,
  [12518] = 12518,
  [12519] = 12519,
  [12520] = 12520,
  [12521] = 12521,
  [12522] = 12522,
  [12523] = 12523,
  [12524] = 12524,
  [12525] = 12525,
  [12526] = 12526,
  [12527] = 12527,
  [12528] = 12528,
  [12529] = 12529,
  [12530] = 12530,
  [12531] = 12517,
  [12532] = 12532,
  [12533] = 12533,
  [12534] = 12534,
  [12535] = 12535,
  [12536] = 12536,
  [12537] = 12503,
  [12538] = 12538,
  [12539] = 12539,
  [12540] = 12540,
  [12541] = 12541,
  [12542] = 12542,
  [12543] = 12509,
  [12544] = 12511,
  [12545] = 12513,
  [12546] = 12514,
  [12547] = 12527,
  [12548] = 12548,
  [12549] = 12549,
  [12550] = 12550,
  [12551] = 12551,
  [12552] = 12528,
  [12553] = 12553,
  [12554] = 12554,
  [12555] = 12555,
  [12556] = 12556,
  [12557] = 12557,
  [12558] = 12558,
  [12559] = 12559,
  [12560] = 12560,
  [12561] = 12561,
  [12562] = 12562,
  [12563] = 12563,
  [12564] = 12564,
  [12565] = 12565,
  [12566] = 12566,
  [12567] = 12567,
  [12568] = 12568,
  [12569] = 12569,
  [12570] = 12570,
  [12571] = 12571,
  [12572] = 12572,
  [12573] = 12573,
  [12574] = 12574,
  [12575] = 12575,
  [12576] = 12576,
  [12577] = 12510,
  [12578] = 12512,
  [12579] = 12515,
  [12580] = 12516,
  [12581] = 12518,
  [12582] = 12519,
  [12583] = 12520,
  [12584] = 12521,
  [12585] = 12522,
  [12586] = 12523,
  [12587] = 12524,
  [12588] = 12526,
  [12589] = 12589,
  [12590] = 12590,
  [12591] = 12591,
  [12592] = 12592,
  [12593] = 12593,
  [12594] = 12594,
  [12595] = 12595,
  [12596] = 12553,
  [12597] = 12554,
  [12598] = 12548,
  [12599] = 12589,
  [12600] = 12600,
  [12601] = 12590,
  [12602] = 12591,
  [12603] = 12505,
  [12604] = 12592,
  [12605] = 12593,
  [12606] = 12594,
  [12607] = 12607,
  [12608] = 12608,
  [12609] = 12555,
  [12610] = 12517,
  [12611] = 12549,
  [12612] = 12595,
  [12613] = 12613,
  [12614] = 12550,
  [12615] = 12551,
  [12616] = 12525,
  [12617] = 12617,
  [12618] = 12618,
  [12619] = 12529,
  [12620] = 12620,
  [12621] = 12621,
  [12622] = 12622,
  [12623] = 12532,
  [12624] = 12533,
  [12625] = 12534,
  [12626] = 12535,
  [12627] = 12536,
  [12628] = 12503,
  [12629] = 12538,
  [12630] = 12539,
  [12631] = 12540,
  [12632] = 12541,
  [12633] = 12542,
  [12634] = 12509,
  [12635] = 12511,
  [12636] = 12513,
  [12637] = 12514,
  [12638] = 12527,
  [12639] = 12548,
  [12640] = 12549,
  [12641] = 12550,
  [12642] = 12551,
  [12643] = 12528,
  [12644] = 12553,
  [12645] = 12554,
  [12646] = 12555,
  [12647] = 12556,
  [12648] = 12557,
  [12649] = 12558,
  [12650] = 12559,
  [12651] = 12560,
  [12652] = 12561,
  [12653] = 12562,
  [12654] = 12563,
  [12655] = 12564,
  [12656] = 12565,
  [12657] = 12566,
  [12658] = 12567,
  [12659] = 12568,
  [12660] = 12569,
  [12661] = 12570,
  [12662] = 12571,
  [12663] = 12572,
  [12664] = 12573,
  [12665] = 12574,
  [12666] = 12575,
  [12667] = 12576,
  [12668] = 12510,
  [12669] = 12512,
  [12670] = 12515,
  [12671] = 12516,
  [12672] = 12518,
  [12673] = 12519,
  [12674] = 12520,
  [12675] = 12521,
  [12676] = 12522,
  [12677] = 12523,
  [12678] = 12524,
  [12679] = 12526,
  [12680] = 12589,
  [12681] = 12590,
  [12682] = 12591,
  [12683] = 12592,
  [12684] = 12593,
  [12685] = 12594,
  [12686] = 12595,
  [12687] = 12687,
  [12688] = 12688,
  [12689] = 12689,
  [12690] = 12690,
  [12691] = 12691,
  [12692] = 12505,
  [12693] = 12693,
  [12694] = 12694,
  [12695] = 12517,
  [12696] = 12696,
  [12697] = 12697,
  [12698] = 12525,
  [12699] = 12699,
  [12700] = 12529,
  [12701] = 12701,
  [12702] = 12702,
  [12703] = 12532,
  [12704] = 12533,
  [12705] = 12534,
  [12706] = 12535,
  [12707] = 12536,
  [12708] = 12503,
  [12709] = 12538,
  [12710] = 12539,
  [12711] = 12540,
  [12712] = 12541,
  [12713] = 12542,
  [12714] = 12509,
  [12715] = 12511,
  [12716] = 12513,
  [12717] = 12514,
  [12718] = 12527,
  [12719] = 12548,
  [12720] = 12549,
  [12721] = 12550,
  [12722] = 12551,
  [12723] = 12528,
  [12724] = 12553,
  [12725] = 12554,
  [12726] = 12555,
  [12727] = 12556,
  [12728] = 12557,
  [12729] = 12558,
  [12730] = 12559,
  [12731] = 12560,
  [12732] = 12561,
  [12733] = 12562,
  [12734] = 12563,
  [12735] = 12564,
  [12736] = 12565,
  [12737] = 12566,
  [12738] = 12567,
  [12739] = 12568,
  [12740] = 12569,
  [12741] = 12570,
  [12742] = 12571,
  [12743] = 12572,
  [12744] = 12573,
  [12745] = 12574,
  [12746] = 12575,
  [12747] = 12576,
  [12748] = 12510,
  [12749] = 12512,
  [12750] = 12515,
  [12751] = 12516,
  [12752] = 12518,
  [12753] = 12519,
  [12754] = 12520,
  [12755] = 12521,
  [12756] = 12522,
  [12757] = 12523,
  [12758] = 12524,
  [12759] = 12526,
  [12760] = 12589,
  [12761] = 12590,
  [12762] = 12591,
  [12763] = 12592,
  [12764] = 12593,
  [12765] = 12594,
  [12766] = 12595,
  [12767] = 12767,
  [12768] = 12768,
  [12769] = 12769,
  [12770] = 12770,
  [12771] = 12771,
  [12772] = 12772,
  [12773] = 12505,
  [12774] = 12505,
  [12775] = 12775,
  [12776] = 12776,
  [12777] = 12777,
  [12778] = 12517,
  [12779] = 12779,
  [12780] = 12525,
  [12781] = 12781,
  [12782] = 12529,
  [12783] = 12532,
  [12784] = 12533,
  [12785] = 12534,
  [12786] = 12535,
  [12787] = 12536,
  [12788] = 12503,
  [12789] = 12538,
  [12790] = 12539,
  [12791] = 12540,
  [12792] = 12541,
  [12793] = 12542,
  [12794] = 12509,
  [12795] = 12511,
  [12796] = 12513,
  [12797] = 12514,
  [12798] = 12527,
  [12799] = 12548,
  [12800] = 12549,
  [12801] = 12550,
  [12802] = 12551,
  [12803] = 12528,
  [12804] = 12553,
  [12805] = 12554,
  [12806] = 12555,
  [12807] = 12556,
  [12808] = 12557,
  [12809] = 12558,
  [12810] = 12559,
  [12811] = 12560,
  [12812] = 12561,
  [12813] = 12562,
  [12814] = 12563,
  [12815] = 12564,
  [12816] = 12565,
  [12817] = 12566,
  [12818] = 12567,
  [12819] = 12568,
  [12820] = 12569,
  [12821] = 12570,
  [12822] = 12571,
  [12823] = 12572,
  [12824] = 12573,
  [12825] = 12574,
  [12826] = 12575,
  [12827] = 12576,
  [12828] = 12510,
  [12829] = 12512,
  [12830] = 12515,
  [12831] = 12516,
  [12832] = 12518,
  [12833] = 12519,
  [12834] = 12520,
  [12835] = 12521,
  [12836] = 12522,
  [12837] = 12523,
  [12838] = 12524,
  [12839] = 12526,
  [12840] = 12589,
  [12841] = 12590,
  [12842] = 12591,
  [12843] = 12592,
  [12844] = 12593,
  [12845] = 12594,
  [12846] = 12595,
  [12847] = 12847,
  [12848] = 12848,
  [12849] = 12556,
  [12850] = 12848,
  [12851] = 12557,
  [12852] = 12536,
  [12853] = 12503,
  [12854] = 12549,
  [12855] = 12550,
  [12856] = 12551,
  [12857] = 12570,
  [12858] = 12571,
  [12859] = 12572,
  [12860] = 12526,
  [12861] = 12558,
  [12862] = 12559,
  [12863] = 12560,
  [12864] = 12528,
  [12865] = 12561,
  [12866] = 12562,
  [12867] = 12563,
  [12868] = 12503,
  [12869] = 12549,
  [12870] = 12550,
  [12871] = 12551,
  [12872] = 12570,
  [12873] = 12571,
  [12874] = 12572,
  [12875] = 12526,
  [12876] = 12553,
  [12877] = 12564,
  [12878] = 12554,
  [12879] = 12879,
  [12880] = 12565,
  [12881] = 12505,
  [12882] = 12882,
  [12883] = 12503,
  [12884] = 12549,
  [12885] = 12550,
  [12886] = 12551,
  [12887] = 12570,
  [12888] = 12571,
  [12889] = 12572,
  [12890] = 12526,
  [12891] = 12517,
  [12892] = 12503,
  [12893] = 12549,
  [12894] = 12550,
  [12895] = 12551,
  [12896] = 12570,
  [12897] = 12571,
  [12898] = 12572,
  [12899] = 12526,
  [12900] = 12503,
  [12901] = 12549,
  [12902] = 12550,
  [12903] = 12551,
  [12904] = 12570,
  [12905] = 12571,
  [12906] = 12572,
  [12907] = 12526,
  [12908] = 12503,
  [12909] = 12549,
  [12910] = 12550,
  [12911] = 12551,
  [12912] = 12570,
  [12913] = 12571,
  [12914] = 12572,
  [12915] = 12526,
  [12916] = 12916,
  [12917] = 12549,
  [12918] = 12550,
  [12919] = 12551,
  [12920] = 12570,
  [12921] = 12571,
  [12922] = 12572,
  [12923] = 12526,
  [12924] = 12503,
  [12925] = 12549,
  [12926] = 12550,
  [12927] = 12551,
  [12928] = 12570,
  [12929] = 12571,
  [12930] = 12572,
  [12931] = 12526,
  [12932] = 12503,
  [12933] = 12549,
  [12934] = 12550,
  [12935] = 12551,
  [12936] = 12570,
  [12937] = 12571,
  [12938] = 12572,
  [12939] = 12526,
  [12940] = 12503,
  [12941] = 12549,
  [12942] = 12550,
  [12943] = 12551,
  [12944] = 12570,
  [12945] = 12571,
  [12946] = 12572,
  [12947] = 12526,
  [12948] = 12503,
  [12949] = 12549,
  [12950] = 12550,
  [12951] = 12551,
  [12952] = 12570,
  [12953] = 12571,
  [12954] = 12572,
  [12955] = 12526,
  [12956] = 12503,
  [12957] = 12549,
  [12958] = 12550,
  [12959] = 12551,
  [12960] = 12570,
  [12961] = 12571,
  [12962] = 12572,
  [12963] = 12526,
  [12964] = 12555,
  [12965] = 12965,
  [12966] = 12566,
  [12967] = 12567,
  [12968] = 12517,
  [12969] = 12556,
  [12970] = 12557,
  [12971] = 12558,
  [12972] = 12559,
  [12973] = 12525,
  [12974] = 12560,
  [12975] = 12561,
  [12976] = 12562,
  [12977] = 12563,
  [12978] = 12564,
  [12979] = 12565,
  [12980] = 12568,
  [12981] = 12569,
  [12982] = 12566,
  [12983] = 12567,
  [12984] = 12568,
  [12985] = 12569,
  [12986] = 12529,
  [12987] = 12534,
  [12988] = 12535,
  [12989] = 12525,
  [12990] = 12529,
  [12991] = 12570,
  [12992] = 12571,
  [12993] = 12572,
  [12994] = 12570,
  [12995] = 12503,
  [12996] = 12571,
  [12997] = 12529,
  [12998] = 12532,
  [12999] = 12548,
  [13000] = 13000,
  [13001] = 12533,
  [13002] = 12600,
  [13003] = 12534,
  [13004] = 12535,
  [13005] = 12536,
  [13006] = 12503,
  [13007] = 12505,
  [13008] = 12538,
  [13009] = 12539,
  [13010] = 12540,
  [13011] = 12541,
  [13012] = 12542,
  [13013] = 12509,
  [13014] = 12511,
  [13015] = 12513,
  [13016] = 12514,
  [13017] = 12527,
  [13018] = 12548,
  [13019] = 12549,
  [13020] = 12550,
  [13021] = 12551,
  [13022] = 12572,
  [13023] = 12528,
  [13024] = 12553,
  [13025] = 12554,
  [13026] = 12555,
  [13027] = 12556,
  [13028] = 12557,
  [13029] = 12558,
  [13030] = 12559,
  [13031] = 12560,
  [13032] = 12561,
  [13033] = 12562,
  [13034] = 12563,
  [13035] = 12564,
  [13036] = 12565,
  [13037] = 12566,
  [13038] = 12567,
  [13039] = 12568,
  [13040] = 12569,
  [13041] = 12527,
  [13042] = 12570,
  [13043] = 12571,
  [13044] = 12572,
  [13045] = 12550,
  [13046] = 12551,
  [13047] = 12532,
  [13048] = 12573,
  [13049] = 12574,
  [13050] = 12575,
  [13051] = 12576,
  [13052] = 12510,
  [13053] = 12512,
  [13054] = 12515,
  [13055] = 12516,
  [13056] = 12518,
  [13057] = 12519,
  [13058] = 12520,
  [13059] = 12521,
  [13060] = 12522,
  [13061] = 12523,
  [13062] = 12524,
  [13063] = 12526,
  [13064] = 12533,
  [13065] = 12530,
  [13066] = 12534,
  [13067] = 12535,
  [13068] = 12589,
  [13069] = 12590,
  [13070] = 12591,
  [13071] = 12592,
  [13072] = 12593,
  [13073] = 12594,
  [13074] = 12607,
  [13075] = 12608,
  [13076] = 12536,
  [13077] = 12595,
  [13078] = 12613,
  [13079] = 12617,
  [13080] = 12618,
  [13081] = 12620,
  [13082] = 12621,
  [13083] = 12622,
  [13084] = 12687,
  [13085] = 12688,
  [13086] = 12689,
  [13087] = 12690,
  [13088] = 12691,
  [13089] = 12693,
  [13090] = 12694,
  [13091] = 12696,
  [13092] = 12697,
  [13093] = 12699,
  [13094] = 12701,
  [13095] = 12702,
  [13096] = 12767,
  [13097] = 12768,
  [13098] = 12769,
  [13099] = 12770,
  [13100] = 12771,
  [13101] = 12772,
  [13102] = 12775,
  [13103] = 12776,
  [13104] = 12777,
  [13105] = 12779,
  [13106] = 12781,
  [13107] = 12847,
  [13108] = 12848,
  [13109] = 12573,
  [13110] = 12503,
  [13111] = 12538,
  [13112] = 12574,
  [13113] = 12575,
  [13114] = 12576,
  [13115] = 12539,
  [13116] = 12540,
  [13117] = 12541,
  [13118] = 12510,
  [13119] = 12542,
  [13120] = 12512,
  [13121] = 12515,
  [13122] = 12509,
  [13123] = 12516,
  [13124] = 12518,
  [13125] = 12511,
  [13126] = 12513,
  [13127] = 12514,
  [13128] = 12527,
  [13129] = 12549,
  [13130] = 12548,
  [13131] = 12519,
  [13132] = 12549,
  [13133] = 12520,
  [13134] = 12521,
  [13135] = 12522,
  [13136] = 12523,
  [13137] = 12524,
  [13138] = 12526,
  [13139] = 12550,
  [13140] = 12551,
  [13141] = 12505,
  [13142] = 12530,
  [13143] = 12528,
  [13144] = 12553,
  [13145] = 12554,
  [13146] = 12517,
  [13147] = 12525,
  [13148] = 12555,
  [13149] = 12525,
  [13150] = 12589,
  [13151] = 12590,
  [13152] = 12591,
  [13153] = 12592,
  [13154] = 12556,
  [13155] = 12593,
  [13156] = 12529,
  [13157] = 12557,
  [13158] = 12916,
  [13159] = 12558,
  [13160] = 12600,
  [13161] = 12594,
  [13162] = 12607,
  [13163] = 12532,
  [13164] = 12608,
  [13165] = 12559,
  [13166] = 12532,
  [13167] = 12560,
  [13168] = 12916,
  [13169] = 12561,
  [13170] = 12600,
  [13171] = 13171,
  [13172] = 12533,
  [13173] = 12534,
  [13174] = 12535,
  [13175] = 12536,
  [13176] = 10894,
  [13177] = 12573,
  [13178] = 12916,
  [13179] = 12562,
  [13180] = 12600,
  [13181] = 12503,
  [13182] = 12538,
  [13183] = 12539,
  [13184] = 12540,
  [13185] = 12541,
  [13186] = 12542,
  [13187] = 12509,
  [13188] = 12511,
  [13189] = 12513,
  [13190] = 12514,
  [13191] = 12527,
  [13192] = 12548,
  [13193] = 12549,
  [13194] = 12563,
  [13195] = 12916,
  [13196] = 12564,
  [13197] = 12600,
  [13198] = 12550,
  [13199] = 12551,
  [13200] = 12565,
  [13201] = 12528,
  [13202] = 12553,
  [13203] = 12554,
  [13204] = 12916,
  [13205] = 12600,
  [13206] = 12555,
  [13207] = 12556,
  [13208] = 12557,
  [13209] = 12558,
  [13210] = 12559,
  [13211] = 12560,
  [13212] = 12561,
  [13213] = 12595,
  [13214] = 12562,
  [13215] = 12563,
  [13216] = 12916,
  [13217] = 12600,
  [13218] = 12564,
  [13219] = 12565,
  [13220] = 12566,
  [13221] = 12567,
  [13222] = 12568,
  [13223] = 12916,
  [13224] = 12600,
  [13225] = 12569,
  [13226] = 12916,
  [13227] = 12600,
  [13228] = 12570,
  [13229] = 12571,
  [13230] = 12916,
  [13231] = 12600,
  [13232] = 12916,
  [13233] = 12600,
  [13234] = 12916,
  [13235] = 12600,
  [13236] = 12572,
  [13237] = 12566,
  [13238] = 12567,
  [13239] = 12568,
  [13240] = 12573,
  [13241] = 12574,
  [13242] = 12575,
  [13243] = 12576,
  [13244] = 12510,
  [13245] = 12512,
  [13246] = 12515,
  [13247] = 12569,
  [13248] = 12516,
  [13249] = 12518,
  [13250] = 12519,
  [13251] = 12520,
  [13252] = 12521,
  [13253] = 12522,
  [13254] = 12965,
  [13255] = 12523,
  [13256] = 12524,
  [13257] = 12526,
  [13258] = 12570,
  [13259] = 12530,
  [13260] = 12571,
  [13261] = 12572,
  [13262] = 12589,
  [13263] = 12590,
  [13264] = 12591,
  [13265] = 12592,
  [13266] = 12593,
  [13267] = 12594,
  [13268] = 12607,
  [13269] = 12608,
  [13270] = 12573,
  [13271] = 12595,
  [13272] = 12613,
  [13273] = 12617,
  [13274] = 12618,
  [13275] = 12620,
  [13276] = 12621,
  [13277] = 12622,
  [13278] = 12687,
  [13279] = 12688,
  [13280] = 12689,
  [13281] = 12690,
  [13282] = 12691,
  [13283] = 12693,
  [13284] = 12694,
  [13285] = 12696,
  [13286] = 12697,
  [13287] = 12699,
  [13288] = 12701,
  [13289] = 12702,
  [13290] = 12767,
  [13291] = 12768,
  [13292] = 12769,
  [13293] = 12770,
  [13294] = 12771,
  [13295] = 12772,
  [13296] = 12775,
  [13297] = 12776,
  [13298] = 12777,
  [13299] = 12779,
  [13300] = 12781,
  [13301] = 12847,
  [13302] = 12848,
  [13303] = 13303,
  [13304] = 12613,
  [13305] = 12617,
  [13306] = 12574,
  [13307] = 12618,
  [13308] = 12620,
  [13309] = 12575,
  [13310] = 12576,
  [13311] = 12510,
  [13312] = 12512,
  [13313] = 12965,
  [13314] = 12621,
  [13315] = 12515,
  [13316] = 12516,
  [13317] = 12518,
  [13318] = 12965,
  [13319] = 12519,
  [13320] = 12505,
  [13321] = 12622,
  [13322] = 12687,
  [13323] = 12688,
  [13324] = 12689,
  [13325] = 12520,
  [13326] = 12690,
  [13327] = 12691,
  [13328] = 12517,
  [13329] = 12521,
  [13330] = 12693,
  [13331] = 12694,
  [13332] = 12696,
  [13333] = 12697,
  [13334] = 12522,
  [13335] = 12523,
  [13336] = 12524,
  [13337] = 12525,
  [13338] = 12699,
  [13339] = 12701,
  [13340] = 12702,
  [13341] = 12767,
  [13342] = 12526,
  [13343] = 12529,
  [13344] = 12768,
  [13345] = 12769,
  [13346] = 12770,
  [13347] = 12771,
  [13348] = 12772,
  [13349] = 12775,
  [13350] = 12589,
  [13351] = 12532,
  [13352] = 12776,
  [13353] = 12590,
  [13354] = 12591,
  [13355] = 12592,
  [13356] = 12593,
  [13357] = 12533,
  [13358] = 12534,
  [13359] = 12535,
  [13360] = 12536,
  [13361] = 12594,
  [13362] = 12595,
  [13363] = 12574,
  [13364] = 12575,
  [13365] = 12777,
  [13366] = 12503,
  [13367] = 12538,
  [13368] = 12533,
  [13369] = 12539,
  [13370] = 12540,
  [13371] = 12779,
  [13372] = 12916,
  [13373] = 12600,
  [13374] = 12538,
  [13375] = 12539,
  [13376] = 12540,
  [13377] = 12541,
  [13378] = 12542,
  [13379] = 12509,
  [13380] = 12511,
  [13381] = 12513,
  [13382] = 12514,
  [13383] = 12576,
  [13384] = 12541,
  [13385] = 12781,
  [13386] = 12847,
  [13387] = 12542,
  [13388] = 12916,
  [13389] = 13389,
  [13390] = 13390,
  [13391] = 13391,
  [13392] = 13392,
  [13393] = 13393,
  [13394] = 13394,
  [13395] = 13395,
  [13396] = 13396,
  [13397] = 13397,
  [13398] = 13398,
  [13399] = 13399,
  [13400] = 13400,
  [13401] = 13401,
  [13402] = 13402,
  [13403] = 13403,
  [13404] = 13390,
  [13405] = 13405,
  [13406] = 13406,
  [13407] = 13407,
  [13408] = 13395,
  [13409] = 13409,
  [13410] = 13410,
  [13411] = 13411,
  [13412] = 13412,
  [13413] = 13413,
  [13414] = 13414,
  [13415] = 13415,
  [13416] = 13416,
  [13417] = 13417,
  [13418] = 13418,
  [13419] = 13419,
  [13420] = 13420,
  [13421] = 13421,
  [13422] = 13422,
  [13423] = 13423,
  [13424] = 13424,
  [13425] = 13425,
  [13426] = 13426,
  [13427] = 13427,
  [13428] = 13428,
  [13429] = 13429,
  [13430] = 13430,
  [13431] = 13431,
  [13432] = 13403,
  [13433] = 13433,
  [13434] = 13427,
  [13435] = 13433,
  [13436] = 13436,
  [13437] = 13437,
  [13438] = 13438,
  [13439] = 13439,
  [13440] = 13440,
  [13441] = 13441,
  [13442] = 13442,
  [13443] = 13436,
  [13444] = 13444,
  [13445] = 13445,
  [13446] = 13446,
  [13447] = 13447,
  [13448] = 13448,
  [13449] = 13449,
  [13450] = 13450,
  [13451] = 13451,
  [13452] = 13452,
  [13453] = 13453,
  [13454] = 13454,
  [13455] = 13455,
  [13456] = 13456,
  [13457] = 13457,
  [13458] = 13455,
  [13459] = 13412,
  [13460] = 13413,
  [13461] = 13401,
  [13462] = 13416,
  [13463] = 13463,
  [13464] = 13464,
  [13465] = 13465,
  [13466] = 13466,
  [13467] = 13467,
  [13468] = 10398,
  [13469] = 13437,
  [13470] = 13470,
  [13471] = 13471,
  [13472] = 13396,
  [13473] = 13466,
  [13474] = 13474,
  [13475] = 13475,
  [13476] = 13391,
  [13477] = 13438,
  [13478] = 13478,
  [13479] = 13393,
  [13480] = 13394,
  [13481] = 13481,
  [13482] = 13425,
  [13483] = 13426,
  [13484] = 13439,
  [13485] = 13428,
  [13486] = 13449,
  [13487] = 13401,
  [13488] = 13416,
  [13489] = 13489,
  [13490] = 13490,
  [13491] = 13440,
  [13492] = 13470,
  [13493] = 13493,
  [13494] = 13471,
  [13495] = 13495,
  [13496] = 13496,
  [13497] = 13474,
  [13498] = 13397,
  [13499] = 13499,
  [13500] = 13500,
  [13501] = 13466,
  [13502] = 13502,
  [13503] = 13391,
  [13504] = 13442,
  [13505] = 13505,
  [13506] = 13393,
  [13507] = 13394,
  [13508] = 13508,
  [13509] = 13425,
  [13510] = 13426,
  [13511] = 13490,
  [13512] = 13428,
  [13513] = 13449,
  [13514] = 13401,
  [13515] = 13416,
  [13516] = 13500,
  [13517] = 13517,
  [13518] = 13518,
  [13519] = 13412,
  [13520] = 13413,
  [13521] = 13398,
  [13522] = 13391,
  [13523] = 13523,
  [13524] = 13445,
  [13525] = 13467,
  [13526] = 13393,
  [13527] = 13466,
  [13528] = 13394,
  [13529] = 13529,
  [13530] = 13391,
  [13531] = 13395,
  [13532] = 13396,
  [13533] = 13393,
  [13534] = 13394,
  [13535] = 13397,
  [13536] = 13425,
  [13537] = 13426,
  [13538] = 13446,
  [13539] = 13428,
  [13540] = 13449,
  [13541] = 13401,
  [13542] = 13416,
  [13543] = 13398,
  [13544] = 13517,
  [13545] = 13399,
  [13546] = 13400,
  [13547] = 13466,
  [13548] = 13447,
  [13549] = 13402,
  [13550] = 13391,
  [13551] = 13551,
  [13552] = 13399,
  [13553] = 13393,
  [13554] = 13394,
  [13555] = 13405,
  [13556] = 13425,
  [13557] = 13426,
  [13558] = 13406,
  [13559] = 13428,
  [13560] = 13449,
  [13561] = 13401,
  [13562] = 13416,
  [13563] = 13407,
  [13564] = 13449,
  [13565] = 13466,
  [13566] = 13409,
  [13567] = 13567,
  [13568] = 13391,
  [13569] = 13411,
  [13570] = 13570,
  [13571] = 13393,
  [13572] = 13394,
  [13573] = 13400,
  [13574] = 13425,
  [13575] = 13426,
  [13576] = 13414,
  [13577] = 13428,
  [13578] = 13449,
  [13579] = 13401,
  [13580] = 13416,
  [13581] = 13415,
  [13582] = 13466,
  [13583] = 13417,
  [13584] = 13391,
  [13585] = 13585,
  [13586] = 13586,
  [13587] = 13393,
  [13588] = 13394,
  [13589] = 13420,
  [13590] = 13425,
  [13591] = 13426,
  [13592] = 13421,
  [13593] = 13428,
  [13594] = 13449,
  [13595] = 13416,
  [13596] = 13596,
  [13597] = 13422,
  [13598] = 13466,
  [13599] = 13551,
  [13600] = 13471,
  [13601] = 13391,
  [13602] = 13425,
  [13603] = 13426,
  [13604] = 13393,
  [13605] = 13394,
  [13606] = 13606,
  [13607] = 13425,
  [13608] = 13426,
  [13609] = 13428,
  [13610] = 13428,
  [13611] = 13449,
  [13612] = 13416,
  [13613] = 13478,
  [13614] = 13429,
  [13615] = 13430,
  [13616] = 13466,
  [13617] = 13431,
  [13618] = 13403,
  [13619] = 13391,
  [13620] = 13620,
  [13621] = 13427,
  [13622] = 13393,
  [13623] = 13394,
  [13624] = 13433,
  [13625] = 13425,
  [13626] = 13426,
  [13627] = 13436,
  [13628] = 13428,
  [13629] = 13449,
  [13630] = 13437,
  [13631] = 13463,
  [13632] = 13466,
  [13633] = 13438,
  [13634] = 13439,
  [13635] = 13391,
  [13636] = 13440,
  [13637] = 13637,
  [13638] = 13393,
  [13639] = 13394,
  [13640] = 13442,
  [13641] = 13425,
  [13642] = 13426,
  [13643] = 13428,
  [13644] = 13449,
  [13645] = 13645,
  [13646] = 13445,
  [13647] = 13466,
  [13648] = 13446,
  [13649] = 13447,
  [13650] = 13391,
  [13651] = 13449,
  [13652] = 13393,
  [13653] = 13394,
  [13654] = 13450,
  [13655] = 13425,
  [13656] = 13426,
  [13657] = 13451,
  [13658] = 13428,
  [13659] = 13449,
  [13660] = 13452,
  [13661] = 13453,
  [13662] = 13466,
  [13663] = 13454,
  [13664] = 13402,
  [13665] = 13391,
  [13666] = 13456,
  [13667] = 13667,
  [13668] = 13393,
  [13669] = 13394,
  [13670] = 13670,
  [13671] = 13425,
  [13672] = 13426,
  [13673] = 13673,
  [13674] = 13428,
  [13675] = 13449,
  [13676] = 13676,
  [13677] = 13457,
  [13678] = 13466,
  [13679] = 13679,
  [13680] = 13680,
  [13681] = 13391,
  [13682] = 13682,
  [13683] = 13683,
  [13684] = 13393,
  [13685] = 13394,
  [13686] = 13508,
  [13687] = 13425,
  [13688] = 13426,
  [13689] = 13412,
  [13690] = 13428,
  [13691] = 13449,
  [13692] = 13481,
  [13693] = 13529,
  [13694] = 13694,
  [13695] = 13695,
  [13696] = 13413,
  [13697] = 13401,
  [13698] = 13416,
  [13699] = 13502,
  [13700] = 13570,
  [13701] = 10641,
  [13702] = 13702,
  [13703] = 13703,
  [13704] = 13490,
  [13705] = 13705,
  [13706] = 13517,
  [13707] = 13495,
  [13708] = 13496,
  [13709] = 13705,
  [13710] = 13695,
  [13711] = 13499,
  [13712] = 13712,
  [13713] = 13567,
  [13714] = 13714,
  [13715] = 13715,
  [13716] = 13716,
  [13717] = 13717,
  [13718] = 11037,
  [13719] = 13719,
  [13720] = 13720,
  [13721] = 13721,
  [13722] = 13722,
  [13723] = 13723,
  [13724] = 13724,
  [13725] = 13725,
  [13726] = 13726,
  [13727] = 13410,
  [13728] = 13419,
  [13729] = 13444,
  [13730] = 13448,
  [13731] = 13731,
  [13732] = 13732,
  [13733] = 13733,
  [13734] = 13505,
  [13735] = 13392,
  [13736] = 13450,
  [13737] = 13714,
  [13738] = 13738,
  [13739] = 13739,
  [13740] = 13518,
  [13741] = 13416,
  [13742] = 13742,
  [13743] = 13551,
  [13744] = 11061,
  [13745] = 13745,
  [13746] = 13746,
  [13747] = 13645,
  [13748] = 13748,
  [13749] = 13391,
  [13750] = 13694,
  [13751] = 13695,
  [13752] = 13451,
  [13753] = 13517,
  [13754] = 13390,
  [13755] = 13502,
  [13756] = 13570,
  [13757] = 13393,
  [13758] = 13394,
  [13759] = 13463,
  [13760] = 13466,
  [13761] = 13705,
  [13762] = 13715,
  [13763] = 13716,
  [13764] = 13717,
  [13765] = 13719,
  [13766] = 13720,
  [13767] = 13721,
  [13768] = 13722,
  [13769] = 13723,
  [13770] = 13724,
  [13771] = 13725,
  [13772] = 13726,
  [13773] = 13773,
  [13774] = 13645,
  [13775] = 13452,
  [13776] = 13715,
  [13777] = 13453,
  [13778] = 13410,
  [13779] = 13716,
  [13780] = 13419,
  [13781] = 13444,
  [13782] = 13448,
  [13783] = 13717,
  [13784] = 13508,
  [13785] = 13714,
  [13786] = 13392,
  [13787] = 13454,
  [13788] = 13412,
  [13789] = 13789,
  [13790] = 13790,
  [13791] = 13567,
  [13792] = 13792,
  [13793] = 13413,
  [13794] = 13794,
  [13795] = 13551,
  [13796] = 13412,
  [13797] = 13529,
  [13798] = 13798,
  [13799] = 13645,
  [13800] = 13694,
  [13801] = 13695,
  [13802] = 13502,
  [13803] = 13570,
  [13804] = 13804,
  [13805] = 13413,
  [13806] = 13418,
  [13807] = 13418,
  [13808] = 13456,
  [13809] = 13705,
  [13810] = 13423,
  [13811] = 13424,
  [13812] = 13812,
  [13813] = 13715,
  [13814] = 13716,
  [13815] = 13717,
  [13816] = 13390,
  [13817] = 13441,
  [13818] = 13719,
  [13819] = 13518,
  [13820] = 13423,
  [13821] = 13424,
  [13822] = 13405,
  [13823] = 13720,
  [13824] = 13721,
  [13825] = 13722,
  [13826] = 13723,
  [13827] = 13724,
  [13828] = 13725,
  [13829] = 13418,
  [13830] = 13726,
  [13831] = 13410,
  [13832] = 13419,
  [13833] = 13444,
  [13834] = 13448,
  [13835] = 13406,
  [13836] = 13466,
  [13837] = 13407,
  [13838] = 13441,
  [13839] = 13423,
  [13840] = 13470,
  [13841] = 13471,
  [13842] = 13424,
  [13843] = 13474,
  [13844] = 13844,
  [13845] = 13667,
  [13846] = 13714,
  [13847] = 13478,
  [13848] = 13481,
  [13849] = 13670,
  [13850] = 13490,
  [13851] = 13441,
  [13852] = 13673,
  [13853] = 13500,
  [13854] = 13495,
  [13855] = 13496,
  [13856] = 13676,
  [13857] = 13499,
  [13858] = 13474,
  [13859] = 13859,
  [13860] = 13466,
  [13861] = 13466,
  [13862] = 13505,
  [13863] = 13457,
  [13864] = 13864,
  [13865] = 13470,
  [13866] = 13518,
  [13867] = 13471,
  [13868] = 13470,
  [13869] = 13474,
  [13870] = 13471,
  [13871] = 13391,
  [13872] = 13872,
  [13873] = 13478,
  [13874] = 13393,
  [13875] = 13394,
  [13876] = 13481,
  [13877] = 13773,
  [13878] = 13474,
  [13879] = 13490,
  [13880] = 13409,
  [13881] = 13508,
  [13882] = 13395,
  [13883] = 13396,
  [13884] = 13397,
  [13885] = 13885,
  [13886] = 13398,
  [13887] = 13399,
  [13888] = 13400,
  [13889] = 13478,
  [13890] = 13402,
  [13891] = 13495,
  [13892] = 13496,
  [13893] = 13405,
  [13894] = 13406,
  [13895] = 13407,
  [13896] = 13481,
  [13897] = 13409,
  [13898] = 13499,
  [13899] = 13411,
  [13900] = 13495,
  [13901] = 13490,
  [13902] = 13414,
  [13903] = 13415,
  [13904] = 13411,
  [13905] = 13417,
  [13906] = 13906,
  [13907] = 13505,
  [13908] = 13496,
  [13909] = 13420,
  [13910] = 13421,
  [13911] = 13495,
  [13912] = 13422,
  [13913] = 13496,
  [13914] = 13518,
  [13915] = 13412,
  [13916] = 13694,
  [13917] = 13695,
  [13918] = 13413,
  [13919] = 13502,
  [13920] = 13570,
  [13921] = 13425,
  [13922] = 13426,
  [13923] = 13428,
  [13924] = 13924,
  [13925] = 13925,
  [13926] = 13499,
  [13927] = 13414,
  [13928] = 13928,
  [13929] = 13705,
  [13930] = 13391,
  [13931] = 13679,
  [13932] = 13715,
  [13933] = 13716,
  [13934] = 13717,
  [13935] = 13429,
  [13936] = 13430,
  [13937] = 13431,
  [13938] = 13403,
  [13939] = 13680,
  [13940] = 13720,
  [13941] = 13427,
  [13942] = 13721,
  [13943] = 13722,
  [13944] = 13723,
  [13945] = 13724,
  [13946] = 13725,
  [13947] = 13433,
  [13948] = 13436,
  [13949] = 13437,
  [13950] = 13393,
  [13951] = 13438,
  [13952] = 13439,
  [13953] = 13440,
  [13954] = 13394,
  [13955] = 13442,
  [13956] = 13682,
  [13957] = 13410,
  [13958] = 13395,
  [13959] = 13419,
  [13960] = 13445,
  [13961] = 13444,
  [13962] = 13448,
  [13963] = 13446,
  [13964] = 13447,
  [13965] = 13396,
  [13966] = 13449,
  [13967] = 13397,
  [13968] = 13585,
  [13969] = 13596,
  [13970] = 13683,
  [13971] = 13606,
  [13972] = 13620,
  [13973] = 13398,
  [13974] = 13450,
  [13975] = 13451,
  [13976] = 13452,
  [13977] = 13453,
  [13978] = 13454,
  [13979] = 13399,
  [13980] = 13456,
  [13981] = 13714,
  [13982] = 13812,
  [13983] = 13400,
  [13984] = 13505,
  [13985] = 13402,
  [13986] = 13986,
  [13987] = 13844,
  [13988] = 13667,
  [13989] = 13670,
  [13990] = 13673,
  [13991] = 13676,
  [13992] = 13415,
  [13993] = 13859,
  [13994] = 13457,
  [13995] = 13864,
  [13996] = 13872,
  [13997] = 13405,
  [13998] = 13885,
  [13999] = 13406,
  [14000] = 13407,
  [14001] = 13906,
  [14002] = 14002,
  [14003] = 13409,
  [14004] = 13518,
  [14005] = 13679,
  [14006] = 13680,
  [14007] = 13682,
  [14008] = 13683,
  [14009] = 13986,
  [14010] = 13411,
  [14011] = 13417,
  [14012] = 13499,
  [14013] = 13414,
  [14014] = 14014,
  [14015] = 13695,
  [14016] = 14016,
  [14017] = 14017,
  [14018] = 13415,
  [14019] = 13570,
  [14020] = 14020,
  [14021] = 14021,
  [14022] = 14014,
  [14023] = 14023,
  [14024] = 13417,
  [14025] = 13391,
  [14026] = 14026,
  [14027] = 14027,
  [14028] = 14016,
  [14029] = 14029,
  [14030] = 14017,
  [14031] = 13420,
  [14032] = 14032,
  [14033] = 13421,
  [14034] = 13393,
  [14035] = 13422,
  [14036] = 14036,
  [14037] = 14037,
  [14038] = 14038,
  [14039] = 14039,
  [14040] = 13394,
  [14041] = 14041,
  [14042] = 14042,
  [14043] = 14043,
  [14044] = 13391,
  [14045] = 14045,
  [14046] = 14046,
  [14047] = 13425,
  [14048] = 14048,
  [14049] = 13426,
  [14050] = 13395,
  [14051] = 13804,
  [14052] = 14002,
  [14053] = 14053,
  [14054] = 14054,
  [14055] = 14055,
  [14056] = 13428,
  [14057] = 14057,
  [14058] = 13742,
  [14059] = 13733,
  [14060] = 13508,
  [14061] = 13395,
  [14062] = 13412,
  [14063] = 13413,
  [14064] = 13396,
  [14065] = 13397,
  [14066] = 13429,
  [14067] = 13702,
  [14068] = 13398,
  [14069] = 13695,
  [14070] = 13570,
  [14071] = 13430,
  [14072] = 13431,
  [14073] = 13399,
  [14074] = 13475,
  [14075] = 13400,
  [14076] = 13732,
  [14077] = 13746,
  [14078] = 13403,
  [14079] = 13402,
  [14080] = 13396,
  [14081] = 13427,
  [14082] = 13433,
  [14083] = 13436,
  [14084] = 13405,
  [14085] = 13406,
  [14086] = 13407,
  [14087] = 13437,
  [14088] = 13397,
  [14089] = 13438,
  [14090] = 13508,
  [14091] = 13412,
  [14092] = 13413,
  [14093] = 13409,
  [14094] = 13401,
  [14095] = 13416,
  [14096] = 13439,
  [14097] = 13411,
  [14098] = 1800,
  [14099] = 13440,
  [14100] = 14020,
  [14101] = 13442,
  [14102] = 13414,
  [14103] = 13415,
  [14104] = 13398,
  [14105] = 13399,
  [14106] = 13445,
  [14107] = 13446,
  [14108] = 13447,
  [14109] = 13400,
  [14110] = 13449,
  [14111] = 13417,
  [14112] = 13450,
  [14113] = 13451,
  [14114] = 13452,
  [14115] = 13453,
  [14116] = 13695,
  [14117] = 13570,
  [14118] = 13420,
  [14119] = 14119,
  [14120] = 13421,
  [14121] = 13454,
  [14122] = 13422,
  [14123] = 14021,
  [14124] = 13456,
  [14125] = 14125,
  [14126] = 14126,
  [14127] = 13475,
  [14128] = 14128,
  [14129] = 13425,
  [14130] = 13426,
  [14131] = 13457,
  [14132] = 13428,
  [14133] = 14133,
  [14134] = 13455,
  [14135] = 13695,
  [14136] = 13570,
  [14137] = 13924,
  [14138] = 13925,
  [14139] = 13508,
  [14140] = 13508,
  [14141] = 13412,
  [14142] = 13412,
  [14143] = 13413,
  [14144] = 13413,
  [14145] = 13928,
  [14146] = 13401,
  [14147] = 13416,
  [14148] = 13402,
  [14149] = 13732,
  [14150] = 13500,
  [14151] = 1801,
  [14152] = 13466,
  [14153] = 13517,
  [14154] = 13392,
  [14155] = 14023,
  [14156] = 13695,
  [14157] = 13570,
  [14158] = 13567,
  [14159] = 14159,
  [14160] = 13719,
  [14161] = 13695,
  [14162] = 13570,
  [14163] = 14163,
  [14164] = 13529,
  [14165] = 13695,
  [14166] = 13570,
  [14167] = 14167,
  [14168] = 13429,
  [14169] = 13567,
  [14170] = 13430,
  [14171] = 13431,
  [14172] = 13403,
  [14173] = 13427,
  [14174] = 13433,
  [14175] = 13436,
  [14176] = 13437,
  [14177] = 13438,
  [14178] = 13439,
  [14179] = 13440,
  [14180] = 13405,
  [14181] = 13442,
  [14182] = 13746,
  [14183] = 13406,
  [14184] = 13738,
  [14185] = 14185,
  [14186] = 13445,
  [14187] = 13586,
  [14188] = 13551,
  [14189] = 13407,
  [14190] = 13420,
  [14191] = 13637,
  [14192] = 13446,
  [14193] = 13409,
  [14194] = 14167,
  [14195] = 14185,
  [14196] = 13447,
  [14197] = 13421,
  [14198] = 13703,
  [14199] = 13748,
  [14200] = 13475,
  [14201] = 14119,
  [14202] = 14125,
  [14203] = 13449,
  [14204] = 13517,
  [14205] = 13493,
  [14206] = 13411,
  [14207] = 14159,
  [14208] = 13463,
  [14209] = 13585,
  [14210] = 13645,
  [14211] = 13596,
  [14212] = 13720,
  [14213] = 14026,
  [14214] = 13606,
  [14215] = 13620,
  [14216] = 13392,
  [14217] = 14027,
  [14218] = 13567,
  [14219] = 13721,
  [14220] = 13722,
  [14221] = 13414,
  [14222] = 13551,
  [14223] = 13415,
  [14224] = 13645,
  [14225] = 13478,
  [14226] = 13723,
  [14227] = 13724,
  [14228] = 13465,
  [14229] = 14159,
  [14230] = 13725,
  [14231] = 14231,
  [14232] = 13417,
  [14233] = 13390,
  [14234] = 14029,
  [14235] = 13422,
  [14236] = 13390,
  [14237] = 13393,
  [14238] = 13732,
  [14239] = 14239,
  [14240] = 13420,
  [14241] = 13421,
  [14242] = 13450,
  [14243] = 14032,
  [14244] = 13418,
  [14245] = 14245,
  [14246] = 13422,
  [14247] = 13465,
  [14248] = 14159,
  [14249] = 13418,
  [14250] = 13394,
  [14251] = 13425,
  [14252] = 13423,
  [14253] = 13423,
  [14254] = 13424,
  [14255] = 13424,
  [14256] = 13425,
  [14257] = 14257,
  [14258] = 13426,
  [14259] = 13441,
  [14260] = 13426,
  [14261] = 13441,
  [14262] = 13428,
  [14263] = 13451,
  [14264] = 14264,
  [14265] = 10349,
  [14266] = 13429,
  [14267] = 13452,
  [14268] = 13430,
  [14269] = 13453,
  [14270] = 13431,
  [14271] = 13403,
  [14272] = 14036,
  [14273] = 13466,
  [14274] = 13466,
  [14275] = 13427,
  [14276] = 13433,
  [14277] = 13470,
  [14278] = 13471,
  [14279] = 13454,
  [14280] = 13470,
  [14281] = 13471,
  [14282] = 13436,
  [14283] = 13474,
  [14284] = 13474,
  [14285] = 13437,
  [14286] = 13478,
  [14287] = 14037,
  [14288] = 13481,
  [14289] = 13478,
  [14290] = 13481,
  [14291] = 13490,
  [14292] = 13438,
  [14293] = 13490,
  [14294] = 13439,
  [14295] = 13495,
  [14296] = 13496,
  [14297] = 13440,
  [14298] = 13499,
  [14299] = 14038,
  [14300] = 13495,
  [14301] = 13496,
  [14302] = 13442,
  [14303] = 13499,
  [14304] = 14039,
  [14305] = 13390,
  [14306] = 13505,
  [14307] = 13445,
  [14308] = 13446,
  [14309] = 13505,
  [14310] = 13518,
  [14311] = 13447,
  [14312] = 14041,
  [14313] = 13449,
  [14314] = 13518,
  [14315] = 13450,
  [14316] = 13456,
  [14317] = 13391,
  [14318] = 13451,
  [14319] = 13452,
  [14320] = 13391,
  [14321] = 13453,
  [14322] = 13393,
  [14323] = 13394,
  [14324] = 13454,
  [14325] = 13393,
  [14326] = 13394,
  [14327] = 14042,
  [14328] = 13395,
  [14329] = 13396,
  [14330] = 13397,
  [14331] = 13773,
  [14332] = 13456,
  [14333] = 13398,
  [14334] = 13399,
  [14335] = 13395,
  [14336] = 14336,
  [14337] = 13396,
  [14338] = 13397,
  [14339] = 13400,
  [14340] = 13398,
  [14341] = 13399,
  [14342] = 13400,
  [14343] = 13667,
  [14344] = 13402,
  [14345] = 13402,
  [14346] = 13670,
  [14347] = 13405,
  [14348] = 13406,
  [14349] = 13407,
  [14350] = 13673,
  [14351] = 13409,
  [14352] = 13405,
  [14353] = 13411,
  [14354] = 13406,
  [14355] = 13407,
  [14356] = 13676,
  [14357] = 13414,
  [14358] = 13415,
  [14359] = 13409,
  [14360] = 13417,
  [14361] = 13457,
  [14362] = 13411,
  [14363] = 13679,
  [14364] = 13420,
  [14365] = 13421,
  [14366] = 13680,
  [14367] = 13414,
  [14368] = 13422,
  [14369] = 13415,
  [14370] = 13682,
  [14371] = 13425,
  [14372] = 13426,
  [14373] = 13417,
  [14374] = 13428,
  [14375] = 14133,
  [14376] = 13924,
  [14377] = 13925,
  [14378] = 13683,
  [14379] = 13508,
  [14380] = 13928,
  [14381] = 13412,
  [14382] = 13712,
  [14383] = 13745,
  [14384] = 13420,
  [14385] = 13429,
  [14386] = 13430,
  [14387] = 13431,
  [14388] = 13403,
  [14389] = 13421,
  [14390] = 13427,
  [14391] = 13433,
  [14392] = 13436,
  [14393] = 13437,
  [14394] = 13413,
  [14395] = 13438,
  [14396] = 13439,
  [14397] = 14126,
  [14398] = 13440,
  [14399] = 13422,
  [14400] = 13442,
  [14401] = 13401,
  [14402] = 13416,
  [14403] = 13445,
  [14404] = 13446,
  [14405] = 13447,
  [14406] = 13425,
  [14407] = 13449,
  [14408] = 13426,
  [14409] = 13585,
  [14410] = 13596,
  [14411] = 14043,
  [14412] = 13606,
  [14413] = 13620,
  [14414] = 13428,
  [14415] = 13450,
  [14416] = 13451,
  [14417] = 13452,
  [14418] = 13453,
  [14419] = 13454,
  [14420] = 13429,
  [14421] = 13456,
  [14422] = 13812,
  [14423] = 13430,
  [14424] = 13431,
  [14425] = 13403,
  [14426] = 13428,
  [14427] = 13844,
  [14428] = 13667,
  [14429] = 13670,
  [14430] = 13673,
  [14431] = 13676,
  [14432] = 13427,
  [14433] = 13859,
  [14434] = 13731,
  [14435] = 13457,
  [14436] = 13864,
  [14437] = 13872,
  [14438] = 13433,
  [14439] = 13885,
  [14440] = 13436,
  [14441] = 13437,
  [14442] = 13906,
  [14443] = 13438,
  [14444] = 13439,
  [14445] = 13679,
  [14446] = 13680,
  [14447] = 13682,
  [14448] = 13683,
  [14449] = 13986,
  [14450] = 13440,
  [14451] = 13418,
  [14452] = 13442,
  [14453] = 14045,
  [14454] = 14014,
  [14455] = 14016,
  [14456] = 14017,
  [14457] = 14046,
  [14458] = 14020,
  [14459] = 14021,
  [14460] = 13445,
  [14461] = 14023,
  [14462] = 13446,
  [14463] = 13447,
  [14464] = 14026,
  [14465] = 14027,
  [14466] = 13924,
  [14467] = 14029,
  [14468] = 13449,
  [14469] = 13450,
  [14470] = 14032,
  [14471] = 13451,
  [14472] = 13452,
  [14473] = 13453,
  [14474] = 14036,
  [14475] = 14037,
  [14476] = 14038,
  [14477] = 14039,
  [14478] = 13454,
  [14479] = 14041,
  [14480] = 14042,
  [14481] = 14043,
  [14482] = 14045,
  [14483] = 14046,
  [14484] = 13456,
  [14485] = 14048,
  [14486] = 13457,
  [14487] = 13508,
  [14488] = 13804,
  [14489] = 14002,
  [14490] = 14053,
  [14491] = 14054,
  [14492] = 14055,
  [14493] = 13412,
  [14494] = 14057,
  [14495] = 13413,
  [14496] = 14496,
  [14497] = 14497,
  [14498] = 13812,
  [14499] = 14499,
  [14500] = 13742,
  [14501] = 13401,
  [14502] = 13416,
  [14503] = 13733,
  [14504] = 13423,
  [14505] = 13508,
  [14506] = 13475,
  [14507] = 13732,
  [14508] = 13746,
  [14509] = 13508,
  [14510] = 13412,
  [14511] = 13413,
  [14512] = 13455,
  [14513] = 14048,
  [14514] = 13401,
  [14515] = 13416,
  [14516] = 13424,
  [14517] = 10337,
  [14518] = 13925,
  [14519] = 13455,
  [14520] = 13844,
  [14521] = 14521,
  [14522] = 13773,
  [14523] = 13667,
  [14524] = 13670,
  [14525] = 13673,
  [14526] = 13676,
  [14527] = 13508,
  [14528] = 14528,
  [14529] = 13731,
  [14530] = 13412,
  [14531] = 13859,
  [14532] = 10623,
  [14533] = 14533,
  [14534] = 13804,
  [14535] = 13746,
  [14536] = 13413,
  [14537] = 13731,
  [14538] = 13455,
  [14539] = 13457,
  [14540] = 14540,
  [14541] = 13864,
  [14542] = 13872,
  [14543] = 14543,
  [14544] = 13885,
  [14545] = 11114,
  [14546] = 14002,
  [14547] = 13906,
  [14548] = 13517,
  [14549] = 13742,
  [14550] = 13500,
  [14551] = 13679,
  [14552] = 13680,
  [14553] = 13733,
  [14554] = 13517,
  [14555] = 14053,
  [14556] = 13682,
  [14557] = 13683,
  [14558] = 13986,
  [14559] = 13567,
  [14560] = 14054,
  [14561] = 13551,
  [14562] = 14055,
  [14563] = 13529,
  [14564] = 13645,
  [14565] = 10325,
  [14566] = 13481,
  [14567] = 13726,
  [14568] = 13390,
  [14569] = 13567,
  [14570] = 14014,
  [14571] = 14016,
  [14572] = 14017,
  [14573] = 13441,
  [14574] = 14020,
  [14575] = 14021,
  [14576] = 14057,
  [14577] = 14023,
  [14578] = 14053,
  [14579] = 13508,
  [14580] = 13508,
  [14581] = 13412,
  [14582] = 13413,
  [14583] = 14583,
  [14584] = 13418,
  [14585] = 13551,
  [14586] = 13412,
  [14587] = 14026,
  [14588] = 10464,
  [14589] = 14027,
  [14590] = 13500,
  [14591] = 14029,
  [14592] = 13413,
  [14593] = 13423,
  [14594] = 14032,
  [14595] = 13424,
  [14596] = 13789,
  [14597] = 13401,
  [14598] = 13416,
  [14599] = 13463,
  [14600] = 13645,
  [14601] = 13789,
  [14602] = 13789,
  [14603] = 13789,
  [14604] = 13789,
  [14605] = 13789,
  [14606] = 13789,
  [14607] = 13789,
  [14608] = 13789,
  [14609] = 13789,
  [14610] = 13789,
  [14611] = 13789,
  [14612] = 13789,
  [14613] = 13789,
  [14614] = 13789,
  [14615] = 13789,
  [14616] = 13789,
  [14617] = 13789,
  [14618] = 13789,
  [14619] = 13789,
  [14620] = 14054,
  [14621] = 13392,
  [14622] = 14036,
  [14623] = 13441,
  [14624] = 14037,
  [14625] = 14038,
  [14626] = 14039,
  [14627] = 13517,
  [14628] = 13928,
  [14629] = 14055,
  [14630] = 13470,
  [14631] = 14336,
  [14632] = 13390,
  [14633] = 13466,
  [14634] = 13529,
  [14635] = 14041,
  [14636] = 14042,
  [14637] = 13470,
  [14638] = 14043,
  [14639] = 13471,
  [14640] = 13474,
  [14641] = 14057,
  [14642] = 14045,
  [14643] = 13505,
  [14644] = 13478,
  [14645] = 13481,
  [14646] = 13567,
  [14647] = 14046,
  [14648] = 13490,
  [14649] = 13401,
  [14650] = 13695,
  [14651] = 13570,
  [14652] = 13694,
  [14653] = 13418,
  [14654] = 13495,
  [14655] = 13496,
  [14656] = 13429,
  [14657] = 13423,
  [14658] = 13424,
  [14659] = 13499,
  [14660] = 13430,
  [14661] = 14048,
  [14662] = 13551,
  [14663] = 13441,
  [14664] = 13694,
  [14665] = 13695,
  [14666] = 13502,
  [14667] = 13570,
  [14668] = 13739,
  [14669] = 13431,
  [14670] = 13505,
  [14671] = 13694,
  [14672] = 13502,
  [14673] = 13463,
  [14674] = 13645,
  [14675] = 13518,
  [14676] = 13508,
  [14677] = 2258,
  [14678] = 13465,
  [14679] = 14679,
  [14680] = 5360,
  [14681] = 5370,
  [14682] = 14682,
  [14683] = 14683,
  [14684] = 14684,
  [14685] = 14685,
  [14686] = 14686,
  [14687] = 5397,
  [14688] = 1824,
  [14689] = 14689,
  [14690] = 14690,
  [14691] = 14691,
  [14692] = 14686,
  [14693] = 14693,
  [14694] = 14686,
  [14695] = 14686,
  [14696] = 14696,
  [14697] = 14685,
  [14698] = 14690,
  [14699] = 14699,
  [14700] = 14700,
  [14701] = 5403,
  [14702] = 14696,
  [14703] = 14685,
  [14704] = 14690,
  [14705] = 14699,
  [14706] = 14696,
  [14707] = 14685,
  [14708] = 14690,
  [14709] = 14699,
  [14710] = 14710,
  [14711] = 14711,
  [14712] = 14686,
  [14713] = 5404,
  [14714] = 14714,
  [14715] = 14715,
  [14716] = 14696,
  [14717] = 14717,
  [14718] = 14679,
  [14719] = 5400,
  [14720] = 5359,
  [14721] = 14679,
  [14722] = 14679,
  [14723] = 14679,
  [14724] = 14679,
  [14725] = 14679,
  [14726] = 14679,
  [14727] = 14679,
  [14728] = 14679,
  [14729] = 14679,
  [14730] = 14679,
  [14731] = 14679,
  [14732] = 14679,
  [14733] = 14679,
  [14734] = 14679,
  [14735] = 14679,
  [14736] = 14679,
  [14737] = 14679,
  [14738] = 14679,
  [14739] = 5390,
  [14740] = 5272,
  [14741] = 5401,
  [14742] = 14699,
  [14743] = 14686,
  [14744] = 14744,
  [14745] = 14745,
  [14746] = 11192,
  [14747] = 14686,
  [14748] = 14696,
  [14749] = 5387,
  [14750] = 14685,
  [14751] = 14690,
  [14752] = 14752,
  [14753] = 5394,
  [14754] = 5356,
  [14755] = 5053,
  [14756] = 14699,
  [14757] = 11181,
  [14758] = 5363,
  [14759] = 14759,
  [14760] = 4477,
  [14761] = 14679,
  [14762] = 14762,
  [14763] = 14763,
  [14764] = 14763,
  [14765] = 14765,
  [14766] = 14765,
  [14767] = 14763,
  [14768] = 14763,
  [14769] = 14765,
  [14770] = 14765,
  [14771] = 14765,
  [14772] = 14763,
  [14773] = 14773,
  [14774] = 14774,
  [14775] = 14775,
  [14776] = 14776,
  [14777] = 14777,
  [14778] = 14778,
  [14779] = 14779,
  [14780] = 14780,
  [14781] = 14781,
  [14782] = 14782,
  [14783] = 14783,
  [14784] = 14784,
  [14785] = 14785,
  [14786] = 14786,
  [14787] = 14787,
  [14788] = 14788,
  [14789] = 14789,
  [14790] = 14774,
  [14791] = 14775,
  [14792] = 14792,
  [14793] = 14793,
  [14794] = 14776,
  [14795] = 14795,
  [14796] = 14783,
  [14797] = 14778,
  [14798] = 14785,
  [14799] = 14788,
  [14800] = 14781,
  [14801] = 14784,
  [14802] = 14774,
  [14803] = 14775,
  [14804] = 14793,
  [14805] = 14792,
  [14806] = 14783,
  [14807] = 14785,
  [14808] = 14788,
  [14809] = 14776,
  [14810] = 14774,
  [14811] = 14777,
  [14812] = 14779,
  [14813] = 14780,
  [14814] = 14775,
  [14815] = 14776,
  [14816] = 14777,
  [14817] = 14779,
  [14818] = 14780,
  [14819] = 14782,
  [14820] = 14777,
  [14821] = 14779,
  [14822] = 14782,
  [14823] = 2375,
  [14824] = 14780,
  [14825] = 14825,
  [14826] = 14782,
  [14827] = 14825,
  [14828] = 2357,
  [14829] = 14795,
  [14830] = 14778,
  [14831] = 14781,
  [14832] = 14784,
  [14833] = 14792,
  [14834] = 14783,
  [14835] = 14785,
  [14836] = 14788,
  [14837] = 14774,
  [14838] = 14775,
  [14839] = 14776,
  [14840] = 14777,
  [14841] = 14779,
  [14842] = 14780,
  [14843] = 14782,
  [14844] = 4917,
  [14845] = 14795,
  [14846] = 14783,
  [14847] = 2370,
  [14848] = 14825,
  [14849] = 14785,
  [14850] = 14850,
  [14851] = 13389,
  [14852] = 14850,
  [14853] = 2358,
  [14854] = 14850,
  [14855] = 2356,
  [14856] = 2365,
  [14857] = 14788,
  [14858] = 2554,
  [14859] = 2555,
  [14860] = 2359,
  [14861] = 14861,
  [14862] = 14780,
  [14863] = 2556,
  [14864] = 2557,
  [14865] = 2558,
  [14866] = 2559,
  [14867] = 14774,
  [14868] = 2374,
  [14869] = 14850,
  [14870] = 2561,
  [14871] = 2562,
  [14872] = 14872,
  [14873] = 14873,
  [14874] = 14795,
  [14875] = 14875,
  [14876] = 14861,
  [14877] = 2371,
  [14878] = 14773,
  [14879] = 14775,
  [14880] = 14778,
  [14881] = 14777,
  [14882] = 14781,
  [14883] = 14873,
  [14884] = 14784,
  [14885] = 14786,
  [14886] = 2563,
  [14887] = 2564,
  [14888] = 2565,
  [14889] = 14787,
  [14890] = 2566,
  [14891] = 14789,
  [14892] = 14873,
  [14893] = 2567,
  [14894] = 2568,
  [14895] = 2569,
  [14896] = 2570,
  [14897] = 2571,
  [14898] = 2572,
  [14899] = 2573,
  [14900] = 2574,
  [14901] = 14788,
  [14902] = 14792,
  [14903] = 2575,
  [14904] = 2576,
  [14905] = 2577,
  [14906] = 14906,
  [14907] = 14825,
  [14908] = 14792,
  [14909] = 14875,
  [14910] = 14783,
  [14911] = 14782,
  [14912] = 14785,
  [14913] = 14795,
  [14914] = 14788,
  [14915] = 14795,
  [14916] = 14774,
  [14917] = 14917,
  [14918] = 14775,
  [14919] = 14875,
  [14920] = 14793,
  [14921] = 14861,
  [14922] = 14776,
  [14923] = 14778,
  [14924] = 14777,
  [14925] = 14781,
  [14926] = 14779,
  [14927] = 14784,
  [14928] = 14780,
  [14929] = 14792,
  [14930] = 14782,
  [14931] = 14783,
  [14932] = 14825,
  [14933] = 14785,
  [14934] = 14793,
  [14935] = 14788,
  [14936] = 13000,
  [14937] = 14774,
  [14938] = 14786,
  [14939] = 14775,
  [14940] = 14787,
  [14941] = 14776,
  [14942] = 14777,
  [14943] = 14789,
  [14944] = 14779,
  [14945] = 14780,
  [14946] = 14782,
  [14947] = 14850,
  [14948] = 14795,
  [14949] = 14773,
  [14950] = 1783,
  [14951] = 5009,
  [14952] = 2361,
  [14953] = 14875,
  [14954] = 14861,
  [14955] = 14778,
  [14956] = 14781,
  [14957] = 14779,
  [14958] = 1775,
  [14959] = 14873,
  [14960] = 14784,
  [14961] = 14786,
  [14962] = 14795,
  [14963] = 14875,
  [14964] = 14861,
  [14965] = 14773,
  [14966] = 14966,
  [14967] = 1796,
  [14968] = 14778,
  [14969] = 14781,
  [14970] = 14784,
  [14971] = 14786,
  [14972] = 14787,
  [14973] = 14787,
  [14974] = 14789,
  [14975] = 14789,
  [14976] = 14792,
  [14977] = 14783,
  [14978] = 14785,
  [14979] = 14788,
  [14980] = 14776,
  [14981] = 14774,
  [14982] = 14775,
  [14983] = 14793,
  [14984] = 14773,
  [14985] = 14781,
  [14986] = 14776,
  [14987] = 14777,
  [14988] = 14779,
  [14989] = 14780,
  [14990] = 14782,
  [14991] = 1797,
  [14992] = 14850,
  [14993] = 14792,
  [14994] = 14795,
  [14995] = 14778,
  [14996] = 14781,
  [14997] = 14784,
  [14998] = 14792,
  [14999] = 14778,
  [15000] = 1784,
  [15001] = 14783,
  [15002] = 14873,
  [15003] = 2367,
  [15004] = 14785,
  [15005] = 2360,
  [15006] = 4933,
  [15007] = 14825,
  [15008] = 14784,
  [15009] = 2439,
  [15010] = 2385,
  [15011] = 2386,
  [15012] = 2508,
  [15013] = 2512,
  [15014] = 15014,
  [15015] = 2513,
  [15016] = 2514,
  [15017] = 2515,
  [15018] = 2516,
  [15019] = 2517,
  [15020] = 2520,
  [15021] = 15021,
  [15022] = 15022,
  [15023] = 15023,
  [15024] = 2387,
  [15025] = 2388,
  [15026] = 2389,
  [15027] = 2390,
  [15028] = 2391,
  [15029] = 2392,
  [15030] = 2393,
  [15031] = 15031,
  [15032] = 15032,
  [15033] = 15033,
  [15034] = 15034,
  [15035] = 15035,
  [15036] = 15036,
  [15037] = 15037,
  [15038] = 15038,
  [15039] = 15039,
  [15040] = 2394,
  [15041] = 2395,
  [15042] = 2396,
  [15043] = 2397,
  [15044] = 2398,
  [15045] = 2399,
  [15046] = 2400,
  [15047] = 2401,
  [15048] = 2402,
  [15049] = 2403,
  [15050] = 2404,
  [15051] = 2405,
  [15052] = 2406,
  [15053] = 15053,
  [15054] = 15054,
  [15055] = 2408,
  [15056] = 2409,
  [15057] = 2410,
  [15058] = 2411,
  [15059] = 2412,
  [15060] = 2413,
  [15061] = 2414,
  [15062] = 2415,
  [15063] = 2416,
  [15064] = 2417,
  [15065] = 2418,
  [15066] = 2419,
  [15067] = 2420,
  [15068] = 2421,
  [15069] = 2422,
  [15070] = 2423,
  [15071] = 15071,
  [15072] = 2604,
  [15073] = 15073,
  [15074] = 2424,
  [15075] = 2425,
  [15076] = 2426,
  [15077] = 15077,
  [15078] = 2427,
  [15079] = 2429,
  [15080] = 2430,
  [15081] = 15081,
  [15082] = 2407,
  [15083] = 2452,
  [15084] = 2492,
  [15085] = 15085,
  [15086] = 15086,
  [15087] = 2463,
  [15088] = 2470,
  [15089] = 2431,
  [15090] = 2432,
  [15091] = 2433,
  [15092] = 2434,
  [15093] = 2435,
  [15094] = 2436,
  [15095] = 2437,
  [15096] = 2438,
  [15097] = 2440,
  [15098] = 2441,
  [15099] = 15032,
  [15100] = 15033,
  [15101] = 15034,
  [15102] = 15035,
  [15103] = 2442,
  [15104] = 15036,
  [15105] = 15037,
  [15106] = 15038,
  [15107] = 15039,
  [15108] = 2443,
  [15109] = 2444,
  [15110] = 2495,
  [15111] = 4477,
  [15112] = 15112,
  [15113] = 2496,
  [15114] = 2445,
  [15115] = 2446,
  [15116] = 2447,
  [15117] = 2553,
  [15118] = 2560,
  [15119] = 2633,
  [15120] = 2448,
  [15121] = 2449,
  [15122] = 4107,
  [15123] = 2578,
  [15124] = 2579,
  [15125] = 2580,
  [15126] = 2581,
  [15127] = 2582,
  [15128] = 2583,
  [15129] = 2584,
  [15130] = 2585,
  [15131] = 2586,
  [15132] = 2587,
  [15133] = 15133,
  [15134] = 15134,
  [15135] = 2588,
  [15136] = 2450,
  [15137] = 2451,
  [15138] = 15138,
  [15139] = 2453,
  [15140] = 15140,
  [15141] = 7453,
  [15142] = 2454,
  [15143] = 2455,
  [15144] = 2521,
  [15145] = 2523,
  [15146] = 2524,
  [15147] = 15147,
  [15148] = 2525,
  [15149] = 15149,
  [15150] = 2456,
  [15151] = 2457,
  [15152] = 2497,
  [15153] = 15032,
  [15154] = 15033,
  [15155] = 15034,
  [15156] = 15035,
  [15157] = 15036,
  [15158] = 15037,
  [15159] = 15038,
  [15160] = 15039,
  [15161] = 15133,
  [15162] = 15138,
  [15163] = 15149,
  [15164] = 2458,
  [15165] = 2459,
  [15166] = 2460,
  [15167] = 2461,
  [15168] = 2462,
  [15169] = 2464,
  [15170] = 2467,
  [15171] = 2468,
  [15172] = 2469,
  [15173] = 2377,
  [15174] = 2471,
  [15175] = 2472,
  [15176] = 2473,
  [15177] = 2474,
  [15178] = 2475,
  [15179] = 2476,
  [15180] = 2477,
  [15181] = 2478,
  [15182] = 2479,
  [15183] = 2480,
  [15184] = 2481,
  [15185] = 2482,
  [15186] = 2483,
  [15187] = 2484,
  [15188] = 2485,
  [15189] = 2486,
  [15190] = 2487,
  [15191] = 15191,
  [15192] = 15032,
  [15193] = 15033,
  [15194] = 15034,
  [15195] = 15035,
  [15196] = 15036,
  [15197] = 15037,
  [15198] = 15038,
  [15199] = 15039,
  [15200] = 2633,
  [15201] = 15147,
  [15202] = 15133,
  [15203] = 15138,
  [15204] = 15149,
  [15205] = 15133,
  [15206] = 15138,
  [15207] = 15207,
  [15208] = 15081,
  [15209] = 15085,
  [15210] = 15086,
  [15211] = 7441,
  [15212] = 15212,
  [15213] = 15149,
  [15214] = 4121,
  [15215] = 15081,
  [15216] = 15216,
  [15217] = 15217,
  [15218] = 15218,
  [15219] = 15085,
  [15220] = 15086,
  [15221] = 15221,
  [15222] = 2527,
  [15223] = 2529,
  [15224] = 15224,
  [15225] = 15073,
  [15226] = 2530,
  [15227] = 15227,
  [15228] = 2488,
  [15229] = 15229,
  [15230] = 15230,
  [15231] = 15032,
  [15232] = 15033,
  [15233] = 2506,
  [15234] = 15034,
  [15235] = 15035,
  [15236] = 15236,
  [15237] = 15237,
  [15238] = 2589,
  [15239] = 2590,
  [15240] = 15073,
  [15241] = 15224,
  [15242] = 15242,
  [15243] = 2591,
  [15244] = 2592,
  [15245] = 2593,
  [15246] = 2489,
  [15247] = 2494,
  [15248] = 2493,
  [15249] = 2384,
  [15250] = 2594,
  [15251] = 15251,
  [15252] = 15073,
  [15253] = 2595,
  [15254] = 2596,
  [15255] = 2531,
  [15256] = 2597,
  [15257] = 2598,
  [15258] = 15073,
  [15259] = 2532,
  [15260] = 2533,
  [15261] = 7412,
  [15262] = 15262,
  [15263] = 15263,
  [15264] = 15264,
  [15265] = 15265,
  [15266] = 2599,
  [15267] = 2600,
  [15268] = 2601,
  [15269] = 2602,
  [15270] = 2603,
  [15271] = 2607,
  [15272] = 2608,
  [15273] = 2610,
  [15274] = 2611,
  [15275] = 2612,
  [15276] = 2613,
  [15277] = 2614,
  [15278] = 2615,
  [15279] = 15134,
  [15280] = 15217,
  [15281] = 15218,
  [15282] = 15282,
  [15283] = 2534,
  [15284] = 2535,
  [15285] = 2536,
  [15286] = 2537,
  [15287] = 2538,
  [15288] = 2539,
  [15289] = 15133,
  [15290] = 15138,
  [15291] = 15149,
  [15292] = 15036,
  [15293] = 15037,
  [15294] = 15038,
  [15295] = 15039,
  [15296] = 15134,
  [15297] = 2616,
  [15298] = 15217,
  [15299] = 15218,
  [15300] = 15282,
  [15301] = 15081,
  [15302] = 15085,
  [15303] = 15086,
  [15304] = 7449,
  [15305] = 2617,
  [15306] = 2618,
  [15307] = 2619,
  [15308] = 2620,
  [15309] = 2621,
  [15310] = 2622,
  [15311] = 2623,
  [15312] = 2624,
  [15313] = 2625,
  [15314] = 15134,
  [15315] = 2626,
  [15316] = 15217,
  [15317] = 15218,
  [15318] = 15282,
  [15319] = 2627,
  [15320] = 2628,
  [15321] = 2629,
  [15322] = 2630,
  [15323] = 15134,
  [15324] = 2631,
  [15325] = 15217,
  [15326] = 15218,
  [15327] = 15282,
  [15328] = 2528,
  [15329] = 2378,
  [15330] = 2379,
  [15331] = 15134,
  [15332] = 15217,
  [15333] = 15218,
  [15334] = 15282,
  [15335] = 15134,
  [15336] = 15217,
  [15337] = 15218,
  [15338] = 15282,
  [15339] = 15134,
  [15340] = 15217,
  [15341] = 15218,
  [15342] = 15282,
  [15343] = 15134,
  [15344] = 15217,
  [15345] = 15218,
  [15346] = 15282,
  [15347] = 15134,
  [15348] = 15217,
  [15349] = 15218,
  [15350] = 15282,
  [15351] = 15134,
  [15352] = 15217,
  [15353] = 15218,
  [15354] = 15282,
  [15355] = 15134,
  [15356] = 15217,
  [15357] = 15218,
  [15358] = 15282,
  [15359] = 15134,
  [15360] = 15217,
  [15361] = 15218,
  [15362] = 15282,
  [15363] = 15282,
  [15364] = 15134,
  [15365] = 15217,
  [15366] = 15218,
  [15367] = 15282,
  [15368] = 15134,
  [15369] = 15217,
  [15370] = 15218,
  [15371] = 15282,
  [15372] = 15134,
  [15373] = 15217,
  [15374] = 15218,
  [15375] = 15282,
  [15376] = 15134,
  [15377] = 15217,
  [15378] = 15218,
  [15379] = 15282,
  [15380] = 15134,
  [15381] = 15217,
  [15382] = 15218,
  [15383] = 15282,
  [15384] = 15134,
  [15385] = 15217,
  [15386] = 15218,
  [15387] = 15282,
  [15388] = 15134,
  [15389] = 15217,
  [15390] = 15218,
  [15391] = 15282,
  [15392] = 15134,
  [15393] = 15217,
  [15394] = 15218,
  [15395] = 15282,
  [15396] = 2540,
  [15397] = 2541,
  [15398] = 15032,
  [15399] = 15033,
  [15400] = 15034,
  [15401] = 15035,
  [15402] = 2542,
  [15403] = 2543,
  [15404] = 15036,
  [15405] = 15037,
  [15406] = 15038,
  [15407] = 15039,
  [15408] = 2544,
  [15409] = 2545,
  [15410] = 15022,
  [15411] = 15031,
  [15412] = 15081,
  [15413] = 15263,
  [15414] = 15265,
  [15415] = 15085,
  [15416] = 2546,
  [15417] = 15022,
  [15418] = 15031,
  [15419] = 15263,
  [15420] = 15265,
  [15421] = 15022,
  [15422] = 15031,
  [15423] = 15263,
  [15424] = 15265,
  [15425] = 15022,
  [15426] = 15031,
  [15427] = 15263,
  [15428] = 15265,
  [15429] = 15022,
  [15430] = 15031,
  [15431] = 15263,
  [15432] = 15265,
  [15433] = 2547,
  [15434] = 2548,
  [15435] = 2550,
  [15436] = 2551,
  [15437] = 15086,
  [15438] = 2552,
  [15439] = 15140,
  [15440] = 2380,
  [15441] = 2381,
  [15442] = 2382,
  [15443] = 2383,
  [15444] = 15073,
  [15445] = 15445,
  [15446] = 15446,
  [15447] = 15447,
  [15448] = 15448,
  [15449] = 15449,
  [15450] = 15450,
  [15451] = 15451,
  [15452] = 15452,
  [15453] = 15453,
  [15454] = 15454,
  [15455] = 15455,
  [15456] = 15456,
  [15457] = 15455,
  [15458] = 15458,
  [15459] = 15459,
  [15460] = 15460,
  [15461] = 15461,
  [15462] = 15462,
  [15463] = 15463,
  [15464] = 15464,
  [15465] = 15465,
  [15466] = 15466,
  [15467] = 15467,
  [15468] = 15468,
  [15469] = 15446,
  [15470] = 15470,
  [15471] = 15471,
  [15472] = 15472,
  [15473] = 15460,
  [15474] = 15461,
  [15475] = 15464,
  [15476] = 15465,
  [15477] = 15453,
  [15478] = 15454,
  [15479] = 15479,
  [15480] = 15480,
  [15481] = 15481,
  [15482] = 15482,
  [15483] = 15483,
  [15484] = 15484,
  [15485] = 15485,
  [15486] = 15486,
  [15487] = 15458,
  [15488] = 15479,
  [15489] = 15482,
  [15490] = 15490,
  [15491] = 15447,
  [15492] = 15492,
  [15493] = 15493,
  [15494] = 15494,
  [15495] = 15495,
  [15496] = 15496,
  [15497] = 15497,
  [15498] = 15498,
  [15499] = 15499,
  [15500] = 15462,
  [15501] = 15501,
  [15502] = 15502,
  [15503] = 15503,
  [15504] = 15504,
  [15505] = 15470,
  [15506] = 15472,
  [15507] = 15507,
  [15508] = 15508,
  [15509] = 15509,
  [15510] = 15510,
  [15511] = 15511,
  [15512] = 15512,
  [15513] = 15513,
  [15514] = 15456,
  [15515] = 15485,
  [15516] = 15516,
  [15517] = 15517,
  [15518] = 15518,
  [15519] = 15519,
  [15520] = 15520,
  [15521] = 15521,
  [15522] = 15522,
  [15523] = 15523,
  [15524] = 15463,
  [15525] = 15510,
  [15526] = 15485,
  [15527] = 15527,
  [15528] = 15528,
  [15529] = 15483,
  [15530] = 15458,
  [15531] = 15531,
  [15532] = 15532,
  [15533] = 15466,
  [15534] = 15534,
  [15535] = 15447,
  [15536] = 15536,
  [15537] = 15467,
  [15538] = 15538,
  [15539] = 15539,
  [15540] = 15540,
  [15541] = 15541,
  [15542] = 15542,
  [15543] = 15513,
  [15544] = 15544,
  [15545] = 15468,
  [15546] = 15446,
  [15547] = 15547,
  [15548] = 15548,
  [15549] = 15466,
  [15550] = 15467,
  [15551] = 15551,
  [15552] = 15552,
  [15553] = 15468,
  [15554] = 15446,
  [15555] = 15547,
  [15556] = 15556,
  [15557] = 15557,
  [15558] = 15558,
  [15559] = 15559,
  [15560] = 15458,
  [15561] = 15479,
  [15562] = 15482,
  [15563] = 15563,
  [15564] = 15449,
  [15565] = 15565,
  [15566] = 15566,
  [15567] = 15567,
  [15568] = 15485,
  [15569] = 15470,
  [15570] = 15472,
  [15571] = 15458,
  [15572] = 15447,
  [15573] = 15573,
  [15574] = 15510,
  [15575] = 15513,
  [15576] = 15502,
  [15577] = 15503,
  [15578] = 15504,
  [15579] = 15466,
  [15580] = 15467,
  [15581] = 15470,
  [15582] = 15468,
  [15583] = 15446,
  [15584] = 15472,
  [15585] = 15507,
  [15586] = 15510,
  [15587] = 15587,
  [15588] = 15511,
  [15589] = 15512,
  [15590] = 15590,
  [15591] = 15591,
  [15592] = 15592,
  [15593] = 15451,
  [15594] = 15452,
  [15595] = 15595,
  [15596] = 15523,
  [15597] = 15453,
  [15598] = 15454,
  [15599] = 15599,
  [15600] = 15513,
  [15601] = 15479,
  [15602] = 15482,
  [15603] = 15603,
  [15604] = 15604,
  [15605] = 15605,
  [15606] = 15492,
  [15607] = 15456,
  [15608] = 15455,
  [15609] = 15458,
  [15610] = 15447,
  [15611] = 15528,
  [15612] = 15541,
  [15613] = 15548,
  [15614] = 15614,
  [15615] = 15459,
  [15616] = 15552,
  [15617] = 15617,
  [15618] = 15462,
  [15619] = 15619,
  [15620] = 15620,
  [15621] = 15565,
  [15622] = 15470,
  [15623] = 15472,
  [15624] = 15557,
  [15625] = 15510,
  [15626] = 15513,
  [15627] = 15451,
  [15628] = 15628,
  [15629] = 15452,
  [15630] = 15630,
  [15631] = 15519,
  [15632] = 15603,
  [15633] = 15453,
  [15634] = 15454,
  [15635] = 15483,
  [15636] = 15497,
  [15637] = 15538,
  [15638] = 15542,
  [15639] = 15639,
  [15640] = 15640,
  [15641] = 15531,
  [15642] = 15534,
  [15643] = 15536,
  [15644] = 15539,
  [15645] = 15645,
  [15646] = 15639,
  [15647] = 15458,
  [15648] = 15540,
  [15649] = 15447,
  [15650] = 15650,
  [15651] = 15651,
  [15652] = 15640,
  [15653] = 15547,
  [15654] = 15654,
  [15655] = 15573,
  [15656] = 15656,
  [15657] = 15458,
  [15658] = 15447,
  [15659] = 15479,
  [15660] = 15448,
  [15661] = 15482,
  [15662] = 15662,
  [15663] = 15566,
  [15664] = 15509,
  [15665] = 15470,
  [15666] = 15458,
  [15667] = 15447,
  [15668] = 15472,
  [15669] = 15463,
  [15670] = 15508,
  [15671] = 15466,
  [15672] = 15458,
  [15673] = 15467,
  [15674] = 15447,
  [15675] = 15468,
  [15676] = 15446,
  [15677] = 15677,
  [15678] = 15458,
  [15679] = 15510,
  [15680] = 15447,
  [15681] = 15513,
  [15682] = 15480,
  [15683] = 15481,
  [15684] = 15458,
  [15685] = 15447,
  [15686] = 15484,
  [15687] = 15486,
  [15688] = 15459,
  [15689] = 15490,
  [15690] = 15494,
  [15691] = 15496,
  [15692] = 15498,
  [15693] = 15501,
  [15694] = 15458,
  [15695] = 15447,
  [15696] = 15502,
  [15697] = 15503,
  [15698] = 15504,
  [15699] = 15507,
  [15700] = 15523,
  [15701] = 15528,
  [15702] = 15541,
  [15703] = 15548,
  [15704] = 15552,
  [15705] = 15557,
  [15706] = 15466,
  [15707] = 15467,
  [15708] = 15708,
  [15709] = 15480,
  [15710] = 15481,
  [15711] = 15468,
  [15712] = 15712,
  [15713] = 15446,
  [15714] = 15714,
  [15715] = 15451,
  [15716] = 15452,
  [15717] = 15630,
  [15718] = 15484,
  [15719] = 15645,
  [15720] = 15650,
  [15721] = 15486,
  [15722] = 15722,
  [15723] = 15723,
  [15724] = 15462,
  [15725] = 15456,
  [15726] = 15453,
  [15727] = 15454,
  [15728] = 15456,
  [15729] = 15455,
  [15730] = 15455,
  [15731] = 15451,
  [15732] = 15452,
  [15733] = 15453,
  [15734] = 15734,
  [15735] = 15454,
  [15736] = 15722,
  [15737] = 15532,
  [15738] = 15723,
  [15739] = 15739,
  [15740] = 15544,
  [15741] = 15741,
  [15742] = 15742,
  [15743] = 15567,
  [15744] = 15744,
  [15745] = 15490,
  [15746] = 15451,
  [15747] = 15747,
  [15748] = 15748,
  [15749] = 15452,
  [15750] = 15750,
  [15751] = 15751,
  [15752] = 15656,
  [15753] = 15566,
  [15754] = 15509,
  [15755] = 15747,
  [15756] = 15508,
  [15757] = 15708,
  [15758] = 15494,
  [15759] = 15496,
  [15760] = 15760,
  [15761] = 4917,
  [15762] = 15519,
  [15763] = 15498,
  [15764] = 15501,
  [15765] = 15479,
  [15766] = 15482,
  [15767] = 15656,
  [15768] = 15453,
  [15769] = 15769,
  [15770] = 15770,
  [15771] = 15470,
  [15772] = 15472,
  [15773] = 15454,
  [15774] = 15510,
  [15775] = 15502,
  [15776] = 15776,
  [15777] = 15777,
  [15778] = 15778,
  [15779] = 15513,
  [15780] = 15780,
  [15781] = 15781,
  [15782] = 15503,
  [15783] = 15466,
  [15784] = 15467,
  [15785] = 15468,
  [15786] = 15786,
  [15787] = 15787,
  [15788] = 15446,
  [15789] = 15451,
  [15790] = 15452,
  [15791] = 15739,
  [15792] = 15453,
  [15793] = 15454,
  [15794] = 15456,
  [15795] = 15455,
  [15796] = 15566,
  [15797] = 15485,
  [15798] = 15456,
  [15799] = 15455,
  [15800] = 15741,
  [15801] = 15504,
  [15802] = 15447,
  [15803] = 15558,
  [15804] = 15559,
  [15805] = 15449,
  [15806] = 15450,
  [15807] = 15748,
  [15808] = 15450,
  [15809] = 15507,
  [15810] = 15511,
  [15811] = 15512,
  [15812] = 15591,
  [15813] = 15592,
  [15814] = 15604,
  [15815] = 15605,
  [15816] = 15614,
  [15817] = 15617,
  [15818] = 15509,
  [15819] = 15508,
  [15820] = 15532,
  [15821] = 15544,
  [15822] = 15822,
  [15823] = 15523,
  [15824] = 15824,
  [15825] = 15825,
  [15826] = 15739,
  [15827] = 15741,
  [15828] = 15742,
  [15829] = 15528,
  [15830] = 15708,
  [15831] = 15744,
  [15832] = 15541,
  [15833] = 15483,
  [15834] = 15460,
  [15835] = 15461,
  [15836] = 15464,
  [15837] = 15465,
  [15838] = 15548,
  [15839] = 15552,
  [15840] = 15750,
  [15841] = 15479,
  [15842] = 15532,
  [15843] = 15482,
  [15844] = 15459,
  [15845] = 15544,
  [15846] = 15492,
  [15847] = 15651,
  [15848] = 15848,
  [15849] = 15747,
  [15850] = 15748,
  [15851] = 11111,
  [15852] = 15750,
  [15853] = 15497,
  [15854] = 15538,
  [15855] = 15542,
  [15856] = 15751,
  [15857] = 15857,
  [15858] = 15656,
  [15859] = 15566,
  [15860] = 15509,
  [15861] = 15508,
  [15862] = 15708,
  [15863] = 15734,
  [15864] = 15864,
  [15865] = 15462,
  [15866] = 15742,
  [15867] = 15639,
  [15868] = 15640,
  [15869] = 15531,
  [15870] = 15619,
  [15871] = 15470,
  [15872] = 15472,
  [15873] = 15744,
  [15874] = 15510,
  [15875] = 15513,
  [15876] = 15447,
  [15877] = 15532,
  [15878] = 15769,
  [15879] = 15519,
  [15880] = 15544,
  [15881] = 15770,
  [15882] = 15534,
  [15883] = 15536,
  [15884] = 15565,
  [15885] = 15539,
  [15886] = 15776,
  [15887] = 15777,
  [15888] = 15778,
  [15889] = 15483,
  [15890] = 15531,
  [15891] = 15534,
  [15892] = 15536,
  [15893] = 15519,
  [15894] = 15539,
  [15895] = 15540,
  [15896] = 15780,
  [15897] = 15781,
  [15898] = 15540,
  [15899] = 15462,
  [15900] = 15547,
  [15901] = 15786,
  [15902] = 15787,
  [15903] = 15532,
  [15904] = 15456,
  [15905] = 15591,
  [15906] = 15466,
  [15907] = 15467,
  [15908] = 15544,
  [15909] = 15468,
  [15910] = 15446,
  [15911] = 15911,
  [15912] = 15912,
  [15913] = 15751,
  [15914] = 15592,
  [15915] = 15915,
  [15916] = 15455,
  [15917] = 15917,
  [15918] = 15532,
  [15919] = 15544,
  [15920] = 15573,
  [15921] = 15547,
  [15922] = 15502,
  [15923] = 15503,
  [15924] = 15479,
  [15925] = 15482,
  [15926] = 15504,
  [15927] = 15492,
  [15928] = 15507,
  [15929] = 15532,
  [15930] = 15523,
  [15931] = 15931,
  [15932] = 15544,
  [15933] = 15933,
  [15934] = 15493,
  [15935] = 15520,
  [15936] = 15527,
  [15937] = 15557,
  [15938] = 11105,
  [15939] = 15939,
  [15940] = 15769,
  [15941] = 15445,
  [15942] = 15448,
  [15943] = 15485,
  [15944] = 15944,
  [15945] = 15770,
  [15946] = 15531,
  [15947] = 15528,
  [15948] = 15541,
  [15949] = 15949,
  [15950] = 15950,
  [15951] = 15463,
  [15952] = 15458,
  [15953] = 15599,
  [15954] = 15470,
  [15955] = 15466,
  [15956] = 15467,
  [15957] = 15604,
  [15958] = 15472,
  [15959] = 15468,
  [15960] = 15446,
  [15961] = 15605,
  [15962] = 15565,
  [15963] = 15548,
  [15964] = 15510,
  [15965] = 15513,
  [15966] = 15447,
  [15967] = 15519,
  [15968] = 15614,
  [15969] = 15552,
  [15970] = 15483,
  [15971] = 15448,
  [15972] = 15617,
  [15973] = 15651,
  [15974] = 15547,
  [15975] = 15975,
  [15976] = 15480,
  [15977] = 15481,
  [15978] = 15484,
  [15979] = 15466,
  [15980] = 15467,
  [15981] = 15511,
  [15982] = 15468,
  [15983] = 15446,
  [15984] = 15486,
  [15985] = 15490,
  [15986] = 15445,
  [15987] = 15557,
  [15988] = 15494,
  [15989] = 15496,
  [15990] = 15498,
  [15991] = 15501,
  [15992] = 15502,
  [15993] = 15503,
  [15994] = 15504,
  [15995] = 15507,
  [15996] = 15523,
  [15997] = 15528,
  [15998] = 15541,
  [15999] = 15534,
  [16000] = 16000,
  [16001] = 15548,
  [16002] = 15552,
  [16003] = 15939,
  [16004] = 15619,
  [16005] = 15468,
  [16006] = 15557,
  [16007] = 15492,
  [16008] = 15451,
  [16009] = 15776,
  [16010] = 15619,
  [16011] = 15456,
  [16012] = 15512,
  [16013] = 15591,
  [16014] = 15455,
  [16015] = 15470,
  [16016] = 15557,
  [16017] = 15451,
  [16018] = 15452,
  [16019] = 16019,
  [16020] = 15452,
  [16021] = 15915,
  [16022] = 15915,
  [16023] = 15592,
  [16024] = 15573,
  [16025] = 15939,
  [16026] = 15472,
  [16027] = 15604,
  [16028] = 15510,
  [16029] = 15513,
  [16030] = 15605,
  [16031] = 15558,
  [16032] = 15599,
  [16033] = 15614,
  [16034] = 15630,
  [16035] = 15915,
  [16036] = 15479,
  [16037] = 15482,
  [16038] = 15617,
  [16039] = 15519,
  [16040] = 15451,
  [16041] = 15645,
  [16042] = 15460,
  [16043] = 15461,
  [16044] = 15650,
  [16045] = 15492,
  [16046] = 15939,
  [16047] = 15464,
  [16048] = 15465,
  [16049] = 15722,
  [16050] = 15723,
  [16051] = 15573,
  [16052] = 15559,
  [16053] = 15452,
  [16054] = 15536,
  [16055] = 15459,
  [16056] = 15939,
  [16057] = 15462,
  [16058] = 15483,
  [16059] = 15497,
  [16060] = 15538,
  [16061] = 15542,
  [16062] = 15565,
  [16063] = 15778,
  [16064] = 15453,
  [16065] = 15470,
  [16066] = 15472,
  [16067] = 15939,
  [16068] = 15708,
  [16069] = 15510,
  [16070] = 15639,
  [16071] = 15640,
  [16072] = 15513,
  [16073] = 15539,
  [16074] = 15540,
  [16075] = 15780,
  [16076] = 15781,
  [16077] = 16077,
  [16078] = 15531,
  [16079] = 15454,
  [16080] = 15558,
  [16081] = 16081,
  [16082] = 15456,
  [16083] = 15455,
  [16084] = 15651,
  [16085] = 15492,
  [16086] = 15559,
  [16087] = 15534,
  [16088] = 15479,
  [16089] = 15482,
  [16090] = 15536,
  [16091] = 11051,
  [16092] = 15539,
  [16093] = 15540,
  [16094] = 15449,
  [16095] = 15450,
  [16096] = 15492,
  [16097] = 15519,
  [16098] = 15483,
  [16099] = 15497,
  [16100] = 15538,
  [16101] = 15542,
  [16102] = 15639,
  [16103] = 15640,
  [16104] = 15531,
  [16105] = 15451,
  [16106] = 15534,
  [16107] = 15536,
  [16108] = 15452,
  [16109] = 15539,
  [16110] = 15540,
  [16111] = 15453,
  [16112] = 15454,
  [16113] = 15547,
  [16114] = 15448,
  [16115] = 16115,
  [16116] = 15445,
  [16117] = 15463,
  [16118] = 15466,
  [16119] = 15467,
  [16120] = 15468,
  [16121] = 15446,
  [16122] = 16122,
  [16123] = 15480,
  [16124] = 15481,
  [16125] = 15484,
  [16126] = 15486,
  [16127] = 15490,
  [16128] = 15494,
  [16129] = 15496,
  [16130] = 15498,
  [16131] = 15501,
  [16132] = 15502,
  [16133] = 15503,
  [16134] = 15504,
  [16135] = 15507,
  [16136] = 15523,
  [16137] = 15528,
  [16138] = 15541,
  [16139] = 15548,
  [16140] = 15552,
  [16141] = 15557,
  [16142] = 15630,
  [16143] = 15453,
  [16144] = 15786,
  [16145] = 15787,
  [16146] = 15630,
  [16147] = 15645,
  [16148] = 15645,
  [16149] = 15650,
  [16150] = 15722,
  [16151] = 15723,
  [16152] = 15650,
  [16153] = 15470,
  [16154] = 15472,
  [16155] = 16155,
  [16156] = 15708,
  [16157] = 15451,
  [16158] = 15452,
  [16159] = 15453,
  [16160] = 15454,
  [16161] = 15739,
  [16162] = 15741,
  [16163] = 15742,
  [16164] = 15744,
  [16165] = 15722,
  [16166] = 15723,
  [16167] = 15739,
  [16168] = 15741,
  [16169] = 15742,
  [16170] = 15744,
  [16171] = 15747,
  [16172] = 15748,
  [16173] = 15750,
  [16174] = 15751,
  [16175] = 15656,
  [16176] = 15566,
  [16177] = 15509,
  [16178] = 15508,
  [16179] = 15708,
  [16180] = 15747,
  [16181] = 15748,
  [16182] = 16182,
  [16183] = 15750,
  [16184] = 15751,
  [16185] = 15656,
  [16186] = 15566,
  [16187] = 15509,
  [16188] = 15508,
  [16189] = 15708,
  [16190] = 15769,
  [16191] = 15770,
  [16192] = 16192,
  [16193] = 15776,
  [16194] = 15777,
  [16195] = 15778,
  [16196] = 15510,
  [16197] = 15513,
  [16198] = 15780,
  [16199] = 15781,
  [16200] = 15786,
  [16201] = 15787,
  [16202] = 15456,
  [16203] = 15455,
  [16204] = 15456,
  [16205] = 15455,
  [16206] = 15454,
  [16207] = 15558,
  [16208] = 15559,
  [16209] = 15449,
  [16210] = 15450,
  [16211] = 15485,
  [16212] = 15511,
  [16213] = 15512,
  [16214] = 15591,
  [16215] = 15592,
  [16216] = 15547,
  [16217] = 16217,
  [16218] = 15599,
  [16219] = 15485,
  [16220] = 15479,
  [16221] = 15604,
  [16222] = 15605,
  [16223] = 15614,
  [16224] = 15617,
  [16225] = 15479,
  [16226] = 15769,
  [16227] = 15770,
  [16228] = 15482,
  [16229] = 15776,
  [16230] = 15458,
  [16231] = 15460,
  [16232] = 15461,
  [16233] = 15464,
  [16234] = 15465,
  [16235] = 15777,
  [16236] = 15599,
  [16237] = 15479,
  [16238] = 15482,
  [16239] = 16239,
  [16240] = 15459,
  [16241] = 15462,
  [16242] = 15565,
  [16243] = 15470,
  [16244] = 15472,
  [16245] = 15510,
  [16246] = 15513,
  [16247] = 15497,
  [16248] = 15538,
  [16249] = 15542,
  [16250] = 15639,
  [16251] = 15640,
  [16252] = 15531,
  [16253] = 15534,
  [16254] = 15536,
  [16255] = 15539,
  [16256] = 15540,
  [16257] = 15448,
  [16258] = 15463,
  [16259] = 15778,
  [16260] = 15466,
  [16261] = 15467,
  [16262] = 15468,
  [16263] = 15446,
  [16264] = 15480,
  [16265] = 15481,
  [16266] = 15484,
  [16267] = 15486,
  [16268] = 15490,
  [16269] = 15494,
  [16270] = 15496,
  [16271] = 15498,
  [16272] = 15501,
  [16273] = 15502,
  [16274] = 15503,
  [16275] = 15504,
  [16276] = 15507,
  [16277] = 15523,
  [16278] = 15528,
  [16279] = 15541,
  [16280] = 15548,
  [16281] = 15552,
  [16282] = 15630,
  [16283] = 15645,
  [16284] = 15650,
  [16285] = 15722,
  [16286] = 15723,
  [16287] = 15451,
  [16288] = 15452,
  [16289] = 15453,
  [16290] = 15454,
  [16291] = 15739,
  [16292] = 15741,
  [16293] = 15742,
  [16294] = 15744,
  [16295] = 15747,
  [16296] = 15748,
  [16297] = 15750,
  [16298] = 15751,
  [16299] = 15656,
  [16300] = 15566,
  [16301] = 15509,
  [16302] = 15508,
  [16303] = 15769,
  [16304] = 15770,
  [16305] = 15776,
  [16306] = 15777,
  [16307] = 15778,
  [16308] = 15780,
  [16309] = 15781,
  [16310] = 15786,
  [16311] = 15787,
  [16312] = 15456,
  [16313] = 15455,
  [16314] = 15558,
  [16315] = 15559,
  [16316] = 15449,
  [16317] = 15450,
  [16318] = 15511,
  [16319] = 15512,
  [16320] = 15591,
  [16321] = 15592,
  [16322] = 15604,
  [16323] = 15605,
  [16324] = 15614,
  [16325] = 15617,
  [16326] = 15460,
  [16327] = 15461,
  [16328] = 15464,
  [16329] = 15465,
  [16330] = 15479,
  [16331] = 15482,
  [16332] = 15470,
  [16333] = 15472,
  [16334] = 15780,
  [16335] = 15510,
  [16336] = 15513,
  [16337] = 15781,
  [16338] = 15466,
  [16339] = 15467,
  [16340] = 16340,
  [16341] = 15468,
  [16342] = 15446,
  [16343] = 15451,
  [16344] = 15452,
  [16345] = 15453,
  [16346] = 15454,
  [16347] = 15456,
  [16348] = 15455,
  [16349] = 15786,
  [16350] = 15787,
  [16351] = 15482,
  [16352] = 15466,
  [16353] = 15573,
  [16354] = 15447,
  [16355] = 15599,
  [16356] = 15777,
  [16357] = 15458,
  [16358] = 15467,
  [16359] = 15573,
  [16360] = 15599,
  [16361] = 15459,
  [16362] = 15462,
  [16363] = 15565,
  [16364] = 15497,
  [16365] = 15538,
  [16366] = 15542,
  [16367] = 15639,
  [16368] = 15640,
  [16369] = 15531,
  [16370] = 15534,
  [16371] = 15536,
  [16372] = 15539,
  [16373] = 15540,
  [16374] = 15448,
  [16375] = 15463,
  [16376] = 15480,
  [16377] = 15481,
  [16378] = 15484,
  [16379] = 15486,
  [16380] = 15490,
  [16381] = 15494,
  [16382] = 15496,
  [16383] = 15498,
  [16384] = 15501,
  [16385] = 15502,
  [16386] = 15503,
  [16387] = 15504,
  [16388] = 15507,
  [16389] = 15523,
  [16390] = 15528,
  [16391] = 15541,
  [16392] = 15548,
  [16393] = 15552,
  [16394] = 15630,
  [16395] = 15645,
  [16396] = 15650,
  [16397] = 15722,
  [16398] = 15723,
  [16399] = 15739,
  [16400] = 15741,
  [16401] = 15742,
  [16402] = 15744,
  [16403] = 15747,
  [16404] = 15748,
  [16405] = 15750,
  [16406] = 15751,
  [16407] = 15656,
  [16408] = 15566,
  [16409] = 15509,
  [16410] = 15508,
  [16411] = 15769,
  [16412] = 15770,
  [16413] = 15776,
  [16414] = 15777,
  [16415] = 15778,
  [16416] = 15780,
  [16417] = 15781,
  [16418] = 15786,
  [16419] = 15787,
  [16420] = 15558,
  [16421] = 15559,
  [16422] = 15449,
  [16423] = 15450,
  [16424] = 15511,
  [16425] = 15512,
  [16426] = 15591,
  [16427] = 15592,
  [16428] = 15604,
  [16429] = 15605,
  [16430] = 15614,
  [16431] = 15617,
  [16432] = 15460,
  [16433] = 15461,
  [16434] = 15464,
  [16435] = 15465,
  [16436] = 16436,
  [16437] = 15656,
  [16438] = 16438,
  [16439] = 16439,
  [16440] = 16440,
  [16441] = 16441,
  [16442] = 4933,
  [16443] = 16440,
  [16444] = 16444,
  [16445] = 16445,
  [16446] = 16446,
  [16447] = 16447,
  [16448] = 16448,
  [16449] = 16449,
  [16450] = 16446,
  [16451] = 16451,
  [16452] = 16452,
  [16453] = 16452,
  [16454] = 11413,
  [16455] = 11505,
  [16456] = 8093,
  [16457] = 16457,
  [16458] = 16458,
  [16459] = 16446,
  [16460] = 16460,
  [16461] = 16452,
  [16462] = 16462,
  [16463] = 16463,
  [16464] = 16464,
  [16465] = 16465,
  [16466] = 16466,
  [16467] = 16467,
  [16468] = 11581,
  [16469] = 16469,
  [16470] = 16440,
  [16471] = 16452,
  [16472] = 16472,
  [16473] = 16449,
  [16474] = 16474,
  [16475] = 16475,
  [16476] = 16476,
  [16477] = 16477,
  [16478] = 16447,
  [16479] = 16479,
  [16480] = 16460,
  [16481] = 16447,
  [16482] = 5225,
  [16483] = 16483,
  [16484] = 16484,
  [16485] = 16449,
  [16486] = 16486,
  [16487] = 16477,
  [16488] = 16452,
  [16489] = 16444,
  [16490] = 16440,
  [16491] = 16483,
  [16492] = 16447,
  [16493] = 16460,
  [16494] = 16494,
  [16495] = 16460,
  [16496] = 16449,
  [16497] = 16484,
  [16498] = 16498,
  [16499] = 16463,
  [16500] = 16444,
  [16501] = 16463,
  [16502] = 8078,
  [16503] = 16503,
  [16504] = 11462,
  [16505] = 16440,
  [16506] = 16444,
  [16507] = 16447,
  [16508] = 16508,
  [16509] = 16446,
  [16510] = 16444,
  [16511] = 2258,
  [16512] = 16512,
  [16513] = 16446,
  [16514] = 16444,
  [16515] = 16515,
  [16516] = 16452,
  [16517] = 16464,
  [16518] = 16512,
  [16519] = 11219,
  [16520] = 16447,
  [16521] = 16460,
  [16522] = 16440,
  [16523] = 16523,
  [16524] = 16449,
  [16525] = 16463,
  [16526] = 16447,
  [16527] = 16527,
  [16528] = 16463,
  [16529] = 16440,
  [16530] = 16452,
  [16531] = 16483,
  [16532] = 16532,
  [16533] = 16533,
  [16534] = 16534,
  [16535] = 16460,
  [16536] = 16440,
  [16537] = 16537,
  [16538] = 16476,
  [16539] = 16449,
  [16540] = 16483,
  [16541] = 16541,
  [16542] = 16464,
  [16543] = 11559,
  [16544] = 16515,
  [16545] = 16545,
  [16546] = 16546,
  [16547] = 16547,
  [16548] = 16449,
  [16549] = 16549,
  [16550] = 16447,
  [16551] = 16464,
  [16552] = 16447,
  [16553] = 16460,
  [16554] = 16554,
  [16555] = 16555,
  [16556] = 16484,
  [16557] = 16449,
  [16558] = 16515,
  [16559] = 16479,
  [16560] = 16460,
  [16561] = 16446,
  [16562] = 16447,
  [16563] = 16449,
  [16564] = 16564,
  [16565] = 16565,
  [16566] = 16566,
  [16567] = 16503,
  [16568] = 16452,
  [16569] = 16569,
  [16570] = 16445,
  [16571] = 16571,
  [16572] = 16572,
  [16573] = 16573,
  [16574] = 16512,
  [16575] = 16575,
  [16576] = 16576,
  [16577] = 16577,
  [16578] = 16578,
  [16579] = 5239,
  [16580] = 16580,
  [16581] = 5335,
  [16582] = 16582,
  [16583] = 16583,
  [16584] = 16584,
  [16585] = 16585,
  [16586] = 16586,
  [16587] = 16587,
  [16588] = 16588,
  [16589] = 16585,
  [16590] = 16590,
  [16591] = 16591,
  [16592] = 16584,
  [16593] = 5262,
  [16594] = 16594,
  [16595] = 16595,
  [16596] = 16596,
  [16597] = 16597,
  [16598] = 16598,
  [16599] = 16599,
  [16600] = 16600,
  [16601] = 16601,
  [16602] = 16585,
  [16603] = 16603,
  [16604] = 16586,
  [16605] = 16605,
  [16606] = 16606,
  [16607] = 16607,
  [16608] = 16608,
  [16609] = 16609,
  [16610] = 16610,
  [16611] = 16611,
  [16612] = 16612,
  [16613] = 16613,
  [16614] = 16614,
  [16615] = 16615,
  [16616] = 16588,
  [16617] = 16617,
  [16618] = 16618,
  [16619] = 16619,
  [16620] = 16620,
  [16621] = 16621,
  [16622] = 16622,
  [16623] = 16623,
  [16624] = 16624,
  [16625] = 16625,
  [16626] = 16621,
  [16627] = 16627,
  [16628] = 16628,
  [16629] = 16629,
  [16630] = 16630,
  [16631] = 16631,
  [16632] = 16632,
  [16633] = 16633,
  [16634] = 16606,
  [16635] = 16635,
  [16636] = 16636,
  [16637] = 16637,
  [16638] = 16638,
  [16639] = 16587,
  [16640] = 16585,
  [16641] = 16633,
  [16642] = 16642,
  [16643] = 16643,
  [16644] = 16644,
  [16645] = 16645,
  [16646] = 16591,
  [16647] = 16647,
  [16648] = 16648,
  [16649] = 16649,
  [16650] = 16630,
  [16651] = 16645,
  [16652] = 16652,
  [16653] = 16653,
  [16654] = 16587,
  [16655] = 16655,
  [16656] = 16656,
  [16657] = 16656,
  [16658] = 16658,
  [16659] = 16631,
  [16660] = 16660,
  [16661] = 16661,
  [16662] = 16662,
  [16663] = 16663,
  [16664] = 16664,
  [16665] = 16665,
  [16666] = 16666,
  [16667] = 16667,
  [16668] = 16668,
  [16669] = 16669,
  [16670] = 16670,
  [16671] = 16671,
  [16672] = 16594,
  [16673] = 16673,
  [16674] = 16674,
  [16675] = 16675,
  [16676] = 16676,
  [16677] = 16677,
  [16678] = 16678,
  [16679] = 16679,
  [16680] = 16680,
  [16681] = 16681,
  [16682] = 16682,
  [16683] = 16683,
  [16684] = 16684,
  [16685] = 16685,
  [16686] = 16686,
  [16687] = 16687,
  [16688] = 16688,
  [16689] = 16596,
  [16690] = 16690,
  [16691] = 16691,
  [16692] = 16692,
  [16693] = 16693,
  [16694] = 16694,
  [16695] = 16695,
  [16696] = 16696,
  [16697] = 16584,
  [16698] = 16698,
  [16699] = 16586,
  [16700] = 16700,
  [16701] = 16588,
  [16702] = 16702,
  [16703] = 16633,
  [16704] = 16591,
  [16705] = 16594,
  [16706] = 16617,
  [16707] = 16596,
  [16708] = 16598,
  [16709] = 16598,
  [16710] = 16645,
  [16711] = 16600,
  [16712] = 16668,
  [16713] = 16713,
  [16714] = 16603,
  [16715] = 16587,
  [16716] = 16605,
  [16717] = 16600,
  [16718] = 16607,
  [16719] = 16608,
  [16720] = 16609,
  [16721] = 16610,
  [16722] = 16722,
  [16723] = 16612,
  [16724] = 16613,
  [16725] = 16725,
  [16726] = 16615,
  [16727] = 16727,
  [16728] = 16617,
  [16729] = 16635,
  [16730] = 16619,
  [16731] = 16620,
  [16732] = 16621,
  [16733] = 16622,
  [16734] = 16623,
  [16735] = 16735,
  [16736] = 16625,
  [16737] = 16627,
  [16738] = 16686,
  [16739] = 16739,
  [16740] = 16740,
  [16741] = 16741,
  [16742] = 16658,
  [16743] = 16665,
  [16744] = 16661,
  [16745] = 16662,
  [16746] = 16746,
  [16747] = 16747,
  [16748] = 16748,
  [16749] = 16609,
  [16750] = 16667,
  [16751] = 16652,
  [16752] = 16603,
  [16753] = 16753,
  [16754] = 16652,
  [16755] = 16652,
  [16756] = 16756,
  [16757] = 16678,
  [16758] = 16679,
  [16759] = 16759,
  [16760] = 16722,
  [16761] = 16761,
  [16762] = 16686,
  [16763] = 16683,
  [16764] = 16764,
  [16765] = 16765,
  [16766] = 16766,
  [16767] = 16695,
  [16768] = 16582,
  [16769] = 16613,
  [16770] = 16591,
  [16771] = 16594,
  [16772] = 16700,
  [16773] = 16596,
  [16774] = 16774,
  [16775] = 16598,
  [16776] = 16776,
  [16777] = 16777,
  [16778] = 16778,
  [16779] = 16779,
  [16780] = 16607,
  [16781] = 16608,
  [16782] = 16609,
  [16783] = 16610,
  [16784] = 16784,
  [16785] = 16612,
  [16786] = 16613,
  [16787] = 16605,
  [16788] = 16615,
  [16789] = 16789,
  [16790] = 16617,
  [16791] = 16791,
  [16792] = 16620,
  [16793] = 16621,
  [16794] = 16622,
  [16795] = 16623,
  [16796] = 16725,
  [16797] = 16625,
  [16798] = 16627,
  [16799] = 16799,
  [16800] = 16682,
  [16801] = 16801,
  [16802] = 16802,
  [16803] = 16658,
  [16804] = 16591,
  [16805] = 16662,
  [16806] = 16806,
  [16807] = 16807,
  [16808] = 16808,
  [16809] = 16607,
  [16810] = 16667,
  [16811] = 16811,
  [16812] = 16812,
  [16813] = 16813,
  [16814] = 16633,
  [16815] = 16713,
  [16816] = 16678,
  [16817] = 16679,
  [16818] = 16818,
  [16819] = 16819,
  [16820] = 16686,
  [16821] = 16608,
  [16822] = 16645,
  [16823] = 16695,
  [16824] = 16740,
  [16825] = 16825,
  [16826] = 16591,
  [16827] = 16594,
  [16828] = 16584,
  [16829] = 16596,
  [16830] = 16632,
  [16831] = 16598,
  [16832] = 16832,
  [16833] = 16601,
  [16834] = 16609,
  [16835] = 16590,
  [16836] = 16607,
  [16837] = 16608,
  [16838] = 16609,
  [16839] = 16610,
  [16840] = 16597,
  [16841] = 16612,
  [16842] = 16613,
  [16843] = 16843,
  [16844] = 16615,
  [16845] = 16845,
  [16846] = 16617,
  [16847] = 16847,
  [16848] = 16620,
  [16849] = 16621,
  [16850] = 16622,
  [16851] = 16623,
  [16852] = 16610,
  [16853] = 16625,
  [16854] = 16627,
  [16855] = 16855,
  [16856] = 16662,
  [16857] = 16669,
  [16858] = 16858,
  [16859] = 16859,
  [16860] = 16740,
  [16861] = 16667,
  [16862] = 16606,
  [16863] = 16863,
  [16864] = 16612,
  [16865] = 16613,
  [16866] = 16678,
  [16867] = 16679,
  [16868] = 16868,
  [16869] = 16686,
  [16870] = 16870,
  [16871] = 16871,
  [16872] = 16695,
  [16873] = 16873,
  [16874] = 16874,
  [16875] = 16591,
  [16876] = 16594,
  [16877] = 16877,
  [16878] = 16596,
  [16879] = 16879,
  [16880] = 16598,
  [16881] = 16881,
  [16882] = 16611,
  [16883] = 16676,
  [16884] = 16884,
  [16885] = 16607,
  [16886] = 16608,
  [16887] = 16609,
  [16888] = 16610,
  [16889] = 16889,
  [16890] = 16612,
  [16891] = 16613,
  [16892] = 16892,
  [16893] = 16615,
  [16894] = 16894,
  [16895] = 16617,
  [16896] = 16896,
  [16897] = 16620,
  [16898] = 16621,
  [16899] = 16622,
  [16900] = 16623,
  [16901] = 16901,
  [16902] = 16625,
  [16903] = 16627,
  [16904] = 16662,
  [16905] = 16905,
  [16906] = 16906,
  [16907] = 16907,
  [16908] = 16667,
  [16909] = 16909,
  [16910] = 16910,
  [16911] = 16911,
  [16912] = 16678,
  [16913] = 16679,
  [16914] = 16914,
  [16915] = 16686,
  [16916] = 16916,
  [16917] = 16917,
  [16918] = 16695,
  [16919] = 16919,
  [16920] = 16920,
  [16921] = 16591,
  [16922] = 16594,
  [16923] = 16923,
  [16924] = 16596,
  [16925] = 16925,
  [16926] = 16598,
  [16927] = 16690,
  [16928] = 16615,
  [16929] = 16929,
  [16930] = 16930,
  [16931] = 16607,
  [16932] = 16608,
  [16933] = 16609,
  [16934] = 16610,
  [16935] = 16935,
  [16936] = 16612,
  [16937] = 16613,
  [16938] = 16938,
  [16939] = 16615,
  [16940] = 16940,
  [16941] = 16617,
  [16942] = 16942,
  [16943] = 16620,
  [16944] = 16621,
  [16945] = 16622,
  [16946] = 16623,
  [16947] = 16652,
  [16948] = 16625,
  [16949] = 16627,
  [16950] = 16696,
  [16951] = 16951,
  [16952] = 16952,
  [16953] = 16953,
  [16954] = 16678,
  [16955] = 16679,
  [16956] = 16686,
  [16957] = 16591,
  [16958] = 16607,
  [16959] = 16608,
  [16960] = 16620,
  [16961] = 16618,
  [16962] = 16698,
  [16963] = 16678,
  [16964] = 16679,
  [16965] = 16686,
  [16966] = 16591,
  [16967] = 16607,
  [16968] = 16608,
  [16969] = 16620,
  [16970] = 16970,
  [16971] = 16971,
  [16972] = 16678,
  [16973] = 16679,
  [16974] = 16686,
  [16975] = 16591,
  [16976] = 16607,
  [16977] = 16608,
  [16978] = 16620,
  [16979] = 16678,
  [16980] = 16679,
  [16981] = 16686,
  [16982] = 16591,
  [16983] = 16607,
  [16984] = 16608,
  [16985] = 16620,
  [16986] = 16678,
  [16987] = 16679,
  [16988] = 16686,
  [16989] = 16591,
  [16990] = 16607,
  [16991] = 16608,
  [16992] = 16620,
  [16993] = 16678,
  [16994] = 16591,
  [16995] = 16607,
  [16996] = 16608,
  [16997] = 16620,
  [16998] = 16678,
  [16999] = 16591,
  [17000] = 16607,
  [17001] = 16608,
  [17002] = 16620,
  [17003] = 16591,
  [17004] = 16607,
  [17005] = 16608,
  [17006] = 16620,
  [17007] = 16591,
  [17008] = 16607,
  [17009] = 16608,
  [17010] = 16620,
  [17011] = 16591,
  [17012] = 16607,
  [17013] = 16608,
  [17014] = 16620,
  [17015] = 16591,
  [17016] = 16607,
  [17017] = 16608,
  [17018] = 16620,
  [17019] = 16591,
  [17020] = 16607,
  [17021] = 16608,
  [17022] = 16620,
  [17023] = 17023,
  [17024] = 17024,
  [17025] = 17025,
  [17026] = 17026,
  [17027] = 17027,
  [17028] = 17028,
  [17029] = 17029,
  [17030] = 17030,
  [17031] = 17031,
  [17032] = 17032,
  [17033] = 16670,
  [17034] = 16614,
  [17035] = 16894,
  [17036] = 17036,
  [17037] = 17037,
  [17038] = 17038,
  [17039] = 16906,
  [17040] = 16599,
  [17041] = 17041,
  [17042] = 17036,
  [17043] = 16610,
  [17044] = 16617,
  [17045] = 17045,
  [17046] = 16713,
  [17047] = 17047,
  [17048] = 16619,
  [17049] = 17049,
  [17050] = 16590,
  [17051] = 16812,
  [17052] = 17052,
  [17053] = 17053,
  [17054] = 16620,
  [17055] = 17055,
  [17056] = 17056,
  [17057] = 16586,
  [17058] = 16863,
  [17059] = 17059,
  [17060] = 17060,
  [17061] = 16660,
  [17062] = 16889,
  [17063] = 16811,
  [17064] = 17064,
  [17065] = 17065,
  [17066] = 17066,
  [17067] = 16601,
  [17068] = 16621,
  [17069] = 16622,
  [17070] = 16588,
  [17071] = 17071,
  [17072] = 16606,
  [17073] = 16863,
  [17074] = 17074,
  [17075] = 16601,
  [17076] = 16764,
  [17077] = 16623,
  [17078] = 16624,
  [17079] = 16601,
  [17080] = 16629,
  [17081] = 17081,
  [17082] = 16735,
  [17083] = 17083,
  [17084] = 16664,
  [17085] = 16776,
  [17086] = 16595,
  [17087] = 17025,
  [17088] = 16747,
  [17089] = 17089,
  [17090] = 16624,
  [17091] = 16629,
  [17092] = 17092,
  [17093] = 17064,
  [17094] = 17094,
  [17095] = 16664,
  [17096] = 17096,
  [17097] = 16664,
  [17098] = 17098,
  [17099] = 16595,
  [17100] = 17100,
  [17101] = 17101,
  [17102] = 16935,
  [17103] = 16633,
  [17104] = 17092,
  [17105] = 16779,
  [17106] = 16625,
  [17107] = 17098,
  [17108] = 17108,
  [17109] = 17074,
  [17110] = 17110,
  [17111] = 16623,
  [17112] = 16645,
  [17113] = 16671,
  [17114] = 17114,
  [17115] = 16892,
  [17116] = 17116,
  [17117] = 17117,
  [17118] = 17118,
  [17119] = 16585,
  [17120] = 17120,
  [17121] = 17121,
  [17122] = 17122,
  [17123] = 17123,
  [17124] = 17124,
  [17125] = 17125,
  [17126] = 17126,
  [17127] = 17127,
  [17128] = 17128,
  [17129] = 17129,
  [17130] = 17130,
  [17131] = 17131,
  [17132] = 17132,
  [17133] = 17133,
  [17134] = 16722,
  [17135] = 17135,
  [17136] = 17136,
  [17137] = 17137,
  [17138] = 17138,
  [17139] = 16647,
  [17140] = 16725,
  [17141] = 16942,
  [17142] = 17142,
  [17143] = 17143,
  [17144] = 16713,
  [17145] = 16766,
  [17146] = 16818,
  [17147] = 16843,
  [17148] = 17148,
  [17149] = 17149,
  [17150] = 16855,
  [17151] = 17151,
  [17152] = 17152,
  [17153] = 17153,
  [17154] = 16582,
  [17155] = 17155,
  [17156] = 17156,
  [17157] = 16595,
  [17158] = 17158,
  [17159] = 17159,
  [17160] = 17158,
  [17161] = 17161,
  [17162] = 16624,
  [17163] = 17163,
  [17164] = 16655,
  [17165] = 16629,
  [17166] = 2701,
  [17167] = 17120,
  [17168] = 16595,
  [17169] = 17121,
  [17170] = 16627,
  [17171] = 17122,
  [17172] = 16624,
  [17173] = 17125,
  [17174] = 16764,
  [17175] = 17118,
  [17176] = 16684,
  [17177] = 17126,
  [17178] = 16599,
  [17179] = 17179,
  [17180] = 17127,
  [17181] = 16629,
  [17182] = 16713,
  [17183] = 17045,
  [17184] = 16774,
  [17185] = 17117,
  [17186] = 17143,
  [17187] = 17187,
  [17188] = 16777,
  [17189] = 16784,
  [17190] = 16802,
  [17191] = 17191,
  [17192] = 17192,
  [17193] = 16587,
  [17194] = 5227,
  [17195] = 17195,
  [17196] = 17196,
  [17197] = 17197,
  [17198] = 17092,
  [17199] = 17199,
  [17200] = 16722,
  [17201] = 16725,
  [17202] = 16587,
  [17203] = 16597,
  [17204] = 17204,
  [17205] = 17128,
  [17206] = 17206,
  [17207] = 17129,
  [17208] = 17130,
  [17209] = 16582,
  [17210] = 16863,
  [17211] = 17131,
  [17212] = 16665,
  [17213] = 17213,
  [17214] = 16624,
  [17215] = 16629,
  [17216] = 16901,
  [17217] = 16628,
  [17218] = 17218,
  [17219] = 17219,
  [17220] = 16873,
  [17221] = 17132,
  [17222] = 17123,
  [17223] = 17124,
  [17224] = 17197,
  [17225] = 17225,
  [17226] = 17226,
  [17227] = 16658,
  [17228] = 17228,
  [17229] = 16700,
  [17230] = 17230,
  [17231] = 16630,
  [17232] = 16624,
  [17233] = 16629,
  [17234] = 17234,
  [17235] = 17235,
  [17236] = 17187,
  [17237] = 17133,
  [17238] = 17238,
  [17239] = 16740,
  [17240] = 16631,
  [17241] = 16813,
  [17242] = 17242,
  [17243] = 16622,
  [17244] = 17244,
  [17245] = 17230,
  [17246] = 16756,
  [17247] = 16601,
  [17248] = 16863,
  [17249] = 16713,
  [17250] = 16664,
  [17251] = 17092,
  [17252] = 16658,
  [17253] = 16660,
  [17254] = 16669,
  [17255] = 17255,
  [17256] = 16917,
  [17257] = 16675,
  [17258] = 17258,
  [17259] = 16587,
  [17260] = 16812,
  [17261] = 5215,
  [17262] = 17059,
  [17263] = 17060,
  [17264] = 16665,
  [17265] = 17265,
  [17266] = 17255,
  [17267] = 17267,
  [17268] = 16582,
  [17269] = 16691,
  [17270] = 17270,
  [17271] = 17271,
  [17272] = 17272,
  [17273] = 17135,
  [17274] = 16635,
  [17275] = 17275,
  [17276] = 16764,
  [17277] = 17267,
  [17278] = 17136,
  [17279] = 16624,
  [17280] = 17137,
  [17281] = 17281,
  [17282] = 16629,
  [17283] = 17138,
  [17284] = 17284,
  [17285] = 16606,
  [17286] = 16863,
  [17287] = 17287,
  [17288] = 17288,
  [17289] = 16587,
  [17290] = 17290,
  [17291] = 16665,
  [17292] = 16636,
  [17293] = 17293,
  [17294] = 17294,
  [17295] = 16582,
  [17296] = 16722,
  [17297] = 17297,
  [17298] = 16700,
  [17299] = 17299,
  [17300] = 17300,
  [17301] = 16647,
  [17302] = 5009,
  [17303] = 16682,
  [17304] = 17304,
  [17305] = 16628,
  [17306] = 17306,
  [17307] = 16683,
  [17308] = 17308,
  [17309] = 17219,
  [17310] = 17310,
  [17311] = 16725,
  [17312] = 17312,
  [17313] = 16700,
  [17314] = 17314,
  [17315] = 17110,
  [17316] = 17316,
  [17317] = 5265,
  [17318] = 16624,
  [17319] = 17319,
  [17320] = 17320,
  [17321] = 17321,
  [17322] = 17322,
  [17323] = 16666,
  [17324] = 16629,
  [17325] = 17325,
  [17326] = 17326,
  [17327] = 16648,
  [17328] = 17328,
  [17329] = 16901,
  [17330] = 17330,
  [17331] = 17331,
  [17332] = 16812,
  [17333] = 16879,
  [17334] = 17059,
  [17335] = 17060,
  [17336] = 17336,
  [17337] = 16687,
  [17338] = 17338,
  [17339] = 17339,
  [17340] = 17340,
  [17341] = 17023,
  [17342] = 16605,
  [17343] = 17343,
  [17344] = 17344,
  [17345] = 16722,
  [17346] = 17346,
  [17347] = 17299,
  [17348] = 17348,
  [17349] = 17349,
  [17350] = 16713,
  [17351] = 17351,
  [17352] = 16642,
  [17353] = 17353,
  [17354] = 17354,
  [17355] = 16919,
  [17356] = 16740,
  [17357] = 16813,
  [17358] = 16907,
  [17359] = 16700,
  [17360] = 16661,
  [17361] = 16909,
  [17362] = 16625,
  [17363] = 17363,
  [17364] = 16615,
  [17365] = 16643,
  [17366] = 17366,
  [17367] = 16907,
  [17368] = 16619,
  [17369] = 17369,
  [17370] = 16909,
  [17371] = 16910,
  [17372] = 17372,
  [17373] = 17310,
  [17374] = 16585,
  [17375] = 17038,
  [17376] = 16911,
  [17377] = 16590,
  [17378] = 16597,
  [17379] = 16587,
  [17380] = 17314,
  [17381] = 17322,
  [17382] = 17325,
  [17383] = 17116,
  [17384] = 17384,
  [17385] = 17047,
  [17386] = 16665,
  [17387] = 17387,
  [17388] = 16725,
  [17389] = 16812,
  [17390] = 17390,
  [17391] = 17059,
  [17392] = 17060,
  [17393] = 17393,
  [17394] = 17394,
  [17395] = 16813,
  [17396] = 17396,
  [17397] = 17397,
  [17398] = 17142,
  [17399] = 17399,
  [17400] = 17400,
  [17401] = 16587,
  [17402] = 16612,
  [17403] = 16914,
  [17404] = 17404,
  [17405] = 17028,
  [17406] = 16648,
  [17407] = 17407,
  [17408] = 17408,
  [17409] = 16722,
  [17410] = 16665,
  [17411] = 17411,
  [17412] = 17412,
  [17413] = 11549,
  [17414] = 17414,
  [17415] = 16916,
  [17416] = 16812,
  [17417] = 17059,
  [17418] = 17060,
  [17419] = 16585,
  [17420] = 16652,
  [17421] = 16910,
  [17422] = 17422,
  [17423] = 16683,
  [17424] = 16696,
  [17425] = 17299,
  [17426] = 17426,
  [17427] = 16633,
  [17428] = 16874,
  [17429] = 16645,
  [17430] = 17306,
  [17431] = 17431,
  [17432] = 5240,
  [17433] = 17059,
  [17434] = 17060,
  [17435] = 17435,
  [17436] = 16764,
  [17437] = 16725,
  [17438] = 17438,
  [17439] = 17426,
  [17440] = 16917,
  [17441] = 16919,
  [17442] = 17059,
  [17443] = 17060,
  [17444] = 17310,
  [17445] = 17445,
  [17446] = 17314,
  [17447] = 16585,
  [17448] = 17322,
  [17449] = 17449,
  [17450] = 17059,
  [17451] = 17060,
  [17452] = 17325,
  [17453] = 17029,
  [17454] = 16590,
  [17455] = 17455,
  [17456] = 16587,
  [17457] = 17059,
  [17458] = 17060,
  [17459] = 16901,
  [17460] = 17460,
  [17461] = 16665,
  [17462] = 17462,
  [17463] = 17463,
  [17464] = 17059,
  [17465] = 17060,
  [17466] = 16766,
  [17467] = 17467,
  [17468] = 16597,
  [17469] = 17469,
  [17470] = 17059,
  [17471] = 17059,
  [17472] = 17060,
  [17473] = 16607,
  [17474] = 16695,
  [17475] = 16599,
  [17476] = 16740,
  [17477] = 17477,
  [17478] = 17059,
  [17479] = 17060,
  [17480] = 16813,
  [17481] = 16590,
  [17482] = 16595,
  [17483] = 17156,
  [17484] = 16597,
  [17485] = 17059,
  [17486] = 17060,
  [17487] = 16585,
  [17488] = 8098,
  [17489] = 17158,
  [17490] = 17490,
  [17491] = 16658,
  [17492] = 17059,
  [17493] = 17493,
  [17494] = 17159,
  [17495] = 16713,
  [17496] = 17060,
  [17497] = 17059,
  [17498] = 5216,
  [17499] = 17499,
  [17500] = 17500,
  [17501] = 16665,
  [17502] = 16590,
  [17503] = 16597,
  [17504] = 17049,
  [17505] = 17505,
  [17506] = 17506,
  [17507] = 16585,
  [17508] = 17508,
  [17509] = 16660,
  [17510] = 16661,
  [17511] = 16652,
  [17512] = 17027,
  [17513] = 16901,
  [17514] = 16662,
  [17515] = 16907,
  [17516] = 16909,
  [17517] = 16910,
  [17518] = 16911,
  [17519] = 16914,
  [17520] = 16917,
  [17521] = 16919,
  [17522] = 17522,
  [17523] = 17101,
  [17524] = 16608,
  [17525] = 17525,
  [17526] = 17526,
  [17527] = 17527,
  [17528] = 16940,
  [17529] = 17490,
  [17530] = 16739,
  [17531] = 17531,
  [17532] = 16818,
  [17533] = 17047,
  [17534] = 16843,
  [17535] = 17535,
  [17536] = 16855,
  [17537] = 17537,
  [17538] = 17538,
  [17539] = 16832,
  [17540] = 16905,
  [17541] = 17199,
  [17542] = 17206,
  [17543] = 17225,
  [17544] = 17244,
  [17545] = 17271,
  [17546] = 17287,
  [17547] = 17294,
  [17548] = 17300,
  [17549] = 17304,
  [17550] = 16652,
  [17551] = 17467,
  [17552] = 17552,
  [17553] = 17553,
  [17554] = 17554,
  [17555] = 17555,
  [17556] = 17556,
  [17557] = 17557,
  [17558] = 17558,
  [17559] = 17559,
  [17560] = 17560,
  [17561] = 17369,
  [17562] = 17562,
  [17563] = 16819,
  [17564] = 17238,
  [17565] = 17288,
  [17566] = 17400,
  [17567] = 16669,
  [17568] = 17151,
  [17569] = 17152,
  [17570] = 16587,
  [17571] = 17571,
  [17572] = 16920,
  [17573] = 17573,
  [17574] = 16764,
  [17575] = 17575,
  [17576] = 17576,
  [17577] = 17396,
  [17578] = 17578,
  [17579] = 17579,
  [17580] = 17580,
  [17581] = 17581,
  [17582] = 17582,
  [17583] = 17094,
  [17584] = 17584,
  [17585] = 17585,
  [17586] = 16633,
  [17587] = 17052,
  [17588] = 17552,
  [17589] = 17158,
  [17590] = 17590,
  [17591] = 17553,
  [17592] = 17554,
  [17593] = 17593,
  [17594] = 16807,
  [17595] = 16658,
  [17596] = 16764,
  [17597] = 16685,
  [17598] = 17598,
  [17599] = 16923,
  [17600] = 17326,
  [17601] = 17601,
  [17602] = 16660,
  [17603] = 17603,
  [17604] = 16645,
  [17605] = 16722,
  [17606] = 16725,
  [17607] = 16661,
  [17608] = 17608,
  [17609] = 17609,
  [17610] = 16667,
  [17611] = 17611,
  [17612] = 17612,
  [17613] = 17590,
  [17614] = 16662,
  [17615] = 17615,
  [17616] = 17616,
  [17617] = 17617,
  [17618] = 16680,
  [17619] = 16695,
  [17620] = 17306,
  [17621] = 16681,
  [17622] = 17622,
  [17623] = 16666,
  [17624] = 16812,
  [17625] = 17490,
  [17626] = 16739,
  [17627] = 17531,
  [17628] = 17535,
  [17629] = 16832,
  [17630] = 16905,
  [17631] = 17199,
  [17632] = 17206,
  [17633] = 17225,
  [17634] = 17271,
  [17635] = 17287,
  [17636] = 17294,
  [17637] = 17300,
  [17638] = 17304,
  [17639] = 17462,
  [17640] = 17467,
  [17641] = 17552,
  [17642] = 17553,
  [17643] = 17554,
  [17644] = 17555,
  [17645] = 17556,
  [17646] = 17557,
  [17647] = 17558,
  [17648] = 17559,
  [17649] = 17560,
  [17650] = 17369,
  [17651] = 17562,
  [17652] = 16819,
  [17653] = 17238,
  [17654] = 17288,
  [17655] = 17400,
  [17656] = 17575,
  [17657] = 17396,
  [17658] = 17578,
  [17659] = 17579,
  [17660] = 17580,
  [17661] = 17581,
  [17662] = 17582,
  [17663] = 17663,
  [17664] = 16687,
  [17665] = 16662,
  [17666] = 16620,
  [17667] = 17293,
  [17668] = 16669,
  [17669] = 16665,
  [17670] = 17670,
  [17671] = 16667,
  [17672] = 17571,
  [17673] = 17673,
  [17674] = 17674,
  [17675] = 17675,
  [17676] = 17676,
  [17677] = 16925,
  [17678] = 16669,
  [17679] = 17679,
  [17680] = 17680,
  [17681] = 16690,
  [17682] = 17682,
  [17683] = 17490,
  [17684] = 16739,
  [17685] = 17531,
  [17686] = 17535,
  [17687] = 17462,
  [17688] = 17467,
  [17689] = 17552,
  [17690] = 17553,
  [17691] = 17554,
  [17692] = 17555,
  [17693] = 17556,
  [17694] = 17557,
  [17695] = 17558,
  [17696] = 17559,
  [17697] = 17560,
  [17698] = 17369,
  [17699] = 17562,
  [17700] = 16819,
  [17701] = 17238,
  [17702] = 17288,
  [17703] = 17575,
  [17704] = 17578,
  [17705] = 17579,
  [17706] = 17580,
  [17707] = 17581,
  [17708] = 17531,
  [17709] = 17709,
  [17710] = 16696,
  [17711] = 17055,
  [17712] = 16682,
  [17713] = 17713,
  [17714] = 16652,
  [17715] = 16811,
  [17716] = 17716,
  [17717] = 16896,
  [17718] = 17179,
  [17719] = 17096,
  [17720] = 17720,
  [17721] = 16671,
  [17722] = 17151,
  [17723] = 16923,
  [17724] = 17152,
  [17725] = 17081,
  [17726] = 17555,
  [17727] = 16590,
  [17728] = 17490,
  [17729] = 16739,
  [17730] = 17531,
  [17731] = 17535,
  [17732] = 17575,
  [17733] = 17037,
  [17734] = 16925,
  [17735] = 17735,
  [17736] = 16702,
  [17737] = 16825,
  [17738] = 16587,
  [17739] = 16665,
  [17740] = 16675,
  [17741] = 17299,
  [17742] = 16627,
  [17743] = 16601,
  [17744] = 16739,
  [17745] = 17531,
  [17746] = 17575,
  [17747] = 16624,
  [17748] = 17748,
  [17749] = 17749,
  [17750] = 17310,
  [17751] = 17314,
  [17752] = 17322,
  [17753] = 17325,
  [17754] = 17754,
  [17755] = 17755,
  [17756] = 17756,
  [17757] = 16597,
  [17758] = 16739,
  [17759] = 17575,
  [17760] = 17760,
  [17761] = 17761,
  [17762] = 16675,
  [17763] = 16678,
  [17764] = 16739,
  [17765] = 17575,
  [17766] = 16679,
  [17767] = 17234,
  [17768] = 17330,
  [17769] = 17349,
  [17770] = 16739,
  [17771] = 17575,
  [17772] = 17772,
  [17773] = 17351,
  [17774] = 17353,
  [17775] = 17354,
  [17776] = 17575,
  [17777] = 17777,
  [17778] = 17372,
  [17779] = 17384,
  [17780] = 17394,
  [17781] = 17575,
  [17782] = 17782,
  [17783] = 16585,
  [17784] = 17784,
  [17785] = 17785,
  [17786] = 17575,
  [17787] = 17399,
  [17788] = 17578,
  [17789] = 17435,
  [17790] = 17522,
  [17791] = 17575,
  [17792] = 17792,
  [17793] = 17526,
  [17794] = 17527,
  [17795] = 17617,
  [17796] = 17575,
  [17797] = 16680,
  [17798] = 16681,
  [17799] = 17679,
  [17800] = 17682,
  [17801] = 17195,
  [17802] = 17608,
  [17803] = 17709,
  [17804] = 17713,
  [17805] = 17716,
  [17806] = 17735,
  [17807] = 17748,
  [17808] = 17579,
  [17809] = 17580,
  [17810] = 16870,
  [17811] = 17811,
  [17812] = 16678,
  [17813] = 17754,
  [17814] = 17756,
  [17815] = 16679,
  [17816] = 17761,
  [17817] = 17777,
  [17818] = 17784,
  [17819] = 17785,
  [17820] = 17617,
  [17821] = 17537,
  [17822] = 16585,
  [17823] = 16713,
  [17824] = 17824,
  [17825] = 16680,
  [17826] = 16930,
  [17827] = 16953,
  [17828] = 17828,
  [17829] = 17066,
  [17830] = 17469,
  [17831] = 17404,
  [17832] = 17340,
  [17833] = 17833,
  [17834] = 17312,
  [17835] = 16658,
  [17836] = 17836,
  [17837] = 16660,
  [17838] = 16812,
  [17839] = 17055,
  [17840] = 17500,
  [17841] = 17438,
  [17842] = 17161,
  [17843] = 16901,
  [17844] = 16764,
  [17845] = 16681,
  [17846] = 17431,
  [17847] = 17055,
  [17848] = 17081,
  [17849] = 17849,
  [17850] = 17850,
  [17851] = 16582,
  [17852] = 16585,
  [17853] = 16585,
  [17854] = 16606,
  [17855] = 16629,
  [17856] = 17556,
  [17857] = 16863,
  [17858] = 17858,
  [17859] = 16597,
  [17860] = 17860,
  [17861] = 17749,
  [17862] = 16740,
  [17863] = 17557,
  [17864] = 16678,
  [17865] = 16811,
  [17866] = 17866,
  [17867] = 17611,
  [17868] = 17868,
  [17869] = 16601,
  [17870] = 17679,
  [17871] = 17871,
  [17872] = 17030,
  [17873] = 17873,
  [17874] = 17682,
  [17875] = 17192,
  [17876] = 17312,
  [17877] = 17500,
  [17878] = 17148,
  [17879] = 17149,
  [17880] = 17535,
  [17881] = 17881,
  [17882] = 16700,
  [17883] = 17493,
  [17884] = 16713,
  [17885] = 17885,
  [17886] = 17886,
  [17887] = 17709,
  [17888] = 16722,
  [17889] = 16606,
  [17890] = 16679,
  [17891] = 16901,
  [17892] = 16863,
  [17893] = 16725,
  [17894] = 17713,
  [17895] = 16907,
  [17896] = 16909,
  [17897] = 17616,
  [17898] = 17716,
  [17899] = 17312,
  [17900] = 17500,
  [17901] = 16667,
  [17902] = 16649,
  [17903] = 16652,
  [17904] = 16910,
  [17905] = 16911,
  [17906] = 16914,
  [17907] = 16916,
  [17908] = 16917,
  [17909] = 16674,
  [17910] = 16911,
  [17911] = 16919,
  [17912] = 16920,
  [17913] = 16914,
  [17914] = 16722,
  [17915] = 17915,
  [17916] = 16923,
  [17917] = 16925,
  [17918] = 17918,
  [17919] = 16901,
  [17920] = 17312,
  [17921] = 17500,
  [17922] = 17735,
  [17923] = 16690,
  [17924] = 17748,
  [17925] = 16725,
  [17926] = 16664,
  [17927] = 16595,
  [17928] = 16624,
  [17929] = 17500,
  [17930] = 17455,
  [17931] = 16696,
  [17932] = 17932,
  [17933] = 16629,
  [17934] = 17092,
  [17935] = 17754,
  [17936] = 17155,
  [17937] = 17500,
  [17938] = 17938,
  [17939] = 17939,
  [17940] = 17500,
  [17941] = 17756,
  [17942] = 17942,
  [17943] = 17500,
  [17944] = 17944,
  [17945] = 17407,
  [17946] = 17500,
  [17947] = 17052,
  [17948] = 17761,
  [17949] = 17500,
  [17950] = 17950,
  [17951] = 16686,
  [17952] = 17500,
  [17953] = 16938,
  [17954] = 16811,
  [17955] = 17500,
  [17956] = 17598,
  [17957] = 17411,
  [17958] = 17500,
  [17959] = 16601,
  [17960] = 17777,
  [17961] = 17196,
  [17962] = 17089,
  [17963] = 16606,
  [17964] = 16863,
  [17965] = 17284,
  [17966] = 17336,
  [17967] = 17784,
  [17968] = 17408,
  [17969] = 16722,
  [17970] = 17785,
  [17971] = 16664,
  [17972] = 16595,
  [17973] = 16652,
  [17974] = 16624,
  [17975] = 17975,
  [17976] = 16629,
  [17977] = 17531,
  [17978] = 17414,
  [17979] = 17422,
  [17980] = 17499,
  [17981] = 17265,
  [17982] = 17290,
  [17983] = 17331,
  [17984] = 17339,
  [17985] = 17615,
  [17986] = 17849,
  [17987] = 17987,
  [17988] = 17987,
  [17989] = 17622,
  [17990] = 17670,
  [17991] = 17328,
  [17992] = 17092,
  [17993] = 17116,
  [17994] = 17142,
  [17995] = 17995,
  [17996] = 17426,
  [17997] = 17680,
  [17998] = 16877,
  [17999] = 17999,
  [18000] = 17975,
  [18001] = 17265,
  [18002] = 17290,
  [18003] = 17331,
  [18004] = 17339,
  [18005] = 17615,
  [18006] = 17849,
  [18007] = 18007,
  [18008] = 16594,
  [18009] = 18009,
  [18010] = 18010,
  [18011] = 17032,
  [18012] = 17581,
  [18013] = 18013,
  [18014] = 18014,
  [18015] = 16725,
  [18016] = 17975,
  [18017] = 17290,
  [18018] = 17331,
  [18019] = 17339,
  [18020] = 17615,
  [18021] = 16671,
  [18022] = 17026,
  [18023] = 17575,
  [18024] = 16632,
  [18025] = 16633,
  [18026] = 5251,
  [18027] = 17558,
  [18028] = 18028,
  [18029] = 17306,
  [18030] = 16666,
  [18031] = 16687,
  [18032] = 16671,
  [18033] = 17094,
  [18034] = 18034,
  [18035] = 17120,
  [18036] = 16656,
  [18037] = 17121,
  [18038] = 17122,
  [18039] = 17125,
  [18040] = 17126,
  [18041] = 18041,
  [18042] = 17603,
  [18043] = 17128,
  [18044] = 17129,
  [18045] = 17226,
  [18046] = 18046,
  [18047] = 17047,
  [18048] = 17130,
  [18049] = 16652,
  [18050] = 17131,
  [18051] = 16970,
  [18052] = 16688,
  [18053] = 16713,
  [18054] = 16601,
  [18055] = 16668,
  [18056] = 18056,
  [18057] = 17132,
  [18058] = 16884,
  [18059] = 16606,
  [18060] = 17133,
  [18061] = 17135,
  [18062] = 16624,
  [18063] = 17136,
  [18064] = 16722,
  [18065] = 16629,
  [18066] = 16624,
  [18067] = 16725,
  [18068] = 16695,
  [18069] = 17108,
  [18070] = 16584,
  [18071] = 16629,
  [18072] = 16586,
  [18073] = 18073,
  [18074] = 16588,
  [18075] = 16690,
  [18076] = 17137,
  [18077] = 17850,
  [18078] = 18078,
  [18079] = 16811,
  [18080] = 16929,
  [18081] = 16591,
  [18082] = 18082,
  [18083] = 16587,
  [18084] = 17871,
  [18085] = 16665,
  [18086] = 16594,
  [18087] = 16686,
  [18088] = 16596,
  [18089] = 17081,
  [18090] = 16598,
  [18091] = 16740,
  [18092] = 16600,
  [18093] = 17573,
  [18094] = 17041,
  [18095] = 16603,
  [18096] = 16585,
  [18097] = 16605,
  [18098] = 16920,
  [18099] = 16663,
  [18100] = 17408,
  [18101] = 16607,
  [18102] = 16608,
  [18103] = 17414,
  [18104] = 16636,
  [18105] = 17192,
  [18106] = 17135,
  [18107] = 16596,
  [18108] = 18078,
  [18109] = 16609,
  [18110] = 16610,
  [18111] = 18111,
  [18112] = 16612,
  [18113] = 16613,
  [18114] = 16652,
  [18115] = 16615,
  [18116] = 18116,
  [18117] = 16617,
  [18118] = 16764,
  [18119] = 16619,
  [18120] = 16620,
  [18121] = 18121,
  [18122] = 16645,
  [18123] = 17071,
  [18124] = 17871,
  [18125] = 17559,
  [18126] = 16722,
  [18127] = 16621,
  [18128] = 16622,
  [18129] = 16623,
  [18130] = 17422,
  [18131] = 16625,
  [18132] = 17622,
  [18133] = 17242,
  [18134] = 16725,
  [18135] = 16971,
  [18136] = 16881,
  [18137] = 16582,
  [18138] = 18138,
  [18139] = 17031,
  [18140] = 17975,
  [18141] = 18116,
  [18142] = 16627,
  [18143] = 16628,
  [18144] = 17136,
  [18145] = 18145,
  [18146] = 17258,
  [18147] = 16920,
  [18148] = 16923,
  [18149] = 17582,
  [18150] = 17137,
  [18151] = 17138,
  [18152] = 16632,
  [18153] = 16647,
  [18154] = 16652,
  [18155] = 16713,
  [18156] = 16656,
  [18157] = 16668,
  [18158] = 17094,
  [18159] = 16753,
  [18160] = 16637,
  [18161] = 16630,
  [18162] = 16631,
  [18163] = 18163,
  [18164] = 16764,
  [18165] = 17083,
  [18166] = 16635,
  [18167] = 17163,
  [18168] = 17560,
  [18169] = 17576,
  [18170] = 16636,
  [18171] = 16700,
  [18172] = 16688,
  [18173] = 16598,
  [18174] = 16642,
  [18175] = 16713,
  [18176] = 16590,
  [18177] = 16766,
  [18178] = 16818,
  [18179] = 16843,
  [18180] = 16855,
  [18181] = 17151,
  [18182] = 17152,
  [18183] = 17155,
  [18184] = 16642,
  [18185] = 16643,
  [18186] = 16597,
  [18187] = 16688,
  [18188] = 18111,
  [18189] = 17138,
  [18190] = 18190,
  [18191] = 17092,
  [18192] = 16916,
  [18193] = 17871,
  [18194] = 17593,
  [18195] = 16648,
  [18196] = 16925,
  [18197] = 16643,
  [18198] = 16587,
  [18199] = 18199,
  [18200] = 17538,
  [18201] = 17116,
  [18202] = 17142,
  [18203] = 17573,
  [18204] = 17024,
  [18205] = 17426,
  [18206] = 16595,
  [18207] = 17117,
  [18208] = 16658,
  [18209] = 17053,
  [18210] = 16660,
  [18211] = 16661,
  [18212] = 16662,
  [18213] = 16812,
  [18214] = 18214,
  [18215] = 17320,
  [18216] = 17445,
  [18217] = 17833,
  [18218] = 16667,
  [18219] = 5261,
  [18220] = 16669,
  [18221] = 17562,
  [18222] = 16585,
  [18223] = 16600,
  [18224] = 17143,
  [18225] = 17187,
  [18226] = 16713,
  [18227] = 16675,
  [18228] = 16665,
  [18229] = 18229,
  [18230] = 16678,
  [18231] = 16679,
  [18232] = 17349,
  [18233] = 17351,
  [18234] = 17353,
  [18235] = 17354,
  [18236] = 17372,
  [18237] = 17394,
  [18238] = 17399,
  [18239] = 17435,
  [18240] = 17522,
  [18241] = 17526,
  [18242] = 17527,
  [18243] = 17617,
  [18244] = 16680,
  [18245] = 16681,
  [18246] = 17679,
  [18247] = 17682,
  [18248] = 17709,
  [18249] = 17713,
  [18250] = 17716,
  [18251] = 17735,
  [18252] = 17748,
  [18253] = 17754,
  [18254] = 17756,
  [18255] = 17761,
  [18256] = 17777,
  [18257] = 17784,
  [18258] = 17785,
  [18259] = 16695,
  [18260] = 18260,
  [18261] = 18028,
  [18262] = 16722,
  [18263] = 16725,
  [18264] = 16777,
  [18265] = 16587,
  [18266] = 16686,
  [18267] = 17336,
  [18268] = 17408,
  [18269] = 17414,
  [18270] = 17422,
  [18271] = 17622,
  [18272] = 17670,
  [18273] = 17680,
  [18274] = 16603,
  [18275] = 17192,
  [18276] = 16774,
  [18277] = 17117,
  [18278] = 18278,
  [18279] = 17143,
  [18280] = 17187,
  [18281] = 16777,
  [18282] = 16784,
  [18283] = 16802,
  [18284] = 18284,
  [18285] = 17135,
  [18286] = 17136,
  [18287] = 16665,
  [18288] = 16688,
  [18289] = 17462,
};

static const TSCharacterRange sym_permission_type_character_set_1[] = {
  {'D', 'D'}, {'I', 'I'}, {'M', 'M'}, {'R', 'R'}, {'X', 'X'}, {'d', 'd'}, {'i', 'i'}, {'m', 'm'},
  {'r', 'r'}, {'x', 'x'},
};

static const TSCharacterRange sym_dotnet_assembly_name_character_set_1[] = {
  {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6},
  {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377}, {0x37a, 0x37d},
  {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x48a, 0x52f},
  {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f}, {0x671, 0x6d3},
  {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f}, {0x74d, 0x7a5},
  {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824}, {0x828, 0x828},
  {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d}, {0x950, 0x950},
  {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a}, {0xa0f, 0xa10},
  {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa72, 0xa74},
  {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd}, {0xad0, 0xad0},
  {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39},
  {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95},
  {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0}, {0xc05, 0xc0c},
  {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61}, {0xc80, 0xc80},
  {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde}, {0xce0, 0xce1},
  {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56}, {0xd5f, 0xd61},
  {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30}, {0xe32, 0xe33},
  {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0}, {0xeb2, 0xeb3},
  {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c}, {0xf88, 0xf8c},
  {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070}, {0x1075, 0x1081},
  {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd},
  {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16f1, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731}, {0x1740, 0x1751},
  {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x1884}, {0x1887, 0x18a8},
  {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x1a00, 0x1a16},
  {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5}, {0x1c00, 0x1c23},
  {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c8a}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6},
  {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c},
  {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128},
  {0x212a, 0x212d}, {0x212f, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2183, 0x2184}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee},
  {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6},
  {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2e2f, 0x2e2f},
  {0x3005, 0x3006}, {0x3031, 0x3035}, {0x303b, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f},
  {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f},
  {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6e5}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7cd}, {0xa7d0, 0xa7d1},
  {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7dc}, {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3},
  {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf},
  {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a},
  {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea},
  {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69},
  {0xab70, 0xabe2}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17},
  {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1},
  {0xfbd3, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdfb}, {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a},
  {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a},
  {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x10340},
  {0x10342, 0x10349}, {0x10350, 0x10375}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb},
  {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1},
  {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x105c0, 0x105f3}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0},
  {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876},
  {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a00},
  {0x10a10, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10b00, 0x10b35},
  {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d23}, {0x10d4a, 0x10d65},
  {0x10d6f, 0x10d85}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10ec2, 0x10ec4}, {0x10f00, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f45}, {0x10f70, 0x10f81},
  {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11071, 0x11072}, {0x11075, 0x11075}, {0x11083, 0x110af}, {0x110d0, 0x110e8}, {0x11103, 0x11126},
  {0x11144, 0x11144}, {0x11147, 0x11147}, {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2}, {0x111c1, 0x111c4}, {0x111da, 0x111da}, {0x111dc, 0x111dc},
  {0x11200, 0x11211}, {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8},
  {0x112b0, 0x112de}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133d, 0x1133d},
  {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11380, 0x11389}, {0x1138b, 0x1138b}, {0x1138e, 0x1138e}, {0x11390, 0x113b5}, {0x113b7, 0x113b7}, {0x113d1, 0x113d1},
  {0x113d3, 0x113d3}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x1145f, 0x11461}, {0x11480, 0x114af}, {0x114c4, 0x114c5}, {0x114c7, 0x114c7}, {0x11580, 0x115ae},
  {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11680, 0x116aa}, {0x116b8, 0x116b8}, {0x11700, 0x1171a}, {0x11740, 0x11746}, {0x11800, 0x1182b},
  {0x118a0, 0x118df}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941},
  {0x119a0, 0x119a7}, {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3}, {0x11a00, 0x11a00}, {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50},
  {0x11a5c, 0x11a89}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11bc0, 0x11be0}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c2e}, {0x11c40, 0x11c40}, {0x11c72, 0x11c8f},
  {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d89}, {0x11d98, 0x11d98},
  {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12480, 0x12543}, {0x12f90, 0x12ff0},
  {0x13000, 0x1342f}, {0x13441, 0x13446}, {0x13460, 0x143fa}, {0x14400, 0x14646}, {0x16100, 0x1611d}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a70, 0x16abe},
  {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16d40, 0x16d6c}, {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a},
  {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18cff, 0x18d08}, {0x1aff0, 0x1aff3},
  {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb},
  {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2},
  {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514},
  {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0},
  {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8},
  {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d}, {0x1e14e, 0x1e14e},
  {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e4d0, 0x1e4eb}, {0x1e5d0, 0x1e5ed}, {0x1e5f0, 0x1e5f0}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee},
  {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e900, 0x1e943}, {0x1e94b, 0x1e94b}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24},
  {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49},
  {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d},
  {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e},
  {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d},
  {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static const TSCharacterRange sym_identifier_character_set_1[] = {
  {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb2, 0xb3}, {0xb5, 0xb5}, {0xb9, 0xba},
  {0xbc, 0xbe}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee},
  {0x370, 0x374}, {0x376, 0x377}, {0x37a, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1},
  {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2},
  {0x620, 0x64a}, {0x660, 0x669}, {0x66e, 0x66f}, {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6fc}, {0x6ff, 0x6ff},
  {0x710, 0x710}, {0x712, 0x72f}, {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7c0, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815},
  {0x81a, 0x81a}, {0x824, 0x824}, {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9},
  {0x904, 0x939}, {0x93d, 0x93d}, {0x950, 0x950}, {0x958, 0x961}, {0x966, 0x96f}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990},
  {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1},
  {0x9e6, 0x9f1}, {0x9f4, 0x9f9}, {0x9fc, 0x9fc}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33},
  {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa66, 0xa6f}, {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91},
  {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd}, {0xad0, 0xad0}, {0xae0, 0xae1}, {0xae6, 0xaef},
  {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3d, 0xb3d},
  {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb66, 0xb6f}, {0xb71, 0xb77}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95},
  {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0}, {0xbe6, 0xbf2},
  {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61},
  {0xc66, 0xc6f}, {0xc78, 0xc7e}, {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9},
  {0xcbd, 0xcbd}, {0xcdd, 0xcde}, {0xce0, 0xce1}, {0xce6, 0xcef}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a},
  {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56}, {0xd58, 0xd61}, {0xd66, 0xd78}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1},
  {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xde6, 0xdef}, {0xe01, 0xe30}, {0xe32, 0xe33}, {0xe40, 0xe46}, {0xe50, 0xe59},
  {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0}, {0xeb2, 0xeb3}, {0xebd, 0xebd},
  {0xec0, 0xec4}, {0xec6, 0xec6}, {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf20, 0xf33}, {0xf40, 0xf47}, {0xf49, 0xf6c},
  {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x1049}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070},
  {0x1075, 0x1081}, {0x108e, 0x108e}, {0x1090, 0x1099}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248},
  {0x124a, 0x124d}, {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5},
  {0x12b8, 0x12be}, {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1369, 0x137c},
  {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8},
  {0x1700, 0x1711}, {0x171f, 0x1731}, {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc},
  {0x17e0, 0x17e9}, {0x17f0, 0x17f9}, {0x1810, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x1884}, {0x1887, 0x18a8}, {0x18aa, 0x18aa}, {0x18b0, 0x18f5},
  {0x1900, 0x191e}, {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a16}, {0x1a20, 0x1a54},
  {0x1a80, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b50, 0x1b59}, {0x1b83, 0x1ba0}, {0x1bae, 0x1be5},
  {0x1c00, 0x1c23}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c8a}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3},
  {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57},
  {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2070, 0x2071}, {0x2074, 0x2079},
  {0x207f, 0x2089}, {0x2090, 0x209c}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124},
  {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x212d}, {0x212f, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2150, 0x2189},
  {0x2460, 0x249b}, {0x24ea, 0x24ff}, {0x2776, 0x2793}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2cfd, 0x2cfd}, {0x2d00, 0x2d25},
  {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6},
  {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2e2f, 0x2e2f}, {0x3005, 0x3007}, {0x3021, 0x3029},
  {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e},
  {0x3192, 0x3195}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3220, 0x3229}, {0x3248, 0x324f}, {0x3251, 0x325f}, {0x3280, 0x3289}, {0x32b1, 0x32bf},
  {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef},
  {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7cd}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7dc}, {0xa7f2, 0xa801}, {0xa803, 0xa805},
  {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa830, 0xa835}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8d0, 0xa8d9}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb},
  {0xa8fd, 0xa8fe}, {0xa900, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9fe},
  {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1},
  {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06},
  {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xabf0, 0xabf9},
  {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d},
  {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfd3d},
  {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdfb}, {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff41, 0xff5a},
  {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a},
  {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10107, 0x10133}, {0x10140, 0x10178}, {0x1018a, 0x1018b}, {0x10280, 0x1029c},
  {0x102a0, 0x102d0}, {0x102e1, 0x102fb}, {0x10300, 0x10323}, {0x1032d, 0x1034a}, {0x10350, 0x10375}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf},
  {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a},
  {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x105c0, 0x105f3},
  {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808},
  {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10858, 0x10876}, {0x10879, 0x1089e}, {0x108a7, 0x108af}, {0x108e0, 0x108f2},
  {0x108f4, 0x108f5}, {0x108fb, 0x1091b}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109bc, 0x109cf}, {0x109d2, 0x10a00}, {0x10a10, 0x10a13}, {0x10a15, 0x10a17},
  {0x10a19, 0x10a35}, {0x10a40, 0x10a48}, {0x10a60, 0x10a7e}, {0x10a80, 0x10a9f}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10aeb, 0x10aef}, {0x10b00, 0x10b35},
  {0x10b40, 0x10b55}, {0x10b58, 0x10b72}, {0x10b78, 0x10b91}, {0x10ba9, 0x10baf}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10cfa, 0x10d23},
  {0x10d30, 0x10d39}, {0x10d40, 0x10d65}, {0x10d6f, 0x10d85}, {0x10e60, 0x10e7e}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10ec2, 0x10ec4}, {0x10f00, 0x10f27},
  {0x10f30, 0x10f45}, {0x10f51, 0x10f54}, {0x10f70, 0x10f81}, {0x10fb0, 0x10fcb}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11052, 0x1106f}, {0x11071, 0x11072},
  {0x11075, 0x11075}, {0x11083, 0x110af}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11103, 0x11126}, {0x11136, 0x1113f}, {0x11144, 0x11144}, {0x11147, 0x11147},
  {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2}, {0x111c1, 0x111c4}, {0x111d0, 0x111da}, {0x111dc, 0x111dc}, {0x111e1, 0x111f4}, {0x11200, 0x11211},
  {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112de},
  {0x112f0, 0x112f9}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133d, 0x1133d},
  {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11380, 0x11389}, {0x1138b, 0x1138b}, {0x1138e, 0x1138e}, {0x11390, 0x113b5}, {0x113b7, 0x113b7}, {0x113d1, 0x113d1},
  {0x113d3, 0x113d3}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x11450, 0x11459}, {0x1145f, 0x11461}, {0x11480, 0x114af}, {0x114c4, 0x114c5}, {0x114c7, 0x114c7},
  {0x114d0, 0x114d9}, {0x11580, 0x115ae}, {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11650, 0x11659}, {0x11680, 0x116aa}, {0x116b8, 0x116b8},
  {0x116c0, 0x116c9}, {0x116d0, 0x116e3}, {0x11700, 0x1171a}, {0x11730, 0x1173b}, {0x11740, 0x11746}, {0x11800, 0x1182b}, {0x118a0, 0x118f2}, {0x118ff, 0x11906},
  {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941}, {0x11950, 0x11959}, {0x119a0, 0x119a7},
  {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3}, {0x11a00, 0x11a00}, {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50}, {0x11a5c, 0x11a89},
  {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11bc0, 0x11be0}, {0x11bf0, 0x11bf9}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c2e}, {0x11c40, 0x11c40}, {0x11c50, 0x11c6c},
  {0x11c72, 0x11c8f}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d50, 0x11d59}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68},
  {0x11d6a, 0x11d89}, {0x11d98, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11f50, 0x11f59},
  {0x11fb0, 0x11fb0}, {0x11fc0, 0x11fd4}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13441, 0x13446},
  {0x13460, 0x143fa}, {0x14400, 0x14646}, {0x16100, 0x1611d}, {0x16130, 0x16139}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe},
  {0x16ac0, 0x16ac9}, {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b5b, 0x16b61}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f},
  {0x16d40, 0x16d6c}, {0x16d70, 0x16d79}, {0x16e40, 0x16e96}, {0x16f00, 0x16f4a}, {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3},
  {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18cff, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132},
  {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99},
  {0x1ccf0, 0x1ccf9}, {0x1d2c0, 0x1d2d3}, {0x1d2e0, 0x1d2f3}, {0x1d360, 0x1d378}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2},
  {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514},
  {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0},
  {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8},
  {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d},
  {0x1e140, 0x1e149}, {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e2f0, 0x1e2f9}, {0x1e4d0, 0x1e4eb}, {0x1e4f0, 0x1e4f9}, {0x1e5d0, 0x1e5ed},
  {0x1e5f0, 0x1e5fa}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e8c7, 0x1e8cf}, {0x1e900, 0x1e943},
  {0x1e94b, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ec71, 0x1ecab}, {0x1ecad, 0x1ecaf}, {0x1ecb1, 0x1ecb4}, {0x1ed01, 0x1ed2d}, {0x1ed2f, 0x1ed3d}, {0x1ee00, 0x1ee03},
  {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b},
  {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57},
  {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72},
  {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb},
  {0x1f100, 0x1f10c}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d},
  {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(118);
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '%', 138,
        '&', 135,
        '\'', 19,
        '(', 181,
        ')', 133,
        '*', 146,
        '+', 184,
        ',', 125,
        '-', 130,
        '.', 121,
        '/', 182,
        ':', 128,
        ';', 119,
        '<', 188,
        '=', 124,
        '>', 187,
        '?', 190,
        '@', 136,
        '[', 148,
        ']', 149,
        '{', 122,
        '|', 137,
        '}', 123,
        'A', 207,
        'a', 207,
        'E', 206,
        'e', 206,
        'O', 202,
        'o', 202,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(116);
      if (set_contains(sym_permission_type_character_set_1, 10, lookahead)) ADVANCE(213);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        ' ', 34,
        'E', 43,
        'I', 35,
        'e', 45,
        'i', 54,
        'p', 70,
        'R', 79,
        'r', 79,
      );
      if (('\t' <= lookahead && lookahead <= '\r')) ADVANCE(80);
      END_STATE();
    case 2:
      if (lookahead == ' ') ADVANCE(34);
      if (lookahead == 'E') ADVANCE(43);
      if (lookahead == 'e') ADVANCE(45);
      if (lookahead == 'p') ADVANCE(70);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(79);
      if (('\t' <= lookahead && lookahead <= '\r')) ADVANCE(80);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '&', 18,
        '\'', 19,
        '(', 132,
        '+', 183,
        ',', 125,
        '-', 129,
        '/', 22,
        ';', 119,
        '@', 20,
        '[', 148,
        '|', 73,
        '}', 123,
        'A', 208,
        'a', 208,
        'O', 211,
        'o', 211,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '&', 18,
        '\'', 19,
        '(', 132,
        '+', 183,
        ',', 125,
        '-', 129,
        '/', 22,
        '@', 20,
        '[', 148,
        '|', 73,
        'A', 208,
        'a', 208,
        'E', 206,
        'e', 206,
        'I', 203,
        'i', 203,
        'O', 211,
        'o', 211,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '\'', 19,
        '(', 181,
        '+', 183,
        '-', 129,
        '/', 22,
        ';', 119,
        '@', 20,
        '[', 148,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(8);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '\'', 19,
        '(', 132,
        ')', 133,
        '*', 146,
        '+', 184,
        ',', 125,
        '-', 130,
        '.', 121,
        '/', 182,
        ':', 127,
        ';', 119,
        '<', 188,
        '=', 124,
        '>', 187,
        '?', 190,
        '@', 136,
        '[', 148,
        ']', 149,
        '{', 122,
        '%', 138,
        '&', 138,
        '|', 138,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '\'', 19,
        '(', 132,
        '+', 183,
        ',', 125,
        '-', 129,
        '/', 22,
        '@', 20,
        '[', 148,
        'E', 206,
        'e', 206,
        'I', 203,
        'i', 203,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '\'', 19,
        '(', 132,
        '+', 183,
        '-', 129,
        '/', 22,
        ';', 119,
        '@', 20,
        '[', 148,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(8);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '\'', 19,
        ')', 133,
        '*', 145,
        ',', 125,
        '-', 129,
        '.', 120,
        '/', 22,
        ';', 119,
        '=', 124,
        '[', 148,
        ']', 149,
        '}', 123,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(9);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(229);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '(', 132,
        ')', 133,
        '*', 146,
        '+', 184,
        ',', 125,
        '-', 130,
        '.', 121,
        '/', 182,
        ':', 127,
        ';', 119,
        '<', 188,
        '=', 124,
        '>', 187,
        '?', 190,
        '[', 148,
        ']', 149,
        '{', 122,
        '}', 123,
        'E', 206,
        'e', 206,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(10);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(229);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '"', 14,
        '#', 39,
        '\'', 19,
        '(', 132,
        '+', 183,
        ',', 125,
        '-', 129,
        '/', 22,
        ';', 119,
        '@', 20,
        '[', 148,
        'I', 203,
        'i', 203,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '"', 14,
        '#', 69,
        '\'', 19,
        '(', 132,
        ')', 133,
        '*', 146,
        '+', 184,
        ',', 125,
        '-', 130,
        '.', 121,
        '/', 182,
        ':', 127,
        ';', 119,
        '<', 188,
        '=', 124,
        '>', 187,
        '?', 190,
        '[', 148,
        ']', 149,
        '{', 122,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(12);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(229);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 13:
      if (lookahead == '"') ADVANCE(14);
      if (lookahead == '#') ADVANCE(69);
      if (lookahead == '\'') ADVANCE(19);
      if (lookahead == '/') ADVANCE(22);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(13);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(152);
      END_STATE();
    case 14:
      if (lookahead == '"') ADVANCE(215);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(14);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '#', 69,
        '(', 132,
        '*', 146,
        '+', 184,
        '-', 130,
        '.', 121,
        '/', 182,
        ':', 25,
        '<', 188,
        '=', 124,
        '>', 187,
        '?', 190,
        '[', 148,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(15);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 16:
      if (lookahead == '#') ADVANCE(69);
      if (lookahead == '/') ADVANCE(22);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(16);
      if (set_contains(sym_permission_type_character_set_1, 10, lookahead)) ADVANCE(147);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '#', 2,
        ')', 133,
        '/', 22,
        ';', 119,
        'A', 106,
        'a', 106,
        'D', 85,
        'd', 85,
        'E', 95,
        'e', 95,
        'O', 86,
        'o', 86,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(17);
      END_STATE();
    case 18:
      if (lookahead == '&') ADVANCE(160);
      END_STATE();
    case 19:
      if (lookahead == '\'') ADVANCE(218);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(19);
      END_STATE();
    case 20:
      if (lookahead == '\'') ADVANCE(21);
      END_STATE();
    case 21:
      if (lookahead == '\'') ADVANCE(219);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 22:
      if (lookahead == '*') ADVANCE(24);
      if (lookahead == '/') ADVANCE(216);
      END_STATE();
    case 23:
      if (lookahead == '*') ADVANCE(23);
      if (lookahead == '/') ADVANCE(217);
      if (lookahead != 0) ADVANCE(24);
      END_STATE();
    case 24:
      if (lookahead == '*') ADVANCE(23);
      if (lookahead != 0) ADVANCE(24);
      END_STATE();
    case 25:
      if (lookahead == ':') ADVANCE(153);
      if (lookahead == '=') ADVANCE(180);
      END_STATE();
    case 26:
      if (lookahead == 'D') ADVANCE(41);
      if (lookahead == 'd') ADVANCE(105);
      END_STATE();
    case 27:
      if (lookahead == 'D') ADVANCE(105);
      if (lookahead == 'd') ADVANCE(64);
      END_STATE();
    case 28:
      if (lookahead == 'D') ADVANCE(105);
      if (lookahead == 'd') ADVANCE(65);
      END_STATE();
    case 29:
      if (lookahead == 'D') ADVANCE(105);
      if (lookahead == 'd') ADVANCE(66);
      END_STATE();
    case 30:
      if (lookahead == 'D') ADVANCE(105);
      if (lookahead == 'd') ADVANCE(67);
      END_STATE();
    case 31:
      if (lookahead == 'D') ADVANCE(42);
      if (lookahead == 'd') ADVANCE(105);
      END_STATE();
    case 32:
      if (lookahead == 'E') ADVANCE(165);
      END_STATE();
    case 33:
      if (lookahead == 'E') ADVANCE(168);
      END_STATE();
    case 34:
      if (lookahead == 'E') ADVANCE(44);
      if (lookahead == 'e') ADVANCE(46);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(79);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(80);
      END_STATE();
    case 35:
      if (lookahead == 'F') ADVANCE(155);
      if (lookahead == 'f') ADVANCE(156);
      END_STATE();
    case 36:
      if (lookahead == 'F') ADVANCE(162);
      END_STATE();
    case 37:
      if (lookahead == 'F') ADVANCE(171);
      END_STATE();
    case 38:
      if (lookahead == 'F') ADVANCE(174);
      END_STATE();
    case 39:
      if (lookahead == 'I') ADVANCE(35);
      if (lookahead == 'i') ADVANCE(54);
      if (lookahead == 'p') ADVANCE(70);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(96);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(79);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(80);
      END_STATE();
    case 40:
      if (lookahead == 'I') ADVANCE(36);
      if (lookahead == 'S') ADVANCE(32);
      END_STATE();
    case 41:
      if (lookahead == 'I') ADVANCE(37);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(84);
      END_STATE();
    case 42:
      if (lookahead == 'I') ADVANCE(38);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(84);
      END_STATE();
    case 43:
      if (lookahead == 'L') ADVANCE(40);
      if (lookahead == 'N') ADVANCE(26);
      if (lookahead == 'l') ADVANCE(62);
      if (lookahead == 'n') ADVANCE(27);
      END_STATE();
    case 44:
      if (lookahead == 'L') ADVANCE(47);
      if (lookahead == 'N') ADVANCE(31);
      if (lookahead == 'l') ADVANCE(71);
      if (lookahead == 'n') ADVANCE(29);
      END_STATE();
    case 45:
      if (lookahead == 'N') ADVANCE(76);
      if (lookahead == 'l') ADVANCE(63);
      if (lookahead == 'n') ADVANCE(28);
      END_STATE();
    case 46:
      if (lookahead == 'N') ADVANCE(76);
      if (lookahead == 'l') ADVANCE(72);
      if (lookahead == 'n') ADVANCE(30);
      END_STATE();
    case 47:
      if (lookahead == 'S') ADVANCE(33);
      END_STATE();
    case 48:
      if (lookahead == 'a') ADVANCE(61);
      END_STATE();
    case 49:
      if (lookahead == 'a') ADVANCE(176);
      END_STATE();
    case 50:
      if (lookahead == 'e') ADVANCE(166);
      END_STATE();
    case 51:
      if (lookahead == 'e') ADVANCE(164);
      END_STATE();
    case 52:
      if (lookahead == 'e') ADVANCE(169);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(167);
      END_STATE();
    case 54:
      if (lookahead == 'f') ADVANCE(154);
      END_STATE();
    case 55:
      if (lookahead == 'f') ADVANCE(163);
      END_STATE();
    case 56:
      if (lookahead == 'f') ADVANCE(161);
      END_STATE();
    case 57:
      if (lookahead == 'f') ADVANCE(172);
      END_STATE();
    case 58:
      if (lookahead == 'f') ADVANCE(170);
      END_STATE();
    case 59:
      if (lookahead == 'f') ADVANCE(175);
      END_STATE();
    case 60:
      if (lookahead == 'f') ADVANCE(173);
      END_STATE();
    case 61:
      if (lookahead == 'g') ADVANCE(68);
      END_STATE();
    case 62:
      if (lookahead == 'i') ADVANCE(55);
      if (lookahead == 's') ADVANCE(50);
      END_STATE();
    case 63:
      if (lookahead == 'i') ADVANCE(56);
      if (lookahead == 's') ADVANCE(51);
      END_STATE();
    case 64:
      if (lookahead == 'i') ADVANCE(57);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(84);
      END_STATE();
    case 65:
      if (lookahead == 'i') ADVANCE(58);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(84);
      END_STATE();
    case 66:
      if (lookahead == 'i') ADVANCE(59);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(84);
      END_STATE();
    case 67:
      if (lookahead == 'i') ADVANCE(60);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(84);
      END_STATE();
    case 68:
      if (lookahead == 'm') ADVANCE(49);
      END_STATE();
    case 69:
      if (lookahead == 'p') ADVANCE(70);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(96);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(79);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(80);
      END_STATE();
    case 70:
      if (lookahead == 'r') ADVANCE(48);
      END_STATE();
    case 71:
      if (lookahead == 's') ADVANCE(52);
      END_STATE();
    case 72:
      if (lookahead == 's') ADVANCE(53);
      END_STATE();
    case 73:
      if (lookahead == '|') ADVANCE(158);
      END_STATE();
    case 74:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(82);
      END_STATE();
    case 75:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(83);
      END_STATE();
    case 76:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(105);
      END_STATE();
    case 77:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(92);
      END_STATE();
    case 78:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(93);
      END_STATE();
    case 79:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 80:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(96);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(79);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(80);
      END_STATE();
    case 81:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(142);
      END_STATE();
    case 82:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 83:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 84:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 85:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(108);
      END_STATE();
    case 86:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(150);
      END_STATE();
    case 87:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(91);
      END_STATE();
    case 88:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(139);
      END_STATE();
    case 89:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(141);
      END_STATE();
    case 90:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(94);
      END_STATE();
    case 91:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(103);
      END_STATE();
    case 92:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(100);
      END_STATE();
    case 93:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(101);
      END_STATE();
    case 94:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(104);
      END_STATE();
    case 95:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(107);
      END_STATE();
    case 96:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(76);
      END_STATE();
    case 97:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(177);
      END_STATE();
    case 98:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(178);
      END_STATE();
    case 99:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(77);
      END_STATE();
    case 100:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(88);
      END_STATE();
    case 101:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(89);
      END_STATE();
    case 102:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(78);
      END_STATE();
    case 103:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(97);
      END_STATE();
    case 104:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(98);
      END_STATE();
    case 105:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(84);
      END_STATE();
    case 106:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(74);
      END_STATE();
    case 107:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(81);
      END_STATE();
    case 108:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(75);
      END_STATE();
    case 109:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(131);
      END_STATE();
    case 110:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(192);
      END_STATE();
    case 111:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(110);
      END_STATE();
    case 112:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(111);
      END_STATE();
    case 113:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(112);
      END_STATE();
    case 114:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(113);
      END_STATE();
    case 115:
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(152);
      END_STATE();
    case 116:
      if (eof) ADVANCE(118);
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '%', 138,
        '&', 135,
        '\'', 19,
        '(', 132,
        ')', 133,
        '*', 146,
        '+', 184,
        ',', 125,
        '-', 130,
        '.', 121,
        '/', 182,
        ':', 128,
        ';', 119,
        '<', 188,
        '=', 124,
        '>', 187,
        '?', 190,
        '@', 136,
        '[', 148,
        ']', 149,
        '{', 122,
        '|', 137,
        '}', 123,
        'A', 207,
        'a', 207,
        'E', 206,
        'e', 206,
        'O', 202,
        'o', 202,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(116);
      if (set_contains(sym_permission_type_character_set_1, 10, lookahead)) ADVANCE(213);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 117:
      if (eof) ADVANCE(118);
      ADVANCE_MAP(
        '"', 14,
        '#', 1,
        '\'', 19,
        '(', 132,
        ')', 133,
        '+', 183,
        ',', 125,
        '-', 129,
        '.', 121,
        '/', 22,
        ':', 126,
        ';', 119,
        '@', 136,
        '[', 148,
        ']', 149,
        '{', 122,
        '}', 123,
      );
      if (('%' <= lookahead && lookahead <= '*') ||
          ('<' <= lookahead && lookahead <= '>') ||
          lookahead == '|') ADVANCE(138);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(117);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (set_contains(sym_dotnet_assembly_name_character_set_1, 678, lookahead)) ADVANCE(214);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(134);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(153);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(153);
      if (lookahead == '=') ADVANCE(179);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(153);
      if (lookahead == '=') ADVANCE(180);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(179);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_decimal);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(131);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(aux_sym_filter_value_token1);
      if (lookahead == '&') ADVANCE(160);
      if (lookahead == '%' ||
          lookahead == '*' ||
          ('<' <= lookahead && lookahead <= '>') ||
          lookahead == '@' ||
          lookahead == '|') ADVANCE(138);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(aux_sym_filter_value_token1);
      if (lookahead == '\'') ADVANCE(21);
      if (lookahead == '%' ||
          lookahead == '&' ||
          lookahead == '*' ||
          ('<' <= lookahead && lookahead <= '>') ||
          lookahead == '@' ||
          lookahead == '|') ADVANCE(138);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(aux_sym_filter_value_token1);
      if (lookahead == '|') ADVANCE(158);
      if (lookahead == '%' ||
          lookahead == '&' ||
          lookahead == '*' ||
          ('<' <= lookahead && lookahead <= '>') ||
          lookahead == '@') ADVANCE(138);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(aux_sym_filter_value_token1);
      if (lookahead == '%' ||
          lookahead == '&' ||
          lookahead == '*' ||
          ('<' <= lookahead && lookahead <= '>') ||
          lookahead == '@' ||
          lookahead == '|') ADVANCE(138);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(aux_sym_sorting_value_token3);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(aux_sym_sorting_value_token3);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(aux_sym_sorting_value_token4);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(aux_sym_else_table_relation_fragment_token1);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(aux_sym_else_table_relation_fragment_token1);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(aux_sym_if_table_relation_token1);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(179);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(sym_permission_type);
      ADVANCE_MAP(
        'D', 147,
        'I', 147,
        'M', 147,
        'R', 147,
        'X', 147,
        'd', 147,
        'i', 147,
        'm', 147,
        'r', 147,
        'x', 147,
      );
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(aux_sym_array_type_token2);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(aux_sym_array_type_token2);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(sym_dotnet_assembly_name);
      if (lookahead == '.') ADVANCE(115);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(152);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_POUNDif);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_POUNDIF);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_POUNDIf);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(aux_sym_preproc_or_expression_token1);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(aux_sym_preproc_and_expression_token1);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_POUNDelif);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_POUNDELIF);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_POUNDElif);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_POUNDelse);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_POUNDELSE);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_POUNDElse);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_POUNDelse2);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_POUNDELSE2);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_POUNDElse2);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_POUNDendif);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_POUNDENDIF);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_POUNDEndif);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_POUNDendif2);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_POUNDENDIF2);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_POUNDEndif2);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_pragma);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(176);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_preproc_region);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(177);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_preproc_endregion);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(178);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym__assignment_operator);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(24);
      if (lookahead == '/') ADVANCE(216);
      if (lookahead == '=') ADVANCE(179);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(179);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(185);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(186);
      if (lookahead == '>') ADVANCE(189);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_LT_GT);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(sym_datetime_literal);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(sym_datetime_literal);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(191);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(sym_date_literal);
      if (lookahead == 'T') ADVANCE(191);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(sym_time_literal);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(sym_time_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(114);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(sym_biginteger_literal);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(200);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(159);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(205);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(210);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(143);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(151);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(157);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(144);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(140);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(209);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(198);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(197);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(198);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(204);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(199);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(157);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(201);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(sym_identifier);
      ADVANCE_MAP(
        'D', 213,
        'I', 213,
        'M', 213,
        'R', 213,
        'X', 213,
        'd', 213,
        'i', 213,
        'm', 213,
        'r', 213,
        'x', 213,
      );
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(sym_identifier);
      if (set_contains(sym_identifier_character_set_1, 771, lookahead)) ADVANCE(214);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(sym_quoted_identifier);
      if (lookahead == '"') ADVANCE(14);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(216);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(sym_multiline_comment);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(sym_string_literal);
      if (lookahead == '\'') ADVANCE(19);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(sym_verbatim_string);
      if (lookahead == '\'') ADVANCE(21);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(228);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(220);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(221);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(222);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(223);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(224);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(225);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(227);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == 'D') ADVANCE(193);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == 'T') ADVANCE(195);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(227);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(sym_integer);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(229);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'A', 1,
        'B', 2,
        'C', 3,
        'D', 4,
        'E', 5,
        'F', 6,
        'I', 7,
        'M', 8,
        'N', 9,
        'O', 10,
        'P', 11,
        'R', 12,
        'T', 13,
        'U', 14,
        'W', 15,
        'X', 16,
        'a', 17,
        'b', 18,
        'c', 19,
        'd', 20,
        'e', 21,
        'f', 22,
        'i', 23,
        'm', 24,
        'n', 25,
        'o', 26,
        'p', 27,
        'r', 28,
        't', 29,
        'u', 30,
        'w', 31,
        'x', 32,
        'G', 33,
        'g', 33,
        'H', 34,
        'h', 34,
        'J', 35,
        'j', 35,
        'L', 36,
        'l', 36,
        'Q', 37,
        'q', 37,
        'S', 38,
        's', 38,
        'V', 39,
        'v', 39,
        'K', 40,
        'k', 40,
        0x212a, 40,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xfeff) SKIP(0);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        'N', 41,
        'n', 42,
        'C', 43,
        'c', 43,
        'D', 44,
        'd', 44,
        'R', 45,
        'r', 45,
        'S', 46,
        's', 46,
      );
      END_STATE();
    case 2:
      ADVANCE_MAP(
        'R', 47,
        'r', 48,
        'E', 49,
        'e', 49,
        'I', 50,
        'i', 50,
        'L', 51,
        'l', 51,
        'O', 52,
        'o', 52,
        'Y', 53,
        'y', 53,
      );
      END_STATE();
    case 3:
      ADVANCE_MAP(
        'A', 54,
        'O', 55,
        'a', 56,
        'o', 57,
        'H', 58,
        'h', 58,
        'R', 59,
        'r', 59,
        'U', 60,
        'u', 60,
      );
      END_STATE();
    case 4:
      ADVANCE_MAP(
        'I', 61,
        'O', 62,
        'i', 63,
        'o', 64,
        'A', 65,
        'a', 65,
        'E', 66,
        'e', 66,
        'U', 67,
        'u', 67,
      );
      END_STATE();
    case 5:
      ADVANCE_MAP(
        'L', 68,
        'N', 69,
        'X', 70,
        'l', 71,
        'n', 72,
        'x', 73,
        'M', 74,
        'm', 74,
        'R', 75,
        'r', 75,
        'V', 76,
        'v', 76,
      );
      END_STATE();
    case 6:
      if (lookahead == 'O') ADVANCE(77);
      if (lookahead == 'o') ADVANCE(78);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(79);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(80);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        'F', 81,
        'N', 82,
        'f', 83,
        'n', 84,
        'M', 85,
        'm', 85,
        'S', 86,
        's', 86,
      );
      END_STATE();
    case 8:
      if (lookahead == 'O') ADVANCE(87);
      if (lookahead == 'o') ADVANCE(88);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(89);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 9:
      if (lookahead == 'O') ADVANCE(91);
      if (lookahead == 'o') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(93);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        'F', 94,
        'R', 95,
        'f', 96,
        'r', 97,
        'P', 98,
        'p', 98,
        'U', 99,
        'u', 99,
      );
      END_STATE();
    case 11:
      ADVANCE_MAP(
        'A', 100,
        'E', 101,
        'R', 102,
        'a', 103,
        'e', 104,
        'r', 105,
        'U', 106,
        'u', 106,
      );
      END_STATE();
    case 12:
      if (lookahead == 'E') ADVANCE(107);
      if (lookahead == 'e') ADVANCE(108);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(109);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        'A', 110,
        'H', 111,
        'O', 112,
        'a', 113,
        'h', 114,
        'o', 115,
        'E', 116,
        'e', 116,
        'I', 117,
        'i', 117,
        'R', 118,
        'r', 118,
        'Y', 119,
        'y', 119,
      );
      END_STATE();
    case 14:
      if (lookahead == 'N') ADVANCE(120);
      if (lookahead == 'n') ADVANCE(121);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(122);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(123);
      END_STATE();
    case 15:
      if (lookahead == 'H') ADVANCE(124);
      if (lookahead == 'I') ADVANCE(125);
      if (lookahead == 'h') ADVANCE(126);
      if (lookahead == 'i') ADVANCE(127);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(128);
      END_STATE();
    case 16:
      if (lookahead == 'M') ADVANCE(129);
      if (lookahead == 'O') ADVANCE(130);
      if (lookahead == 'm') ADVANCE(131);
      if (lookahead == 'o') ADVANCE(132);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        'n', 133,
        'C', 43,
        'c', 43,
        'D', 44,
        'd', 44,
        'R', 45,
        'r', 45,
        'S', 46,
        's', 46,
      );
      END_STATE();
    case 18:
      ADVANCE_MAP(
        'r', 134,
        'E', 49,
        'e', 49,
        'I', 50,
        'i', 50,
        'L', 51,
        'l', 51,
        'O', 52,
        'o', 52,
        'Y', 53,
        'y', 53,
      );
      END_STATE();
    case 19:
      ADVANCE_MAP(
        'O', 135,
        'a', 136,
        'o', 137,
        'H', 58,
        'h', 58,
        'R', 59,
        'r', 59,
        'U', 60,
        'u', 60,
      );
      END_STATE();
    case 20:
      ADVANCE_MAP(
        'I', 138,
        'i', 139,
        'o', 140,
        'A', 65,
        'a', 65,
        'E', 66,
        'e', 66,
        'U', 67,
        'u', 67,
      );
      END_STATE();
    case 21:
      ADVANCE_MAP(
        'L', 141,
        'N', 142,
        'X', 143,
        'l', 144,
        'n', 145,
        'x', 146,
        'M', 74,
        'm', 74,
        'R', 75,
        'r', 75,
        'V', 76,
        'v', 76,
      );
      END_STATE();
    case 22:
      if (lookahead == 'o') ADVANCE(147);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(79);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(80);
      END_STATE();
    case 23:
      if (lookahead == 'N') ADVANCE(148);
      if (lookahead == 'f') ADVANCE(149);
      if (lookahead == 'n') ADVANCE(150);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(85);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(86);
      END_STATE();
    case 24:
      if (lookahead == 'O') ADVANCE(151);
      if (lookahead == 'o') ADVANCE(152);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(89);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 25:
      if (lookahead == 'O') ADVANCE(153);
      if (lookahead == 'o') ADVANCE(154);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(93);
      END_STATE();
    case 26:
      if (lookahead == 'R') ADVANCE(155);
      if (lookahead == 'f') ADVANCE(156);
      if (lookahead == 'r') ADVANCE(157);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(98);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(99);
      END_STATE();
    case 27:
      if (lookahead == 'A') ADVANCE(158);
      if (lookahead == 'R') ADVANCE(159);
      if (lookahead == 'a') ADVANCE(160);
      if (lookahead == 'e') ADVANCE(161);
      if (lookahead == 'r') ADVANCE(162);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(106);
      END_STATE();
    case 28:
      if (lookahead == 'E') ADVANCE(163);
      if (lookahead == 'e') ADVANCE(164);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(109);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        'A', 165,
        'a', 166,
        'h', 167,
        'o', 168,
        'E', 116,
        'e', 116,
        'I', 117,
        'i', 117,
        'R', 118,
        'r', 118,
        'Y', 119,
        'y', 119,
      );
      END_STATE();
    case 30:
      if (lookahead == 'n') ADVANCE(169);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(122);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(123);
      END_STATE();
    case 31:
      if (lookahead == 'H') ADVANCE(170);
      if (lookahead == 'h') ADVANCE(171);
      if (lookahead == 'i') ADVANCE(172);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(128);
      END_STATE();
    case 32:
      if (lookahead == 'M') ADVANCE(173);
      if (lookahead == 'm') ADVANCE(174);
      if (lookahead == 'o') ADVANCE(175);
      END_STATE();
    case 33:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(176);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(177);
      END_STATE();
    case 34:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(178);
      END_STATE();
    case 35:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(179);
      END_STATE();
    case 36:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(180);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(181);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(182);
      END_STATE();
    case 37:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(183);
      END_STATE();
    case 38:
      ADVANCE_MAP(
        'C', 184,
        'c', 184,
        'E', 185,
        'e', 185,
        'O', 186,
        'o', 186,
        'Y', 187,
        'y', 187,
      );
      END_STATE();
    case 39:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(188);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(189);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(190);
      END_STATE();
    case 40:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(191);
      END_STATE();
    case 41:
      if (lookahead == 'D') ADVANCE(192);
      END_STATE();
    case 42:
      if (lookahead == 'd') ADVANCE(193);
      END_STATE();
    case 43:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(194);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(195);
      END_STATE();
    case 44:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(196);
      END_STATE();
    case 45:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(197);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(198);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(aux_sym__expression_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(199);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(200);
      END_STATE();
    case 47:
      if (lookahead == 'E') ADVANCE(201);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(202);
      END_STATE();
    case 49:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(203);
      END_STATE();
    case 50:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(204);
      END_STATE();
    case 51:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(205);
      END_STATE();
    case 52:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(206);
      END_STATE();
    case 53:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(207);
      END_STATE();
    case 54:
      if (lookahead == 'S') ADVANCE(208);
      END_STATE();
    case 55:
      ADVANCE_MAP(
        'D', 209,
        'N', 210,
        'd', 211,
        'n', 212,
        'L', 213,
        'l', 213,
        'M', 214,
        'm', 214,
      );
      END_STATE();
    case 56:
      if (lookahead == 's') ADVANCE(215);
      END_STATE();
    case 57:
      ADVANCE_MAP(
        'D', 216,
        'N', 212,
        'd', 217,
        'n', 218,
        'L', 213,
        'l', 213,
        'M', 214,
        'm', 214,
      );
      END_STATE();
    case 58:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(219);
      END_STATE();
    case 59:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(220);
      END_STATE();
    case 60:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(221);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(222);
      END_STATE();
    case 61:
      if (lookahead == 'V') ADVANCE(223);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_DO);
      if (lookahead == 'T') ADVANCE(226);
      if (lookahead == 'W') ADVANCE(227);
      END_STATE();
    case 63:
      if (lookahead == 'v') ADVANCE(228);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_Do);
      if (lookahead == 't') ADVANCE(229);
      if (lookahead == 'w') ADVANCE(230);
      END_STATE();
    case 65:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(231);
      END_STATE();
    case 66:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(232);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(233);
      END_STATE();
    case 67:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(234);
      END_STATE();
    case 68:
      if (lookahead == 'S') ADVANCE(235);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 69:
      if (lookahead == 'U') ADVANCE(237);
      if (lookahead == 'u') ADVANCE(238);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(239);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 70:
      if (lookahead == 'I') ADVANCE(241);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(242);
      END_STATE();
    case 71:
      if (lookahead == 's') ADVANCE(243);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 72:
      if (lookahead == 'u') ADVANCE(244);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(239);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 73:
      if (lookahead == 'i') ADVANCE(245);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(242);
      END_STATE();
    case 74:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(246);
      END_STATE();
    case 75:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(247);
      END_STATE();
    case 76:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(248);
      END_STATE();
    case 77:
      if (lookahead == 'R') ADVANCE(249);
      END_STATE();
    case 78:
      if (lookahead == 'r') ADVANCE(250);
      END_STATE();
    case 79:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(251);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(252);
      END_STATE();
    case 80:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(253);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(254);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(255);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_IF);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_IN);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_If);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_In);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 85:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(258);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(aux_sym__expression_token1);
      END_STATE();
    case 87:
      if (lookahead == 'D') ADVANCE(259);
      if (lookahead == 'd') ADVANCE(260);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(261);
      END_STATE();
    case 88:
      if (lookahead == 'D') ADVANCE(260);
      if (lookahead == 'd') ADVANCE(262);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(261);
      END_STATE();
    case 89:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(263);
      END_STATE();
    case 90:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(264);
      END_STATE();
    case 91:
      if (lookahead == 'T') ADVANCE(265);
      if (lookahead == 't') ADVANCE(266);
      END_STATE();
    case 92:
      if (lookahead == 'T') ADVANCE(266);
      if (lookahead == 't') ADVANCE(267);
      END_STATE();
    case 93:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(268);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(269);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_OF);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_OR);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_Of);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_Or);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 98:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(271);
      END_STATE();
    case 99:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(272);
      END_STATE();
    case 100:
      if (lookahead == 'G') ADVANCE(273);
      if (lookahead == 'g') ADVANCE(274);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 101:
      if (lookahead == 'R') ADVANCE(276);
      END_STATE();
    case 102:
      if (lookahead == 'O') ADVANCE(277);
      if (lookahead == 'o') ADVANCE(278);
      END_STATE();
    case 103:
      if (lookahead == 'G') ADVANCE(274);
      if (lookahead == 'g') ADVANCE(279);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 104:
      if (lookahead == 'r') ADVANCE(280);
      END_STATE();
    case 105:
      if (lookahead == 'O') ADVANCE(278);
      if (lookahead == 'o') ADVANCE(281);
      END_STATE();
    case 106:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(282);
      END_STATE();
    case 107:
      ADVANCE_MAP(
        'P', 283,
        'p', 284,
        'C', 285,
        'c', 285,
        'N', 286,
        'n', 286,
        'Q', 287,
        'q', 287,
      );
      END_STATE();
    case 108:
      ADVANCE_MAP(
        'P', 284,
        'p', 288,
        'C', 285,
        'c', 285,
        'N', 286,
        'n', 286,
        'Q', 287,
        'q', 287,
      );
      END_STATE();
    case 109:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(289);
      END_STATE();
    case 110:
      if (lookahead == 'B') ADVANCE(290);
      if (lookahead == 'b') ADVANCE(291);
      END_STATE();
    case 111:
      if (lookahead == 'E') ADVANCE(292);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_TO);
      END_STATE();
    case 113:
      if (lookahead == 'B') ADVANCE(291);
      if (lookahead == 'b') ADVANCE(293);
      END_STATE();
    case 114:
      if (lookahead == 'e') ADVANCE(294);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_To);
      END_STATE();
    case 116:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(295);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(296);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(297);
      END_STATE();
    case 117:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(298);
      END_STATE();
    case 118:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(299);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(300);
      END_STATE();
    case 119:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(301);
      END_STATE();
    case 120:
      if (lookahead == 'T') ADVANCE(302);
      END_STATE();
    case 121:
      if (lookahead == 't') ADVANCE(303);
      END_STATE();
    case 122:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(304);
      END_STATE();
    case 123:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(305);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(306);
      END_STATE();
    case 124:
      if (lookahead == 'I') ADVANCE(307);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 125:
      if (lookahead == 'T') ADVANCE(309);
      END_STATE();
    case 126:
      if (lookahead == 'i') ADVANCE(310);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 127:
      if (lookahead == 't') ADVANCE(311);
      END_STATE();
    case 128:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(312);
      END_STATE();
    case 129:
      if (lookahead == 'L') ADVANCE(313);
      if (lookahead == 'l') ADVANCE(314);
      END_STATE();
    case 130:
      if (lookahead == 'R') ADVANCE(315);
      END_STATE();
    case 131:
      if (lookahead == 'L') ADVANCE(314);
      if (lookahead == 'l') ADVANCE(316);
      END_STATE();
    case 132:
      if (lookahead == 'r') ADVANCE(317);
      END_STATE();
    case 133:
      if (lookahead == 'd') ADVANCE(318);
      END_STATE();
    case 134:
      if (lookahead == 'e') ADVANCE(319);
      END_STATE();
    case 135:
      ADVANCE_MAP(
        'D', 216,
        'd', 216,
        'L', 213,
        'l', 213,
        'M', 214,
        'm', 214,
        'N', 212,
        'n', 212,
      );
      END_STATE();
    case 136:
      if (lookahead == 's') ADVANCE(320);
      END_STATE();
    case 137:
      ADVANCE_MAP(
        'D', 216,
        'N', 212,
        'd', 321,
        'n', 322,
        'L', 213,
        'l', 213,
        'M', 214,
        'm', 214,
      );
      END_STATE();
    case 138:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 139:
      if (lookahead == 'v') ADVANCE(323);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_do);
      if (lookahead == 't') ADVANCE(324);
      if (lookahead == 'w') ADVANCE(325);
      END_STATE();
    case 141:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 142:
      if (lookahead == 'U') ADVANCE(326);
      if (lookahead == 'u') ADVANCE(327);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(239);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 143:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(242);
      END_STATE();
    case 144:
      if (lookahead == 's') ADVANCE(328);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 145:
      if (lookahead == 'u') ADVANCE(329);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(239);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 146:
      if (lookahead == 'i') ADVANCE(330);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(242);
      END_STATE();
    case 147:
      if (lookahead == 'r') ADVANCE(331);
      END_STATE();
    case 148:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 151:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(260);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(261);
      END_STATE();
    case 152:
      if (lookahead == 'D') ADVANCE(260);
      if (lookahead == 'd') ADVANCE(332);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(261);
      END_STATE();
    case 153:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(266);
      END_STATE();
    case 154:
      if (lookahead == 'T') ADVANCE(266);
      if (lookahead == 't') ADVANCE(333);
      END_STATE();
    case 155:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_of);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 158:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(274);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 159:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(278);
      END_STATE();
    case 160:
      if (lookahead == 'G') ADVANCE(274);
      if (lookahead == 'g') ADVANCE(334);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 161:
      if (lookahead == 'r') ADVANCE(335);
      END_STATE();
    case 162:
      if (lookahead == 'O') ADVANCE(278);
      if (lookahead == 'o') ADVANCE(336);
      END_STATE();
    case 163:
      ADVANCE_MAP(
        'C', 285,
        'c', 285,
        'N', 286,
        'n', 286,
        'P', 284,
        'p', 284,
        'Q', 287,
        'q', 287,
      );
      END_STATE();
    case 164:
      ADVANCE_MAP(
        'P', 284,
        'p', 337,
        'C', 285,
        'c', 285,
        'N', 286,
        'n', 286,
        'Q', 287,
        'q', 287,
      );
      END_STATE();
    case 165:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(291);
      END_STATE();
    case 166:
      if (lookahead == 'B') ADVANCE(291);
      if (lookahead == 'b') ADVANCE(338);
      END_STATE();
    case 167:
      if (lookahead == 'e') ADVANCE(339);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_to);
      END_STATE();
    case 169:
      if (lookahead == 't') ADVANCE(340);
      END_STATE();
    case 170:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 171:
      if (lookahead == 'i') ADVANCE(341);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 172:
      if (lookahead == 't') ADVANCE(342);
      END_STATE();
    case 173:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(314);
      END_STATE();
    case 174:
      if (lookahead == 'L') ADVANCE(314);
      if (lookahead == 'l') ADVANCE(343);
      END_STATE();
    case 175:
      if (lookahead == 'r') ADVANCE(344);
      END_STATE();
    case 176:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(345);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(346);
      END_STATE();
    case 177:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(347);
      END_STATE();
    case 178:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(348);
      END_STATE();
    case 179:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(349);
      END_STATE();
    case 180:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(350);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(351);
      END_STATE();
    case 181:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(352);
      END_STATE();
    case 182:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(353);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(354);
      END_STATE();
    case 183:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(355);
      END_STATE();
    case 184:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(356);
      END_STATE();
    case 185:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(357);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(358);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(359);
      END_STATE();
    case 186:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(360);
      END_STATE();
    case 187:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(361);
      END_STATE();
    case 188:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(362);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(363);
      END_STATE();
    case 189:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(364);
      END_STATE();
    case 190:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(365);
      END_STATE();
    case 191:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(366);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_AND);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_And);
      END_STATE();
    case 194:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(367);
      END_STATE();
    case 195:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(368);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(aux_sym_add_dataset_modification_token1);
      ADVANCE_MAP(
        'A', 369,
        'a', 369,
        'B', 370,
        'b', 370,
        'F', 371,
        'f', 371,
        'L', 372,
        'l', 372,
      );
      END_STATE();
    case 197:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(373);
      END_STATE();
    case 198:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(374);
      END_STATE();
    case 199:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(375);
      END_STATE();
    case 200:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(376);
      END_STATE();
    case 201:
      if (lookahead == 'A') ADVANCE(377);
      END_STATE();
    case 202:
      if (lookahead == 'a') ADVANCE(378);
      END_STATE();
    case 203:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(379);
      END_STATE();
    case 204:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(380);
      END_STATE();
    case 205:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(381);
      END_STATE();
    case 206:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(382);
      END_STATE();
    case 207:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(383);
      END_STATE();
    case 208:
      if (lookahead == 'E') ADVANCE(384);
      END_STATE();
    case 209:
      if (lookahead == 'E') ADVANCE(385);
      if (lookahead == 'e') ADVANCE(386);
      END_STATE();
    case 210:
      if (lookahead == 'T') ADVANCE(387);
      if (lookahead == 't') ADVANCE(388);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      END_STATE();
    case 211:
      if (lookahead == 'E') ADVANCE(386);
      if (lookahead == 'e') ADVANCE(390);
      END_STATE();
    case 212:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(388);
      END_STATE();
    case 213:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(391);
      END_STATE();
    case 214:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(392);
      END_STATE();
    case 215:
      if (lookahead == 'e') ADVANCE(393);
      END_STATE();
    case 216:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(386);
      END_STATE();
    case 217:
      if (lookahead == 'E') ADVANCE(386);
      if (lookahead == 'e') ADVANCE(394);
      END_STATE();
    case 218:
      if (lookahead == 'T') ADVANCE(388);
      if (lookahead == 't') ADVANCE(395);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      END_STATE();
    case 219:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(396);
      END_STATE();
    case 220:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(397);
      END_STATE();
    case 221:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(398);
      END_STATE();
    case 222:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(399);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_DIV);
      END_STATE();
    case 224:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(400);
      END_STATE();
    case 225:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(401);
      END_STATE();
    case 226:
      if (lookahead == 'N') ADVANCE(402);
      END_STATE();
    case 227:
      if (lookahead == 'N') ADVANCE(403);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_Div);
      END_STATE();
    case 229:
      if (lookahead == 'N') ADVANCE(404);
      if (lookahead == 'n') ADVANCE(405);
      END_STATE();
    case 230:
      if (lookahead == 'n') ADVANCE(406);
      END_STATE();
    case 231:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(407);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(408);
      END_STATE();
    case 232:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(409);
      END_STATE();
    case 233:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(410);
      END_STATE();
    case 234:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(411);
      END_STATE();
    case 235:
      if (lookahead == 'E') ADVANCE(412);
      END_STATE();
    case 236:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(413);
      END_STATE();
    case 237:
      if (lookahead == 'M') ADVANCE(414);
      END_STATE();
    case 238:
      if (lookahead == 'm') ADVANCE(415);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(aux_sym_preproc_split_procedure_body_token2);
      END_STATE();
    case 240:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(416);
      END_STATE();
    case 241:
      if (lookahead == 'T') ADVANCE(417);
      END_STATE();
    case 242:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(418);
      END_STATE();
    case 243:
      if (lookahead == 'e') ADVANCE(419);
      END_STATE();
    case 244:
      if (lookahead == 'm') ADVANCE(420);
      END_STATE();
    case 245:
      if (lookahead == 't') ADVANCE(421);
      END_STATE();
    case 246:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(422);
      END_STATE();
    case 247:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(423);
      END_STATE();
    case 248:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(424);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_FOR);
      if (lookahead == 'E') ADVANCE(425);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_For);
      if (lookahead == 'e') ADVANCE(426);
      END_STATE();
    case 251:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(427);
      END_STATE();
    case 252:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(428);
      END_STATE();
    case 253:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(429);
      END_STATE();
    case 254:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(430);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(431);
      END_STATE();
    case 255:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(432);
      END_STATE();
    case 256:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(433);
      END_STATE();
    case 257:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(434);
      END_STATE();
    case 258:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(435);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_MOD);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 260:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 261:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(438);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_Mod);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 263:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(439);
      END_STATE();
    case 264:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(440);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_NOT);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(441);
      END_STATE();
    case 266:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(441);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(anon_sym_Not);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(441);
      END_STATE();
    case 268:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(442);
      END_STATE();
    case 269:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(443);
      END_STATE();
    case 270:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(444);
      END_STATE();
    case 271:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(445);
      END_STATE();
    case 272:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(446);
      END_STATE();
    case 273:
      if (lookahead == 'E') ADVANCE(447);
      if (lookahead == 'e') ADVANCE(448);
      END_STATE();
    case 274:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(448);
      END_STATE();
    case 275:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(449);
      END_STATE();
    case 276:
      if (lookahead == 'M') ADVANCE(450);
      END_STATE();
    case 277:
      ADVANCE_MAP(
        'F', 451,
        'f', 452,
        'C', 453,
        'c', 453,
        'M', 454,
        'm', 454,
        'T', 455,
        't', 455,
      );
      END_STATE();
    case 278:
      ADVANCE_MAP(
        'C', 453,
        'c', 453,
        'F', 452,
        'f', 452,
        'M', 454,
        'm', 454,
        'T', 455,
        't', 455,
      );
      END_STATE();
    case 279:
      if (lookahead == 'E') ADVANCE(448);
      if (lookahead == 'e') ADVANCE(456);
      END_STATE();
    case 280:
      if (lookahead == 'm') ADVANCE(457);
      END_STATE();
    case 281:
      ADVANCE_MAP(
        'F', 452,
        'f', 458,
        'C', 453,
        'c', 453,
        'M', 454,
        'm', 454,
        'T', 455,
        't', 455,
      );
      END_STATE();
    case 282:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(459);
      END_STATE();
    case 283:
      if (lookahead == 'E') ADVANCE(460);
      if (lookahead == 'O') ADVANCE(461);
      if (lookahead == 'e') ADVANCE(462);
      if (lookahead == 'o') ADVANCE(463);
      END_STATE();
    case 284:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(462);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(463);
      END_STATE();
    case 285:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(464);
      END_STATE();
    case 286:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(465);
      END_STATE();
    case 287:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(466);
      END_STATE();
    case 288:
      if (lookahead == 'E') ADVANCE(462);
      if (lookahead == 'O') ADVANCE(463);
      if (lookahead == 'e') ADVANCE(467);
      if (lookahead == 'o') ADVANCE(468);
      END_STATE();
    case 289:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(469);
      END_STATE();
    case 290:
      if (lookahead == 'L') ADVANCE(470);
      if (lookahead == 'l') ADVANCE(471);
      END_STATE();
    case 291:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(471);
      END_STATE();
    case 292:
      if (lookahead == 'N') ADVANCE(472);
      END_STATE();
    case 293:
      if (lookahead == 'L') ADVANCE(471);
      if (lookahead == 'l') ADVANCE(473);
      END_STATE();
    case 294:
      if (lookahead == 'n') ADVANCE(474);
      END_STATE();
    case 295:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(475);
      END_STATE();
    case 296:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(476);
      END_STATE();
    case 297:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(477);
      END_STATE();
    case 298:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(478);
      END_STATE();
    case 299:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(479);
      END_STATE();
    case 300:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(480);
      END_STATE();
    case 301:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(481);
      END_STATE();
    case 302:
      if (lookahead == 'I') ADVANCE(482);
      END_STATE();
    case 303:
      if (lookahead == 'i') ADVANCE(483);
      END_STATE();
    case 304:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(484);
      END_STATE();
    case 305:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(485);
      END_STATE();
    case 306:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(486);
      END_STATE();
    case 307:
      if (lookahead == 'L') ADVANCE(487);
      END_STATE();
    case 308:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(488);
      END_STATE();
    case 309:
      if (lookahead == 'H') ADVANCE(489);
      END_STATE();
    case 310:
      if (lookahead == 'l') ADVANCE(490);
      END_STATE();
    case 311:
      if (lookahead == 'h') ADVANCE(491);
      END_STATE();
    case 312:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(492);
      END_STATE();
    case 313:
      ADVANCE_MAP(
        'P', 493,
        'p', 494,
        'A', 495,
        'a', 495,
        'D', 496,
        'd', 496,
        'E', 497,
        'e', 497,
        'N', 498,
        'n', 498,
      );
      END_STATE();
    case 314:
      ADVANCE_MAP(
        'A', 495,
        'a', 495,
        'D', 496,
        'd', 496,
        'E', 497,
        'e', 497,
        'N', 498,
        'n', 498,
      );
      END_STATE();
    case 315:
      ACCEPT_TOKEN(anon_sym_XOR);
      END_STATE();
    case 316:
      ADVANCE_MAP(
        'P', 499,
        'p', 500,
        'A', 495,
        'a', 495,
        'D', 496,
        'd', 496,
        'E', 497,
        'e', 497,
        'N', 498,
        'n', 498,
      );
      END_STATE();
    case 317:
      ACCEPT_TOKEN(anon_sym_Xor);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 319:
      if (lookahead == 'a') ADVANCE(501);
      END_STATE();
    case 320:
      if (lookahead == 'e') ADVANCE(502);
      END_STATE();
    case 321:
      if (lookahead == 'E') ADVANCE(386);
      if (lookahead == 'e') ADVANCE(503);
      END_STATE();
    case 322:
      if (lookahead == 'T') ADVANCE(388);
      if (lookahead == 't') ADVANCE(504);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(anon_sym_div);
      END_STATE();
    case 324:
      if (lookahead == 'N') ADVANCE(505);
      if (lookahead == 'n') ADVANCE(506);
      END_STATE();
    case 325:
      if (lookahead == 'n') ADVANCE(507);
      END_STATE();
    case 326:
      if (lookahead == 'M') ADVANCE(508);
      END_STATE();
    case 327:
      if (lookahead == 'm') ADVANCE(509);
      END_STATE();
    case 328:
      if (lookahead == 'e') ADVANCE(510);
      END_STATE();
    case 329:
      if (lookahead == 'm') ADVANCE(511);
      END_STATE();
    case 330:
      if (lookahead == 't') ADVANCE(512);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == 'e') ADVANCE(513);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(anon_sym_mod);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(436);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(anon_sym_not);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(441);
      END_STATE();
    case 334:
      if (lookahead == 'E') ADVANCE(448);
      if (lookahead == 'e') ADVANCE(514);
      END_STATE();
    case 335:
      if (lookahead == 'm') ADVANCE(515);
      END_STATE();
    case 336:
      ADVANCE_MAP(
        'F', 452,
        'f', 516,
        'C', 453,
        'c', 453,
        'M', 454,
        'm', 454,
        'T', 455,
        't', 455,
      );
      END_STATE();
    case 337:
      if (lookahead == 'E') ADVANCE(462);
      if (lookahead == 'O') ADVANCE(463);
      if (lookahead == 'e') ADVANCE(517);
      if (lookahead == 'o') ADVANCE(518);
      END_STATE();
    case 338:
      if (lookahead == 'L') ADVANCE(471);
      if (lookahead == 'l') ADVANCE(519);
      END_STATE();
    case 339:
      if (lookahead == 'n') ADVANCE(520);
      END_STATE();
    case 340:
      if (lookahead == 'i') ADVANCE(521);
      END_STATE();
    case 341:
      if (lookahead == 'l') ADVANCE(522);
      END_STATE();
    case 342:
      if (lookahead == 'h') ADVANCE(523);
      END_STATE();
    case 343:
      ADVANCE_MAP(
        'p', 524,
        'A', 495,
        'a', 495,
        'D', 496,
        'd', 496,
        'E', 497,
        'e', 497,
        'N', 498,
        'n', 498,
      );
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_xor);
      END_STATE();
    case 345:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(525);
      END_STATE();
    case 346:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(526);
      END_STATE();
    case 347:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(527);
      END_STATE();
    case 348:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(528);
      END_STATE();
    case 349:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(529);
      END_STATE();
    case 350:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(530);
      END_STATE();
    case 351:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(531);
      END_STATE();
    case 352:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(532);
      END_STATE();
    case 353:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(533);
      if (lookahead == 'K' ||
          lookahead == 'k' ||
          lookahead == 0x212a) ADVANCE(534);
      END_STATE();
    case 354:
      if (lookahead == 'K' ||
          lookahead == 'k' ||
          lookahead == 0x212a) ADVANCE(535);
      END_STATE();
    case 355:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(536);
      END_STATE();
    case 356:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(537);
      END_STATE();
    case 357:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(538);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(539);
      END_STATE();
    case 358:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(540);
      END_STATE();
    case 359:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(541);
      END_STATE();
    case 360:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(542);
      END_STATE();
    case 361:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(543);
      END_STATE();
    case 362:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(544);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(sym_var_keyword);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(545);
      END_STATE();
    case 364:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(546);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(547);
      END_STATE();
    case 365:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(548);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(sym_key_keyword);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(549);
      END_STATE();
    case 367:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(550);
      END_STATE();
    case 368:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(551);
      END_STATE();
    case 369:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(552);
      END_STATE();
    case 370:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(553);
      END_STATE();
    case 371:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(554);
      END_STATE();
    case 372:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(555);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(sym_area_keyword);
      END_STATE();
    case 374:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(556);
      END_STATE();
    case 375:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(557);
      END_STATE();
    case 376:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(558);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(559);
      END_STATE();
    case 377:
      if (lookahead == 'K') ADVANCE(560);
      END_STATE();
    case 378:
      if (lookahead == 'k') ADVANCE(561);
      END_STATE();
    case 379:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(562);
      END_STATE();
    case 380:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(563);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(aux_sym_basic_type_token16);
      END_STATE();
    case 382:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(564);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(aux_sym_basic_type_token4);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(anon_sym_CASE);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      if (lookahead == 'U') ADVANCE(565);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      END_STATE();
    case 387:
      if (lookahead == 'I') ADVANCE(566);
      if (lookahead == 'R') ADVANCE(567);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 388:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 389:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(569);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      if (lookahead == 'u') ADVANCE(570);
      END_STATE();
    case 391:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(571);
      END_STATE();
    case 392:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(572);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_Case);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      if (lookahead == 'U') ADVANCE(573);
      if (lookahead == 'u') ADVANCE(574);
      END_STATE();
    case 395:
      if (lookahead == 'i') ADVANCE(575);
      if (lookahead == 'r') ADVANCE(576);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(aux_sym_basic_type_token5);
      END_STATE();
    case 397:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(577);
      END_STATE();
    case 398:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(578);
      END_STATE();
    case 399:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(579);
      END_STATE();
    case 400:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(580);
      END_STATE();
    case 401:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(581);
      END_STATE();
    case 402:
      if (lookahead == 'E') ADVANCE(582);
      END_STATE();
    case 403:
      if (lookahead == 'T') ADVANCE(583);
      END_STATE();
    case 404:
      if (lookahead == 'e') ADVANCE(584);
      END_STATE();
    case 405:
      if (lookahead == 'e') ADVANCE(585);
      END_STATE();
    case 406:
      if (lookahead == 't') ADVANCE(586);
      END_STATE();
    case 407:
      ADVANCE_MAP(
        'B', 587,
        'b', 587,
        'I', 588,
        'i', 588,
        'S', 589,
        's', 589,
        'T', 590,
        't', 590,
      );
      END_STATE();
    case 408:
      ACCEPT_TOKEN(aux_sym_basic_type_token9);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(591);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(592);
      END_STATE();
    case 409:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(593);
      END_STATE();
    case 410:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(594);
      END_STATE();
    case 411:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(595);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_ELSE);
      END_STATE();
    case 413:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(596);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_ENUM);
      if (lookahead == 'E') ADVANCE(597);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_ENum);
      END_STATE();
    case 416:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(598);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(anon_sym_EXIT);
      END_STATE();
    case 418:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(599);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_Else);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_Enum);
      if (lookahead == 'E') ADVANCE(600);
      if (lookahead == 'e') ADVANCE(601);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(anon_sym_Exit);
      END_STATE();
    case 422:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(602);
      END_STATE();
    case 423:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(603);
      END_STATE();
    case 424:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(604);
      END_STATE();
    case 425:
      if (lookahead == 'A') ADVANCE(605);
      END_STATE();
    case 426:
      if (lookahead == 'a') ADVANCE(606);
      END_STATE();
    case 427:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(607);
      END_STATE();
    case 428:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(608);
      END_STATE();
    case 429:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(609);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(aux_sym_basic_type_token48);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(610);
      END_STATE();
    case 431:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(611);
      END_STATE();
    case 432:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(612);
      END_STATE();
    case 433:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(613);
      END_STATE();
    case 434:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(614);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(615);
      END_STATE();
    case 435:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(616);
      END_STATE();
    case 436:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(617);
      END_STATE();
    case 437:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(618);
      END_STATE();
    case 438:
      ADVANCE_MAP(
        'A', 619,
        'a', 619,
        'B', 620,
        'b', 620,
        'F', 621,
        'f', 621,
        'L', 622,
        'l', 622,
      );
      END_STATE();
    case 439:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(623);
      END_STATE();
    case 440:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(624);
      END_STATE();
    case 441:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(625);
      END_STATE();
    case 442:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(626);
      END_STATE();
    case 443:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(627);
      END_STATE();
    case 444:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(628);
      END_STATE();
    case 445:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(629);
      END_STATE();
    case 446:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(630);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(sym_page_keyword);
      if (lookahead == 'C') ADVANCE(631);
      if (lookahead == 'E') ADVANCE(632);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(sym_page_keyword);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(sym_part_keyword);
      END_STATE();
    case 450:
      if (lookahead == 'I') ADVANCE(633);
      END_STATE();
    case 451:
      if (lookahead == 'I') ADVANCE(634);
      if (lookahead == 'i') ADVANCE(635);
      END_STATE();
    case 452:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(635);
      END_STATE();
    case 453:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(636);
      END_STATE();
    case 454:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(637);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(638);
      END_STATE();
    case 455:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(639);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(sym_page_keyword);
      if (lookahead == 'C') ADVANCE(640);
      if (lookahead == 'E') ADVANCE(641);
      if (lookahead == 'c') ADVANCE(642);
      if (lookahead == 'e') ADVANCE(643);
      END_STATE();
    case 457:
      if (lookahead == 'i') ADVANCE(644);
      END_STATE();
    case 458:
      if (lookahead == 'I') ADVANCE(635);
      if (lookahead == 'i') ADVANCE(645);
      END_STATE();
    case 459:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(646);
      END_STATE();
    case 460:
      if (lookahead == 'A') ADVANCE(647);
      if (lookahead == 'a') ADVANCE(648);
      END_STATE();
    case 461:
      if (lookahead == 'R') ADVANCE(649);
      if (lookahead == 'r') ADVANCE(650);
      END_STATE();
    case 462:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(648);
      END_STATE();
    case 463:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(650);
      END_STATE();
    case 464:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(651);
      END_STATE();
    case 465:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(652);
      END_STATE();
    case 466:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(653);
      END_STATE();
    case 467:
      if (lookahead == 'A') ADVANCE(648);
      if (lookahead == 'a') ADVANCE(654);
      END_STATE();
    case 468:
      if (lookahead == 'R') ADVANCE(650);
      if (lookahead == 'r') ADVANCE(655);
      END_STATE();
    case 469:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(656);
      END_STATE();
    case 470:
      if (lookahead == 'E') ADVANCE(657);
      if (lookahead == 'e') ADVANCE(658);
      END_STATE();
    case 471:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(658);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_THEN);
      END_STATE();
    case 473:
      if (lookahead == 'E') ADVANCE(658);
      if (lookahead == 'e') ADVANCE(659);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_Then);
      END_STATE();
    case 475:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(660);
      END_STATE();
    case 476:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(661);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(662);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(aux_sym_text_type_token1);
      ADVANCE_MAP(
        'A', 663,
        'a', 663,
        'B', 664,
        'b', 664,
        'C', 665,
        'c', 665,
        'E', 666,
        'e', 666,
      );
      END_STATE();
    case 478:
      ACCEPT_TOKEN(aux_sym_basic_type_token10);
      END_STATE();
    case 479:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(667);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(aux_sym_boolean_token1);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(aux_sym_type_declaration_token1);
      END_STATE();
    case 482:
      if (lookahead == 'L') ADVANCE(668);
      END_STATE();
    case 483:
      if (lookahead == 'l') ADVANCE(669);
      END_STATE();
    case 484:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(670);
      END_STATE();
    case 485:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(671);
      END_STATE();
    case 486:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(672);
      END_STATE();
    case 487:
      if (lookahead == 'E') ADVANCE(673);
      END_STATE();
    case 488:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(674);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_WITH);
      END_STATE();
    case 490:
      if (lookahead == 'e') ADVANCE(675);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_With);
      END_STATE();
    case 492:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(676);
      END_STATE();
    case 493:
      if (lookahead == 'O') ADVANCE(677);
      if (lookahead == 'o') ADVANCE(678);
      END_STATE();
    case 494:
      if (lookahead == 'o') ADVANCE(679);
      END_STATE();
    case 495:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(680);
      END_STATE();
    case 496:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(681);
      END_STATE();
    case 497:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(682);
      END_STATE();
    case 498:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(683);
      END_STATE();
    case 499:
      if (lookahead == 'o') ADVANCE(684);
      END_STATE();
    case 500:
      if (lookahead == 'o') ADVANCE(685);
      END_STATE();
    case 501:
      if (lookahead == 'k') ADVANCE(686);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(aux_sym_code_type_token1);
      if (lookahead == 'U') ADVANCE(687);
      if (lookahead == 'u') ADVANCE(688);
      END_STATE();
    case 504:
      if (lookahead == 'i') ADVANCE(689);
      if (lookahead == 'r') ADVANCE(690);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 505:
      if (lookahead == 'e') ADVANCE(691);
      END_STATE();
    case 506:
      if (lookahead == 'e') ADVANCE(692);
      END_STATE();
    case 507:
      if (lookahead == 't') ADVANCE(693);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_eNUM);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_eNum);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_enum);
      if (lookahead == 'E') ADVANCE(694);
      if (lookahead == 'e') ADVANCE(695);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_exit);
      END_STATE();
    case 513:
      if (lookahead == 'a') ADVANCE(696);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(sym_page_keyword);
      if (lookahead == 'C') ADVANCE(697);
      if (lookahead == 'E') ADVANCE(698);
      if (lookahead == 'c') ADVANCE(699);
      if (lookahead == 'e') ADVANCE(700);
      END_STATE();
    case 515:
      if (lookahead == 'i') ADVANCE(701);
      END_STATE();
    case 516:
      if (lookahead == 'I') ADVANCE(635);
      if (lookahead == 'i') ADVANCE(702);
      END_STATE();
    case 517:
      if (lookahead == 'A') ADVANCE(648);
      if (lookahead == 'a') ADVANCE(703);
      END_STATE();
    case 518:
      if (lookahead == 'R') ADVANCE(650);
      if (lookahead == 'r') ADVANCE(704);
      END_STATE();
    case 519:
      if (lookahead == 'E') ADVANCE(658);
      if (lookahead == 'e') ADVANCE(705);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 521:
      if (lookahead == 'l') ADVANCE(706);
      END_STATE();
    case 522:
      if (lookahead == 'e') ADVANCE(707);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 524:
      if (lookahead == 'o') ADVANCE(708);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(sym_grid_keyword);
      END_STATE();
    case 526:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(709);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(aux_sym_basic_type_token15);
      END_STATE();
    case 528:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(710);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(711);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(712);
      END_STATE();
    case 529:
      ADVANCE_MAP(
        'A', 713,
        'a', 713,
        'O', 714,
        'o', 714,
        'T', 715,
        't', 715,
        'V', 716,
        'v', 716,
      );
      END_STATE();
    case 530:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(717);
      END_STATE();
    case 531:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(718);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(aux_sym_list_type_token1);
      END_STATE();
    case 533:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(719);
      END_STATE();
    case 534:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(720);
      END_STATE();
    case 535:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(721);
      END_STATE();
    case 536:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(722);
      END_STATE();
    case 537:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(723);
      END_STATE();
    case 538:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(724);
      END_STATE();
    case 539:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(725);
      END_STATE();
    case 540:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(726);
      END_STATE();
    case 541:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(727);
      END_STATE();
    case 542:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(728);
      END_STATE();
    case 543:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(729);
      END_STATE();
    case 544:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(730);
      END_STATE();
    case 545:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(731);
      END_STATE();
    case 546:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(732);
      END_STATE();
    case 547:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(733);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(sym_view_keyword);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(734);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(sym_keys_keyword);
      END_STATE();
    case 550:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(735);
      END_STATE();
    case 551:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(736);
      END_STATE();
    case 552:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(737);
      END_STATE();
    case 553:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(738);
      END_STATE();
    case 554:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(739);
      END_STATE();
    case 555:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(740);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(aux_sym_array_type_token1);
      END_STATE();
    case 557:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(741);
      END_STATE();
    case 558:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(742);
      END_STATE();
    case 559:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(743);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_BREAK);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_Break);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(aux_sym_preproc_split_procedure_body_token1);
      END_STATE();
    case 563:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(744);
      END_STATE();
    case 564:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(745);
      END_STATE();
    case 565:
      if (lookahead == 'N') ADVANCE(746);
      END_STATE();
    case 566:
      if (lookahead == 'N') ADVANCE(747);
      END_STATE();
    case 567:
      if (lookahead == 'O') ADVANCE(748);
      END_STATE();
    case 568:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(749);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(aux_sym_where_condition_token3);
      END_STATE();
    case 570:
      if (lookahead == 'n') ADVANCE(750);
      END_STATE();
    case 571:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(751);
      END_STATE();
    case 572:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(752);
      END_STATE();
    case 573:
      if (lookahead == 'n') ADVANCE(753);
      END_STATE();
    case 574:
      if (lookahead == 'n') ADVANCE(754);
      END_STATE();
    case 575:
      if (lookahead == 'n') ADVANCE(755);
      END_STATE();
    case 576:
      if (lookahead == 'o') ADVANCE(756);
      END_STATE();
    case 577:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(757);
      END_STATE();
    case 578:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(758);
      END_STATE();
    case 579:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(759);
      END_STATE();
    case 580:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(760);
      END_STATE();
    case 581:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(761);
      END_STATE();
    case 582:
      if (lookahead == 'T') ADVANCE(762);
      END_STATE();
    case 583:
      if (lookahead == 'O') ADVANCE(763);
      END_STATE();
    case 584:
      if (lookahead == 't') ADVANCE(764);
      END_STATE();
    case 585:
      if (lookahead == 't') ADVANCE(765);
      END_STATE();
    case 586:
      if (lookahead == 'o') ADVANCE(766);
      END_STATE();
    case 587:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(767);
      END_STATE();
    case 588:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(768);
      END_STATE();
    case 589:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(769);
      END_STATE();
    case 590:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(770);
      END_STATE();
    case 591:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(771);
      END_STATE();
    case 592:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(772);
      END_STATE();
    case 593:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(773);
      END_STATE();
    case 594:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(774);
      END_STATE();
    case 595:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(775);
      END_STATE();
    case 596:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(776);
      END_STATE();
    case 597:
      if (lookahead == 'X') ADVANCE(777);
      END_STATE();
    case 598:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(778);
      END_STATE();
    case 599:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(779);
      END_STATE();
    case 600:
      if (lookahead == 'x') ADVANCE(780);
      END_STATE();
    case 601:
      if (lookahead == 'x') ADVANCE(781);
      END_STATE();
    case 602:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(782);
      END_STATE();
    case 603:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(783);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym_event_keyword);
      END_STATE();
    case 605:
      if (lookahead == 'C') ADVANCE(784);
      END_STATE();
    case 606:
      if (lookahead == 'c') ADVANCE(785);
      END_STATE();
    case 607:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(786);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(aux_sym_boolean_token2);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(aux_sym_where_condition_token1);
      ADVANCE_MAP(
        'A', 787,
        'a', 787,
        'E', 788,
        'e', 788,
        'G', 789,
        'g', 789,
        'R', 790,
        'r', 790,
        'S', 791,
        's', 791,
      );
      END_STATE();
    case 610:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(792);
      END_STATE();
    case 611:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(793);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(sym_fixed_keyword);
      END_STATE();
    case 613:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(794);
      END_STATE();
    case 614:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(795);
      END_STATE();
    case 615:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(796);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(797);
      END_STATE();
    case 616:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(798);
      END_STATE();
    case 617:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(799);
      END_STATE();
    case 618:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(800);
      END_STATE();
    case 619:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(801);
      END_STATE();
    case 620:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(802);
      END_STATE();
    case 621:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(803);
      END_STATE();
    case 622:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(804);
      END_STATE();
    case 623:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(805);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(aux_sym_basic_type_token28);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(806);
      END_STATE();
    case 625:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(807);
      END_STATE();
    case 626:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(808);
      END_STATE();
    case 627:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(809);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(aux_sym_sorting_value_token2);
      END_STATE();
    case 629:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(810);
      END_STATE();
    case 630:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(811);
      END_STATE();
    case 631:
      if (lookahead == 'U') ADVANCE(812);
      END_STATE();
    case 632:
      if (lookahead == 'X') ADVANCE(813);
      END_STATE();
    case 633:
      if (lookahead == 'S') ADVANCE(814);
      END_STATE();
    case 634:
      if (lookahead == 'L') ADVANCE(815);
      if (lookahead == 'l') ADVANCE(816);
      END_STATE();
    case 635:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(816);
      END_STATE();
    case 636:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(817);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(818);
      END_STATE();
    case 637:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(819);
      END_STATE();
    case 638:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(820);
      END_STATE();
    case 639:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(821);
      END_STATE();
    case 640:
      if (lookahead == 'u') ADVANCE(822);
      END_STATE();
    case 641:
      if (lookahead == 'x') ADVANCE(823);
      END_STATE();
    case 642:
      if (lookahead == 'u') ADVANCE(824);
      END_STATE();
    case 643:
      if (lookahead == 'x') ADVANCE(825);
      END_STATE();
    case 644:
      if (lookahead == 's') ADVANCE(826);
      END_STATE();
    case 645:
      if (lookahead == 'L') ADVANCE(816);
      if (lookahead == 'l') ADVANCE(827);
      END_STATE();
    case 646:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(828);
      END_STATE();
    case 647:
      if (lookahead == 'T') ADVANCE(829);
      if (lookahead == 't') ADVANCE(830);
      END_STATE();
    case 648:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(830);
      END_STATE();
    case 649:
      if (lookahead == 'T') ADVANCE(831);
      if (lookahead == 't') ADVANCE(832);
      END_STATE();
    case 650:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(832);
      END_STATE();
    case 651:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(833);
      END_STATE();
    case 652:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(834);
      END_STATE();
    case 653:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(835);
      END_STATE();
    case 654:
      if (lookahead == 'T') ADVANCE(830);
      if (lookahead == 't') ADVANCE(836);
      END_STATE();
    case 655:
      if (lookahead == 'T') ADVANCE(832);
      if (lookahead == 't') ADVANCE(837);
      END_STATE();
    case 656:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(838);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_table_keyword);
      ADVANCE_MAP(
        'E', 839,
        'e', 840,
        'C', 841,
        'c', 841,
        'D', 842,
        'd', 842,
        'F', 843,
        'f', 843,
      );
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym_table_keyword);
      ADVANCE_MAP(
        'C', 841,
        'c', 841,
        'D', 842,
        'd', 842,
        'E', 840,
        'e', 840,
        'F', 843,
        'f', 843,
      );
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_table_keyword);
      ADVANCE_MAP(
        'E', 844,
        'e', 845,
        'C', 841,
        'c', 841,
        'D', 842,
        'd', 842,
        'F', 843,
        'f', 843,
      );
      END_STATE();
    case 660:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(846);
      END_STATE();
    case 661:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(847);
      END_STATE();
    case 662:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(848);
      END_STATE();
    case 663:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(849);
      END_STATE();
    case 664:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(850);
      END_STATE();
    case 665:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(851);
      END_STATE();
    case 666:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(852);
      END_STATE();
    case 667:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(853);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(anon_sym_UNTIL);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(anon_sym_Until);
      END_STATE();
    case 670:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(854);
      END_STATE();
    case 671:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(855);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(sym_using_keyword);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(anon_sym_WHILE);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(aux_sym_where_clause_token1);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(anon_sym_While);
      END_STATE();
    case 676:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(856);
      END_STATE();
    case 677:
      if (lookahead == 'R') ADVANCE(857);
      END_STATE();
    case 678:
      if (lookahead == 'r') ADVANCE(858);
      END_STATE();
    case 679:
      if (lookahead == 'r') ADVANCE(859);
      END_STATE();
    case 680:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(860);
      END_STATE();
    case 681:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(861);
      END_STATE();
    case 682:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(862);
      END_STATE();
    case 683:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(863);
      END_STATE();
    case 684:
      if (lookahead == 'r') ADVANCE(864);
      END_STATE();
    case 685:
      if (lookahead == 'r') ADVANCE(865);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 687:
      if (lookahead == 'n') ADVANCE(866);
      END_STATE();
    case 688:
      if (lookahead == 'n') ADVANCE(867);
      END_STATE();
    case 689:
      if (lookahead == 'n') ADVANCE(868);
      END_STATE();
    case 690:
      if (lookahead == 'o') ADVANCE(869);
      END_STATE();
    case 691:
      if (lookahead == 't') ADVANCE(870);
      END_STATE();
    case 692:
      if (lookahead == 't') ADVANCE(871);
      END_STATE();
    case 693:
      if (lookahead == 'o') ADVANCE(872);
      END_STATE();
    case 694:
      if (lookahead == 'x') ADVANCE(873);
      END_STATE();
    case 695:
      if (lookahead == 'x') ADVANCE(874);
      END_STATE();
    case 696:
      if (lookahead == 'c') ADVANCE(875);
      END_STATE();
    case 697:
      if (lookahead == 'u') ADVANCE(876);
      END_STATE();
    case 698:
      if (lookahead == 'x') ADVANCE(877);
      END_STATE();
    case 699:
      if (lookahead == 'u') ADVANCE(878);
      END_STATE();
    case 700:
      if (lookahead == 'x') ADVANCE(879);
      END_STATE();
    case 701:
      if (lookahead == 's') ADVANCE(880);
      END_STATE();
    case 702:
      if (lookahead == 'L') ADVANCE(816);
      if (lookahead == 'l') ADVANCE(881);
      END_STATE();
    case 703:
      if (lookahead == 'T') ADVANCE(830);
      if (lookahead == 't') ADVANCE(882);
      END_STATE();
    case 704:
      if (lookahead == 'T') ADVANCE(832);
      if (lookahead == 't') ADVANCE(883);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(sym_table_keyword);
      ADVANCE_MAP(
        'E', 884,
        'e', 885,
        'C', 841,
        'c', 841,
        'D', 842,
        'd', 842,
        'F', 843,
        'f', 843,
      );
      END_STATE();
    case 706:
      ACCEPT_TOKEN(anon_sym_until);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 708:
      if (lookahead == 'r') ADVANCE(886);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(sym_group_keyword);
      END_STATE();
    case 710:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(887);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(888);
      END_STATE();
    case 711:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(889);
      END_STATE();
    case 712:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(890);
      END_STATE();
    case 713:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(891);
      END_STATE();
    case 714:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(892);
      END_STATE();
    case 715:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(893);
      END_STATE();
    case 716:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(894);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(aux_sym_basic_type_token6);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(895);
      END_STATE();
    case 718:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(896);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(sym_local_keyword);
      END_STATE();
    case 720:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(897);
      END_STATE();
    case 721:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(898);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(sym_query_keyword);
      END_STATE();
    case 723:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(899);
      END_STATE();
    case 724:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(900);
      END_STATE();
    case 725:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(901);
      END_STATE();
    case 726:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(902);
      END_STATE();
    case 727:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(903);
      END_STATE();
    case 728:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(904);
      END_STATE();
    case 729:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(905);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(aux_sym_enum_value_declaration_token1);
      END_STATE();
    case 731:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(906);
      END_STATE();
    case 732:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(907);
      END_STATE();
    case 733:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(908);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(sym_views_keyword);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(aux_sym_interface_declaration_token1);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(aux_sym_basic_type_token22);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(909);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(910);
      END_STATE();
    case 737:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(911);
      END_STATE();
    case 738:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(912);
      END_STATE();
    case 739:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(913);
      END_STATE();
    case 740:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(914);
      END_STATE();
    case 741:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(915);
      END_STATE();
    case 742:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(916);
      END_STATE();
    case 743:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(917);
      END_STATE();
    case 744:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(918);
      END_STATE();
    case 745:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(919);
      END_STATE();
    case 746:
      if (lookahead == 'I') ADVANCE(920);
      END_STATE();
    case 747:
      if (lookahead == 'U') ADVANCE(921);
      END_STATE();
    case 748:
      if (lookahead == 'L') ADVANCE(922);
      END_STATE();
    case 749:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(923);
      END_STATE();
    case 750:
      if (lookahead == 'i') ADVANCE(924);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(sym_column_keyword);
      END_STATE();
    case 752:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(925);
      END_STATE();
    case 753:
      if (lookahead == 'i') ADVANCE(926);
      END_STATE();
    case 754:
      if (lookahead == 'i') ADVANCE(927);
      END_STATE();
    case 755:
      if (lookahead == 'u') ADVANCE(928);
      END_STATE();
    case 756:
      if (lookahead == 'l') ADVANCE(929);
      END_STATE();
    case 757:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(930);
      END_STATE();
    case 758:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(931);
      END_STATE();
    case 759:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(932);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(933);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(aux_sym_basic_type_token21);
      END_STATE();
    case 761:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(934);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(anon_sym_DOTNET);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(anon_sym_DOWNTO);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(anon_sym_DotNet);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(anon_sym_Dotnet);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(anon_sym_Downto);
      END_STATE();
    case 767:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(935);
      END_STATE();
    case 768:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(936);
      END_STATE();
    case 769:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(937);
      END_STATE();
    case 770:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(938);
      END_STATE();
    case 771:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(939);
      END_STATE();
    case 772:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(940);
      END_STATE();
    case 773:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(941);
      END_STATE();
    case 774:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(942);
      END_STATE();
    case 775:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(943);
      END_STATE();
    case 776:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(944);
      END_STATE();
    case 777:
      if (lookahead == 'T') ADVANCE(945);
      END_STATE();
    case 778:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(946);
      END_STATE();
    case 779:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(947);
      END_STATE();
    case 780:
      if (lookahead == 't') ADVANCE(948);
      END_STATE();
    case 781:
      if (lookahead == 't') ADVANCE(949);
      END_STATE();
    case 782:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(950);
      END_STATE();
    case 783:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(951);
      END_STATE();
    case 784:
      if (lookahead == 'H') ADVANCE(952);
      END_STATE();
    case 785:
      if (lookahead == 'h') ADVANCE(953);
      END_STATE();
    case 786:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(954);
      END_STATE();
    case 787:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(955);
      END_STATE();
    case 788:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(956);
      END_STATE();
    case 789:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(957);
      END_STATE();
    case 790:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(958);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(sym_fields_keyword);
      END_STATE();
    case 792:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(959);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(sym_filter_keyword);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(960);
      END_STATE();
    case 794:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(961);
      END_STATE();
    case 795:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(962);
      END_STATE();
    case 796:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(963);
      END_STATE();
    case 797:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(964);
      END_STATE();
    case 798:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(965);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(aux_sym_modify_modification_token1);
      END_STATE();
    case 800:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(966);
      END_STATE();
    case 801:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(967);
      END_STATE();
    case 802:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(968);
      END_STATE();
    case 803:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(969);
      END_STATE();
    case 804:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(970);
      END_STATE();
    case 805:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(971);
      END_STATE();
    case 806:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(972);
      END_STATE();
    case 807:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(973);
      END_STATE();
    case 808:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(974);
      END_STATE();
    case 809:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(975);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(aux_sym_option_type_token1);
      END_STATE();
    case 811:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(976);
      END_STATE();
    case 812:
      if (lookahead == 'S') ADVANCE(977);
      END_STATE();
    case 813:
      if (lookahead == 'T') ADVANCE(978);
      END_STATE();
    case 814:
      if (lookahead == 'S') ADVANCE(979);
      END_STATE();
    case 815:
      if (lookahead == 'E') ADVANCE(980);
      if (lookahead == 'e') ADVANCE(981);
      END_STATE();
    case 816:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(981);
      END_STATE();
    case 817:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(982);
      END_STATE();
    case 818:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(983);
      END_STATE();
    case 819:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(984);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(aux_sym_area_section_token6);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(985);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(986);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(987);
      END_STATE();
    case 821:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(988);
      END_STATE();
    case 822:
      if (lookahead == 's') ADVANCE(989);
      END_STATE();
    case 823:
      if (lookahead == 't') ADVANCE(990);
      END_STATE();
    case 824:
      if (lookahead == 's') ADVANCE(991);
      END_STATE();
    case 825:
      if (lookahead == 't') ADVANCE(992);
      END_STATE();
    case 826:
      if (lookahead == 's') ADVANCE(993);
      END_STATE();
    case 827:
      if (lookahead == 'E') ADVANCE(981);
      if (lookahead == 'e') ADVANCE(994);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(aux_sym_interface_declaration_token2);
      END_STATE();
    case 829:
      ACCEPT_TOKEN(anon_sym_REPEAT);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(995);
      END_STATE();
    case 830:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(995);
      END_STATE();
    case 831:
      ACCEPT_TOKEN(sym_report_keyword);
      if (lookahead == 'E') ADVANCE(996);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      END_STATE();
    case 832:
      ACCEPT_TOKEN(sym_report_keyword);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(aux_sym_record_type_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(998);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(999);
      END_STATE();
    case 834:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1000);
      END_STATE();
    case 835:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1001);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(anon_sym_Repeat);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(995);
      END_STATE();
    case 837:
      ACCEPT_TOKEN(sym_report_keyword);
      if (lookahead == 'E') ADVANCE(1002);
      if (lookahead == 'e') ADVANCE(1003);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      END_STATE();
    case 838:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1004);
      END_STATE();
    case 839:
      if (lookahead == 'X') ADVANCE(1005);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 840:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 841:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1007);
      END_STATE();
    case 842:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1008);
      END_STATE();
    case 843:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1009);
      END_STATE();
    case 844:
      if (lookahead == 'x') ADVANCE(1010);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 845:
      if (lookahead == 'x') ADVANCE(1011);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 846:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1012);
      END_STATE();
    case 847:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1013);
      END_STATE();
    case 848:
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1014);
      END_STATE();
    case 849:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1015);
      END_STATE();
    case 850:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1016);
      END_STATE();
    case 851:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1017);
      END_STATE();
    case 852:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1018);
      END_STATE();
    case 853:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1019);
      END_STATE();
    case 854:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1020);
      END_STATE();
    case 855:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1021);
      END_STATE();
    case 856:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1022);
      END_STATE();
    case 857:
      if (lookahead == 'T') ADVANCE(1023);
      END_STATE();
    case 858:
      if (lookahead == 't') ADVANCE(1024);
      END_STATE();
    case 859:
      if (lookahead == 't') ADVANCE(1025);
      END_STATE();
    case 860:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1026);
      END_STATE();
    case 861:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1027);
      END_STATE();
    case 862:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1028);
      END_STATE();
    case 863:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1029);
      END_STATE();
    case 864:
      if (lookahead == 't') ADVANCE(1030);
      END_STATE();
    case 865:
      if (lookahead == 't') ADVANCE(1031);
      END_STATE();
    case 866:
      if (lookahead == 'i') ADVANCE(1032);
      END_STATE();
    case 867:
      if (lookahead == 'i') ADVANCE(1033);
      END_STATE();
    case 868:
      if (lookahead == 'u') ADVANCE(1034);
      END_STATE();
    case 869:
      if (lookahead == 'l') ADVANCE(1035);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(anon_sym_dotNet);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(anon_sym_dotnet);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(anon_sym_downto);
      END_STATE();
    case 873:
      if (lookahead == 't') ADVANCE(1036);
      END_STATE();
    case 874:
      if (lookahead == 't') ADVANCE(1037);
      END_STATE();
    case 875:
      if (lookahead == 'h') ADVANCE(1038);
      END_STATE();
    case 876:
      if (lookahead == 's') ADVANCE(1039);
      END_STATE();
    case 877:
      if (lookahead == 't') ADVANCE(1040);
      END_STATE();
    case 878:
      if (lookahead == 's') ADVANCE(1041);
      END_STATE();
    case 879:
      if (lookahead == 't') ADVANCE(1042);
      END_STATE();
    case 880:
      if (lookahead == 's') ADVANCE(1043);
      END_STATE();
    case 881:
      if (lookahead == 'E') ADVANCE(981);
      if (lookahead == 'e') ADVANCE(1044);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(anon_sym_repeat);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(995);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(sym_report_keyword);
      if (lookahead == 'E') ADVANCE(1045);
      if (lookahead == 'e') ADVANCE(1046);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      END_STATE();
    case 884:
      if (lookahead == 'x') ADVANCE(1047);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 885:
      if (lookahead == 'x') ADVANCE(1048);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1006);
      END_STATE();
    case 886:
      if (lookahead == 't') ADVANCE(1049);
      END_STATE();
    case 887:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1050);
      END_STATE();
    case 888:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1051);
      END_STATE();
    case 889:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1052);
      END_STATE();
    case 890:
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1053);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1054);
      END_STATE();
    case 891:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1055);
      END_STATE();
    case 892:
      if (lookahead == 'J' ||
          lookahead == 'j') ADVANCE(1056);
      END_STATE();
    case 893:
      if (lookahead == 'K' ||
          lookahead == 'k' ||
          lookahead == 0x212a) ADVANCE(1057);
      END_STATE();
    case 894:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1058);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(sym_labels_keyword);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(sym_layout_keyword);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(aux_sym_ml_value_list_token1);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(aux_sym_lookup_formula_token1);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(sym_schema_keyword);
      END_STATE();
    case 900:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1059);
      END_STATE();
    case 901:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1060);
      END_STATE();
    case 902:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1061);
      END_STATE();
    case 903:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1062);
      END_STATE();
    case 904:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1063);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(aux_sym_tabledata_permission_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1064);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1065);
      END_STATE();
    case 906:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1066);
      END_STATE();
    case 907:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1067);
      END_STATE();
    case 908:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1068);
      END_STATE();
    case 909:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1069);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(sym_actions_keyword);
      END_STATE();
    case 911:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1070);
      END_STATE();
    case 912:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1071);
      END_STATE();
    case 913:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1072);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(aux_sym_addlast_fieldgroup_modification_token1);
      END_STATE();
    case 915:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1073);
      END_STATE();
    case 916:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1074);
      END_STATE();
    case 917:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1075);
      END_STATE();
    case 918:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1076);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(aux_sym_basic_type_token14);
      END_STATE();
    case 920:
      if (lookahead == 'T') ADVANCE(1077);
      END_STATE();
    case 921:
      if (lookahead == 'E') ADVANCE(1078);
      END_STATE();
    case 922:
      if (lookahead == 'A') ADVANCE(1079);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(aux_sym_area_section_token1);
      END_STATE();
    case 924:
      if (lookahead == 't') ADVANCE(1080);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(aux_sym_label_declaration_token1);
      END_STATE();
    case 926:
      if (lookahead == 't') ADVANCE(1081);
      END_STATE();
    case 927:
      if (lookahead == 't') ADVANCE(1082);
      END_STATE();
    case 928:
      if (lookahead == 'e') ADVANCE(1083);
      END_STATE();
    case 929:
      if (lookahead == 'A') ADVANCE(1084);
      if (lookahead == 'a') ADVANCE(1085);
      END_STATE();
    case 930:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1086);
      END_STATE();
    case 931:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1087);
      END_STATE();
    case 932:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1088);
      END_STATE();
    case 933:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(1089);
      END_STATE();
    case 934:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1090);
      END_STATE();
    case 935:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1091);
      END_STATE();
    case 936:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1092);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(sym_dataset_keyword);
      END_STATE();
    case 938:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1093);
      END_STATE();
    case 939:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1094);
      END_STATE();
    case 940:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1095);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(aux_sym_basic_type_token3);
      END_STATE();
    case 942:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1096);
      END_STATE();
    case 943:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1097);
      END_STATE();
    case 944:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1098);
      END_STATE();
    case 945:
      if (lookahead == 'E') ADVANCE(1099);
      END_STATE();
    case 946:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1100);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(sym_extends_keyword);
      END_STATE();
    case 948:
      if (lookahead == 'e') ADVANCE(1101);
      END_STATE();
    case 949:
      if (lookahead == 'e') ADVANCE(1102);
      END_STATE();
    case 950:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1103);
      END_STATE();
    case 951:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1104);
      END_STATE();
    case 952:
      ACCEPT_TOKEN(anon_sym_FOREACH);
      END_STATE();
    case 953:
      ACCEPT_TOKEN(anon_sym_Foreach);
      END_STATE();
    case 954:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1105);
      END_STATE();
    case 955:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1106);
      END_STATE();
    case 956:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1107);
      END_STATE();
    case 957:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1108);
      END_STATE();
    case 958:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1109);
      END_STATE();
    case 959:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1110);
      END_STATE();
    case 960:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1111);
      END_STATE();
    case 961:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1112);
      END_STATE();
    case 962:
      ACCEPT_TOKEN(aux_sym_basic_type_token1);
      END_STATE();
    case 963:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1113);
      END_STATE();
    case 964:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1114);
      END_STATE();
    case 965:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1115);
      END_STATE();
    case 966:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1116);
      END_STATE();
    case 967:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1117);
      END_STATE();
    case 968:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1118);
      END_STATE();
    case 969:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1119);
      END_STATE();
    case 970:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1120);
      END_STATE();
    case 971:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1121);
      END_STATE();
    case 972:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1122);
      END_STATE();
    case 973:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1123);
      END_STATE();
    case 974:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1124);
      END_STATE();
    case 975:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1125);
      END_STATE();
    case 976:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1126);
      END_STATE();
    case 977:
      if (lookahead == 'T') ADVANCE(1127);
      END_STATE();
    case 978:
      if (lookahead == 'E') ADVANCE(1128);
      END_STATE();
    case 979:
      if (lookahead == 'I') ADVANCE(1129);
      END_STATE();
    case 980:
      ACCEPT_TOKEN(sym_profile_keyword);
      if (lookahead == 'E') ADVANCE(1130);
      END_STATE();
    case 981:
      ACCEPT_TOKEN(sym_profile_keyword);
      END_STATE();
    case 982:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1131);
      END_STATE();
    case 983:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1132);
      END_STATE();
    case 984:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1133);
      END_STATE();
    case 985:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1134);
      END_STATE();
    case 986:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1135);
      END_STATE();
    case 987:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1136);
      END_STATE();
    case 988:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1137);
      END_STATE();
    case 989:
      if (lookahead == 't') ADVANCE(1138);
      END_STATE();
    case 990:
      if (lookahead == 'e') ADVANCE(1139);
      END_STATE();
    case 991:
      if (lookahead == 't') ADVANCE(1140);
      END_STATE();
    case 992:
      if (lookahead == 'e') ADVANCE(1141);
      END_STATE();
    case 993:
      if (lookahead == 'i') ADVANCE(1142);
      END_STATE();
    case 994:
      ACCEPT_TOKEN(sym_profile_keyword);
      if (lookahead == 'E') ADVANCE(1143);
      if (lookahead == 'e') ADVANCE(1144);
      END_STATE();
    case 995:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1145);
      END_STATE();
    case 996:
      if (lookahead == 'X') ADVANCE(1146);
      END_STATE();
    case 997:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1147);
      END_STATE();
    case 998:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1148);
      END_STATE();
    case 999:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1149);
      END_STATE();
    case 1000:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1150);
      END_STATE();
    case 1001:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1151);
      END_STATE();
    case 1002:
      if (lookahead == 'x') ADVANCE(1152);
      END_STATE();
    case 1003:
      if (lookahead == 'x') ADVANCE(1153);
      END_STATE();
    case 1004:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1154);
      END_STATE();
    case 1005:
      if (lookahead == 'T') ADVANCE(1155);
      END_STATE();
    case 1006:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1156);
      END_STATE();
    case 1007:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1157);
      END_STATE();
    case 1008:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1158);
      END_STATE();
    case 1009:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1159);
      END_STATE();
    case 1010:
      if (lookahead == 't') ADVANCE(1160);
      END_STATE();
    case 1011:
      if (lookahead == 't') ADVANCE(1161);
      END_STATE();
    case 1012:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1162);
      END_STATE();
    case 1013:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1163);
      END_STATE();
    case 1014:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1164);
      END_STATE();
    case 1015:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1165);
      END_STATE();
    case 1016:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1166);
      END_STATE();
    case 1017:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1167);
      END_STATE();
    case 1018:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1168);
      END_STATE();
    case 1019:
      ACCEPT_TOKEN(sym_trigger_keyword);
      END_STATE();
    case 1020:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1169);
      END_STATE();
    case 1021:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1170);
      END_STATE();
    case 1022:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1171);
      END_STATE();
    case 1023:
      ACCEPT_TOKEN(anon_sym_XMLPORT);
      END_STATE();
    case 1024:
      ACCEPT_TOKEN(anon_sym_XMLPort);
      END_STATE();
    case 1025:
      ACCEPT_TOKEN(anon_sym_XMLport);
      END_STATE();
    case 1026:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1172);
      END_STATE();
    case 1027:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1173);
      END_STATE();
    case 1028:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1174);
      END_STATE();
    case 1029:
      ACCEPT_TOKEN(aux_sym_basic_type_token43);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1175);
      END_STATE();
    case 1030:
      ACCEPT_TOKEN(anon_sym_XmlPort);
      END_STATE();
    case 1031:
      ACCEPT_TOKEN(anon_sym_Xmlport);
      END_STATE();
    case 1032:
      if (lookahead == 't') ADVANCE(1176);
      END_STATE();
    case 1033:
      if (lookahead == 't') ADVANCE(1177);
      END_STATE();
    case 1034:
      if (lookahead == 'e') ADVANCE(1178);
      END_STATE();
    case 1035:
      if (lookahead == 'A') ADVANCE(1179);
      if (lookahead == 'a') ADVANCE(1180);
      END_STATE();
    case 1036:
      if (lookahead == 'e') ADVANCE(1181);
      END_STATE();
    case 1037:
      if (lookahead == 'e') ADVANCE(1182);
      END_STATE();
    case 1038:
      ACCEPT_TOKEN(anon_sym_foreach);
      END_STATE();
    case 1039:
      if (lookahead == 't') ADVANCE(1183);
      END_STATE();
    case 1040:
      if (lookahead == 'e') ADVANCE(1184);
      END_STATE();
    case 1041:
      if (lookahead == 't') ADVANCE(1185);
      END_STATE();
    case 1042:
      if (lookahead == 'e') ADVANCE(1186);
      END_STATE();
    case 1043:
      if (lookahead == 'i') ADVANCE(1187);
      END_STATE();
    case 1044:
      ACCEPT_TOKEN(sym_profile_keyword);
      if (lookahead == 'E') ADVANCE(1188);
      if (lookahead == 'e') ADVANCE(1189);
      END_STATE();
    case 1045:
      if (lookahead == 'x') ADVANCE(1190);
      END_STATE();
    case 1046:
      if (lookahead == 'x') ADVANCE(1191);
      END_STATE();
    case 1047:
      if (lookahead == 't') ADVANCE(1192);
      END_STATE();
    case 1048:
      if (lookahead == 't') ADVANCE(1193);
      END_STATE();
    case 1049:
      ACCEPT_TOKEN(anon_sym_xmlport);
      END_STATE();
    case 1050:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1194);
      END_STATE();
    case 1051:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1195);
      END_STATE();
    case 1052:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1196);
      END_STATE();
    case 1053:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1197);
      END_STATE();
    case 1054:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1198);
      END_STATE();
    case 1055:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1199);
      END_STATE();
    case 1056:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1200);
      END_STATE();
    case 1057:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1201);
      END_STATE();
    case 1058:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1202);
      END_STATE();
    case 1059:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1203);
      END_STATE();
    case 1060:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1204);
      END_STATE();
    case 1061:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1205);
      END_STATE();
    case 1062:
      ACCEPT_TOKEN(aux_sym_keyword_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1206);
      END_STATE();
    case 1063:
      ACCEPT_TOKEN(aux_sym_sorting_value_token1);
      END_STATE();
    case 1064:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1207);
      END_STATE();
    case 1065:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1208);
      END_STATE();
    case 1066:
      ACCEPT_TOKEN(aux_sym_basic_type_token20);
      END_STATE();
    case 1067:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1209);
      END_STATE();
    case 1068:
      ACCEPT_TOKEN(aux_sym_basic_type_token53);
      END_STATE();
    case 1069:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1210);
      END_STATE();
    case 1070:
      ACCEPT_TOKEN(aux_sym_addafter_modification_token1);
      END_STATE();
    case 1071:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1211);
      END_STATE();
    case 1072:
      ACCEPT_TOKEN(aux_sym_addfirst_fieldgroup_modification_token1);
      END_STATE();
    case 1073:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1212);
      END_STATE();
    case 1074:
      ACCEPT_TOKEN(aux_sym_assembly_declaration_token1);
      END_STATE();
    case 1075:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1213);
      END_STATE();
    case 1076:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1214);
      END_STATE();
    case 1077:
      ACCEPT_TOKEN(anon_sym_CODEUNIT);
      END_STATE();
    case 1078:
      ACCEPT_TOKEN(anon_sym_CONTINUE);
      END_STATE();
    case 1079:
      if (lookahead == 'D') ADVANCE(1215);
      END_STATE();
    case 1080:
      ACCEPT_TOKEN(anon_sym_COdeunit);
      END_STATE();
    case 1081:
      ACCEPT_TOKEN(anon_sym_CodeUnit);
      END_STATE();
    case 1082:
      ACCEPT_TOKEN(anon_sym_Codeunit);
      END_STATE();
    case 1083:
      ACCEPT_TOKEN(anon_sym_Continue);
      END_STATE();
    case 1084:
      if (lookahead == 'd') ADVANCE(1216);
      END_STATE();
    case 1085:
      if (lookahead == 'd') ADVANCE(1217);
      END_STATE();
    case 1086:
      ACCEPT_TOKEN(aux_sym_action_area_section_token3);
      END_STATE();
    case 1087:
      ACCEPT_TOKEN(sym_cuegroup_keyword);
      END_STATE();
    case 1088:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1218);
      END_STATE();
    case 1089:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1219);
      END_STATE();
    case 1090:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1220);
      END_STATE();
    case 1091:
      ACCEPT_TOKEN(aux_sym_keyword_identifier_token2);
      END_STATE();
    case 1092:
      ACCEPT_TOKEN(sym_dataitem_keyword);
      END_STATE();
    case 1093:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1221);
      END_STATE();
    case 1094:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1222);
      END_STATE();
    case 1095:
      ACCEPT_TOKEN(aux_sym_basic_type_token11);
      END_STATE();
    case 1096:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1223);
      END_STATE();
    case 1097:
      ACCEPT_TOKEN(aux_sym_basic_type_token12);
      END_STATE();
    case 1098:
      ACCEPT_TOKEN(sym_elements_keyword);
      END_STATE();
    case 1099:
      if (lookahead == 'N') ADVANCE(1224);
      END_STATE();
    case 1100:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1225);
      END_STATE();
    case 1101:
      if (lookahead == 'n') ADVANCE(1226);
      END_STATE();
    case 1102:
      if (lookahead == 'n') ADVANCE(1227);
      END_STATE();
    case 1103:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1228);
      END_STATE();
    case 1104:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1229);
      END_STATE();
    case 1105:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1230);
      END_STATE();
    case 1106:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1231);
      END_STATE();
    case 1107:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1232);
      END_STATE();
    case 1108:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1233);
      END_STATE();
    case 1109:
      ACCEPT_TOKEN(aux_sym_basic_type_token19);
      END_STATE();
    case 1110:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1234);
      END_STATE();
    case 1111:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1235);
      END_STATE();
    case 1112:
      ACCEPT_TOKEN(aux_sym_basic_type_token30);
      END_STATE();
    case 1113:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1236);
      END_STATE();
    case 1114:
      ACCEPT_TOKEN(sym_internal_keyword);
      END_STATE();
    case 1115:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1237);
      END_STATE();
    case 1116:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1238);
      END_STATE();
    case 1117:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1239);
      END_STATE();
    case 1118:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1240);
      END_STATE();
    case 1119:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1241);
      END_STATE();
    case 1120:
      ACCEPT_TOKEN(aux_sym_movelast_modification_token1);
      END_STATE();
    case 1121:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1242);
      END_STATE();
    case 1122:
      ACCEPT_TOKEN(aux_sym_basic_type_token29);
      END_STATE();
    case 1123:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1243);
      END_STATE();
    case 1124:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1244);
      END_STATE();
    case 1125:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1245);
      END_STATE();
    case 1126:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1246);
      END_STATE();
    case 1127:
      if (lookahead == 'O') ADVANCE(1247);
      END_STATE();
    case 1128:
      if (lookahead == 'N') ADVANCE(1248);
      END_STATE();
    case 1129:
      if (lookahead == 'O') ADVANCE(1249);
      END_STATE();
    case 1130:
      if (lookahead == 'X') ADVANCE(1250);
      END_STATE();
    case 1131:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1251);
      END_STATE();
    case 1132:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1252);
      END_STATE();
    case 1133:
      ACCEPT_TOKEN(aux_sym_action_area_section_token4);
      END_STATE();
    case 1134:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1253);
      END_STATE();
    case 1135:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1254);
      END_STATE();
    case 1136:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1255);
      END_STATE();
    case 1137:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1256);
      END_STATE();
    case 1138:
      if (lookahead == 'o') ADVANCE(1257);
      END_STATE();
    case 1139:
      if (lookahead == 'n') ADVANCE(1258);
      END_STATE();
    case 1140:
      if (lookahead == 'o') ADVANCE(1259);
      END_STATE();
    case 1141:
      if (lookahead == 'n') ADVANCE(1260);
      END_STATE();
    case 1142:
      if (lookahead == 'o') ADVANCE(1261);
      END_STATE();
    case 1143:
      if (lookahead == 'x') ADVANCE(1262);
      END_STATE();
    case 1144:
      if (lookahead == 'x') ADVANCE(1263);
      END_STATE();
    case 1145:
      ACCEPT_TOKEN(sym_repeater_keyword);
      END_STATE();
    case 1146:
      if (lookahead == 'T') ADVANCE(1264);
      END_STATE();
    case 1147:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1265);
      END_STATE();
    case 1148:
      ACCEPT_TOKEN(aux_sym_basic_type_token17);
      END_STATE();
    case 1149:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1266);
      END_STATE();
    case 1150:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1267);
      END_STATE();
    case 1151:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1268);
      END_STATE();
    case 1152:
      if (lookahead == 't') ADVANCE(1269);
      END_STATE();
    case 1153:
      if (lookahead == 't') ADVANCE(1270);
      END_STATE();
    case 1154:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1271);
      END_STATE();
    case 1155:
      if (lookahead == 'E') ADVANCE(1272);
      END_STATE();
    case 1156:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1273);
      END_STATE();
    case 1157:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1274);
      END_STATE();
    case 1158:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1275);
      END_STATE();
    case 1159:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1276);
      END_STATE();
    case 1160:
      if (lookahead == 'e') ADVANCE(1277);
      END_STATE();
    case 1161:
      if (lookahead == 'e') ADVANCE(1278);
      END_STATE();
    case 1162:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1279);
      END_STATE();
    case 1163:
      ACCEPT_TOKEN(aux_sym_object_reference_type_token1);
      END_STATE();
    case 1164:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1280);
      END_STATE();
    case 1165:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1281);
      END_STATE();
    case 1166:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1282);
      END_STATE();
    case 1167:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1283);
      END_STATE();
    case 1168:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1284);
      END_STATE();
    case 1169:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1285);
      END_STATE();
    case 1170:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1286);
      END_STATE();
    case 1171:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1287);
      END_STATE();
    case 1172:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1288);
      END_STATE();
    case 1173:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1289);
      END_STATE();
    case 1174:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1290);
      END_STATE();
    case 1175:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1291);
      END_STATE();
    case 1176:
      ACCEPT_TOKEN(anon_sym_codeUnit);
      END_STATE();
    case 1177:
      ACCEPT_TOKEN(anon_sym_codeunit);
      END_STATE();
    case 1178:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 1179:
      if (lookahead == 'd') ADVANCE(1292);
      END_STATE();
    case 1180:
      if (lookahead == 'd') ADVANCE(1293);
      END_STATE();
    case 1181:
      if (lookahead == 'n') ADVANCE(1294);
      END_STATE();
    case 1182:
      if (lookahead == 'n') ADVANCE(1295);
      END_STATE();
    case 1183:
      if (lookahead == 'o') ADVANCE(1296);
      END_STATE();
    case 1184:
      if (lookahead == 'n') ADVANCE(1297);
      END_STATE();
    case 1185:
      if (lookahead == 'o') ADVANCE(1298);
      END_STATE();
    case 1186:
      if (lookahead == 'n') ADVANCE(1299);
      END_STATE();
    case 1187:
      if (lookahead == 'o') ADVANCE(1300);
      END_STATE();
    case 1188:
      if (lookahead == 'x') ADVANCE(1301);
      END_STATE();
    case 1189:
      if (lookahead == 'x') ADVANCE(1302);
      END_STATE();
    case 1190:
      if (lookahead == 't') ADVANCE(1303);
      END_STATE();
    case 1191:
      if (lookahead == 't') ADVANCE(1304);
      END_STATE();
    case 1192:
      if (lookahead == 'e') ADVANCE(1305);
      END_STATE();
    case 1193:
      if (lookahead == 'e') ADVANCE(1306);
      END_STATE();
    case 1194:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1307);
      END_STATE();
    case 1195:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1308);
      END_STATE();
    case 1196:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1309);
      END_STATE();
    case 1197:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1310);
      END_STATE();
    case 1198:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1311);
      END_STATE();
    case 1199:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1312);
      END_STATE();
    case 1200:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1313);
      END_STATE();
    case 1201:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1314);
      END_STATE();
    case 1202:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1315);
      END_STATE();
    case 1203:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1316);
      END_STATE();
    case 1204:
      ACCEPT_TOKEN(aux_sym_action_area_section_token5);
      END_STATE();
    case 1205:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1317);
      END_STATE();
    case 1206:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1318);
      END_STATE();
    case 1207:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1319);
      END_STATE();
    case 1208:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1320);
      END_STATE();
    case 1209:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1321);
      END_STATE();
    case 1210:
      ACCEPT_TOKEN(aux_sym_actionref_declaration_token1);
      END_STATE();
    case 1211:
      ACCEPT_TOKEN(aux_sym_addbefore_modification_token1);
      END_STATE();
    case 1212:
      ACCEPT_TOKEN(aux_sym_order_by_item_token1);
      END_STATE();
    case 1213:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1322);
      END_STATE();
    case 1214:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1323);
      END_STATE();
    case 1215:
      if (lookahead == 'D') ADVANCE(1324);
      END_STATE();
    case 1216:
      if (lookahead == 'd') ADVANCE(1325);
      END_STATE();
    case 1217:
      if (lookahead == 'd') ADVANCE(1326);
      END_STATE();
    case 1218:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1327);
      END_STATE();
    case 1219:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1328);
      END_STATE();
    case 1220:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1329);
      END_STATE();
    case 1221:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1330);
      END_STATE();
    case 1222:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1331);
      END_STATE();
    case 1223:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1332);
      END_STATE();
    case 1224:
      if (lookahead == 'S') ADVANCE(1333);
      END_STATE();
    case 1225:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1334);
      END_STATE();
    case 1226:
      if (lookahead == 's') ADVANCE(1335);
      END_STATE();
    case 1227:
      if (lookahead == 's') ADVANCE(1336);
      END_STATE();
    case 1228:
      ACCEPT_TOKEN(aux_sym_action_area_section_token6);
      END_STATE();
    case 1229:
      ACCEPT_TOKEN(aux_sym_basic_type_token46);
      END_STATE();
    case 1230:
      ACCEPT_TOKEN(aux_sym_area_section_token2);
      END_STATE();
    case 1231:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1337);
      END_STATE();
    case 1232:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1338);
      END_STATE();
    case 1233:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1339);
      END_STATE();
    case 1234:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1340);
      END_STATE();
    case 1235:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1341);
      END_STATE();
    case 1236:
      ACCEPT_TOKEN(sym_interface_keyword);
      END_STATE();
    case 1237:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1342);
      END_STATE();
    case 1238:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1343);
      END_STATE();
    case 1239:
      ACCEPT_TOKEN(aux_sym_moveafter_modification_token1);
      END_STATE();
    case 1240:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1344);
      END_STATE();
    case 1241:
      ACCEPT_TOKEN(aux_sym_movefirst_modification_token1);
      END_STATE();
    case 1242:
      ACCEPT_TOKEN(aux_sym_label_declaration_token2);
      END_STATE();
    case 1243:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1345);
      END_STATE();
    case 1244:
      ACCEPT_TOKEN(sym_namespace_keyword);
      END_STATE();
    case 1245:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1346);
      END_STATE();
    case 1246:
      ACCEPT_TOKEN(aux_sym_basic_type_token31);
      END_STATE();
    case 1247:
      if (lookahead == 'M') ADVANCE(1347);
      END_STATE();
    case 1248:
      if (lookahead == 'S') ADVANCE(1348);
      END_STATE();
    case 1249:
      if (lookahead == 'N') ADVANCE(1349);
      END_STATE();
    case 1250:
      if (lookahead == 'T') ADVANCE(1350);
      END_STATE();
    case 1251:
      ACCEPT_TOKEN(sym_procedure_keyword);
      END_STATE();
    case 1252:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1351);
      END_STATE();
    case 1253:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1352);
      END_STATE();
    case 1254:
      ACCEPT_TOKEN(aux_sym_area_section_token5);
      END_STATE();
    case 1255:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1353);
      END_STATE();
    case 1256:
      ACCEPT_TOKEN(sym_protected_keyword);
      END_STATE();
    case 1257:
      if (lookahead == 'm') ADVANCE(1354);
      END_STATE();
    case 1258:
      if (lookahead == 's') ADVANCE(1355);
      END_STATE();
    case 1259:
      if (lookahead == 'm') ADVANCE(1356);
      END_STATE();
    case 1260:
      if (lookahead == 's') ADVANCE(1357);
      END_STATE();
    case 1261:
      if (lookahead == 'n') ADVANCE(1358);
      END_STATE();
    case 1262:
      if (lookahead == 't') ADVANCE(1359);
      END_STATE();
    case 1263:
      if (lookahead == 't') ADVANCE(1360);
      END_STATE();
    case 1264:
      if (lookahead == 'E') ADVANCE(1361);
      END_STATE();
    case 1265:
      ACCEPT_TOKEN(aux_sym_action_area_section_token1);
      END_STATE();
    case 1266:
      ACCEPT_TOKEN(aux_sym_basic_type_token18);
      END_STATE();
    case 1267:
      ACCEPT_TOKEN(sym_rendering_keyword);
      END_STATE();
    case 1268:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1362);
      END_STATE();
    case 1269:
      if (lookahead == 'e') ADVANCE(1363);
      END_STATE();
    case 1270:
      if (lookahead == 'e') ADVANCE(1364);
      END_STATE();
    case 1271:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1365);
      END_STATE();
    case 1272:
      if (lookahead == 'N') ADVANCE(1366);
      END_STATE();
    case 1273:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1367);
      END_STATE();
    case 1274:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1368);
      END_STATE();
    case 1275:
      ACCEPT_TOKEN(aux_sym_tabledata_permission_token1);
      END_STATE();
    case 1276:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1369);
      END_STATE();
    case 1277:
      if (lookahead == 'n') ADVANCE(1370);
      END_STATE();
    case 1278:
      if (lookahead == 'n') ADVANCE(1371);
      END_STATE();
    case 1279:
      ACCEPT_TOKEN(sym_temporary_keyword);
      END_STATE();
    case 1280:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1372);
      END_STATE();
    case 1281:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1373);
      END_STATE();
    case 1282:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1374);
      END_STATE();
    case 1283:
      ACCEPT_TOKEN(aux_sym_basic_type_token8);
      END_STATE();
    case 1284:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1375);
      END_STATE();
    case 1285:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1376);
      END_STATE();
    case 1286:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1377);
      END_STATE();
    case 1287:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1378);
      END_STATE();
    case 1288:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1379);
      END_STATE();
    case 1289:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1380);
      END_STATE();
    case 1290:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1381);
      END_STATE();
    case 1291:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1382);
      END_STATE();
    case 1292:
      if (lookahead == 'd') ADVANCE(1383);
      END_STATE();
    case 1293:
      if (lookahead == 'd') ADVANCE(1384);
      END_STATE();
    case 1294:
      if (lookahead == 's') ADVANCE(1385);
      END_STATE();
    case 1295:
      if (lookahead == 's') ADVANCE(1386);
      END_STATE();
    case 1296:
      if (lookahead == 'm') ADVANCE(1387);
      END_STATE();
    case 1297:
      if (lookahead == 's') ADVANCE(1388);
      END_STATE();
    case 1298:
      if (lookahead == 'm') ADVANCE(1389);
      END_STATE();
    case 1299:
      if (lookahead == 's') ADVANCE(1390);
      END_STATE();
    case 1300:
      if (lookahead == 'n') ADVANCE(1391);
      END_STATE();
    case 1301:
      if (lookahead == 't') ADVANCE(1392);
      END_STATE();
    case 1302:
      if (lookahead == 't') ADVANCE(1393);
      END_STATE();
    case 1303:
      if (lookahead == 'e') ADVANCE(1394);
      END_STATE();
    case 1304:
      if (lookahead == 'e') ADVANCE(1395);
      END_STATE();
    case 1305:
      if (lookahead == 'n') ADVANCE(1396);
      END_STATE();
    case 1306:
      if (lookahead == 'n') ADVANCE(1397);
      END_STATE();
    case 1307:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1398);
      END_STATE();
    case 1308:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1399);
      END_STATE();
    case 1309:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1400);
      END_STATE();
    case 1310:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1401);
      END_STATE();
    case 1311:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1402);
      END_STATE();
    case 1312:
      ACCEPT_TOKEN(aux_sym_basic_type_token26);
      END_STATE();
    case 1313:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1403);
      END_STATE();
    case 1314:
      ACCEPT_TOKEN(aux_sym_basic_type_token24);
      END_STATE();
    case 1315:
      ACCEPT_TOKEN(aux_sym_basic_type_token25);
      END_STATE();
    case 1316:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1404);
      END_STATE();
    case 1317:
      ACCEPT_TOKEN(aux_sym_separator_action_token1);
      END_STATE();
    case 1318:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1405);
      END_STATE();
    case 1319:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1406);
      END_STATE();
    case 1320:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1407);
      END_STATE();
    case 1321:
      ACCEPT_TOKEN(aux_sym_basic_type_token51);
      END_STATE();
    case 1322:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1408);
      END_STATE();
    case 1323:
      ACCEPT_TOKEN(aux_sym_basic_type_token2);
      END_STATE();
    case 1324:
      if (lookahead == 'I') ADVANCE(1409);
      END_STATE();
    case 1325:
      if (lookahead == 'I') ADVANCE(1410);
      if (lookahead == 'i') ADVANCE(1411);
      END_STATE();
    case 1326:
      if (lookahead == 'i') ADVANCE(1412);
      END_STATE();
    case 1327:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1413);
      END_STATE();
    case 1328:
      ACCEPT_TOKEN(sym_customizes_keyword);
      END_STATE();
    case 1329:
      ACCEPT_TOKEN(aux_sym_dictionary_type_token1);
      END_STATE();
    case 1330:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1414);
      END_STATE();
    case 1331:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1415);
      END_STATE();
    case 1332:
      ACCEPT_TOKEN(aux_sym_order_by_item_token2);
      END_STATE();
    case 1333:
      if (lookahead == 'I') ADVANCE(1416);
      END_STATE();
    case 1334:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1417);
      END_STATE();
    case 1335:
      if (lookahead == 'i') ADVANCE(1418);
      END_STATE();
    case 1336:
      if (lookahead == 'i') ADVANCE(1419);
      END_STATE();
    case 1337:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1420);
      END_STATE();
    case 1338:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1421);
      END_STATE();
    case 1339:
      ACCEPT_TOKEN(sym_fieldgroup_keyword);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1422);
      END_STATE();
    case 1340:
      ACCEPT_TOKEN(aux_sym_basic_type_token49);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1423);
      END_STATE();
    case 1341:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1424);
      END_STATE();
    case 1342:
      ACCEPT_TOKEN(sym_implements_keyword);
      END_STATE();
    case 1343:
      ACCEPT_TOKEN(aux_sym_basic_type_token50);
      END_STATE();
    case 1344:
      ACCEPT_TOKEN(aux_sym_movebefore_modification_token1);
      END_STATE();
    case 1345:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1425);
      END_STATE();
    case 1346:
      ACCEPT_TOKEN(aux_sym_action_area_section_token2);
      END_STATE();
    case 1347:
      if (lookahead == 'I') ADVANCE(1426);
      END_STATE();
    case 1348:
      if (lookahead == 'I') ADVANCE(1427);
      END_STATE();
    case 1349:
      if (lookahead == 'S') ADVANCE(1428);
      END_STATE();
    case 1350:
      if (lookahead == 'E') ADVANCE(1429);
      END_STATE();
    case 1351:
      ACCEPT_TOKEN(aux_sym_area_section_token3);
      END_STATE();
    case 1352:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1430);
      END_STATE();
    case 1353:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1431);
      END_STATE();
    case 1354:
      if (lookahead == 'i') ADVANCE(1432);
      END_STATE();
    case 1355:
      if (lookahead == 'i') ADVANCE(1433);
      END_STATE();
    case 1356:
      if (lookahead == 'i') ADVANCE(1434);
      END_STATE();
    case 1357:
      if (lookahead == 'i') ADVANCE(1435);
      END_STATE();
    case 1358:
      if (lookahead == 'S') ADVANCE(1436);
      if (lookahead == 's') ADVANCE(1437);
      END_STATE();
    case 1359:
      if (lookahead == 'e') ADVANCE(1438);
      END_STATE();
    case 1360:
      if (lookahead == 'e') ADVANCE(1439);
      END_STATE();
    case 1361:
      if (lookahead == 'N') ADVANCE(1440);
      END_STATE();
    case 1362:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1441);
      END_STATE();
    case 1363:
      if (lookahead == 'n') ADVANCE(1442);
      END_STATE();
    case 1364:
      if (lookahead == 'n') ADVANCE(1443);
      END_STATE();
    case 1365:
      ACCEPT_TOKEN(aux_sym_area_section_token4);
      END_STATE();
    case 1366:
      if (lookahead == 'S') ADVANCE(1444);
      END_STATE();
    case 1367:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1445);
      END_STATE();
    case 1368:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1446);
      END_STATE();
    case 1369:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1447);
      END_STATE();
    case 1370:
      if (lookahead == 's') ADVANCE(1448);
      END_STATE();
    case 1371:
      if (lookahead == 's') ADVANCE(1449);
      END_STATE();
    case 1372:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1450);
      END_STATE();
    case 1373:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1451);
      END_STATE();
    case 1374:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1452);
      END_STATE();
    case 1375:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1453);
      END_STATE();
    case 1376:
      ACCEPT_TOKEN(aux_sym_where_condition_token2);
      END_STATE();
    case 1377:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1454);
      END_STATE();
    case 1378:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1455);
      END_STATE();
    case 1379:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1456);
      END_STATE();
    case 1380:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1457);
      END_STATE();
    case 1381:
      ACCEPT_TOKEN(aux_sym_basic_type_token42);
      END_STATE();
    case 1382:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1458);
      END_STATE();
    case 1383:
      if (lookahead == 'I') ADVANCE(1459);
      if (lookahead == 'i') ADVANCE(1460);
      END_STATE();
    case 1384:
      if (lookahead == 'i') ADVANCE(1461);
      END_STATE();
    case 1385:
      if (lookahead == 'i') ADVANCE(1462);
      END_STATE();
    case 1386:
      if (lookahead == 'i') ADVANCE(1463);
      END_STATE();
    case 1387:
      if (lookahead == 'i') ADVANCE(1464);
      END_STATE();
    case 1388:
      if (lookahead == 'i') ADVANCE(1465);
      END_STATE();
    case 1389:
      if (lookahead == 'i') ADVANCE(1466);
      END_STATE();
    case 1390:
      if (lookahead == 'i') ADVANCE(1467);
      END_STATE();
    case 1391:
      if (lookahead == 'S') ADVANCE(1468);
      if (lookahead == 's') ADVANCE(1469);
      END_STATE();
    case 1392:
      if (lookahead == 'e') ADVANCE(1470);
      END_STATE();
    case 1393:
      if (lookahead == 'e') ADVANCE(1471);
      END_STATE();
    case 1394:
      if (lookahead == 'n') ADVANCE(1472);
      END_STATE();
    case 1395:
      if (lookahead == 'n') ADVANCE(1473);
      END_STATE();
    case 1396:
      if (lookahead == 's') ADVANCE(1474);
      END_STATE();
    case 1397:
      if (lookahead == 's') ADVANCE(1475);
      END_STATE();
    case 1398:
      ACCEPT_TOKEN(aux_sym_basic_type_token32);
      END_STATE();
    case 1399:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1476);
      END_STATE();
    case 1400:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1477);
      END_STATE();
    case 1401:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1478);
      END_STATE();
    case 1402:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1479);
      END_STATE();
    case 1403:
      ACCEPT_TOKEN(aux_sym_basic_type_token27);
      END_STATE();
    case 1404:
      ACCEPT_TOKEN(aux_sym_basic_type_token23);
      END_STATE();
    case 1405:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1480);
      END_STATE();
    case 1406:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1481);
      END_STATE();
    case 1407:
      ACCEPT_TOKEN(sym_systempart_keyword);
      END_STATE();
    case 1408:
      ACCEPT_TOKEN(sym_asserterror_keyword);
      END_STATE();
    case 1409:
      if (lookahead == 'N') ADVANCE(1482);
      END_STATE();
    case 1410:
      if (lookahead == 'n') ADVANCE(1483);
      END_STATE();
    case 1411:
      if (lookahead == 'n') ADVANCE(1484);
      END_STATE();
    case 1412:
      if (lookahead == 'n') ADVANCE(1485);
      END_STATE();
    case 1413:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1486);
      END_STATE();
    case 1414:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1487);
      END_STATE();
    case 1415:
      ACCEPT_TOKEN(aux_sym_basic_type_token13);
      END_STATE();
    case 1416:
      if (lookahead == 'O') ADVANCE(1488);
      END_STATE();
    case 1417:
      ACCEPT_TOKEN(sym_entitlement_keyword);
      END_STATE();
    case 1418:
      if (lookahead == 'o') ADVANCE(1489);
      END_STATE();
    case 1419:
      if (lookahead == 'o') ADVANCE(1490);
      END_STATE();
    case 1420:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1491);
      END_STATE();
    case 1421:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1492);
      END_STATE();
    case 1422:
      ACCEPT_TOKEN(sym_fieldgroups_keyword);
      END_STATE();
    case 1423:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1493);
      END_STATE();
    case 1424:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1494);
      END_STATE();
    case 1425:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1495);
      END_STATE();
    case 1426:
      if (lookahead == 'Z') ADVANCE(1496);
      END_STATE();
    case 1427:
      if (lookahead == 'O') ADVANCE(1497);
      END_STATE();
    case 1428:
      if (lookahead == 'E') ADVANCE(1498);
      END_STATE();
    case 1429:
      if (lookahead == 'N') ADVANCE(1499);
      END_STATE();
    case 1430:
      ACCEPT_TOKEN(aux_sym_action_area_section_token7);
      END_STATE();
    case 1431:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1500);
      END_STATE();
    case 1432:
      if (lookahead == 'z') ADVANCE(1501);
      END_STATE();
    case 1433:
      if (lookahead == 'o') ADVANCE(1502);
      END_STATE();
    case 1434:
      if (lookahead == 'z') ADVANCE(1503);
      END_STATE();
    case 1435:
      if (lookahead == 'o') ADVANCE(1504);
      END_STATE();
    case 1436:
      if (lookahead == 'e') ADVANCE(1505);
      END_STATE();
    case 1437:
      if (lookahead == 'e') ADVANCE(1506);
      END_STATE();
    case 1438:
      if (lookahead == 'n') ADVANCE(1507);
      END_STATE();
    case 1439:
      if (lookahead == 'n') ADVANCE(1508);
      END_STATE();
    case 1440:
      if (lookahead == 'S') ADVANCE(1509);
      END_STATE();
    case 1441:
      ACCEPT_TOKEN(sym_requestpage_keyword);
      END_STATE();
    case 1442:
      if (lookahead == 's') ADVANCE(1510);
      END_STATE();
    case 1443:
      if (lookahead == 's') ADVANCE(1511);
      END_STATE();
    case 1444:
      if (lookahead == 'I') ADVANCE(1512);
      END_STATE();
    case 1445:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1513);
      END_STATE();
    case 1446:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1514);
      END_STATE();
    case 1447:
      ACCEPT_TOKEN(aux_sym_basic_type_token39);
      END_STATE();
    case 1448:
      if (lookahead == 'i') ADVANCE(1515);
      END_STATE();
    case 1449:
      if (lookahead == 'i') ADVANCE(1516);
      END_STATE();
    case 1450:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1517);
      END_STATE();
    case 1451:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1518);
      END_STATE();
    case 1452:
      ACCEPT_TOKEN(aux_sym_basic_type_token7);
      END_STATE();
    case 1453:
      ACCEPT_TOKEN(aux_sym_xmlport_element_token3);
      END_STATE();
    case 1454:
      ACCEPT_TOKEN(sym_usercontrol_keyword);
      END_STATE();
    case 1455:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1519);
      END_STATE();
    case 1456:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1520);
      END_STATE();
    case 1457:
      ACCEPT_TOKEN(aux_sym_basic_type_token41);
      END_STATE();
    case 1458:
      ACCEPT_TOKEN(aux_sym_basic_type_token44);
      END_STATE();
    case 1459:
      if (lookahead == 'n') ADVANCE(1521);
      END_STATE();
    case 1460:
      if (lookahead == 'n') ADVANCE(1522);
      END_STATE();
    case 1461:
      if (lookahead == 'n') ADVANCE(1523);
      END_STATE();
    case 1462:
      if (lookahead == 'o') ADVANCE(1524);
      END_STATE();
    case 1463:
      if (lookahead == 'o') ADVANCE(1525);
      END_STATE();
    case 1464:
      if (lookahead == 'z') ADVANCE(1526);
      END_STATE();
    case 1465:
      if (lookahead == 'o') ADVANCE(1527);
      END_STATE();
    case 1466:
      if (lookahead == 'z') ADVANCE(1528);
      END_STATE();
    case 1467:
      if (lookahead == 'o') ADVANCE(1529);
      END_STATE();
    case 1468:
      if (lookahead == 'e') ADVANCE(1530);
      END_STATE();
    case 1469:
      if (lookahead == 'e') ADVANCE(1531);
      END_STATE();
    case 1470:
      if (lookahead == 'n') ADVANCE(1532);
      END_STATE();
    case 1471:
      if (lookahead == 'n') ADVANCE(1533);
      END_STATE();
    case 1472:
      if (lookahead == 's') ADVANCE(1534);
      END_STATE();
    case 1473:
      if (lookahead == 's') ADVANCE(1535);
      END_STATE();
    case 1474:
      if (lookahead == 'i') ADVANCE(1536);
      END_STATE();
    case 1475:
      if (lookahead == 'i') ADVANCE(1537);
      END_STATE();
    case 1476:
      ACCEPT_TOKEN(aux_sym_basic_type_token33);
      END_STATE();
    case 1477:
      ACCEPT_TOKEN(aux_sym_basic_type_token34);
      END_STATE();
    case 1478:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1538);
      END_STATE();
    case 1479:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1539);
      END_STATE();
    case 1480:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1540);
      END_STATE();
    case 1481:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1541);
      END_STATE();
    case 1482:
      ACCEPT_TOKEN(anon_sym_CONTROLADDIN);
      END_STATE();
    case 1483:
      ACCEPT_TOKEN(anon_sym_ControlAddIn);
      END_STATE();
    case 1484:
      ACCEPT_TOKEN(anon_sym_ControlAddin);
      END_STATE();
    case 1485:
      ACCEPT_TOKEN(anon_sym_Controladdin);
      END_STATE();
    case 1486:
      ACCEPT_TOKEN(aux_sym_customaction_declaration_token1);
      END_STATE();
    case 1487:
      ACCEPT_TOKEN(aux_sym_basic_type_token52);
      END_STATE();
    case 1488:
      if (lookahead == 'N') ADVANCE(1542);
      END_STATE();
    case 1489:
      if (lookahead == 'n') ADVANCE(1543);
      END_STATE();
    case 1490:
      if (lookahead == 'n') ADVANCE(1544);
      END_STATE();
    case 1491:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1545);
      END_STATE();
    case 1492:
      ACCEPT_TOKEN(aux_sym_xmlport_element_token2);
      END_STATE();
    case 1493:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1546);
      END_STATE();
    case 1494:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1547);
      END_STATE();
    case 1495:
      ACCEPT_TOKEN(aux_sym_basic_type_token37);
      END_STATE();
    case 1496:
      if (lookahead == 'A') ADVANCE(1548);
      END_STATE();
    case 1497:
      if (lookahead == 'N') ADVANCE(1549);
      END_STATE();
    case 1498:
      if (lookahead == 'T') ADVANCE(1550);
      END_STATE();
    case 1499:
      if (lookahead == 'S') ADVANCE(1551);
      END_STATE();
    case 1500:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1552);
      END_STATE();
    case 1501:
      if (lookahead == 'a') ADVANCE(1553);
      END_STATE();
    case 1502:
      if (lookahead == 'n') ADVANCE(1554);
      END_STATE();
    case 1503:
      if (lookahead == 'a') ADVANCE(1555);
      END_STATE();
    case 1504:
      if (lookahead == 'n') ADVANCE(1556);
      END_STATE();
    case 1505:
      if (lookahead == 't') ADVANCE(1557);
      END_STATE();
    case 1506:
      if (lookahead == 't') ADVANCE(1558);
      END_STATE();
    case 1507:
      if (lookahead == 's') ADVANCE(1559);
      END_STATE();
    case 1508:
      if (lookahead == 's') ADVANCE(1560);
      END_STATE();
    case 1509:
      if (lookahead == 'I') ADVANCE(1561);
      END_STATE();
    case 1510:
      if (lookahead == 'i') ADVANCE(1562);
      END_STATE();
    case 1511:
      if (lookahead == 'i') ADVANCE(1563);
      END_STATE();
    case 1512:
      if (lookahead == 'O') ADVANCE(1564);
      END_STATE();
    case 1513:
      ACCEPT_TOKEN(aux_sym_xmlport_element_token1);
      END_STATE();
    case 1514:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1565);
      END_STATE();
    case 1515:
      if (lookahead == 'o') ADVANCE(1566);
      END_STATE();
    case 1516:
      if (lookahead == 'o') ADVANCE(1567);
      END_STATE();
    case 1517:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1568);
      END_STATE();
    case 1518:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1569);
      END_STATE();
    case 1519:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1570);
      END_STATE();
    case 1520:
      ACCEPT_TOKEN(aux_sym_basic_type_token45);
      END_STATE();
    case 1521:
      ACCEPT_TOKEN(anon_sym_controlAddIn);
      END_STATE();
    case 1522:
      ACCEPT_TOKEN(anon_sym_controlAddin);
      END_STATE();
    case 1523:
      ACCEPT_TOKEN(anon_sym_controladdin);
      END_STATE();
    case 1524:
      if (lookahead == 'n') ADVANCE(1571);
      END_STATE();
    case 1525:
      if (lookahead == 'n') ADVANCE(1572);
      END_STATE();
    case 1526:
      if (lookahead == 'a') ADVANCE(1573);
      END_STATE();
    case 1527:
      if (lookahead == 'n') ADVANCE(1574);
      END_STATE();
    case 1528:
      if (lookahead == 'a') ADVANCE(1575);
      END_STATE();
    case 1529:
      if (lookahead == 'n') ADVANCE(1576);
      END_STATE();
    case 1530:
      if (lookahead == 't') ADVANCE(1577);
      END_STATE();
    case 1531:
      if (lookahead == 't') ADVANCE(1578);
      END_STATE();
    case 1532:
      if (lookahead == 's') ADVANCE(1579);
      END_STATE();
    case 1533:
      if (lookahead == 's') ADVANCE(1580);
      END_STATE();
    case 1534:
      if (lookahead == 'i') ADVANCE(1581);
      END_STATE();
    case 1535:
      if (lookahead == 'i') ADVANCE(1582);
      END_STATE();
    case 1536:
      if (lookahead == 'o') ADVANCE(1583);
      END_STATE();
    case 1537:
      if (lookahead == 'o') ADVANCE(1584);
      END_STATE();
    case 1538:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1585);
      END_STATE();
    case 1539:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1586);
      END_STATE();
    case 1540:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1587);
      END_STATE();
    case 1541:
      ACCEPT_TOKEN(aux_sym_systemaction_declaration_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1588);
      END_STATE();
    case 1542:
      ACCEPT_TOKEN(anon_sym_ENUMEXTENSION);
      END_STATE();
    case 1543:
      ACCEPT_TOKEN(anon_sym_EnumExtension);
      END_STATE();
    case 1544:
      ACCEPT_TOKEN(anon_sym_Enumextension);
      END_STATE();
    case 1545:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1589);
      END_STATE();
    case 1546:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1590);
      END_STATE();
    case 1547:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1591);
      END_STATE();
    case 1548:
      if (lookahead == 'T') ADVANCE(1592);
      END_STATE();
    case 1549:
      ACCEPT_TOKEN(anon_sym_PAGEEXTENSION);
      END_STATE();
    case 1550:
      ACCEPT_TOKEN(anon_sym_PERMISSIONSET);
      if (lookahead == 'E') ADVANCE(1593);
      END_STATE();
    case 1551:
      if (lookahead == 'I') ADVANCE(1594);
      END_STATE();
    case 1552:
      ACCEPT_TOKEN(aux_sym_area_section_token7);
      END_STATE();
    case 1553:
      if (lookahead == 't') ADVANCE(1595);
      END_STATE();
    case 1554:
      ACCEPT_TOKEN(anon_sym_PageExtension);
      END_STATE();
    case 1555:
      if (lookahead == 't') ADVANCE(1596);
      END_STATE();
    case 1556:
      ACCEPT_TOKEN(anon_sym_Pageextension);
      END_STATE();
    case 1557:
      ACCEPT_TOKEN(anon_sym_PermissionSet);
      if (lookahead == 'E') ADVANCE(1597);
      END_STATE();
    case 1558:
      ACCEPT_TOKEN(anon_sym_Permissionset);
      if (lookahead == 'e') ADVANCE(1598);
      END_STATE();
    case 1559:
      if (lookahead == 'i') ADVANCE(1599);
      END_STATE();
    case 1560:
      if (lookahead == 'i') ADVANCE(1600);
      END_STATE();
    case 1561:
      if (lookahead == 'O') ADVANCE(1601);
      END_STATE();
    case 1562:
      if (lookahead == 'o') ADVANCE(1602);
      END_STATE();
    case 1563:
      if (lookahead == 'o') ADVANCE(1603);
      END_STATE();
    case 1564:
      if (lookahead == 'N') ADVANCE(1604);
      END_STATE();
    case 1565:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1605);
      END_STATE();
    case 1566:
      if (lookahead == 'n') ADVANCE(1606);
      END_STATE();
    case 1567:
      if (lookahead == 'n') ADVANCE(1607);
      END_STATE();
    case 1568:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1608);
      END_STATE();
    case 1569:
      ACCEPT_TOKEN(aux_sym_xmlport_attribute_token2);
      END_STATE();
    case 1570:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1609);
      END_STATE();
    case 1571:
      ACCEPT_TOKEN(anon_sym_enumExtension);
      END_STATE();
    case 1572:
      ACCEPT_TOKEN(anon_sym_enumextension);
      END_STATE();
    case 1573:
      if (lookahead == 't') ADVANCE(1610);
      END_STATE();
    case 1574:
      ACCEPT_TOKEN(anon_sym_pageExtension);
      END_STATE();
    case 1575:
      if (lookahead == 't') ADVANCE(1611);
      END_STATE();
    case 1576:
      ACCEPT_TOKEN(anon_sym_pageextension);
      END_STATE();
    case 1577:
      ACCEPT_TOKEN(anon_sym_permissionSet);
      if (lookahead == 'E') ADVANCE(1612);
      END_STATE();
    case 1578:
      ACCEPT_TOKEN(anon_sym_permissionset);
      if (lookahead == 'e') ADVANCE(1613);
      END_STATE();
    case 1579:
      if (lookahead == 'i') ADVANCE(1614);
      END_STATE();
    case 1580:
      if (lookahead == 'i') ADVANCE(1615);
      END_STATE();
    case 1581:
      if (lookahead == 'o') ADVANCE(1616);
      END_STATE();
    case 1582:
      if (lookahead == 'o') ADVANCE(1617);
      END_STATE();
    case 1583:
      if (lookahead == 'n') ADVANCE(1618);
      END_STATE();
    case 1584:
      if (lookahead == 'n') ADVANCE(1619);
      END_STATE();
    case 1585:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1620);
      END_STATE();
    case 1586:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1621);
      END_STATE();
    case 1587:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1622);
      END_STATE();
    case 1588:
      ACCEPT_TOKEN(aux_sym_area_section_token8);
      END_STATE();
    case 1589:
      ACCEPT_TOKEN(aux_sym_xmlport_attribute_token1);
      END_STATE();
    case 1590:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1623);
      END_STATE();
    case 1591:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1624);
      END_STATE();
    case 1592:
      if (lookahead == 'I') ADVANCE(1625);
      END_STATE();
    case 1593:
      if (lookahead == 'X') ADVANCE(1626);
      END_STATE();
    case 1594:
      if (lookahead == 'O') ADVANCE(1627);
      END_STATE();
    case 1595:
      if (lookahead == 'i') ADVANCE(1628);
      END_STATE();
    case 1596:
      if (lookahead == 'i') ADVANCE(1629);
      END_STATE();
    case 1597:
      if (lookahead == 'x') ADVANCE(1630);
      END_STATE();
    case 1598:
      if (lookahead == 'x') ADVANCE(1631);
      END_STATE();
    case 1599:
      if (lookahead == 'o') ADVANCE(1632);
      END_STATE();
    case 1600:
      if (lookahead == 'o') ADVANCE(1633);
      END_STATE();
    case 1601:
      if (lookahead == 'N') ADVANCE(1634);
      END_STATE();
    case 1602:
      if (lookahead == 'n') ADVANCE(1635);
      END_STATE();
    case 1603:
      if (lookahead == 'n') ADVANCE(1636);
      END_STATE();
    case 1604:
      ACCEPT_TOKEN(anon_sym_TABLEEXTENSION);
      END_STATE();
    case 1605:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1637);
      END_STATE();
    case 1606:
      ACCEPT_TOKEN(anon_sym_TableExtension);
      END_STATE();
    case 1607:
      ACCEPT_TOKEN(anon_sym_Tableextension);
      END_STATE();
    case 1608:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1638);
      END_STATE();
    case 1609:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1639);
      END_STATE();
    case 1610:
      if (lookahead == 'i') ADVANCE(1640);
      END_STATE();
    case 1611:
      if (lookahead == 'i') ADVANCE(1641);
      END_STATE();
    case 1612:
      if (lookahead == 'x') ADVANCE(1642);
      END_STATE();
    case 1613:
      if (lookahead == 'x') ADVANCE(1643);
      END_STATE();
    case 1614:
      if (lookahead == 'o') ADVANCE(1644);
      END_STATE();
    case 1615:
      if (lookahead == 'o') ADVANCE(1645);
      END_STATE();
    case 1616:
      if (lookahead == 'n') ADVANCE(1646);
      END_STATE();
    case 1617:
      if (lookahead == 'n') ADVANCE(1647);
      END_STATE();
    case 1618:
      ACCEPT_TOKEN(anon_sym_tableExtension);
      END_STATE();
    case 1619:
      ACCEPT_TOKEN(anon_sym_tableextension);
      END_STATE();
    case 1620:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1648);
      END_STATE();
    case 1621:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1649);
      END_STATE();
    case 1622:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1650);
      END_STATE();
    case 1623:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1651);
      END_STATE();
    case 1624:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1652);
      END_STATE();
    case 1625:
      if (lookahead == 'O') ADVANCE(1653);
      END_STATE();
    case 1626:
      if (lookahead == 'T') ADVANCE(1654);
      END_STATE();
    case 1627:
      if (lookahead == 'N') ADVANCE(1655);
      END_STATE();
    case 1628:
      if (lookahead == 'o') ADVANCE(1656);
      END_STATE();
    case 1629:
      if (lookahead == 'o') ADVANCE(1657);
      END_STATE();
    case 1630:
      if (lookahead == 't') ADVANCE(1658);
      END_STATE();
    case 1631:
      if (lookahead == 't') ADVANCE(1659);
      END_STATE();
    case 1632:
      if (lookahead == 'n') ADVANCE(1660);
      END_STATE();
    case 1633:
      if (lookahead == 'n') ADVANCE(1661);
      END_STATE();
    case 1634:
      ACCEPT_TOKEN(anon_sym_REPORTEXTENSION);
      END_STATE();
    case 1635:
      ACCEPT_TOKEN(anon_sym_ReportExtension);
      END_STATE();
    case 1636:
      ACCEPT_TOKEN(anon_sym_Reportextension);
      END_STATE();
    case 1637:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1662);
      END_STATE();
    case 1638:
      ACCEPT_TOKEN(aux_sym_object_reference_type_token2);
      END_STATE();
    case 1639:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1663);
      END_STATE();
    case 1640:
      if (lookahead == 'o') ADVANCE(1664);
      END_STATE();
    case 1641:
      if (lookahead == 'o') ADVANCE(1665);
      END_STATE();
    case 1642:
      if (lookahead == 't') ADVANCE(1666);
      END_STATE();
    case 1643:
      if (lookahead == 't') ADVANCE(1667);
      END_STATE();
    case 1644:
      if (lookahead == 'n') ADVANCE(1668);
      END_STATE();
    case 1645:
      if (lookahead == 'n') ADVANCE(1669);
      END_STATE();
    case 1646:
      ACCEPT_TOKEN(anon_sym_reportExtension);
      END_STATE();
    case 1647:
      ACCEPT_TOKEN(anon_sym_reportextension);
      END_STATE();
    case 1648:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1670);
      END_STATE();
    case 1649:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1671);
      END_STATE();
    case 1650:
      ACCEPT_TOKEN(aux_sym_basic_type_token47);
      END_STATE();
    case 1651:
      ACCEPT_TOKEN(aux_sym_fileuploadaction_declaration_token1);
      END_STATE();
    case 1652:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1672);
      END_STATE();
    case 1653:
      if (lookahead == 'N') ADVANCE(1673);
      END_STATE();
    case 1654:
      if (lookahead == 'E') ADVANCE(1674);
      END_STATE();
    case 1655:
      ACCEPT_TOKEN(anon_sym_PROFILEEXTENSION);
      END_STATE();
    case 1656:
      if (lookahead == 'n') ADVANCE(1675);
      END_STATE();
    case 1657:
      if (lookahead == 'n') ADVANCE(1676);
      END_STATE();
    case 1658:
      if (lookahead == 'e') ADVANCE(1677);
      END_STATE();
    case 1659:
      if (lookahead == 'e') ADVANCE(1678);
      END_STATE();
    case 1660:
      ACCEPT_TOKEN(anon_sym_ProfileExtension);
      END_STATE();
    case 1661:
      ACCEPT_TOKEN(anon_sym_Profileextension);
      END_STATE();
    case 1662:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1679);
      END_STATE();
    case 1663:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1680);
      END_STATE();
    case 1664:
      if (lookahead == 'n') ADVANCE(1681);
      END_STATE();
    case 1665:
      if (lookahead == 'n') ADVANCE(1682);
      END_STATE();
    case 1666:
      if (lookahead == 'e') ADVANCE(1683);
      END_STATE();
    case 1667:
      if (lookahead == 'e') ADVANCE(1684);
      END_STATE();
    case 1668:
      ACCEPT_TOKEN(anon_sym_profileExtension);
      END_STATE();
    case 1669:
      ACCEPT_TOKEN(anon_sym_profileextension);
      END_STATE();
    case 1670:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1685);
      END_STATE();
    case 1671:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1686);
      END_STATE();
    case 1672:
      ACCEPT_TOKEN(aux_sym_basic_type_token38);
      END_STATE();
    case 1673:
      ACCEPT_TOKEN(anon_sym_PAGECUSTOMIZATION);
      END_STATE();
    case 1674:
      if (lookahead == 'N') ADVANCE(1687);
      END_STATE();
    case 1675:
      ACCEPT_TOKEN(anon_sym_PageCustomization);
      END_STATE();
    case 1676:
      ACCEPT_TOKEN(anon_sym_Pagecustomization);
      END_STATE();
    case 1677:
      if (lookahead == 'n') ADVANCE(1688);
      END_STATE();
    case 1678:
      if (lookahead == 'n') ADVANCE(1689);
      END_STATE();
    case 1679:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1690);
      END_STATE();
    case 1680:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1691);
      END_STATE();
    case 1681:
      ACCEPT_TOKEN(anon_sym_pageCustomization);
      END_STATE();
    case 1682:
      ACCEPT_TOKEN(anon_sym_pagecustomization);
      END_STATE();
    case 1683:
      if (lookahead == 'n') ADVANCE(1692);
      END_STATE();
    case 1684:
      if (lookahead == 'n') ADVANCE(1693);
      END_STATE();
    case 1685:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1694);
      END_STATE();
    case 1686:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1695);
      END_STATE();
    case 1687:
      if (lookahead == 'S') ADVANCE(1696);
      END_STATE();
    case 1688:
      if (lookahead == 's') ADVANCE(1697);
      END_STATE();
    case 1689:
      if (lookahead == 's') ADVANCE(1698);
      END_STATE();
    case 1690:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1699);
      END_STATE();
    case 1691:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1700);
      END_STATE();
    case 1692:
      if (lookahead == 's') ADVANCE(1701);
      END_STATE();
    case 1693:
      if (lookahead == 's') ADVANCE(1702);
      END_STATE();
    case 1694:
      ACCEPT_TOKEN(aux_sym_basic_type_token35);
      END_STATE();
    case 1695:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1703);
      END_STATE();
    case 1696:
      if (lookahead == 'I') ADVANCE(1704);
      END_STATE();
    case 1697:
      if (lookahead == 'i') ADVANCE(1705);
      END_STATE();
    case 1698:
      if (lookahead == 'i') ADVANCE(1706);
      END_STATE();
    case 1699:
      ACCEPT_TOKEN(aux_sym_basic_type_token40);
      END_STATE();
    case 1700:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1707);
      END_STATE();
    case 1701:
      if (lookahead == 'i') ADVANCE(1708);
      END_STATE();
    case 1702:
      if (lookahead == 'i') ADVANCE(1709);
      END_STATE();
    case 1703:
      ACCEPT_TOKEN(aux_sym_basic_type_token36);
      END_STATE();
    case 1704:
      if (lookahead == 'O') ADVANCE(1710);
      END_STATE();
    case 1705:
      if (lookahead == 'o') ADVANCE(1711);
      END_STATE();
    case 1706:
      if (lookahead == 'o') ADVANCE(1712);
      END_STATE();
    case 1707:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1713);
      END_STATE();
    case 1708:
      if (lookahead == 'o') ADVANCE(1714);
      END_STATE();
    case 1709:
      if (lookahead == 'o') ADVANCE(1715);
      END_STATE();
    case 1710:
      if (lookahead == 'N') ADVANCE(1716);
      END_STATE();
    case 1711:
      if (lookahead == 'n') ADVANCE(1717);
      END_STATE();
    case 1712:
      if (lookahead == 'n') ADVANCE(1718);
      END_STATE();
    case 1713:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1719);
      END_STATE();
    case 1714:
      if (lookahead == 'n') ADVANCE(1720);
      END_STATE();
    case 1715:
      if (lookahead == 'n') ADVANCE(1721);
      END_STATE();
    case 1716:
      ACCEPT_TOKEN(anon_sym_PERMISSIONSETEXTENSION);
      END_STATE();
    case 1717:
      ACCEPT_TOKEN(anon_sym_PermissionSetExtension);
      END_STATE();
    case 1718:
      ACCEPT_TOKEN(anon_sym_Permissionsetextension);
      END_STATE();
    case 1719:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1722);
      END_STATE();
    case 1720:
      ACCEPT_TOKEN(anon_sym_permissionSetExtension);
      END_STATE();
    case 1721:
      ACCEPT_TOKEN(anon_sym_permissionsetextension);
      END_STATE();
    case 1722:
      ACCEPT_TOKEN(aux_sym_basic_type_token54);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 117, .external_lex_state = 2},
  [2] = {.lex_state = 117, .external_lex_state = 3},
  [3] = {.lex_state = 117, .external_lex_state = 4},
  [4] = {.lex_state = 117, .external_lex_state = 3},
  [5] = {.lex_state = 117, .external_lex_state = 3},
  [6] = {.lex_state = 117, .external_lex_state = 3},
  [7] = {.lex_state = 117, .external_lex_state = 3},
  [8] = {.lex_state = 117, .external_lex_state = 3},
  [9] = {.lex_state = 117, .external_lex_state = 3},
  [10] = {.lex_state = 117, .external_lex_state = 3},
  [11] = {.lex_state = 117, .external_lex_state = 3},
  [12] = {.lex_state = 117, .external_lex_state = 3},
  [13] = {.lex_state = 117, .external_lex_state = 3},
  [14] = {.lex_state = 117, .external_lex_state = 3},
  [15] = {.lex_state = 117, .external_lex_state = 3},
  [16] = {.lex_state = 117, .external_lex_state = 3},
  [17] = {.lex_state = 117, .external_lex_state = 3},
  [18] = {.lex_state = 117, .external_lex_state = 3},
  [19] = {.lex_state = 117, .external_lex_state = 3},
  [20] = {.lex_state = 117, .external_lex_state = 3},
  [21] = {.lex_state = 117, .external_lex_state = 3},
  [22] = {.lex_state = 117, .external_lex_state = 3},
  [23] = {.lex_state = 117, .external_lex_state = 3},
  [24] = {.lex_state = 117, .external_lex_state = 3},
  [25] = {.lex_state = 117, .external_lex_state = 3},
  [26] = {.lex_state = 117, .external_lex_state = 3},
  [27] = {.lex_state = 117, .external_lex_state = 3},
  [28] = {.lex_state = 117, .external_lex_state = 3},
  [29] = {.lex_state = 117, .external_lex_state = 3},
  [30] = {.lex_state = 117, .external_lex_state = 3},
  [31] = {.lex_state = 117, .external_lex_state = 3},
  [32] = {.lex_state = 117, .external_lex_state = 3},
  [33] = {.lex_state = 117, .external_lex_state = 3},
  [34] = {.lex_state = 117, .external_lex_state = 3},
  [35] = {.lex_state = 117, .external_lex_state = 3},
  [36] = {.lex_state = 117, .external_lex_state = 3},
  [37] = {.lex_state = 117, .external_lex_state = 3},
  [38] = {.lex_state = 117, .external_lex_state = 3},
  [39] = {.lex_state = 117, .external_lex_state = 3},
  [40] = {.lex_state = 117, .external_lex_state = 3},
  [41] = {.lex_state = 117, .external_lex_state = 3},
  [42] = {.lex_state = 117, .external_lex_state = 3},
  [43] = {.lex_state = 117, .external_lex_state = 3},
  [44] = {.lex_state = 117, .external_lex_state = 3},
  [45] = {.lex_state = 117, .external_lex_state = 3},
  [46] = {.lex_state = 117, .external_lex_state = 3},
  [47] = {.lex_state = 117, .external_lex_state = 3},
  [48] = {.lex_state = 117, .external_lex_state = 3},
  [49] = {.lex_state = 117, .external_lex_state = 3},
  [50] = {.lex_state = 117, .external_lex_state = 3},
  [51] = {.lex_state = 117, .external_lex_state = 3},
  [52] = {.lex_state = 117, .external_lex_state = 3},
  [53] = {.lex_state = 117, .external_lex_state = 3},
  [54] = {.lex_state = 117, .external_lex_state = 4},
  [55] = {.lex_state = 117, .external_lex_state = 3},
  [56] = {.lex_state = 117, .external_lex_state = 3},
  [57] = {.lex_state = 117, .external_lex_state = 3},
  [58] = {.lex_state = 117, .external_lex_state = 3},
  [59] = {.lex_state = 117, .external_lex_state = 3},
  [60] = {.lex_state = 117, .external_lex_state = 3},
  [61] = {.lex_state = 117, .external_lex_state = 3},
  [62] = {.lex_state = 117, .external_lex_state = 3},
  [63] = {.lex_state = 117, .external_lex_state = 3},
  [64] = {.lex_state = 117, .external_lex_state = 3},
  [65] = {.lex_state = 117, .external_lex_state = 3},
  [66] = {.lex_state = 117, .external_lex_state = 3},
  [67] = {.lex_state = 117, .external_lex_state = 3},
  [68] = {.lex_state = 117, .external_lex_state = 3},
  [69] = {.lex_state = 117, .external_lex_state = 3},
  [70] = {.lex_state = 117, .external_lex_state = 3},
  [71] = {.lex_state = 117, .external_lex_state = 3},
  [72] = {.lex_state = 117, .external_lex_state = 3},
  [73] = {.lex_state = 117, .external_lex_state = 3},
  [74] = {.lex_state = 117, .external_lex_state = 3},
  [75] = {.lex_state = 117, .external_lex_state = 3},
  [76] = {.lex_state = 117, .external_lex_state = 3},
  [77] = {.lex_state = 117, .external_lex_state = 3},
  [78] = {.lex_state = 117, .external_lex_state = 3},
  [79] = {.lex_state = 117, .external_lex_state = 3},
  [80] = {.lex_state = 117, .external_lex_state = 3},
  [81] = {.lex_state = 117, .external_lex_state = 3},
  [82] = {.lex_state = 117, .external_lex_state = 3},
  [83] = {.lex_state = 117, .external_lex_state = 3},
  [84] = {.lex_state = 117, .external_lex_state = 3},
  [85] = {.lex_state = 117, .external_lex_state = 3},
  [86] = {.lex_state = 117, .external_lex_state = 3},
  [87] = {.lex_state = 117, .external_lex_state = 3},
  [88] = {.lex_state = 117, .external_lex_state = 3},
  [89] = {.lex_state = 117, .external_lex_state = 3},
  [90] = {.lex_state = 117, .external_lex_state = 3},
  [91] = {.lex_state = 117, .external_lex_state = 4},
  [92] = {.lex_state = 117, .external_lex_state = 4},
  [93] = {.lex_state = 117, .external_lex_state = 4},
  [94] = {.lex_state = 117, .external_lex_state = 4},
  [95] = {.lex_state = 117, .external_lex_state = 4},
  [96] = {.lex_state = 117, .external_lex_state = 4},
  [97] = {.lex_state = 117, .external_lex_state = 4},
  [98] = {.lex_state = 117, .external_lex_state = 4},
  [99] = {.lex_state = 117, .external_lex_state = 4},
  [100] = {.lex_state = 117, .external_lex_state = 4},
  [101] = {.lex_state = 117, .external_lex_state = 4},
  [102] = {.lex_state = 117, .external_lex_state = 4},
  [103] = {.lex_state = 117, .external_lex_state = 4},
  [104] = {.lex_state = 117, .external_lex_state = 4},
  [105] = {.lex_state = 117, .external_lex_state = 4},
  [106] = {.lex_state = 117, .external_lex_state = 4},
  [107] = {.lex_state = 117, .external_lex_state = 4},
  [108] = {.lex_state = 117, .external_lex_state = 4},
  [109] = {.lex_state = 117, .external_lex_state = 4},
  [110] = {.lex_state = 117, .external_lex_state = 3},
  [111] = {.lex_state = 117, .external_lex_state = 5},
  [112] = {.lex_state = 117, .external_lex_state = 3},
  [113] = {.lex_state = 117, .external_lex_state = 5},
  [114] = {.lex_state = 117, .external_lex_state = 3},
  [115] = {.lex_state = 117, .external_lex_state = 3},
  [116] = {.lex_state = 117, .external_lex_state = 5},
  [117] = {.lex_state = 117, .external_lex_state = 3},
  [118] = {.lex_state = 117, .external_lex_state = 5},
  [119] = {.lex_state = 117, .external_lex_state = 5},
  [120] = {.lex_state = 117, .external_lex_state = 3},
  [121] = {.lex_state = 117, .external_lex_state = 5},
  [122] = {.lex_state = 117, .external_lex_state = 5},
  [123] = {.lex_state = 117, .external_lex_state = 5},
  [124] = {.lex_state = 117, .external_lex_state = 5},
  [125] = {.lex_state = 117, .external_lex_state = 5},
  [126] = {.lex_state = 117, .external_lex_state = 5},
  [127] = {.lex_state = 117, .external_lex_state = 3},
  [128] = {.lex_state = 117, .external_lex_state = 5},
  [129] = {.lex_state = 117, .external_lex_state = 6},
  [130] = {.lex_state = 117, .external_lex_state = 6},
  [131] = {.lex_state = 117, .external_lex_state = 3},
  [132] = {.lex_state = 117, .external_lex_state = 3},
  [133] = {.lex_state = 117, .external_lex_state = 3},
  [134] = {.lex_state = 117, .external_lex_state = 3},
  [135] = {.lex_state = 117, .external_lex_state = 3},
  [136] = {.lex_state = 117, .external_lex_state = 3},
  [137] = {.lex_state = 117, .external_lex_state = 3},
  [138] = {.lex_state = 117, .external_lex_state = 3},
  [139] = {.lex_state = 117, .external_lex_state = 3},
  [140] = {.lex_state = 117, .external_lex_state = 3},
  [141] = {.lex_state = 117, .external_lex_state = 3},
  [142] = {.lex_state = 117, .external_lex_state = 3},
  [143] = {.lex_state = 117, .external_lex_state = 3},
  [144] = {.lex_state = 117, .external_lex_state = 3},
  [145] = {.lex_state = 117, .external_lex_state = 3},
  [146] = {.lex_state = 117, .external_lex_state = 3},
  [147] = {.lex_state = 117, .external_lex_state = 3},
  [148] = {.lex_state = 117, .external_lex_state = 3},
  [149] = {.lex_state = 117, .external_lex_state = 3},
  [150] = {.lex_state = 117, .external_lex_state = 3},
  [151] = {.lex_state = 117, .external_lex_state = 6},
  [152] = {.lex_state = 117, .external_lex_state = 5},
  [153] = {.lex_state = 117, .external_lex_state = 6},
  [154] = {.lex_state = 117, .external_lex_state = 5},
  [155] = {.lex_state = 117, .external_lex_state = 6},
  [156] = {.lex_state = 117, .external_lex_state = 5},
  [157] = {.lex_state = 117, .external_lex_state = 5},
  [158] = {.lex_state = 117, .external_lex_state = 5},
  [159] = {.lex_state = 117, .external_lex_state = 5},
  [160] = {.lex_state = 117, .external_lex_state = 3},
  [161] = {.lex_state = 6, .external_lex_state = 3},
  [162] = {.lex_state = 117, .external_lex_state = 3},
  [163] = {.lex_state = 117, .external_lex_state = 3},
  [164] = {.lex_state = 6, .external_lex_state = 3},
  [165] = {.lex_state = 117, .external_lex_state = 3},
  [166] = {.lex_state = 6, .external_lex_state = 3},
  [167] = {.lex_state = 117, .external_lex_state = 6},
  [168] = {.lex_state = 117, .external_lex_state = 6},
  [169] = {.lex_state = 117, .external_lex_state = 6},
  [170] = {.lex_state = 117, .external_lex_state = 6},
  [171] = {.lex_state = 117, .external_lex_state = 6},
  [172] = {.lex_state = 117, .external_lex_state = 6},
  [173] = {.lex_state = 117, .external_lex_state = 6},
  [174] = {.lex_state = 117, .external_lex_state = 6},
  [175] = {.lex_state = 117, .external_lex_state = 6},
  [176] = {.lex_state = 117, .external_lex_state = 7},
  [177] = {.lex_state = 117, .external_lex_state = 7},
  [178] = {.lex_state = 117, .external_lex_state = 7},
  [179] = {.lex_state = 117, .external_lex_state = 8},
  [180] = {.lex_state = 117, .external_lex_state = 7},
  [181] = {.lex_state = 117, .external_lex_state = 6},
  [182] = {.lex_state = 117, .external_lex_state = 7},
  [183] = {.lex_state = 6, .external_lex_state = 8},
  [184] = {.lex_state = 117, .external_lex_state = 6},
  [185] = {.lex_state = 117, .external_lex_state = 6},
  [186] = {.lex_state = 117, .external_lex_state = 6},
  [187] = {.lex_state = 117, .external_lex_state = 6},
  [188] = {.lex_state = 117, .external_lex_state = 6},
  [189] = {.lex_state = 117, .external_lex_state = 6},
  [190] = {.lex_state = 117, .external_lex_state = 6},
  [191] = {.lex_state = 117, .external_lex_state = 7},
  [192] = {.lex_state = 117, .external_lex_state = 6},
  [193] = {.lex_state = 117, .external_lex_state = 6},
  [194] = {.lex_state = 117, .external_lex_state = 6},
  [195] = {.lex_state = 117, .external_lex_state = 6},
  [196] = {.lex_state = 117, .external_lex_state = 6},
  [197] = {.lex_state = 117, .external_lex_state = 6},
  [198] = {.lex_state = 117, .external_lex_state = 6},
  [199] = {.lex_state = 117, .external_lex_state = 6},
  [200] = {.lex_state = 117, .external_lex_state = 6},
  [201] = {.lex_state = 117, .external_lex_state = 6},
  [202] = {.lex_state = 117, .external_lex_state = 6},
  [203] = {.lex_state = 117, .external_lex_state = 6},
  [204] = {.lex_state = 117, .external_lex_state = 6},
  [205] = {.lex_state = 117, .external_lex_state = 6},
  [206] = {.lex_state = 117, .external_lex_state = 6},
  [207] = {.lex_state = 117, .external_lex_state = 6},
  [208] = {.lex_state = 117, .external_lex_state = 6},
  [209] = {.lex_state = 117, .external_lex_state = 6},
  [210] = {.lex_state = 117, .external_lex_state = 6},
  [211] = {.lex_state = 117, .external_lex_state = 6},
  [212] = {.lex_state = 117, .external_lex_state = 6},
  [213] = {.lex_state = 117, .external_lex_state = 7},
  [214] = {.lex_state = 117, .external_lex_state = 7},
  [215] = {.lex_state = 117, .external_lex_state = 7},
  [216] = {.lex_state = 117, .external_lex_state = 7},
  [217] = {.lex_state = 117, .external_lex_state = 6},
  [218] = {.lex_state = 117, .external_lex_state = 7},
  [219] = {.lex_state = 117, .external_lex_state = 7},
  [220] = {.lex_state = 117, .external_lex_state = 7},
  [221] = {.lex_state = 117, .external_lex_state = 7},
  [222] = {.lex_state = 117, .external_lex_state = 7},
  [223] = {.lex_state = 117, .external_lex_state = 7},
  [224] = {.lex_state = 117, .external_lex_state = 6},
  [225] = {.lex_state = 117, .external_lex_state = 8},
  [226] = {.lex_state = 117, .external_lex_state = 8},
  [227] = {.lex_state = 117, .external_lex_state = 8},
  [228] = {.lex_state = 117, .external_lex_state = 8},
  [229] = {.lex_state = 117, .external_lex_state = 8},
  [230] = {.lex_state = 117, .external_lex_state = 8},
  [231] = {.lex_state = 117, .external_lex_state = 8},
  [232] = {.lex_state = 117, .external_lex_state = 8},
  [233] = {.lex_state = 117, .external_lex_state = 8},
  [234] = {.lex_state = 117, .external_lex_state = 8},
  [235] = {.lex_state = 6, .external_lex_state = 8},
  [236] = {.lex_state = 117, .external_lex_state = 8},
  [237] = {.lex_state = 117, .external_lex_state = 8},
  [238] = {.lex_state = 117, .external_lex_state = 8},
  [239] = {.lex_state = 117, .external_lex_state = 8},
  [240] = {.lex_state = 117, .external_lex_state = 8},
  [241] = {.lex_state = 117, .external_lex_state = 8},
  [242] = {.lex_state = 117, .external_lex_state = 8},
  [243] = {.lex_state = 117, .external_lex_state = 8},
  [244] = {.lex_state = 117, .external_lex_state = 8},
  [245] = {.lex_state = 117, .external_lex_state = 8},
  [246] = {.lex_state = 117, .external_lex_state = 8},
  [247] = {.lex_state = 117, .external_lex_state = 8},
  [248] = {.lex_state = 117, .external_lex_state = 8},
  [249] = {.lex_state = 117, .external_lex_state = 8},
  [250] = {.lex_state = 6, .external_lex_state = 3},
  [251] = {.lex_state = 117, .external_lex_state = 8},
  [252] = {.lex_state = 117, .external_lex_state = 8},
  [253] = {.lex_state = 117, .external_lex_state = 8},
  [254] = {.lex_state = 117, .external_lex_state = 8},
  [255] = {.lex_state = 117, .external_lex_state = 3},
  [256] = {.lex_state = 117, .external_lex_state = 3},
  [257] = {.lex_state = 117, .external_lex_state = 3},
  [258] = {.lex_state = 117, .external_lex_state = 3},
  [259] = {.lex_state = 117, .external_lex_state = 3},
  [260] = {.lex_state = 6, .external_lex_state = 7},
  [261] = {.lex_state = 117, .external_lex_state = 3},
  [262] = {.lex_state = 117, .external_lex_state = 3},
  [263] = {.lex_state = 117, .external_lex_state = 9},
  [264] = {.lex_state = 117, .external_lex_state = 3},
  [265] = {.lex_state = 117, .external_lex_state = 3},
  [266] = {.lex_state = 117, .external_lex_state = 3},
  [267] = {.lex_state = 117, .external_lex_state = 3},
  [268] = {.lex_state = 117, .external_lex_state = 3},
  [269] = {.lex_state = 117, .external_lex_state = 3},
  [270] = {.lex_state = 117, .external_lex_state = 3},
  [271] = {.lex_state = 117, .external_lex_state = 3},
  [272] = {.lex_state = 117, .external_lex_state = 3},
  [273] = {.lex_state = 117, .external_lex_state = 7},
  [274] = {.lex_state = 117, .external_lex_state = 3},
  [275] = {.lex_state = 117, .external_lex_state = 3},
  [276] = {.lex_state = 117, .external_lex_state = 3},
  [277] = {.lex_state = 117, .external_lex_state = 3},
  [278] = {.lex_state = 117, .external_lex_state = 3},
  [279] = {.lex_state = 117, .external_lex_state = 3},
  [280] = {.lex_state = 117, .external_lex_state = 3},
  [281] = {.lex_state = 117, .external_lex_state = 3},
  [282] = {.lex_state = 117, .external_lex_state = 3},
  [283] = {.lex_state = 6, .external_lex_state = 8},
  [284] = {.lex_state = 117, .external_lex_state = 3},
  [285] = {.lex_state = 117, .external_lex_state = 3},
  [286] = {.lex_state = 117, .external_lex_state = 3},
  [287] = {.lex_state = 117, .external_lex_state = 3},
  [288] = {.lex_state = 117, .external_lex_state = 3},
  [289] = {.lex_state = 117, .external_lex_state = 3},
  [290] = {.lex_state = 117, .external_lex_state = 3},
  [291] = {.lex_state = 6, .external_lex_state = 7},
  [292] = {.lex_state = 6, .external_lex_state = 7},
  [293] = {.lex_state = 117, .external_lex_state = 8},
  [294] = {.lex_state = 117, .external_lex_state = 8},
  [295] = {.lex_state = 117, .external_lex_state = 8},
  [296] = {.lex_state = 117, .external_lex_state = 8},
  [297] = {.lex_state = 117, .external_lex_state = 9},
  [298] = {.lex_state = 117, .external_lex_state = 8},
  [299] = {.lex_state = 117, .external_lex_state = 8},
  [300] = {.lex_state = 117, .external_lex_state = 8},
  [301] = {.lex_state = 117, .external_lex_state = 8},
  [302] = {.lex_state = 117, .external_lex_state = 8},
  [303] = {.lex_state = 117, .external_lex_state = 8},
  [304] = {.lex_state = 117, .external_lex_state = 8},
  [305] = {.lex_state = 117, .external_lex_state = 8},
  [306] = {.lex_state = 117, .external_lex_state = 7},
  [307] = {.lex_state = 117, .external_lex_state = 10},
  [308] = {.lex_state = 117, .external_lex_state = 10},
  [309] = {.lex_state = 117, .external_lex_state = 7},
  [310] = {.lex_state = 117, .external_lex_state = 7},
  [311] = {.lex_state = 117, .external_lex_state = 11},
  [312] = {.lex_state = 117, .external_lex_state = 9},
  [313] = {.lex_state = 117, .external_lex_state = 9},
  [314] = {.lex_state = 117, .external_lex_state = 9},
  [315] = {.lex_state = 117, .external_lex_state = 9},
  [316] = {.lex_state = 117, .external_lex_state = 9},
  [317] = {.lex_state = 117, .external_lex_state = 9},
  [318] = {.lex_state = 117, .external_lex_state = 9},
  [319] = {.lex_state = 117, .external_lex_state = 9},
  [320] = {.lex_state = 117, .external_lex_state = 9},
  [321] = {.lex_state = 117, .external_lex_state = 9},
  [322] = {.lex_state = 117, .external_lex_state = 9},
  [323] = {.lex_state = 117, .external_lex_state = 9},
  [324] = {.lex_state = 117, .external_lex_state = 9},
  [325] = {.lex_state = 117, .external_lex_state = 9},
  [326] = {.lex_state = 117, .external_lex_state = 9},
  [327] = {.lex_state = 117, .external_lex_state = 9},
  [328] = {.lex_state = 117, .external_lex_state = 9},
  [329] = {.lex_state = 117, .external_lex_state = 9},
  [330] = {.lex_state = 117, .external_lex_state = 7},
  [331] = {.lex_state = 117, .external_lex_state = 7},
  [332] = {.lex_state = 117, .external_lex_state = 9},
  [333] = {.lex_state = 117, .external_lex_state = 9},
  [334] = {.lex_state = 117, .external_lex_state = 9},
  [335] = {.lex_state = 117, .external_lex_state = 9},
  [336] = {.lex_state = 117, .external_lex_state = 9},
  [337] = {.lex_state = 117, .external_lex_state = 9},
  [338] = {.lex_state = 117, .external_lex_state = 7},
  [339] = {.lex_state = 117, .external_lex_state = 7},
  [340] = {.lex_state = 117, .external_lex_state = 9},
  [341] = {.lex_state = 117, .external_lex_state = 7},
  [342] = {.lex_state = 117, .external_lex_state = 7},
  [343] = {.lex_state = 117, .external_lex_state = 7},
  [344] = {.lex_state = 117, .external_lex_state = 7},
  [345] = {.lex_state = 117, .external_lex_state = 9},
  [346] = {.lex_state = 117, .external_lex_state = 9},
  [347] = {.lex_state = 117, .external_lex_state = 7},
  [348] = {.lex_state = 117, .external_lex_state = 7},
  [349] = {.lex_state = 117, .external_lex_state = 7},
  [350] = {.lex_state = 117, .external_lex_state = 7},
  [351] = {.lex_state = 117, .external_lex_state = 7},
  [352] = {.lex_state = 117, .external_lex_state = 7},
  [353] = {.lex_state = 117, .external_lex_state = 7},
  [354] = {.lex_state = 117, .external_lex_state = 7},
  [355] = {.lex_state = 117, .external_lex_state = 7},
  [356] = {.lex_state = 117, .external_lex_state = 7},
  [357] = {.lex_state = 117, .external_lex_state = 7},
  [358] = {.lex_state = 117, .external_lex_state = 7},
  [359] = {.lex_state = 117, .external_lex_state = 7},
  [360] = {.lex_state = 117, .external_lex_state = 7},
  [361] = {.lex_state = 117, .external_lex_state = 7},
  [362] = {.lex_state = 117, .external_lex_state = 7},
  [363] = {.lex_state = 117, .external_lex_state = 7},
  [364] = {.lex_state = 117, .external_lex_state = 7},
  [365] = {.lex_state = 117, .external_lex_state = 7},
  [366] = {.lex_state = 117, .external_lex_state = 7},
  [367] = {.lex_state = 117, .external_lex_state = 7},
  [368] = {.lex_state = 117, .external_lex_state = 7},
  [369] = {.lex_state = 117, .external_lex_state = 7},
  [370] = {.lex_state = 117, .external_lex_state = 7},
  [371] = {.lex_state = 117, .external_lex_state = 7},
  [372] = {.lex_state = 117, .external_lex_state = 7},
  [373] = {.lex_state = 117, .external_lex_state = 9},
  [374] = {.lex_state = 117, .external_lex_state = 9},
  [375] = {.lex_state = 117, .external_lex_state = 9},
  [376] = {.lex_state = 117, .external_lex_state = 9},
  [377] = {.lex_state = 117, .external_lex_state = 9},
  [378] = {.lex_state = 117, .external_lex_state = 9},
  [379] = {.lex_state = 117, .external_lex_state = 9},
  [380] = {.lex_state = 117, .external_lex_state = 9},
  [381] = {.lex_state = 117, .external_lex_state = 9},
  [382] = {.lex_state = 117, .external_lex_state = 9},
  [383] = {.lex_state = 117, .external_lex_state = 9},
  [384] = {.lex_state = 117, .external_lex_state = 11},
  [385] = {.lex_state = 117, .external_lex_state = 9},
  [386] = {.lex_state = 117, .external_lex_state = 9},
  [387] = {.lex_state = 117, .external_lex_state = 9},
  [388] = {.lex_state = 117, .external_lex_state = 9},
  [389] = {.lex_state = 117, .external_lex_state = 9},
  [390] = {.lex_state = 117, .external_lex_state = 9},
  [391] = {.lex_state = 117, .external_lex_state = 9},
  [392] = {.lex_state = 117, .external_lex_state = 9},
  [393] = {.lex_state = 117, .external_lex_state = 9},
  [394] = {.lex_state = 117, .external_lex_state = 9},
  [395] = {.lex_state = 117, .external_lex_state = 9},
  [396] = {.lex_state = 117, .external_lex_state = 9},
  [397] = {.lex_state = 117, .external_lex_state = 11},
  [398] = {.lex_state = 117, .external_lex_state = 11},
  [399] = {.lex_state = 117, .external_lex_state = 9},
  [400] = {.lex_state = 117, .external_lex_state = 7},
  [401] = {.lex_state = 117, .external_lex_state = 7},
  [402] = {.lex_state = 117, .external_lex_state = 7},
  [403] = {.lex_state = 117, .external_lex_state = 7},
  [404] = {.lex_state = 117, .external_lex_state = 7},
  [405] = {.lex_state = 117, .external_lex_state = 9},
  [406] = {.lex_state = 117, .external_lex_state = 9},
  [407] = {.lex_state = 117, .external_lex_state = 9},
  [408] = {.lex_state = 117, .external_lex_state = 9},
  [409] = {.lex_state = 117, .external_lex_state = 9},
  [410] = {.lex_state = 117, .external_lex_state = 9},
  [411] = {.lex_state = 117, .external_lex_state = 9},
  [412] = {.lex_state = 117, .external_lex_state = 9},
  [413] = {.lex_state = 117, .external_lex_state = 9},
  [414] = {.lex_state = 117, .external_lex_state = 9},
  [415] = {.lex_state = 117, .external_lex_state = 9},
  [416] = {.lex_state = 117, .external_lex_state = 9},
  [417] = {.lex_state = 117, .external_lex_state = 9},
  [418] = {.lex_state = 117, .external_lex_state = 9},
  [419] = {.lex_state = 117, .external_lex_state = 9},
  [420] = {.lex_state = 117, .external_lex_state = 9},
  [421] = {.lex_state = 117, .external_lex_state = 9},
  [422] = {.lex_state = 117, .external_lex_state = 9},
  [423] = {.lex_state = 117, .external_lex_state = 7},
  [424] = {.lex_state = 117, .external_lex_state = 7},
  [425] = {.lex_state = 117, .external_lex_state = 9},
  [426] = {.lex_state = 117, .external_lex_state = 9},
  [427] = {.lex_state = 117, .external_lex_state = 9},
  [428] = {.lex_state = 117, .external_lex_state = 7},
  [429] = {.lex_state = 117, .external_lex_state = 9},
  [430] = {.lex_state = 117, .external_lex_state = 7},
  [431] = {.lex_state = 117, .external_lex_state = 7},
  [432] = {.lex_state = 117, .external_lex_state = 7},
  [433] = {.lex_state = 117, .external_lex_state = 7},
  [434] = {.lex_state = 117, .external_lex_state = 7},
  [435] = {.lex_state = 117, .external_lex_state = 9},
  [436] = {.lex_state = 117, .external_lex_state = 7},
  [437] = {.lex_state = 117, .external_lex_state = 7},
  [438] = {.lex_state = 117, .external_lex_state = 7},
  [439] = {.lex_state = 117, .external_lex_state = 7},
  [440] = {.lex_state = 117, .external_lex_state = 7},
  [441] = {.lex_state = 117, .external_lex_state = 7},
  [442] = {.lex_state = 117, .external_lex_state = 7},
  [443] = {.lex_state = 117, .external_lex_state = 7},
  [444] = {.lex_state = 117, .external_lex_state = 7},
  [445] = {.lex_state = 117, .external_lex_state = 7},
  [446] = {.lex_state = 117, .external_lex_state = 7},
  [447] = {.lex_state = 117, .external_lex_state = 7},
  [448] = {.lex_state = 117, .external_lex_state = 7},
  [449] = {.lex_state = 117, .external_lex_state = 7},
  [450] = {.lex_state = 117, .external_lex_state = 7},
  [451] = {.lex_state = 117, .external_lex_state = 7},
  [452] = {.lex_state = 117, .external_lex_state = 7},
  [453] = {.lex_state = 117, .external_lex_state = 7},
  [454] = {.lex_state = 117, .external_lex_state = 7},
  [455] = {.lex_state = 117, .external_lex_state = 7},
  [456] = {.lex_state = 117, .external_lex_state = 7},
  [457] = {.lex_state = 117, .external_lex_state = 7},
  [458] = {.lex_state = 117, .external_lex_state = 7},
  [459] = {.lex_state = 117, .external_lex_state = 7},
  [460] = {.lex_state = 117, .external_lex_state = 7},
  [461] = {.lex_state = 117, .external_lex_state = 7},
  [462] = {.lex_state = 117, .external_lex_state = 7},
  [463] = {.lex_state = 117, .external_lex_state = 7},
  [464] = {.lex_state = 117, .external_lex_state = 7},
  [465] = {.lex_state = 117, .external_lex_state = 9},
  [466] = {.lex_state = 117, .external_lex_state = 7},
  [467] = {.lex_state = 117, .external_lex_state = 7},
  [468] = {.lex_state = 117, .external_lex_state = 7},
  [469] = {.lex_state = 117, .external_lex_state = 7},
  [470] = {.lex_state = 117, .external_lex_state = 7},
  [471] = {.lex_state = 117, .external_lex_state = 7},
  [472] = {.lex_state = 117, .external_lex_state = 7},
  [473] = {.lex_state = 117, .external_lex_state = 7},
  [474] = {.lex_state = 117, .external_lex_state = 7},
  [475] = {.lex_state = 117, .external_lex_state = 7},
  [476] = {.lex_state = 117, .external_lex_state = 7},
  [477] = {.lex_state = 117, .external_lex_state = 9},
  [478] = {.lex_state = 117, .external_lex_state = 9},
  [479] = {.lex_state = 117, .external_lex_state = 9},
  [480] = {.lex_state = 117, .external_lex_state = 9},
  [481] = {.lex_state = 117, .external_lex_state = 9},
  [482] = {.lex_state = 117, .external_lex_state = 9},
  [483] = {.lex_state = 117, .external_lex_state = 7},
  [484] = {.lex_state = 117, .external_lex_state = 7},
  [485] = {.lex_state = 117, .external_lex_state = 7},
  [486] = {.lex_state = 117, .external_lex_state = 7},
  [487] = {.lex_state = 117, .external_lex_state = 7},
  [488] = {.lex_state = 117, .external_lex_state = 7},
  [489] = {.lex_state = 117, .external_lex_state = 7},
  [490] = {.lex_state = 117, .external_lex_state = 7},
  [491] = {.lex_state = 117, .external_lex_state = 9},
  [492] = {.lex_state = 117, .external_lex_state = 7},
  [493] = {.lex_state = 117, .external_lex_state = 7},
  [494] = {.lex_state = 117, .external_lex_state = 7},
  [495] = {.lex_state = 117, .external_lex_state = 7},
  [496] = {.lex_state = 117, .external_lex_state = 7},
  [497] = {.lex_state = 117, .external_lex_state = 7},
  [498] = {.lex_state = 117, .external_lex_state = 7},
  [499] = {.lex_state = 117, .external_lex_state = 7},
  [500] = {.lex_state = 117, .external_lex_state = 7},
  [501] = {.lex_state = 117, .external_lex_state = 7},
  [502] = {.lex_state = 117, .external_lex_state = 7},
  [503] = {.lex_state = 117, .external_lex_state = 7},
  [504] = {.lex_state = 117, .external_lex_state = 7},
  [505] = {.lex_state = 117, .external_lex_state = 7},
  [506] = {.lex_state = 117, .external_lex_state = 7},
  [507] = {.lex_state = 117, .external_lex_state = 7},
  [508] = {.lex_state = 117, .external_lex_state = 7},
  [509] = {.lex_state = 117, .external_lex_state = 7},
  [510] = {.lex_state = 117, .external_lex_state = 7},
  [511] = {.lex_state = 117, .external_lex_state = 7},
  [512] = {.lex_state = 117, .external_lex_state = 7},
  [513] = {.lex_state = 117, .external_lex_state = 7},
  [514] = {.lex_state = 117, .external_lex_state = 7},
  [515] = {.lex_state = 117, .external_lex_state = 7},
  [516] = {.lex_state = 117, .external_lex_state = 7},
  [517] = {.lex_state = 117, .external_lex_state = 7},
  [518] = {.lex_state = 117, .external_lex_state = 7},
  [519] = {.lex_state = 117, .external_lex_state = 7},
  [520] = {.lex_state = 117, .external_lex_state = 7},
  [521] = {.lex_state = 117, .external_lex_state = 7},
  [522] = {.lex_state = 117, .external_lex_state = 7},
  [523] = {.lex_state = 117, .external_lex_state = 7},
  [524] = {.lex_state = 117, .external_lex_state = 7},
  [525] = {.lex_state = 117, .external_lex_state = 7},
  [526] = {.lex_state = 117, .external_lex_state = 7},
  [527] = {.lex_state = 117, .external_lex_state = 9},
  [528] = {.lex_state = 117, .external_lex_state = 9},
  [529] = {.lex_state = 117, .external_lex_state = 7},
  [530] = {.lex_state = 117, .external_lex_state = 7},
  [531] = {.lex_state = 117, .external_lex_state = 7},
  [532] = {.lex_state = 117, .external_lex_state = 7},
  [533] = {.lex_state = 117, .external_lex_state = 7},
  [534] = {.lex_state = 117, .external_lex_state = 7},
  [535] = {.lex_state = 117, .external_lex_state = 7},
  [536] = {.lex_state = 117, .external_lex_state = 7},
  [537] = {.lex_state = 117, .external_lex_state = 7},
  [538] = {.lex_state = 117, .external_lex_state = 7},
  [539] = {.lex_state = 117, .external_lex_state = 7},
  [540] = {.lex_state = 117, .external_lex_state = 7},
  [541] = {.lex_state = 117, .external_lex_state = 7},
  [542] = {.lex_state = 117, .external_lex_state = 7},
  [543] = {.lex_state = 117, .external_lex_state = 7},
  [544] = {.lex_state = 117, .external_lex_state = 7},
  [545] = {.lex_state = 117, .external_lex_state = 7},
  [546] = {.lex_state = 117, .external_lex_state = 7},
  [547] = {.lex_state = 117, .external_lex_state = 7},
  [548] = {.lex_state = 117, .external_lex_state = 7},
  [549] = {.lex_state = 117, .external_lex_state = 7},
  [550] = {.lex_state = 117, .external_lex_state = 7},
  [551] = {.lex_state = 117, .external_lex_state = 7},
  [552] = {.lex_state = 117, .external_lex_state = 7},
  [553] = {.lex_state = 117, .external_lex_state = 7},
  [554] = {.lex_state = 117, .external_lex_state = 7},
  [555] = {.lex_state = 117, .external_lex_state = 7},
  [556] = {.lex_state = 117, .external_lex_state = 7},
  [557] = {.lex_state = 117, .external_lex_state = 7},
  [558] = {.lex_state = 117, .external_lex_state = 7},
  [559] = {.lex_state = 117, .external_lex_state = 7},
  [560] = {.lex_state = 117, .external_lex_state = 7},
  [561] = {.lex_state = 117, .external_lex_state = 7},
  [562] = {.lex_state = 117, .external_lex_state = 7},
  [563] = {.lex_state = 117, .external_lex_state = 7},
  [564] = {.lex_state = 117, .external_lex_state = 7},
  [565] = {.lex_state = 117, .external_lex_state = 7},
  [566] = {.lex_state = 117, .external_lex_state = 7},
  [567] = {.lex_state = 117, .external_lex_state = 7},
  [568] = {.lex_state = 117, .external_lex_state = 7},
  [569] = {.lex_state = 117, .external_lex_state = 7},
  [570] = {.lex_state = 117, .external_lex_state = 9},
  [571] = {.lex_state = 117, .external_lex_state = 7},
  [572] = {.lex_state = 117, .external_lex_state = 7},
  [573] = {.lex_state = 117, .external_lex_state = 7},
  [574] = {.lex_state = 117, .external_lex_state = 7},
  [575] = {.lex_state = 117, .external_lex_state = 7},
  [576] = {.lex_state = 117, .external_lex_state = 7},
  [577] = {.lex_state = 117, .external_lex_state = 7},
  [578] = {.lex_state = 117, .external_lex_state = 7},
  [579] = {.lex_state = 117, .external_lex_state = 7},
  [580] = {.lex_state = 117, .external_lex_state = 7},
  [581] = {.lex_state = 117, .external_lex_state = 7},
  [582] = {.lex_state = 117, .external_lex_state = 9},
  [583] = {.lex_state = 117, .external_lex_state = 9},
  [584] = {.lex_state = 6, .external_lex_state = 8},
  [585] = {.lex_state = 117, .external_lex_state = 9},
  [586] = {.lex_state = 117, .external_lex_state = 7},
  [587] = {.lex_state = 117, .external_lex_state = 9},
  [588] = {.lex_state = 117, .external_lex_state = 9},
  [589] = {.lex_state = 117, .external_lex_state = 7},
  [590] = {.lex_state = 117, .external_lex_state = 7},
  [591] = {.lex_state = 117, .external_lex_state = 9},
  [592] = {.lex_state = 117, .external_lex_state = 7},
  [593] = {.lex_state = 117, .external_lex_state = 7},
  [594] = {.lex_state = 117, .external_lex_state = 7},
  [595] = {.lex_state = 117, .external_lex_state = 7},
  [596] = {.lex_state = 117, .external_lex_state = 7},
  [597] = {.lex_state = 117, .external_lex_state = 7},
  [598] = {.lex_state = 117, .external_lex_state = 7},
  [599] = {.lex_state = 117, .external_lex_state = 7},
  [600] = {.lex_state = 117, .external_lex_state = 7},
  [601] = {.lex_state = 117, .external_lex_state = 7},
  [602] = {.lex_state = 117, .external_lex_state = 9},
  [603] = {.lex_state = 117, .external_lex_state = 7},
  [604] = {.lex_state = 117, .external_lex_state = 7},
  [605] = {.lex_state = 117, .external_lex_state = 9},
  [606] = {.lex_state = 117, .external_lex_state = 9},
  [607] = {.lex_state = 117, .external_lex_state = 9},
  [608] = {.lex_state = 117, .external_lex_state = 7},
  [609] = {.lex_state = 117, .external_lex_state = 9},
  [610] = {.lex_state = 117, .external_lex_state = 9},
  [611] = {.lex_state = 117, .external_lex_state = 9},
  [612] = {.lex_state = 117, .external_lex_state = 9},
  [613] = {.lex_state = 117, .external_lex_state = 9},
  [614] = {.lex_state = 117, .external_lex_state = 9},
  [615] = {.lex_state = 117, .external_lex_state = 7},
  [616] = {.lex_state = 117, .external_lex_state = 9},
  [617] = {.lex_state = 117, .external_lex_state = 9},
  [618] = {.lex_state = 117, .external_lex_state = 9},
  [619] = {.lex_state = 117, .external_lex_state = 9},
  [620] = {.lex_state = 117, .external_lex_state = 9},
  [621] = {.lex_state = 117, .external_lex_state = 9},
  [622] = {.lex_state = 117, .external_lex_state = 9},
  [623] = {.lex_state = 117, .external_lex_state = 9},
  [624] = {.lex_state = 117, .external_lex_state = 9},
  [625] = {.lex_state = 117, .external_lex_state = 9},
  [626] = {.lex_state = 117, .external_lex_state = 9},
  [627] = {.lex_state = 117, .external_lex_state = 7},
  [628] = {.lex_state = 117, .external_lex_state = 9},
  [629] = {.lex_state = 117, .external_lex_state = 9},
  [630] = {.lex_state = 117, .external_lex_state = 9},
  [631] = {.lex_state = 117, .external_lex_state = 9},
  [632] = {.lex_state = 117, .external_lex_state = 9},
  [633] = {.lex_state = 117, .external_lex_state = 9},
  [634] = {.lex_state = 117, .external_lex_state = 7},
  [635] = {.lex_state = 117, .external_lex_state = 9},
  [636] = {.lex_state = 117, .external_lex_state = 9},
  [637] = {.lex_state = 117, .external_lex_state = 9},
  [638] = {.lex_state = 117, .external_lex_state = 9},
  [639] = {.lex_state = 117, .external_lex_state = 9},
  [640] = {.lex_state = 117, .external_lex_state = 7},
  [641] = {.lex_state = 117, .external_lex_state = 9},
  [642] = {.lex_state = 117, .external_lex_state = 9},
  [643] = {.lex_state = 117, .external_lex_state = 9},
  [644] = {.lex_state = 117, .external_lex_state = 9},
  [645] = {.lex_state = 117, .external_lex_state = 9},
  [646] = {.lex_state = 117, .external_lex_state = 9},
  [647] = {.lex_state = 117, .external_lex_state = 9},
  [648] = {.lex_state = 117, .external_lex_state = 9},
  [649] = {.lex_state = 117, .external_lex_state = 9},
  [650] = {.lex_state = 117, .external_lex_state = 9},
  [651] = {.lex_state = 117, .external_lex_state = 9},
  [652] = {.lex_state = 117, .external_lex_state = 9},
  [653] = {.lex_state = 117, .external_lex_state = 9},
  [654] = {.lex_state = 117, .external_lex_state = 9},
  [655] = {.lex_state = 117, .external_lex_state = 9},
  [656] = {.lex_state = 117, .external_lex_state = 9},
  [657] = {.lex_state = 117, .external_lex_state = 9},
  [658] = {.lex_state = 117, .external_lex_state = 9},
  [659] = {.lex_state = 117, .external_lex_state = 9},
  [660] = {.lex_state = 117, .external_lex_state = 9},
  [661] = {.lex_state = 117, .external_lex_state = 9},
  [662] = {.lex_state = 117, .external_lex_state = 9},
  [663] = {.lex_state = 117, .external_lex_state = 7},
  [664] = {.lex_state = 117, .external_lex_state = 9},
  [665] = {.lex_state = 117, .external_lex_state = 9},
  [666] = {.lex_state = 117, .external_lex_state = 9},
  [667] = {.lex_state = 117, .external_lex_state = 9},
  [668] = {.lex_state = 117, .external_lex_state = 9},
  [669] = {.lex_state = 117, .external_lex_state = 9},
  [670] = {.lex_state = 117, .external_lex_state = 9},
  [671] = {.lex_state = 117, .external_lex_state = 9},
  [672] = {.lex_state = 117, .external_lex_state = 9},
  [673] = {.lex_state = 117, .external_lex_state = 9},
  [674] = {.lex_state = 117, .external_lex_state = 9},
  [675] = {.lex_state = 117, .external_lex_state = 9},
  [676] = {.lex_state = 117, .external_lex_state = 9},
  [677] = {.lex_state = 117, .external_lex_state = 9},
  [678] = {.lex_state = 117, .external_lex_state = 9},
  [679] = {.lex_state = 117, .external_lex_state = 9},
  [680] = {.lex_state = 117, .external_lex_state = 9},
  [681] = {.lex_state = 117, .external_lex_state = 9},
  [682] = {.lex_state = 117, .external_lex_state = 9},
  [683] = {.lex_state = 117, .external_lex_state = 9},
  [684] = {.lex_state = 117, .external_lex_state = 9},
  [685] = {.lex_state = 117, .external_lex_state = 9},
  [686] = {.lex_state = 117, .external_lex_state = 9},
  [687] = {.lex_state = 117, .external_lex_state = 9},
  [688] = {.lex_state = 117, .external_lex_state = 9},
  [689] = {.lex_state = 117, .external_lex_state = 9},
  [690] = {.lex_state = 117, .external_lex_state = 9},
  [691] = {.lex_state = 117, .external_lex_state = 9},
  [692] = {.lex_state = 117, .external_lex_state = 9},
  [693] = {.lex_state = 117, .external_lex_state = 9},
  [694] = {.lex_state = 117, .external_lex_state = 9},
  [695] = {.lex_state = 117, .external_lex_state = 9},
  [696] = {.lex_state = 117, .external_lex_state = 9},
  [697] = {.lex_state = 117, .external_lex_state = 7},
  [698] = {.lex_state = 117, .external_lex_state = 9},
  [699] = {.lex_state = 117, .external_lex_state = 9},
  [700] = {.lex_state = 117, .external_lex_state = 9},
  [701] = {.lex_state = 117, .external_lex_state = 7},
  [702] = {.lex_state = 117, .external_lex_state = 9},
  [703] = {.lex_state = 117, .external_lex_state = 9},
  [704] = {.lex_state = 117, .external_lex_state = 9},
  [705] = {.lex_state = 117, .external_lex_state = 9},
  [706] = {.lex_state = 117, .external_lex_state = 9},
  [707] = {.lex_state = 117, .external_lex_state = 9},
  [708] = {.lex_state = 117, .external_lex_state = 9},
  [709] = {.lex_state = 117, .external_lex_state = 9},
  [710] = {.lex_state = 117, .external_lex_state = 9},
  [711] = {.lex_state = 117, .external_lex_state = 9},
  [712] = {.lex_state = 117, .external_lex_state = 9},
  [713] = {.lex_state = 117, .external_lex_state = 9},
  [714] = {.lex_state = 117, .external_lex_state = 9},
  [715] = {.lex_state = 117, .external_lex_state = 9},
  [716] = {.lex_state = 117, .external_lex_state = 9},
  [717] = {.lex_state = 117, .external_lex_state = 9},
  [718] = {.lex_state = 117, .external_lex_state = 9},
  [719] = {.lex_state = 117, .external_lex_state = 9},
  [720] = {.lex_state = 117, .external_lex_state = 9},
  [721] = {.lex_state = 117, .external_lex_state = 9},
  [722] = {.lex_state = 117, .external_lex_state = 9},
  [723] = {.lex_state = 117, .external_lex_state = 9},
  [724] = {.lex_state = 117, .external_lex_state = 9},
  [725] = {.lex_state = 117, .external_lex_state = 9},
  [726] = {.lex_state = 117, .external_lex_state = 9},
  [727] = {.lex_state = 117, .external_lex_state = 9},
  [728] = {.lex_state = 117, .external_lex_state = 9},
  [729] = {.lex_state = 117, .external_lex_state = 9},
  [730] = {.lex_state = 117, .external_lex_state = 9},
  [731] = {.lex_state = 117, .external_lex_state = 9},
  [732] = {.lex_state = 117, .external_lex_state = 9},
  [733] = {.lex_state = 117, .external_lex_state = 9},
  [734] = {.lex_state = 117, .external_lex_state = 9},
  [735] = {.lex_state = 117, .external_lex_state = 9},
  [736] = {.lex_state = 117, .external_lex_state = 9},
  [737] = {.lex_state = 117, .external_lex_state = 9},
  [738] = {.lex_state = 117, .external_lex_state = 9},
  [739] = {.lex_state = 117, .external_lex_state = 9},
  [740] = {.lex_state = 117, .external_lex_state = 9},
  [741] = {.lex_state = 117, .external_lex_state = 9},
  [742] = {.lex_state = 117, .external_lex_state = 9},
  [743] = {.lex_state = 117, .external_lex_state = 9},
  [744] = {.lex_state = 117, .external_lex_state = 9},
  [745] = {.lex_state = 117, .external_lex_state = 9},
  [746] = {.lex_state = 117, .external_lex_state = 9},
  [747] = {.lex_state = 117, .external_lex_state = 9},
  [748] = {.lex_state = 117, .external_lex_state = 9},
  [749] = {.lex_state = 117, .external_lex_state = 9},
  [750] = {.lex_state = 117, .external_lex_state = 9},
  [751] = {.lex_state = 117, .external_lex_state = 9},
  [752] = {.lex_state = 117, .external_lex_state = 9},
  [753] = {.lex_state = 117, .external_lex_state = 9},
  [754] = {.lex_state = 117, .external_lex_state = 9},
  [755] = {.lex_state = 117, .external_lex_state = 9},
  [756] = {.lex_state = 117, .external_lex_state = 9},
  [757] = {.lex_state = 117, .external_lex_state = 9},
  [758] = {.lex_state = 117, .external_lex_state = 9},
  [759] = {.lex_state = 117, .external_lex_state = 9},
  [760] = {.lex_state = 117, .external_lex_state = 9},
  [761] = {.lex_state = 117, .external_lex_state = 9},
  [762] = {.lex_state = 117, .external_lex_state = 9},
  [763] = {.lex_state = 117, .external_lex_state = 9},
  [764] = {.lex_state = 117, .external_lex_state = 9},
  [765] = {.lex_state = 117, .external_lex_state = 9},
  [766] = {.lex_state = 117, .external_lex_state = 9},
  [767] = {.lex_state = 117, .external_lex_state = 9},
  [768] = {.lex_state = 117, .external_lex_state = 9},
  [769] = {.lex_state = 117, .external_lex_state = 9},
  [770] = {.lex_state = 117, .external_lex_state = 9},
  [771] = {.lex_state = 117, .external_lex_state = 9},
  [772] = {.lex_state = 117, .external_lex_state = 9},
  [773] = {.lex_state = 117, .external_lex_state = 9},
  [774] = {.lex_state = 117, .external_lex_state = 9},
  [775] = {.lex_state = 117, .external_lex_state = 9},
  [776] = {.lex_state = 117, .external_lex_state = 9},
  [777] = {.lex_state = 117, .external_lex_state = 9},
  [778] = {.lex_state = 117, .external_lex_state = 9},
  [779] = {.lex_state = 117, .external_lex_state = 9},
  [780] = {.lex_state = 117, .external_lex_state = 9},
  [781] = {.lex_state = 117, .external_lex_state = 9},
  [782] = {.lex_state = 117, .external_lex_state = 9},
  [783] = {.lex_state = 117, .external_lex_state = 9},
  [784] = {.lex_state = 117, .external_lex_state = 9},
  [785] = {.lex_state = 117, .external_lex_state = 9},
  [786] = {.lex_state = 117, .external_lex_state = 9},
  [787] = {.lex_state = 117, .external_lex_state = 9},
  [788] = {.lex_state = 117, .external_lex_state = 9},
  [789] = {.lex_state = 117, .external_lex_state = 9},
  [790] = {.lex_state = 117, .external_lex_state = 9},
  [791] = {.lex_state = 117, .external_lex_state = 9},
  [792] = {.lex_state = 117, .external_lex_state = 9},
  [793] = {.lex_state = 117, .external_lex_state = 9},
  [794] = {.lex_state = 117, .external_lex_state = 9},
  [795] = {.lex_state = 117, .external_lex_state = 9},
  [796] = {.lex_state = 117, .external_lex_state = 9},
  [797] = {.lex_state = 117, .external_lex_state = 9},
  [798] = {.lex_state = 117, .external_lex_state = 8},
  [799] = {.lex_state = 117, .external_lex_state = 8},
  [800] = {.lex_state = 117, .external_lex_state = 8},
  [801] = {.lex_state = 117, .external_lex_state = 8},
  [802] = {.lex_state = 117, .external_lex_state = 8},
  [803] = {.lex_state = 117, .external_lex_state = 8},
  [804] = {.lex_state = 117, .external_lex_state = 8},
  [805] = {.lex_state = 117, .external_lex_state = 8},
  [806] = {.lex_state = 117, .external_lex_state = 8},
  [807] = {.lex_state = 117, .external_lex_state = 8},
  [808] = {.lex_state = 117, .external_lex_state = 8},
  [809] = {.lex_state = 117, .external_lex_state = 8},
  [810] = {.lex_state = 117, .external_lex_state = 8},
  [811] = {.lex_state = 117, .external_lex_state = 8},
  [812] = {.lex_state = 117, .external_lex_state = 8},
  [813] = {.lex_state = 117, .external_lex_state = 8},
  [814] = {.lex_state = 117, .external_lex_state = 8},
  [815] = {.lex_state = 117, .external_lex_state = 8},
  [816] = {.lex_state = 117, .external_lex_state = 8},
  [817] = {.lex_state = 117, .external_lex_state = 8},
  [818] = {.lex_state = 117, .external_lex_state = 8},
  [819] = {.lex_state = 117, .external_lex_state = 8},
  [820] = {.lex_state = 117, .external_lex_state = 8},
  [821] = {.lex_state = 117, .external_lex_state = 8},
  [822] = {.lex_state = 117, .external_lex_state = 8},
  [823] = {.lex_state = 117, .external_lex_state = 8},
  [824] = {.lex_state = 117, .external_lex_state = 8},
  [825] = {.lex_state = 117, .external_lex_state = 8},
  [826] = {.lex_state = 117, .external_lex_state = 8},
  [827] = {.lex_state = 117, .external_lex_state = 8},
  [828] = {.lex_state = 117, .external_lex_state = 8},
  [829] = {.lex_state = 117, .external_lex_state = 8},
  [830] = {.lex_state = 117, .external_lex_state = 8},
  [831] = {.lex_state = 117, .external_lex_state = 8},
  [832] = {.lex_state = 117, .external_lex_state = 8},
  [833] = {.lex_state = 117, .external_lex_state = 8},
  [834] = {.lex_state = 117, .external_lex_state = 8},
  [835] = {.lex_state = 117, .external_lex_state = 8},
  [836] = {.lex_state = 117, .external_lex_state = 8},
  [837] = {.lex_state = 117, .external_lex_state = 8},
  [838] = {.lex_state = 117, .external_lex_state = 8},
  [839] = {.lex_state = 117, .external_lex_state = 8},
  [840] = {.lex_state = 117, .external_lex_state = 8},
  [841] = {.lex_state = 117, .external_lex_state = 8},
  [842] = {.lex_state = 117, .external_lex_state = 8},
  [843] = {.lex_state = 117, .external_lex_state = 8},
  [844] = {.lex_state = 117, .external_lex_state = 8},
  [845] = {.lex_state = 117, .external_lex_state = 8},
  [846] = {.lex_state = 117, .external_lex_state = 8},
  [847] = {.lex_state = 117, .external_lex_state = 8},
  [848] = {.lex_state = 117, .external_lex_state = 8},
  [849] = {.lex_state = 117, .external_lex_state = 8},
  [850] = {.lex_state = 117, .external_lex_state = 8},
  [851] = {.lex_state = 117, .external_lex_state = 8},
  [852] = {.lex_state = 117, .external_lex_state = 8},
  [853] = {.lex_state = 117, .external_lex_state = 8},
  [854] = {.lex_state = 117, .external_lex_state = 8},
  [855] = {.lex_state = 117, .external_lex_state = 8},
  [856] = {.lex_state = 117, .external_lex_state = 8},
  [857] = {.lex_state = 117, .external_lex_state = 8},
  [858] = {.lex_state = 117, .external_lex_state = 8},
  [859] = {.lex_state = 117, .external_lex_state = 8},
  [860] = {.lex_state = 117, .external_lex_state = 8},
  [861] = {.lex_state = 117, .external_lex_state = 8},
  [862] = {.lex_state = 117, .external_lex_state = 8},
  [863] = {.lex_state = 117, .external_lex_state = 8},
  [864] = {.lex_state = 117, .external_lex_state = 8},
  [865] = {.lex_state = 117, .external_lex_state = 8},
  [866] = {.lex_state = 117, .external_lex_state = 8},
  [867] = {.lex_state = 117, .external_lex_state = 8},
  [868] = {.lex_state = 117, .external_lex_state = 8},
  [869] = {.lex_state = 117, .external_lex_state = 8},
  [870] = {.lex_state = 117, .external_lex_state = 8},
  [871] = {.lex_state = 117, .external_lex_state = 8},
  [872] = {.lex_state = 117, .external_lex_state = 8},
  [873] = {.lex_state = 117, .external_lex_state = 8},
  [874] = {.lex_state = 117, .external_lex_state = 8},
  [875] = {.lex_state = 117, .external_lex_state = 8},
  [876] = {.lex_state = 117, .external_lex_state = 8},
  [877] = {.lex_state = 117, .external_lex_state = 8},
  [878] = {.lex_state = 117, .external_lex_state = 8},
  [879] = {.lex_state = 117, .external_lex_state = 8},
  [880] = {.lex_state = 117, .external_lex_state = 8},
  [881] = {.lex_state = 117, .external_lex_state = 8},
  [882] = {.lex_state = 117, .external_lex_state = 8},
  [883] = {.lex_state = 117, .external_lex_state = 8},
  [884] = {.lex_state = 117, .external_lex_state = 8},
  [885] = {.lex_state = 117, .external_lex_state = 8},
  [886] = {.lex_state = 117, .external_lex_state = 8},
  [887] = {.lex_state = 117, .external_lex_state = 8},
  [888] = {.lex_state = 117, .external_lex_state = 8},
  [889] = {.lex_state = 117, .external_lex_state = 8},
  [890] = {.lex_state = 117, .external_lex_state = 8},
  [891] = {.lex_state = 117, .external_lex_state = 8},
  [892] = {.lex_state = 117, .external_lex_state = 8},
  [893] = {.lex_state = 117, .external_lex_state = 8},
  [894] = {.lex_state = 117, .external_lex_state = 8},
  [895] = {.lex_state = 117, .external_lex_state = 8},
  [896] = {.lex_state = 117, .external_lex_state = 8},
  [897] = {.lex_state = 117, .external_lex_state = 8},
  [898] = {.lex_state = 117, .external_lex_state = 8},
  [899] = {.lex_state = 117, .external_lex_state = 8},
  [900] = {.lex_state = 117, .external_lex_state = 8},
  [901] = {.lex_state = 117, .external_lex_state = 8},
  [902] = {.lex_state = 117, .external_lex_state = 8},
  [903] = {.lex_state = 117, .external_lex_state = 8},
  [904] = {.lex_state = 117, .external_lex_state = 8},
  [905] = {.lex_state = 117, .external_lex_state = 8},
  [906] = {.lex_state = 117, .external_lex_state = 8},
  [907] = {.lex_state = 117, .external_lex_state = 8},
  [908] = {.lex_state = 117, .external_lex_state = 8},
  [909] = {.lex_state = 117, .external_lex_state = 8},
  [910] = {.lex_state = 117, .external_lex_state = 8},
  [911] = {.lex_state = 117, .external_lex_state = 8},
  [912] = {.lex_state = 117, .external_lex_state = 8},
  [913] = {.lex_state = 117, .external_lex_state = 8},
  [914] = {.lex_state = 117, .external_lex_state = 8},
  [915] = {.lex_state = 117, .external_lex_state = 8},
  [916] = {.lex_state = 117, .external_lex_state = 8},
  [917] = {.lex_state = 117, .external_lex_state = 8},
  [918] = {.lex_state = 117, .external_lex_state = 8},
  [919] = {.lex_state = 117, .external_lex_state = 8},
  [920] = {.lex_state = 117, .external_lex_state = 8},
  [921] = {.lex_state = 117, .external_lex_state = 8},
  [922] = {.lex_state = 117, .external_lex_state = 8},
  [923] = {.lex_state = 117, .external_lex_state = 8},
  [924] = {.lex_state = 117, .external_lex_state = 8},
  [925] = {.lex_state = 117, .external_lex_state = 8},
  [926] = {.lex_state = 117, .external_lex_state = 8},
  [927] = {.lex_state = 117, .external_lex_state = 8},
  [928] = {.lex_state = 117, .external_lex_state = 8},
  [929] = {.lex_state = 117, .external_lex_state = 8},
  [930] = {.lex_state = 117, .external_lex_state = 8},
  [931] = {.lex_state = 117, .external_lex_state = 8},
  [932] = {.lex_state = 117, .external_lex_state = 8},
  [933] = {.lex_state = 117, .external_lex_state = 8},
  [934] = {.lex_state = 117, .external_lex_state = 8},
  [935] = {.lex_state = 117, .external_lex_state = 8},
  [936] = {.lex_state = 117, .external_lex_state = 8},
  [937] = {.lex_state = 117, .external_lex_state = 8},
  [938] = {.lex_state = 117, .external_lex_state = 8},
  [939] = {.lex_state = 117, .external_lex_state = 8},
  [940] = {.lex_state = 117, .external_lex_state = 8},
  [941] = {.lex_state = 117, .external_lex_state = 8},
  [942] = {.lex_state = 117, .external_lex_state = 8},
  [943] = {.lex_state = 117, .external_lex_state = 8},
  [944] = {.lex_state = 117, .external_lex_state = 8},
  [945] = {.lex_state = 117, .external_lex_state = 8},
  [946] = {.lex_state = 117, .external_lex_state = 8},
  [947] = {.lex_state = 117, .external_lex_state = 8},
  [948] = {.lex_state = 117, .external_lex_state = 8},
  [949] = {.lex_state = 117, .external_lex_state = 8},
  [950] = {.lex_state = 117, .external_lex_state = 8},
  [951] = {.lex_state = 117, .external_lex_state = 8},
  [952] = {.lex_state = 117, .external_lex_state = 8},
  [953] = {.lex_state = 117, .external_lex_state = 8},
  [954] = {.lex_state = 117, .external_lex_state = 8},
  [955] = {.lex_state = 117, .external_lex_state = 8},
  [956] = {.lex_state = 117, .external_lex_state = 8},
  [957] = {.lex_state = 117, .external_lex_state = 8},
  [958] = {.lex_state = 117, .external_lex_state = 8},
  [959] = {.lex_state = 117, .external_lex_state = 8},
  [960] = {.lex_state = 117, .external_lex_state = 8},
  [961] = {.lex_state = 117, .external_lex_state = 8},
  [962] = {.lex_state = 117, .external_lex_state = 8},
  [963] = {.lex_state = 117, .external_lex_state = 8},
  [964] = {.lex_state = 117, .external_lex_state = 8},
  [965] = {.lex_state = 117, .external_lex_state = 8},
  [966] = {.lex_state = 117, .external_lex_state = 8},
  [967] = {.lex_state = 117, .external_lex_state = 8},
  [968] = {.lex_state = 117, .external_lex_state = 8},
  [969] = {.lex_state = 117, .external_lex_state = 8},
  [970] = {.lex_state = 117, .external_lex_state = 8},
  [971] = {.lex_state = 117, .external_lex_state = 8},
  [972] = {.lex_state = 117, .external_lex_state = 8},
  [973] = {.lex_state = 117, .external_lex_state = 8},
  [974] = {.lex_state = 117, .external_lex_state = 8},
  [975] = {.lex_state = 117, .external_lex_state = 8},
  [976] = {.lex_state = 117, .external_lex_state = 8},
  [977] = {.lex_state = 117, .external_lex_state = 8},
  [978] = {.lex_state = 117, .external_lex_state = 8},
  [979] = {.lex_state = 117, .external_lex_state = 8},
  [980] = {.lex_state = 117, .external_lex_state = 8},
  [981] = {.lex_state = 117, .external_lex_state = 8},
  [982] = {.lex_state = 117, .external_lex_state = 8},
  [983] = {.lex_state = 117, .external_lex_state = 8},
  [984] = {.lex_state = 117, .external_lex_state = 8},
  [985] = {.lex_state = 117, .external_lex_state = 8},
  [986] = {.lex_state = 117, .external_lex_state = 8},
  [987] = {.lex_state = 117, .external_lex_state = 8},
  [988] = {.lex_state = 117, .external_lex_state = 8},
  [989] = {.lex_state = 117, .external_lex_state = 8},
  [990] = {.lex_state = 117, .external_lex_state = 8},
  [991] = {.lex_state = 117, .external_lex_state = 8},
  [992] = {.lex_state = 117, .external_lex_state = 8},
  [993] = {.lex_state = 117, .external_lex_state = 8},
  [994] = {.lex_state = 117, .external_lex_state = 8},
  [995] = {.lex_state = 117, .external_lex_state = 8},
  [996] = {.lex_state = 117, .external_lex_state = 8},
  [997] = {.lex_state = 117, .external_lex_state = 8},
  [998] = {.lex_state = 117, .external_lex_state = 8},
  [999] = {.lex_state = 117, .external_lex_state = 8},
  [1000] = {.lex_state = 117, .external_lex_state = 8},
  [1001] = {.lex_state = 117, .external_lex_state = 8},
  [1002] = {.lex_state = 117, .external_lex_state = 8},
  [1003] = {.lex_state = 117, .external_lex_state = 8},
  [1004] = {.lex_state = 117, .external_lex_state = 8},
  [1005] = {.lex_state = 117, .external_lex_state = 8},
  [1006] = {.lex_state = 117, .external_lex_state = 8},
  [1007] = {.lex_state = 117, .external_lex_state = 8},
  [1008] = {.lex_state = 117, .external_lex_state = 8},
  [1009] = {.lex_state = 117, .external_lex_state = 8},
  [1010] = {.lex_state = 117, .external_lex_state = 8},
  [1011] = {.lex_state = 117, .external_lex_state = 8},
  [1012] = {.lex_state = 117, .external_lex_state = 8},
  [1013] = {.lex_state = 117, .external_lex_state = 8},
  [1014] = {.lex_state = 117, .external_lex_state = 8},
  [1015] = {.lex_state = 117, .external_lex_state = 8},
  [1016] = {.lex_state = 117, .external_lex_state = 8},
  [1017] = {.lex_state = 117, .external_lex_state = 8},
  [1018] = {.lex_state = 117, .external_lex_state = 8},
  [1019] = {.lex_state = 117, .external_lex_state = 8},
  [1020] = {.lex_state = 117, .external_lex_state = 8},
  [1021] = {.lex_state = 117, .external_lex_state = 8},
  [1022] = {.lex_state = 117, .external_lex_state = 8},
  [1023] = {.lex_state = 117, .external_lex_state = 8},
  [1024] = {.lex_state = 117, .external_lex_state = 8},
  [1025] = {.lex_state = 117, .external_lex_state = 8},
  [1026] = {.lex_state = 117, .external_lex_state = 8},
  [1027] = {.lex_state = 117, .external_lex_state = 8},
  [1028] = {.lex_state = 117, .external_lex_state = 8},
  [1029] = {.lex_state = 117, .external_lex_state = 8},
  [1030] = {.lex_state = 117, .external_lex_state = 8},
  [1031] = {.lex_state = 117, .external_lex_state = 8},
  [1032] = {.lex_state = 117, .external_lex_state = 8},
  [1033] = {.lex_state = 117, .external_lex_state = 8},
  [1034] = {.lex_state = 117, .external_lex_state = 8},
  [1035] = {.lex_state = 117, .external_lex_state = 8},
  [1036] = {.lex_state = 117, .external_lex_state = 8},
  [1037] = {.lex_state = 117, .external_lex_state = 8},
  [1038] = {.lex_state = 117, .external_lex_state = 8},
  [1039] = {.lex_state = 117, .external_lex_state = 8},
  [1040] = {.lex_state = 117, .external_lex_state = 8},
  [1041] = {.lex_state = 117, .external_lex_state = 8},
  [1042] = {.lex_state = 117, .external_lex_state = 8},
  [1043] = {.lex_state = 117, .external_lex_state = 8},
  [1044] = {.lex_state = 117, .external_lex_state = 8},
  [1045] = {.lex_state = 117, .external_lex_state = 8},
  [1046] = {.lex_state = 117, .external_lex_state = 8},
  [1047] = {.lex_state = 117, .external_lex_state = 8},
  [1048] = {.lex_state = 117, .external_lex_state = 8},
  [1049] = {.lex_state = 117, .external_lex_state = 8},
  [1050] = {.lex_state = 117, .external_lex_state = 8},
  [1051] = {.lex_state = 117, .external_lex_state = 8},
  [1052] = {.lex_state = 117, .external_lex_state = 8},
  [1053] = {.lex_state = 117, .external_lex_state = 8},
  [1054] = {.lex_state = 117, .external_lex_state = 8},
  [1055] = {.lex_state = 117, .external_lex_state = 8},
  [1056] = {.lex_state = 117, .external_lex_state = 8},
  [1057] = {.lex_state = 117, .external_lex_state = 8},
  [1058] = {.lex_state = 117, .external_lex_state = 8},
  [1059] = {.lex_state = 117, .external_lex_state = 8},
  [1060] = {.lex_state = 117, .external_lex_state = 8},
  [1061] = {.lex_state = 117, .external_lex_state = 8},
  [1062] = {.lex_state = 117, .external_lex_state = 8},
  [1063] = {.lex_state = 117, .external_lex_state = 8},
  [1064] = {.lex_state = 117, .external_lex_state = 8},
  [1065] = {.lex_state = 117, .external_lex_state = 8},
  [1066] = {.lex_state = 117, .external_lex_state = 8},
  [1067] = {.lex_state = 117, .external_lex_state = 8},
  [1068] = {.lex_state = 117, .external_lex_state = 8},
  [1069] = {.lex_state = 117, .external_lex_state = 8},
  [1070] = {.lex_state = 117, .external_lex_state = 8},
  [1071] = {.lex_state = 117, .external_lex_state = 8},
  [1072] = {.lex_state = 117, .external_lex_state = 8},
  [1073] = {.lex_state = 117, .external_lex_state = 8},
  [1074] = {.lex_state = 117, .external_lex_state = 8},
  [1075] = {.lex_state = 117, .external_lex_state = 8},
  [1076] = {.lex_state = 117, .external_lex_state = 8},
  [1077] = {.lex_state = 117, .external_lex_state = 8},
  [1078] = {.lex_state = 117, .external_lex_state = 8},
  [1079] = {.lex_state = 117, .external_lex_state = 8},
  [1080] = {.lex_state = 117, .external_lex_state = 8},
  [1081] = {.lex_state = 117, .external_lex_state = 8},
  [1082] = {.lex_state = 117, .external_lex_state = 8},
  [1083] = {.lex_state = 117, .external_lex_state = 8},
  [1084] = {.lex_state = 117, .external_lex_state = 8},
  [1085] = {.lex_state = 117, .external_lex_state = 8},
  [1086] = {.lex_state = 117, .external_lex_state = 8},
  [1087] = {.lex_state = 117, .external_lex_state = 8},
  [1088] = {.lex_state = 117, .external_lex_state = 8},
  [1089] = {.lex_state = 117, .external_lex_state = 8},
  [1090] = {.lex_state = 117, .external_lex_state = 8},
  [1091] = {.lex_state = 117, .external_lex_state = 8},
  [1092] = {.lex_state = 117, .external_lex_state = 8},
  [1093] = {.lex_state = 117, .external_lex_state = 8},
  [1094] = {.lex_state = 117, .external_lex_state = 8},
  [1095] = {.lex_state = 117, .external_lex_state = 8},
  [1096] = {.lex_state = 117, .external_lex_state = 8},
  [1097] = {.lex_state = 117, .external_lex_state = 8},
  [1098] = {.lex_state = 117, .external_lex_state = 8},
  [1099] = {.lex_state = 117, .external_lex_state = 8},
  [1100] = {.lex_state = 117, .external_lex_state = 8},
  [1101] = {.lex_state = 117, .external_lex_state = 8},
  [1102] = {.lex_state = 117, .external_lex_state = 8},
  [1103] = {.lex_state = 117, .external_lex_state = 8},
  [1104] = {.lex_state = 117, .external_lex_state = 8},
  [1105] = {.lex_state = 117, .external_lex_state = 8},
  [1106] = {.lex_state = 117, .external_lex_state = 8},
  [1107] = {.lex_state = 117, .external_lex_state = 8},
  [1108] = {.lex_state = 117, .external_lex_state = 8},
  [1109] = {.lex_state = 117, .external_lex_state = 8},
  [1110] = {.lex_state = 117, .external_lex_state = 8},
  [1111] = {.lex_state = 117, .external_lex_state = 8},
  [1112] = {.lex_state = 117, .external_lex_state = 8},
  [1113] = {.lex_state = 117, .external_lex_state = 8},
  [1114] = {.lex_state = 117, .external_lex_state = 8},
  [1115] = {.lex_state = 117, .external_lex_state = 8},
  [1116] = {.lex_state = 117, .external_lex_state = 8},
  [1117] = {.lex_state = 117, .external_lex_state = 8},
  [1118] = {.lex_state = 117, .external_lex_state = 8},
  [1119] = {.lex_state = 117, .external_lex_state = 8},
  [1120] = {.lex_state = 117, .external_lex_state = 8},
  [1121] = {.lex_state = 117, .external_lex_state = 8},
  [1122] = {.lex_state = 117, .external_lex_state = 8},
  [1123] = {.lex_state = 117, .external_lex_state = 8},
  [1124] = {.lex_state = 117, .external_lex_state = 8},
  [1125] = {.lex_state = 117, .external_lex_state = 8},
  [1126] = {.lex_state = 117, .external_lex_state = 8},
  [1127] = {.lex_state = 117, .external_lex_state = 8},
  [1128] = {.lex_state = 117, .external_lex_state = 8},
  [1129] = {.lex_state = 117, .external_lex_state = 8},
  [1130] = {.lex_state = 117, .external_lex_state = 8},
  [1131] = {.lex_state = 117, .external_lex_state = 8},
  [1132] = {.lex_state = 117, .external_lex_state = 8},
  [1133] = {.lex_state = 117, .external_lex_state = 8},
  [1134] = {.lex_state = 117, .external_lex_state = 8},
  [1135] = {.lex_state = 117, .external_lex_state = 8},
  [1136] = {.lex_state = 117, .external_lex_state = 8},
  [1137] = {.lex_state = 117, .external_lex_state = 8},
  [1138] = {.lex_state = 117, .external_lex_state = 8},
  [1139] = {.lex_state = 117, .external_lex_state = 8},
  [1140] = {.lex_state = 117, .external_lex_state = 8},
  [1141] = {.lex_state = 117, .external_lex_state = 8},
  [1142] = {.lex_state = 117, .external_lex_state = 8},
  [1143] = {.lex_state = 117, .external_lex_state = 8},
  [1144] = {.lex_state = 117, .external_lex_state = 8},
  [1145] = {.lex_state = 117, .external_lex_state = 8},
  [1146] = {.lex_state = 117, .external_lex_state = 8},
  [1147] = {.lex_state = 117, .external_lex_state = 8},
  [1148] = {.lex_state = 117, .external_lex_state = 8},
  [1149] = {.lex_state = 117, .external_lex_state = 8},
  [1150] = {.lex_state = 117, .external_lex_state = 8},
  [1151] = {.lex_state = 117, .external_lex_state = 8},
  [1152] = {.lex_state = 117, .external_lex_state = 8},
  [1153] = {.lex_state = 117, .external_lex_state = 8},
  [1154] = {.lex_state = 117, .external_lex_state = 8},
  [1155] = {.lex_state = 117, .external_lex_state = 8},
  [1156] = {.lex_state = 117, .external_lex_state = 8},
  [1157] = {.lex_state = 117, .external_lex_state = 8},
  [1158] = {.lex_state = 117, .external_lex_state = 8},
  [1159] = {.lex_state = 117, .external_lex_state = 8},
  [1160] = {.lex_state = 117, .external_lex_state = 8},
  [1161] = {.lex_state = 117, .external_lex_state = 8},
  [1162] = {.lex_state = 117, .external_lex_state = 8},
  [1163] = {.lex_state = 117, .external_lex_state = 8},
  [1164] = {.lex_state = 117, .external_lex_state = 8},
  [1165] = {.lex_state = 117, .external_lex_state = 8},
  [1166] = {.lex_state = 117, .external_lex_state = 8},
  [1167] = {.lex_state = 117, .external_lex_state = 8},
  [1168] = {.lex_state = 117, .external_lex_state = 8},
  [1169] = {.lex_state = 117, .external_lex_state = 8},
  [1170] = {.lex_state = 117, .external_lex_state = 8},
  [1171] = {.lex_state = 117, .external_lex_state = 8},
  [1172] = {.lex_state = 117, .external_lex_state = 8},
  [1173] = {.lex_state = 117, .external_lex_state = 8},
  [1174] = {.lex_state = 117, .external_lex_state = 8},
  [1175] = {.lex_state = 117, .external_lex_state = 8},
  [1176] = {.lex_state = 117, .external_lex_state = 8},
  [1177] = {.lex_state = 117, .external_lex_state = 8},
  [1178] = {.lex_state = 117, .external_lex_state = 8},
  [1179] = {.lex_state = 117, .external_lex_state = 8},
  [1180] = {.lex_state = 117, .external_lex_state = 8},
  [1181] = {.lex_state = 117, .external_lex_state = 8},
  [1182] = {.lex_state = 117, .external_lex_state = 8},
  [1183] = {.lex_state = 117, .external_lex_state = 8},
  [1184] = {.lex_state = 117, .external_lex_state = 8},
  [1185] = {.lex_state = 117, .external_lex_state = 8},
  [1186] = {.lex_state = 117, .external_lex_state = 8},
  [1187] = {.lex_state = 117, .external_lex_state = 8},
  [1188] = {.lex_state = 117, .external_lex_state = 8},
  [1189] = {.lex_state = 117, .external_lex_state = 8},
  [1190] = {.lex_state = 117, .external_lex_state = 8},
  [1191] = {.lex_state = 117, .external_lex_state = 8},
  [1192] = {.lex_state = 117, .external_lex_state = 8},
  [1193] = {.lex_state = 117, .external_lex_state = 8},
  [1194] = {.lex_state = 117, .external_lex_state = 8},
  [1195] = {.lex_state = 117, .external_lex_state = 8},
  [1196] = {.lex_state = 117, .external_lex_state = 8},
  [1197] = {.lex_state = 117, .external_lex_state = 8},
  [1198] = {.lex_state = 117, .external_lex_state = 8},
  [1199] = {.lex_state = 117, .external_lex_state = 8},
  [1200] = {.lex_state = 117, .external_lex_state = 8},
  [1201] = {.lex_state = 117, .external_lex_state = 8},
  [1202] = {.lex_state = 117, .external_lex_state = 8},
  [1203] = {.lex_state = 117, .external_lex_state = 8},
  [1204] = {.lex_state = 117, .external_lex_state = 8},
  [1205] = {.lex_state = 117, .external_lex_state = 8},
  [1206] = {.lex_state = 117, .external_lex_state = 8},
  [1207] = {.lex_state = 117, .external_lex_state = 8},
  [1208] = {.lex_state = 117, .external_lex_state = 8},
  [1209] = {.lex_state = 117, .external_lex_state = 8},
  [1210] = {.lex_state = 117, .external_lex_state = 8},
  [1211] = {.lex_state = 117, .external_lex_state = 8},
  [1212] = {.lex_state = 117, .external_lex_state = 8},
  [1213] = {.lex_state = 117, .external_lex_state = 8},
  [1214] = {.lex_state = 117, .external_lex_state = 8},
  [1215] = {.lex_state = 117, .external_lex_state = 8},
  [1216] = {.lex_state = 117, .external_lex_state = 8},
  [1217] = {.lex_state = 117, .external_lex_state = 8},
  [1218] = {.lex_state = 117, .external_lex_state = 8},
  [1219] = {.lex_state = 117, .external_lex_state = 8},
  [1220] = {.lex_state = 117, .external_lex_state = 8},
  [1221] = {.lex_state = 117, .external_lex_state = 8},
  [1222] = {.lex_state = 117, .external_lex_state = 8},
  [1223] = {.lex_state = 117, .external_lex_state = 8},
  [1224] = {.lex_state = 117, .external_lex_state = 8},
  [1225] = {.lex_state = 117, .external_lex_state = 8},
  [1226] = {.lex_state = 117, .external_lex_state = 8},
  [1227] = {.lex_state = 117, .external_lex_state = 8},
  [1228] = {.lex_state = 117, .external_lex_state = 8},
  [1229] = {.lex_state = 117, .external_lex_state = 8},
  [1230] = {.lex_state = 117, .external_lex_state = 8},
  [1231] = {.lex_state = 117, .external_lex_state = 8},
  [1232] = {.lex_state = 117, .external_lex_state = 8},
  [1233] = {.lex_state = 117, .external_lex_state = 8},
  [1234] = {.lex_state = 117, .external_lex_state = 8},
  [1235] = {.lex_state = 117, .external_lex_state = 8},
  [1236] = {.lex_state = 117, .external_lex_state = 8},
  [1237] = {.lex_state = 117, .external_lex_state = 8},
  [1238] = {.lex_state = 117, .external_lex_state = 8},
  [1239] = {.lex_state = 117, .external_lex_state = 8},
  [1240] = {.lex_state = 117, .external_lex_state = 8},
  [1241] = {.lex_state = 117, .external_lex_state = 8},
  [1242] = {.lex_state = 117, .external_lex_state = 8},
  [1243] = {.lex_state = 117, .external_lex_state = 8},
  [1244] = {.lex_state = 117, .external_lex_state = 8},
  [1245] = {.lex_state = 117, .external_lex_state = 8},
  [1246] = {.lex_state = 117, .external_lex_state = 8},
  [1247] = {.lex_state = 117, .external_lex_state = 8},
  [1248] = {.lex_state = 117, .external_lex_state = 8},
  [1249] = {.lex_state = 117, .external_lex_state = 8},
  [1250] = {.lex_state = 117, .external_lex_state = 8},
  [1251] = {.lex_state = 117, .external_lex_state = 8},
  [1252] = {.lex_state = 117, .external_lex_state = 8},
  [1253] = {.lex_state = 117, .external_lex_state = 8},
  [1254] = {.lex_state = 117, .external_lex_state = 8},
  [1255] = {.lex_state = 117, .external_lex_state = 8},
  [1256] = {.lex_state = 117, .external_lex_state = 8},
  [1257] = {.lex_state = 117, .external_lex_state = 8},
  [1258] = {.lex_state = 117, .external_lex_state = 8},
  [1259] = {.lex_state = 117, .external_lex_state = 8},
  [1260] = {.lex_state = 117, .external_lex_state = 8},
  [1261] = {.lex_state = 117, .external_lex_state = 8},
  [1262] = {.lex_state = 117, .external_lex_state = 8},
  [1263] = {.lex_state = 117, .external_lex_state = 8},
  [1264] = {.lex_state = 117, .external_lex_state = 8},
  [1265] = {.lex_state = 117, .external_lex_state = 8},
  [1266] = {.lex_state = 117, .external_lex_state = 8},
  [1267] = {.lex_state = 117, .external_lex_state = 8},
  [1268] = {.lex_state = 117, .external_lex_state = 8},
  [1269] = {.lex_state = 117, .external_lex_state = 8},
  [1270] = {.lex_state = 117, .external_lex_state = 8},
  [1271] = {.lex_state = 117, .external_lex_state = 8},
  [1272] = {.lex_state = 117, .external_lex_state = 8},
  [1273] = {.lex_state = 117, .external_lex_state = 8},
  [1274] = {.lex_state = 117, .external_lex_state = 8},
  [1275] = {.lex_state = 117, .external_lex_state = 8},
  [1276] = {.lex_state = 117, .external_lex_state = 8},
  [1277] = {.lex_state = 117, .external_lex_state = 8},
  [1278] = {.lex_state = 117, .external_lex_state = 8},
  [1279] = {.lex_state = 117, .external_lex_state = 8},
  [1280] = {.lex_state = 117, .external_lex_state = 8},
  [1281] = {.lex_state = 117, .external_lex_state = 8},
  [1282] = {.lex_state = 117, .external_lex_state = 8},
  [1283] = {.lex_state = 117, .external_lex_state = 8},
  [1284] = {.lex_state = 117, .external_lex_state = 8},
  [1285] = {.lex_state = 117, .external_lex_state = 8},
  [1286] = {.lex_state = 117, .external_lex_state = 8},
  [1287] = {.lex_state = 117, .external_lex_state = 8},
  [1288] = {.lex_state = 117, .external_lex_state = 8},
  [1289] = {.lex_state = 117, .external_lex_state = 8},
  [1290] = {.lex_state = 117, .external_lex_state = 8},
  [1291] = {.lex_state = 117, .external_lex_state = 8},
  [1292] = {.lex_state = 117, .external_lex_state = 8},
  [1293] = {.lex_state = 117, .external_lex_state = 8},
  [1294] = {.lex_state = 117, .external_lex_state = 8},
  [1295] = {.lex_state = 117, .external_lex_state = 8},
  [1296] = {.lex_state = 117, .external_lex_state = 8},
  [1297] = {.lex_state = 117, .external_lex_state = 8},
  [1298] = {.lex_state = 117, .external_lex_state = 8},
  [1299] = {.lex_state = 117, .external_lex_state = 8},
  [1300] = {.lex_state = 117, .external_lex_state = 8},
  [1301] = {.lex_state = 117, .external_lex_state = 8},
  [1302] = {.lex_state = 117, .external_lex_state = 8},
  [1303] = {.lex_state = 117, .external_lex_state = 8},
  [1304] = {.lex_state = 117, .external_lex_state = 8},
  [1305] = {.lex_state = 117, .external_lex_state = 8},
  [1306] = {.lex_state = 117, .external_lex_state = 8},
  [1307] = {.lex_state = 117, .external_lex_state = 8},
  [1308] = {.lex_state = 117, .external_lex_state = 8},
  [1309] = {.lex_state = 117, .external_lex_state = 8},
  [1310] = {.lex_state = 117, .external_lex_state = 8},
  [1311] = {.lex_state = 117, .external_lex_state = 8},
  [1312] = {.lex_state = 117, .external_lex_state = 8},
  [1313] = {.lex_state = 117, .external_lex_state = 8},
  [1314] = {.lex_state = 117, .external_lex_state = 8},
  [1315] = {.lex_state = 117, .external_lex_state = 8},
  [1316] = {.lex_state = 117, .external_lex_state = 8},
  [1317] = {.lex_state = 117, .external_lex_state = 8},
  [1318] = {.lex_state = 117, .external_lex_state = 8},
  [1319] = {.lex_state = 117, .external_lex_state = 8},
  [1320] = {.lex_state = 117, .external_lex_state = 8},
  [1321] = {.lex_state = 117, .external_lex_state = 8},
  [1322] = {.lex_state = 117, .external_lex_state = 8},
  [1323] = {.lex_state = 117, .external_lex_state = 8},
  [1324] = {.lex_state = 117, .external_lex_state = 8},
  [1325] = {.lex_state = 117, .external_lex_state = 8},
  [1326] = {.lex_state = 117, .external_lex_state = 8},
  [1327] = {.lex_state = 117, .external_lex_state = 8},
  [1328] = {.lex_state = 117, .external_lex_state = 8},
  [1329] = {.lex_state = 117, .external_lex_state = 8},
  [1330] = {.lex_state = 117, .external_lex_state = 8},
  [1331] = {.lex_state = 117, .external_lex_state = 8},
  [1332] = {.lex_state = 117, .external_lex_state = 8},
  [1333] = {.lex_state = 117, .external_lex_state = 8},
  [1334] = {.lex_state = 117, .external_lex_state = 8},
  [1335] = {.lex_state = 117, .external_lex_state = 8},
  [1336] = {.lex_state = 117, .external_lex_state = 8},
  [1337] = {.lex_state = 117, .external_lex_state = 8},
  [1338] = {.lex_state = 117, .external_lex_state = 8},
  [1339] = {.lex_state = 117, .external_lex_state = 8},
  [1340] = {.lex_state = 117, .external_lex_state = 8},
  [1341] = {.lex_state = 117, .external_lex_state = 8},
  [1342] = {.lex_state = 117, .external_lex_state = 8},
  [1343] = {.lex_state = 117, .external_lex_state = 8},
  [1344] = {.lex_state = 117, .external_lex_state = 8},
  [1345] = {.lex_state = 117, .external_lex_state = 8},
  [1346] = {.lex_state = 117, .external_lex_state = 8},
  [1347] = {.lex_state = 117, .external_lex_state = 8},
  [1348] = {.lex_state = 117, .external_lex_state = 8},
  [1349] = {.lex_state = 117, .external_lex_state = 8},
  [1350] = {.lex_state = 117, .external_lex_state = 8},
  [1351] = {.lex_state = 117, .external_lex_state = 8},
  [1352] = {.lex_state = 117, .external_lex_state = 8},
  [1353] = {.lex_state = 117, .external_lex_state = 8},
  [1354] = {.lex_state = 117, .external_lex_state = 8},
  [1355] = {.lex_state = 117, .external_lex_state = 8},
  [1356] = {.lex_state = 117, .external_lex_state = 8},
  [1357] = {.lex_state = 117, .external_lex_state = 8},
  [1358] = {.lex_state = 117, .external_lex_state = 8},
  [1359] = {.lex_state = 117, .external_lex_state = 8},
  [1360] = {.lex_state = 117, .external_lex_state = 8},
  [1361] = {.lex_state = 117, .external_lex_state = 8},
  [1362] = {.lex_state = 117, .external_lex_state = 8},
  [1363] = {.lex_state = 117, .external_lex_state = 8},
  [1364] = {.lex_state = 117, .external_lex_state = 8},
  [1365] = {.lex_state = 117, .external_lex_state = 8},
  [1366] = {.lex_state = 117, .external_lex_state = 8},
  [1367] = {.lex_state = 117, .external_lex_state = 8},
  [1368] = {.lex_state = 117, .external_lex_state = 8},
  [1369] = {.lex_state = 117, .external_lex_state = 8},
  [1370] = {.lex_state = 117, .external_lex_state = 8},
  [1371] = {.lex_state = 117, .external_lex_state = 8},
  [1372] = {.lex_state = 117, .external_lex_state = 8},
  [1373] = {.lex_state = 117, .external_lex_state = 8},
  [1374] = {.lex_state = 117, .external_lex_state = 8},
  [1375] = {.lex_state = 117, .external_lex_state = 8},
  [1376] = {.lex_state = 117, .external_lex_state = 8},
  [1377] = {.lex_state = 117, .external_lex_state = 8},
  [1378] = {.lex_state = 117, .external_lex_state = 8},
  [1379] = {.lex_state = 117, .external_lex_state = 8},
  [1380] = {.lex_state = 117, .external_lex_state = 8},
  [1381] = {.lex_state = 117, .external_lex_state = 8},
  [1382] = {.lex_state = 117, .external_lex_state = 8},
  [1383] = {.lex_state = 117, .external_lex_state = 8},
  [1384] = {.lex_state = 117, .external_lex_state = 8},
  [1385] = {.lex_state = 117, .external_lex_state = 8},
  [1386] = {.lex_state = 117, .external_lex_state = 8},
  [1387] = {.lex_state = 117, .external_lex_state = 8},
  [1388] = {.lex_state = 117, .external_lex_state = 8},
  [1389] = {.lex_state = 117, .external_lex_state = 8},
  [1390] = {.lex_state = 117, .external_lex_state = 8},
  [1391] = {.lex_state = 117, .external_lex_state = 8},
  [1392] = {.lex_state = 117, .external_lex_state = 8},
  [1393] = {.lex_state = 117, .external_lex_state = 8},
  [1394] = {.lex_state = 117, .external_lex_state = 8},
  [1395] = {.lex_state = 117, .external_lex_state = 8},
  [1396] = {.lex_state = 117, .external_lex_state = 8},
  [1397] = {.lex_state = 117, .external_lex_state = 8},
  [1398] = {.lex_state = 117, .external_lex_state = 8},
  [1399] = {.lex_state = 117, .external_lex_state = 8},
  [1400] = {.lex_state = 117, .external_lex_state = 8},
  [1401] = {.lex_state = 117, .external_lex_state = 8},
  [1402] = {.lex_state = 117, .external_lex_state = 8},
  [1403] = {.lex_state = 117, .external_lex_state = 8},
  [1404] = {.lex_state = 117, .external_lex_state = 8},
  [1405] = {.lex_state = 117, .external_lex_state = 8},
  [1406] = {.lex_state = 117, .external_lex_state = 8},
  [1407] = {.lex_state = 117, .external_lex_state = 8},
  [1408] = {.lex_state = 117, .external_lex_state = 8},
  [1409] = {.lex_state = 117, .external_lex_state = 8},
  [1410] = {.lex_state = 117, .external_lex_state = 8},
  [1411] = {.lex_state = 117, .external_lex_state = 8},
  [1412] = {.lex_state = 117, .external_lex_state = 8},
  [1413] = {.lex_state = 117, .external_lex_state = 8},
  [1414] = {.lex_state = 117, .external_lex_state = 8},
  [1415] = {.lex_state = 117, .external_lex_state = 8},
  [1416] = {.lex_state = 117, .external_lex_state = 8},
  [1417] = {.lex_state = 117, .external_lex_state = 8},
  [1418] = {.lex_state = 117, .external_lex_state = 8},
  [1419] = {.lex_state = 117, .external_lex_state = 8},
  [1420] = {.lex_state = 117, .external_lex_state = 8},
  [1421] = {.lex_state = 117, .external_lex_state = 8},
  [1422] = {.lex_state = 117, .external_lex_state = 8},
  [1423] = {.lex_state = 117, .external_lex_state = 8},
  [1424] = {.lex_state = 117, .external_lex_state = 8},
  [1425] = {.lex_state = 117, .external_lex_state = 8},
  [1426] = {.lex_state = 117, .external_lex_state = 8},
  [1427] = {.lex_state = 117, .external_lex_state = 8},
  [1428] = {.lex_state = 117, .external_lex_state = 8},
  [1429] = {.lex_state = 117, .external_lex_state = 8},
  [1430] = {.lex_state = 117, .external_lex_state = 8},
  [1431] = {.lex_state = 117, .external_lex_state = 8},
  [1432] = {.lex_state = 117, .external_lex_state = 8},
  [1433] = {.lex_state = 117, .external_lex_state = 8},
  [1434] = {.lex_state = 117, .external_lex_state = 8},
  [1435] = {.lex_state = 117, .external_lex_state = 8},
  [1436] = {.lex_state = 117, .external_lex_state = 8},
  [1437] = {.lex_state = 117, .external_lex_state = 8},
  [1438] = {.lex_state = 117, .external_lex_state = 8},
  [1439] = {.lex_state = 117, .external_lex_state = 8},
  [1440] = {.lex_state = 117, .external_lex_state = 8},
  [1441] = {.lex_state = 117, .external_lex_state = 8},
  [1442] = {.lex_state = 117, .external_lex_state = 8},
  [1443] = {.lex_state = 117, .external_lex_state = 8},
  [1444] = {.lex_state = 117, .external_lex_state = 8},
  [1445] = {.lex_state = 117, .external_lex_state = 8},
  [1446] = {.lex_state = 117, .external_lex_state = 8},
  [1447] = {.lex_state = 117, .external_lex_state = 8},
  [1448] = {.lex_state = 117, .external_lex_state = 8},
  [1449] = {.lex_state = 117, .external_lex_state = 8},
  [1450] = {.lex_state = 117, .external_lex_state = 8},
  [1451] = {.lex_state = 117, .external_lex_state = 8},
  [1452] = {.lex_state = 117, .external_lex_state = 8},
  [1453] = {.lex_state = 117, .external_lex_state = 8},
  [1454] = {.lex_state = 117, .external_lex_state = 8},
  [1455] = {.lex_state = 117, .external_lex_state = 8},
  [1456] = {.lex_state = 117, .external_lex_state = 8},
  [1457] = {.lex_state = 117, .external_lex_state = 8},
  [1458] = {.lex_state = 117, .external_lex_state = 8},
  [1459] = {.lex_state = 117, .external_lex_state = 8},
  [1460] = {.lex_state = 117, .external_lex_state = 8},
  [1461] = {.lex_state = 117, .external_lex_state = 8},
  [1462] = {.lex_state = 117, .external_lex_state = 8},
  [1463] = {.lex_state = 117, .external_lex_state = 8},
  [1464] = {.lex_state = 117, .external_lex_state = 8},
  [1465] = {.lex_state = 117, .external_lex_state = 8},
  [1466] = {.lex_state = 117, .external_lex_state = 8},
  [1467] = {.lex_state = 117, .external_lex_state = 8},
  [1468] = {.lex_state = 117, .external_lex_state = 8},
  [1469] = {.lex_state = 117, .external_lex_state = 8},
  [1470] = {.lex_state = 117, .external_lex_state = 8},
  [1471] = {.lex_state = 117, .external_lex_state = 8},
  [1472] = {.lex_state = 117, .external_lex_state = 8},
  [1473] = {.lex_state = 117, .external_lex_state = 8},
  [1474] = {.lex_state = 117, .external_lex_state = 8},
  [1475] = {.lex_state = 117, .external_lex_state = 8},
  [1476] = {.lex_state = 117, .external_lex_state = 8},
  [1477] = {.lex_state = 117, .external_lex_state = 8},
  [1478] = {.lex_state = 117, .external_lex_state = 8},
  [1479] = {.lex_state = 117, .external_lex_state = 8},
  [1480] = {.lex_state = 117, .external_lex_state = 8},
  [1481] = {.lex_state = 117, .external_lex_state = 8},
  [1482] = {.lex_state = 117, .external_lex_state = 8},
  [1483] = {.lex_state = 117, .external_lex_state = 8},
  [1484] = {.lex_state = 117, .external_lex_state = 8},
  [1485] = {.lex_state = 117, .external_lex_state = 8},
  [1486] = {.lex_state = 117, .external_lex_state = 8},
  [1487] = {.lex_state = 117, .external_lex_state = 8},
  [1488] = {.lex_state = 117, .external_lex_state = 8},
  [1489] = {.lex_state = 117, .external_lex_state = 8},
  [1490] = {.lex_state = 117, .external_lex_state = 8},
  [1491] = {.lex_state = 117, .external_lex_state = 8},
  [1492] = {.lex_state = 117, .external_lex_state = 8},
  [1493] = {.lex_state = 117, .external_lex_state = 8},
  [1494] = {.lex_state = 117, .external_lex_state = 8},
  [1495] = {.lex_state = 117, .external_lex_state = 8},
  [1496] = {.lex_state = 117, .external_lex_state = 8},
  [1497] = {.lex_state = 117, .external_lex_state = 8},
  [1498] = {.lex_state = 117, .external_lex_state = 8},
  [1499] = {.lex_state = 117, .external_lex_state = 8},
  [1500] = {.lex_state = 117, .external_lex_state = 8},
  [1501] = {.lex_state = 117, .external_lex_state = 8},
  [1502] = {.lex_state = 117, .external_lex_state = 8},
  [1503] = {.lex_state = 117, .external_lex_state = 8},
  [1504] = {.lex_state = 117, .external_lex_state = 8},
  [1505] = {.lex_state = 117, .external_lex_state = 8},
  [1506] = {.lex_state = 117, .external_lex_state = 8},
  [1507] = {.lex_state = 117, .external_lex_state = 8},
  [1508] = {.lex_state = 117, .external_lex_state = 8},
  [1509] = {.lex_state = 117, .external_lex_state = 8},
  [1510] = {.lex_state = 117, .external_lex_state = 8},
  [1511] = {.lex_state = 117, .external_lex_state = 8},
  [1512] = {.lex_state = 117, .external_lex_state = 8},
  [1513] = {.lex_state = 117, .external_lex_state = 8},
  [1514] = {.lex_state = 117, .external_lex_state = 8},
  [1515] = {.lex_state = 117, .external_lex_state = 8},
  [1516] = {.lex_state = 117, .external_lex_state = 8},
  [1517] = {.lex_state = 117, .external_lex_state = 8},
  [1518] = {.lex_state = 117, .external_lex_state = 8},
  [1519] = {.lex_state = 117, .external_lex_state = 8},
  [1520] = {.lex_state = 117, .external_lex_state = 8},
  [1521] = {.lex_state = 117, .external_lex_state = 8},
  [1522] = {.lex_state = 117, .external_lex_state = 8},
  [1523] = {.lex_state = 117, .external_lex_state = 8},
  [1524] = {.lex_state = 117, .external_lex_state = 8},
  [1525] = {.lex_state = 117, .external_lex_state = 8},
  [1526] = {.lex_state = 117, .external_lex_state = 8},
  [1527] = {.lex_state = 117, .external_lex_state = 8},
  [1528] = {.lex_state = 117, .external_lex_state = 8},
  [1529] = {.lex_state = 117, .external_lex_state = 8},
  [1530] = {.lex_state = 117, .external_lex_state = 8},
  [1531] = {.lex_state = 117, .external_lex_state = 8},
  [1532] = {.lex_state = 117, .external_lex_state = 8},
  [1533] = {.lex_state = 117, .external_lex_state = 8},
  [1534] = {.lex_state = 117, .external_lex_state = 8},
  [1535] = {.lex_state = 117, .external_lex_state = 8},
  [1536] = {.lex_state = 117, .external_lex_state = 8},
  [1537] = {.lex_state = 117, .external_lex_state = 8},
  [1538] = {.lex_state = 117, .external_lex_state = 8},
  [1539] = {.lex_state = 117, .external_lex_state = 8},
  [1540] = {.lex_state = 117, .external_lex_state = 8},
  [1541] = {.lex_state = 117, .external_lex_state = 8},
  [1542] = {.lex_state = 117, .external_lex_state = 8},
  [1543] = {.lex_state = 117, .external_lex_state = 8},
  [1544] = {.lex_state = 117, .external_lex_state = 8},
  [1545] = {.lex_state = 117, .external_lex_state = 8},
  [1546] = {.lex_state = 117, .external_lex_state = 8},
  [1547] = {.lex_state = 117, .external_lex_state = 8},
  [1548] = {.lex_state = 117, .external_lex_state = 8},
  [1549] = {.lex_state = 117, .external_lex_state = 8},
  [1550] = {.lex_state = 117, .external_lex_state = 8},
  [1551] = {.lex_state = 117, .external_lex_state = 8},
  [1552] = {.lex_state = 117, .external_lex_state = 8},
  [1553] = {.lex_state = 117, .external_lex_state = 8},
  [1554] = {.lex_state = 117, .external_lex_state = 8},
  [1555] = {.lex_state = 117, .external_lex_state = 8},
  [1556] = {.lex_state = 117, .external_lex_state = 8},
  [1557] = {.lex_state = 117, .external_lex_state = 8},
  [1558] = {.lex_state = 117, .external_lex_state = 8},
  [1559] = {.lex_state = 117, .external_lex_state = 8},
  [1560] = {.lex_state = 117, .external_lex_state = 8},
  [1561] = {.lex_state = 117, .external_lex_state = 8},
  [1562] = {.lex_state = 117, .external_lex_state = 8},
  [1563] = {.lex_state = 117, .external_lex_state = 8},
  [1564] = {.lex_state = 117, .external_lex_state = 8},
  [1565] = {.lex_state = 117, .external_lex_state = 8},
  [1566] = {.lex_state = 117, .external_lex_state = 8},
  [1567] = {.lex_state = 117, .external_lex_state = 8},
  [1568] = {.lex_state = 117, .external_lex_state = 8},
  [1569] = {.lex_state = 117, .external_lex_state = 8},
  [1570] = {.lex_state = 117, .external_lex_state = 8},
  [1571] = {.lex_state = 117, .external_lex_state = 8},
  [1572] = {.lex_state = 117, .external_lex_state = 8},
  [1573] = {.lex_state = 117, .external_lex_state = 8},
  [1574] = {.lex_state = 117, .external_lex_state = 8},
  [1575] = {.lex_state = 117, .external_lex_state = 8},
  [1576] = {.lex_state = 117, .external_lex_state = 8},
  [1577] = {.lex_state = 117, .external_lex_state = 8},
  [1578] = {.lex_state = 117, .external_lex_state = 8},
  [1579] = {.lex_state = 117, .external_lex_state = 8},
  [1580] = {.lex_state = 117, .external_lex_state = 8},
  [1581] = {.lex_state = 117, .external_lex_state = 8},
  [1582] = {.lex_state = 117, .external_lex_state = 8},
  [1583] = {.lex_state = 117, .external_lex_state = 8},
  [1584] = {.lex_state = 117, .external_lex_state = 8},
  [1585] = {.lex_state = 117, .external_lex_state = 8},
  [1586] = {.lex_state = 117, .external_lex_state = 8},
  [1587] = {.lex_state = 117, .external_lex_state = 8},
  [1588] = {.lex_state = 117, .external_lex_state = 8},
  [1589] = {.lex_state = 117, .external_lex_state = 8},
  [1590] = {.lex_state = 117, .external_lex_state = 8},
  [1591] = {.lex_state = 117, .external_lex_state = 8},
  [1592] = {.lex_state = 117, .external_lex_state = 8},
  [1593] = {.lex_state = 117, .external_lex_state = 8},
  [1594] = {.lex_state = 117, .external_lex_state = 8},
  [1595] = {.lex_state = 117, .external_lex_state = 8},
  [1596] = {.lex_state = 117, .external_lex_state = 8},
  [1597] = {.lex_state = 117, .external_lex_state = 8},
  [1598] = {.lex_state = 117, .external_lex_state = 8},
  [1599] = {.lex_state = 117, .external_lex_state = 8},
  [1600] = {.lex_state = 117, .external_lex_state = 8},
  [1601] = {.lex_state = 117, .external_lex_state = 8},
  [1602] = {.lex_state = 117, .external_lex_state = 8},
  [1603] = {.lex_state = 117, .external_lex_state = 8},
  [1604] = {.lex_state = 117, .external_lex_state = 8},
  [1605] = {.lex_state = 117, .external_lex_state = 8},
  [1606] = {.lex_state = 117, .external_lex_state = 8},
  [1607] = {.lex_state = 117, .external_lex_state = 8},
  [1608] = {.lex_state = 117, .external_lex_state = 8},
  [1609] = {.lex_state = 117, .external_lex_state = 8},
  [1610] = {.lex_state = 117, .external_lex_state = 8},
  [1611] = {.lex_state = 117, .external_lex_state = 8},
  [1612] = {.lex_state = 117, .external_lex_state = 8},
  [1613] = {.lex_state = 117, .external_lex_state = 8},
  [1614] = {.lex_state = 117, .external_lex_state = 8},
  [1615] = {.lex_state = 117, .external_lex_state = 8},
  [1616] = {.lex_state = 117, .external_lex_state = 8},
  [1617] = {.lex_state = 117, .external_lex_state = 8},
  [1618] = {.lex_state = 117, .external_lex_state = 8},
  [1619] = {.lex_state = 117, .external_lex_state = 8},
  [1620] = {.lex_state = 117, .external_lex_state = 8},
  [1621] = {.lex_state = 117, .external_lex_state = 8},
  [1622] = {.lex_state = 117, .external_lex_state = 8},
  [1623] = {.lex_state = 117, .external_lex_state = 8},
  [1624] = {.lex_state = 117, .external_lex_state = 8},
  [1625] = {.lex_state = 117, .external_lex_state = 8},
  [1626] = {.lex_state = 117, .external_lex_state = 8},
  [1627] = {.lex_state = 117, .external_lex_state = 8},
  [1628] = {.lex_state = 117, .external_lex_state = 8},
  [1629] = {.lex_state = 117, .external_lex_state = 8},
  [1630] = {.lex_state = 117, .external_lex_state = 8},
  [1631] = {.lex_state = 117, .external_lex_state = 8},
  [1632] = {.lex_state = 117, .external_lex_state = 8},
  [1633] = {.lex_state = 117, .external_lex_state = 8},
  [1634] = {.lex_state = 117, .external_lex_state = 8},
  [1635] = {.lex_state = 117, .external_lex_state = 8},
  [1636] = {.lex_state = 117, .external_lex_state = 8},
  [1637] = {.lex_state = 117, .external_lex_state = 8},
  [1638] = {.lex_state = 117, .external_lex_state = 8},
  [1639] = {.lex_state = 117, .external_lex_state = 8},
  [1640] = {.lex_state = 117, .external_lex_state = 8},
  [1641] = {.lex_state = 117, .external_lex_state = 8},
  [1642] = {.lex_state = 117, .external_lex_state = 8},
  [1643] = {.lex_state = 117, .external_lex_state = 8},
  [1644] = {.lex_state = 117, .external_lex_state = 8},
  [1645] = {.lex_state = 117, .external_lex_state = 8},
  [1646] = {.lex_state = 117, .external_lex_state = 8},
  [1647] = {.lex_state = 117, .external_lex_state = 8},
  [1648] = {.lex_state = 117, .external_lex_state = 8},
  [1649] = {.lex_state = 117, .external_lex_state = 8},
  [1650] = {.lex_state = 117, .external_lex_state = 8},
  [1651] = {.lex_state = 117, .external_lex_state = 8},
  [1652] = {.lex_state = 117, .external_lex_state = 8},
  [1653] = {.lex_state = 117, .external_lex_state = 8},
  [1654] = {.lex_state = 117, .external_lex_state = 8},
  [1655] = {.lex_state = 117, .external_lex_state = 8},
  [1656] = {.lex_state = 117, .external_lex_state = 8},
  [1657] = {.lex_state = 117, .external_lex_state = 8},
  [1658] = {.lex_state = 117, .external_lex_state = 8},
  [1659] = {.lex_state = 117, .external_lex_state = 8},
  [1660] = {.lex_state = 117, .external_lex_state = 8},
  [1661] = {.lex_state = 6, .external_lex_state = 7},
  [1662] = {.lex_state = 117, .external_lex_state = 8},
  [1663] = {.lex_state = 117, .external_lex_state = 8},
  [1664] = {.lex_state = 117, .external_lex_state = 8},
  [1665] = {.lex_state = 117, .external_lex_state = 8},
  [1666] = {.lex_state = 117, .external_lex_state = 8},
  [1667] = {.lex_state = 117, .external_lex_state = 8},
  [1668] = {.lex_state = 117, .external_lex_state = 8},
  [1669] = {.lex_state = 117, .external_lex_state = 8},
  [1670] = {.lex_state = 117, .external_lex_state = 8},
  [1671] = {.lex_state = 117, .external_lex_state = 8},
  [1672] = {.lex_state = 117, .external_lex_state = 8},
  [1673] = {.lex_state = 117, .external_lex_state = 8},
  [1674] = {.lex_state = 117, .external_lex_state = 8},
  [1675] = {.lex_state = 117, .external_lex_state = 8},
  [1676] = {.lex_state = 117, .external_lex_state = 8},
  [1677] = {.lex_state = 117, .external_lex_state = 8},
  [1678] = {.lex_state = 117, .external_lex_state = 8},
  [1679] = {.lex_state = 117, .external_lex_state = 8},
  [1680] = {.lex_state = 117, .external_lex_state = 8},
  [1681] = {.lex_state = 117, .external_lex_state = 8},
  [1682] = {.lex_state = 117, .external_lex_state = 8},
  [1683] = {.lex_state = 117, .external_lex_state = 8},
  [1684] = {.lex_state = 117, .external_lex_state = 8},
  [1685] = {.lex_state = 117, .external_lex_state = 8},
  [1686] = {.lex_state = 117, .external_lex_state = 8},
  [1687] = {.lex_state = 117, .external_lex_state = 8},
  [1688] = {.lex_state = 117, .external_lex_state = 8},
  [1689] = {.lex_state = 117, .external_lex_state = 8},
  [1690] = {.lex_state = 117, .external_lex_state = 8},
  [1691] = {.lex_state = 117, .external_lex_state = 8},
  [1692] = {.lex_state = 117, .external_lex_state = 8},
  [1693] = {.lex_state = 117, .external_lex_state = 8},
  [1694] = {.lex_state = 117, .external_lex_state = 8},
  [1695] = {.lex_state = 117, .external_lex_state = 8},
  [1696] = {.lex_state = 117, .external_lex_state = 8},
  [1697] = {.lex_state = 117, .external_lex_state = 8},
  [1698] = {.lex_state = 117, .external_lex_state = 8},
  [1699] = {.lex_state = 117, .external_lex_state = 8},
  [1700] = {.lex_state = 117, .external_lex_state = 8},
  [1701] = {.lex_state = 117, .external_lex_state = 8},
  [1702] = {.lex_state = 117, .external_lex_state = 8},
  [1703] = {.lex_state = 117, .external_lex_state = 8},
  [1704] = {.lex_state = 117, .external_lex_state = 8},
  [1705] = {.lex_state = 117, .external_lex_state = 8},
  [1706] = {.lex_state = 117, .external_lex_state = 8},
  [1707] = {.lex_state = 117, .external_lex_state = 8},
  [1708] = {.lex_state = 117, .external_lex_state = 8},
  [1709] = {.lex_state = 117, .external_lex_state = 8},
  [1710] = {.lex_state = 117, .external_lex_state = 8},
  [1711] = {.lex_state = 117, .external_lex_state = 8},
  [1712] = {.lex_state = 117, .external_lex_state = 8},
  [1713] = {.lex_state = 117, .external_lex_state = 8},
  [1714] = {.lex_state = 117, .external_lex_state = 10},
  [1715] = {.lex_state = 117, .external_lex_state = 8},
  [1716] = {.lex_state = 117, .external_lex_state = 8},
  [1717] = {.lex_state = 117, .external_lex_state = 8},
  [1718] = {.lex_state = 117, .external_lex_state = 8},
  [1719] = {.lex_state = 117, .external_lex_state = 8},
  [1720] = {.lex_state = 117, .external_lex_state = 8},
  [1721] = {.lex_state = 117, .external_lex_state = 8},
  [1722] = {.lex_state = 117, .external_lex_state = 8},
  [1723] = {.lex_state = 117, .external_lex_state = 8},
  [1724] = {.lex_state = 117, .external_lex_state = 8},
  [1725] = {.lex_state = 117, .external_lex_state = 8},
  [1726] = {.lex_state = 117, .external_lex_state = 8},
  [1727] = {.lex_state = 117, .external_lex_state = 8},
  [1728] = {.lex_state = 117, .external_lex_state = 8},
  [1729] = {.lex_state = 117, .external_lex_state = 10},
  [1730] = {.lex_state = 117, .external_lex_state = 10},
  [1731] = {.lex_state = 117, .external_lex_state = 8},
  [1732] = {.lex_state = 117, .external_lex_state = 8},
  [1733] = {.lex_state = 117, .external_lex_state = 8},
  [1734] = {.lex_state = 117, .external_lex_state = 8},
  [1735] = {.lex_state = 117, .external_lex_state = 8},
  [1736] = {.lex_state = 117, .external_lex_state = 10},
  [1737] = {.lex_state = 117, .external_lex_state = 8},
  [1738] = {.lex_state = 117, .external_lex_state = 8},
  [1739] = {.lex_state = 117, .external_lex_state = 8},
  [1740] = {.lex_state = 117, .external_lex_state = 8},
  [1741] = {.lex_state = 117, .external_lex_state = 8},
  [1742] = {.lex_state = 117, .external_lex_state = 8},
  [1743] = {.lex_state = 117, .external_lex_state = 8},
  [1744] = {.lex_state = 117, .external_lex_state = 8},
  [1745] = {.lex_state = 117, .external_lex_state = 8},
  [1746] = {.lex_state = 117, .external_lex_state = 8},
  [1747] = {.lex_state = 117, .external_lex_state = 8},
  [1748] = {.lex_state = 117, .external_lex_state = 8},
  [1749] = {.lex_state = 117, .external_lex_state = 8},
  [1750] = {.lex_state = 117, .external_lex_state = 8},
  [1751] = {.lex_state = 117, .external_lex_state = 8},
  [1752] = {.lex_state = 117, .external_lex_state = 8},
  [1753] = {.lex_state = 117, .external_lex_state = 8},
  [1754] = {.lex_state = 117, .external_lex_state = 8},
  [1755] = {.lex_state = 117, .external_lex_state = 8},
  [1756] = {.lex_state = 117, .external_lex_state = 8},
  [1757] = {.lex_state = 117, .external_lex_state = 8},
  [1758] = {.lex_state = 117, .external_lex_state = 8},
  [1759] = {.lex_state = 117, .external_lex_state = 8},
  [1760] = {.lex_state = 117, .external_lex_state = 8},
  [1761] = {.lex_state = 117, .external_lex_state = 8},
  [1762] = {.lex_state = 117, .external_lex_state = 8},
  [1763] = {.lex_state = 117, .external_lex_state = 8},
  [1764] = {.lex_state = 117, .external_lex_state = 8},
  [1765] = {.lex_state = 117, .external_lex_state = 8},
  [1766] = {.lex_state = 117, .external_lex_state = 8},
  [1767] = {.lex_state = 117, .external_lex_state = 10},
  [1768] = {.lex_state = 117, .external_lex_state = 10},
  [1769] = {.lex_state = 117, .external_lex_state = 8},
  [1770] = {.lex_state = 117, .external_lex_state = 10},
  [1771] = {.lex_state = 6, .external_lex_state = 3},
  [1772] = {.lex_state = 6, .external_lex_state = 3},
  [1773] = {.lex_state = 6, .external_lex_state = 3},
  [1774] = {.lex_state = 6, .external_lex_state = 3},
  [1775] = {.lex_state = 6, .external_lex_state = 3},
  [1776] = {.lex_state = 6, .external_lex_state = 3},
  [1777] = {.lex_state = 6, .external_lex_state = 3},
  [1778] = {.lex_state = 6, .external_lex_state = 3},
  [1779] = {.lex_state = 6, .external_lex_state = 3},
  [1780] = {.lex_state = 6, .external_lex_state = 3},
  [1781] = {.lex_state = 6, .external_lex_state = 3},
  [1782] = {.lex_state = 6, .external_lex_state = 3},
  [1783] = {.lex_state = 6, .external_lex_state = 3},
  [1784] = {.lex_state = 6, .external_lex_state = 3},
  [1785] = {.lex_state = 6, .external_lex_state = 3},
  [1786] = {.lex_state = 6, .external_lex_state = 3},
  [1787] = {.lex_state = 6, .external_lex_state = 3},
  [1788] = {.lex_state = 6, .external_lex_state = 3},
  [1789] = {.lex_state = 6, .external_lex_state = 3},
  [1790] = {.lex_state = 6, .external_lex_state = 3},
  [1791] = {.lex_state = 6, .external_lex_state = 3},
  [1792] = {.lex_state = 6, .external_lex_state = 3},
  [1793] = {.lex_state = 6, .external_lex_state = 3},
  [1794] = {.lex_state = 6, .external_lex_state = 3},
  [1795] = {.lex_state = 6, .external_lex_state = 3},
  [1796] = {.lex_state = 6, .external_lex_state = 3},
  [1797] = {.lex_state = 6, .external_lex_state = 3},
  [1798] = {.lex_state = 6, .external_lex_state = 3},
  [1799] = {.lex_state = 6, .external_lex_state = 3},
  [1800] = {.lex_state = 6, .external_lex_state = 3},
  [1801] = {.lex_state = 6, .external_lex_state = 3},
  [1802] = {.lex_state = 6, .external_lex_state = 3},
  [1803] = {.lex_state = 6, .external_lex_state = 3},
  [1804] = {.lex_state = 6, .external_lex_state = 3},
  [1805] = {.lex_state = 6, .external_lex_state = 3},
  [1806] = {.lex_state = 6, .external_lex_state = 3},
  [1807] = {.lex_state = 6, .external_lex_state = 3},
  [1808] = {.lex_state = 6, .external_lex_state = 3},
  [1809] = {.lex_state = 6, .external_lex_state = 3},
  [1810] = {.lex_state = 6, .external_lex_state = 3},
  [1811] = {.lex_state = 6, .external_lex_state = 3},
  [1812] = {.lex_state = 6, .external_lex_state = 3},
  [1813] = {.lex_state = 6, .external_lex_state = 3},
  [1814] = {.lex_state = 6, .external_lex_state = 3},
  [1815] = {.lex_state = 6, .external_lex_state = 3},
  [1816] = {.lex_state = 6, .external_lex_state = 3},
  [1817] = {.lex_state = 6, .external_lex_state = 3},
  [1818] = {.lex_state = 6, .external_lex_state = 3},
  [1819] = {.lex_state = 6, .external_lex_state = 3},
  [1820] = {.lex_state = 6, .external_lex_state = 3},
  [1821] = {.lex_state = 6, .external_lex_state = 3},
  [1822] = {.lex_state = 6, .external_lex_state = 3},
  [1823] = {.lex_state = 6, .external_lex_state = 3},
  [1824] = {.lex_state = 6, .external_lex_state = 3},
  [1825] = {.lex_state = 6, .external_lex_state = 3},
  [1826] = {.lex_state = 6, .external_lex_state = 3},
  [1827] = {.lex_state = 117, .external_lex_state = 10},
  [1828] = {.lex_state = 117, .external_lex_state = 10},
  [1829] = {.lex_state = 117, .external_lex_state = 10},
  [1830] = {.lex_state = 6, .external_lex_state = 3},
  [1831] = {.lex_state = 6, .external_lex_state = 3},
  [1832] = {.lex_state = 6, .external_lex_state = 3},
  [1833] = {.lex_state = 6, .external_lex_state = 3},
  [1834] = {.lex_state = 117, .external_lex_state = 10},
  [1835] = {.lex_state = 6, .external_lex_state = 3},
  [1836] = {.lex_state = 6, .external_lex_state = 3},
  [1837] = {.lex_state = 6, .external_lex_state = 3},
  [1838] = {.lex_state = 6, .external_lex_state = 3},
  [1839] = {.lex_state = 6, .external_lex_state = 3},
  [1840] = {.lex_state = 6, .external_lex_state = 3},
  [1841] = {.lex_state = 6, .external_lex_state = 3},
  [1842] = {.lex_state = 6, .external_lex_state = 3},
  [1843] = {.lex_state = 6, .external_lex_state = 3},
  [1844] = {.lex_state = 6, .external_lex_state = 3},
  [1845] = {.lex_state = 6, .external_lex_state = 3},
  [1846] = {.lex_state = 6, .external_lex_state = 3},
  [1847] = {.lex_state = 6, .external_lex_state = 3},
  [1848] = {.lex_state = 6, .external_lex_state = 3},
  [1849] = {.lex_state = 6, .external_lex_state = 3},
  [1850] = {.lex_state = 6, .external_lex_state = 3},
  [1851] = {.lex_state = 6, .external_lex_state = 3},
  [1852] = {.lex_state = 6, .external_lex_state = 3},
  [1853] = {.lex_state = 6, .external_lex_state = 3},
  [1854] = {.lex_state = 6, .external_lex_state = 3},
  [1855] = {.lex_state = 6, .external_lex_state = 3},
  [1856] = {.lex_state = 6, .external_lex_state = 3},
  [1857] = {.lex_state = 6, .external_lex_state = 3},
  [1858] = {.lex_state = 6, .external_lex_state = 3},
  [1859] = {.lex_state = 6, .external_lex_state = 3},
  [1860] = {.lex_state = 6, .external_lex_state = 3},
  [1861] = {.lex_state = 11, .external_lex_state = 8},
  [1862] = {.lex_state = 11, .external_lex_state = 8},
  [1863] = {.lex_state = 11, .external_lex_state = 8},
  [1864] = {.lex_state = 11, .external_lex_state = 8},
  [1865] = {.lex_state = 11, .external_lex_state = 8},
  [1866] = {.lex_state = 11, .external_lex_state = 8},
  [1867] = {.lex_state = 11, .external_lex_state = 8},
  [1868] = {.lex_state = 6, .external_lex_state = 3},
  [1869] = {.lex_state = 11, .external_lex_state = 8},
  [1870] = {.lex_state = 11, .external_lex_state = 8},
  [1871] = {.lex_state = 11, .external_lex_state = 8},
  [1872] = {.lex_state = 11, .external_lex_state = 8},
  [1873] = {.lex_state = 6, .external_lex_state = 8},
  [1874] = {.lex_state = 6, .external_lex_state = 8},
  [1875] = {.lex_state = 6, .external_lex_state = 8},
  [1876] = {.lex_state = 6, .external_lex_state = 8},
  [1877] = {.lex_state = 6, .external_lex_state = 8},
  [1878] = {.lex_state = 6, .external_lex_state = 8},
  [1879] = {.lex_state = 6, .external_lex_state = 8},
  [1880] = {.lex_state = 6, .external_lex_state = 8},
  [1881] = {.lex_state = 6, .external_lex_state = 8},
  [1882] = {.lex_state = 6, .external_lex_state = 8},
  [1883] = {.lex_state = 6, .external_lex_state = 8},
  [1884] = {.lex_state = 6, .external_lex_state = 8},
  [1885] = {.lex_state = 6, .external_lex_state = 8},
  [1886] = {.lex_state = 6, .external_lex_state = 8},
  [1887] = {.lex_state = 6, .external_lex_state = 8},
  [1888] = {.lex_state = 6, .external_lex_state = 8},
  [1889] = {.lex_state = 6, .external_lex_state = 8},
  [1890] = {.lex_state = 6, .external_lex_state = 8},
  [1891] = {.lex_state = 6, .external_lex_state = 8},
  [1892] = {.lex_state = 6, .external_lex_state = 8},
  [1893] = {.lex_state = 6, .external_lex_state = 8},
  [1894] = {.lex_state = 6, .external_lex_state = 8},
  [1895] = {.lex_state = 6, .external_lex_state = 8},
  [1896] = {.lex_state = 6, .external_lex_state = 8},
  [1897] = {.lex_state = 6, .external_lex_state = 8},
  [1898] = {.lex_state = 6, .external_lex_state = 8},
  [1899] = {.lex_state = 117, .external_lex_state = 10},
  [1900] = {.lex_state = 117, .external_lex_state = 10},
  [1901] = {.lex_state = 117, .external_lex_state = 10},
  [1902] = {.lex_state = 117, .external_lex_state = 10},
  [1903] = {.lex_state = 6, .external_lex_state = 8},
  [1904] = {.lex_state = 6, .external_lex_state = 8},
  [1905] = {.lex_state = 117, .external_lex_state = 10},
  [1906] = {.lex_state = 6, .external_lex_state = 8},
  [1907] = {.lex_state = 6, .external_lex_state = 8},
  [1908] = {.lex_state = 6, .external_lex_state = 8},
  [1909] = {.lex_state = 6, .external_lex_state = 8},
  [1910] = {.lex_state = 6, .external_lex_state = 8},
  [1911] = {.lex_state = 6, .external_lex_state = 8},
  [1912] = {.lex_state = 6, .external_lex_state = 8},
  [1913] = {.lex_state = 6, .external_lex_state = 8},
  [1914] = {.lex_state = 6, .external_lex_state = 8},
  [1915] = {.lex_state = 117, .external_lex_state = 10},
  [1916] = {.lex_state = 6, .external_lex_state = 8},
  [1917] = {.lex_state = 6, .external_lex_state = 8},
  [1918] = {.lex_state = 6, .external_lex_state = 8},
  [1919] = {.lex_state = 6, .external_lex_state = 8},
  [1920] = {.lex_state = 6, .external_lex_state = 8},
  [1921] = {.lex_state = 6, .external_lex_state = 8},
  [1922] = {.lex_state = 117, .external_lex_state = 10},
  [1923] = {.lex_state = 117, .external_lex_state = 10},
  [1924] = {.lex_state = 6, .external_lex_state = 8},
  [1925] = {.lex_state = 6, .external_lex_state = 8},
  [1926] = {.lex_state = 6, .external_lex_state = 8},
  [1927] = {.lex_state = 6, .external_lex_state = 8},
  [1928] = {.lex_state = 6, .external_lex_state = 8},
  [1929] = {.lex_state = 6, .external_lex_state = 8},
  [1930] = {.lex_state = 6, .external_lex_state = 8},
  [1931] = {.lex_state = 6, .external_lex_state = 8},
  [1932] = {.lex_state = 6, .external_lex_state = 8},
  [1933] = {.lex_state = 6, .external_lex_state = 8},
  [1934] = {.lex_state = 6, .external_lex_state = 8},
  [1935] = {.lex_state = 6, .external_lex_state = 8},
  [1936] = {.lex_state = 6, .external_lex_state = 8},
  [1937] = {.lex_state = 6, .external_lex_state = 8},
  [1938] = {.lex_state = 6, .external_lex_state = 8},
  [1939] = {.lex_state = 6, .external_lex_state = 7},
  [1940] = {.lex_state = 6, .external_lex_state = 8},
  [1941] = {.lex_state = 6, .external_lex_state = 8},
  [1942] = {.lex_state = 6, .external_lex_state = 7},
  [1943] = {.lex_state = 117, .external_lex_state = 10},
  [1944] = {.lex_state = 6, .external_lex_state = 7},
  [1945] = {.lex_state = 6, .external_lex_state = 8},
  [1946] = {.lex_state = 6, .external_lex_state = 8},
  [1947] = {.lex_state = 6, .external_lex_state = 8},
  [1948] = {.lex_state = 6, .external_lex_state = 7},
  [1949] = {.lex_state = 117, .external_lex_state = 12},
  [1950] = {.lex_state = 6, .external_lex_state = 7},
  [1951] = {.lex_state = 117, .external_lex_state = 10},
  [1952] = {.lex_state = 6, .external_lex_state = 7},
  [1953] = {.lex_state = 6, .external_lex_state = 8},
  [1954] = {.lex_state = 6, .external_lex_state = 7},
  [1955] = {.lex_state = 6, .external_lex_state = 7},
  [1956] = {.lex_state = 6, .external_lex_state = 7},
  [1957] = {.lex_state = 6, .external_lex_state = 8},
  [1958] = {.lex_state = 6, .external_lex_state = 8},
  [1959] = {.lex_state = 6, .external_lex_state = 7},
  [1960] = {.lex_state = 6, .external_lex_state = 7},
  [1961] = {.lex_state = 6, .external_lex_state = 7},
  [1962] = {.lex_state = 6, .external_lex_state = 7},
  [1963] = {.lex_state = 6, .external_lex_state = 7},
  [1964] = {.lex_state = 6, .external_lex_state = 7},
  [1965] = {.lex_state = 117, .external_lex_state = 6},
  [1966] = {.lex_state = 117, .external_lex_state = 10},
  [1967] = {.lex_state = 6, .external_lex_state = 7},
  [1968] = {.lex_state = 6, .external_lex_state = 7},
  [1969] = {.lex_state = 6, .external_lex_state = 7},
  [1970] = {.lex_state = 117, .external_lex_state = 10},
  [1971] = {.lex_state = 6, .external_lex_state = 7},
  [1972] = {.lex_state = 117, .external_lex_state = 10},
  [1973] = {.lex_state = 117, .external_lex_state = 10},
  [1974] = {.lex_state = 117, .external_lex_state = 10},
  [1975] = {.lex_state = 117, .external_lex_state = 10},
  [1976] = {.lex_state = 117, .external_lex_state = 10},
  [1977] = {.lex_state = 6, .external_lex_state = 7},
  [1978] = {.lex_state = 6, .external_lex_state = 7},
  [1979] = {.lex_state = 6, .external_lex_state = 7},
  [1980] = {.lex_state = 6, .external_lex_state = 7},
  [1981] = {.lex_state = 6, .external_lex_state = 8},
  [1982] = {.lex_state = 6, .external_lex_state = 8},
  [1983] = {.lex_state = 6, .external_lex_state = 7},
  [1984] = {.lex_state = 6, .external_lex_state = 7},
  [1985] = {.lex_state = 117, .external_lex_state = 10},
  [1986] = {.lex_state = 117, .external_lex_state = 10},
  [1987] = {.lex_state = 6, .external_lex_state = 7},
  [1988] = {.lex_state = 6, .external_lex_state = 7},
  [1989] = {.lex_state = 6, .external_lex_state = 7},
  [1990] = {.lex_state = 6, .external_lex_state = 7},
  [1991] = {.lex_state = 6, .external_lex_state = 7},
  [1992] = {.lex_state = 6, .external_lex_state = 7},
  [1993] = {.lex_state = 117, .external_lex_state = 10},
  [1994] = {.lex_state = 6, .external_lex_state = 7},
  [1995] = {.lex_state = 117, .external_lex_state = 10},
  [1996] = {.lex_state = 117, .external_lex_state = 10},
  [1997] = {.lex_state = 6, .external_lex_state = 7},
  [1998] = {.lex_state = 6, .external_lex_state = 7},
  [1999] = {.lex_state = 6, .external_lex_state = 7},
  [2000] = {.lex_state = 6, .external_lex_state = 7},
  [2001] = {.lex_state = 117, .external_lex_state = 10},
  [2002] = {.lex_state = 6, .external_lex_state = 7},
  [2003] = {.lex_state = 117, .external_lex_state = 10},
  [2004] = {.lex_state = 6, .external_lex_state = 8},
  [2005] = {.lex_state = 6, .external_lex_state = 8},
  [2006] = {.lex_state = 6, .external_lex_state = 8},
  [2007] = {.lex_state = 6, .external_lex_state = 8},
  [2008] = {.lex_state = 6, .external_lex_state = 8},
  [2009] = {.lex_state = 6, .external_lex_state = 8},
  [2010] = {.lex_state = 6, .external_lex_state = 8},
  [2011] = {.lex_state = 6, .external_lex_state = 8},
  [2012] = {.lex_state = 6, .external_lex_state = 8},
  [2013] = {.lex_state = 117, .external_lex_state = 10},
  [2014] = {.lex_state = 6, .external_lex_state = 8},
  [2015] = {.lex_state = 6, .external_lex_state = 8},
  [2016] = {.lex_state = 6, .external_lex_state = 8},
  [2017] = {.lex_state = 6, .external_lex_state = 8},
  [2018] = {.lex_state = 6, .external_lex_state = 8},
  [2019] = {.lex_state = 6, .external_lex_state = 8},
  [2020] = {.lex_state = 6, .external_lex_state = 8},
  [2021] = {.lex_state = 6, .external_lex_state = 8},
  [2022] = {.lex_state = 6, .external_lex_state = 8},
  [2023] = {.lex_state = 6, .external_lex_state = 7},
  [2024] = {.lex_state = 6, .external_lex_state = 7},
  [2025] = {.lex_state = 6, .external_lex_state = 7},
  [2026] = {.lex_state = 6, .external_lex_state = 7},
  [2027] = {.lex_state = 117, .external_lex_state = 10},
  [2028] = {.lex_state = 6, .external_lex_state = 7},
  [2029] = {.lex_state = 6, .external_lex_state = 7},
  [2030] = {.lex_state = 6, .external_lex_state = 7},
  [2031] = {.lex_state = 6, .external_lex_state = 7},
  [2032] = {.lex_state = 6, .external_lex_state = 7},
  [2033] = {.lex_state = 6, .external_lex_state = 7},
  [2034] = {.lex_state = 6, .external_lex_state = 7},
  [2035] = {.lex_state = 6, .external_lex_state = 7},
  [2036] = {.lex_state = 6, .external_lex_state = 7},
  [2037] = {.lex_state = 6, .external_lex_state = 7},
  [2038] = {.lex_state = 6, .external_lex_state = 7},
  [2039] = {.lex_state = 6, .external_lex_state = 7},
  [2040] = {.lex_state = 6, .external_lex_state = 7},
  [2041] = {.lex_state = 6, .external_lex_state = 7},
  [2042] = {.lex_state = 6, .external_lex_state = 7},
  [2043] = {.lex_state = 6, .external_lex_state = 7},
  [2044] = {.lex_state = 6, .external_lex_state = 7},
  [2045] = {.lex_state = 6, .external_lex_state = 7},
  [2046] = {.lex_state = 6, .external_lex_state = 7},
  [2047] = {.lex_state = 7, .external_lex_state = 3},
  [2048] = {.lex_state = 6, .external_lex_state = 7},
  [2049] = {.lex_state = 6, .external_lex_state = 7},
  [2050] = {.lex_state = 6, .external_lex_state = 7},
  [2051] = {.lex_state = 6, .external_lex_state = 7},
  [2052] = {.lex_state = 6, .external_lex_state = 7},
  [2053] = {.lex_state = 7, .external_lex_state = 3},
  [2054] = {.lex_state = 7, .external_lex_state = 3},
  [2055] = {.lex_state = 6, .external_lex_state = 7},
  [2056] = {.lex_state = 6, .external_lex_state = 7},
  [2057] = {.lex_state = 6, .external_lex_state = 7},
  [2058] = {.lex_state = 6, .external_lex_state = 7},
  [2059] = {.lex_state = 6, .external_lex_state = 7},
  [2060] = {.lex_state = 6, .external_lex_state = 3},
  [2061] = {.lex_state = 6, .external_lex_state = 7},
  [2062] = {.lex_state = 6, .external_lex_state = 7},
  [2063] = {.lex_state = 6, .external_lex_state = 7},
  [2064] = {.lex_state = 6, .external_lex_state = 7},
  [2065] = {.lex_state = 6, .external_lex_state = 7},
  [2066] = {.lex_state = 7, .external_lex_state = 3},
  [2067] = {.lex_state = 6, .external_lex_state = 7},
  [2068] = {.lex_state = 7, .external_lex_state = 3},
  [2069] = {.lex_state = 7, .external_lex_state = 3},
  [2070] = {.lex_state = 6, .external_lex_state = 7},
  [2071] = {.lex_state = 6, .external_lex_state = 7},
  [2072] = {.lex_state = 7, .external_lex_state = 3},
  [2073] = {.lex_state = 6, .external_lex_state = 7},
  [2074] = {.lex_state = 6, .external_lex_state = 7},
  [2075] = {.lex_state = 117, .external_lex_state = 12},
  [2076] = {.lex_state = 6, .external_lex_state = 7},
  [2077] = {.lex_state = 6, .external_lex_state = 7},
  [2078] = {.lex_state = 6, .external_lex_state = 7},
  [2079] = {.lex_state = 6, .external_lex_state = 7},
  [2080] = {.lex_state = 117, .external_lex_state = 12},
  [2081] = {.lex_state = 6, .external_lex_state = 7},
  [2082] = {.lex_state = 7, .external_lex_state = 3},
  [2083] = {.lex_state = 7, .external_lex_state = 3},
  [2084] = {.lex_state = 6, .external_lex_state = 7},
  [2085] = {.lex_state = 6, .external_lex_state = 3},
  [2086] = {.lex_state = 6, .external_lex_state = 3},
  [2087] = {.lex_state = 117, .external_lex_state = 2},
  [2088] = {.lex_state = 117, .external_lex_state = 9},
  [2089] = {.lex_state = 117, .external_lex_state = 2},
  [2090] = {.lex_state = 117, .external_lex_state = 2},
  [2091] = {.lex_state = 117, .external_lex_state = 2},
  [2092] = {.lex_state = 7, .external_lex_state = 3},
  [2093] = {.lex_state = 117, .external_lex_state = 12},
  [2094] = {.lex_state = 117, .external_lex_state = 13},
  [2095] = {.lex_state = 7, .external_lex_state = 3},
  [2096] = {.lex_state = 6, .external_lex_state = 3},
  [2097] = {.lex_state = 117, .external_lex_state = 12},
  [2098] = {.lex_state = 6, .external_lex_state = 14},
  [2099] = {.lex_state = 117, .external_lex_state = 12},
  [2100] = {.lex_state = 117, .external_lex_state = 12},
  [2101] = {.lex_state = 117, .external_lex_state = 12},
  [2102] = {.lex_state = 117, .external_lex_state = 12},
  [2103] = {.lex_state = 6, .external_lex_state = 14},
  [2104] = {.lex_state = 6, .external_lex_state = 14},
  [2105] = {.lex_state = 7, .external_lex_state = 3},
  [2106] = {.lex_state = 117},
  [2107] = {.lex_state = 117},
  [2108] = {.lex_state = 117},
  [2109] = {.lex_state = 117},
  [2110] = {.lex_state = 117},
  [2111] = {.lex_state = 117},
  [2112] = {.lex_state = 117},
  [2113] = {.lex_state = 7, .external_lex_state = 3},
  [2114] = {.lex_state = 117},
  [2115] = {.lex_state = 117},
  [2116] = {.lex_state = 117},
  [2117] = {.lex_state = 7, .external_lex_state = 3},
  [2118] = {.lex_state = 117},
  [2119] = {.lex_state = 117},
  [2120] = {.lex_state = 117},
  [2121] = {.lex_state = 117},
  [2122] = {.lex_state = 117},
  [2123] = {.lex_state = 117},
  [2124] = {.lex_state = 117},
  [2125] = {.lex_state = 7, .external_lex_state = 3},
  [2126] = {.lex_state = 117},
  [2127] = {.lex_state = 117},
  [2128] = {.lex_state = 117},
  [2129] = {.lex_state = 117},
  [2130] = {.lex_state = 117},
  [2131] = {.lex_state = 7, .external_lex_state = 3},
  [2132] = {.lex_state = 117},
  [2133] = {.lex_state = 117},
  [2134] = {.lex_state = 117},
  [2135] = {.lex_state = 7, .external_lex_state = 3},
  [2136] = {.lex_state = 117},
  [2137] = {.lex_state = 117},
  [2138] = {.lex_state = 117},
  [2139] = {.lex_state = 7, .external_lex_state = 3},
  [2140] = {.lex_state = 117},
  [2141] = {.lex_state = 117},
  [2142] = {.lex_state = 7, .external_lex_state = 3},
  [2143] = {.lex_state = 117},
  [2144] = {.lex_state = 117},
  [2145] = {.lex_state = 7, .external_lex_state = 3},
  [2146] = {.lex_state = 117},
  [2147] = {.lex_state = 117},
  [2148] = {.lex_state = 117},
  [2149] = {.lex_state = 117},
  [2150] = {.lex_state = 117},
  [2151] = {.lex_state = 117},
  [2152] = {.lex_state = 117},
  [2153] = {.lex_state = 117},
  [2154] = {.lex_state = 117},
  [2155] = {.lex_state = 117},
  [2156] = {.lex_state = 117},
  [2157] = {.lex_state = 117},
  [2158] = {.lex_state = 117},
  [2159] = {.lex_state = 117},
  [2160] = {.lex_state = 117},
  [2161] = {.lex_state = 117},
  [2162] = {.lex_state = 117},
  [2163] = {.lex_state = 117},
  [2164] = {.lex_state = 117},
  [2165] = {.lex_state = 117},
  [2166] = {.lex_state = 117},
  [2167] = {.lex_state = 117},
  [2168] = {.lex_state = 117},
  [2169] = {.lex_state = 117},
  [2170] = {.lex_state = 117},
  [2171] = {.lex_state = 117},
  [2172] = {.lex_state = 117},
  [2173] = {.lex_state = 117},
  [2174] = {.lex_state = 117},
  [2175] = {.lex_state = 117},
  [2176] = {.lex_state = 117},
  [2177] = {.lex_state = 117},
  [2178] = {.lex_state = 7, .external_lex_state = 3},
  [2179] = {.lex_state = 117},
  [2180] = {.lex_state = 117},
  [2181] = {.lex_state = 117},
  [2182] = {.lex_state = 117},
  [2183] = {.lex_state = 117},
  [2184] = {.lex_state = 117},
  [2185] = {.lex_state = 117},
  [2186] = {.lex_state = 117},
  [2187] = {.lex_state = 117},
  [2188] = {.lex_state = 117},
  [2189] = {.lex_state = 117},
  [2190] = {.lex_state = 117},
  [2191] = {.lex_state = 117},
  [2192] = {.lex_state = 117},
  [2193] = {.lex_state = 117},
  [2194] = {.lex_state = 117},
  [2195] = {.lex_state = 117},
  [2196] = {.lex_state = 117},
  [2197] = {.lex_state = 117},
  [2198] = {.lex_state = 117},
  [2199] = {.lex_state = 117},
  [2200] = {.lex_state = 117},
  [2201] = {.lex_state = 117},
  [2202] = {.lex_state = 117},
  [2203] = {.lex_state = 117},
  [2204] = {.lex_state = 117},
  [2205] = {.lex_state = 117},
  [2206] = {.lex_state = 117},
  [2207] = {.lex_state = 117},
  [2208] = {.lex_state = 117},
  [2209] = {.lex_state = 117},
  [2210] = {.lex_state = 117},
  [2211] = {.lex_state = 117},
  [2212] = {.lex_state = 117},
  [2213] = {.lex_state = 117},
  [2214] = {.lex_state = 117},
  [2215] = {.lex_state = 117},
  [2216] = {.lex_state = 117},
  [2217] = {.lex_state = 117},
  [2218] = {.lex_state = 117},
  [2219] = {.lex_state = 117},
  [2220] = {.lex_state = 117},
  [2221] = {.lex_state = 117},
  [2222] = {.lex_state = 117},
  [2223] = {.lex_state = 117},
  [2224] = {.lex_state = 117},
  [2225] = {.lex_state = 117},
  [2226] = {.lex_state = 117},
  [2227] = {.lex_state = 117},
  [2228] = {.lex_state = 117},
  [2229] = {.lex_state = 117},
  [2230] = {.lex_state = 117},
  [2231] = {.lex_state = 117},
  [2232] = {.lex_state = 117},
  [2233] = {.lex_state = 117},
  [2234] = {.lex_state = 117},
  [2235] = {.lex_state = 7, .external_lex_state = 3},
  [2236] = {.lex_state = 7, .external_lex_state = 3},
  [2237] = {.lex_state = 117, .external_lex_state = 12},
  [2238] = {.lex_state = 117, .external_lex_state = 12},
  [2239] = {.lex_state = 7, .external_lex_state = 3},
  [2240] = {.lex_state = 7, .external_lex_state = 3},
  [2241] = {.lex_state = 7, .external_lex_state = 3},
  [2242] = {.lex_state = 7, .external_lex_state = 3},
  [2243] = {.lex_state = 7, .external_lex_state = 3},
  [2244] = {.lex_state = 6, .external_lex_state = 8},
  [2245] = {.lex_state = 7, .external_lex_state = 3},
  [2246] = {.lex_state = 7, .external_lex_state = 3},
  [2247] = {.lex_state = 7, .external_lex_state = 3},
  [2248] = {.lex_state = 117, .external_lex_state = 12},
  [2249] = {.lex_state = 6, .external_lex_state = 8},
  [2250] = {.lex_state = 6, .external_lex_state = 8},
  [2251] = {.lex_state = 117, .external_lex_state = 12},
  [2252] = {.lex_state = 6, .external_lex_state = 14},
  [2253] = {.lex_state = 117, .external_lex_state = 12},
  [2254] = {.lex_state = 117, .external_lex_state = 12},
  [2255] = {.lex_state = 117, .external_lex_state = 12},
  [2256] = {.lex_state = 117, .external_lex_state = 12},
  [2257] = {.lex_state = 117, .external_lex_state = 12},
  [2258] = {.lex_state = 117, .external_lex_state = 2},
  [2259] = {.lex_state = 117, .external_lex_state = 12},
  [2260] = {.lex_state = 6, .external_lex_state = 3},
  [2261] = {.lex_state = 7, .external_lex_state = 3},
  [2262] = {.lex_state = 6, .external_lex_state = 3},
  [2263] = {.lex_state = 6, .external_lex_state = 3},
  [2264] = {.lex_state = 6, .external_lex_state = 3},
  [2265] = {.lex_state = 6, .external_lex_state = 3},
  [2266] = {.lex_state = 6, .external_lex_state = 3},
  [2267] = {.lex_state = 6, .external_lex_state = 3},
  [2268] = {.lex_state = 6, .external_lex_state = 3},
  [2269] = {.lex_state = 6, .external_lex_state = 3},
  [2270] = {.lex_state = 6, .external_lex_state = 3},
  [2271] = {.lex_state = 6, .external_lex_state = 3},
  [2272] = {.lex_state = 6, .external_lex_state = 3},
  [2273] = {.lex_state = 6, .external_lex_state = 3},
  [2274] = {.lex_state = 6, .external_lex_state = 3},
  [2275] = {.lex_state = 6, .external_lex_state = 3},
  [2276] = {.lex_state = 6, .external_lex_state = 3},
  [2277] = {.lex_state = 6, .external_lex_state = 3},
  [2278] = {.lex_state = 6, .external_lex_state = 3},
  [2279] = {.lex_state = 6, .external_lex_state = 3},
  [2280] = {.lex_state = 6, .external_lex_state = 3},
  [2281] = {.lex_state = 6, .external_lex_state = 3},
  [2282] = {.lex_state = 6, .external_lex_state = 3},
  [2283] = {.lex_state = 6, .external_lex_state = 3},
  [2284] = {.lex_state = 6, .external_lex_state = 3},
  [2285] = {.lex_state = 6, .external_lex_state = 3},
  [2286] = {.lex_state = 6, .external_lex_state = 3},
  [2287] = {.lex_state = 6, .external_lex_state = 3},
  [2288] = {.lex_state = 117, .external_lex_state = 3},
  [2289] = {.lex_state = 6, .external_lex_state = 3},
  [2290] = {.lex_state = 3, .external_lex_state = 3},
  [2291] = {.lex_state = 3, .external_lex_state = 3},
  [2292] = {.lex_state = 3, .external_lex_state = 3},
  [2293] = {.lex_state = 3, .external_lex_state = 3},
  [2294] = {.lex_state = 6, .external_lex_state = 3},
  [2295] = {.lex_state = 6, .external_lex_state = 3},
  [2296] = {.lex_state = 6, .external_lex_state = 3},
  [2297] = {.lex_state = 6, .external_lex_state = 3},
  [2298] = {.lex_state = 6, .external_lex_state = 3},
  [2299] = {.lex_state = 6, .external_lex_state = 3},
  [2300] = {.lex_state = 6, .external_lex_state = 3},
  [2301] = {.lex_state = 6, .external_lex_state = 3},
  [2302] = {.lex_state = 10, .external_lex_state = 12},
  [2303] = {.lex_state = 6, .external_lex_state = 3},
  [2304] = {.lex_state = 6, .external_lex_state = 3},
  [2305] = {.lex_state = 6, .external_lex_state = 3},
  [2306] = {.lex_state = 6, .external_lex_state = 3},
  [2307] = {.lex_state = 6, .external_lex_state = 3},
  [2308] = {.lex_state = 6, .external_lex_state = 3},
  [2309] = {.lex_state = 6, .external_lex_state = 3},
  [2310] = {.lex_state = 3, .external_lex_state = 3},
  [2311] = {.lex_state = 6, .external_lex_state = 3},
  [2312] = {.lex_state = 6, .external_lex_state = 3},
  [2313] = {.lex_state = 6, .external_lex_state = 3},
  [2314] = {.lex_state = 6, .external_lex_state = 3},
  [2315] = {.lex_state = 6, .external_lex_state = 3},
  [2316] = {.lex_state = 6, .external_lex_state = 3},
  [2317] = {.lex_state = 6, .external_lex_state = 3},
  [2318] = {.lex_state = 6, .external_lex_state = 3},
  [2319] = {.lex_state = 6, .external_lex_state = 3},
  [2320] = {.lex_state = 6, .external_lex_state = 3},
  [2321] = {.lex_state = 6, .external_lex_state = 3},
  [2322] = {.lex_state = 6, .external_lex_state = 3},
  [2323] = {.lex_state = 6, .external_lex_state = 3},
  [2324] = {.lex_state = 6, .external_lex_state = 3},
  [2325] = {.lex_state = 6, .external_lex_state = 3},
  [2326] = {.lex_state = 6, .external_lex_state = 3},
  [2327] = {.lex_state = 6, .external_lex_state = 3},
  [2328] = {.lex_state = 6, .external_lex_state = 3},
  [2329] = {.lex_state = 6, .external_lex_state = 3},
  [2330] = {.lex_state = 6, .external_lex_state = 3},
  [2331] = {.lex_state = 10, .external_lex_state = 12},
  [2332] = {.lex_state = 6, .external_lex_state = 3},
  [2333] = {.lex_state = 6, .external_lex_state = 3},
  [2334] = {.lex_state = 6, .external_lex_state = 3},
  [2335] = {.lex_state = 6, .external_lex_state = 3},
  [2336] = {.lex_state = 6, .external_lex_state = 3},
  [2337] = {.lex_state = 6, .external_lex_state = 3},
  [2338] = {.lex_state = 6, .external_lex_state = 3},
  [2339] = {.lex_state = 6, .external_lex_state = 3},
  [2340] = {.lex_state = 6, .external_lex_state = 3},
  [2341] = {.lex_state = 117, .external_lex_state = 3},
  [2342] = {.lex_state = 6, .external_lex_state = 3},
  [2343] = {.lex_state = 6, .external_lex_state = 3},
  [2344] = {.lex_state = 6, .external_lex_state = 3},
  [2345] = {.lex_state = 6, .external_lex_state = 3},
  [2346] = {.lex_state = 6, .external_lex_state = 3},
  [2347] = {.lex_state = 6, .external_lex_state = 3},
  [2348] = {.lex_state = 6, .external_lex_state = 3},
  [2349] = {.lex_state = 6, .external_lex_state = 3},
  [2350] = {.lex_state = 6, .external_lex_state = 3},
  [2351] = {.lex_state = 6, .external_lex_state = 3},
  [2352] = {.lex_state = 6, .external_lex_state = 3},
  [2353] = {.lex_state = 6, .external_lex_state = 3},
  [2354] = {.lex_state = 6, .external_lex_state = 3},
  [2355] = {.lex_state = 6, .external_lex_state = 3},
  [2356] = {.lex_state = 117, .external_lex_state = 3},
  [2357] = {.lex_state = 117, .external_lex_state = 3},
  [2358] = {.lex_state = 117, .external_lex_state = 3},
  [2359] = {.lex_state = 5, .external_lex_state = 3},
  [2360] = {.lex_state = 117, .external_lex_state = 3},
  [2361] = {.lex_state = 117, .external_lex_state = 3},
  [2362] = {.lex_state = 3, .external_lex_state = 4},
  [2363] = {.lex_state = 10, .external_lex_state = 12},
  [2364] = {.lex_state = 10, .external_lex_state = 12},
  [2365] = {.lex_state = 5, .external_lex_state = 3},
  [2366] = {.lex_state = 117, .external_lex_state = 3},
  [2367] = {.lex_state = 117, .external_lex_state = 3},
  [2368] = {.lex_state = 3, .external_lex_state = 4},
  [2369] = {.lex_state = 3, .external_lex_state = 4},
  [2370] = {.lex_state = 117, .external_lex_state = 3},
  [2371] = {.lex_state = 117, .external_lex_state = 3},
  [2372] = {.lex_state = 3, .external_lex_state = 4},
  [2373] = {.lex_state = 10, .external_lex_state = 12},
  [2374] = {.lex_state = 117, .external_lex_state = 3},
  [2375] = {.lex_state = 117, .external_lex_state = 3},
  [2376] = {.lex_state = 117, .external_lex_state = 3},
  [2377] = {.lex_state = 117, .external_lex_state = 3},
  [2378] = {.lex_state = 117, .external_lex_state = 3},
  [2379] = {.lex_state = 117, .external_lex_state = 3},
  [2380] = {.lex_state = 117, .external_lex_state = 3},
  [2381] = {.lex_state = 117, .external_lex_state = 3},
  [2382] = {.lex_state = 117, .external_lex_state = 3},
  [2383] = {.lex_state = 117, .external_lex_state = 3},
  [2384] = {.lex_state = 117, .external_lex_state = 3},
  [2385] = {.lex_state = 117, .external_lex_state = 3},
  [2386] = {.lex_state = 117, .external_lex_state = 3},
  [2387] = {.lex_state = 117, .external_lex_state = 3},
  [2388] = {.lex_state = 117, .external_lex_state = 3},
  [2389] = {.lex_state = 117, .external_lex_state = 3},
  [2390] = {.lex_state = 117, .external_lex_state = 3},
  [2391] = {.lex_state = 117, .external_lex_state = 3},
  [2392] = {.lex_state = 117, .external_lex_state = 3},
  [2393] = {.lex_state = 117, .external_lex_state = 3},
  [2394] = {.lex_state = 117, .external_lex_state = 3},
  [2395] = {.lex_state = 117, .external_lex_state = 3},
  [2396] = {.lex_state = 117, .external_lex_state = 3},
  [2397] = {.lex_state = 117, .external_lex_state = 3},
  [2398] = {.lex_state = 117, .external_lex_state = 3},
  [2399] = {.lex_state = 117, .external_lex_state = 3},
  [2400] = {.lex_state = 117, .external_lex_state = 3},
  [2401] = {.lex_state = 117, .external_lex_state = 3},
  [2402] = {.lex_state = 117, .external_lex_state = 3},
  [2403] = {.lex_state = 117, .external_lex_state = 3},
  [2404] = {.lex_state = 117, .external_lex_state = 3},
  [2405] = {.lex_state = 117, .external_lex_state = 3},
  [2406] = {.lex_state = 117, .external_lex_state = 3},
  [2407] = {.lex_state = 117, .external_lex_state = 3},
  [2408] = {.lex_state = 117, .external_lex_state = 3},
  [2409] = {.lex_state = 117, .external_lex_state = 3},
  [2410] = {.lex_state = 117, .external_lex_state = 3},
  [2411] = {.lex_state = 117, .external_lex_state = 3},
  [2412] = {.lex_state = 117, .external_lex_state = 3},
  [2413] = {.lex_state = 117, .external_lex_state = 3},
  [2414] = {.lex_state = 117, .external_lex_state = 3},
  [2415] = {.lex_state = 117, .external_lex_state = 3},
  [2416] = {.lex_state = 117, .external_lex_state = 3},
  [2417] = {.lex_state = 117, .external_lex_state = 3},
  [2418] = {.lex_state = 117, .external_lex_state = 3},
  [2419] = {.lex_state = 117, .external_lex_state = 3},
  [2420] = {.lex_state = 117, .external_lex_state = 3},
  [2421] = {.lex_state = 117, .external_lex_state = 3},
  [2422] = {.lex_state = 117, .external_lex_state = 3},
  [2423] = {.lex_state = 117, .external_lex_state = 3},
  [2424] = {.lex_state = 117, .external_lex_state = 3},
  [2425] = {.lex_state = 117, .external_lex_state = 3},
  [2426] = {.lex_state = 117, .external_lex_state = 3},
  [2427] = {.lex_state = 117, .external_lex_state = 3},
  [2428] = {.lex_state = 3, .external_lex_state = 10},
  [2429] = {.lex_state = 117, .external_lex_state = 3},
  [2430] = {.lex_state = 117, .external_lex_state = 3},
  [2431] = {.lex_state = 117, .external_lex_state = 3},
  [2432] = {.lex_state = 117, .external_lex_state = 3},
  [2433] = {.lex_state = 117, .external_lex_state = 3},
  [2434] = {.lex_state = 117, .external_lex_state = 3},
  [2435] = {.lex_state = 117, .external_lex_state = 3},
  [2436] = {.lex_state = 117, .external_lex_state = 3},
  [2437] = {.lex_state = 117, .external_lex_state = 3},
  [2438] = {.lex_state = 117, .external_lex_state = 3},
  [2439] = {.lex_state = 117, .external_lex_state = 3},
  [2440] = {.lex_state = 117, .external_lex_state = 3},
  [2441] = {.lex_state = 117, .external_lex_state = 3},
  [2442] = {.lex_state = 117, .external_lex_state = 3},
  [2443] = {.lex_state = 117, .external_lex_state = 3},
  [2444] = {.lex_state = 117, .external_lex_state = 3},
  [2445] = {.lex_state = 117, .external_lex_state = 3},
  [2446] = {.lex_state = 117, .external_lex_state = 3},
  [2447] = {.lex_state = 117, .external_lex_state = 3},
  [2448] = {.lex_state = 117, .external_lex_state = 3},
  [2449] = {.lex_state = 117, .external_lex_state = 3},
  [2450] = {.lex_state = 117, .external_lex_state = 3},
  [2451] = {.lex_state = 117, .external_lex_state = 3},
  [2452] = {.lex_state = 117, .external_lex_state = 3},
  [2453] = {.lex_state = 117, .external_lex_state = 3},
  [2454] = {.lex_state = 117, .external_lex_state = 3},
  [2455] = {.lex_state = 117, .external_lex_state = 3},
  [2456] = {.lex_state = 117, .external_lex_state = 3},
  [2457] = {.lex_state = 117, .external_lex_state = 3},
  [2458] = {.lex_state = 117, .external_lex_state = 3},
  [2459] = {.lex_state = 117, .external_lex_state = 3},
  [2460] = {.lex_state = 117, .external_lex_state = 3},
  [2461] = {.lex_state = 117, .external_lex_state = 3},
  [2462] = {.lex_state = 117, .external_lex_state = 3},
  [2463] = {.lex_state = 117, .external_lex_state = 3},
  [2464] = {.lex_state = 117, .external_lex_state = 3},
  [2465] = {.lex_state = 117, .external_lex_state = 3},
  [2466] = {.lex_state = 117, .external_lex_state = 3},
  [2467] = {.lex_state = 117, .external_lex_state = 3},
  [2468] = {.lex_state = 117, .external_lex_state = 3},
  [2469] = {.lex_state = 117, .external_lex_state = 3},
  [2470] = {.lex_state = 117, .external_lex_state = 3},
  [2471] = {.lex_state = 117, .external_lex_state = 3},
  [2472] = {.lex_state = 117, .external_lex_state = 3},
  [2473] = {.lex_state = 117, .external_lex_state = 3},
  [2474] = {.lex_state = 117, .external_lex_state = 3},
  [2475] = {.lex_state = 117, .external_lex_state = 3},
  [2476] = {.lex_state = 117, .external_lex_state = 3},
  [2477] = {.lex_state = 117, .external_lex_state = 3},
  [2478] = {.lex_state = 117, .external_lex_state = 3},
  [2479] = {.lex_state = 117, .external_lex_state = 3},
  [2480] = {.lex_state = 117, .external_lex_state = 3},
  [2481] = {.lex_state = 117, .external_lex_state = 3},
  [2482] = {.lex_state = 117, .external_lex_state = 3},
  [2483] = {.lex_state = 117, .external_lex_state = 3},
  [2484] = {.lex_state = 117, .external_lex_state = 3},
  [2485] = {.lex_state = 117, .external_lex_state = 3},
  [2486] = {.lex_state = 117, .external_lex_state = 3},
  [2487] = {.lex_state = 117, .external_lex_state = 3},
  [2488] = {.lex_state = 117, .external_lex_state = 3},
  [2489] = {.lex_state = 117, .external_lex_state = 3},
  [2490] = {.lex_state = 117, .external_lex_state = 3},
  [2491] = {.lex_state = 117, .external_lex_state = 3},
  [2492] = {.lex_state = 117, .external_lex_state = 3},
  [2493] = {.lex_state = 117, .external_lex_state = 3},
  [2494] = {.lex_state = 117, .external_lex_state = 3},
  [2495] = {.lex_state = 117, .external_lex_state = 3},
  [2496] = {.lex_state = 117, .external_lex_state = 3},
  [2497] = {.lex_state = 117, .external_lex_state = 3},
  [2498] = {.lex_state = 117, .external_lex_state = 3},
  [2499] = {.lex_state = 117, .external_lex_state = 3},
  [2500] = {.lex_state = 3, .external_lex_state = 10},
  [2501] = {.lex_state = 117, .external_lex_state = 3},
  [2502] = {.lex_state = 117, .external_lex_state = 3},
  [2503] = {.lex_state = 117, .external_lex_state = 3},
  [2504] = {.lex_state = 117, .external_lex_state = 3},
  [2505] = {.lex_state = 117, .external_lex_state = 3},
  [2506] = {.lex_state = 117, .external_lex_state = 3},
  [2507] = {.lex_state = 117, .external_lex_state = 3},
  [2508] = {.lex_state = 117, .external_lex_state = 3},
  [2509] = {.lex_state = 117, .external_lex_state = 12},
  [2510] = {.lex_state = 3, .external_lex_state = 10},
  [2511] = {.lex_state = 3, .external_lex_state = 10},
  [2512] = {.lex_state = 117, .external_lex_state = 3},
  [2513] = {.lex_state = 117, .external_lex_state = 3},
  [2514] = {.lex_state = 117, .external_lex_state = 3},
  [2515] = {.lex_state = 117, .external_lex_state = 3},
  [2516] = {.lex_state = 117, .external_lex_state = 3},
  [2517] = {.lex_state = 117, .external_lex_state = 3},
  [2518] = {.lex_state = 6, .external_lex_state = 3},
  [2519] = {.lex_state = 117, .external_lex_state = 3},
  [2520] = {.lex_state = 117, .external_lex_state = 3},
  [2521] = {.lex_state = 117, .external_lex_state = 3},
  [2522] = {.lex_state = 10, .external_lex_state = 12},
  [2523] = {.lex_state = 117, .external_lex_state = 3},
  [2524] = {.lex_state = 117, .external_lex_state = 3},
  [2525] = {.lex_state = 117, .external_lex_state = 3},
  [2526] = {.lex_state = 12},
  [2527] = {.lex_state = 117, .external_lex_state = 3},
  [2528] = {.lex_state = 117, .external_lex_state = 3},
  [2529] = {.lex_state = 117, .external_lex_state = 3},
  [2530] = {.lex_state = 117, .external_lex_state = 3},
  [2531] = {.lex_state = 117, .external_lex_state = 3},
  [2532] = {.lex_state = 117, .external_lex_state = 3},
  [2533] = {.lex_state = 117, .external_lex_state = 3},
  [2534] = {.lex_state = 117, .external_lex_state = 3},
  [2535] = {.lex_state = 117, .external_lex_state = 3},
  [2536] = {.lex_state = 117, .external_lex_state = 3},
  [2537] = {.lex_state = 117, .external_lex_state = 3},
  [2538] = {.lex_state = 117, .external_lex_state = 3},
  [2539] = {.lex_state = 117, .external_lex_state = 3},
  [2540] = {.lex_state = 117, .external_lex_state = 3},
  [2541] = {.lex_state = 117, .external_lex_state = 3},
  [2542] = {.lex_state = 117, .external_lex_state = 3},
  [2543] = {.lex_state = 117, .external_lex_state = 3},
  [2544] = {.lex_state = 117, .external_lex_state = 3},
  [2545] = {.lex_state = 117, .external_lex_state = 3},
  [2546] = {.lex_state = 117, .external_lex_state = 3},
  [2547] = {.lex_state = 117, .external_lex_state = 3},
  [2548] = {.lex_state = 117, .external_lex_state = 3},
  [2549] = {.lex_state = 117, .external_lex_state = 3},
  [2550] = {.lex_state = 117, .external_lex_state = 3},
  [2551] = {.lex_state = 117, .external_lex_state = 3},
  [2552] = {.lex_state = 117, .external_lex_state = 3},
  [2553] = {.lex_state = 117, .external_lex_state = 3},
  [2554] = {.lex_state = 117, .external_lex_state = 3},
  [2555] = {.lex_state = 117, .external_lex_state = 3},
  [2556] = {.lex_state = 117, .external_lex_state = 3},
  [2557] = {.lex_state = 117, .external_lex_state = 3},
  [2558] = {.lex_state = 117, .external_lex_state = 3},
  [2559] = {.lex_state = 117, .external_lex_state = 3},
  [2560] = {.lex_state = 117, .external_lex_state = 3},
  [2561] = {.lex_state = 117, .external_lex_state = 3},
  [2562] = {.lex_state = 117, .external_lex_state = 3},
  [2563] = {.lex_state = 117, .external_lex_state = 3},
  [2564] = {.lex_state = 117, .external_lex_state = 3},
  [2565] = {.lex_state = 117, .external_lex_state = 3},
  [2566] = {.lex_state = 117, .external_lex_state = 3},
  [2567] = {.lex_state = 117, .external_lex_state = 3},
  [2568] = {.lex_state = 117, .external_lex_state = 3},
  [2569] = {.lex_state = 117, .external_lex_state = 3},
  [2570] = {.lex_state = 117, .external_lex_state = 3},
  [2571] = {.lex_state = 117, .external_lex_state = 3},
  [2572] = {.lex_state = 117, .external_lex_state = 3},
  [2573] = {.lex_state = 117, .external_lex_state = 3},
  [2574] = {.lex_state = 117, .external_lex_state = 3},
  [2575] = {.lex_state = 117, .external_lex_state = 3},
  [2576] = {.lex_state = 117, .external_lex_state = 3},
  [2577] = {.lex_state = 117, .external_lex_state = 3},
  [2578] = {.lex_state = 117, .external_lex_state = 3},
  [2579] = {.lex_state = 117, .external_lex_state = 3},
  [2580] = {.lex_state = 117, .external_lex_state = 3},
  [2581] = {.lex_state = 117, .external_lex_state = 3},
  [2582] = {.lex_state = 117, .external_lex_state = 3},
  [2583] = {.lex_state = 117, .external_lex_state = 3},
  [2584] = {.lex_state = 117, .external_lex_state = 3},
  [2585] = {.lex_state = 117, .external_lex_state = 3},
  [2586] = {.lex_state = 117, .external_lex_state = 3},
  [2587] = {.lex_state = 117, .external_lex_state = 3},
  [2588] = {.lex_state = 117, .external_lex_state = 3},
  [2589] = {.lex_state = 117, .external_lex_state = 3},
  [2590] = {.lex_state = 117, .external_lex_state = 3},
  [2591] = {.lex_state = 117, .external_lex_state = 3},
  [2592] = {.lex_state = 117, .external_lex_state = 3},
  [2593] = {.lex_state = 117, .external_lex_state = 3},
  [2594] = {.lex_state = 117, .external_lex_state = 3},
  [2595] = {.lex_state = 117, .external_lex_state = 3},
  [2596] = {.lex_state = 117, .external_lex_state = 3},
  [2597] = {.lex_state = 117, .external_lex_state = 3},
  [2598] = {.lex_state = 117, .external_lex_state = 3},
  [2599] = {.lex_state = 117, .external_lex_state = 3},
  [2600] = {.lex_state = 117, .external_lex_state = 3},
  [2601] = {.lex_state = 117, .external_lex_state = 3},
  [2602] = {.lex_state = 117, .external_lex_state = 3},
  [2603] = {.lex_state = 117, .external_lex_state = 3},
  [2604] = {.lex_state = 117, .external_lex_state = 3},
  [2605] = {.lex_state = 117, .external_lex_state = 3},
  [2606] = {.lex_state = 117, .external_lex_state = 3},
  [2607] = {.lex_state = 117, .external_lex_state = 3},
  [2608] = {.lex_state = 117, .external_lex_state = 3},
  [2609] = {.lex_state = 3, .external_lex_state = 10},
  [2610] = {.lex_state = 117, .external_lex_state = 3},
  [2611] = {.lex_state = 117, .external_lex_state = 3},
  [2612] = {.lex_state = 117, .external_lex_state = 3},
  [2613] = {.lex_state = 117, .external_lex_state = 3},
  [2614] = {.lex_state = 117, .external_lex_state = 3},
  [2615] = {.lex_state = 117, .external_lex_state = 3},
  [2616] = {.lex_state = 117, .external_lex_state = 3},
  [2617] = {.lex_state = 117, .external_lex_state = 3},
  [2618] = {.lex_state = 117, .external_lex_state = 3},
  [2619] = {.lex_state = 117, .external_lex_state = 3},
  [2620] = {.lex_state = 117, .external_lex_state = 3},
  [2621] = {.lex_state = 117, .external_lex_state = 3},
  [2622] = {.lex_state = 117, .external_lex_state = 3},
  [2623] = {.lex_state = 117, .external_lex_state = 3},
  [2624] = {.lex_state = 117, .external_lex_state = 3},
  [2625] = {.lex_state = 117, .external_lex_state = 3},
  [2626] = {.lex_state = 117, .external_lex_state = 3},
  [2627] = {.lex_state = 117, .external_lex_state = 3},
  [2628] = {.lex_state = 117, .external_lex_state = 3},
  [2629] = {.lex_state = 117, .external_lex_state = 3},
  [2630] = {.lex_state = 117, .external_lex_state = 3},
  [2631] = {.lex_state = 117, .external_lex_state = 3},
  [2632] = {.lex_state = 6, .external_lex_state = 8},
  [2633] = {.lex_state = 117, .external_lex_state = 3},
  [2634] = {.lex_state = 7, .external_lex_state = 3},
  [2635] = {.lex_state = 117, .external_lex_state = 15},
  [2636] = {.lex_state = 117, .external_lex_state = 15},
  [2637] = {.lex_state = 117, .external_lex_state = 15},
  [2638] = {.lex_state = 7, .external_lex_state = 3},
  [2639] = {.lex_state = 7, .external_lex_state = 3},
  [2640] = {.lex_state = 117, .external_lex_state = 15},
  [2641] = {.lex_state = 7, .external_lex_state = 3},
  [2642] = {.lex_state = 117, .external_lex_state = 15},
  [2643] = {.lex_state = 7, .external_lex_state = 3},
  [2644] = {.lex_state = 7, .external_lex_state = 3},
  [2645] = {.lex_state = 10, .external_lex_state = 12},
  [2646] = {.lex_state = 117, .external_lex_state = 15},
  [2647] = {.lex_state = 117, .external_lex_state = 15},
  [2648] = {.lex_state = 6, .external_lex_state = 3},
  [2649] = {.lex_state = 117, .external_lex_state = 15},
  [2650] = {.lex_state = 117, .external_lex_state = 15},
  [2651] = {.lex_state = 117, .external_lex_state = 15},
  [2652] = {.lex_state = 7, .external_lex_state = 3},
  [2653] = {.lex_state = 117, .external_lex_state = 3},
  [2654] = {.lex_state = 117, .external_lex_state = 15},
  [2655] = {.lex_state = 117, .external_lex_state = 15},
  [2656] = {.lex_state = 117, .external_lex_state = 15},
  [2657] = {.lex_state = 12},
  [2658] = {.lex_state = 117, .external_lex_state = 15},
  [2659] = {.lex_state = 7, .external_lex_state = 3},
  [2660] = {.lex_state = 117, .external_lex_state = 15},
  [2661] = {.lex_state = 117, .external_lex_state = 15},
  [2662] = {.lex_state = 117, .external_lex_state = 15},
  [2663] = {.lex_state = 7, .external_lex_state = 3},
  [2664] = {.lex_state = 7, .external_lex_state = 3},
  [2665] = {.lex_state = 117, .external_lex_state = 15},
  [2666] = {.lex_state = 7, .external_lex_state = 3},
  [2667] = {.lex_state = 7, .external_lex_state = 3},
  [2668] = {.lex_state = 117, .external_lex_state = 15},
  [2669] = {.lex_state = 7, .external_lex_state = 3},
  [2670] = {.lex_state = 7, .external_lex_state = 3},
  [2671] = {.lex_state = 7, .external_lex_state = 3},
  [2672] = {.lex_state = 117, .external_lex_state = 15},
  [2673] = {.lex_state = 117, .external_lex_state = 15},
  [2674] = {.lex_state = 117, .external_lex_state = 15},
  [2675] = {.lex_state = 117, .external_lex_state = 15},
  [2676] = {.lex_state = 7, .external_lex_state = 3},
  [2677] = {.lex_state = 117, .external_lex_state = 15},
  [2678] = {.lex_state = 117, .external_lex_state = 15},
  [2679] = {.lex_state = 7, .external_lex_state = 3},
  [2680] = {.lex_state = 7, .external_lex_state = 3},
  [2681] = {.lex_state = 117, .external_lex_state = 5},
  [2682] = {.lex_state = 117, .external_lex_state = 15},
  [2683] = {.lex_state = 117, .external_lex_state = 15},
  [2684] = {.lex_state = 117, .external_lex_state = 15},
  [2685] = {.lex_state = 117, .external_lex_state = 15},
  [2686] = {.lex_state = 117, .external_lex_state = 15},
  [2687] = {.lex_state = 117, .external_lex_state = 15},
  [2688] = {.lex_state = 117, .external_lex_state = 15},
  [2689] = {.lex_state = 117, .external_lex_state = 15},
  [2690] = {.lex_state = 117, .external_lex_state = 15},
  [2691] = {.lex_state = 117, .external_lex_state = 15},
  [2692] = {.lex_state = 117, .external_lex_state = 15},
  [2693] = {.lex_state = 117, .external_lex_state = 15},
  [2694] = {.lex_state = 117, .external_lex_state = 15},
  [2695] = {.lex_state = 117, .external_lex_state = 15},
  [2696] = {.lex_state = 7, .external_lex_state = 3},
  [2697] = {.lex_state = 7, .external_lex_state = 3},
  [2698] = {.lex_state = 7, .external_lex_state = 3},
  [2699] = {.lex_state = 7, .external_lex_state = 3},
  [2700] = {.lex_state = 7, .external_lex_state = 3},
  [2701] = {.lex_state = 117, .external_lex_state = 5},
  [2702] = {.lex_state = 7, .external_lex_state = 3},
  [2703] = {.lex_state = 7, .external_lex_state = 3},
  [2704] = {.lex_state = 7, .external_lex_state = 3},
  [2705] = {.lex_state = 7, .external_lex_state = 3},
  [2706] = {.lex_state = 7, .external_lex_state = 3},
  [2707] = {.lex_state = 117, .external_lex_state = 15},
  [2708] = {.lex_state = 7, .external_lex_state = 3},
  [2709] = {.lex_state = 7, .external_lex_state = 3},
  [2710] = {.lex_state = 117, .external_lex_state = 15},
  [2711] = {.lex_state = 7, .external_lex_state = 3},
  [2712] = {.lex_state = 7, .external_lex_state = 3},
  [2713] = {.lex_state = 7, .external_lex_state = 3},
  [2714] = {.lex_state = 7, .external_lex_state = 3},
  [2715] = {.lex_state = 7, .external_lex_state = 3},
  [2716] = {.lex_state = 7, .external_lex_state = 3},
  [2717] = {.lex_state = 6, .external_lex_state = 3},
  [2718] = {.lex_state = 117, .external_lex_state = 3},
  [2719] = {.lex_state = 6, .external_lex_state = 3},
  [2720] = {.lex_state = 117, .external_lex_state = 6},
  [2721] = {.lex_state = 12},
  [2722] = {.lex_state = 117, .external_lex_state = 3},
  [2723] = {.lex_state = 117, .external_lex_state = 3},
  [2724] = {.lex_state = 117, .external_lex_state = 3},
  [2725] = {.lex_state = 117, .external_lex_state = 3},
  [2726] = {.lex_state = 117, .external_lex_state = 3},
  [2727] = {.lex_state = 12},
  [2728] = {.lex_state = 6, .external_lex_state = 14},
  [2729] = {.lex_state = 6, .external_lex_state = 14},
  [2730] = {.lex_state = 6, .external_lex_state = 14},
  [2731] = {.lex_state = 6, .external_lex_state = 14},
  [2732] = {.lex_state = 6, .external_lex_state = 14},
  [2733] = {.lex_state = 117, .external_lex_state = 10},
  [2734] = {.lex_state = 6, .external_lex_state = 14},
  [2735] = {.lex_state = 6, .external_lex_state = 14},
  [2736] = {.lex_state = 6, .external_lex_state = 14},
  [2737] = {.lex_state = 6, .external_lex_state = 14},
  [2738] = {.lex_state = 6, .external_lex_state = 14},
  [2739] = {.lex_state = 6, .external_lex_state = 14},
  [2740] = {.lex_state = 6, .external_lex_state = 14},
  [2741] = {.lex_state = 6, .external_lex_state = 14},
  [2742] = {.lex_state = 6, .external_lex_state = 14},
  [2743] = {.lex_state = 6, .external_lex_state = 14},
  [2744] = {.lex_state = 6, .external_lex_state = 14},
  [2745] = {.lex_state = 6, .external_lex_state = 14},
  [2746] = {.lex_state = 6, .external_lex_state = 14},
  [2747] = {.lex_state = 6, .external_lex_state = 14},
  [2748] = {.lex_state = 6, .external_lex_state = 14},
  [2749] = {.lex_state = 6, .external_lex_state = 14},
  [2750] = {.lex_state = 6, .external_lex_state = 14},
  [2751] = {.lex_state = 6, .external_lex_state = 14},
  [2752] = {.lex_state = 6, .external_lex_state = 14},
  [2753] = {.lex_state = 6, .external_lex_state = 14},
  [2754] = {.lex_state = 6, .external_lex_state = 14},
  [2755] = {.lex_state = 6, .external_lex_state = 14},
  [2756] = {.lex_state = 6, .external_lex_state = 14},
  [2757] = {.lex_state = 6, .external_lex_state = 14},
  [2758] = {.lex_state = 6, .external_lex_state = 14},
  [2759] = {.lex_state = 117, .external_lex_state = 10},
  [2760] = {.lex_state = 117, .external_lex_state = 10},
  [2761] = {.lex_state = 117, .external_lex_state = 10},
  [2762] = {.lex_state = 117, .external_lex_state = 10},
  [2763] = {.lex_state = 117, .external_lex_state = 10},
  [2764] = {.lex_state = 117, .external_lex_state = 10},
  [2765] = {.lex_state = 117, .external_lex_state = 10},
  [2766] = {.lex_state = 117, .external_lex_state = 10},
  [2767] = {.lex_state = 117, .external_lex_state = 10},
  [2768] = {.lex_state = 117, .external_lex_state = 10},
  [2769] = {.lex_state = 117, .external_lex_state = 10},
  [2770] = {.lex_state = 5, .external_lex_state = 8},
  [2771] = {.lex_state = 5, .external_lex_state = 8},
  [2772] = {.lex_state = 117, .external_lex_state = 10},
  [2773] = {.lex_state = 117, .external_lex_state = 10},
  [2774] = {.lex_state = 117, .external_lex_state = 10},
  [2775] = {.lex_state = 117, .external_lex_state = 10},
  [2776] = {.lex_state = 117, .external_lex_state = 8},
  [2777] = {.lex_state = 117, .external_lex_state = 8},
  [2778] = {.lex_state = 117, .external_lex_state = 10},
  [2779] = {.lex_state = 117, .external_lex_state = 10},
  [2780] = {.lex_state = 117, .external_lex_state = 10},
  [2781] = {.lex_state = 117, .external_lex_state = 10},
  [2782] = {.lex_state = 6, .external_lex_state = 14},
  [2783] = {.lex_state = 6, .external_lex_state = 14},
  [2784] = {.lex_state = 117, .external_lex_state = 10},
  [2785] = {.lex_state = 117, .external_lex_state = 10},
  [2786] = {.lex_state = 117, .external_lex_state = 10},
  [2787] = {.lex_state = 117, .external_lex_state = 8},
  [2788] = {.lex_state = 117, .external_lex_state = 8},
  [2789] = {.lex_state = 117, .external_lex_state = 8},
  [2790] = {.lex_state = 117, .external_lex_state = 8},
  [2791] = {.lex_state = 117, .external_lex_state = 8},
  [2792] = {.lex_state = 117, .external_lex_state = 8},
  [2793] = {.lex_state = 117, .external_lex_state = 10},
  [2794] = {.lex_state = 117, .external_lex_state = 10},
  [2795] = {.lex_state = 117, .external_lex_state = 10},
  [2796] = {.lex_state = 117, .external_lex_state = 10},
  [2797] = {.lex_state = 117, .external_lex_state = 10},
  [2798] = {.lex_state = 117, .external_lex_state = 10},
  [2799] = {.lex_state = 117, .external_lex_state = 10},
  [2800] = {.lex_state = 6, .external_lex_state = 14},
  [2801] = {.lex_state = 117, .external_lex_state = 10},
  [2802] = {.lex_state = 117, .external_lex_state = 10},
  [2803] = {.lex_state = 117, .external_lex_state = 10},
  [2804] = {.lex_state = 117, .external_lex_state = 10},
  [2805] = {.lex_state = 117, .external_lex_state = 10},
  [2806] = {.lex_state = 117, .external_lex_state = 10},
  [2807] = {.lex_state = 117, .external_lex_state = 10},
  [2808] = {.lex_state = 117, .external_lex_state = 10},
  [2809] = {.lex_state = 117, .external_lex_state = 10},
  [2810] = {.lex_state = 117, .external_lex_state = 10},
  [2811] = {.lex_state = 117, .external_lex_state = 10},
  [2812] = {.lex_state = 117, .external_lex_state = 10},
  [2813] = {.lex_state = 10, .external_lex_state = 15},
  [2814] = {.lex_state = 117, .external_lex_state = 10},
  [2815] = {.lex_state = 117, .external_lex_state = 10},
  [2816] = {.lex_state = 117, .external_lex_state = 10},
  [2817] = {.lex_state = 117, .external_lex_state = 10},
  [2818] = {.lex_state = 117, .external_lex_state = 10},
  [2819] = {.lex_state = 117, .external_lex_state = 10},
  [2820] = {.lex_state = 117, .external_lex_state = 10},
  [2821] = {.lex_state = 117, .external_lex_state = 10},
  [2822] = {.lex_state = 117, .external_lex_state = 10},
  [2823] = {.lex_state = 117, .external_lex_state = 10},
  [2824] = {.lex_state = 117, .external_lex_state = 10},
  [2825] = {.lex_state = 117, .external_lex_state = 10},
  [2826] = {.lex_state = 117, .external_lex_state = 10},
  [2827] = {.lex_state = 117, .external_lex_state = 10},
  [2828] = {.lex_state = 117, .external_lex_state = 10},
  [2829] = {.lex_state = 6, .external_lex_state = 14},
  [2830] = {.lex_state = 6, .external_lex_state = 14},
  [2831] = {.lex_state = 6, .external_lex_state = 14},
  [2832] = {.lex_state = 9, .external_lex_state = 16},
  [2833] = {.lex_state = 6, .external_lex_state = 14},
  [2834] = {.lex_state = 6, .external_lex_state = 14},
  [2835] = {.lex_state = 6, .external_lex_state = 14},
  [2836] = {.lex_state = 6, .external_lex_state = 14},
  [2837] = {.lex_state = 6, .external_lex_state = 14},
  [2838] = {.lex_state = 6, .external_lex_state = 14},
  [2839] = {.lex_state = 6, .external_lex_state = 14},
  [2840] = {.lex_state = 117, .external_lex_state = 8},
  [2841] = {.lex_state = 117, .external_lex_state = 10},
  [2842] = {.lex_state = 117, .external_lex_state = 10},
  [2843] = {.lex_state = 117, .external_lex_state = 10},
  [2844] = {.lex_state = 6, .external_lex_state = 14},
  [2845] = {.lex_state = 6, .external_lex_state = 14},
  [2846] = {.lex_state = 117, .external_lex_state = 10},
  [2847] = {.lex_state = 117, .external_lex_state = 10},
  [2848] = {.lex_state = 117, .external_lex_state = 10},
  [2849] = {.lex_state = 117, .external_lex_state = 10},
  [2850] = {.lex_state = 117, .external_lex_state = 10},
  [2851] = {.lex_state = 117, .external_lex_state = 10},
  [2852] = {.lex_state = 117, .external_lex_state = 10},
  [2853] = {.lex_state = 117, .external_lex_state = 10},
  [2854] = {.lex_state = 117, .external_lex_state = 10},
  [2855] = {.lex_state = 6, .external_lex_state = 14},
  [2856] = {.lex_state = 6, .external_lex_state = 14},
  [2857] = {.lex_state = 117, .external_lex_state = 10},
  [2858] = {.lex_state = 6, .external_lex_state = 14},
  [2859] = {.lex_state = 117, .external_lex_state = 10},
  [2860] = {.lex_state = 117, .external_lex_state = 10},
  [2861] = {.lex_state = 117, .external_lex_state = 10},
  [2862] = {.lex_state = 6, .external_lex_state = 14},
  [2863] = {.lex_state = 117, .external_lex_state = 10},
  [2864] = {.lex_state = 117, .external_lex_state = 10},
  [2865] = {.lex_state = 117, .external_lex_state = 10},
  [2866] = {.lex_state = 117, .external_lex_state = 10},
  [2867] = {.lex_state = 117, .external_lex_state = 10},
  [2868] = {.lex_state = 117, .external_lex_state = 8},
  [2869] = {.lex_state = 117, .external_lex_state = 8},
  [2870] = {.lex_state = 6, .external_lex_state = 14},
  [2871] = {.lex_state = 117, .external_lex_state = 10},
  [2872] = {.lex_state = 117, .external_lex_state = 10},
  [2873] = {.lex_state = 6, .external_lex_state = 14},
  [2874] = {.lex_state = 117, .external_lex_state = 10},
  [2875] = {.lex_state = 6, .external_lex_state = 14},
  [2876] = {.lex_state = 117, .external_lex_state = 10},
  [2877] = {.lex_state = 117, .external_lex_state = 8},
  [2878] = {.lex_state = 117, .external_lex_state = 8},
  [2879] = {.lex_state = 117, .external_lex_state = 8},
  [2880] = {.lex_state = 117, .external_lex_state = 8},
  [2881] = {.lex_state = 117, .external_lex_state = 8},
  [2882] = {.lex_state = 117, .external_lex_state = 8},
  [2883] = {.lex_state = 117, .external_lex_state = 8},
  [2884] = {.lex_state = 117, .external_lex_state = 8},
  [2885] = {.lex_state = 117, .external_lex_state = 8},
  [2886] = {.lex_state = 117, .external_lex_state = 8},
  [2887] = {.lex_state = 117, .external_lex_state = 8},
  [2888] = {.lex_state = 117, .external_lex_state = 8},
  [2889] = {.lex_state = 117, .external_lex_state = 8},
  [2890] = {.lex_state = 117, .external_lex_state = 8},
  [2891] = {.lex_state = 117, .external_lex_state = 8},
  [2892] = {.lex_state = 117, .external_lex_state = 8},
  [2893] = {.lex_state = 117, .external_lex_state = 8},
  [2894] = {.lex_state = 117, .external_lex_state = 8},
  [2895] = {.lex_state = 117, .external_lex_state = 8},
  [2896] = {.lex_state = 117, .external_lex_state = 8},
  [2897] = {.lex_state = 117, .external_lex_state = 8},
  [2898] = {.lex_state = 117, .external_lex_state = 8},
  [2899] = {.lex_state = 117, .external_lex_state = 8},
  [2900] = {.lex_state = 117, .external_lex_state = 8},
  [2901] = {.lex_state = 117, .external_lex_state = 8},
  [2902] = {.lex_state = 117, .external_lex_state = 8},
  [2903] = {.lex_state = 117, .external_lex_state = 8},
  [2904] = {.lex_state = 6, .external_lex_state = 14},
  [2905] = {.lex_state = 117, .external_lex_state = 8},
  [2906] = {.lex_state = 117, .external_lex_state = 8},
  [2907] = {.lex_state = 117, .external_lex_state = 8},
  [2908] = {.lex_state = 117, .external_lex_state = 8},
  [2909] = {.lex_state = 117, .external_lex_state = 8},
  [2910] = {.lex_state = 117, .external_lex_state = 8},
  [2911] = {.lex_state = 117, .external_lex_state = 8},
  [2912] = {.lex_state = 117, .external_lex_state = 8},
  [2913] = {.lex_state = 117, .external_lex_state = 8},
  [2914] = {.lex_state = 117, .external_lex_state = 8},
  [2915] = {.lex_state = 117, .external_lex_state = 8},
  [2916] = {.lex_state = 117, .external_lex_state = 8},
  [2917] = {.lex_state = 117, .external_lex_state = 8},
  [2918] = {.lex_state = 117, .external_lex_state = 8},
  [2919] = {.lex_state = 117, .external_lex_state = 8},
  [2920] = {.lex_state = 117, .external_lex_state = 8},
  [2921] = {.lex_state = 117, .external_lex_state = 8},
  [2922] = {.lex_state = 117, .external_lex_state = 8},
  [2923] = {.lex_state = 117, .external_lex_state = 8},
  [2924] = {.lex_state = 117, .external_lex_state = 8},
  [2925] = {.lex_state = 117, .external_lex_state = 8},
  [2926] = {.lex_state = 117, .external_lex_state = 8},
  [2927] = {.lex_state = 117, .external_lex_state = 8},
  [2928] = {.lex_state = 117, .external_lex_state = 8},
  [2929] = {.lex_state = 117, .external_lex_state = 8},
  [2930] = {.lex_state = 117, .external_lex_state = 8},
  [2931] = {.lex_state = 117, .external_lex_state = 8},
  [2932] = {.lex_state = 117, .external_lex_state = 8},
  [2933] = {.lex_state = 117, .external_lex_state = 8},
  [2934] = {.lex_state = 117, .external_lex_state = 8},
  [2935] = {.lex_state = 117, .external_lex_state = 8},
  [2936] = {.lex_state = 117, .external_lex_state = 8},
  [2937] = {.lex_state = 117, .external_lex_state = 8},
  [2938] = {.lex_state = 117, .external_lex_state = 8},
  [2939] = {.lex_state = 117, .external_lex_state = 8},
  [2940] = {.lex_state = 117, .external_lex_state = 8},
  [2941] = {.lex_state = 117, .external_lex_state = 8},
  [2942] = {.lex_state = 117, .external_lex_state = 8},
  [2943] = {.lex_state = 117, .external_lex_state = 8},
  [2944] = {.lex_state = 117, .external_lex_state = 8},
  [2945] = {.lex_state = 117, .external_lex_state = 8},
  [2946] = {.lex_state = 117, .external_lex_state = 8},
  [2947] = {.lex_state = 117, .external_lex_state = 8},
  [2948] = {.lex_state = 117, .external_lex_state = 8},
  [2949] = {.lex_state = 117, .external_lex_state = 8},
  [2950] = {.lex_state = 117, .external_lex_state = 8},
  [2951] = {.lex_state = 117, .external_lex_state = 8},
  [2952] = {.lex_state = 117, .external_lex_state = 8},
  [2953] = {.lex_state = 117, .external_lex_state = 8},
  [2954] = {.lex_state = 117, .external_lex_state = 8},
  [2955] = {.lex_state = 117, .external_lex_state = 8},
  [2956] = {.lex_state = 117, .external_lex_state = 8},
  [2957] = {.lex_state = 117, .external_lex_state = 8},
  [2958] = {.lex_state = 117, .external_lex_state = 8},
  [2959] = {.lex_state = 117, .external_lex_state = 8},
  [2960] = {.lex_state = 117, .external_lex_state = 8},
  [2961] = {.lex_state = 117, .external_lex_state = 8},
  [2962] = {.lex_state = 117, .external_lex_state = 8},
  [2963] = {.lex_state = 117, .external_lex_state = 8},
  [2964] = {.lex_state = 117, .external_lex_state = 8},
  [2965] = {.lex_state = 117, .external_lex_state = 8},
  [2966] = {.lex_state = 117, .external_lex_state = 8},
  [2967] = {.lex_state = 117, .external_lex_state = 8},
  [2968] = {.lex_state = 117, .external_lex_state = 8},
  [2969] = {.lex_state = 117, .external_lex_state = 8},
  [2970] = {.lex_state = 117, .external_lex_state = 8},
  [2971] = {.lex_state = 117, .external_lex_state = 8},
  [2972] = {.lex_state = 117, .external_lex_state = 8},
  [2973] = {.lex_state = 117, .external_lex_state = 8},
  [2974] = {.lex_state = 117, .external_lex_state = 8},
  [2975] = {.lex_state = 117, .external_lex_state = 8},
  [2976] = {.lex_state = 117, .external_lex_state = 8},
  [2977] = {.lex_state = 117, .external_lex_state = 8},
  [2978] = {.lex_state = 117, .external_lex_state = 8},
  [2979] = {.lex_state = 117, .external_lex_state = 8},
  [2980] = {.lex_state = 117, .external_lex_state = 8},
  [2981] = {.lex_state = 117, .external_lex_state = 8},
  [2982] = {.lex_state = 117, .external_lex_state = 8},
  [2983] = {.lex_state = 117, .external_lex_state = 8},
  [2984] = {.lex_state = 117, .external_lex_state = 8},
  [2985] = {.lex_state = 117, .external_lex_state = 8},
  [2986] = {.lex_state = 117, .external_lex_state = 8},
  [2987] = {.lex_state = 117, .external_lex_state = 8},
  [2988] = {.lex_state = 117, .external_lex_state = 8},
  [2989] = {.lex_state = 117, .external_lex_state = 8},
  [2990] = {.lex_state = 117, .external_lex_state = 8},
  [2991] = {.lex_state = 117, .external_lex_state = 8},
  [2992] = {.lex_state = 117, .external_lex_state = 8},
  [2993] = {.lex_state = 117, .external_lex_state = 8},
  [2994] = {.lex_state = 117, .external_lex_state = 8},
  [2995] = {.lex_state = 117, .external_lex_state = 8},
  [2996] = {.lex_state = 117, .external_lex_state = 8},
  [2997] = {.lex_state = 117, .external_lex_state = 8},
  [2998] = {.lex_state = 117, .external_lex_state = 8},
  [2999] = {.lex_state = 117, .external_lex_state = 8},
  [3000] = {.lex_state = 117, .external_lex_state = 8},
  [3001] = {.lex_state = 117, .external_lex_state = 8},
  [3002] = {.lex_state = 117, .external_lex_state = 8},
  [3003] = {.lex_state = 117, .external_lex_state = 8},
  [3004] = {.lex_state = 117, .external_lex_state = 8},
  [3005] = {.lex_state = 117, .external_lex_state = 8},
  [3006] = {.lex_state = 117, .external_lex_state = 8},
  [3007] = {.lex_state = 117, .external_lex_state = 8},
  [3008] = {.lex_state = 117, .external_lex_state = 8},
  [3009] = {.lex_state = 117, .external_lex_state = 8},
  [3010] = {.lex_state = 117, .external_lex_state = 8},
  [3011] = {.lex_state = 117, .external_lex_state = 8},
  [3012] = {.lex_state = 117, .external_lex_state = 8},
  [3013] = {.lex_state = 117, .external_lex_state = 8},
  [3014] = {.lex_state = 117, .external_lex_state = 8},
  [3015] = {.lex_state = 117, .external_lex_state = 8},
  [3016] = {.lex_state = 117, .external_lex_state = 8},
  [3017] = {.lex_state = 117, .external_lex_state = 8},
  [3018] = {.lex_state = 117, .external_lex_state = 8},
  [3019] = {.lex_state = 117, .external_lex_state = 8},
  [3020] = {.lex_state = 117, .external_lex_state = 8},
  [3021] = {.lex_state = 117, .external_lex_state = 8},
  [3022] = {.lex_state = 117, .external_lex_state = 8},
  [3023] = {.lex_state = 117, .external_lex_state = 8},
  [3024] = {.lex_state = 117, .external_lex_state = 8},
  [3025] = {.lex_state = 117, .external_lex_state = 8},
  [3026] = {.lex_state = 117, .external_lex_state = 8},
  [3027] = {.lex_state = 117, .external_lex_state = 8},
  [3028] = {.lex_state = 117, .external_lex_state = 8},
  [3029] = {.lex_state = 117, .external_lex_state = 8},
  [3030] = {.lex_state = 117, .external_lex_state = 8},
  [3031] = {.lex_state = 117, .external_lex_state = 8},
  [3032] = {.lex_state = 6, .external_lex_state = 14},
  [3033] = {.lex_state = 117, .external_lex_state = 8},
  [3034] = {.lex_state = 117, .external_lex_state = 8},
  [3035] = {.lex_state = 117, .external_lex_state = 8},
  [3036] = {.lex_state = 117, .external_lex_state = 8},
  [3037] = {.lex_state = 117, .external_lex_state = 8},
  [3038] = {.lex_state = 117, .external_lex_state = 8},
  [3039] = {.lex_state = 117, .external_lex_state = 8},
  [3040] = {.lex_state = 117, .external_lex_state = 8},
  [3041] = {.lex_state = 117, .external_lex_state = 8},
  [3042] = {.lex_state = 117, .external_lex_state = 8},
  [3043] = {.lex_state = 117, .external_lex_state = 8},
  [3044] = {.lex_state = 117, .external_lex_state = 8},
  [3045] = {.lex_state = 117, .external_lex_state = 8},
  [3046] = {.lex_state = 117, .external_lex_state = 8},
  [3047] = {.lex_state = 117, .external_lex_state = 8},
  [3048] = {.lex_state = 117, .external_lex_state = 8},
  [3049] = {.lex_state = 117, .external_lex_state = 8},
  [3050] = {.lex_state = 117, .external_lex_state = 8},
  [3051] = {.lex_state = 117, .external_lex_state = 8},
  [3052] = {.lex_state = 117, .external_lex_state = 8},
  [3053] = {.lex_state = 117, .external_lex_state = 8},
  [3054] = {.lex_state = 117, .external_lex_state = 8},
  [3055] = {.lex_state = 117, .external_lex_state = 8},
  [3056] = {.lex_state = 117, .external_lex_state = 8},
  [3057] = {.lex_state = 117, .external_lex_state = 8},
  [3058] = {.lex_state = 117, .external_lex_state = 8},
  [3059] = {.lex_state = 117, .external_lex_state = 8},
  [3060] = {.lex_state = 117, .external_lex_state = 8},
  [3061] = {.lex_state = 117, .external_lex_state = 8},
  [3062] = {.lex_state = 117, .external_lex_state = 8},
  [3063] = {.lex_state = 117, .external_lex_state = 8},
  [3064] = {.lex_state = 117, .external_lex_state = 8},
  [3065] = {.lex_state = 10, .external_lex_state = 15},
  [3066] = {.lex_state = 6, .external_lex_state = 14},
  [3067] = {.lex_state = 117, .external_lex_state = 6},
  [3068] = {.lex_state = 6, .external_lex_state = 14},
  [3069] = {.lex_state = 117, .external_lex_state = 8},
  [3070] = {.lex_state = 117, .external_lex_state = 8},
  [3071] = {.lex_state = 6, .external_lex_state = 14},
  [3072] = {.lex_state = 117, .external_lex_state = 8},
  [3073] = {.lex_state = 6, .external_lex_state = 14},
  [3074] = {.lex_state = 9, .external_lex_state = 16},
  [3075] = {.lex_state = 117, .external_lex_state = 8},
  [3076] = {.lex_state = 6, .external_lex_state = 14},
  [3077] = {.lex_state = 117, .external_lex_state = 8},
  [3078] = {.lex_state = 6, .external_lex_state = 14},
  [3079] = {.lex_state = 6, .external_lex_state = 14},
  [3080] = {.lex_state = 6, .external_lex_state = 14},
  [3081] = {.lex_state = 6, .external_lex_state = 14},
  [3082] = {.lex_state = 6, .external_lex_state = 14},
  [3083] = {.lex_state = 6, .external_lex_state = 14},
  [3084] = {.lex_state = 6, .external_lex_state = 14},
  [3085] = {.lex_state = 6, .external_lex_state = 14},
  [3086] = {.lex_state = 6, .external_lex_state = 14},
  [3087] = {.lex_state = 6, .external_lex_state = 14},
  [3088] = {.lex_state = 6, .external_lex_state = 14},
  [3089] = {.lex_state = 6, .external_lex_state = 14},
  [3090] = {.lex_state = 6, .external_lex_state = 14},
  [3091] = {.lex_state = 117, .external_lex_state = 8},
  [3092] = {.lex_state = 6, .external_lex_state = 14},
  [3093] = {.lex_state = 6, .external_lex_state = 14},
  [3094] = {.lex_state = 6, .external_lex_state = 14},
  [3095] = {.lex_state = 117, .external_lex_state = 8},
  [3096] = {.lex_state = 117, .external_lex_state = 8},
  [3097] = {.lex_state = 6, .external_lex_state = 14},
  [3098] = {.lex_state = 117, .external_lex_state = 8},
  [3099] = {.lex_state = 6, .external_lex_state = 14},
  [3100] = {.lex_state = 117, .external_lex_state = 8},
  [3101] = {.lex_state = 117, .external_lex_state = 8},
  [3102] = {.lex_state = 117, .external_lex_state = 8},
  [3103] = {.lex_state = 117, .external_lex_state = 8},
  [3104] = {.lex_state = 117, .external_lex_state = 8},
  [3105] = {.lex_state = 117, .external_lex_state = 8},
  [3106] = {.lex_state = 117, .external_lex_state = 8},
  [3107] = {.lex_state = 117, .external_lex_state = 8},
  [3108] = {.lex_state = 117, .external_lex_state = 8},
  [3109] = {.lex_state = 117, .external_lex_state = 8},
  [3110] = {.lex_state = 117, .external_lex_state = 8},
  [3111] = {.lex_state = 117, .external_lex_state = 8},
  [3112] = {.lex_state = 117, .external_lex_state = 8},
  [3113] = {.lex_state = 6, .external_lex_state = 14},
  [3114] = {.lex_state = 117, .external_lex_state = 8},
  [3115] = {.lex_state = 117, .external_lex_state = 8},
  [3116] = {.lex_state = 117, .external_lex_state = 8},
  [3117] = {.lex_state = 117, .external_lex_state = 8},
  [3118] = {.lex_state = 117, .external_lex_state = 8},
  [3119] = {.lex_state = 117, .external_lex_state = 8},
  [3120] = {.lex_state = 117, .external_lex_state = 8},
  [3121] = {.lex_state = 117, .external_lex_state = 8},
  [3122] = {.lex_state = 117, .external_lex_state = 8},
  [3123] = {.lex_state = 117, .external_lex_state = 8},
  [3124] = {.lex_state = 117, .external_lex_state = 8},
  [3125] = {.lex_state = 117, .external_lex_state = 8},
  [3126] = {.lex_state = 117, .external_lex_state = 8},
  [3127] = {.lex_state = 117, .external_lex_state = 8},
  [3128] = {.lex_state = 117, .external_lex_state = 8},
  [3129] = {.lex_state = 117, .external_lex_state = 8},
  [3130] = {.lex_state = 6, .external_lex_state = 14},
  [3131] = {.lex_state = 6, .external_lex_state = 14},
  [3132] = {.lex_state = 12},
  [3133] = {.lex_state = 117, .external_lex_state = 8},
  [3134] = {.lex_state = 117, .external_lex_state = 8},
  [3135] = {.lex_state = 117, .external_lex_state = 8},
  [3136] = {.lex_state = 117, .external_lex_state = 8},
  [3137] = {.lex_state = 6, .external_lex_state = 14},
  [3138] = {.lex_state = 117, .external_lex_state = 8},
  [3139] = {.lex_state = 6, .external_lex_state = 14},
  [3140] = {.lex_state = 117, .external_lex_state = 8},
  [3141] = {.lex_state = 6, .external_lex_state = 14},
  [3142] = {.lex_state = 6, .external_lex_state = 14},
  [3143] = {.lex_state = 6, .external_lex_state = 14},
  [3144] = {.lex_state = 117, .external_lex_state = 8},
  [3145] = {.lex_state = 5, .external_lex_state = 7},
  [3146] = {.lex_state = 117, .external_lex_state = 17},
  [3147] = {.lex_state = 117, .external_lex_state = 7},
  [3148] = {.lex_state = 10, .external_lex_state = 15},
  [3149] = {.lex_state = 10, .external_lex_state = 15},
  [3150] = {.lex_state = 10, .external_lex_state = 15},
  [3151] = {.lex_state = 117, .external_lex_state = 17},
  [3152] = {.lex_state = 117, .external_lex_state = 17},
  [3153] = {.lex_state = 5, .external_lex_state = 7},
  [3154] = {.lex_state = 117, .external_lex_state = 17},
  [3155] = {.lex_state = 117, .external_lex_state = 7},
  [3156] = {.lex_state = 117, .external_lex_state = 7},
  [3157] = {.lex_state = 117, .external_lex_state = 17},
  [3158] = {.lex_state = 12},
  [3159] = {.lex_state = 117, .external_lex_state = 17},
  [3160] = {.lex_state = 117, .external_lex_state = 12},
  [3161] = {.lex_state = 117, .external_lex_state = 17},
  [3162] = {.lex_state = 117, .external_lex_state = 7},
  [3163] = {.lex_state = 117, .external_lex_state = 7},
  [3164] = {.lex_state = 117, .external_lex_state = 7},
  [3165] = {.lex_state = 9, .external_lex_state = 16},
  [3166] = {.lex_state = 117, .external_lex_state = 7},
  [3167] = {.lex_state = 117, .external_lex_state = 17},
  [3168] = {.lex_state = 117, .external_lex_state = 12},
  [3169] = {.lex_state = 117, .external_lex_state = 7},
  [3170] = {.lex_state = 117, .external_lex_state = 7},
  [3171] = {.lex_state = 117, .external_lex_state = 7},
  [3172] = {.lex_state = 117, .external_lex_state = 7},
  [3173] = {.lex_state = 117, .external_lex_state = 7},
  [3174] = {.lex_state = 117, .external_lex_state = 7},
  [3175] = {.lex_state = 117, .external_lex_state = 7},
  [3176] = {.lex_state = 117, .external_lex_state = 7},
  [3177] = {.lex_state = 117, .external_lex_state = 7},
  [3178] = {.lex_state = 117, .external_lex_state = 7},
  [3179] = {.lex_state = 117, .external_lex_state = 7},
  [3180] = {.lex_state = 117, .external_lex_state = 7},
  [3181] = {.lex_state = 117, .external_lex_state = 7},
  [3182] = {.lex_state = 117, .external_lex_state = 7},
  [3183] = {.lex_state = 117, .external_lex_state = 7},
  [3184] = {.lex_state = 117, .external_lex_state = 7},
  [3185] = {.lex_state = 117, .external_lex_state = 7},
  [3186] = {.lex_state = 117, .external_lex_state = 7},
  [3187] = {.lex_state = 117, .external_lex_state = 7},
  [3188] = {.lex_state = 117, .external_lex_state = 7},
  [3189] = {.lex_state = 117, .external_lex_state = 7},
  [3190] = {.lex_state = 117, .external_lex_state = 7},
  [3191] = {.lex_state = 117, .external_lex_state = 7},
  [3192] = {.lex_state = 117, .external_lex_state = 7},
  [3193] = {.lex_state = 117, .external_lex_state = 7},
  [3194] = {.lex_state = 117, .external_lex_state = 7},
  [3195] = {.lex_state = 117, .external_lex_state = 7},
  [3196] = {.lex_state = 117, .external_lex_state = 7},
  [3197] = {.lex_state = 117, .external_lex_state = 7},
  [3198] = {.lex_state = 117, .external_lex_state = 7},
  [3199] = {.lex_state = 117, .external_lex_state = 7},
  [3200] = {.lex_state = 117, .external_lex_state = 7},
  [3201] = {.lex_state = 117, .external_lex_state = 7},
  [3202] = {.lex_state = 117, .external_lex_state = 7},
  [3203] = {.lex_state = 117, .external_lex_state = 7},
  [3204] = {.lex_state = 117, .external_lex_state = 7},
  [3205] = {.lex_state = 117, .external_lex_state = 7},
  [3206] = {.lex_state = 117, .external_lex_state = 7},
  [3207] = {.lex_state = 117, .external_lex_state = 7},
  [3208] = {.lex_state = 117, .external_lex_state = 7},
  [3209] = {.lex_state = 117, .external_lex_state = 7},
  [3210] = {.lex_state = 117, .external_lex_state = 7},
  [3211] = {.lex_state = 117, .external_lex_state = 7},
  [3212] = {.lex_state = 117, .external_lex_state = 7},
  [3213] = {.lex_state = 117, .external_lex_state = 7},
  [3214] = {.lex_state = 117, .external_lex_state = 7},
  [3215] = {.lex_state = 117, .external_lex_state = 7},
  [3216] = {.lex_state = 117, .external_lex_state = 7},
  [3217] = {.lex_state = 117, .external_lex_state = 7},
  [3218] = {.lex_state = 117, .external_lex_state = 7},
  [3219] = {.lex_state = 117, .external_lex_state = 7},
  [3220] = {.lex_state = 117, .external_lex_state = 7},
  [3221] = {.lex_state = 117, .external_lex_state = 7},
  [3222] = {.lex_state = 117, .external_lex_state = 7},
  [3223] = {.lex_state = 117, .external_lex_state = 7},
  [3224] = {.lex_state = 117, .external_lex_state = 7},
  [3225] = {.lex_state = 117, .external_lex_state = 7},
  [3226] = {.lex_state = 117, .external_lex_state = 7},
  [3227] = {.lex_state = 117, .external_lex_state = 7},
  [3228] = {.lex_state = 117, .external_lex_state = 7},
  [3229] = {.lex_state = 117, .external_lex_state = 7},
  [3230] = {.lex_state = 117, .external_lex_state = 7},
  [3231] = {.lex_state = 117, .external_lex_state = 7},
  [3232] = {.lex_state = 117, .external_lex_state = 7},
  [3233] = {.lex_state = 117, .external_lex_state = 7},
  [3234] = {.lex_state = 117, .external_lex_state = 7},
  [3235] = {.lex_state = 117, .external_lex_state = 7},
  [3236] = {.lex_state = 117, .external_lex_state = 7},
  [3237] = {.lex_state = 117, .external_lex_state = 7},
  [3238] = {.lex_state = 117, .external_lex_state = 7},
  [3239] = {.lex_state = 117, .external_lex_state = 7},
  [3240] = {.lex_state = 117, .external_lex_state = 7},
  [3241] = {.lex_state = 12},
  [3242] = {.lex_state = 117, .external_lex_state = 7},
  [3243] = {.lex_state = 117, .external_lex_state = 7},
  [3244] = {.lex_state = 117, .external_lex_state = 7},
  [3245] = {.lex_state = 117, .external_lex_state = 7},
  [3246] = {.lex_state = 117, .external_lex_state = 7},
  [3247] = {.lex_state = 117, .external_lex_state = 7},
  [3248] = {.lex_state = 117, .external_lex_state = 7},
  [3249] = {.lex_state = 117, .external_lex_state = 7},
  [3250] = {.lex_state = 117, .external_lex_state = 7},
  [3251] = {.lex_state = 117, .external_lex_state = 7},
  [3252] = {.lex_state = 10, .external_lex_state = 15},
  [3253] = {.lex_state = 117, .external_lex_state = 7},
  [3254] = {.lex_state = 10, .external_lex_state = 17},
  [3255] = {.lex_state = 117, .external_lex_state = 7},
  [3256] = {.lex_state = 117, .external_lex_state = 7},
  [3257] = {.lex_state = 117, .external_lex_state = 7},
  [3258] = {.lex_state = 117, .external_lex_state = 7},
  [3259] = {.lex_state = 117, .external_lex_state = 7},
  [3260] = {.lex_state = 117, .external_lex_state = 7},
  [3261] = {.lex_state = 117, .external_lex_state = 7},
  [3262] = {.lex_state = 117, .external_lex_state = 7},
  [3263] = {.lex_state = 117, .external_lex_state = 7},
  [3264] = {.lex_state = 117, .external_lex_state = 7},
  [3265] = {.lex_state = 117, .external_lex_state = 7},
  [3266] = {.lex_state = 117, .external_lex_state = 7},
  [3267] = {.lex_state = 117, .external_lex_state = 7},
  [3268] = {.lex_state = 117, .external_lex_state = 7},
  [3269] = {.lex_state = 117, .external_lex_state = 7},
  [3270] = {.lex_state = 117, .external_lex_state = 7},
  [3271] = {.lex_state = 117, .external_lex_state = 7},
  [3272] = {.lex_state = 117, .external_lex_state = 7},
  [3273] = {.lex_state = 117, .external_lex_state = 7},
  [3274] = {.lex_state = 117, .external_lex_state = 7},
  [3275] = {.lex_state = 117, .external_lex_state = 7},
  [3276] = {.lex_state = 117, .external_lex_state = 7},
  [3277] = {.lex_state = 117, .external_lex_state = 7},
  [3278] = {.lex_state = 117, .external_lex_state = 7},
  [3279] = {.lex_state = 117, .external_lex_state = 7},
  [3280] = {.lex_state = 117, .external_lex_state = 7},
  [3281] = {.lex_state = 117, .external_lex_state = 7},
  [3282] = {.lex_state = 117, .external_lex_state = 7},
  [3283] = {.lex_state = 117, .external_lex_state = 7},
  [3284] = {.lex_state = 117, .external_lex_state = 7},
  [3285] = {.lex_state = 117, .external_lex_state = 7},
  [3286] = {.lex_state = 117, .external_lex_state = 7},
  [3287] = {.lex_state = 117, .external_lex_state = 7},
  [3288] = {.lex_state = 117, .external_lex_state = 7},
  [3289] = {.lex_state = 117, .external_lex_state = 7},
  [3290] = {.lex_state = 117, .external_lex_state = 7},
  [3291] = {.lex_state = 117, .external_lex_state = 7},
  [3292] = {.lex_state = 117, .external_lex_state = 7},
  [3293] = {.lex_state = 117, .external_lex_state = 7},
  [3294] = {.lex_state = 117, .external_lex_state = 7},
  [3295] = {.lex_state = 117, .external_lex_state = 7},
  [3296] = {.lex_state = 117, .external_lex_state = 7},
  [3297] = {.lex_state = 117, .external_lex_state = 7},
  [3298] = {.lex_state = 117, .external_lex_state = 7},
  [3299] = {.lex_state = 117, .external_lex_state = 7},
  [3300] = {.lex_state = 117, .external_lex_state = 7},
  [3301] = {.lex_state = 117, .external_lex_state = 7},
  [3302] = {.lex_state = 117, .external_lex_state = 7},
  [3303] = {.lex_state = 117, .external_lex_state = 7},
  [3304] = {.lex_state = 117, .external_lex_state = 7},
  [3305] = {.lex_state = 117, .external_lex_state = 7},
  [3306] = {.lex_state = 117, .external_lex_state = 7},
  [3307] = {.lex_state = 117, .external_lex_state = 7},
  [3308] = {.lex_state = 117, .external_lex_state = 7},
  [3309] = {.lex_state = 117, .external_lex_state = 7},
  [3310] = {.lex_state = 117, .external_lex_state = 7},
  [3311] = {.lex_state = 117, .external_lex_state = 7},
  [3312] = {.lex_state = 117, .external_lex_state = 7},
  [3313] = {.lex_state = 117, .external_lex_state = 7},
  [3314] = {.lex_state = 117, .external_lex_state = 7},
  [3315] = {.lex_state = 117, .external_lex_state = 7},
  [3316] = {.lex_state = 117, .external_lex_state = 7},
  [3317] = {.lex_state = 117, .external_lex_state = 7},
  [3318] = {.lex_state = 117, .external_lex_state = 7},
  [3319] = {.lex_state = 117, .external_lex_state = 7},
  [3320] = {.lex_state = 117, .external_lex_state = 7},
  [3321] = {.lex_state = 117, .external_lex_state = 7},
  [3322] = {.lex_state = 117, .external_lex_state = 7},
  [3323] = {.lex_state = 117, .external_lex_state = 7},
  [3324] = {.lex_state = 117, .external_lex_state = 7},
  [3325] = {.lex_state = 117, .external_lex_state = 7},
  [3326] = {.lex_state = 117, .external_lex_state = 7},
  [3327] = {.lex_state = 117, .external_lex_state = 7},
  [3328] = {.lex_state = 117, .external_lex_state = 7},
  [3329] = {.lex_state = 117, .external_lex_state = 7},
  [3330] = {.lex_state = 117, .external_lex_state = 7},
  [3331] = {.lex_state = 117, .external_lex_state = 7},
  [3332] = {.lex_state = 117, .external_lex_state = 7},
  [3333] = {.lex_state = 117, .external_lex_state = 7},
  [3334] = {.lex_state = 117, .external_lex_state = 7},
  [3335] = {.lex_state = 117, .external_lex_state = 7},
  [3336] = {.lex_state = 117, .external_lex_state = 7},
  [3337] = {.lex_state = 117, .external_lex_state = 7},
  [3338] = {.lex_state = 117, .external_lex_state = 7},
  [3339] = {.lex_state = 117, .external_lex_state = 7},
  [3340] = {.lex_state = 117, .external_lex_state = 7},
  [3341] = {.lex_state = 117, .external_lex_state = 7},
  [3342] = {.lex_state = 117, .external_lex_state = 7},
  [3343] = {.lex_state = 117, .external_lex_state = 7},
  [3344] = {.lex_state = 117, .external_lex_state = 7},
  [3345] = {.lex_state = 117, .external_lex_state = 7},
  [3346] = {.lex_state = 117, .external_lex_state = 7},
  [3347] = {.lex_state = 117, .external_lex_state = 7},
  [3348] = {.lex_state = 117, .external_lex_state = 7},
  [3349] = {.lex_state = 117, .external_lex_state = 7},
  [3350] = {.lex_state = 117, .external_lex_state = 7},
  [3351] = {.lex_state = 117, .external_lex_state = 7},
  [3352] = {.lex_state = 117, .external_lex_state = 7},
  [3353] = {.lex_state = 117, .external_lex_state = 7},
  [3354] = {.lex_state = 117, .external_lex_state = 7},
  [3355] = {.lex_state = 117, .external_lex_state = 7},
  [3356] = {.lex_state = 117, .external_lex_state = 7},
  [3357] = {.lex_state = 117, .external_lex_state = 7},
  [3358] = {.lex_state = 117, .external_lex_state = 7},
  [3359] = {.lex_state = 117, .external_lex_state = 7},
  [3360] = {.lex_state = 117, .external_lex_state = 7},
  [3361] = {.lex_state = 117, .external_lex_state = 7},
  [3362] = {.lex_state = 117, .external_lex_state = 7},
  [3363] = {.lex_state = 117, .external_lex_state = 7},
  [3364] = {.lex_state = 117, .external_lex_state = 7},
  [3365] = {.lex_state = 117, .external_lex_state = 7},
  [3366] = {.lex_state = 117, .external_lex_state = 7},
  [3367] = {.lex_state = 117, .external_lex_state = 7},
  [3368] = {.lex_state = 117, .external_lex_state = 7},
  [3369] = {.lex_state = 117, .external_lex_state = 7},
  [3370] = {.lex_state = 117, .external_lex_state = 7},
  [3371] = {.lex_state = 117, .external_lex_state = 7},
  [3372] = {.lex_state = 117, .external_lex_state = 7},
  [3373] = {.lex_state = 117, .external_lex_state = 7},
  [3374] = {.lex_state = 117, .external_lex_state = 7},
  [3375] = {.lex_state = 117, .external_lex_state = 7},
  [3376] = {.lex_state = 117, .external_lex_state = 7},
  [3377] = {.lex_state = 117, .external_lex_state = 7},
  [3378] = {.lex_state = 117, .external_lex_state = 7},
  [3379] = {.lex_state = 117, .external_lex_state = 7},
  [3380] = {.lex_state = 117, .external_lex_state = 7},
  [3381] = {.lex_state = 117, .external_lex_state = 7},
  [3382] = {.lex_state = 117, .external_lex_state = 7},
  [3383] = {.lex_state = 117, .external_lex_state = 7},
  [3384] = {.lex_state = 117, .external_lex_state = 7},
  [3385] = {.lex_state = 12},
  [3386] = {.lex_state = 117, .external_lex_state = 7},
  [3387] = {.lex_state = 117, .external_lex_state = 7},
  [3388] = {.lex_state = 117, .external_lex_state = 7},
  [3389] = {.lex_state = 117, .external_lex_state = 7},
  [3390] = {.lex_state = 117, .external_lex_state = 7},
  [3391] = {.lex_state = 117, .external_lex_state = 3},
  [3392] = {.lex_state = 117, .external_lex_state = 7},
  [3393] = {.lex_state = 117, .external_lex_state = 7},
  [3394] = {.lex_state = 117, .external_lex_state = 7},
  [3395] = {.lex_state = 117, .external_lex_state = 7},
  [3396] = {.lex_state = 117, .external_lex_state = 7},
  [3397] = {.lex_state = 117, .external_lex_state = 7},
  [3398] = {.lex_state = 117, .external_lex_state = 7},
  [3399] = {.lex_state = 117, .external_lex_state = 7},
  [3400] = {.lex_state = 117, .external_lex_state = 7},
  [3401] = {.lex_state = 117, .external_lex_state = 7},
  [3402] = {.lex_state = 117, .external_lex_state = 7},
  [3403] = {.lex_state = 117, .external_lex_state = 7},
  [3404] = {.lex_state = 117, .external_lex_state = 7},
  [3405] = {.lex_state = 117, .external_lex_state = 7},
  [3406] = {.lex_state = 117, .external_lex_state = 7},
  [3407] = {.lex_state = 117, .external_lex_state = 7},
  [3408] = {.lex_state = 117, .external_lex_state = 7},
  [3409] = {.lex_state = 117, .external_lex_state = 3},
  [3410] = {.lex_state = 10, .external_lex_state = 17},
  [3411] = {.lex_state = 117, .external_lex_state = 3},
  [3412] = {.lex_state = 117, .external_lex_state = 3},
  [3413] = {.lex_state = 117, .external_lex_state = 3},
  [3414] = {.lex_state = 6, .external_lex_state = 17},
  [3415] = {.lex_state = 12},
  [3416] = {.lex_state = 117, .external_lex_state = 17},
  [3417] = {.lex_state = 117, .external_lex_state = 12},
  [3418] = {.lex_state = 117, .external_lex_state = 3},
  [3419] = {.lex_state = 10, .external_lex_state = 15},
  [3420] = {.lex_state = 117, .external_lex_state = 3},
  [3421] = {.lex_state = 117, .external_lex_state = 8},
  [3422] = {.lex_state = 117, .external_lex_state = 17},
  [3423] = {.lex_state = 117, .external_lex_state = 12},
  [3424] = {.lex_state = 117, .external_lex_state = 17},
  [3425] = {.lex_state = 117, .external_lex_state = 3},
  [3426] = {.lex_state = 117, .external_lex_state = 17},
  [3427] = {.lex_state = 117, .external_lex_state = 17},
  [3428] = {.lex_state = 117, .external_lex_state = 17},
  [3429] = {.lex_state = 117, .external_lex_state = 17},
  [3430] = {.lex_state = 117, .external_lex_state = 17},
  [3431] = {.lex_state = 117, .external_lex_state = 3},
  [3432] = {.lex_state = 6, .external_lex_state = 8},
  [3433] = {.lex_state = 6, .external_lex_state = 8},
  [3434] = {.lex_state = 6, .external_lex_state = 8},
  [3435] = {.lex_state = 6, .external_lex_state = 8},
  [3436] = {.lex_state = 6, .external_lex_state = 8},
  [3437] = {.lex_state = 6, .external_lex_state = 8},
  [3438] = {.lex_state = 6, .external_lex_state = 8},
  [3439] = {.lex_state = 6, .external_lex_state = 8},
  [3440] = {.lex_state = 6, .external_lex_state = 8},
  [3441] = {.lex_state = 6, .external_lex_state = 8},
  [3442] = {.lex_state = 6, .external_lex_state = 8},
  [3443] = {.lex_state = 6, .external_lex_state = 8},
  [3444] = {.lex_state = 6, .external_lex_state = 8},
  [3445] = {.lex_state = 6, .external_lex_state = 8},
  [3446] = {.lex_state = 6, .external_lex_state = 8},
  [3447] = {.lex_state = 6, .external_lex_state = 8},
  [3448] = {.lex_state = 6, .external_lex_state = 17},
  [3449] = {.lex_state = 6, .external_lex_state = 8},
  [3450] = {.lex_state = 6, .external_lex_state = 8},
  [3451] = {.lex_state = 6, .external_lex_state = 8},
  [3452] = {.lex_state = 6, .external_lex_state = 8},
  [3453] = {.lex_state = 6, .external_lex_state = 8},
  [3454] = {.lex_state = 6, .external_lex_state = 8},
  [3455] = {.lex_state = 6, .external_lex_state = 8},
  [3456] = {.lex_state = 117, .external_lex_state = 6},
  [3457] = {.lex_state = 117, .external_lex_state = 12},
  [3458] = {.lex_state = 10, .external_lex_state = 17},
  [3459] = {.lex_state = 6, .external_lex_state = 8},
  [3460] = {.lex_state = 10, .external_lex_state = 17},
  [3461] = {.lex_state = 10, .external_lex_state = 17},
  [3462] = {.lex_state = 6, .external_lex_state = 8},
  [3463] = {.lex_state = 117, .external_lex_state = 12},
  [3464] = {.lex_state = 6, .external_lex_state = 8},
  [3465] = {.lex_state = 6, .external_lex_state = 8},
  [3466] = {.lex_state = 12},
  [3467] = {.lex_state = 6, .external_lex_state = 8},
  [3468] = {.lex_state = 6, .external_lex_state = 8},
  [3469] = {.lex_state = 11, .external_lex_state = 8},
  [3470] = {.lex_state = 6, .external_lex_state = 8},
  [3471] = {.lex_state = 6, .external_lex_state = 8},
  [3472] = {.lex_state = 6, .external_lex_state = 8},
  [3473] = {.lex_state = 6, .external_lex_state = 8},
  [3474] = {.lex_state = 6, .external_lex_state = 8},
  [3475] = {.lex_state = 11, .external_lex_state = 8},
  [3476] = {.lex_state = 117, .external_lex_state = 14},
  [3477] = {.lex_state = 117, .external_lex_state = 14},
  [3478] = {.lex_state = 117, .external_lex_state = 14},
  [3479] = {.lex_state = 11, .external_lex_state = 8},
  [3480] = {.lex_state = 117, .external_lex_state = 14},
  [3481] = {.lex_state = 6, .external_lex_state = 17},
  [3482] = {.lex_state = 11, .external_lex_state = 8},
  [3483] = {.lex_state = 6, .external_lex_state = 8},
  [3484] = {.lex_state = 117, .external_lex_state = 9},
  [3485] = {.lex_state = 11, .external_lex_state = 8},
  [3486] = {.lex_state = 10, .external_lex_state = 17},
  [3487] = {.lex_state = 6, .external_lex_state = 8},
  [3488] = {.lex_state = 6, .external_lex_state = 8},
  [3489] = {.lex_state = 117, .external_lex_state = 14},
  [3490] = {.lex_state = 6, .external_lex_state = 8},
  [3491] = {.lex_state = 117, .external_lex_state = 7},
  [3492] = {.lex_state = 6, .external_lex_state = 8},
  [3493] = {.lex_state = 6, .external_lex_state = 8},
  [3494] = {.lex_state = 11, .external_lex_state = 8},
  [3495] = {.lex_state = 11, .external_lex_state = 8},
  [3496] = {.lex_state = 6, .external_lex_state = 8},
  [3497] = {.lex_state = 6, .external_lex_state = 8},
  [3498] = {.lex_state = 117, .external_lex_state = 14},
  [3499] = {.lex_state = 6, .external_lex_state = 8},
  [3500] = {.lex_state = 6, .external_lex_state = 17},
  [3501] = {.lex_state = 6, .external_lex_state = 8},
  [3502] = {.lex_state = 6, .external_lex_state = 17},
  [3503] = {.lex_state = 6, .external_lex_state = 8},
  [3504] = {.lex_state = 6, .external_lex_state = 8},
  [3505] = {.lex_state = 11, .external_lex_state = 8},
  [3506] = {.lex_state = 11, .external_lex_state = 8},
  [3507] = {.lex_state = 6, .external_lex_state = 8},
  [3508] = {.lex_state = 11, .external_lex_state = 8},
  [3509] = {.lex_state = 117, .external_lex_state = 14},
  [3510] = {.lex_state = 6, .external_lex_state = 8},
  [3511] = {.lex_state = 6, .external_lex_state = 8},
  [3512] = {.lex_state = 6, .external_lex_state = 8},
  [3513] = {.lex_state = 6, .external_lex_state = 8},
  [3514] = {.lex_state = 6, .external_lex_state = 8},
  [3515] = {.lex_state = 6, .external_lex_state = 8},
  [3516] = {.lex_state = 6, .external_lex_state = 8},
  [3517] = {.lex_state = 6, .external_lex_state = 8},
  [3518] = {.lex_state = 6, .external_lex_state = 8},
  [3519] = {.lex_state = 6, .external_lex_state = 8},
  [3520] = {.lex_state = 6, .external_lex_state = 8},
  [3521] = {.lex_state = 6, .external_lex_state = 8},
  [3522] = {.lex_state = 6, .external_lex_state = 8},
  [3523] = {.lex_state = 6, .external_lex_state = 8},
  [3524] = {.lex_state = 6, .external_lex_state = 8},
  [3525] = {.lex_state = 6, .external_lex_state = 8},
  [3526] = {.lex_state = 6, .external_lex_state = 8},
  [3527] = {.lex_state = 6, .external_lex_state = 8},
  [3528] = {.lex_state = 6, .external_lex_state = 8},
  [3529] = {.lex_state = 6, .external_lex_state = 8},
  [3530] = {.lex_state = 6, .external_lex_state = 8},
  [3531] = {.lex_state = 6, .external_lex_state = 8},
  [3532] = {.lex_state = 6, .external_lex_state = 8},
  [3533] = {.lex_state = 117, .external_lex_state = 10},
  [3534] = {.lex_state = 6, .external_lex_state = 8},
  [3535] = {.lex_state = 6, .external_lex_state = 8},
  [3536] = {.lex_state = 6, .external_lex_state = 8},
  [3537] = {.lex_state = 6, .external_lex_state = 8},
  [3538] = {.lex_state = 6, .external_lex_state = 8},
  [3539] = {.lex_state = 6, .external_lex_state = 8},
  [3540] = {.lex_state = 6, .external_lex_state = 8},
  [3541] = {.lex_state = 6, .external_lex_state = 8},
  [3542] = {.lex_state = 6, .external_lex_state = 8},
  [3543] = {.lex_state = 6, .external_lex_state = 8},
  [3544] = {.lex_state = 6, .external_lex_state = 8},
  [3545] = {.lex_state = 6, .external_lex_state = 8},
  [3546] = {.lex_state = 117, .external_lex_state = 12},
  [3547] = {.lex_state = 6, .external_lex_state = 17},
  [3548] = {.lex_state = 117, .external_lex_state = 12},
  [3549] = {.lex_state = 10, .external_lex_state = 17},
  [3550] = {.lex_state = 6, .external_lex_state = 8},
  [3551] = {.lex_state = 6, .external_lex_state = 8},
  [3552] = {.lex_state = 6, .external_lex_state = 8},
  [3553] = {.lex_state = 6, .external_lex_state = 8},
  [3554] = {.lex_state = 117, .external_lex_state = 17},
  [3555] = {.lex_state = 6, .external_lex_state = 17},
  [3556] = {.lex_state = 117, .external_lex_state = 17},
  [3557] = {.lex_state = 117, .external_lex_state = 17},
  [3558] = {.lex_state = 9, .external_lex_state = 16},
  [3559] = {.lex_state = 10, .external_lex_state = 12},
  [3560] = {.lex_state = 117, .external_lex_state = 8},
  [3561] = {.lex_state = 117, .external_lex_state = 8},
  [3562] = {.lex_state = 117, .external_lex_state = 12},
  [3563] = {.lex_state = 10, .external_lex_state = 12},
  [3564] = {.lex_state = 117, .external_lex_state = 12},
  [3565] = {.lex_state = 117, .external_lex_state = 8},
  [3566] = {.lex_state = 117, .external_lex_state = 8},
  [3567] = {.lex_state = 12},
  [3568] = {.lex_state = 117, .external_lex_state = 12},
  [3569] = {.lex_state = 117, .external_lex_state = 12},
  [3570] = {.lex_state = 117, .external_lex_state = 8},
  [3571] = {.lex_state = 117, .external_lex_state = 8},
  [3572] = {.lex_state = 117, .external_lex_state = 8},
  [3573] = {.lex_state = 117, .external_lex_state = 8},
  [3574] = {.lex_state = 117, .external_lex_state = 12},
  [3575] = {.lex_state = 117, .external_lex_state = 12},
  [3576] = {.lex_state = 117, .external_lex_state = 15},
  [3577] = {.lex_state = 117, .external_lex_state = 15},
  [3578] = {.lex_state = 117, .external_lex_state = 15},
  [3579] = {.lex_state = 117, .external_lex_state = 14},
  [3580] = {.lex_state = 10, .external_lex_state = 12},
  [3581] = {.lex_state = 117, .external_lex_state = 12},
  [3582] = {.lex_state = 10, .external_lex_state = 12},
  [3583] = {.lex_state = 117, .external_lex_state = 15},
  [3584] = {.lex_state = 117, .external_lex_state = 12},
  [3585] = {.lex_state = 117, .external_lex_state = 14},
  [3586] = {.lex_state = 117, .external_lex_state = 15},
  [3587] = {.lex_state = 117, .external_lex_state = 15},
  [3588] = {.lex_state = 10, .external_lex_state = 12},
  [3589] = {.lex_state = 117, .external_lex_state = 12},
  [3590] = {.lex_state = 117, .external_lex_state = 15},
  [3591] = {.lex_state = 6, .external_lex_state = 8},
  [3592] = {.lex_state = 117, .external_lex_state = 14},
  [3593] = {.lex_state = 117, .external_lex_state = 12},
  [3594] = {.lex_state = 117, .external_lex_state = 9},
  [3595] = {.lex_state = 117, .external_lex_state = 8},
  [3596] = {.lex_state = 10, .external_lex_state = 12},
  [3597] = {.lex_state = 6, .external_lex_state = 8},
  [3598] = {.lex_state = 117, .external_lex_state = 11},
  [3599] = {.lex_state = 117, .external_lex_state = 12},
  [3600] = {.lex_state = 117, .external_lex_state = 8},
  [3601] = {.lex_state = 117, .external_lex_state = 12},
  [3602] = {.lex_state = 117, .external_lex_state = 14},
  [3603] = {.lex_state = 117, .external_lex_state = 9},
  [3604] = {.lex_state = 117, .external_lex_state = 9},
  [3605] = {.lex_state = 117, .external_lex_state = 12},
  [3606] = {.lex_state = 6, .external_lex_state = 8},
  [3607] = {.lex_state = 10, .external_lex_state = 12},
  [3608] = {.lex_state = 6, .external_lex_state = 8},
  [3609] = {.lex_state = 117, .external_lex_state = 12},
  [3610] = {.lex_state = 117, .external_lex_state = 14},
  [3611] = {.lex_state = 4, .external_lex_state = 3},
  [3612] = {.lex_state = 4, .external_lex_state = 3},
  [3613] = {.lex_state = 117, .external_lex_state = 12},
  [3614] = {.lex_state = 4, .external_lex_state = 3},
  [3615] = {.lex_state = 4, .external_lex_state = 3},
  [3616] = {.lex_state = 4, .external_lex_state = 3},
  [3617] = {.lex_state = 117, .external_lex_state = 12},
  [3618] = {.lex_state = 117, .external_lex_state = 12},
  [3619] = {.lex_state = 117, .external_lex_state = 8},
  [3620] = {.lex_state = 117, .external_lex_state = 12},
  [3621] = {.lex_state = 6, .external_lex_state = 18},
  [3622] = {.lex_state = 117, .external_lex_state = 12},
  [3623] = {.lex_state = 117, .external_lex_state = 17},
  [3624] = {.lex_state = 117, .external_lex_state = 12},
  [3625] = {.lex_state = 117, .external_lex_state = 12},
  [3626] = {.lex_state = 117, .external_lex_state = 17},
  [3627] = {.lex_state = 117, .external_lex_state = 17},
  [3628] = {.lex_state = 117, .external_lex_state = 17},
  [3629] = {.lex_state = 117, .external_lex_state = 17},
  [3630] = {.lex_state = 117, .external_lex_state = 2},
  [3631] = {.lex_state = 117, .external_lex_state = 2},
  [3632] = {.lex_state = 117, .external_lex_state = 18},
  [3633] = {.lex_state = 117, .external_lex_state = 2},
  [3634] = {.lex_state = 117, .external_lex_state = 2},
  [3635] = {.lex_state = 6, .external_lex_state = 18},
  [3636] = {.lex_state = 117, .external_lex_state = 2},
  [3637] = {.lex_state = 117, .external_lex_state = 2},
  [3638] = {.lex_state = 117, .external_lex_state = 2},
  [3639] = {.lex_state = 117, .external_lex_state = 2},
  [3640] = {.lex_state = 117, .external_lex_state = 12},
  [3641] = {.lex_state = 117, .external_lex_state = 2},
  [3642] = {.lex_state = 117, .external_lex_state = 18},
  [3643] = {.lex_state = 117, .external_lex_state = 2},
  [3644] = {.lex_state = 117, .external_lex_state = 2},
  [3645] = {.lex_state = 117, .external_lex_state = 2},
  [3646] = {.lex_state = 117, .external_lex_state = 2},
  [3647] = {.lex_state = 117, .external_lex_state = 2},
  [3648] = {.lex_state = 117, .external_lex_state = 2},
  [3649] = {.lex_state = 9, .external_lex_state = 19},
  [3650] = {.lex_state = 6, .external_lex_state = 18},
  [3651] = {.lex_state = 117, .external_lex_state = 2},
  [3652] = {.lex_state = 117, .external_lex_state = 2},
  [3653] = {.lex_state = 117, .external_lex_state = 2},
  [3654] = {.lex_state = 117, .external_lex_state = 18},
  [3655] = {.lex_state = 117, .external_lex_state = 2},
  [3656] = {.lex_state = 117, .external_lex_state = 12},
  [3657] = {.lex_state = 117, .external_lex_state = 2},
  [3658] = {.lex_state = 117, .external_lex_state = 2},
  [3659] = {.lex_state = 117, .external_lex_state = 12},
  [3660] = {.lex_state = 117, .external_lex_state = 2},
  [3661] = {.lex_state = 117, .external_lex_state = 2},
  [3662] = {.lex_state = 117, .external_lex_state = 18},
  [3663] = {.lex_state = 117, .external_lex_state = 2},
  [3664] = {.lex_state = 117, .external_lex_state = 2},
  [3665] = {.lex_state = 117, .external_lex_state = 2},
  [3666] = {.lex_state = 117, .external_lex_state = 2},
  [3667] = {.lex_state = 117, .external_lex_state = 2},
  [3668] = {.lex_state = 117, .external_lex_state = 2},
  [3669] = {.lex_state = 117, .external_lex_state = 2},
  [3670] = {.lex_state = 117, .external_lex_state = 2},
  [3671] = {.lex_state = 117, .external_lex_state = 2},
  [3672] = {.lex_state = 117, .external_lex_state = 2},
  [3673] = {.lex_state = 117, .external_lex_state = 2},
  [3674] = {.lex_state = 6, .external_lex_state = 18},
  [3675] = {.lex_state = 117, .external_lex_state = 2},
  [3676] = {.lex_state = 4, .external_lex_state = 3},
  [3677] = {.lex_state = 6, .external_lex_state = 18},
  [3678] = {.lex_state = 4, .external_lex_state = 3},
  [3679] = {.lex_state = 4, .external_lex_state = 3},
  [3680] = {.lex_state = 117, .external_lex_state = 2},
  [3681] = {.lex_state = 117, .external_lex_state = 12},
  [3682] = {.lex_state = 117, .external_lex_state = 18},
  [3683] = {.lex_state = 6, .external_lex_state = 18},
  [3684] = {.lex_state = 117, .external_lex_state = 2},
  [3685] = {.lex_state = 117, .external_lex_state = 2},
  [3686] = {.lex_state = 117, .external_lex_state = 18},
  [3687] = {.lex_state = 117, .external_lex_state = 2},
  [3688] = {.lex_state = 117, .external_lex_state = 12},
  [3689] = {.lex_state = 117, .external_lex_state = 2},
  [3690] = {.lex_state = 117, .external_lex_state = 2},
  [3691] = {.lex_state = 117, .external_lex_state = 2},
  [3692] = {.lex_state = 117, .external_lex_state = 2},
  [3693] = {.lex_state = 117, .external_lex_state = 8},
  [3694] = {.lex_state = 117, .external_lex_state = 18},
  [3695] = {.lex_state = 6, .external_lex_state = 18},
  [3696] = {.lex_state = 117, .external_lex_state = 2},
  [3697] = {.lex_state = 4, .external_lex_state = 3},
  [3698] = {.lex_state = 4, .external_lex_state = 3},
  [3699] = {.lex_state = 117, .external_lex_state = 2},
  [3700] = {.lex_state = 117, .external_lex_state = 2},
  [3701] = {.lex_state = 117, .external_lex_state = 2},
  [3702] = {.lex_state = 117, .external_lex_state = 2},
  [3703] = {.lex_state = 6, .external_lex_state = 18},
  [3704] = {.lex_state = 117, .external_lex_state = 2},
  [3705] = {.lex_state = 117, .external_lex_state = 2},
  [3706] = {.lex_state = 117, .external_lex_state = 2},
  [3707] = {.lex_state = 117, .external_lex_state = 2},
  [3708] = {.lex_state = 117, .external_lex_state = 2},
  [3709] = {.lex_state = 117, .external_lex_state = 2},
  [3710] = {.lex_state = 117, .external_lex_state = 2},
  [3711] = {.lex_state = 117, .external_lex_state = 2},
  [3712] = {.lex_state = 117, .external_lex_state = 2},
  [3713] = {.lex_state = 117, .external_lex_state = 2},
  [3714] = {.lex_state = 117, .external_lex_state = 2},
  [3715] = {.lex_state = 117, .external_lex_state = 2},
  [3716] = {.lex_state = 117, .external_lex_state = 2},
  [3717] = {.lex_state = 117, .external_lex_state = 2},
  [3718] = {.lex_state = 117, .external_lex_state = 18},
  [3719] = {.lex_state = 117, .external_lex_state = 2},
  [3720] = {.lex_state = 117, .external_lex_state = 2},
  [3721] = {.lex_state = 117, .external_lex_state = 2},
  [3722] = {.lex_state = 117, .external_lex_state = 2},
  [3723] = {.lex_state = 117, .external_lex_state = 2},
  [3724] = {.lex_state = 117, .external_lex_state = 2},
  [3725] = {.lex_state = 117, .external_lex_state = 2},
  [3726] = {.lex_state = 6, .external_lex_state = 18},
  [3727] = {.lex_state = 117, .external_lex_state = 2},
  [3728] = {.lex_state = 117, .external_lex_state = 18},
  [3729] = {.lex_state = 117, .external_lex_state = 2},
  [3730] = {.lex_state = 117, .external_lex_state = 12},
  [3731] = {.lex_state = 117, .external_lex_state = 2},
  [3732] = {.lex_state = 117, .external_lex_state = 2},
  [3733] = {.lex_state = 117, .external_lex_state = 2},
  [3734] = {.lex_state = 117, .external_lex_state = 8},
  [3735] = {.lex_state = 117, .external_lex_state = 2},
  [3736] = {.lex_state = 117, .external_lex_state = 2},
  [3737] = {.lex_state = 117, .external_lex_state = 18},
  [3738] = {.lex_state = 117, .external_lex_state = 2},
  [3739] = {.lex_state = 117, .external_lex_state = 2},
  [3740] = {.lex_state = 117, .external_lex_state = 2},
  [3741] = {.lex_state = 117, .external_lex_state = 2},
  [3742] = {.lex_state = 117, .external_lex_state = 2},
  [3743] = {.lex_state = 117, .external_lex_state = 12},
  [3744] = {.lex_state = 6, .external_lex_state = 18},
  [3745] = {.lex_state = 117, .external_lex_state = 9},
  [3746] = {.lex_state = 6, .external_lex_state = 18},
  [3747] = {.lex_state = 6, .external_lex_state = 18},
  [3748] = {.lex_state = 6, .external_lex_state = 18},
  [3749] = {.lex_state = 117, .external_lex_state = 17},
  [3750] = {.lex_state = 117, .external_lex_state = 17},
  [3751] = {.lex_state = 117, .external_lex_state = 12},
  [3752] = {.lex_state = 117, .external_lex_state = 12},
  [3753] = {.lex_state = 117, .external_lex_state = 12},
  [3754] = {.lex_state = 117, .external_lex_state = 12},
  [3755] = {.lex_state = 117, .external_lex_state = 12},
  [3756] = {.lex_state = 117, .external_lex_state = 12},
  [3757] = {.lex_state = 117, .external_lex_state = 12},
  [3758] = {.lex_state = 117, .external_lex_state = 12},
  [3759] = {.lex_state = 117, .external_lex_state = 17},
  [3760] = {.lex_state = 117, .external_lex_state = 17},
  [3761] = {.lex_state = 117, .external_lex_state = 17},
  [3762] = {.lex_state = 117, .external_lex_state = 17},
  [3763] = {.lex_state = 117, .external_lex_state = 17},
  [3764] = {.lex_state = 117, .external_lex_state = 17},
  [3765] = {.lex_state = 117, .external_lex_state = 12},
  [3766] = {.lex_state = 117, .external_lex_state = 17},
  [3767] = {.lex_state = 117, .external_lex_state = 17},
  [3768] = {.lex_state = 117, .external_lex_state = 17},
  [3769] = {.lex_state = 117, .external_lex_state = 17},
  [3770] = {.lex_state = 117, .external_lex_state = 17},
  [3771] = {.lex_state = 117, .external_lex_state = 17},
  [3772] = {.lex_state = 117, .external_lex_state = 17},
  [3773] = {.lex_state = 117, .external_lex_state = 17},
  [3774] = {.lex_state = 117, .external_lex_state = 17},
  [3775] = {.lex_state = 117, .external_lex_state = 17},
  [3776] = {.lex_state = 117, .external_lex_state = 17},
  [3777] = {.lex_state = 117, .external_lex_state = 17},
  [3778] = {.lex_state = 117, .external_lex_state = 17},
  [3779] = {.lex_state = 117, .external_lex_state = 17},
  [3780] = {.lex_state = 117, .external_lex_state = 17},
  [3781] = {.lex_state = 117, .external_lex_state = 17},
  [3782] = {.lex_state = 117, .external_lex_state = 17},
  [3783] = {.lex_state = 117, .external_lex_state = 17},
  [3784] = {.lex_state = 117, .external_lex_state = 17},
  [3785] = {.lex_state = 117, .external_lex_state = 17},
  [3786] = {.lex_state = 117, .external_lex_state = 17},
  [3787] = {.lex_state = 117, .external_lex_state = 17},
  [3788] = {.lex_state = 117, .external_lex_state = 17},
  [3789] = {.lex_state = 117, .external_lex_state = 17},
  [3790] = {.lex_state = 117, .external_lex_state = 17},
  [3791] = {.lex_state = 117, .external_lex_state = 17},
  [3792] = {.lex_state = 117, .external_lex_state = 17},
  [3793] = {.lex_state = 117, .external_lex_state = 17},
  [3794] = {.lex_state = 117, .external_lex_state = 17},
  [3795] = {.lex_state = 117, .external_lex_state = 17},
  [3796] = {.lex_state = 117, .external_lex_state = 17},
  [3797] = {.lex_state = 117, .external_lex_state = 17},
  [3798] = {.lex_state = 117, .external_lex_state = 17},
  [3799] = {.lex_state = 117, .external_lex_state = 17},
  [3800] = {.lex_state = 117, .external_lex_state = 17},
  [3801] = {.lex_state = 117, .external_lex_state = 17},
  [3802] = {.lex_state = 117, .external_lex_state = 17},
  [3803] = {.lex_state = 117, .external_lex_state = 17},
  [3804] = {.lex_state = 117, .external_lex_state = 17},
  [3805] = {.lex_state = 117, .external_lex_state = 17},
  [3806] = {.lex_state = 9, .external_lex_state = 19},
  [3807] = {.lex_state = 117, .external_lex_state = 12},
  [3808] = {.lex_state = 117, .external_lex_state = 12},
  [3809] = {.lex_state = 6, .external_lex_state = 18},
  [3810] = {.lex_state = 117, .external_lex_state = 12},
  [3811] = {.lex_state = 117, .external_lex_state = 8},
  [3812] = {.lex_state = 117, .external_lex_state = 8},
  [3813] = {.lex_state = 117, .external_lex_state = 8},
  [3814] = {.lex_state = 9, .external_lex_state = 20},
  [3815] = {.lex_state = 9, .external_lex_state = 19},
  [3816] = {.lex_state = 117, .external_lex_state = 8},
  [3817] = {.lex_state = 117, .external_lex_state = 8},
  [3818] = {.lex_state = 117, .external_lex_state = 8},
  [3819] = {.lex_state = 117, .external_lex_state = 8},
  [3820] = {.lex_state = 117, .external_lex_state = 8},
  [3821] = {.lex_state = 117, .external_lex_state = 8},
  [3822] = {.lex_state = 117, .external_lex_state = 8},
  [3823] = {.lex_state = 117, .external_lex_state = 8},
  [3824] = {.lex_state = 117, .external_lex_state = 14},
  [3825] = {.lex_state = 117, .external_lex_state = 12},
  [3826] = {.lex_state = 117, .external_lex_state = 12},
  [3827] = {.lex_state = 117, .external_lex_state = 14},
  [3828] = {.lex_state = 117, .external_lex_state = 14},
  [3829] = {.lex_state = 117, .external_lex_state = 14},
  [3830] = {.lex_state = 117, .external_lex_state = 14},
  [3831] = {.lex_state = 117, .external_lex_state = 14},
  [3832] = {.lex_state = 117, .external_lex_state = 14},
  [3833] = {.lex_state = 117, .external_lex_state = 14},
  [3834] = {.lex_state = 117, .external_lex_state = 12},
  [3835] = {.lex_state = 117, .external_lex_state = 14},
  [3836] = {.lex_state = 117, .external_lex_state = 14},
  [3837] = {.lex_state = 117, .external_lex_state = 14},
  [3838] = {.lex_state = 117, .external_lex_state = 12},
  [3839] = {.lex_state = 117, .external_lex_state = 14},
  [3840] = {.lex_state = 117, .external_lex_state = 14},
  [3841] = {.lex_state = 117, .external_lex_state = 12},
  [3842] = {.lex_state = 9, .external_lex_state = 20},
  [3843] = {.lex_state = 117, .external_lex_state = 12},
  [3844] = {.lex_state = 117, .external_lex_state = 14},
  [3845] = {.lex_state = 117, .external_lex_state = 14},
  [3846] = {.lex_state = 117, .external_lex_state = 14},
  [3847] = {.lex_state = 117, .external_lex_state = 14},
  [3848] = {.lex_state = 117, .external_lex_state = 14},
  [3849] = {.lex_state = 117, .external_lex_state = 14},
  [3850] = {.lex_state = 117, .external_lex_state = 14},
  [3851] = {.lex_state = 117, .external_lex_state = 14},
  [3852] = {.lex_state = 117, .external_lex_state = 14},
  [3853] = {.lex_state = 117, .external_lex_state = 14},
  [3854] = {.lex_state = 117, .external_lex_state = 14},
  [3855] = {.lex_state = 117, .external_lex_state = 14},
  [3856] = {.lex_state = 117, .external_lex_state = 14},
  [3857] = {.lex_state = 117, .external_lex_state = 14},
  [3858] = {.lex_state = 117, .external_lex_state = 14},
  [3859] = {.lex_state = 117, .external_lex_state = 14},
  [3860] = {.lex_state = 117, .external_lex_state = 14},
  [3861] = {.lex_state = 117, .external_lex_state = 14},
  [3862] = {.lex_state = 117, .external_lex_state = 12},
  [3863] = {.lex_state = 117, .external_lex_state = 8},
  [3864] = {.lex_state = 117, .external_lex_state = 8},
  [3865] = {.lex_state = 117, .external_lex_state = 8},
  [3866] = {.lex_state = 117, .external_lex_state = 8},
  [3867] = {.lex_state = 117, .external_lex_state = 8},
  [3868] = {.lex_state = 117, .external_lex_state = 8},
  [3869] = {.lex_state = 117, .external_lex_state = 8},
  [3870] = {.lex_state = 117, .external_lex_state = 8},
  [3871] = {.lex_state = 117, .external_lex_state = 8},
  [3872] = {.lex_state = 117, .external_lex_state = 8},
  [3873] = {.lex_state = 117, .external_lex_state = 8},
  [3874] = {.lex_state = 117, .external_lex_state = 8},
  [3875] = {.lex_state = 117, .external_lex_state = 8},
  [3876] = {.lex_state = 117, .external_lex_state = 8},
  [3877] = {.lex_state = 117, .external_lex_state = 8},
  [3878] = {.lex_state = 117, .external_lex_state = 8},
  [3879] = {.lex_state = 117, .external_lex_state = 8},
  [3880] = {.lex_state = 117, .external_lex_state = 8},
  [3881] = {.lex_state = 117, .external_lex_state = 8},
  [3882] = {.lex_state = 117, .external_lex_state = 8},
  [3883] = {.lex_state = 117, .external_lex_state = 8},
  [3884] = {.lex_state = 117, .external_lex_state = 8},
  [3885] = {.lex_state = 117, .external_lex_state = 8},
  [3886] = {.lex_state = 117, .external_lex_state = 8},
  [3887] = {.lex_state = 117, .external_lex_state = 8},
  [3888] = {.lex_state = 117, .external_lex_state = 8},
  [3889] = {.lex_state = 117, .external_lex_state = 8},
  [3890] = {.lex_state = 117, .external_lex_state = 8},
  [3891] = {.lex_state = 117, .external_lex_state = 8},
  [3892] = {.lex_state = 117, .external_lex_state = 8},
  [3893] = {.lex_state = 117, .external_lex_state = 8},
  [3894] = {.lex_state = 117, .external_lex_state = 12},
  [3895] = {.lex_state = 117, .external_lex_state = 8},
  [3896] = {.lex_state = 117, .external_lex_state = 8},
  [3897] = {.lex_state = 117, .external_lex_state = 8},
  [3898] = {.lex_state = 117, .external_lex_state = 8},
  [3899] = {.lex_state = 117, .external_lex_state = 8},
  [3900] = {.lex_state = 117, .external_lex_state = 8},
  [3901] = {.lex_state = 117, .external_lex_state = 8},
  [3902] = {.lex_state = 117, .external_lex_state = 8},
  [3903] = {.lex_state = 117, .external_lex_state = 8},
  [3904] = {.lex_state = 117, .external_lex_state = 8},
  [3905] = {.lex_state = 117, .external_lex_state = 8},
  [3906] = {.lex_state = 117, .external_lex_state = 8},
  [3907] = {.lex_state = 117, .external_lex_state = 8},
  [3908] = {.lex_state = 117, .external_lex_state = 8},
  [3909] = {.lex_state = 117, .external_lex_state = 8},
  [3910] = {.lex_state = 117, .external_lex_state = 8},
  [3911] = {.lex_state = 117, .external_lex_state = 8},
  [3912] = {.lex_state = 117, .external_lex_state = 8},
  [3913] = {.lex_state = 117, .external_lex_state = 8},
  [3914] = {.lex_state = 117, .external_lex_state = 8},
  [3915] = {.lex_state = 117, .external_lex_state = 8},
  [3916] = {.lex_state = 117, .external_lex_state = 8},
  [3917] = {.lex_state = 117, .external_lex_state = 8},
  [3918] = {.lex_state = 117, .external_lex_state = 8},
  [3919] = {.lex_state = 117, .external_lex_state = 8},
  [3920] = {.lex_state = 117, .external_lex_state = 8},
  [3921] = {.lex_state = 117, .external_lex_state = 8},
  [3922] = {.lex_state = 117, .external_lex_state = 8},
  [3923] = {.lex_state = 117, .external_lex_state = 8},
  [3924] = {.lex_state = 117, .external_lex_state = 8},
  [3925] = {.lex_state = 117, .external_lex_state = 8},
  [3926] = {.lex_state = 117, .external_lex_state = 8},
  [3927] = {.lex_state = 117, .external_lex_state = 8},
  [3928] = {.lex_state = 117, .external_lex_state = 8},
  [3929] = {.lex_state = 117, .external_lex_state = 8},
  [3930] = {.lex_state = 117, .external_lex_state = 8},
  [3931] = {.lex_state = 117, .external_lex_state = 8},
  [3932] = {.lex_state = 117, .external_lex_state = 8},
  [3933] = {.lex_state = 117, .external_lex_state = 8},
  [3934] = {.lex_state = 117, .external_lex_state = 8},
  [3935] = {.lex_state = 117, .external_lex_state = 8},
  [3936] = {.lex_state = 117, .external_lex_state = 8},
  [3937] = {.lex_state = 117, .external_lex_state = 8},
  [3938] = {.lex_state = 117, .external_lex_state = 8},
  [3939] = {.lex_state = 117, .external_lex_state = 8},
  [3940] = {.lex_state = 117, .external_lex_state = 8},
  [3941] = {.lex_state = 117, .external_lex_state = 8},
  [3942] = {.lex_state = 117, .external_lex_state = 8},
  [3943] = {.lex_state = 117, .external_lex_state = 8},
  [3944] = {.lex_state = 117, .external_lex_state = 8},
  [3945] = {.lex_state = 117, .external_lex_state = 8},
  [3946] = {.lex_state = 117, .external_lex_state = 8},
  [3947] = {.lex_state = 117, .external_lex_state = 8},
  [3948] = {.lex_state = 117, .external_lex_state = 8},
  [3949] = {.lex_state = 9, .external_lex_state = 20},
  [3950] = {.lex_state = 9, .external_lex_state = 10},
  [3951] = {.lex_state = 117, .external_lex_state = 8},
  [3952] = {.lex_state = 117, .external_lex_state = 17},
  [3953] = {.lex_state = 117, .external_lex_state = 17},
  [3954] = {.lex_state = 117, .external_lex_state = 12},
  [3955] = {.lex_state = 117, .external_lex_state = 2},
  [3956] = {.lex_state = 117, .external_lex_state = 12},
  [3957] = {.lex_state = 117, .external_lex_state = 12},
  [3958] = {.lex_state = 117, .external_lex_state = 12},
  [3959] = {.lex_state = 117, .external_lex_state = 12},
  [3960] = {.lex_state = 9, .external_lex_state = 10},
  [3961] = {.lex_state = 117, .external_lex_state = 12},
  [3962] = {.lex_state = 117, .external_lex_state = 18},
  [3963] = {.lex_state = 3, .external_lex_state = 12},
  [3964] = {.lex_state = 117, .external_lex_state = 12},
  [3965] = {.lex_state = 117, .external_lex_state = 12},
  [3966] = {.lex_state = 117, .external_lex_state = 12},
  [3967] = {.lex_state = 117, .external_lex_state = 12},
  [3968] = {.lex_state = 117, .external_lex_state = 21},
  [3969] = {.lex_state = 117, .external_lex_state = 12},
  [3970] = {.lex_state = 117, .external_lex_state = 12},
  [3971] = {.lex_state = 117, .external_lex_state = 12},
  [3972] = {.lex_state = 3, .external_lex_state = 12},
  [3973] = {.lex_state = 117, .external_lex_state = 12},
  [3974] = {.lex_state = 117, .external_lex_state = 12},
  [3975] = {.lex_state = 3, .external_lex_state = 12},
  [3976] = {.lex_state = 117, .external_lex_state = 12},
  [3977] = {.lex_state = 3, .external_lex_state = 12},
  [3978] = {.lex_state = 3, .external_lex_state = 12},
  [3979] = {.lex_state = 9, .external_lex_state = 10},
  [3980] = {.lex_state = 117, .external_lex_state = 12},
  [3981] = {.lex_state = 117, .external_lex_state = 17},
  [3982] = {.lex_state = 117, .external_lex_state = 17},
  [3983] = {.lex_state = 117, .external_lex_state = 17},
  [3984] = {.lex_state = 117, .external_lex_state = 17},
  [3985] = {.lex_state = 117, .external_lex_state = 17},
  [3986] = {.lex_state = 117, .external_lex_state = 17},
  [3987] = {.lex_state = 117, .external_lex_state = 17},
  [3988] = {.lex_state = 117, .external_lex_state = 17},
  [3989] = {.lex_state = 117, .external_lex_state = 17},
  [3990] = {.lex_state = 117, .external_lex_state = 17},
  [3991] = {.lex_state = 117, .external_lex_state = 17},
  [3992] = {.lex_state = 117, .external_lex_state = 17},
  [3993] = {.lex_state = 117, .external_lex_state = 17},
  [3994] = {.lex_state = 117, .external_lex_state = 17},
  [3995] = {.lex_state = 117, .external_lex_state = 17},
  [3996] = {.lex_state = 117, .external_lex_state = 17},
  [3997] = {.lex_state = 117, .external_lex_state = 17},
  [3998] = {.lex_state = 117, .external_lex_state = 17},
  [3999] = {.lex_state = 117, .external_lex_state = 17},
  [4000] = {.lex_state = 117, .external_lex_state = 12},
  [4001] = {.lex_state = 117, .external_lex_state = 17},
  [4002] = {.lex_state = 117, .external_lex_state = 12},
  [4003] = {.lex_state = 117, .external_lex_state = 17},
  [4004] = {.lex_state = 117, .external_lex_state = 17},
  [4005] = {.lex_state = 117, .external_lex_state = 17},
  [4006] = {.lex_state = 117, .external_lex_state = 17},
  [4007] = {.lex_state = 117, .external_lex_state = 17},
  [4008] = {.lex_state = 117, .external_lex_state = 17},
  [4009] = {.lex_state = 117, .external_lex_state = 12},
  [4010] = {.lex_state = 117, .external_lex_state = 17},
  [4011] = {.lex_state = 117, .external_lex_state = 17},
  [4012] = {.lex_state = 117, .external_lex_state = 12},
  [4013] = {.lex_state = 117, .external_lex_state = 17},
  [4014] = {.lex_state = 117, .external_lex_state = 12},
  [4015] = {.lex_state = 117, .external_lex_state = 17},
  [4016] = {.lex_state = 117, .external_lex_state = 17},
  [4017] = {.lex_state = 117, .external_lex_state = 17},
  [4018] = {.lex_state = 117, .external_lex_state = 17},
  [4019] = {.lex_state = 117, .external_lex_state = 17},
  [4020] = {.lex_state = 117, .external_lex_state = 17},
  [4021] = {.lex_state = 117, .external_lex_state = 12},
  [4022] = {.lex_state = 117, .external_lex_state = 17},
  [4023] = {.lex_state = 117, .external_lex_state = 17},
  [4024] = {.lex_state = 117, .external_lex_state = 17},
  [4025] = {.lex_state = 117, .external_lex_state = 17},
  [4026] = {.lex_state = 117, .external_lex_state = 17},
  [4027] = {.lex_state = 117, .external_lex_state = 17},
  [4028] = {.lex_state = 117, .external_lex_state = 17},
  [4029] = {.lex_state = 117, .external_lex_state = 17},
  [4030] = {.lex_state = 117, .external_lex_state = 12},
  [4031] = {.lex_state = 117, .external_lex_state = 12},
  [4032] = {.lex_state = 117, .external_lex_state = 17},
  [4033] = {.lex_state = 117, .external_lex_state = 12},
  [4034] = {.lex_state = 117, .external_lex_state = 17},
  [4035] = {.lex_state = 117, .external_lex_state = 12},
  [4036] = {.lex_state = 117, .external_lex_state = 17},
  [4037] = {.lex_state = 117, .external_lex_state = 17},
  [4038] = {.lex_state = 117, .external_lex_state = 17},
  [4039] = {.lex_state = 117, .external_lex_state = 17},
  [4040] = {.lex_state = 117, .external_lex_state = 17},
  [4041] = {.lex_state = 117, .external_lex_state = 17},
  [4042] = {.lex_state = 117, .external_lex_state = 17},
  [4043] = {.lex_state = 117, .external_lex_state = 17},
  [4044] = {.lex_state = 117, .external_lex_state = 12},
  [4045] = {.lex_state = 117, .external_lex_state = 12},
  [4046] = {.lex_state = 117, .external_lex_state = 17},
  [4047] = {.lex_state = 117, .external_lex_state = 17},
  [4048] = {.lex_state = 117, .external_lex_state = 17},
  [4049] = {.lex_state = 117, .external_lex_state = 17},
  [4050] = {.lex_state = 117, .external_lex_state = 17},
  [4051] = {.lex_state = 117, .external_lex_state = 17},
  [4052] = {.lex_state = 117, .external_lex_state = 17},
  [4053] = {.lex_state = 117, .external_lex_state = 12},
  [4054] = {.lex_state = 117, .external_lex_state = 12},
  [4055] = {.lex_state = 117, .external_lex_state = 12},
  [4056] = {.lex_state = 117, .external_lex_state = 12},
  [4057] = {.lex_state = 117, .external_lex_state = 17},
  [4058] = {.lex_state = 117, .external_lex_state = 18},
  [4059] = {.lex_state = 117, .external_lex_state = 12},
  [4060] = {.lex_state = 10, .external_lex_state = 15},
  [4061] = {.lex_state = 9, .external_lex_state = 19},
  [4062] = {.lex_state = 117, .external_lex_state = 12},
  [4063] = {.lex_state = 117, .external_lex_state = 15},
  [4064] = {.lex_state = 117, .external_lex_state = 18},
  [4065] = {.lex_state = 117, .external_lex_state = 15},
  [4066] = {.lex_state = 117, .external_lex_state = 18},
  [4067] = {.lex_state = 117, .external_lex_state = 12},
  [4068] = {.lex_state = 117, .external_lex_state = 12},
  [4069] = {.lex_state = 9, .external_lex_state = 22},
  [4070] = {.lex_state = 117, .external_lex_state = 12},
  [4071] = {.lex_state = 117, .external_lex_state = 12},
  [4072] = {.lex_state = 117, .external_lex_state = 12},
  [4073] = {.lex_state = 117, .external_lex_state = 15},
  [4074] = {.lex_state = 117, .external_lex_state = 12},
  [4075] = {.lex_state = 117, .external_lex_state = 12},
  [4076] = {.lex_state = 117, .external_lex_state = 18},
  [4077] = {.lex_state = 117, .external_lex_state = 12},
  [4078] = {.lex_state = 117, .external_lex_state = 12},
  [4079] = {.lex_state = 117, .external_lex_state = 12},
  [4080] = {.lex_state = 117, .external_lex_state = 12},
  [4081] = {.lex_state = 117, .external_lex_state = 12},
  [4082] = {.lex_state = 10, .external_lex_state = 15},
  [4083] = {.lex_state = 117, .external_lex_state = 18},
  [4084] = {.lex_state = 117, .external_lex_state = 12},
  [4085] = {.lex_state = 117, .external_lex_state = 12},
  [4086] = {.lex_state = 117, .external_lex_state = 18},
  [4087] = {.lex_state = 117, .external_lex_state = 18},
  [4088] = {.lex_state = 117, .external_lex_state = 12},
  [4089] = {.lex_state = 117, .external_lex_state = 12},
  [4090] = {.lex_state = 117, .external_lex_state = 12},
  [4091] = {.lex_state = 117, .external_lex_state = 12},
  [4092] = {.lex_state = 117, .external_lex_state = 12},
  [4093] = {.lex_state = 117, .external_lex_state = 12},
  [4094] = {.lex_state = 117, .external_lex_state = 12},
  [4095] = {.lex_state = 117, .external_lex_state = 12},
  [4096] = {.lex_state = 117, .external_lex_state = 12},
  [4097] = {.lex_state = 117, .external_lex_state = 12},
  [4098] = {.lex_state = 117, .external_lex_state = 12},
  [4099] = {.lex_state = 117, .external_lex_state = 12},
  [4100] = {.lex_state = 117, .external_lex_state = 12},
  [4101] = {.lex_state = 117, .external_lex_state = 12},
  [4102] = {.lex_state = 117, .external_lex_state = 12},
  [4103] = {.lex_state = 117, .external_lex_state = 12},
  [4104] = {.lex_state = 117, .external_lex_state = 12},
  [4105] = {.lex_state = 117, .external_lex_state = 12},
  [4106] = {.lex_state = 117, .external_lex_state = 12},
  [4107] = {.lex_state = 117, .external_lex_state = 12},
  [4108] = {.lex_state = 117, .external_lex_state = 12},
  [4109] = {.lex_state = 117, .external_lex_state = 12},
  [4110] = {.lex_state = 117, .external_lex_state = 12},
  [4111] = {.lex_state = 117, .external_lex_state = 3},
  [4112] = {.lex_state = 117, .external_lex_state = 3},
  [4113] = {.lex_state = 117, .external_lex_state = 12},
  [4114] = {.lex_state = 117, .external_lex_state = 12},
  [4115] = {.lex_state = 117, .external_lex_state = 12},
  [4116] = {.lex_state = 117, .external_lex_state = 12},
  [4117] = {.lex_state = 117, .external_lex_state = 12},
  [4118] = {.lex_state = 117, .external_lex_state = 12},
  [4119] = {.lex_state = 117, .external_lex_state = 12},
  [4120] = {.lex_state = 117, .external_lex_state = 12},
  [4121] = {.lex_state = 117, .external_lex_state = 12},
  [4122] = {.lex_state = 117, .external_lex_state = 12},
  [4123] = {.lex_state = 117, .external_lex_state = 12},
  [4124] = {.lex_state = 117, .external_lex_state = 12},
  [4125] = {.lex_state = 117, .external_lex_state = 12},
  [4126] = {.lex_state = 117, .external_lex_state = 12},
  [4127] = {.lex_state = 117, .external_lex_state = 12},
  [4128] = {.lex_state = 117, .external_lex_state = 12},
  [4129] = {.lex_state = 117, .external_lex_state = 12},
  [4130] = {.lex_state = 117, .external_lex_state = 12},
  [4131] = {.lex_state = 117, .external_lex_state = 12},
  [4132] = {.lex_state = 117, .external_lex_state = 12},
  [4133] = {.lex_state = 117, .external_lex_state = 12},
  [4134] = {.lex_state = 117, .external_lex_state = 12},
  [4135] = {.lex_state = 117, .external_lex_state = 12},
  [4136] = {.lex_state = 117, .external_lex_state = 12},
  [4137] = {.lex_state = 117, .external_lex_state = 12},
  [4138] = {.lex_state = 117, .external_lex_state = 12},
  [4139] = {.lex_state = 117, .external_lex_state = 12},
  [4140] = {.lex_state = 117, .external_lex_state = 12},
  [4141] = {.lex_state = 117, .external_lex_state = 12},
  [4142] = {.lex_state = 117, .external_lex_state = 12},
  [4143] = {.lex_state = 117, .external_lex_state = 12},
  [4144] = {.lex_state = 117, .external_lex_state = 12},
  [4145] = {.lex_state = 117, .external_lex_state = 12},
  [4146] = {.lex_state = 117, .external_lex_state = 3},
  [4147] = {.lex_state = 117, .external_lex_state = 3},
  [4148] = {.lex_state = 117, .external_lex_state = 3},
  [4149] = {.lex_state = 117, .external_lex_state = 3},
  [4150] = {.lex_state = 117, .external_lex_state = 3},
  [4151] = {.lex_state = 117, .external_lex_state = 3},
  [4152] = {.lex_state = 117, .external_lex_state = 3},
  [4153] = {.lex_state = 117, .external_lex_state = 3},
  [4154] = {.lex_state = 117, .external_lex_state = 12},
  [4155] = {.lex_state = 9, .external_lex_state = 20},
  [4156] = {.lex_state = 117, .external_lex_state = 12},
  [4157] = {.lex_state = 117, .external_lex_state = 12},
  [4158] = {.lex_state = 117, .external_lex_state = 12},
  [4159] = {.lex_state = 117, .external_lex_state = 12},
  [4160] = {.lex_state = 117, .external_lex_state = 12},
  [4161] = {.lex_state = 117, .external_lex_state = 12},
  [4162] = {.lex_state = 117, .external_lex_state = 12},
  [4163] = {.lex_state = 117, .external_lex_state = 12},
  [4164] = {.lex_state = 117, .external_lex_state = 12},
  [4165] = {.lex_state = 117, .external_lex_state = 12},
  [4166] = {.lex_state = 117, .external_lex_state = 12},
  [4167] = {.lex_state = 117, .external_lex_state = 12},
  [4168] = {.lex_state = 117, .external_lex_state = 12},
  [4169] = {.lex_state = 117, .external_lex_state = 12},
  [4170] = {.lex_state = 117, .external_lex_state = 12},
  [4171] = {.lex_state = 117, .external_lex_state = 12},
  [4172] = {.lex_state = 117, .external_lex_state = 12},
  [4173] = {.lex_state = 117, .external_lex_state = 12},
  [4174] = {.lex_state = 117, .external_lex_state = 12},
  [4175] = {.lex_state = 117, .external_lex_state = 12},
  [4176] = {.lex_state = 117, .external_lex_state = 12},
  [4177] = {.lex_state = 117, .external_lex_state = 12},
  [4178] = {.lex_state = 117, .external_lex_state = 12},
  [4179] = {.lex_state = 117, .external_lex_state = 12},
  [4180] = {.lex_state = 117, .external_lex_state = 12},
  [4181] = {.lex_state = 117, .external_lex_state = 12},
  [4182] = {.lex_state = 117, .external_lex_state = 12},
  [4183] = {.lex_state = 117, .external_lex_state = 12},
  [4184] = {.lex_state = 117, .external_lex_state = 12},
  [4185] = {.lex_state = 117, .external_lex_state = 12},
  [4186] = {.lex_state = 117, .external_lex_state = 12},
  [4187] = {.lex_state = 117, .external_lex_state = 12},
  [4188] = {.lex_state = 117, .external_lex_state = 12},
  [4189] = {.lex_state = 117, .external_lex_state = 18},
  [4190] = {.lex_state = 117, .external_lex_state = 12},
  [4191] = {.lex_state = 117, .external_lex_state = 12},
  [4192] = {.lex_state = 117, .external_lex_state = 12},
  [4193] = {.lex_state = 117, .external_lex_state = 12},
  [4194] = {.lex_state = 117, .external_lex_state = 12},
  [4195] = {.lex_state = 117, .external_lex_state = 12},
  [4196] = {.lex_state = 117, .external_lex_state = 12},
  [4197] = {.lex_state = 117, .external_lex_state = 12},
  [4198] = {.lex_state = 117, .external_lex_state = 12},
  [4199] = {.lex_state = 117, .external_lex_state = 12},
  [4200] = {.lex_state = 117, .external_lex_state = 12},
  [4201] = {.lex_state = 117, .external_lex_state = 12},
  [4202] = {.lex_state = 117, .external_lex_state = 12},
  [4203] = {.lex_state = 117, .external_lex_state = 12},
  [4204] = {.lex_state = 117, .external_lex_state = 12},
  [4205] = {.lex_state = 117, .external_lex_state = 12},
  [4206] = {.lex_state = 117, .external_lex_state = 12},
  [4207] = {.lex_state = 117, .external_lex_state = 12},
  [4208] = {.lex_state = 117, .external_lex_state = 12},
  [4209] = {.lex_state = 117, .external_lex_state = 12},
  [4210] = {.lex_state = 117, .external_lex_state = 12},
  [4211] = {.lex_state = 117, .external_lex_state = 12},
  [4212] = {.lex_state = 117, .external_lex_state = 12},
  [4213] = {.lex_state = 117, .external_lex_state = 12},
  [4214] = {.lex_state = 117, .external_lex_state = 12},
  [4215] = {.lex_state = 117, .external_lex_state = 12},
  [4216] = {.lex_state = 117, .external_lex_state = 12},
  [4217] = {.lex_state = 117, .external_lex_state = 12},
  [4218] = {.lex_state = 117, .external_lex_state = 12},
  [4219] = {.lex_state = 117, .external_lex_state = 12},
  [4220] = {.lex_state = 117, .external_lex_state = 12},
  [4221] = {.lex_state = 117, .external_lex_state = 12},
  [4222] = {.lex_state = 9, .external_lex_state = 22},
  [4223] = {.lex_state = 117, .external_lex_state = 12},
  [4224] = {.lex_state = 117, .external_lex_state = 12},
  [4225] = {.lex_state = 117, .external_lex_state = 12},
  [4226] = {.lex_state = 117, .external_lex_state = 12},
  [4227] = {.lex_state = 117, .external_lex_state = 12},
  [4228] = {.lex_state = 117, .external_lex_state = 17},
  [4229] = {.lex_state = 117, .external_lex_state = 12},
  [4230] = {.lex_state = 117, .external_lex_state = 12},
  [4231] = {.lex_state = 117, .external_lex_state = 12},
  [4232] = {.lex_state = 117, .external_lex_state = 12},
  [4233] = {.lex_state = 117, .external_lex_state = 12},
  [4234] = {.lex_state = 117, .external_lex_state = 12},
  [4235] = {.lex_state = 117, .external_lex_state = 12},
  [4236] = {.lex_state = 117, .external_lex_state = 3},
  [4237] = {.lex_state = 117, .external_lex_state = 3},
  [4238] = {.lex_state = 117, .external_lex_state = 15},
  [4239] = {.lex_state = 117, .external_lex_state = 12},
  [4240] = {.lex_state = 117, .external_lex_state = 12},
  [4241] = {.lex_state = 117, .external_lex_state = 18},
  [4242] = {.lex_state = 117, .external_lex_state = 12},
  [4243] = {.lex_state = 117, .external_lex_state = 12},
  [4244] = {.lex_state = 117, .external_lex_state = 12},
  [4245] = {.lex_state = 117, .external_lex_state = 12},
  [4246] = {.lex_state = 10, .external_lex_state = 15},
  [4247] = {.lex_state = 10, .external_lex_state = 15},
  [4248] = {.lex_state = 117, .external_lex_state = 12},
  [4249] = {.lex_state = 117, .external_lex_state = 12},
  [4250] = {.lex_state = 10, .external_lex_state = 15},
  [4251] = {.lex_state = 117, .external_lex_state = 15},
  [4252] = {.lex_state = 117, .external_lex_state = 12},
  [4253] = {.lex_state = 117, .external_lex_state = 12},
  [4254] = {.lex_state = 117, .external_lex_state = 12},
  [4255] = {.lex_state = 117, .external_lex_state = 12},
  [4256] = {.lex_state = 117, .external_lex_state = 12},
  [4257] = {.lex_state = 117, .external_lex_state = 12},
  [4258] = {.lex_state = 117, .external_lex_state = 12},
  [4259] = {.lex_state = 117, .external_lex_state = 12},
  [4260] = {.lex_state = 117, .external_lex_state = 12},
  [4261] = {.lex_state = 117, .external_lex_state = 12},
  [4262] = {.lex_state = 117, .external_lex_state = 12},
  [4263] = {.lex_state = 117, .external_lex_state = 12},
  [4264] = {.lex_state = 117, .external_lex_state = 12},
  [4265] = {.lex_state = 117, .external_lex_state = 12},
  [4266] = {.lex_state = 117, .external_lex_state = 12},
  [4267] = {.lex_state = 117, .external_lex_state = 12},
  [4268] = {.lex_state = 117, .external_lex_state = 12},
  [4269] = {.lex_state = 117, .external_lex_state = 12},
  [4270] = {.lex_state = 117, .external_lex_state = 12},
  [4271] = {.lex_state = 117, .external_lex_state = 12},
  [4272] = {.lex_state = 117, .external_lex_state = 12},
  [4273] = {.lex_state = 117, .external_lex_state = 12},
  [4274] = {.lex_state = 117, .external_lex_state = 12},
  [4275] = {.lex_state = 117, .external_lex_state = 12},
  [4276] = {.lex_state = 6, .external_lex_state = 22},
  [4277] = {.lex_state = 117, .external_lex_state = 12},
  [4278] = {.lex_state = 117, .external_lex_state = 17},
  [4279] = {.lex_state = 117, .external_lex_state = 12},
  [4280] = {.lex_state = 117, .external_lex_state = 12},
  [4281] = {.lex_state = 117, .external_lex_state = 12},
  [4282] = {.lex_state = 117, .external_lex_state = 12},
  [4283] = {.lex_state = 117, .external_lex_state = 12},
  [4284] = {.lex_state = 117, .external_lex_state = 12},
  [4285] = {.lex_state = 117, .external_lex_state = 12},
  [4286] = {.lex_state = 117, .external_lex_state = 12},
  [4287] = {.lex_state = 117, .external_lex_state = 12},
  [4288] = {.lex_state = 117, .external_lex_state = 12},
  [4289] = {.lex_state = 117, .external_lex_state = 12},
  [4290] = {.lex_state = 117, .external_lex_state = 12},
  [4291] = {.lex_state = 117, .external_lex_state = 12},
  [4292] = {.lex_state = 117, .external_lex_state = 12},
  [4293] = {.lex_state = 117, .external_lex_state = 12},
  [4294] = {.lex_state = 117, .external_lex_state = 12},
  [4295] = {.lex_state = 117, .external_lex_state = 12},
  [4296] = {.lex_state = 117, .external_lex_state = 12},
  [4297] = {.lex_state = 117, .external_lex_state = 12},
  [4298] = {.lex_state = 117, .external_lex_state = 12},
  [4299] = {.lex_state = 117, .external_lex_state = 17},
  [4300] = {.lex_state = 117, .external_lex_state = 17},
  [4301] = {.lex_state = 117, .external_lex_state = 17},
  [4302] = {.lex_state = 117, .external_lex_state = 17},
  [4303] = {.lex_state = 117, .external_lex_state = 17},
  [4304] = {.lex_state = 7, .external_lex_state = 3},
  [4305] = {.lex_state = 117, .external_lex_state = 17},
  [4306] = {.lex_state = 117, .external_lex_state = 17},
  [4307] = {.lex_state = 10, .external_lex_state = 15},
  [4308] = {.lex_state = 117, .external_lex_state = 12},
  [4309] = {.lex_state = 117, .external_lex_state = 17},
  [4310] = {.lex_state = 117, .external_lex_state = 17},
  [4311] = {.lex_state = 117, .external_lex_state = 17},
  [4312] = {.lex_state = 117, .external_lex_state = 17},
  [4313] = {.lex_state = 117, .external_lex_state = 12},
  [4314] = {.lex_state = 9, .external_lex_state = 22},
  [4315] = {.lex_state = 117, .external_lex_state = 18},
  [4316] = {.lex_state = 117, .external_lex_state = 18},
  [4317] = {.lex_state = 117, .external_lex_state = 18},
  [4318] = {.lex_state = 117, .external_lex_state = 3},
  [4319] = {.lex_state = 117, .external_lex_state = 18},
  [4320] = {.lex_state = 117, .external_lex_state = 3},
  [4321] = {.lex_state = 117, .external_lex_state = 3},
  [4322] = {.lex_state = 117, .external_lex_state = 3},
  [4323] = {.lex_state = 117, .external_lex_state = 3},
  [4324] = {.lex_state = 117, .external_lex_state = 3},
  [4325] = {.lex_state = 117, .external_lex_state = 3},
  [4326] = {.lex_state = 117, .external_lex_state = 10},
  [4327] = {.lex_state = 117, .external_lex_state = 3},
  [4328] = {.lex_state = 117, .external_lex_state = 3},
  [4329] = {.lex_state = 117, .external_lex_state = 3},
  [4330] = {.lex_state = 10, .external_lex_state = 12},
  [4331] = {.lex_state = 117, .external_lex_state = 3},
  [4332] = {.lex_state = 117, .external_lex_state = 3},
  [4333] = {.lex_state = 117, .external_lex_state = 3},
  [4334] = {.lex_state = 117, .external_lex_state = 3},
  [4335] = {.lex_state = 117, .external_lex_state = 18},
  [4336] = {.lex_state = 117, .external_lex_state = 3},
  [4337] = {.lex_state = 117, .external_lex_state = 3},
  [4338] = {.lex_state = 117, .external_lex_state = 18},
  [4339] = {.lex_state = 117, .external_lex_state = 3},
  [4340] = {.lex_state = 117, .external_lex_state = 3},
  [4341] = {.lex_state = 117, .external_lex_state = 12},
  [4342] = {.lex_state = 117, .external_lex_state = 18},
  [4343] = {.lex_state = 117, .external_lex_state = 18},
  [4344] = {.lex_state = 117, .external_lex_state = 12},
  [4345] = {.lex_state = 117, .external_lex_state = 18},
  [4346] = {.lex_state = 117, .external_lex_state = 18},
  [4347] = {.lex_state = 117, .external_lex_state = 18},
  [4348] = {.lex_state = 117, .external_lex_state = 18},
  [4349] = {.lex_state = 117, .external_lex_state = 3},
  [4350] = {.lex_state = 117, .external_lex_state = 18},
  [4351] = {.lex_state = 117, .external_lex_state = 3},
  [4352] = {.lex_state = 117, .external_lex_state = 18},
  [4353] = {.lex_state = 117, .external_lex_state = 18},
  [4354] = {.lex_state = 117, .external_lex_state = 10},
  [4355] = {.lex_state = 117, .external_lex_state = 18},
  [4356] = {.lex_state = 117, .external_lex_state = 18},
  [4357] = {.lex_state = 117, .external_lex_state = 18},
  [4358] = {.lex_state = 117, .external_lex_state = 10},
  [4359] = {.lex_state = 117, .external_lex_state = 18},
  [4360] = {.lex_state = 117, .external_lex_state = 18},
  [4361] = {.lex_state = 117, .external_lex_state = 18},
  [4362] = {.lex_state = 117, .external_lex_state = 3},
  [4363] = {.lex_state = 117, .external_lex_state = 18},
  [4364] = {.lex_state = 117, .external_lex_state = 18},
  [4365] = {.lex_state = 117, .external_lex_state = 3},
  [4366] = {.lex_state = 117, .external_lex_state = 3},
  [4367] = {.lex_state = 117, .external_lex_state = 3},
  [4368] = {.lex_state = 117, .external_lex_state = 18},
  [4369] = {.lex_state = 10, .external_lex_state = 15},
  [4370] = {.lex_state = 117, .external_lex_state = 3},
  [4371] = {.lex_state = 117, .external_lex_state = 18},
  [4372] = {.lex_state = 117, .external_lex_state = 3},
  [4373] = {.lex_state = 117, .external_lex_state = 18},
  [4374] = {.lex_state = 117, .external_lex_state = 3},
  [4375] = {.lex_state = 117, .external_lex_state = 3},
  [4376] = {.lex_state = 117, .external_lex_state = 18},
  [4377] = {.lex_state = 117, .external_lex_state = 18},
  [4378] = {.lex_state = 117, .external_lex_state = 18},
  [4379] = {.lex_state = 117, .external_lex_state = 18},
  [4380] = {.lex_state = 117, .external_lex_state = 18},
  [4381] = {.lex_state = 117, .external_lex_state = 3},
  [4382] = {.lex_state = 10, .external_lex_state = 12},
  [4383] = {.lex_state = 117, .external_lex_state = 18},
  [4384] = {.lex_state = 117, .external_lex_state = 18},
  [4385] = {.lex_state = 117, .external_lex_state = 10},
  [4386] = {.lex_state = 117, .external_lex_state = 18},
  [4387] = {.lex_state = 117, .external_lex_state = 3},
  [4388] = {.lex_state = 117, .external_lex_state = 18},
  [4389] = {.lex_state = 10, .external_lex_state = 12},
  [4390] = {.lex_state = 117, .external_lex_state = 3},
  [4391] = {.lex_state = 117, .external_lex_state = 18},
  [4392] = {.lex_state = 117, .external_lex_state = 12},
  [4393] = {.lex_state = 117, .external_lex_state = 18},
  [4394] = {.lex_state = 117, .external_lex_state = 18},
  [4395] = {.lex_state = 117, .external_lex_state = 18},
  [4396] = {.lex_state = 117, .external_lex_state = 3},
  [4397] = {.lex_state = 117, .external_lex_state = 18},
  [4398] = {.lex_state = 117, .external_lex_state = 18},
  [4399] = {.lex_state = 117, .external_lex_state = 18},
  [4400] = {.lex_state = 117, .external_lex_state = 18},
  [4401] = {.lex_state = 117, .external_lex_state = 18},
  [4402] = {.lex_state = 117, .external_lex_state = 18},
  [4403] = {.lex_state = 117, .external_lex_state = 18},
  [4404] = {.lex_state = 117, .external_lex_state = 18},
  [4405] = {.lex_state = 117, .external_lex_state = 18},
  [4406] = {.lex_state = 117, .external_lex_state = 3},
  [4407] = {.lex_state = 117, .external_lex_state = 3},
  [4408] = {.lex_state = 117, .external_lex_state = 18},
  [4409] = {.lex_state = 117, .external_lex_state = 18},
  [4410] = {.lex_state = 117, .external_lex_state = 18},
  [4411] = {.lex_state = 117, .external_lex_state = 3},
  [4412] = {.lex_state = 117, .external_lex_state = 18},
  [4413] = {.lex_state = 117, .external_lex_state = 18},
  [4414] = {.lex_state = 117, .external_lex_state = 18},
  [4415] = {.lex_state = 117, .external_lex_state = 18},
  [4416] = {.lex_state = 117, .external_lex_state = 3},
  [4417] = {.lex_state = 117, .external_lex_state = 18},
  [4418] = {.lex_state = 117, .external_lex_state = 3},
  [4419] = {.lex_state = 117, .external_lex_state = 10},
  [4420] = {.lex_state = 117, .external_lex_state = 18},
  [4421] = {.lex_state = 117, .external_lex_state = 18},
  [4422] = {.lex_state = 9, .external_lex_state = 10},
  [4423] = {.lex_state = 117, .external_lex_state = 18},
  [4424] = {.lex_state = 117, .external_lex_state = 18},
  [4425] = {.lex_state = 117, .external_lex_state = 18},
  [4426] = {.lex_state = 117, .external_lex_state = 3},
  [4427] = {.lex_state = 117, .external_lex_state = 18},
  [4428] = {.lex_state = 117, .external_lex_state = 3},
  [4429] = {.lex_state = 117, .external_lex_state = 18},
  [4430] = {.lex_state = 117, .external_lex_state = 18},
  [4431] = {.lex_state = 117, .external_lex_state = 3},
  [4432] = {.lex_state = 117, .external_lex_state = 18},
  [4433] = {.lex_state = 117, .external_lex_state = 18},
  [4434] = {.lex_state = 117, .external_lex_state = 18},
  [4435] = {.lex_state = 117, .external_lex_state = 18},
  [4436] = {.lex_state = 117, .external_lex_state = 18},
  [4437] = {.lex_state = 117, .external_lex_state = 18},
  [4438] = {.lex_state = 117, .external_lex_state = 12},
  [4439] = {.lex_state = 117, .external_lex_state = 18},
  [4440] = {.lex_state = 117, .external_lex_state = 18},
  [4441] = {.lex_state = 117, .external_lex_state = 18},
  [4442] = {.lex_state = 117, .external_lex_state = 12},
  [4443] = {.lex_state = 117, .external_lex_state = 12},
  [4444] = {.lex_state = 117, .external_lex_state = 18},
  [4445] = {.lex_state = 117, .external_lex_state = 18},
  [4446] = {.lex_state = 117, .external_lex_state = 18},
  [4447] = {.lex_state = 117, .external_lex_state = 18},
  [4448] = {.lex_state = 117, .external_lex_state = 18},
  [4449] = {.lex_state = 117, .external_lex_state = 18},
  [4450] = {.lex_state = 117, .external_lex_state = 18},
  [4451] = {.lex_state = 117, .external_lex_state = 18},
  [4452] = {.lex_state = 117, .external_lex_state = 18},
  [4453] = {.lex_state = 117, .external_lex_state = 18},
  [4454] = {.lex_state = 117, .external_lex_state = 18},
  [4455] = {.lex_state = 117, .external_lex_state = 18},
  [4456] = {.lex_state = 117, .external_lex_state = 18},
  [4457] = {.lex_state = 117, .external_lex_state = 18},
  [4458] = {.lex_state = 117, .external_lex_state = 18},
  [4459] = {.lex_state = 117, .external_lex_state = 18},
  [4460] = {.lex_state = 117, .external_lex_state = 18},
  [4461] = {.lex_state = 117, .external_lex_state = 18},
  [4462] = {.lex_state = 117, .external_lex_state = 18},
  [4463] = {.lex_state = 117, .external_lex_state = 18},
  [4464] = {.lex_state = 117, .external_lex_state = 18},
  [4465] = {.lex_state = 117, .external_lex_state = 18},
  [4466] = {.lex_state = 117, .external_lex_state = 18},
  [4467] = {.lex_state = 117, .external_lex_state = 12},
  [4468] = {.lex_state = 117, .external_lex_state = 12},
  [4469] = {.lex_state = 117, .external_lex_state = 12},
  [4470] = {.lex_state = 117, .external_lex_state = 12},
  [4471] = {.lex_state = 117, .external_lex_state = 18},
  [4472] = {.lex_state = 117, .external_lex_state = 18},
  [4473] = {.lex_state = 117, .external_lex_state = 18},
  [4474] = {.lex_state = 117, .external_lex_state = 18},
  [4475] = {.lex_state = 117, .external_lex_state = 18},
  [4476] = {.lex_state = 117, .external_lex_state = 15},
  [4477] = {.lex_state = 10, .external_lex_state = 12},
  [4478] = {.lex_state = 117, .external_lex_state = 18},
  [4479] = {.lex_state = 117, .external_lex_state = 18},
  [4480] = {.lex_state = 117, .external_lex_state = 18},
  [4481] = {.lex_state = 117, .external_lex_state = 15},
  [4482] = {.lex_state = 117, .external_lex_state = 18},
  [4483] = {.lex_state = 117, .external_lex_state = 12},
  [4484] = {.lex_state = 117, .external_lex_state = 10},
  [4485] = {.lex_state = 117, .external_lex_state = 15},
  [4486] = {.lex_state = 117, .external_lex_state = 18},
  [4487] = {.lex_state = 117, .external_lex_state = 18},
  [4488] = {.lex_state = 117, .external_lex_state = 15},
  [4489] = {.lex_state = 117, .external_lex_state = 18},
  [4490] = {.lex_state = 117, .external_lex_state = 18},
  [4491] = {.lex_state = 117, .external_lex_state = 18},
  [4492] = {.lex_state = 117, .external_lex_state = 18},
  [4493] = {.lex_state = 117, .external_lex_state = 18},
  [4494] = {.lex_state = 117, .external_lex_state = 18},
  [4495] = {.lex_state = 117, .external_lex_state = 18},
  [4496] = {.lex_state = 117, .external_lex_state = 18},
  [4497] = {.lex_state = 117, .external_lex_state = 18},
  [4498] = {.lex_state = 117, .external_lex_state = 18},
  [4499] = {.lex_state = 117, .external_lex_state = 18},
  [4500] = {.lex_state = 117, .external_lex_state = 18},
  [4501] = {.lex_state = 117, .external_lex_state = 18},
  [4502] = {.lex_state = 117, .external_lex_state = 18},
  [4503] = {.lex_state = 117, .external_lex_state = 18},
  [4504] = {.lex_state = 117, .external_lex_state = 18},
  [4505] = {.lex_state = 117, .external_lex_state = 18},
  [4506] = {.lex_state = 117, .external_lex_state = 18},
  [4507] = {.lex_state = 117, .external_lex_state = 12},
  [4508] = {.lex_state = 117, .external_lex_state = 18},
  [4509] = {.lex_state = 117, .external_lex_state = 18},
  [4510] = {.lex_state = 117, .external_lex_state = 18},
  [4511] = {.lex_state = 117, .external_lex_state = 18},
  [4512] = {.lex_state = 117, .external_lex_state = 18},
  [4513] = {.lex_state = 117, .external_lex_state = 18},
  [4514] = {.lex_state = 117, .external_lex_state = 18},
  [4515] = {.lex_state = 117, .external_lex_state = 18},
  [4516] = {.lex_state = 117, .external_lex_state = 18},
  [4517] = {.lex_state = 117, .external_lex_state = 18},
  [4518] = {.lex_state = 117, .external_lex_state = 18},
  [4519] = {.lex_state = 117, .external_lex_state = 18},
  [4520] = {.lex_state = 117, .external_lex_state = 18},
  [4521] = {.lex_state = 117, .external_lex_state = 18},
  [4522] = {.lex_state = 117, .external_lex_state = 18},
  [4523] = {.lex_state = 117, .external_lex_state = 18},
  [4524] = {.lex_state = 117, .external_lex_state = 18},
  [4525] = {.lex_state = 117, .external_lex_state = 18},
  [4526] = {.lex_state = 117, .external_lex_state = 18},
  [4527] = {.lex_state = 117, .external_lex_state = 18},
  [4528] = {.lex_state = 117, .external_lex_state = 18},
  [4529] = {.lex_state = 117, .external_lex_state = 18},
  [4530] = {.lex_state = 117, .external_lex_state = 18},
  [4531] = {.lex_state = 117, .external_lex_state = 18},
  [4532] = {.lex_state = 117, .external_lex_state = 18},
  [4533] = {.lex_state = 117, .external_lex_state = 18},
  [4534] = {.lex_state = 117, .external_lex_state = 18},
  [4535] = {.lex_state = 117, .external_lex_state = 15},
  [4536] = {.lex_state = 117, .external_lex_state = 18},
  [4537] = {.lex_state = 117, .external_lex_state = 18},
  [4538] = {.lex_state = 117, .external_lex_state = 18},
  [4539] = {.lex_state = 117, .external_lex_state = 18},
  [4540] = {.lex_state = 117, .external_lex_state = 18},
  [4541] = {.lex_state = 117, .external_lex_state = 18},
  [4542] = {.lex_state = 117, .external_lex_state = 18},
  [4543] = {.lex_state = 117, .external_lex_state = 18},
  [4544] = {.lex_state = 117, .external_lex_state = 18},
  [4545] = {.lex_state = 117, .external_lex_state = 18},
  [4546] = {.lex_state = 117, .external_lex_state = 18},
  [4547] = {.lex_state = 117, .external_lex_state = 18},
  [4548] = {.lex_state = 117, .external_lex_state = 18},
  [4549] = {.lex_state = 117, .external_lex_state = 18},
  [4550] = {.lex_state = 117, .external_lex_state = 18},
  [4551] = {.lex_state = 117, .external_lex_state = 18},
  [4552] = {.lex_state = 117, .external_lex_state = 18},
  [4553] = {.lex_state = 117, .external_lex_state = 18},
  [4554] = {.lex_state = 117, .external_lex_state = 18},
  [4555] = {.lex_state = 117, .external_lex_state = 18},
  [4556] = {.lex_state = 117, .external_lex_state = 18},
  [4557] = {.lex_state = 117, .external_lex_state = 18},
  [4558] = {.lex_state = 117, .external_lex_state = 18},
  [4559] = {.lex_state = 117, .external_lex_state = 18},
  [4560] = {.lex_state = 117, .external_lex_state = 18},
  [4561] = {.lex_state = 117, .external_lex_state = 15},
  [4562] = {.lex_state = 117, .external_lex_state = 18},
  [4563] = {.lex_state = 117, .external_lex_state = 18},
  [4564] = {.lex_state = 117, .external_lex_state = 18},
  [4565] = {.lex_state = 117, .external_lex_state = 15},
  [4566] = {.lex_state = 117, .external_lex_state = 10},
  [4567] = {.lex_state = 117, .external_lex_state = 15},
  [4568] = {.lex_state = 117, .external_lex_state = 15},
  [4569] = {.lex_state = 117, .external_lex_state = 18},
  [4570] = {.lex_state = 117, .external_lex_state = 18},
  [4571] = {.lex_state = 117, .external_lex_state = 18},
  [4572] = {.lex_state = 117, .external_lex_state = 18},
  [4573] = {.lex_state = 117, .external_lex_state = 18},
  [4574] = {.lex_state = 117, .external_lex_state = 18},
  [4575] = {.lex_state = 117, .external_lex_state = 18},
  [4576] = {.lex_state = 117, .external_lex_state = 18},
  [4577] = {.lex_state = 117, .external_lex_state = 18},
  [4578] = {.lex_state = 117, .external_lex_state = 18},
  [4579] = {.lex_state = 117, .external_lex_state = 18},
  [4580] = {.lex_state = 117, .external_lex_state = 18},
  [4581] = {.lex_state = 117, .external_lex_state = 18},
  [4582] = {.lex_state = 117, .external_lex_state = 18},
  [4583] = {.lex_state = 117, .external_lex_state = 18},
  [4584] = {.lex_state = 117, .external_lex_state = 18},
  [4585] = {.lex_state = 117, .external_lex_state = 18},
  [4586] = {.lex_state = 117, .external_lex_state = 18},
  [4587] = {.lex_state = 117, .external_lex_state = 10},
  [4588] = {.lex_state = 117, .external_lex_state = 18},
  [4589] = {.lex_state = 117, .external_lex_state = 18},
  [4590] = {.lex_state = 117, .external_lex_state = 18},
  [4591] = {.lex_state = 117, .external_lex_state = 18},
  [4592] = {.lex_state = 117, .external_lex_state = 18},
  [4593] = {.lex_state = 117, .external_lex_state = 18},
  [4594] = {.lex_state = 117, .external_lex_state = 18},
  [4595] = {.lex_state = 117, .external_lex_state = 18},
  [4596] = {.lex_state = 117, .external_lex_state = 18},
  [4597] = {.lex_state = 117, .external_lex_state = 18},
  [4598] = {.lex_state = 117, .external_lex_state = 18},
  [4599] = {.lex_state = 117, .external_lex_state = 18},
  [4600] = {.lex_state = 117, .external_lex_state = 18},
  [4601] = {.lex_state = 117, .external_lex_state = 18},
  [4602] = {.lex_state = 117, .external_lex_state = 18},
  [4603] = {.lex_state = 117, .external_lex_state = 18},
  [4604] = {.lex_state = 117, .external_lex_state = 18},
  [4605] = {.lex_state = 117, .external_lex_state = 18},
  [4606] = {.lex_state = 117, .external_lex_state = 18},
  [4607] = {.lex_state = 117, .external_lex_state = 10},
  [4608] = {.lex_state = 117, .external_lex_state = 18},
  [4609] = {.lex_state = 117, .external_lex_state = 18},
  [4610] = {.lex_state = 117, .external_lex_state = 18},
  [4611] = {.lex_state = 117, .external_lex_state = 18},
  [4612] = {.lex_state = 117, .external_lex_state = 18},
  [4613] = {.lex_state = 117, .external_lex_state = 18},
  [4614] = {.lex_state = 117, .external_lex_state = 18},
  [4615] = {.lex_state = 117, .external_lex_state = 18},
  [4616] = {.lex_state = 117, .external_lex_state = 18},
  [4617] = {.lex_state = 117, .external_lex_state = 18},
  [4618] = {.lex_state = 117, .external_lex_state = 18},
  [4619] = {.lex_state = 117, .external_lex_state = 18},
  [4620] = {.lex_state = 117, .external_lex_state = 18},
  [4621] = {.lex_state = 117, .external_lex_state = 18},
  [4622] = {.lex_state = 117, .external_lex_state = 18},
  [4623] = {.lex_state = 117, .external_lex_state = 18},
  [4624] = {.lex_state = 117, .external_lex_state = 18},
  [4625] = {.lex_state = 117, .external_lex_state = 18},
  [4626] = {.lex_state = 117, .external_lex_state = 18},
  [4627] = {.lex_state = 117, .external_lex_state = 18},
  [4628] = {.lex_state = 117, .external_lex_state = 18},
  [4629] = {.lex_state = 117, .external_lex_state = 18},
  [4630] = {.lex_state = 117, .external_lex_state = 18},
  [4631] = {.lex_state = 117, .external_lex_state = 18},
  [4632] = {.lex_state = 117, .external_lex_state = 18},
  [4633] = {.lex_state = 117, .external_lex_state = 18},
  [4634] = {.lex_state = 117, .external_lex_state = 18},
  [4635] = {.lex_state = 117, .external_lex_state = 18},
  [4636] = {.lex_state = 117, .external_lex_state = 18},
  [4637] = {.lex_state = 117, .external_lex_state = 18},
  [4638] = {.lex_state = 117, .external_lex_state = 18},
  [4639] = {.lex_state = 117, .external_lex_state = 18},
  [4640] = {.lex_state = 117, .external_lex_state = 18},
  [4641] = {.lex_state = 117, .external_lex_state = 18},
  [4642] = {.lex_state = 117, .external_lex_state = 18},
  [4643] = {.lex_state = 117, .external_lex_state = 15},
  [4644] = {.lex_state = 117, .external_lex_state = 18},
  [4645] = {.lex_state = 117, .external_lex_state = 18},
  [4646] = {.lex_state = 117, .external_lex_state = 18},
  [4647] = {.lex_state = 117, .external_lex_state = 18},
  [4648] = {.lex_state = 117, .external_lex_state = 18},
  [4649] = {.lex_state = 117, .external_lex_state = 18},
  [4650] = {.lex_state = 10, .external_lex_state = 12},
  [4651] = {.lex_state = 117, .external_lex_state = 18},
  [4652] = {.lex_state = 117, .external_lex_state = 18},
  [4653] = {.lex_state = 117, .external_lex_state = 18},
  [4654] = {.lex_state = 117, .external_lex_state = 18},
  [4655] = {.lex_state = 117, .external_lex_state = 18},
  [4656] = {.lex_state = 117, .external_lex_state = 18},
  [4657] = {.lex_state = 117, .external_lex_state = 18},
  [4658] = {.lex_state = 117, .external_lex_state = 18},
  [4659] = {.lex_state = 117, .external_lex_state = 18},
  [4660] = {.lex_state = 117, .external_lex_state = 18},
  [4661] = {.lex_state = 117, .external_lex_state = 18},
  [4662] = {.lex_state = 117, .external_lex_state = 18},
  [4663] = {.lex_state = 117, .external_lex_state = 18},
  [4664] = {.lex_state = 117, .external_lex_state = 18},
  [4665] = {.lex_state = 117, .external_lex_state = 18},
  [4666] = {.lex_state = 117, .external_lex_state = 18},
  [4667] = {.lex_state = 117, .external_lex_state = 18},
  [4668] = {.lex_state = 117, .external_lex_state = 18},
  [4669] = {.lex_state = 117, .external_lex_state = 18},
  [4670] = {.lex_state = 117, .external_lex_state = 18},
  [4671] = {.lex_state = 117, .external_lex_state = 18},
  [4672] = {.lex_state = 117, .external_lex_state = 18},
  [4673] = {.lex_state = 117, .external_lex_state = 18},
  [4674] = {.lex_state = 117, .external_lex_state = 18},
  [4675] = {.lex_state = 117, .external_lex_state = 18},
  [4676] = {.lex_state = 117, .external_lex_state = 18},
  [4677] = {.lex_state = 117, .external_lex_state = 18},
  [4678] = {.lex_state = 117, .external_lex_state = 18},
  [4679] = {.lex_state = 117, .external_lex_state = 18},
  [4680] = {.lex_state = 117, .external_lex_state = 18},
  [4681] = {.lex_state = 117, .external_lex_state = 18},
  [4682] = {.lex_state = 117, .external_lex_state = 18},
  [4683] = {.lex_state = 117, .external_lex_state = 18},
  [4684] = {.lex_state = 117, .external_lex_state = 18},
  [4685] = {.lex_state = 117, .external_lex_state = 18},
  [4686] = {.lex_state = 117, .external_lex_state = 18},
  [4687] = {.lex_state = 117, .external_lex_state = 18},
  [4688] = {.lex_state = 117, .external_lex_state = 18},
  [4689] = {.lex_state = 117, .external_lex_state = 18},
  [4690] = {.lex_state = 117, .external_lex_state = 18},
  [4691] = {.lex_state = 117, .external_lex_state = 18},
  [4692] = {.lex_state = 117, .external_lex_state = 18},
  [4693] = {.lex_state = 117, .external_lex_state = 18},
  [4694] = {.lex_state = 117, .external_lex_state = 18},
  [4695] = {.lex_state = 117, .external_lex_state = 18},
  [4696] = {.lex_state = 117, .external_lex_state = 18},
  [4697] = {.lex_state = 117, .external_lex_state = 18},
  [4698] = {.lex_state = 117, .external_lex_state = 18},
  [4699] = {.lex_state = 117, .external_lex_state = 18},
  [4700] = {.lex_state = 117, .external_lex_state = 10},
  [4701] = {.lex_state = 117, .external_lex_state = 10},
  [4702] = {.lex_state = 7, .external_lex_state = 3},
  [4703] = {.lex_state = 117, .external_lex_state = 12},
  [4704] = {.lex_state = 117, .external_lex_state = 15},
  [4705] = {.lex_state = 117, .external_lex_state = 15},
  [4706] = {.lex_state = 117, .external_lex_state = 18},
  [4707] = {.lex_state = 117, .external_lex_state = 18},
  [4708] = {.lex_state = 117, .external_lex_state = 18},
  [4709] = {.lex_state = 117, .external_lex_state = 18},
  [4710] = {.lex_state = 117, .external_lex_state = 18},
  [4711] = {.lex_state = 117, .external_lex_state = 18},
  [4712] = {.lex_state = 117, .external_lex_state = 18},
  [4713] = {.lex_state = 117, .external_lex_state = 18},
  [4714] = {.lex_state = 117, .external_lex_state = 18},
  [4715] = {.lex_state = 117, .external_lex_state = 18},
  [4716] = {.lex_state = 117, .external_lex_state = 18},
  [4717] = {.lex_state = 117, .external_lex_state = 18},
  [4718] = {.lex_state = 117, .external_lex_state = 18},
  [4719] = {.lex_state = 117, .external_lex_state = 18},
  [4720] = {.lex_state = 117, .external_lex_state = 18},
  [4721] = {.lex_state = 117, .external_lex_state = 18},
  [4722] = {.lex_state = 117, .external_lex_state = 18},
  [4723] = {.lex_state = 117, .external_lex_state = 18},
  [4724] = {.lex_state = 117, .external_lex_state = 18},
  [4725] = {.lex_state = 117, .external_lex_state = 18},
  [4726] = {.lex_state = 117, .external_lex_state = 18},
  [4727] = {.lex_state = 117, .external_lex_state = 18},
  [4728] = {.lex_state = 117, .external_lex_state = 18},
  [4729] = {.lex_state = 117, .external_lex_state = 18},
  [4730] = {.lex_state = 117, .external_lex_state = 18},
  [4731] = {.lex_state = 117, .external_lex_state = 10},
  [4732] = {.lex_state = 117, .external_lex_state = 18},
  [4733] = {.lex_state = 117, .external_lex_state = 18},
  [4734] = {.lex_state = 117, .external_lex_state = 18},
  [4735] = {.lex_state = 117, .external_lex_state = 18},
  [4736] = {.lex_state = 117, .external_lex_state = 18},
  [4737] = {.lex_state = 117, .external_lex_state = 18},
  [4738] = {.lex_state = 117, .external_lex_state = 18},
  [4739] = {.lex_state = 117, .external_lex_state = 18},
  [4740] = {.lex_state = 117, .external_lex_state = 18},
  [4741] = {.lex_state = 117, .external_lex_state = 18},
  [4742] = {.lex_state = 117, .external_lex_state = 18},
  [4743] = {.lex_state = 117, .external_lex_state = 18},
  [4744] = {.lex_state = 117, .external_lex_state = 18},
  [4745] = {.lex_state = 117, .external_lex_state = 18},
  [4746] = {.lex_state = 117, .external_lex_state = 18},
  [4747] = {.lex_state = 117, .external_lex_state = 18},
  [4748] = {.lex_state = 117, .external_lex_state = 18},
  [4749] = {.lex_state = 117, .external_lex_state = 18},
  [4750] = {.lex_state = 117, .external_lex_state = 18},
  [4751] = {.lex_state = 117, .external_lex_state = 18},
  [4752] = {.lex_state = 117, .external_lex_state = 18},
  [4753] = {.lex_state = 117, .external_lex_state = 18},
  [4754] = {.lex_state = 117, .external_lex_state = 18},
  [4755] = {.lex_state = 117, .external_lex_state = 18},
  [4756] = {.lex_state = 117, .external_lex_state = 18},
  [4757] = {.lex_state = 117, .external_lex_state = 18},
  [4758] = {.lex_state = 117, .external_lex_state = 18},
  [4759] = {.lex_state = 117, .external_lex_state = 18},
  [4760] = {.lex_state = 117, .external_lex_state = 18},
  [4761] = {.lex_state = 117, .external_lex_state = 18},
  [4762] = {.lex_state = 117, .external_lex_state = 18},
  [4763] = {.lex_state = 117, .external_lex_state = 18},
  [4764] = {.lex_state = 117, .external_lex_state = 18},
  [4765] = {.lex_state = 117, .external_lex_state = 18},
  [4766] = {.lex_state = 117, .external_lex_state = 18},
  [4767] = {.lex_state = 117, .external_lex_state = 18},
  [4768] = {.lex_state = 117, .external_lex_state = 18},
  [4769] = {.lex_state = 117, .external_lex_state = 18},
  [4770] = {.lex_state = 117, .external_lex_state = 18},
  [4771] = {.lex_state = 117, .external_lex_state = 18},
  [4772] = {.lex_state = 117, .external_lex_state = 18},
  [4773] = {.lex_state = 117, .external_lex_state = 18},
  [4774] = {.lex_state = 117, .external_lex_state = 18},
  [4775] = {.lex_state = 117, .external_lex_state = 15},
  [4776] = {.lex_state = 117, .external_lex_state = 18},
  [4777] = {.lex_state = 117, .external_lex_state = 18},
  [4778] = {.lex_state = 117, .external_lex_state = 18},
  [4779] = {.lex_state = 117, .external_lex_state = 18},
  [4780] = {.lex_state = 117, .external_lex_state = 18},
  [4781] = {.lex_state = 117, .external_lex_state = 18},
  [4782] = {.lex_state = 117, .external_lex_state = 18},
  [4783] = {.lex_state = 117, .external_lex_state = 18},
  [4784] = {.lex_state = 117, .external_lex_state = 18},
  [4785] = {.lex_state = 117, .external_lex_state = 18},
  [4786] = {.lex_state = 117, .external_lex_state = 18},
  [4787] = {.lex_state = 117, .external_lex_state = 18},
  [4788] = {.lex_state = 117, .external_lex_state = 18},
  [4789] = {.lex_state = 117, .external_lex_state = 18},
  [4790] = {.lex_state = 117, .external_lex_state = 18},
  [4791] = {.lex_state = 117, .external_lex_state = 18},
  [4792] = {.lex_state = 117, .external_lex_state = 18},
  [4793] = {.lex_state = 117, .external_lex_state = 18},
  [4794] = {.lex_state = 117, .external_lex_state = 18},
  [4795] = {.lex_state = 117, .external_lex_state = 18},
  [4796] = {.lex_state = 117, .external_lex_state = 18},
  [4797] = {.lex_state = 117, .external_lex_state = 18},
  [4798] = {.lex_state = 117, .external_lex_state = 18},
  [4799] = {.lex_state = 117, .external_lex_state = 18},
  [4800] = {.lex_state = 117, .external_lex_state = 18},
  [4801] = {.lex_state = 117, .external_lex_state = 3},
  [4802] = {.lex_state = 117, .external_lex_state = 18},
  [4803] = {.lex_state = 117, .external_lex_state = 18},
  [4804] = {.lex_state = 117, .external_lex_state = 18},
  [4805] = {.lex_state = 117, .external_lex_state = 18},
  [4806] = {.lex_state = 117, .external_lex_state = 18},
  [4807] = {.lex_state = 117, .external_lex_state = 18},
  [4808] = {.lex_state = 117, .external_lex_state = 18},
  [4809] = {.lex_state = 117, .external_lex_state = 18},
  [4810] = {.lex_state = 117, .external_lex_state = 18},
  [4811] = {.lex_state = 117, .external_lex_state = 18},
  [4812] = {.lex_state = 117, .external_lex_state = 18},
  [4813] = {.lex_state = 117, .external_lex_state = 18},
  [4814] = {.lex_state = 117, .external_lex_state = 18},
  [4815] = {.lex_state = 117, .external_lex_state = 18},
  [4816] = {.lex_state = 117, .external_lex_state = 18},
  [4817] = {.lex_state = 117, .external_lex_state = 18},
  [4818] = {.lex_state = 117, .external_lex_state = 18},
  [4819] = {.lex_state = 117, .external_lex_state = 18},
  [4820] = {.lex_state = 117, .external_lex_state = 18},
  [4821] = {.lex_state = 117, .external_lex_state = 18},
  [4822] = {.lex_state = 117, .external_lex_state = 18},
  [4823] = {.lex_state = 117, .external_lex_state = 18},
  [4824] = {.lex_state = 117, .external_lex_state = 18},
  [4825] = {.lex_state = 117, .external_lex_state = 18},
  [4826] = {.lex_state = 117, .external_lex_state = 18},
  [4827] = {.lex_state = 117, .external_lex_state = 18},
  [4828] = {.lex_state = 117, .external_lex_state = 18},
  [4829] = {.lex_state = 117, .external_lex_state = 18},
  [4830] = {.lex_state = 117, .external_lex_state = 18},
  [4831] = {.lex_state = 117, .external_lex_state = 18},
  [4832] = {.lex_state = 117, .external_lex_state = 18},
  [4833] = {.lex_state = 117, .external_lex_state = 18},
  [4834] = {.lex_state = 117, .external_lex_state = 18},
  [4835] = {.lex_state = 117, .external_lex_state = 18},
  [4836] = {.lex_state = 117, .external_lex_state = 18},
  [4837] = {.lex_state = 117, .external_lex_state = 18},
  [4838] = {.lex_state = 117, .external_lex_state = 18},
  [4839] = {.lex_state = 117, .external_lex_state = 18},
  [4840] = {.lex_state = 117, .external_lex_state = 18},
  [4841] = {.lex_state = 117, .external_lex_state = 18},
  [4842] = {.lex_state = 117, .external_lex_state = 18},
  [4843] = {.lex_state = 117, .external_lex_state = 18},
  [4844] = {.lex_state = 117, .external_lex_state = 18},
  [4845] = {.lex_state = 117, .external_lex_state = 18},
  [4846] = {.lex_state = 117, .external_lex_state = 18},
  [4847] = {.lex_state = 117, .external_lex_state = 18},
  [4848] = {.lex_state = 117, .external_lex_state = 18},
  [4849] = {.lex_state = 117, .external_lex_state = 18},
  [4850] = {.lex_state = 117, .external_lex_state = 18},
  [4851] = {.lex_state = 117, .external_lex_state = 18},
  [4852] = {.lex_state = 117, .external_lex_state = 18},
  [4853] = {.lex_state = 117, .external_lex_state = 18},
  [4854] = {.lex_state = 117, .external_lex_state = 18},
  [4855] = {.lex_state = 117, .external_lex_state = 18},
  [4856] = {.lex_state = 117, .external_lex_state = 18},
  [4857] = {.lex_state = 117, .external_lex_state = 18},
  [4858] = {.lex_state = 117, .external_lex_state = 18},
  [4859] = {.lex_state = 117, .external_lex_state = 18},
  [4860] = {.lex_state = 117, .external_lex_state = 18},
  [4861] = {.lex_state = 117, .external_lex_state = 18},
  [4862] = {.lex_state = 117, .external_lex_state = 18},
  [4863] = {.lex_state = 117, .external_lex_state = 18},
  [4864] = {.lex_state = 117, .external_lex_state = 18},
  [4865] = {.lex_state = 117, .external_lex_state = 18},
  [4866] = {.lex_state = 117, .external_lex_state = 18},
  [4867] = {.lex_state = 117, .external_lex_state = 18},
  [4868] = {.lex_state = 117, .external_lex_state = 18},
  [4869] = {.lex_state = 117, .external_lex_state = 18},
  [4870] = {.lex_state = 117, .external_lex_state = 18},
  [4871] = {.lex_state = 117, .external_lex_state = 18},
  [4872] = {.lex_state = 117, .external_lex_state = 18},
  [4873] = {.lex_state = 117, .external_lex_state = 18},
  [4874] = {.lex_state = 117, .external_lex_state = 18},
  [4875] = {.lex_state = 117, .external_lex_state = 18},
  [4876] = {.lex_state = 117, .external_lex_state = 18},
  [4877] = {.lex_state = 117, .external_lex_state = 18},
  [4878] = {.lex_state = 117, .external_lex_state = 10},
  [4879] = {.lex_state = 117, .external_lex_state = 23},
  [4880] = {.lex_state = 117, .external_lex_state = 23},
  [4881] = {.lex_state = 117, .external_lex_state = 23},
  [4882] = {.lex_state = 117, .external_lex_state = 23},
  [4883] = {.lex_state = 117, .external_lex_state = 15},
  [4884] = {.lex_state = 117, .external_lex_state = 15},
  [4885] = {.lex_state = 117, .external_lex_state = 23},
  [4886] = {.lex_state = 117, .external_lex_state = 15},
  [4887] = {.lex_state = 117, .external_lex_state = 15},
  [4888] = {.lex_state = 117, .external_lex_state = 15},
  [4889] = {.lex_state = 117, .external_lex_state = 10},
  [4890] = {.lex_state = 117, .external_lex_state = 15},
  [4891] = {.lex_state = 117, .external_lex_state = 12},
  [4892] = {.lex_state = 117, .external_lex_state = 15},
  [4893] = {.lex_state = 117, .external_lex_state = 3},
  [4894] = {.lex_state = 117, .external_lex_state = 10},
  [4895] = {.lex_state = 117, .external_lex_state = 10},
  [4896] = {.lex_state = 117, .external_lex_state = 12},
  [4897] = {.lex_state = 117, .external_lex_state = 12},
  [4898] = {.lex_state = 3, .external_lex_state = 14},
  [4899] = {.lex_state = 3, .external_lex_state = 14},
  [4900] = {.lex_state = 117, .external_lex_state = 2},
  [4901] = {.lex_state = 117, .external_lex_state = 17},
  [4902] = {.lex_state = 117, .external_lex_state = 12},
  [4903] = {.lex_state = 3, .external_lex_state = 14},
  [4904] = {.lex_state = 117, .external_lex_state = 17},
  [4905] = {.lex_state = 3},
  [4906] = {.lex_state = 12},
  [4907] = {.lex_state = 117, .external_lex_state = 12},
  [4908] = {.lex_state = 117, .external_lex_state = 12},
  [4909] = {.lex_state = 117, .external_lex_state = 12},
  [4910] = {.lex_state = 117, .external_lex_state = 2},
  [4911] = {.lex_state = 3, .external_lex_state = 14},
  [4912] = {.lex_state = 3},
  [4913] = {.lex_state = 3},
  [4914] = {.lex_state = 117, .external_lex_state = 12},
  [4915] = {.lex_state = 117, .external_lex_state = 12},
  [4916] = {.lex_state = 117, .external_lex_state = 12},
  [4917] = {.lex_state = 10, .external_lex_state = 12},
  [4918] = {.lex_state = 117, .external_lex_state = 12},
  [4919] = {.lex_state = 117, .external_lex_state = 12},
  [4920] = {.lex_state = 117, .external_lex_state = 12},
  [4921] = {.lex_state = 117, .external_lex_state = 16},
  [4922] = {.lex_state = 117, .external_lex_state = 12},
  [4923] = {.lex_state = 117, .external_lex_state = 12},
  [4924] = {.lex_state = 117, .external_lex_state = 12},
  [4925] = {.lex_state = 12},
  [4926] = {.lex_state = 117, .external_lex_state = 12},
  [4927] = {.lex_state = 117, .external_lex_state = 12},
  [4928] = {.lex_state = 117, .external_lex_state = 12},
  [4929] = {.lex_state = 12},
  [4930] = {.lex_state = 117, .external_lex_state = 17},
  [4931] = {.lex_state = 117, .external_lex_state = 12},
  [4932] = {.lex_state = 117, .external_lex_state = 16},
  [4933] = {.lex_state = 10, .external_lex_state = 12},
  [4934] = {.lex_state = 117, .external_lex_state = 12},
  [4935] = {.lex_state = 117, .external_lex_state = 15},
  [4936] = {.lex_state = 117, .external_lex_state = 17},
  [4937] = {.lex_state = 3, .external_lex_state = 14},
  [4938] = {.lex_state = 117, .external_lex_state = 12},
  [4939] = {.lex_state = 117, .external_lex_state = 12},
  [4940] = {.lex_state = 117, .external_lex_state = 17},
  [4941] = {.lex_state = 117, .external_lex_state = 12},
  [4942] = {.lex_state = 117, .external_lex_state = 15},
  [4943] = {.lex_state = 117, .external_lex_state = 12},
  [4944] = {.lex_state = 117, .external_lex_state = 16},
  [4945] = {.lex_state = 117, .external_lex_state = 12},
  [4946] = {.lex_state = 117, .external_lex_state = 2},
  [4947] = {.lex_state = 117, .external_lex_state = 2},
  [4948] = {.lex_state = 117, .external_lex_state = 12},
  [4949] = {.lex_state = 117, .external_lex_state = 12},
  [4950] = {.lex_state = 117, .external_lex_state = 12},
  [4951] = {.lex_state = 117, .external_lex_state = 12},
  [4952] = {.lex_state = 117, .external_lex_state = 12},
  [4953] = {.lex_state = 117, .external_lex_state = 12},
  [4954] = {.lex_state = 117, .external_lex_state = 16},
  [4955] = {.lex_state = 117, .external_lex_state = 12},
  [4956] = {.lex_state = 117, .external_lex_state = 12},
  [4957] = {.lex_state = 117, .external_lex_state = 12},
  [4958] = {.lex_state = 117, .external_lex_state = 12},
  [4959] = {.lex_state = 117, .external_lex_state = 12},
  [4960] = {.lex_state = 117, .external_lex_state = 12},
  [4961] = {.lex_state = 117, .external_lex_state = 12},
  [4962] = {.lex_state = 117, .external_lex_state = 12},
  [4963] = {.lex_state = 117, .external_lex_state = 12},
  [4964] = {.lex_state = 117, .external_lex_state = 12},
  [4965] = {.lex_state = 117, .external_lex_state = 12},
  [4966] = {.lex_state = 117, .external_lex_state = 12},
  [4967] = {.lex_state = 3},
  [4968] = {.lex_state = 117, .external_lex_state = 12},
  [4969] = {.lex_state = 117, .external_lex_state = 12},
  [4970] = {.lex_state = 117, .external_lex_state = 12},
  [4971] = {.lex_state = 117, .external_lex_state = 12},
  [4972] = {.lex_state = 117, .external_lex_state = 12},
  [4973] = {.lex_state = 117, .external_lex_state = 12},
  [4974] = {.lex_state = 117, .external_lex_state = 12},
  [4975] = {.lex_state = 117, .external_lex_state = 12},
  [4976] = {.lex_state = 117, .external_lex_state = 12},
  [4977] = {.lex_state = 117, .external_lex_state = 12},
  [4978] = {.lex_state = 117, .external_lex_state = 12},
  [4979] = {.lex_state = 117, .external_lex_state = 12},
  [4980] = {.lex_state = 117, .external_lex_state = 12},
  [4981] = {.lex_state = 117, .external_lex_state = 12},
  [4982] = {.lex_state = 117, .external_lex_state = 12},
  [4983] = {.lex_state = 117, .external_lex_state = 12},
  [4984] = {.lex_state = 117, .external_lex_state = 12},
  [4985] = {.lex_state = 117, .external_lex_state = 12},
  [4986] = {.lex_state = 117, .external_lex_state = 12},
  [4987] = {.lex_state = 117, .external_lex_state = 15},
  [4988] = {.lex_state = 117, .external_lex_state = 12},
  [4989] = {.lex_state = 117, .external_lex_state = 12},
  [4990] = {.lex_state = 117, .external_lex_state = 12},
  [4991] = {.lex_state = 117, .external_lex_state = 12},
  [4992] = {.lex_state = 117, .external_lex_state = 12},
  [4993] = {.lex_state = 117, .external_lex_state = 12},
  [4994] = {.lex_state = 117, .external_lex_state = 12},
  [4995] = {.lex_state = 117, .external_lex_state = 12},
  [4996] = {.lex_state = 117, .external_lex_state = 12},
  [4997] = {.lex_state = 117, .external_lex_state = 12},
  [4998] = {.lex_state = 117, .external_lex_state = 12},
  [4999] = {.lex_state = 117, .external_lex_state = 12},
  [5000] = {.lex_state = 117, .external_lex_state = 12},
  [5001] = {.lex_state = 117, .external_lex_state = 12},
  [5002] = {.lex_state = 117, .external_lex_state = 12},
  [5003] = {.lex_state = 117, .external_lex_state = 12},
  [5004] = {.lex_state = 117, .external_lex_state = 12},
  [5005] = {.lex_state = 117, .external_lex_state = 12},
  [5006] = {.lex_state = 117, .external_lex_state = 12},
  [5007] = {.lex_state = 117, .external_lex_state = 15},
  [5008] = {.lex_state = 117, .external_lex_state = 15},
  [5009] = {.lex_state = 117, .external_lex_state = 12},
  [5010] = {.lex_state = 117, .external_lex_state = 12},
  [5011] = {.lex_state = 117, .external_lex_state = 12},
  [5012] = {.lex_state = 117, .external_lex_state = 12},
  [5013] = {.lex_state = 117, .external_lex_state = 12},
  [5014] = {.lex_state = 117, .external_lex_state = 12},
  [5015] = {.lex_state = 117, .external_lex_state = 12},
  [5016] = {.lex_state = 117, .external_lex_state = 12},
  [5017] = {.lex_state = 117, .external_lex_state = 12},
  [5018] = {.lex_state = 117, .external_lex_state = 12},
  [5019] = {.lex_state = 117, .external_lex_state = 12},
  [5020] = {.lex_state = 117, .external_lex_state = 12},
  [5021] = {.lex_state = 117, .external_lex_state = 12},
  [5022] = {.lex_state = 117, .external_lex_state = 12},
  [5023] = {.lex_state = 117, .external_lex_state = 12},
  [5024] = {.lex_state = 117, .external_lex_state = 12},
  [5025] = {.lex_state = 117, .external_lex_state = 12},
  [5026] = {.lex_state = 117, .external_lex_state = 12},
  [5027] = {.lex_state = 117, .external_lex_state = 12},
  [5028] = {.lex_state = 117, .external_lex_state = 12},
  [5029] = {.lex_state = 117, .external_lex_state = 12},
  [5030] = {.lex_state = 117, .external_lex_state = 12},
  [5031] = {.lex_state = 117, .external_lex_state = 12},
  [5032] = {.lex_state = 117, .external_lex_state = 12},
  [5033] = {.lex_state = 117, .external_lex_state = 12},
  [5034] = {.lex_state = 117, .external_lex_state = 12},
  [5035] = {.lex_state = 117, .external_lex_state = 12},
  [5036] = {.lex_state = 117, .external_lex_state = 12},
  [5037] = {.lex_state = 117, .external_lex_state = 12},
  [5038] = {.lex_state = 117, .external_lex_state = 12},
  [5039] = {.lex_state = 117, .external_lex_state = 12},
  [5040] = {.lex_state = 117, .external_lex_state = 12},
  [5041] = {.lex_state = 117, .external_lex_state = 12},
  [5042] = {.lex_state = 117, .external_lex_state = 12},
  [5043] = {.lex_state = 117, .external_lex_state = 12},
  [5044] = {.lex_state = 117, .external_lex_state = 12},
  [5045] = {.lex_state = 117, .external_lex_state = 12},
  [5046] = {.lex_state = 117, .external_lex_state = 12},
  [5047] = {.lex_state = 117, .external_lex_state = 12},
  [5048] = {.lex_state = 117, .external_lex_state = 12},
  [5049] = {.lex_state = 117, .external_lex_state = 12},
  [5050] = {.lex_state = 117, .external_lex_state = 12},
  [5051] = {.lex_state = 117, .external_lex_state = 12},
  [5052] = {.lex_state = 117, .external_lex_state = 12},
  [5053] = {.lex_state = 117, .external_lex_state = 12},
  [5054] = {.lex_state = 117, .external_lex_state = 15},
  [5055] = {.lex_state = 117, .external_lex_state = 12},
  [5056] = {.lex_state = 117, .external_lex_state = 15},
  [5057] = {.lex_state = 117, .external_lex_state = 12},
  [5058] = {.lex_state = 117, .external_lex_state = 12},
  [5059] = {.lex_state = 117, .external_lex_state = 12},
  [5060] = {.lex_state = 117, .external_lex_state = 12},
  [5061] = {.lex_state = 117, .external_lex_state = 12},
  [5062] = {.lex_state = 117, .external_lex_state = 12},
  [5063] = {.lex_state = 117, .external_lex_state = 12},
  [5064] = {.lex_state = 117, .external_lex_state = 12},
  [5065] = {.lex_state = 117, .external_lex_state = 12},
  [5066] = {.lex_state = 117, .external_lex_state = 12},
  [5067] = {.lex_state = 117, .external_lex_state = 12},
  [5068] = {.lex_state = 117, .external_lex_state = 12},
  [5069] = {.lex_state = 117, .external_lex_state = 12},
  [5070] = {.lex_state = 117, .external_lex_state = 12},
  [5071] = {.lex_state = 117, .external_lex_state = 12},
  [5072] = {.lex_state = 117, .external_lex_state = 12},
  [5073] = {.lex_state = 117, .external_lex_state = 12},
  [5074] = {.lex_state = 117, .external_lex_state = 12},
  [5075] = {.lex_state = 117, .external_lex_state = 12},
  [5076] = {.lex_state = 117, .external_lex_state = 12},
  [5077] = {.lex_state = 117, .external_lex_state = 15},
  [5078] = {.lex_state = 117, .external_lex_state = 12},
  [5079] = {.lex_state = 117, .external_lex_state = 12},
  [5080] = {.lex_state = 117, .external_lex_state = 12},
  [5081] = {.lex_state = 117, .external_lex_state = 12},
  [5082] = {.lex_state = 117, .external_lex_state = 12},
  [5083] = {.lex_state = 117, .external_lex_state = 12},
  [5084] = {.lex_state = 117, .external_lex_state = 12},
  [5085] = {.lex_state = 117, .external_lex_state = 12},
  [5086] = {.lex_state = 117, .external_lex_state = 12},
  [5087] = {.lex_state = 117, .external_lex_state = 15},
  [5088] = {.lex_state = 117, .external_lex_state = 12},
  [5089] = {.lex_state = 117, .external_lex_state = 12},
  [5090] = {.lex_state = 117, .external_lex_state = 12},
  [5091] = {.lex_state = 117, .external_lex_state = 12},
  [5092] = {.lex_state = 117, .external_lex_state = 12},
  [5093] = {.lex_state = 117, .external_lex_state = 12},
  [5094] = {.lex_state = 117, .external_lex_state = 12},
  [5095] = {.lex_state = 117, .external_lex_state = 12},
  [5096] = {.lex_state = 117, .external_lex_state = 15},
  [5097] = {.lex_state = 117, .external_lex_state = 15},
  [5098] = {.lex_state = 117, .external_lex_state = 15},
  [5099] = {.lex_state = 117, .external_lex_state = 12},
  [5100] = {.lex_state = 117, .external_lex_state = 12},
  [5101] = {.lex_state = 117, .external_lex_state = 12},
  [5102] = {.lex_state = 117, .external_lex_state = 15},
  [5103] = {.lex_state = 117, .external_lex_state = 12},
  [5104] = {.lex_state = 117, .external_lex_state = 12},
  [5105] = {.lex_state = 117, .external_lex_state = 15},
  [5106] = {.lex_state = 117, .external_lex_state = 12},
  [5107] = {.lex_state = 117, .external_lex_state = 15},
  [5108] = {.lex_state = 117, .external_lex_state = 12},
  [5109] = {.lex_state = 117, .external_lex_state = 12},
  [5110] = {.lex_state = 117, .external_lex_state = 12},
  [5111] = {.lex_state = 117, .external_lex_state = 12},
  [5112] = {.lex_state = 117, .external_lex_state = 12},
  [5113] = {.lex_state = 117, .external_lex_state = 12},
  [5114] = {.lex_state = 117, .external_lex_state = 12},
  [5115] = {.lex_state = 117, .external_lex_state = 12},
  [5116] = {.lex_state = 117, .external_lex_state = 12},
  [5117] = {.lex_state = 117, .external_lex_state = 12},
  [5118] = {.lex_state = 117, .external_lex_state = 12},
  [5119] = {.lex_state = 117, .external_lex_state = 12},
  [5120] = {.lex_state = 117, .external_lex_state = 12},
  [5121] = {.lex_state = 117, .external_lex_state = 12},
  [5122] = {.lex_state = 117, .external_lex_state = 12},
  [5123] = {.lex_state = 117, .external_lex_state = 12},
  [5124] = {.lex_state = 117, .external_lex_state = 12},
  [5125] = {.lex_state = 117, .external_lex_state = 12},
  [5126] = {.lex_state = 117, .external_lex_state = 12},
  [5127] = {.lex_state = 117, .external_lex_state = 12},
  [5128] = {.lex_state = 117, .external_lex_state = 12},
  [5129] = {.lex_state = 117, .external_lex_state = 12},
  [5130] = {.lex_state = 117, .external_lex_state = 12},
  [5131] = {.lex_state = 117, .external_lex_state = 12},
  [5132] = {.lex_state = 117, .external_lex_state = 12},
  [5133] = {.lex_state = 117, .external_lex_state = 12},
  [5134] = {.lex_state = 117, .external_lex_state = 12},
  [5135] = {.lex_state = 117, .external_lex_state = 12},
  [5136] = {.lex_state = 117, .external_lex_state = 12},
  [5137] = {.lex_state = 117, .external_lex_state = 12},
  [5138] = {.lex_state = 117, .external_lex_state = 12},
  [5139] = {.lex_state = 117, .external_lex_state = 12},
  [5140] = {.lex_state = 117, .external_lex_state = 12},
  [5141] = {.lex_state = 117, .external_lex_state = 12},
  [5142] = {.lex_state = 117, .external_lex_state = 12},
  [5143] = {.lex_state = 117, .external_lex_state = 12},
  [5144] = {.lex_state = 117, .external_lex_state = 12},
  [5145] = {.lex_state = 117, .external_lex_state = 12},
  [5146] = {.lex_state = 117, .external_lex_state = 12},
  [5147] = {.lex_state = 117, .external_lex_state = 12},
  [5148] = {.lex_state = 117, .external_lex_state = 12},
  [5149] = {.lex_state = 117, .external_lex_state = 12},
  [5150] = {.lex_state = 117, .external_lex_state = 12},
  [5151] = {.lex_state = 117, .external_lex_state = 12},
  [5152] = {.lex_state = 117, .external_lex_state = 12},
  [5153] = {.lex_state = 117, .external_lex_state = 12},
  [5154] = {.lex_state = 117, .external_lex_state = 12},
  [5155] = {.lex_state = 117, .external_lex_state = 12},
  [5156] = {.lex_state = 117, .external_lex_state = 12},
  [5157] = {.lex_state = 117, .external_lex_state = 12},
  [5158] = {.lex_state = 117, .external_lex_state = 12},
  [5159] = {.lex_state = 117, .external_lex_state = 12},
  [5160] = {.lex_state = 117, .external_lex_state = 12},
  [5161] = {.lex_state = 117, .external_lex_state = 12},
  [5162] = {.lex_state = 117, .external_lex_state = 12},
  [5163] = {.lex_state = 117, .external_lex_state = 12},
  [5164] = {.lex_state = 117, .external_lex_state = 12},
  [5165] = {.lex_state = 117, .external_lex_state = 12},
  [5166] = {.lex_state = 117, .external_lex_state = 12},
  [5167] = {.lex_state = 117, .external_lex_state = 12},
  [5168] = {.lex_state = 117, .external_lex_state = 12},
  [5169] = {.lex_state = 117, .external_lex_state = 12},
  [5170] = {.lex_state = 117, .external_lex_state = 12},
  [5171] = {.lex_state = 117, .external_lex_state = 12},
  [5172] = {.lex_state = 117, .external_lex_state = 12},
  [5173] = {.lex_state = 117, .external_lex_state = 12},
  [5174] = {.lex_state = 117, .external_lex_state = 12},
  [5175] = {.lex_state = 117, .external_lex_state = 12},
  [5176] = {.lex_state = 117, .external_lex_state = 12},
  [5177] = {.lex_state = 117, .external_lex_state = 12},
  [5178] = {.lex_state = 117, .external_lex_state = 15},
  [5179] = {.lex_state = 117, .external_lex_state = 12},
  [5180] = {.lex_state = 117, .external_lex_state = 12},
  [5181] = {.lex_state = 117, .external_lex_state = 12},
  [5182] = {.lex_state = 117, .external_lex_state = 12},
  [5183] = {.lex_state = 117, .external_lex_state = 12},
  [5184] = {.lex_state = 117, .external_lex_state = 12},
  [5185] = {.lex_state = 117, .external_lex_state = 12},
  [5186] = {.lex_state = 117, .external_lex_state = 12},
  [5187] = {.lex_state = 117, .external_lex_state = 12},
  [5188] = {.lex_state = 117, .external_lex_state = 12},
  [5189] = {.lex_state = 117, .external_lex_state = 12},
  [5190] = {.lex_state = 117, .external_lex_state = 12},
  [5191] = {.lex_state = 117, .external_lex_state = 12},
  [5192] = {.lex_state = 117, .external_lex_state = 12},
  [5193] = {.lex_state = 117, .external_lex_state = 12},
  [5194] = {.lex_state = 117, .external_lex_state = 12},
  [5195] = {.lex_state = 117, .external_lex_state = 12},
  [5196] = {.lex_state = 117, .external_lex_state = 12},
  [5197] = {.lex_state = 117, .external_lex_state = 12},
  [5198] = {.lex_state = 117, .external_lex_state = 12},
  [5199] = {.lex_state = 117, .external_lex_state = 12},
  [5200] = {.lex_state = 117, .external_lex_state = 12},
  [5201] = {.lex_state = 117, .external_lex_state = 12},
  [5202] = {.lex_state = 117, .external_lex_state = 12},
  [5203] = {.lex_state = 117, .external_lex_state = 12},
  [5204] = {.lex_state = 117, .external_lex_state = 12},
  [5205] = {.lex_state = 117, .external_lex_state = 12},
  [5206] = {.lex_state = 117, .external_lex_state = 12},
  [5207] = {.lex_state = 117, .external_lex_state = 12},
  [5208] = {.lex_state = 117, .external_lex_state = 12},
  [5209] = {.lex_state = 117, .external_lex_state = 12},
  [5210] = {.lex_state = 117, .external_lex_state = 12},
  [5211] = {.lex_state = 117, .external_lex_state = 12},
  [5212] = {.lex_state = 117, .external_lex_state = 15},
  [5213] = {.lex_state = 117, .external_lex_state = 12},
  [5214] = {.lex_state = 117, .external_lex_state = 12},
  [5215] = {.lex_state = 117, .external_lex_state = 12},
  [5216] = {.lex_state = 117, .external_lex_state = 12},
  [5217] = {.lex_state = 117, .external_lex_state = 12},
  [5218] = {.lex_state = 117, .external_lex_state = 12},
  [5219] = {.lex_state = 117, .external_lex_state = 12},
  [5220] = {.lex_state = 117, .external_lex_state = 12},
  [5221] = {.lex_state = 117, .external_lex_state = 12},
  [5222] = {.lex_state = 117, .external_lex_state = 12},
  [5223] = {.lex_state = 117, .external_lex_state = 12},
  [5224] = {.lex_state = 117, .external_lex_state = 12},
  [5225] = {.lex_state = 117, .external_lex_state = 12},
  [5226] = {.lex_state = 117, .external_lex_state = 12},
  [5227] = {.lex_state = 117, .external_lex_state = 12},
  [5228] = {.lex_state = 117, .external_lex_state = 12},
  [5229] = {.lex_state = 117, .external_lex_state = 12},
  [5230] = {.lex_state = 117, .external_lex_state = 12},
  [5231] = {.lex_state = 117, .external_lex_state = 12},
  [5232] = {.lex_state = 117, .external_lex_state = 12},
  [5233] = {.lex_state = 117, .external_lex_state = 12},
  [5234] = {.lex_state = 117, .external_lex_state = 12},
  [5235] = {.lex_state = 117, .external_lex_state = 12},
  [5236] = {.lex_state = 117, .external_lex_state = 12},
  [5237] = {.lex_state = 117, .external_lex_state = 12},
  [5238] = {.lex_state = 117, .external_lex_state = 12},
  [5239] = {.lex_state = 117, .external_lex_state = 12},
  [5240] = {.lex_state = 117, .external_lex_state = 12},
  [5241] = {.lex_state = 117, .external_lex_state = 12},
  [5242] = {.lex_state = 117, .external_lex_state = 12},
  [5243] = {.lex_state = 117, .external_lex_state = 12},
  [5244] = {.lex_state = 117, .external_lex_state = 12},
  [5245] = {.lex_state = 117, .external_lex_state = 12},
  [5246] = {.lex_state = 117, .external_lex_state = 12},
  [5247] = {.lex_state = 117, .external_lex_state = 12},
  [5248] = {.lex_state = 117, .external_lex_state = 12},
  [5249] = {.lex_state = 117, .external_lex_state = 12},
  [5250] = {.lex_state = 117, .external_lex_state = 12},
  [5251] = {.lex_state = 117, .external_lex_state = 12},
  [5252] = {.lex_state = 117, .external_lex_state = 12},
  [5253] = {.lex_state = 117, .external_lex_state = 12},
  [5254] = {.lex_state = 117, .external_lex_state = 12},
  [5255] = {.lex_state = 117, .external_lex_state = 12},
  [5256] = {.lex_state = 117, .external_lex_state = 12},
  [5257] = {.lex_state = 117, .external_lex_state = 12},
  [5258] = {.lex_state = 117, .external_lex_state = 12},
  [5259] = {.lex_state = 117, .external_lex_state = 12},
  [5260] = {.lex_state = 117, .external_lex_state = 12},
  [5261] = {.lex_state = 117, .external_lex_state = 12},
  [5262] = {.lex_state = 117, .external_lex_state = 12},
  [5263] = {.lex_state = 117, .external_lex_state = 12},
  [5264] = {.lex_state = 117, .external_lex_state = 12},
  [5265] = {.lex_state = 117, .external_lex_state = 12},
  [5266] = {.lex_state = 117, .external_lex_state = 12},
  [5267] = {.lex_state = 117, .external_lex_state = 12},
  [5268] = {.lex_state = 117, .external_lex_state = 12},
  [5269] = {.lex_state = 117, .external_lex_state = 12},
  [5270] = {.lex_state = 117, .external_lex_state = 12},
  [5271] = {.lex_state = 117, .external_lex_state = 12},
  [5272] = {.lex_state = 117, .external_lex_state = 12},
  [5273] = {.lex_state = 117, .external_lex_state = 12},
  [5274] = {.lex_state = 117, .external_lex_state = 12},
  [5275] = {.lex_state = 117, .external_lex_state = 12},
  [5276] = {.lex_state = 117, .external_lex_state = 12},
  [5277] = {.lex_state = 117, .external_lex_state = 12},
  [5278] = {.lex_state = 117, .external_lex_state = 12},
  [5279] = {.lex_state = 117, .external_lex_state = 12},
  [5280] = {.lex_state = 117, .external_lex_state = 12},
  [5281] = {.lex_state = 117, .external_lex_state = 12},
  [5282] = {.lex_state = 117, .external_lex_state = 12},
  [5283] = {.lex_state = 117, .external_lex_state = 12},
  [5284] = {.lex_state = 117, .external_lex_state = 12},
  [5285] = {.lex_state = 117, .external_lex_state = 12},
  [5286] = {.lex_state = 117, .external_lex_state = 12},
  [5287] = {.lex_state = 117, .external_lex_state = 12},
  [5288] = {.lex_state = 117, .external_lex_state = 12},
  [5289] = {.lex_state = 117, .external_lex_state = 12},
  [5290] = {.lex_state = 117, .external_lex_state = 12},
  [5291] = {.lex_state = 117, .external_lex_state = 12},
  [5292] = {.lex_state = 117, .external_lex_state = 12},
  [5293] = {.lex_state = 117, .external_lex_state = 12},
  [5294] = {.lex_state = 117, .external_lex_state = 12},
  [5295] = {.lex_state = 117, .external_lex_state = 12},
  [5296] = {.lex_state = 117, .external_lex_state = 12},
  [5297] = {.lex_state = 117, .external_lex_state = 12},
  [5298] = {.lex_state = 117, .external_lex_state = 12},
  [5299] = {.lex_state = 117, .external_lex_state = 12},
  [5300] = {.lex_state = 117, .external_lex_state = 15},
  [5301] = {.lex_state = 117, .external_lex_state = 12},
  [5302] = {.lex_state = 117, .external_lex_state = 15},
  [5303] = {.lex_state = 117, .external_lex_state = 12},
  [5304] = {.lex_state = 117, .external_lex_state = 12},
  [5305] = {.lex_state = 117, .external_lex_state = 12},
  [5306] = {.lex_state = 117, .external_lex_state = 12},
  [5307] = {.lex_state = 117, .external_lex_state = 12},
  [5308] = {.lex_state = 117, .external_lex_state = 12},
  [5309] = {.lex_state = 117, .external_lex_state = 12},
  [5310] = {.lex_state = 117, .external_lex_state = 12},
  [5311] = {.lex_state = 117, .external_lex_state = 12},
  [5312] = {.lex_state = 117, .external_lex_state = 12},
  [5313] = {.lex_state = 117, .external_lex_state = 12},
  [5314] = {.lex_state = 117, .external_lex_state = 12},
  [5315] = {.lex_state = 117, .external_lex_state = 12},
  [5316] = {.lex_state = 117, .external_lex_state = 10},
  [5317] = {.lex_state = 117, .external_lex_state = 12},
  [5318] = {.lex_state = 117, .external_lex_state = 12},
  [5319] = {.lex_state = 117, .external_lex_state = 12},
  [5320] = {.lex_state = 117, .external_lex_state = 15},
  [5321] = {.lex_state = 117, .external_lex_state = 15},
  [5322] = {.lex_state = 117, .external_lex_state = 12},
  [5323] = {.lex_state = 117, .external_lex_state = 15},
  [5324] = {.lex_state = 117, .external_lex_state = 12},
  [5325] = {.lex_state = 117, .external_lex_state = 15},
  [5326] = {.lex_state = 9, .external_lex_state = 22},
  [5327] = {.lex_state = 117, .external_lex_state = 15},
  [5328] = {.lex_state = 117, .external_lex_state = 12},
  [5329] = {.lex_state = 117, .external_lex_state = 15},
  [5330] = {.lex_state = 117, .external_lex_state = 14},
  [5331] = {.lex_state = 117, .external_lex_state = 12},
  [5332] = {.lex_state = 117, .external_lex_state = 15},
  [5333] = {.lex_state = 117, .external_lex_state = 15},
  [5334] = {.lex_state = 117, .external_lex_state = 15},
  [5335] = {.lex_state = 10, .external_lex_state = 12},
  [5336] = {.lex_state = 117, .external_lex_state = 15},
  [5337] = {.lex_state = 117, .external_lex_state = 15},
  [5338] = {.lex_state = 117, .external_lex_state = 15},
  [5339] = {.lex_state = 117, .external_lex_state = 15},
  [5340] = {.lex_state = 117, .external_lex_state = 12},
  [5341] = {.lex_state = 117, .external_lex_state = 10},
  [5342] = {.lex_state = 117, .external_lex_state = 15},
  [5343] = {.lex_state = 117, .external_lex_state = 10},
  [5344] = {.lex_state = 117, .external_lex_state = 15},
  [5345] = {.lex_state = 117, .external_lex_state = 15},
  [5346] = {.lex_state = 9, .external_lex_state = 24},
  [5347] = {.lex_state = 117, .external_lex_state = 12},
  [5348] = {.lex_state = 117, .external_lex_state = 12},
  [5349] = {.lex_state = 117, .external_lex_state = 15},
  [5350] = {.lex_state = 117, .external_lex_state = 15},
  [5351] = {.lex_state = 117, .external_lex_state = 12},
  [5352] = {.lex_state = 117, .external_lex_state = 12},
  [5353] = {.lex_state = 117, .external_lex_state = 12},
  [5354] = {.lex_state = 117, .external_lex_state = 12},
  [5355] = {.lex_state = 117, .external_lex_state = 12},
  [5356] = {.lex_state = 117, .external_lex_state = 12},
  [5357] = {.lex_state = 117, .external_lex_state = 12},
  [5358] = {.lex_state = 9, .external_lex_state = 24},
  [5359] = {.lex_state = 117, .external_lex_state = 12},
  [5360] = {.lex_state = 117, .external_lex_state = 12},
  [5361] = {.lex_state = 117, .external_lex_state = 12},
  [5362] = {.lex_state = 117, .external_lex_state = 12},
  [5363] = {.lex_state = 117, .external_lex_state = 12},
  [5364] = {.lex_state = 117, .external_lex_state = 12},
  [5365] = {.lex_state = 117, .external_lex_state = 12},
  [5366] = {.lex_state = 117, .external_lex_state = 12},
  [5367] = {.lex_state = 117, .external_lex_state = 12},
  [5368] = {.lex_state = 117, .external_lex_state = 12},
  [5369] = {.lex_state = 117, .external_lex_state = 12},
  [5370] = {.lex_state = 117, .external_lex_state = 12},
  [5371] = {.lex_state = 117, .external_lex_state = 14},
  [5372] = {.lex_state = 117, .external_lex_state = 12},
  [5373] = {.lex_state = 117, .external_lex_state = 12},
  [5374] = {.lex_state = 117, .external_lex_state = 12},
  [5375] = {.lex_state = 117, .external_lex_state = 12},
  [5376] = {.lex_state = 117, .external_lex_state = 12},
  [5377] = {.lex_state = 117, .external_lex_state = 12},
  [5378] = {.lex_state = 117, .external_lex_state = 12},
  [5379] = {.lex_state = 117, .external_lex_state = 12},
  [5380] = {.lex_state = 117, .external_lex_state = 12},
  [5381] = {.lex_state = 117, .external_lex_state = 12},
  [5382] = {.lex_state = 117, .external_lex_state = 12},
  [5383] = {.lex_state = 117, .external_lex_state = 12},
  [5384] = {.lex_state = 117, .external_lex_state = 12},
  [5385] = {.lex_state = 117, .external_lex_state = 12},
  [5386] = {.lex_state = 117, .external_lex_state = 12},
  [5387] = {.lex_state = 117, .external_lex_state = 12},
  [5388] = {.lex_state = 117, .external_lex_state = 12},
  [5389] = {.lex_state = 117, .external_lex_state = 12},
  [5390] = {.lex_state = 117, .external_lex_state = 12},
  [5391] = {.lex_state = 117, .external_lex_state = 12},
  [5392] = {.lex_state = 117, .external_lex_state = 12},
  [5393] = {.lex_state = 117, .external_lex_state = 12},
  [5394] = {.lex_state = 117, .external_lex_state = 12},
  [5395] = {.lex_state = 117, .external_lex_state = 12},
  [5396] = {.lex_state = 117, .external_lex_state = 12},
  [5397] = {.lex_state = 117, .external_lex_state = 12},
  [5398] = {.lex_state = 117, .external_lex_state = 12},
  [5399] = {.lex_state = 117, .external_lex_state = 12},
  [5400] = {.lex_state = 117, .external_lex_state = 12},
  [5401] = {.lex_state = 117, .external_lex_state = 12},
  [5402] = {.lex_state = 117, .external_lex_state = 12},
  [5403] = {.lex_state = 117, .external_lex_state = 12},
  [5404] = {.lex_state = 117, .external_lex_state = 12},
  [5405] = {.lex_state = 117, .external_lex_state = 12},
  [5406] = {.lex_state = 117, .external_lex_state = 12},
  [5407] = {.lex_state = 117, .external_lex_state = 12},
  [5408] = {.lex_state = 117, .external_lex_state = 12},
  [5409] = {.lex_state = 117, .external_lex_state = 12},
  [5410] = {.lex_state = 117, .external_lex_state = 12},
  [5411] = {.lex_state = 117, .external_lex_state = 12},
  [5412] = {.lex_state = 117},
  [5413] = {.lex_state = 117, .external_lex_state = 12},
  [5414] = {.lex_state = 117, .external_lex_state = 12},
  [5415] = {.lex_state = 117, .external_lex_state = 12},
  [5416] = {.lex_state = 117},
  [5417] = {.lex_state = 117},
  [5418] = {.lex_state = 117},
  [5419] = {.lex_state = 117, .external_lex_state = 15},
  [5420] = {.lex_state = 117, .external_lex_state = 15},
  [5421] = {.lex_state = 9, .external_lex_state = 24},
  [5422] = {.lex_state = 117},
  [5423] = {.lex_state = 117},
  [5424] = {.lex_state = 117},
  [5425] = {.lex_state = 117},
  [5426] = {.lex_state = 117},
  [5427] = {.lex_state = 117},
  [5428] = {.lex_state = 117},
  [5429] = {.lex_state = 117},
  [5430] = {.lex_state = 117, .external_lex_state = 15},
  [5431] = {.lex_state = 117, .external_lex_state = 15},
  [5432] = {.lex_state = 117},
  [5433] = {.lex_state = 117, .external_lex_state = 15},
  [5434] = {.lex_state = 117},
  [5435] = {.lex_state = 117, .external_lex_state = 15},
  [5436] = {.lex_state = 117, .external_lex_state = 15},
  [5437] = {.lex_state = 117, .external_lex_state = 15},
  [5438] = {.lex_state = 117, .external_lex_state = 15},
  [5439] = {.lex_state = 10, .external_lex_state = 15},
  [5440] = {.lex_state = 117, .external_lex_state = 15},
  [5441] = {.lex_state = 117, .external_lex_state = 15},
  [5442] = {.lex_state = 117, .external_lex_state = 15},
  [5443] = {.lex_state = 117, .external_lex_state = 15},
  [5444] = {.lex_state = 117, .external_lex_state = 15},
  [5445] = {.lex_state = 117, .external_lex_state = 15},
  [5446] = {.lex_state = 117, .external_lex_state = 15},
  [5447] = {.lex_state = 10, .external_lex_state = 15},
  [5448] = {.lex_state = 117, .external_lex_state = 15},
  [5449] = {.lex_state = 117, .external_lex_state = 15},
  [5450] = {.lex_state = 117, .external_lex_state = 15},
  [5451] = {.lex_state = 117, .external_lex_state = 15},
  [5452] = {.lex_state = 10, .external_lex_state = 15},
  [5453] = {.lex_state = 117, .external_lex_state = 15},
  [5454] = {.lex_state = 117, .external_lex_state = 15},
  [5455] = {.lex_state = 117, .external_lex_state = 15},
  [5456] = {.lex_state = 117, .external_lex_state = 15},
  [5457] = {.lex_state = 117, .external_lex_state = 15},
  [5458] = {.lex_state = 117, .external_lex_state = 15},
  [5459] = {.lex_state = 117, .external_lex_state = 15},
  [5460] = {.lex_state = 117, .external_lex_state = 15},
  [5461] = {.lex_state = 117, .external_lex_state = 15},
  [5462] = {.lex_state = 117, .external_lex_state = 15},
  [5463] = {.lex_state = 117, .external_lex_state = 15},
  [5464] = {.lex_state = 117, .external_lex_state = 15},
  [5465] = {.lex_state = 117, .external_lex_state = 15},
  [5466] = {.lex_state = 117, .external_lex_state = 15},
  [5467] = {.lex_state = 117, .external_lex_state = 15},
  [5468] = {.lex_state = 117, .external_lex_state = 15},
  [5469] = {.lex_state = 117, .external_lex_state = 15},
  [5470] = {.lex_state = 117, .external_lex_state = 15},
  [5471] = {.lex_state = 117, .external_lex_state = 15},
  [5472] = {.lex_state = 117, .external_lex_state = 15},
  [5473] = {.lex_state = 117, .external_lex_state = 15},
  [5474] = {.lex_state = 117, .external_lex_state = 15},
  [5475] = {.lex_state = 117, .external_lex_state = 15},
  [5476] = {.lex_state = 117, .external_lex_state = 15},
  [5477] = {.lex_state = 117, .external_lex_state = 15},
  [5478] = {.lex_state = 117, .external_lex_state = 15},
  [5479] = {.lex_state = 117, .external_lex_state = 15},
  [5480] = {.lex_state = 117, .external_lex_state = 15},
  [5481] = {.lex_state = 117, .external_lex_state = 23},
  [5482] = {.lex_state = 117, .external_lex_state = 23},
  [5483] = {.lex_state = 117, .external_lex_state = 23},
  [5484] = {.lex_state = 117, .external_lex_state = 23},
  [5485] = {.lex_state = 117, .external_lex_state = 15},
  [5486] = {.lex_state = 117, .external_lex_state = 15},
  [5487] = {.lex_state = 117, .external_lex_state = 15},
  [5488] = {.lex_state = 117, .external_lex_state = 15},
  [5489] = {.lex_state = 117, .external_lex_state = 15},
  [5490] = {.lex_state = 117, .external_lex_state = 15},
  [5491] = {.lex_state = 117, .external_lex_state = 15},
  [5492] = {.lex_state = 117, .external_lex_state = 15},
  [5493] = {.lex_state = 117, .external_lex_state = 15},
  [5494] = {.lex_state = 117, .external_lex_state = 15},
  [5495] = {.lex_state = 117, .external_lex_state = 15},
  [5496] = {.lex_state = 117, .external_lex_state = 15},
  [5497] = {.lex_state = 117, .external_lex_state = 15},
  [5498] = {.lex_state = 117, .external_lex_state = 15},
  [5499] = {.lex_state = 117, .external_lex_state = 15},
  [5500] = {.lex_state = 117, .external_lex_state = 15},
  [5501] = {.lex_state = 117, .external_lex_state = 15},
  [5502] = {.lex_state = 117, .external_lex_state = 15},
  [5503] = {.lex_state = 117, .external_lex_state = 15},
  [5504] = {.lex_state = 117, .external_lex_state = 15},
  [5505] = {.lex_state = 117, .external_lex_state = 15},
  [5506] = {.lex_state = 117, .external_lex_state = 15},
  [5507] = {.lex_state = 117, .external_lex_state = 15},
  [5508] = {.lex_state = 117, .external_lex_state = 15},
  [5509] = {.lex_state = 117, .external_lex_state = 23},
  [5510] = {.lex_state = 117, .external_lex_state = 15},
  [5511] = {.lex_state = 117, .external_lex_state = 15},
  [5512] = {.lex_state = 117, .external_lex_state = 15},
  [5513] = {.lex_state = 117, .external_lex_state = 15},
  [5514] = {.lex_state = 117, .external_lex_state = 15},
  [5515] = {.lex_state = 117, .external_lex_state = 15},
  [5516] = {.lex_state = 117, .external_lex_state = 15},
  [5517] = {.lex_state = 117, .external_lex_state = 15},
  [5518] = {.lex_state = 117, .external_lex_state = 23},
  [5519] = {.lex_state = 117, .external_lex_state = 15},
  [5520] = {.lex_state = 117, .external_lex_state = 15},
  [5521] = {.lex_state = 117, .external_lex_state = 15},
  [5522] = {.lex_state = 117, .external_lex_state = 15},
  [5523] = {.lex_state = 117, .external_lex_state = 15},
  [5524] = {.lex_state = 10, .external_lex_state = 15},
  [5525] = {.lex_state = 117, .external_lex_state = 15},
  [5526] = {.lex_state = 117, .external_lex_state = 15},
  [5527] = {.lex_state = 117, .external_lex_state = 15},
  [5528] = {.lex_state = 117, .external_lex_state = 15},
  [5529] = {.lex_state = 117, .external_lex_state = 23},
  [5530] = {.lex_state = 117, .external_lex_state = 15},
  [5531] = {.lex_state = 117, .external_lex_state = 23},
  [5532] = {.lex_state = 117, .external_lex_state = 15},
  [5533] = {.lex_state = 117, .external_lex_state = 15},
  [5534] = {.lex_state = 117, .external_lex_state = 15},
  [5535] = {.lex_state = 117, .external_lex_state = 15},
  [5536] = {.lex_state = 117, .external_lex_state = 15},
  [5537] = {.lex_state = 117, .external_lex_state = 15},
  [5538] = {.lex_state = 117, .external_lex_state = 23},
  [5539] = {.lex_state = 117, .external_lex_state = 15},
  [5540] = {.lex_state = 117, .external_lex_state = 23},
  [5541] = {.lex_state = 117, .external_lex_state = 15},
  [5542] = {.lex_state = 117, .external_lex_state = 15},
  [5543] = {.lex_state = 117, .external_lex_state = 15},
  [5544] = {.lex_state = 117, .external_lex_state = 23},
  [5545] = {.lex_state = 117, .external_lex_state = 23},
  [5546] = {.lex_state = 117, .external_lex_state = 15},
  [5547] = {.lex_state = 117, .external_lex_state = 15},
  [5548] = {.lex_state = 117, .external_lex_state = 15},
  [5549] = {.lex_state = 117, .external_lex_state = 15},
  [5550] = {.lex_state = 117, .external_lex_state = 23},
  [5551] = {.lex_state = 117, .external_lex_state = 23},
  [5552] = {.lex_state = 117, .external_lex_state = 23},
  [5553] = {.lex_state = 117, .external_lex_state = 15},
  [5554] = {.lex_state = 117, .external_lex_state = 15},
  [5555] = {.lex_state = 117, .external_lex_state = 15},
  [5556] = {.lex_state = 117, .external_lex_state = 15},
  [5557] = {.lex_state = 117, .external_lex_state = 15},
  [5558] = {.lex_state = 117, .external_lex_state = 15},
  [5559] = {.lex_state = 117, .external_lex_state = 15},
  [5560] = {.lex_state = 117, .external_lex_state = 15},
  [5561] = {.lex_state = 117, .external_lex_state = 15},
  [5562] = {.lex_state = 117, .external_lex_state = 15},
  [5563] = {.lex_state = 117, .external_lex_state = 15},
  [5564] = {.lex_state = 117, .external_lex_state = 15},
  [5565] = {.lex_state = 117, .external_lex_state = 15},
  [5566] = {.lex_state = 117, .external_lex_state = 15},
  [5567] = {.lex_state = 117, .external_lex_state = 15},
  [5568] = {.lex_state = 117, .external_lex_state = 15},
  [5569] = {.lex_state = 117, .external_lex_state = 15},
  [5570] = {.lex_state = 117, .external_lex_state = 15},
  [5571] = {.lex_state = 117, .external_lex_state = 15},
  [5572] = {.lex_state = 117, .external_lex_state = 15},
  [5573] = {.lex_state = 117, .external_lex_state = 15},
  [5574] = {.lex_state = 117, .external_lex_state = 15},
  [5575] = {.lex_state = 117, .external_lex_state = 15},
  [5576] = {.lex_state = 117, .external_lex_state = 15},
  [5577] = {.lex_state = 10, .external_lex_state = 15},
  [5578] = {.lex_state = 117, .external_lex_state = 15},
  [5579] = {.lex_state = 117, .external_lex_state = 23},
  [5580] = {.lex_state = 117, .external_lex_state = 23},
  [5581] = {.lex_state = 117, .external_lex_state = 23},
  [5582] = {.lex_state = 117, .external_lex_state = 15},
  [5583] = {.lex_state = 117, .external_lex_state = 23},
  [5584] = {.lex_state = 117, .external_lex_state = 23},
  [5585] = {.lex_state = 117, .external_lex_state = 23},
  [5586] = {.lex_state = 117, .external_lex_state = 23},
  [5587] = {.lex_state = 117, .external_lex_state = 15},
  [5588] = {.lex_state = 117, .external_lex_state = 23},
  [5589] = {.lex_state = 117, .external_lex_state = 15},
  [5590] = {.lex_state = 117, .external_lex_state = 23},
  [5591] = {.lex_state = 117, .external_lex_state = 15},
  [5592] = {.lex_state = 117, .external_lex_state = 23},
  [5593] = {.lex_state = 117, .external_lex_state = 15},
  [5594] = {.lex_state = 117, .external_lex_state = 15},
  [5595] = {.lex_state = 117, .external_lex_state = 15},
  [5596] = {.lex_state = 117, .external_lex_state = 15},
  [5597] = {.lex_state = 117, .external_lex_state = 15},
  [5598] = {.lex_state = 117, .external_lex_state = 15},
  [5599] = {.lex_state = 117, .external_lex_state = 23},
  [5600] = {.lex_state = 117, .external_lex_state = 15},
  [5601] = {.lex_state = 117, .external_lex_state = 15},
  [5602] = {.lex_state = 117, .external_lex_state = 15},
  [5603] = {.lex_state = 117, .external_lex_state = 15},
  [5604] = {.lex_state = 117, .external_lex_state = 15},
  [5605] = {.lex_state = 117, .external_lex_state = 15},
  [5606] = {.lex_state = 117, .external_lex_state = 15},
  [5607] = {.lex_state = 117, .external_lex_state = 15},
  [5608] = {.lex_state = 117, .external_lex_state = 15},
  [5609] = {.lex_state = 117, .external_lex_state = 15},
  [5610] = {.lex_state = 117, .external_lex_state = 23},
  [5611] = {.lex_state = 117, .external_lex_state = 15},
  [5612] = {.lex_state = 117, .external_lex_state = 23},
  [5613] = {.lex_state = 117, .external_lex_state = 15},
  [5614] = {.lex_state = 117, .external_lex_state = 15},
  [5615] = {.lex_state = 117, .external_lex_state = 15},
  [5616] = {.lex_state = 117, .external_lex_state = 15},
  [5617] = {.lex_state = 117, .external_lex_state = 23},
  [5618] = {.lex_state = 117, .external_lex_state = 23},
  [5619] = {.lex_state = 117, .external_lex_state = 15},
  [5620] = {.lex_state = 117, .external_lex_state = 15},
  [5621] = {.lex_state = 117, .external_lex_state = 15},
  [5622] = {.lex_state = 117, .external_lex_state = 23},
  [5623] = {.lex_state = 117, .external_lex_state = 15},
  [5624] = {.lex_state = 117, .external_lex_state = 23},
  [5625] = {.lex_state = 117, .external_lex_state = 23},
  [5626] = {.lex_state = 117, .external_lex_state = 15},
  [5627] = {.lex_state = 117, .external_lex_state = 15},
  [5628] = {.lex_state = 117, .external_lex_state = 15},
  [5629] = {.lex_state = 117, .external_lex_state = 15},
  [5630] = {.lex_state = 117, .external_lex_state = 15},
  [5631] = {.lex_state = 117, .external_lex_state = 15},
  [5632] = {.lex_state = 117, .external_lex_state = 15},
  [5633] = {.lex_state = 117, .external_lex_state = 15},
  [5634] = {.lex_state = 117, .external_lex_state = 15},
  [5635] = {.lex_state = 117, .external_lex_state = 15},
  [5636] = {.lex_state = 117, .external_lex_state = 23},
  [5637] = {.lex_state = 117, .external_lex_state = 15},
  [5638] = {.lex_state = 117, .external_lex_state = 15},
  [5639] = {.lex_state = 117, .external_lex_state = 15},
  [5640] = {.lex_state = 117, .external_lex_state = 15},
  [5641] = {.lex_state = 117, .external_lex_state = 15},
  [5642] = {.lex_state = 117, .external_lex_state = 15},
  [5643] = {.lex_state = 117, .external_lex_state = 15},
  [5644] = {.lex_state = 117, .external_lex_state = 15},
  [5645] = {.lex_state = 117, .external_lex_state = 15},
  [5646] = {.lex_state = 117, .external_lex_state = 15},
  [5647] = {.lex_state = 117, .external_lex_state = 15},
  [5648] = {.lex_state = 117, .external_lex_state = 15},
  [5649] = {.lex_state = 117, .external_lex_state = 15},
  [5650] = {.lex_state = 117, .external_lex_state = 15},
  [5651] = {.lex_state = 117, .external_lex_state = 15},
  [5652] = {.lex_state = 117, .external_lex_state = 15},
  [5653] = {.lex_state = 117, .external_lex_state = 15},
  [5654] = {.lex_state = 117, .external_lex_state = 15},
  [5655] = {.lex_state = 117, .external_lex_state = 15},
  [5656] = {.lex_state = 117, .external_lex_state = 15},
  [5657] = {.lex_state = 117, .external_lex_state = 15},
  [5658] = {.lex_state = 117, .external_lex_state = 15},
  [5659] = {.lex_state = 117, .external_lex_state = 15},
  [5660] = {.lex_state = 117, .external_lex_state = 15},
  [5661] = {.lex_state = 117, .external_lex_state = 15},
  [5662] = {.lex_state = 117, .external_lex_state = 15},
  [5663] = {.lex_state = 117, .external_lex_state = 15},
  [5664] = {.lex_state = 117, .external_lex_state = 15},
  [5665] = {.lex_state = 117, .external_lex_state = 15},
  [5666] = {.lex_state = 117, .external_lex_state = 15},
  [5667] = {.lex_state = 117, .external_lex_state = 15},
  [5668] = {.lex_state = 117, .external_lex_state = 15},
  [5669] = {.lex_state = 117, .external_lex_state = 23},
  [5670] = {.lex_state = 117, .external_lex_state = 15},
  [5671] = {.lex_state = 117, .external_lex_state = 15},
  [5672] = {.lex_state = 117, .external_lex_state = 15},
  [5673] = {.lex_state = 117, .external_lex_state = 15},
  [5674] = {.lex_state = 117, .external_lex_state = 15},
  [5675] = {.lex_state = 117, .external_lex_state = 15},
  [5676] = {.lex_state = 117, .external_lex_state = 15},
  [5677] = {.lex_state = 117, .external_lex_state = 15},
  [5678] = {.lex_state = 117, .external_lex_state = 15},
  [5679] = {.lex_state = 117, .external_lex_state = 23},
  [5680] = {.lex_state = 117, .external_lex_state = 15},
  [5681] = {.lex_state = 117, .external_lex_state = 15},
  [5682] = {.lex_state = 117, .external_lex_state = 15},
  [5683] = {.lex_state = 117, .external_lex_state = 15},
  [5684] = {.lex_state = 117, .external_lex_state = 15},
  [5685] = {.lex_state = 117, .external_lex_state = 15},
  [5686] = {.lex_state = 117, .external_lex_state = 15},
  [5687] = {.lex_state = 117, .external_lex_state = 15},
  [5688] = {.lex_state = 117, .external_lex_state = 15},
  [5689] = {.lex_state = 117, .external_lex_state = 15},
  [5690] = {.lex_state = 117, .external_lex_state = 15},
  [5691] = {.lex_state = 117, .external_lex_state = 15},
  [5692] = {.lex_state = 117, .external_lex_state = 15},
  [5693] = {.lex_state = 117, .external_lex_state = 23},
  [5694] = {.lex_state = 117, .external_lex_state = 15},
  [5695] = {.lex_state = 117, .external_lex_state = 15},
  [5696] = {.lex_state = 117, .external_lex_state = 15},
  [5697] = {.lex_state = 117, .external_lex_state = 23},
  [5698] = {.lex_state = 117, .external_lex_state = 15},
  [5699] = {.lex_state = 117, .external_lex_state = 15},
  [5700] = {.lex_state = 117, .external_lex_state = 15},
  [5701] = {.lex_state = 117, .external_lex_state = 15},
  [5702] = {.lex_state = 117, .external_lex_state = 15},
  [5703] = {.lex_state = 117, .external_lex_state = 15},
  [5704] = {.lex_state = 117, .external_lex_state = 15},
  [5705] = {.lex_state = 117, .external_lex_state = 23},
  [5706] = {.lex_state = 117, .external_lex_state = 15},
  [5707] = {.lex_state = 117, .external_lex_state = 23},
  [5708] = {.lex_state = 117, .external_lex_state = 23},
  [5709] = {.lex_state = 117, .external_lex_state = 15},
  [5710] = {.lex_state = 117, .external_lex_state = 15},
  [5711] = {.lex_state = 117, .external_lex_state = 15},
  [5712] = {.lex_state = 117, .external_lex_state = 23},
  [5713] = {.lex_state = 117, .external_lex_state = 15},
  [5714] = {.lex_state = 117, .external_lex_state = 15},
  [5715] = {.lex_state = 117, .external_lex_state = 15},
  [5716] = {.lex_state = 117, .external_lex_state = 15},
  [5717] = {.lex_state = 117, .external_lex_state = 15},
  [5718] = {.lex_state = 117, .external_lex_state = 15},
  [5719] = {.lex_state = 117, .external_lex_state = 23},
  [5720] = {.lex_state = 117, .external_lex_state = 15},
  [5721] = {.lex_state = 117, .external_lex_state = 15},
  [5722] = {.lex_state = 117, .external_lex_state = 15},
  [5723] = {.lex_state = 117, .external_lex_state = 15},
  [5724] = {.lex_state = 117, .external_lex_state = 15},
  [5725] = {.lex_state = 117, .external_lex_state = 15},
  [5726] = {.lex_state = 117, .external_lex_state = 15},
  [5727] = {.lex_state = 117, .external_lex_state = 23},
  [5728] = {.lex_state = 117, .external_lex_state = 23},
  [5729] = {.lex_state = 117, .external_lex_state = 15},
  [5730] = {.lex_state = 117, .external_lex_state = 15},
  [5731] = {.lex_state = 117, .external_lex_state = 15},
  [5732] = {.lex_state = 117, .external_lex_state = 15},
  [5733] = {.lex_state = 117, .external_lex_state = 15},
  [5734] = {.lex_state = 117, .external_lex_state = 15},
  [5735] = {.lex_state = 117, .external_lex_state = 15},
  [5736] = {.lex_state = 117, .external_lex_state = 23},
  [5737] = {.lex_state = 117, .external_lex_state = 15},
  [5738] = {.lex_state = 117, .external_lex_state = 15},
  [5739] = {.lex_state = 117, .external_lex_state = 15},
  [5740] = {.lex_state = 117, .external_lex_state = 23},
  [5741] = {.lex_state = 117, .external_lex_state = 23},
  [5742] = {.lex_state = 117, .external_lex_state = 15},
  [5743] = {.lex_state = 117, .external_lex_state = 23},
  [5744] = {.lex_state = 117, .external_lex_state = 23},
  [5745] = {.lex_state = 117, .external_lex_state = 15},
  [5746] = {.lex_state = 117, .external_lex_state = 15},
  [5747] = {.lex_state = 117, .external_lex_state = 15},
  [5748] = {.lex_state = 117, .external_lex_state = 15},
  [5749] = {.lex_state = 117, .external_lex_state = 15},
  [5750] = {.lex_state = 117, .external_lex_state = 15},
  [5751] = {.lex_state = 117, .external_lex_state = 15},
  [5752] = {.lex_state = 117, .external_lex_state = 15},
  [5753] = {.lex_state = 117, .external_lex_state = 15},
  [5754] = {.lex_state = 117, .external_lex_state = 15},
  [5755] = {.lex_state = 117, .external_lex_state = 15},
  [5756] = {.lex_state = 117, .external_lex_state = 15},
  [5757] = {.lex_state = 117, .external_lex_state = 15},
  [5758] = {.lex_state = 117, .external_lex_state = 15},
  [5759] = {.lex_state = 117, .external_lex_state = 23},
  [5760] = {.lex_state = 117, .external_lex_state = 15},
  [5761] = {.lex_state = 117, .external_lex_state = 15},
  [5762] = {.lex_state = 117, .external_lex_state = 23},
  [5763] = {.lex_state = 117, .external_lex_state = 23},
  [5764] = {.lex_state = 117, .external_lex_state = 15},
  [5765] = {.lex_state = 117, .external_lex_state = 15},
  [5766] = {.lex_state = 117, .external_lex_state = 15},
  [5767] = {.lex_state = 117, .external_lex_state = 23},
  [5768] = {.lex_state = 117, .external_lex_state = 15},
  [5769] = {.lex_state = 117, .external_lex_state = 15},
  [5770] = {.lex_state = 117, .external_lex_state = 15},
  [5771] = {.lex_state = 117, .external_lex_state = 15},
  [5772] = {.lex_state = 117, .external_lex_state = 23},
  [5773] = {.lex_state = 117, .external_lex_state = 23},
  [5774] = {.lex_state = 117, .external_lex_state = 23},
  [5775] = {.lex_state = 117, .external_lex_state = 15},
  [5776] = {.lex_state = 117, .external_lex_state = 15},
  [5777] = {.lex_state = 117, .external_lex_state = 15},
  [5778] = {.lex_state = 117, .external_lex_state = 15},
  [5779] = {.lex_state = 117, .external_lex_state = 15},
  [5780] = {.lex_state = 117, .external_lex_state = 15},
  [5781] = {.lex_state = 117, .external_lex_state = 15},
  [5782] = {.lex_state = 117, .external_lex_state = 15},
  [5783] = {.lex_state = 117, .external_lex_state = 15},
  [5784] = {.lex_state = 117, .external_lex_state = 15},
  [5785] = {.lex_state = 117, .external_lex_state = 23},
  [5786] = {.lex_state = 117, .external_lex_state = 15},
  [5787] = {.lex_state = 117, .external_lex_state = 15},
  [5788] = {.lex_state = 117, .external_lex_state = 15},
  [5789] = {.lex_state = 117, .external_lex_state = 15},
  [5790] = {.lex_state = 117, .external_lex_state = 15},
  [5791] = {.lex_state = 117, .external_lex_state = 15},
  [5792] = {.lex_state = 117, .external_lex_state = 15},
  [5793] = {.lex_state = 117, .external_lex_state = 23},
  [5794] = {.lex_state = 117, .external_lex_state = 15},
  [5795] = {.lex_state = 117, .external_lex_state = 15},
  [5796] = {.lex_state = 117, .external_lex_state = 15},
  [5797] = {.lex_state = 117, .external_lex_state = 15},
  [5798] = {.lex_state = 117, .external_lex_state = 15},
  [5799] = {.lex_state = 117, .external_lex_state = 15},
  [5800] = {.lex_state = 117, .external_lex_state = 15},
  [5801] = {.lex_state = 117, .external_lex_state = 15},
  [5802] = {.lex_state = 117, .external_lex_state = 15},
  [5803] = {.lex_state = 117, .external_lex_state = 15},
  [5804] = {.lex_state = 117, .external_lex_state = 15},
  [5805] = {.lex_state = 117, .external_lex_state = 15},
  [5806] = {.lex_state = 117, .external_lex_state = 15},
  [5807] = {.lex_state = 117, .external_lex_state = 15},
  [5808] = {.lex_state = 117, .external_lex_state = 15},
  [5809] = {.lex_state = 117, .external_lex_state = 15},
  [5810] = {.lex_state = 117, .external_lex_state = 15},
  [5811] = {.lex_state = 117, .external_lex_state = 15},
  [5812] = {.lex_state = 117, .external_lex_state = 15},
  [5813] = {.lex_state = 117, .external_lex_state = 15},
  [5814] = {.lex_state = 117, .external_lex_state = 15},
  [5815] = {.lex_state = 117, .external_lex_state = 15},
  [5816] = {.lex_state = 117, .external_lex_state = 15},
  [5817] = {.lex_state = 117, .external_lex_state = 15},
  [5818] = {.lex_state = 117, .external_lex_state = 23},
  [5819] = {.lex_state = 117, .external_lex_state = 15},
  [5820] = {.lex_state = 117, .external_lex_state = 15},
  [5821] = {.lex_state = 117, .external_lex_state = 15},
  [5822] = {.lex_state = 117, .external_lex_state = 15},
  [5823] = {.lex_state = 117, .external_lex_state = 15},
  [5824] = {.lex_state = 117, .external_lex_state = 15},
  [5825] = {.lex_state = 117, .external_lex_state = 15},
  [5826] = {.lex_state = 117, .external_lex_state = 15},
  [5827] = {.lex_state = 117, .external_lex_state = 15},
  [5828] = {.lex_state = 117, .external_lex_state = 15},
  [5829] = {.lex_state = 117, .external_lex_state = 15},
  [5830] = {.lex_state = 117, .external_lex_state = 15},
  [5831] = {.lex_state = 117, .external_lex_state = 15},
  [5832] = {.lex_state = 117, .external_lex_state = 15},
  [5833] = {.lex_state = 117, .external_lex_state = 15},
  [5834] = {.lex_state = 117, .external_lex_state = 15},
  [5835] = {.lex_state = 117, .external_lex_state = 15},
  [5836] = {.lex_state = 117, .external_lex_state = 15},
  [5837] = {.lex_state = 117, .external_lex_state = 15},
  [5838] = {.lex_state = 117, .external_lex_state = 15},
  [5839] = {.lex_state = 117, .external_lex_state = 15},
  [5840] = {.lex_state = 117, .external_lex_state = 15},
  [5841] = {.lex_state = 117, .external_lex_state = 15},
  [5842] = {.lex_state = 117, .external_lex_state = 15},
  [5843] = {.lex_state = 117, .external_lex_state = 15},
  [5844] = {.lex_state = 117, .external_lex_state = 15},
  [5845] = {.lex_state = 117, .external_lex_state = 15},
  [5846] = {.lex_state = 117, .external_lex_state = 15},
  [5847] = {.lex_state = 117, .external_lex_state = 15},
  [5848] = {.lex_state = 117, .external_lex_state = 15},
  [5849] = {.lex_state = 117, .external_lex_state = 15},
  [5850] = {.lex_state = 117, .external_lex_state = 15},
  [5851] = {.lex_state = 117, .external_lex_state = 23},
  [5852] = {.lex_state = 117, .external_lex_state = 15},
  [5853] = {.lex_state = 117, .external_lex_state = 15},
  [5854] = {.lex_state = 117, .external_lex_state = 15},
  [5855] = {.lex_state = 117, .external_lex_state = 15},
  [5856] = {.lex_state = 117, .external_lex_state = 15},
  [5857] = {.lex_state = 117, .external_lex_state = 15},
  [5858] = {.lex_state = 117, .external_lex_state = 17},
  [5859] = {.lex_state = 117, .external_lex_state = 12},
  [5860] = {.lex_state = 117, .external_lex_state = 17},
  [5861] = {.lex_state = 117, .external_lex_state = 17},
  [5862] = {.lex_state = 117, .external_lex_state = 17},
  [5863] = {.lex_state = 117, .external_lex_state = 15},
  [5864] = {.lex_state = 117, .external_lex_state = 17},
  [5865] = {.lex_state = 117, .external_lex_state = 12},
  [5866] = {.lex_state = 117, .external_lex_state = 12},
  [5867] = {.lex_state = 117, .external_lex_state = 15},
  [5868] = {.lex_state = 117, .external_lex_state = 17},
  [5869] = {.lex_state = 117, .external_lex_state = 17},
  [5870] = {.lex_state = 117, .external_lex_state = 17},
  [5871] = {.lex_state = 117, .external_lex_state = 17},
  [5872] = {.lex_state = 117, .external_lex_state = 17},
  [5873] = {.lex_state = 117, .external_lex_state = 17},
  [5874] = {.lex_state = 117, .external_lex_state = 12},
  [5875] = {.lex_state = 117, .external_lex_state = 17},
  [5876] = {.lex_state = 117, .external_lex_state = 17},
  [5877] = {.lex_state = 117, .external_lex_state = 17},
  [5878] = {.lex_state = 117, .external_lex_state = 17},
  [5879] = {.lex_state = 117, .external_lex_state = 17},
  [5880] = {.lex_state = 117, .external_lex_state = 17},
  [5881] = {.lex_state = 117, .external_lex_state = 17},
  [5882] = {.lex_state = 117, .external_lex_state = 17},
  [5883] = {.lex_state = 117, .external_lex_state = 17},
  [5884] = {.lex_state = 117, .external_lex_state = 17},
  [5885] = {.lex_state = 117, .external_lex_state = 17},
  [5886] = {.lex_state = 117, .external_lex_state = 17},
  [5887] = {.lex_state = 117, .external_lex_state = 17},
  [5888] = {.lex_state = 117, .external_lex_state = 17},
  [5889] = {.lex_state = 117, .external_lex_state = 17},
  [5890] = {.lex_state = 117, .external_lex_state = 17},
  [5891] = {.lex_state = 117, .external_lex_state = 17},
  [5892] = {.lex_state = 117, .external_lex_state = 15},
  [5893] = {.lex_state = 117, .external_lex_state = 15},
  [5894] = {.lex_state = 117, .external_lex_state = 17},
  [5895] = {.lex_state = 117, .external_lex_state = 17},
  [5896] = {.lex_state = 117, .external_lex_state = 17},
  [5897] = {.lex_state = 117, .external_lex_state = 17},
  [5898] = {.lex_state = 117, .external_lex_state = 17},
  [5899] = {.lex_state = 117, .external_lex_state = 15},
  [5900] = {.lex_state = 117, .external_lex_state = 17},
  [5901] = {.lex_state = 117, .external_lex_state = 17},
  [5902] = {.lex_state = 117, .external_lex_state = 17},
  [5903] = {.lex_state = 117, .external_lex_state = 17},
  [5904] = {.lex_state = 117, .external_lex_state = 15},
  [5905] = {.lex_state = 117, .external_lex_state = 17},
  [5906] = {.lex_state = 117, .external_lex_state = 17},
  [5907] = {.lex_state = 117, .external_lex_state = 17},
  [5908] = {.lex_state = 117, .external_lex_state = 17},
  [5909] = {.lex_state = 117, .external_lex_state = 15},
  [5910] = {.lex_state = 117, .external_lex_state = 15},
  [5911] = {.lex_state = 117, .external_lex_state = 17},
  [5912] = {.lex_state = 117, .external_lex_state = 17},
  [5913] = {.lex_state = 117, .external_lex_state = 17},
  [5914] = {.lex_state = 117, .external_lex_state = 17},
  [5915] = {.lex_state = 117, .external_lex_state = 17},
  [5916] = {.lex_state = 117, .external_lex_state = 12},
  [5917] = {.lex_state = 117, .external_lex_state = 17},
  [5918] = {.lex_state = 117, .external_lex_state = 17},
  [5919] = {.lex_state = 9},
  [5920] = {.lex_state = 117, .external_lex_state = 17},
  [5921] = {.lex_state = 117, .external_lex_state = 17},
  [5922] = {.lex_state = 117, .external_lex_state = 17},
  [5923] = {.lex_state = 117, .external_lex_state = 17},
  [5924] = {.lex_state = 117, .external_lex_state = 17},
  [5925] = {.lex_state = 117, .external_lex_state = 17},
  [5926] = {.lex_state = 117, .external_lex_state = 17},
  [5927] = {.lex_state = 117, .external_lex_state = 17},
  [5928] = {.lex_state = 117, .external_lex_state = 17},
  [5929] = {.lex_state = 117, .external_lex_state = 17},
  [5930] = {.lex_state = 117, .external_lex_state = 17},
  [5931] = {.lex_state = 117, .external_lex_state = 17},
  [5932] = {.lex_state = 117, .external_lex_state = 17},
  [5933] = {.lex_state = 3, .external_lex_state = 17},
  [5934] = {.lex_state = 117, .external_lex_state = 15},
  [5935] = {.lex_state = 9},
  [5936] = {.lex_state = 10, .external_lex_state = 15},
  [5937] = {.lex_state = 10, .external_lex_state = 17},
  [5938] = {.lex_state = 10, .external_lex_state = 17},
  [5939] = {.lex_state = 117, .external_lex_state = 15},
  [5940] = {.lex_state = 117, .external_lex_state = 15},
  [5941] = {.lex_state = 3, .external_lex_state = 17},
  [5942] = {.lex_state = 3, .external_lex_state = 17},
  [5943] = {.lex_state = 3, .external_lex_state = 17},
  [5944] = {.lex_state = 117, .external_lex_state = 15},
  [5945] = {.lex_state = 10, .external_lex_state = 17},
  [5946] = {.lex_state = 10},
  [5947] = {.lex_state = 3, .external_lex_state = 17},
  [5948] = {.lex_state = 117, .external_lex_state = 15},
  [5949] = {.lex_state = 10, .external_lex_state = 15},
  [5950] = {.lex_state = 117, .external_lex_state = 15},
  [5951] = {.lex_state = 117, .external_lex_state = 15},
  [5952] = {.lex_state = 117, .external_lex_state = 15},
  [5953] = {.lex_state = 117, .external_lex_state = 15},
  [5954] = {.lex_state = 117, .external_lex_state = 15},
  [5955] = {.lex_state = 117, .external_lex_state = 15},
  [5956] = {.lex_state = 117, .external_lex_state = 15},
  [5957] = {.lex_state = 117, .external_lex_state = 15},
  [5958] = {.lex_state = 117, .external_lex_state = 15},
  [5959] = {.lex_state = 117, .external_lex_state = 15},
  [5960] = {.lex_state = 117, .external_lex_state = 15},
  [5961] = {.lex_state = 117, .external_lex_state = 15},
  [5962] = {.lex_state = 117, .external_lex_state = 15},
  [5963] = {.lex_state = 117, .external_lex_state = 15},
  [5964] = {.lex_state = 117, .external_lex_state = 8},
  [5965] = {.lex_state = 117, .external_lex_state = 8},
  [5966] = {.lex_state = 117, .external_lex_state = 15},
  [5967] = {.lex_state = 117, .external_lex_state = 8},
  [5968] = {.lex_state = 117, .external_lex_state = 8},
  [5969] = {.lex_state = 117, .external_lex_state = 8},
  [5970] = {.lex_state = 117, .external_lex_state = 8},
  [5971] = {.lex_state = 117, .external_lex_state = 8},
  [5972] = {.lex_state = 117, .external_lex_state = 8},
  [5973] = {.lex_state = 117, .external_lex_state = 15},
  [5974] = {.lex_state = 117, .external_lex_state = 15},
  [5975] = {.lex_state = 117, .external_lex_state = 15},
  [5976] = {.lex_state = 117, .external_lex_state = 15},
  [5977] = {.lex_state = 117, .external_lex_state = 15},
  [5978] = {.lex_state = 117, .external_lex_state = 15},
  [5979] = {.lex_state = 117, .external_lex_state = 15},
  [5980] = {.lex_state = 117, .external_lex_state = 15},
  [5981] = {.lex_state = 117, .external_lex_state = 15},
  [5982] = {.lex_state = 117, .external_lex_state = 15},
  [5983] = {.lex_state = 117, .external_lex_state = 15},
  [5984] = {.lex_state = 117, .external_lex_state = 15},
  [5985] = {.lex_state = 117, .external_lex_state = 15},
  [5986] = {.lex_state = 117, .external_lex_state = 15},
  [5987] = {.lex_state = 117, .external_lex_state = 15},
  [5988] = {.lex_state = 117, .external_lex_state = 15},
  [5989] = {.lex_state = 117, .external_lex_state = 15},
  [5990] = {.lex_state = 117, .external_lex_state = 15},
  [5991] = {.lex_state = 117, .external_lex_state = 17},
  [5992] = {.lex_state = 117, .external_lex_state = 15},
  [5993] = {.lex_state = 117, .external_lex_state = 15},
  [5994] = {.lex_state = 117, .external_lex_state = 15},
  [5995] = {.lex_state = 117, .external_lex_state = 15},
  [5996] = {.lex_state = 117, .external_lex_state = 15},
  [5997] = {.lex_state = 117, .external_lex_state = 15},
  [5998] = {.lex_state = 117, .external_lex_state = 15},
  [5999] = {.lex_state = 117, .external_lex_state = 15},
  [6000] = {.lex_state = 117, .external_lex_state = 8},
  [6001] = {.lex_state = 117, .external_lex_state = 8},
  [6002] = {.lex_state = 117, .external_lex_state = 15},
  [6003] = {.lex_state = 117, .external_lex_state = 15},
  [6004] = {.lex_state = 117, .external_lex_state = 15},
  [6005] = {.lex_state = 117, .external_lex_state = 15},
  [6006] = {.lex_state = 117, .external_lex_state = 17},
  [6007] = {.lex_state = 117, .external_lex_state = 15},
  [6008] = {.lex_state = 117, .external_lex_state = 15},
  [6009] = {.lex_state = 117, .external_lex_state = 15},
  [6010] = {.lex_state = 117, .external_lex_state = 15},
  [6011] = {.lex_state = 117, .external_lex_state = 15},
  [6012] = {.lex_state = 117, .external_lex_state = 15},
  [6013] = {.lex_state = 117, .external_lex_state = 17},
  [6014] = {.lex_state = 117, .external_lex_state = 15},
  [6015] = {.lex_state = 117, .external_lex_state = 15},
  [6016] = {.lex_state = 117, .external_lex_state = 15},
  [6017] = {.lex_state = 117, .external_lex_state = 15},
  [6018] = {.lex_state = 117, .external_lex_state = 15},
  [6019] = {.lex_state = 117, .external_lex_state = 15},
  [6020] = {.lex_state = 117, .external_lex_state = 15},
  [6021] = {.lex_state = 117, .external_lex_state = 15},
  [6022] = {.lex_state = 117, .external_lex_state = 15},
  [6023] = {.lex_state = 117, .external_lex_state = 15},
  [6024] = {.lex_state = 117, .external_lex_state = 15},
  [6025] = {.lex_state = 117, .external_lex_state = 15},
  [6026] = {.lex_state = 117, .external_lex_state = 15},
  [6027] = {.lex_state = 117, .external_lex_state = 15},
  [6028] = {.lex_state = 117, .external_lex_state = 15},
  [6029] = {.lex_state = 117, .external_lex_state = 15},
  [6030] = {.lex_state = 10, .external_lex_state = 22},
  [6031] = {.lex_state = 117, .external_lex_state = 15},
  [6032] = {.lex_state = 117, .external_lex_state = 15},
  [6033] = {.lex_state = 117, .external_lex_state = 15},
  [6034] = {.lex_state = 117, .external_lex_state = 15},
  [6035] = {.lex_state = 117, .external_lex_state = 15},
  [6036] = {.lex_state = 117, .external_lex_state = 15},
  [6037] = {.lex_state = 117, .external_lex_state = 15},
  [6038] = {.lex_state = 117, .external_lex_state = 15},
  [6039] = {.lex_state = 117, .external_lex_state = 15},
  [6040] = {.lex_state = 117, .external_lex_state = 15},
  [6041] = {.lex_state = 117, .external_lex_state = 15},
  [6042] = {.lex_state = 117, .external_lex_state = 15},
  [6043] = {.lex_state = 117, .external_lex_state = 15},
  [6044] = {.lex_state = 117, .external_lex_state = 15},
  [6045] = {.lex_state = 117, .external_lex_state = 15},
  [6046] = {.lex_state = 117, .external_lex_state = 15},
  [6047] = {.lex_state = 117, .external_lex_state = 15},
  [6048] = {.lex_state = 117, .external_lex_state = 15},
  [6049] = {.lex_state = 117, .external_lex_state = 15},
  [6050] = {.lex_state = 117, .external_lex_state = 15},
  [6051] = {.lex_state = 117, .external_lex_state = 15},
  [6052] = {.lex_state = 117, .external_lex_state = 15},
  [6053] = {.lex_state = 117, .external_lex_state = 15},
  [6054] = {.lex_state = 117, .external_lex_state = 15},
  [6055] = {.lex_state = 117, .external_lex_state = 15},
  [6056] = {.lex_state = 117, .external_lex_state = 15},
  [6057] = {.lex_state = 117, .external_lex_state = 15},
  [6058] = {.lex_state = 117, .external_lex_state = 15},
  [6059] = {.lex_state = 117, .external_lex_state = 15},
  [6060] = {.lex_state = 117, .external_lex_state = 15},
  [6061] = {.lex_state = 117, .external_lex_state = 15},
  [6062] = {.lex_state = 117, .external_lex_state = 15},
  [6063] = {.lex_state = 117, .external_lex_state = 15},
  [6064] = {.lex_state = 117, .external_lex_state = 15},
  [6065] = {.lex_state = 117, .external_lex_state = 15},
  [6066] = {.lex_state = 117, .external_lex_state = 15},
  [6067] = {.lex_state = 117, .external_lex_state = 15},
  [6068] = {.lex_state = 117, .external_lex_state = 15},
  [6069] = {.lex_state = 117, .external_lex_state = 15},
  [6070] = {.lex_state = 117, .external_lex_state = 15},
  [6071] = {.lex_state = 117, .external_lex_state = 15},
  [6072] = {.lex_state = 117, .external_lex_state = 15},
  [6073] = {.lex_state = 117, .external_lex_state = 15},
  [6074] = {.lex_state = 117, .external_lex_state = 15},
  [6075] = {.lex_state = 117, .external_lex_state = 15},
  [6076] = {.lex_state = 117, .external_lex_state = 15},
  [6077] = {.lex_state = 117, .external_lex_state = 15},
  [6078] = {.lex_state = 117, .external_lex_state = 15},
  [6079] = {.lex_state = 117, .external_lex_state = 15},
  [6080] = {.lex_state = 117, .external_lex_state = 15},
  [6081] = {.lex_state = 117, .external_lex_state = 15},
  [6082] = {.lex_state = 117, .external_lex_state = 15},
  [6083] = {.lex_state = 117, .external_lex_state = 15},
  [6084] = {.lex_state = 117, .external_lex_state = 15},
  [6085] = {.lex_state = 117, .external_lex_state = 15},
  [6086] = {.lex_state = 117, .external_lex_state = 15},
  [6087] = {.lex_state = 117, .external_lex_state = 15},
  [6088] = {.lex_state = 117, .external_lex_state = 15},
  [6089] = {.lex_state = 117, .external_lex_state = 15},
  [6090] = {.lex_state = 117, .external_lex_state = 15},
  [6091] = {.lex_state = 117, .external_lex_state = 15},
  [6092] = {.lex_state = 117, .external_lex_state = 15},
  [6093] = {.lex_state = 117, .external_lex_state = 15},
  [6094] = {.lex_state = 117, .external_lex_state = 15},
  [6095] = {.lex_state = 117, .external_lex_state = 15},
  [6096] = {.lex_state = 117, .external_lex_state = 15},
  [6097] = {.lex_state = 117, .external_lex_state = 15},
  [6098] = {.lex_state = 117, .external_lex_state = 15},
  [6099] = {.lex_state = 117, .external_lex_state = 8},
  [6100] = {.lex_state = 117, .external_lex_state = 8},
  [6101] = {.lex_state = 117, .external_lex_state = 15},
  [6102] = {.lex_state = 117, .external_lex_state = 15},
  [6103] = {.lex_state = 117, .external_lex_state = 15},
  [6104] = {.lex_state = 117, .external_lex_state = 15},
  [6105] = {.lex_state = 117, .external_lex_state = 15},
  [6106] = {.lex_state = 117, .external_lex_state = 15},
  [6107] = {.lex_state = 117, .external_lex_state = 15},
  [6108] = {.lex_state = 117, .external_lex_state = 15},
  [6109] = {.lex_state = 117, .external_lex_state = 15},
  [6110] = {.lex_state = 117, .external_lex_state = 15},
  [6111] = {.lex_state = 117, .external_lex_state = 15},
  [6112] = {.lex_state = 117, .external_lex_state = 15},
  [6113] = {.lex_state = 117, .external_lex_state = 15},
  [6114] = {.lex_state = 117, .external_lex_state = 15},
  [6115] = {.lex_state = 117, .external_lex_state = 15},
  [6116] = {.lex_state = 117, .external_lex_state = 15},
  [6117] = {.lex_state = 117, .external_lex_state = 15},
  [6118] = {.lex_state = 117, .external_lex_state = 15},
  [6119] = {.lex_state = 117, .external_lex_state = 15},
  [6120] = {.lex_state = 117, .external_lex_state = 15},
  [6121] = {.lex_state = 117, .external_lex_state = 15},
  [6122] = {.lex_state = 117, .external_lex_state = 15},
  [6123] = {.lex_state = 117, .external_lex_state = 15},
  [6124] = {.lex_state = 117, .external_lex_state = 15},
  [6125] = {.lex_state = 117, .external_lex_state = 15},
  [6126] = {.lex_state = 117, .external_lex_state = 15},
  [6127] = {.lex_state = 117, .external_lex_state = 15},
  [6128] = {.lex_state = 117, .external_lex_state = 15},
  [6129] = {.lex_state = 117, .external_lex_state = 15},
  [6130] = {.lex_state = 117, .external_lex_state = 15},
  [6131] = {.lex_state = 117, .external_lex_state = 15},
  [6132] = {.lex_state = 117, .external_lex_state = 15},
  [6133] = {.lex_state = 117, .external_lex_state = 15},
  [6134] = {.lex_state = 117, .external_lex_state = 15},
  [6135] = {.lex_state = 117, .external_lex_state = 15},
  [6136] = {.lex_state = 117, .external_lex_state = 15},
  [6137] = {.lex_state = 117, .external_lex_state = 15},
  [6138] = {.lex_state = 117, .external_lex_state = 15},
  [6139] = {.lex_state = 117, .external_lex_state = 15},
  [6140] = {.lex_state = 117, .external_lex_state = 15},
  [6141] = {.lex_state = 117, .external_lex_state = 15},
  [6142] = {.lex_state = 117, .external_lex_state = 15},
  [6143] = {.lex_state = 117, .external_lex_state = 15},
  [6144] = {.lex_state = 117, .external_lex_state = 15},
  [6145] = {.lex_state = 117, .external_lex_state = 15},
  [6146] = {.lex_state = 117, .external_lex_state = 15},
  [6147] = {.lex_state = 117, .external_lex_state = 15},
  [6148] = {.lex_state = 117, .external_lex_state = 15},
  [6149] = {.lex_state = 117, .external_lex_state = 15},
  [6150] = {.lex_state = 117, .external_lex_state = 15},
  [6151] = {.lex_state = 117, .external_lex_state = 15},
  [6152] = {.lex_state = 117, .external_lex_state = 15},
  [6153] = {.lex_state = 117, .external_lex_state = 15},
  [6154] = {.lex_state = 117, .external_lex_state = 15},
  [6155] = {.lex_state = 117, .external_lex_state = 15},
  [6156] = {.lex_state = 117, .external_lex_state = 15},
  [6157] = {.lex_state = 117, .external_lex_state = 15},
  [6158] = {.lex_state = 117, .external_lex_state = 15},
  [6159] = {.lex_state = 117, .external_lex_state = 15},
  [6160] = {.lex_state = 117, .external_lex_state = 15},
  [6161] = {.lex_state = 117, .external_lex_state = 15},
  [6162] = {.lex_state = 117, .external_lex_state = 15},
  [6163] = {.lex_state = 117, .external_lex_state = 15},
  [6164] = {.lex_state = 117, .external_lex_state = 15},
  [6165] = {.lex_state = 117, .external_lex_state = 15},
  [6166] = {.lex_state = 117, .external_lex_state = 15},
  [6167] = {.lex_state = 117, .external_lex_state = 15},
  [6168] = {.lex_state = 117, .external_lex_state = 15},
  [6169] = {.lex_state = 117, .external_lex_state = 15},
  [6170] = {.lex_state = 117, .external_lex_state = 15},
  [6171] = {.lex_state = 117, .external_lex_state = 15},
  [6172] = {.lex_state = 117, .external_lex_state = 15},
  [6173] = {.lex_state = 117, .external_lex_state = 15},
  [6174] = {.lex_state = 117, .external_lex_state = 15},
  [6175] = {.lex_state = 117, .external_lex_state = 15},
  [6176] = {.lex_state = 117, .external_lex_state = 15},
  [6177] = {.lex_state = 117, .external_lex_state = 15},
  [6178] = {.lex_state = 117, .external_lex_state = 15},
  [6179] = {.lex_state = 117, .external_lex_state = 15},
  [6180] = {.lex_state = 117, .external_lex_state = 15},
  [6181] = {.lex_state = 117, .external_lex_state = 15},
  [6182] = {.lex_state = 117, .external_lex_state = 15},
  [6183] = {.lex_state = 117, .external_lex_state = 15},
  [6184] = {.lex_state = 117, .external_lex_state = 15},
  [6185] = {.lex_state = 117, .external_lex_state = 15},
  [6186] = {.lex_state = 117, .external_lex_state = 15},
  [6187] = {.lex_state = 117, .external_lex_state = 15},
  [6188] = {.lex_state = 117, .external_lex_state = 15},
  [6189] = {.lex_state = 117, .external_lex_state = 15},
  [6190] = {.lex_state = 117, .external_lex_state = 15},
  [6191] = {.lex_state = 117, .external_lex_state = 15},
  [6192] = {.lex_state = 117, .external_lex_state = 15},
  [6193] = {.lex_state = 117, .external_lex_state = 15},
  [6194] = {.lex_state = 117, .external_lex_state = 15},
  [6195] = {.lex_state = 117, .external_lex_state = 15},
  [6196] = {.lex_state = 117, .external_lex_state = 15},
  [6197] = {.lex_state = 117, .external_lex_state = 15},
  [6198] = {.lex_state = 117, .external_lex_state = 15},
  [6199] = {.lex_state = 117, .external_lex_state = 15},
  [6200] = {.lex_state = 117, .external_lex_state = 15},
  [6201] = {.lex_state = 117, .external_lex_state = 15},
  [6202] = {.lex_state = 117, .external_lex_state = 15},
  [6203] = {.lex_state = 117, .external_lex_state = 15},
  [6204] = {.lex_state = 117, .external_lex_state = 15},
  [6205] = {.lex_state = 117, .external_lex_state = 15},
  [6206] = {.lex_state = 117, .external_lex_state = 15},
  [6207] = {.lex_state = 117, .external_lex_state = 15},
  [6208] = {.lex_state = 117, .external_lex_state = 15},
  [6209] = {.lex_state = 117, .external_lex_state = 15},
  [6210] = {.lex_state = 117, .external_lex_state = 15},
  [6211] = {.lex_state = 117, .external_lex_state = 15},
  [6212] = {.lex_state = 117, .external_lex_state = 15},
  [6213] = {.lex_state = 117, .external_lex_state = 15},
  [6214] = {.lex_state = 117, .external_lex_state = 15},
  [6215] = {.lex_state = 117, .external_lex_state = 15},
  [6216] = {.lex_state = 117, .external_lex_state = 15},
  [6217] = {.lex_state = 117, .external_lex_state = 15},
  [6218] = {.lex_state = 117, .external_lex_state = 15},
  [6219] = {.lex_state = 117, .external_lex_state = 15},
  [6220] = {.lex_state = 117, .external_lex_state = 15},
  [6221] = {.lex_state = 117, .external_lex_state = 15},
  [6222] = {.lex_state = 117, .external_lex_state = 15},
  [6223] = {.lex_state = 117, .external_lex_state = 15},
  [6224] = {.lex_state = 117, .external_lex_state = 15},
  [6225] = {.lex_state = 117, .external_lex_state = 15},
  [6226] = {.lex_state = 117, .external_lex_state = 15},
  [6227] = {.lex_state = 117, .external_lex_state = 15},
  [6228] = {.lex_state = 117, .external_lex_state = 15},
  [6229] = {.lex_state = 117, .external_lex_state = 15},
  [6230] = {.lex_state = 117, .external_lex_state = 15},
  [6231] = {.lex_state = 117, .external_lex_state = 15},
  [6232] = {.lex_state = 117, .external_lex_state = 15},
  [6233] = {.lex_state = 117, .external_lex_state = 15},
  [6234] = {.lex_state = 117, .external_lex_state = 15},
  [6235] = {.lex_state = 117, .external_lex_state = 15},
  [6236] = {.lex_state = 117, .external_lex_state = 15},
  [6237] = {.lex_state = 117, .external_lex_state = 15},
  [6238] = {.lex_state = 117, .external_lex_state = 15},
  [6239] = {.lex_state = 117, .external_lex_state = 15},
  [6240] = {.lex_state = 117, .external_lex_state = 15},
  [6241] = {.lex_state = 117, .external_lex_state = 15},
  [6242] = {.lex_state = 117, .external_lex_state = 15},
  [6243] = {.lex_state = 117, .external_lex_state = 15},
  [6244] = {.lex_state = 117, .external_lex_state = 15},
  [6245] = {.lex_state = 117, .external_lex_state = 15},
  [6246] = {.lex_state = 117, .external_lex_state = 15},
  [6247] = {.lex_state = 117, .external_lex_state = 15},
  [6248] = {.lex_state = 117, .external_lex_state = 15},
  [6249] = {.lex_state = 117, .external_lex_state = 15},
  [6250] = {.lex_state = 117, .external_lex_state = 15},
  [6251] = {.lex_state = 117, .external_lex_state = 15},
  [6252] = {.lex_state = 117, .external_lex_state = 15},
  [6253] = {.lex_state = 117, .external_lex_state = 15},
  [6254] = {.lex_state = 117, .external_lex_state = 15},
  [6255] = {.lex_state = 117, .external_lex_state = 15},
  [6256] = {.lex_state = 117, .external_lex_state = 15},
  [6257] = {.lex_state = 117, .external_lex_state = 15},
  [6258] = {.lex_state = 117, .external_lex_state = 15},
  [6259] = {.lex_state = 117, .external_lex_state = 15},
  [6260] = {.lex_state = 117, .external_lex_state = 15},
  [6261] = {.lex_state = 117, .external_lex_state = 15},
  [6262] = {.lex_state = 117, .external_lex_state = 15},
  [6263] = {.lex_state = 117, .external_lex_state = 15},
  [6264] = {.lex_state = 117, .external_lex_state = 15},
  [6265] = {.lex_state = 117, .external_lex_state = 15},
  [6266] = {.lex_state = 117, .external_lex_state = 15},
  [6267] = {.lex_state = 117, .external_lex_state = 15},
  [6268] = {.lex_state = 117, .external_lex_state = 15},
  [6269] = {.lex_state = 117, .external_lex_state = 15},
  [6270] = {.lex_state = 117, .external_lex_state = 15},
  [6271] = {.lex_state = 117, .external_lex_state = 15},
  [6272] = {.lex_state = 117, .external_lex_state = 15},
  [6273] = {.lex_state = 117, .external_lex_state = 15},
  [6274] = {.lex_state = 117, .external_lex_state = 15},
  [6275] = {.lex_state = 117, .external_lex_state = 15},
  [6276] = {.lex_state = 117, .external_lex_state = 15},
  [6277] = {.lex_state = 117, .external_lex_state = 15},
  [6278] = {.lex_state = 117, .external_lex_state = 15},
  [6279] = {.lex_state = 117, .external_lex_state = 15},
  [6280] = {.lex_state = 117, .external_lex_state = 15},
  [6281] = {.lex_state = 117, .external_lex_state = 15},
  [6282] = {.lex_state = 117, .external_lex_state = 15},
  [6283] = {.lex_state = 117, .external_lex_state = 15},
  [6284] = {.lex_state = 117, .external_lex_state = 15},
  [6285] = {.lex_state = 117, .external_lex_state = 15},
  [6286] = {.lex_state = 117, .external_lex_state = 15},
  [6287] = {.lex_state = 117, .external_lex_state = 15},
  [6288] = {.lex_state = 117, .external_lex_state = 15},
  [6289] = {.lex_state = 117, .external_lex_state = 15},
  [6290] = {.lex_state = 117, .external_lex_state = 15},
  [6291] = {.lex_state = 117, .external_lex_state = 15},
  [6292] = {.lex_state = 117, .external_lex_state = 15},
  [6293] = {.lex_state = 117, .external_lex_state = 15},
  [6294] = {.lex_state = 117, .external_lex_state = 15},
  [6295] = {.lex_state = 117, .external_lex_state = 15},
  [6296] = {.lex_state = 117, .external_lex_state = 15},
  [6297] = {.lex_state = 117, .external_lex_state = 15},
  [6298] = {.lex_state = 117, .external_lex_state = 15},
  [6299] = {.lex_state = 117, .external_lex_state = 15},
  [6300] = {.lex_state = 117, .external_lex_state = 15},
  [6301] = {.lex_state = 117, .external_lex_state = 15},
  [6302] = {.lex_state = 117, .external_lex_state = 15},
  [6303] = {.lex_state = 117, .external_lex_state = 15},
  [6304] = {.lex_state = 117, .external_lex_state = 15},
  [6305] = {.lex_state = 117, .external_lex_state = 15},
  [6306] = {.lex_state = 117, .external_lex_state = 15},
  [6307] = {.lex_state = 117, .external_lex_state = 15},
  [6308] = {.lex_state = 117, .external_lex_state = 15},
  [6309] = {.lex_state = 117, .external_lex_state = 15},
  [6310] = {.lex_state = 117, .external_lex_state = 15},
  [6311] = {.lex_state = 117, .external_lex_state = 15},
  [6312] = {.lex_state = 117, .external_lex_state = 15},
  [6313] = {.lex_state = 117, .external_lex_state = 15},
  [6314] = {.lex_state = 117, .external_lex_state = 15},
  [6315] = {.lex_state = 117, .external_lex_state = 15},
  [6316] = {.lex_state = 117, .external_lex_state = 15},
  [6317] = {.lex_state = 117, .external_lex_state = 15},
  [6318] = {.lex_state = 117, .external_lex_state = 15},
  [6319] = {.lex_state = 117, .external_lex_state = 15},
  [6320] = {.lex_state = 117, .external_lex_state = 15},
  [6321] = {.lex_state = 117, .external_lex_state = 15},
  [6322] = {.lex_state = 117, .external_lex_state = 15},
  [6323] = {.lex_state = 117, .external_lex_state = 15},
  [6324] = {.lex_state = 117, .external_lex_state = 15},
  [6325] = {.lex_state = 117, .external_lex_state = 15},
  [6326] = {.lex_state = 117, .external_lex_state = 15},
  [6327] = {.lex_state = 117, .external_lex_state = 15},
  [6328] = {.lex_state = 117, .external_lex_state = 15},
  [6329] = {.lex_state = 117, .external_lex_state = 15},
  [6330] = {.lex_state = 117, .external_lex_state = 15},
  [6331] = {.lex_state = 117, .external_lex_state = 15},
  [6332] = {.lex_state = 117, .external_lex_state = 15},
  [6333] = {.lex_state = 117, .external_lex_state = 15},
  [6334] = {.lex_state = 117, .external_lex_state = 15},
  [6335] = {.lex_state = 117, .external_lex_state = 15},
  [6336] = {.lex_state = 117, .external_lex_state = 15},
  [6337] = {.lex_state = 117, .external_lex_state = 15},
  [6338] = {.lex_state = 117, .external_lex_state = 15},
  [6339] = {.lex_state = 117, .external_lex_state = 15},
  [6340] = {.lex_state = 117, .external_lex_state = 15},
  [6341] = {.lex_state = 117, .external_lex_state = 15},
  [6342] = {.lex_state = 117, .external_lex_state = 15},
  [6343] = {.lex_state = 117, .external_lex_state = 15},
  [6344] = {.lex_state = 117, .external_lex_state = 15},
  [6345] = {.lex_state = 117, .external_lex_state = 15},
  [6346] = {.lex_state = 117, .external_lex_state = 15},
  [6347] = {.lex_state = 117, .external_lex_state = 15},
  [6348] = {.lex_state = 117, .external_lex_state = 15},
  [6349] = {.lex_state = 117, .external_lex_state = 15},
  [6350] = {.lex_state = 117, .external_lex_state = 15},
  [6351] = {.lex_state = 117, .external_lex_state = 15},
  [6352] = {.lex_state = 117, .external_lex_state = 15},
  [6353] = {.lex_state = 117, .external_lex_state = 15},
  [6354] = {.lex_state = 117, .external_lex_state = 15},
  [6355] = {.lex_state = 117, .external_lex_state = 15},
  [6356] = {.lex_state = 117, .external_lex_state = 15},
  [6357] = {.lex_state = 117, .external_lex_state = 15},
  [6358] = {.lex_state = 117, .external_lex_state = 15},
  [6359] = {.lex_state = 117, .external_lex_state = 15},
  [6360] = {.lex_state = 117, .external_lex_state = 15},
  [6361] = {.lex_state = 117, .external_lex_state = 15},
  [6362] = {.lex_state = 117, .external_lex_state = 15},
  [6363] = {.lex_state = 117, .external_lex_state = 15},
  [6364] = {.lex_state = 117, .external_lex_state = 15},
  [6365] = {.lex_state = 117, .external_lex_state = 15},
  [6366] = {.lex_state = 117, .external_lex_state = 15},
  [6367] = {.lex_state = 117, .external_lex_state = 15},
  [6368] = {.lex_state = 117, .external_lex_state = 15},
  [6369] = {.lex_state = 117, .external_lex_state = 15},
  [6370] = {.lex_state = 117, .external_lex_state = 23},
  [6371] = {.lex_state = 117, .external_lex_state = 15},
  [6372] = {.lex_state = 117, .external_lex_state = 23},
  [6373] = {.lex_state = 117, .external_lex_state = 15},
  [6374] = {.lex_state = 117, .external_lex_state = 23},
  [6375] = {.lex_state = 117, .external_lex_state = 15},
  [6376] = {.lex_state = 117, .external_lex_state = 15},
  [6377] = {.lex_state = 117, .external_lex_state = 15},
  [6378] = {.lex_state = 10, .external_lex_state = 17},
  [6379] = {.lex_state = 117, .external_lex_state = 15},
  [6380] = {.lex_state = 117, .external_lex_state = 15},
  [6381] = {.lex_state = 117, .external_lex_state = 15},
  [6382] = {.lex_state = 117, .external_lex_state = 15},
  [6383] = {.lex_state = 117, .external_lex_state = 23},
  [6384] = {.lex_state = 117, .external_lex_state = 23},
  [6385] = {.lex_state = 117, .external_lex_state = 15},
  [6386] = {.lex_state = 117, .external_lex_state = 15},
  [6387] = {.lex_state = 117, .external_lex_state = 15},
  [6388] = {.lex_state = 117, .external_lex_state = 15},
  [6389] = {.lex_state = 117, .external_lex_state = 15},
  [6390] = {.lex_state = 117, .external_lex_state = 15},
  [6391] = {.lex_state = 117, .external_lex_state = 15},
  [6392] = {.lex_state = 117, .external_lex_state = 15},
  [6393] = {.lex_state = 117, .external_lex_state = 15},
  [6394] = {.lex_state = 117, .external_lex_state = 15},
  [6395] = {.lex_state = 117, .external_lex_state = 15},
  [6396] = {.lex_state = 117, .external_lex_state = 15},
  [6397] = {.lex_state = 117, .external_lex_state = 15},
  [6398] = {.lex_state = 117, .external_lex_state = 15},
  [6399] = {.lex_state = 117, .external_lex_state = 15},
  [6400] = {.lex_state = 117, .external_lex_state = 15},
  [6401] = {.lex_state = 117, .external_lex_state = 15},
  [6402] = {.lex_state = 117, .external_lex_state = 15},
  [6403] = {.lex_state = 117, .external_lex_state = 15},
  [6404] = {.lex_state = 117, .external_lex_state = 15},
  [6405] = {.lex_state = 117, .external_lex_state = 15},
  [6406] = {.lex_state = 117, .external_lex_state = 15},
  [6407] = {.lex_state = 117, .external_lex_state = 15},
  [6408] = {.lex_state = 117, .external_lex_state = 15},
  [6409] = {.lex_state = 117, .external_lex_state = 15},
  [6410] = {.lex_state = 117, .external_lex_state = 15},
  [6411] = {.lex_state = 117, .external_lex_state = 15},
  [6412] = {.lex_state = 117, .external_lex_state = 15},
  [6413] = {.lex_state = 117, .external_lex_state = 15},
  [6414] = {.lex_state = 117, .external_lex_state = 15},
  [6415] = {.lex_state = 117, .external_lex_state = 15},
  [6416] = {.lex_state = 117, .external_lex_state = 15},
  [6417] = {.lex_state = 117, .external_lex_state = 15},
  [6418] = {.lex_state = 117, .external_lex_state = 15},
  [6419] = {.lex_state = 117, .external_lex_state = 15},
  [6420] = {.lex_state = 117, .external_lex_state = 15},
  [6421] = {.lex_state = 117, .external_lex_state = 15},
  [6422] = {.lex_state = 117, .external_lex_state = 15},
  [6423] = {.lex_state = 117, .external_lex_state = 15},
  [6424] = {.lex_state = 117, .external_lex_state = 15},
  [6425] = {.lex_state = 117, .external_lex_state = 15},
  [6426] = {.lex_state = 117, .external_lex_state = 15},
  [6427] = {.lex_state = 117, .external_lex_state = 15},
  [6428] = {.lex_state = 117, .external_lex_state = 15},
  [6429] = {.lex_state = 117, .external_lex_state = 15},
  [6430] = {.lex_state = 117, .external_lex_state = 15},
  [6431] = {.lex_state = 117, .external_lex_state = 15},
  [6432] = {.lex_state = 117, .external_lex_state = 15},
  [6433] = {.lex_state = 117, .external_lex_state = 15},
  [6434] = {.lex_state = 117, .external_lex_state = 15},
  [6435] = {.lex_state = 117, .external_lex_state = 15},
  [6436] = {.lex_state = 117, .external_lex_state = 15},
  [6437] = {.lex_state = 10, .external_lex_state = 17},
  [6438] = {.lex_state = 117, .external_lex_state = 15},
  [6439] = {.lex_state = 117, .external_lex_state = 15},
  [6440] = {.lex_state = 117, .external_lex_state = 15},
  [6441] = {.lex_state = 9},
  [6442] = {.lex_state = 117, .external_lex_state = 15},
  [6443] = {.lex_state = 117, .external_lex_state = 15},
  [6444] = {.lex_state = 117, .external_lex_state = 15},
  [6445] = {.lex_state = 117, .external_lex_state = 15},
  [6446] = {.lex_state = 117, .external_lex_state = 15},
  [6447] = {.lex_state = 117, .external_lex_state = 15},
  [6448] = {.lex_state = 117, .external_lex_state = 15},
  [6449] = {.lex_state = 117, .external_lex_state = 15},
  [6450] = {.lex_state = 117, .external_lex_state = 15},
  [6451] = {.lex_state = 117, .external_lex_state = 15},
  [6452] = {.lex_state = 117, .external_lex_state = 15},
  [6453] = {.lex_state = 117, .external_lex_state = 15},
  [6454] = {.lex_state = 117, .external_lex_state = 15},
  [6455] = {.lex_state = 117, .external_lex_state = 15},
  [6456] = {.lex_state = 117, .external_lex_state = 15},
  [6457] = {.lex_state = 117, .external_lex_state = 15},
  [6458] = {.lex_state = 117, .external_lex_state = 15},
  [6459] = {.lex_state = 117, .external_lex_state = 15},
  [6460] = {.lex_state = 117, .external_lex_state = 15},
  [6461] = {.lex_state = 117, .external_lex_state = 15},
  [6462] = {.lex_state = 117, .external_lex_state = 15},
  [6463] = {.lex_state = 117, .external_lex_state = 15},
  [6464] = {.lex_state = 117, .external_lex_state = 15},
  [6465] = {.lex_state = 117, .external_lex_state = 15},
  [6466] = {.lex_state = 117, .external_lex_state = 15},
  [6467] = {.lex_state = 117, .external_lex_state = 15},
  [6468] = {.lex_state = 117, .external_lex_state = 15},
  [6469] = {.lex_state = 117, .external_lex_state = 15},
  [6470] = {.lex_state = 117, .external_lex_state = 15},
  [6471] = {.lex_state = 117, .external_lex_state = 15},
  [6472] = {.lex_state = 117, .external_lex_state = 15},
  [6473] = {.lex_state = 117, .external_lex_state = 15},
  [6474] = {.lex_state = 117, .external_lex_state = 15},
  [6475] = {.lex_state = 117, .external_lex_state = 15},
  [6476] = {.lex_state = 117, .external_lex_state = 15},
  [6477] = {.lex_state = 117, .external_lex_state = 15},
  [6478] = {.lex_state = 117, .external_lex_state = 15},
  [6479] = {.lex_state = 117, .external_lex_state = 15},
  [6480] = {.lex_state = 117, .external_lex_state = 12},
  [6481] = {.lex_state = 117, .external_lex_state = 10},
  [6482] = {.lex_state = 117, .external_lex_state = 10},
  [6483] = {.lex_state = 117, .external_lex_state = 10},
  [6484] = {.lex_state = 3},
  [6485] = {.lex_state = 117, .external_lex_state = 12},
  [6486] = {.lex_state = 117, .external_lex_state = 10},
  [6487] = {.lex_state = 117, .external_lex_state = 10},
  [6488] = {.lex_state = 117, .external_lex_state = 8},
  [6489] = {.lex_state = 117, .external_lex_state = 8},
  [6490] = {.lex_state = 117, .external_lex_state = 10},
  [6491] = {.lex_state = 117, .external_lex_state = 10},
  [6492] = {.lex_state = 117, .external_lex_state = 17},
  [6493] = {.lex_state = 117, .external_lex_state = 15},
  [6494] = {.lex_state = 117, .external_lex_state = 15},
  [6495] = {.lex_state = 117, .external_lex_state = 12},
  [6496] = {.lex_state = 117, .external_lex_state = 17},
  [6497] = {.lex_state = 117, .external_lex_state = 10},
  [6498] = {.lex_state = 117, .external_lex_state = 10},
  [6499] = {.lex_state = 117, .external_lex_state = 10},
  [6500] = {.lex_state = 9, .external_lex_state = 24},
  [6501] = {.lex_state = 117, .external_lex_state = 10},
  [6502] = {.lex_state = 117, .external_lex_state = 10},
  [6503] = {.lex_state = 117, .external_lex_state = 10},
  [6504] = {.lex_state = 117, .external_lex_state = 10},
  [6505] = {.lex_state = 117, .external_lex_state = 10},
  [6506] = {.lex_state = 117, .external_lex_state = 12},
  [6507] = {.lex_state = 117, .external_lex_state = 10},
  [6508] = {.lex_state = 117, .external_lex_state = 10},
  [6509] = {.lex_state = 117, .external_lex_state = 10},
  [6510] = {.lex_state = 117, .external_lex_state = 12},
  [6511] = {.lex_state = 117, .external_lex_state = 10},
  [6512] = {.lex_state = 117, .external_lex_state = 10},
  [6513] = {.lex_state = 117, .external_lex_state = 12},
  [6514] = {.lex_state = 117, .external_lex_state = 10},
  [6515] = {.lex_state = 117, .external_lex_state = 10},
  [6516] = {.lex_state = 10, .external_lex_state = 22},
  [6517] = {.lex_state = 3, .external_lex_state = 8},
  [6518] = {.lex_state = 117, .external_lex_state = 8},
  [6519] = {.lex_state = 10, .external_lex_state = 17},
  [6520] = {.lex_state = 3, .external_lex_state = 8},
  [6521] = {.lex_state = 117, .external_lex_state = 8},
  [6522] = {.lex_state = 10, .external_lex_state = 22},
  [6523] = {.lex_state = 117, .external_lex_state = 12},
  [6524] = {.lex_state = 117, .external_lex_state = 8},
  [6525] = {.lex_state = 117, .external_lex_state = 8},
  [6526] = {.lex_state = 117, .external_lex_state = 8},
  [6527] = {.lex_state = 117, .external_lex_state = 8},
  [6528] = {.lex_state = 117, .external_lex_state = 8},
  [6529] = {.lex_state = 117, .external_lex_state = 8},
  [6530] = {.lex_state = 117, .external_lex_state = 8},
  [6531] = {.lex_state = 117, .external_lex_state = 8},
  [6532] = {.lex_state = 117, .external_lex_state = 8},
  [6533] = {.lex_state = 117, .external_lex_state = 8},
  [6534] = {.lex_state = 3, .external_lex_state = 8},
  [6535] = {.lex_state = 117, .external_lex_state = 8},
  [6536] = {.lex_state = 117, .external_lex_state = 8},
  [6537] = {.lex_state = 117, .external_lex_state = 8},
  [6538] = {.lex_state = 117, .external_lex_state = 8},
  [6539] = {.lex_state = 117, .external_lex_state = 8},
  [6540] = {.lex_state = 117, .external_lex_state = 8},
  [6541] = {.lex_state = 117, .external_lex_state = 8},
  [6542] = {.lex_state = 117, .external_lex_state = 8},
  [6543] = {.lex_state = 117, .external_lex_state = 8},
  [6544] = {.lex_state = 117, .external_lex_state = 8},
  [6545] = {.lex_state = 117, .external_lex_state = 8},
  [6546] = {.lex_state = 6, .external_lex_state = 2},
  [6547] = {.lex_state = 117, .external_lex_state = 8},
  [6548] = {.lex_state = 117, .external_lex_state = 8},
  [6549] = {.lex_state = 117, .external_lex_state = 8},
  [6550] = {.lex_state = 117, .external_lex_state = 8},
  [6551] = {.lex_state = 117, .external_lex_state = 12},
  [6552] = {.lex_state = 117, .external_lex_state = 8},
  [6553] = {.lex_state = 117, .external_lex_state = 8},
  [6554] = {.lex_state = 117, .external_lex_state = 8},
  [6555] = {.lex_state = 117, .external_lex_state = 8},
  [6556] = {.lex_state = 117, .external_lex_state = 8},
  [6557] = {.lex_state = 117, .external_lex_state = 8},
  [6558] = {.lex_state = 117, .external_lex_state = 8},
  [6559] = {.lex_state = 117, .external_lex_state = 8},
  [6560] = {.lex_state = 117, .external_lex_state = 8},
  [6561] = {.lex_state = 117, .external_lex_state = 8},
  [6562] = {.lex_state = 117, .external_lex_state = 8},
  [6563] = {.lex_state = 117, .external_lex_state = 8},
  [6564] = {.lex_state = 117, .external_lex_state = 8},
  [6565] = {.lex_state = 10, .external_lex_state = 17},
  [6566] = {.lex_state = 117, .external_lex_state = 8},
  [6567] = {.lex_state = 117, .external_lex_state = 8},
  [6568] = {.lex_state = 6, .external_lex_state = 22},
  [6569] = {.lex_state = 117, .external_lex_state = 8},
  [6570] = {.lex_state = 10, .external_lex_state = 15},
  [6571] = {.lex_state = 117, .external_lex_state = 8},
  [6572] = {.lex_state = 10, .external_lex_state = 22},
  [6573] = {.lex_state = 117, .external_lex_state = 8},
  [6574] = {.lex_state = 117, .external_lex_state = 8},
  [6575] = {.lex_state = 117, .external_lex_state = 8},
  [6576] = {.lex_state = 117, .external_lex_state = 8},
  [6577] = {.lex_state = 117, .external_lex_state = 8},
  [6578] = {.lex_state = 117, .external_lex_state = 8},
  [6579] = {.lex_state = 117, .external_lex_state = 8},
  [6580] = {.lex_state = 117, .external_lex_state = 8},
  [6581] = {.lex_state = 117, .external_lex_state = 8},
  [6582] = {.lex_state = 117, .external_lex_state = 8},
  [6583] = {.lex_state = 117, .external_lex_state = 8},
  [6584] = {.lex_state = 117, .external_lex_state = 8},
  [6585] = {.lex_state = 117, .external_lex_state = 8},
  [6586] = {.lex_state = 117, .external_lex_state = 8},
  [6587] = {.lex_state = 117, .external_lex_state = 8},
  [6588] = {.lex_state = 117, .external_lex_state = 8},
  [6589] = {.lex_state = 117, .external_lex_state = 8},
  [6590] = {.lex_state = 117, .external_lex_state = 8},
  [6591] = {.lex_state = 117, .external_lex_state = 8},
  [6592] = {.lex_state = 117, .external_lex_state = 8},
  [6593] = {.lex_state = 117, .external_lex_state = 12},
  [6594] = {.lex_state = 117, .external_lex_state = 8},
  [6595] = {.lex_state = 117, .external_lex_state = 8},
  [6596] = {.lex_state = 117, .external_lex_state = 8},
  [6597] = {.lex_state = 3, .external_lex_state = 8},
  [6598] = {.lex_state = 117, .external_lex_state = 8},
  [6599] = {.lex_state = 117, .external_lex_state = 8},
  [6600] = {.lex_state = 117, .external_lex_state = 8},
  [6601] = {.lex_state = 117, .external_lex_state = 8},
  [6602] = {.lex_state = 117, .external_lex_state = 8},
  [6603] = {.lex_state = 117, .external_lex_state = 8},
  [6604] = {.lex_state = 117, .external_lex_state = 8},
  [6605] = {.lex_state = 117, .external_lex_state = 8},
  [6606] = {.lex_state = 117, .external_lex_state = 8},
  [6607] = {.lex_state = 117, .external_lex_state = 8},
  [6608] = {.lex_state = 10, .external_lex_state = 17},
  [6609] = {.lex_state = 117, .external_lex_state = 15},
  [6610] = {.lex_state = 10, .external_lex_state = 22},
  [6611] = {.lex_state = 117, .external_lex_state = 8},
  [6612] = {.lex_state = 117, .external_lex_state = 8},
  [6613] = {.lex_state = 117, .external_lex_state = 8},
  [6614] = {.lex_state = 117, .external_lex_state = 8},
  [6615] = {.lex_state = 117, .external_lex_state = 8},
  [6616] = {.lex_state = 117, .external_lex_state = 8},
  [6617] = {.lex_state = 117, .external_lex_state = 17},
  [6618] = {.lex_state = 117, .external_lex_state = 17},
  [6619] = {.lex_state = 117, .external_lex_state = 17},
  [6620] = {.lex_state = 117, .external_lex_state = 17},
  [6621] = {.lex_state = 117, .external_lex_state = 17},
  [6622] = {.lex_state = 117, .external_lex_state = 17},
  [6623] = {.lex_state = 117, .external_lex_state = 17},
  [6624] = {.lex_state = 117, .external_lex_state = 17},
  [6625] = {.lex_state = 117, .external_lex_state = 17},
  [6626] = {.lex_state = 117, .external_lex_state = 17},
  [6627] = {.lex_state = 117, .external_lex_state = 17},
  [6628] = {.lex_state = 117, .external_lex_state = 17},
  [6629] = {.lex_state = 117, .external_lex_state = 17},
  [6630] = {.lex_state = 117, .external_lex_state = 17},
  [6631] = {.lex_state = 117, .external_lex_state = 17},
  [6632] = {.lex_state = 117, .external_lex_state = 17},
  [6633] = {.lex_state = 117, .external_lex_state = 17},
  [6634] = {.lex_state = 117, .external_lex_state = 17},
  [6635] = {.lex_state = 117, .external_lex_state = 17},
  [6636] = {.lex_state = 117, .external_lex_state = 17},
  [6637] = {.lex_state = 117, .external_lex_state = 17},
  [6638] = {.lex_state = 10, .external_lex_state = 22},
  [6639] = {.lex_state = 117, .external_lex_state = 17},
  [6640] = {.lex_state = 117, .external_lex_state = 17},
  [6641] = {.lex_state = 117, .external_lex_state = 17},
  [6642] = {.lex_state = 117, .external_lex_state = 17},
  [6643] = {.lex_state = 117, .external_lex_state = 17},
  [6644] = {.lex_state = 117, .external_lex_state = 17},
  [6645] = {.lex_state = 117, .external_lex_state = 17},
  [6646] = {.lex_state = 117, .external_lex_state = 17},
  [6647] = {.lex_state = 117, .external_lex_state = 17},
  [6648] = {.lex_state = 117, .external_lex_state = 17},
  [6649] = {.lex_state = 117, .external_lex_state = 17},
  [6650] = {.lex_state = 117, .external_lex_state = 17},
  [6651] = {.lex_state = 117, .external_lex_state = 17},
  [6652] = {.lex_state = 117, .external_lex_state = 17},
  [6653] = {.lex_state = 117, .external_lex_state = 17},
  [6654] = {.lex_state = 117, .external_lex_state = 17},
  [6655] = {.lex_state = 117, .external_lex_state = 17},
  [6656] = {.lex_state = 117, .external_lex_state = 17},
  [6657] = {.lex_state = 117, .external_lex_state = 17},
  [6658] = {.lex_state = 117, .external_lex_state = 17},
  [6659] = {.lex_state = 117, .external_lex_state = 17},
  [6660] = {.lex_state = 117, .external_lex_state = 17},
  [6661] = {.lex_state = 117, .external_lex_state = 17},
  [6662] = {.lex_state = 117, .external_lex_state = 17},
  [6663] = {.lex_state = 117, .external_lex_state = 17},
  [6664] = {.lex_state = 117, .external_lex_state = 17},
  [6665] = {.lex_state = 117, .external_lex_state = 17},
  [6666] = {.lex_state = 117, .external_lex_state = 17},
  [6667] = {.lex_state = 117, .external_lex_state = 17},
  [6668] = {.lex_state = 117, .external_lex_state = 17},
  [6669] = {.lex_state = 117, .external_lex_state = 17},
  [6670] = {.lex_state = 117, .external_lex_state = 17},
  [6671] = {.lex_state = 117, .external_lex_state = 17},
  [6672] = {.lex_state = 117, .external_lex_state = 17},
  [6673] = {.lex_state = 117, .external_lex_state = 17},
  [6674] = {.lex_state = 117, .external_lex_state = 17},
  [6675] = {.lex_state = 117, .external_lex_state = 17},
  [6676] = {.lex_state = 117, .external_lex_state = 17},
  [6677] = {.lex_state = 117, .external_lex_state = 17},
  [6678] = {.lex_state = 117, .external_lex_state = 17},
  [6679] = {.lex_state = 117, .external_lex_state = 17},
  [6680] = {.lex_state = 117, .external_lex_state = 17},
  [6681] = {.lex_state = 117, .external_lex_state = 17},
  [6682] = {.lex_state = 12},
  [6683] = {.lex_state = 117, .external_lex_state = 17},
  [6684] = {.lex_state = 117, .external_lex_state = 17},
  [6685] = {.lex_state = 117, .external_lex_state = 17},
  [6686] = {.lex_state = 117, .external_lex_state = 17},
  [6687] = {.lex_state = 117, .external_lex_state = 17},
  [6688] = {.lex_state = 117, .external_lex_state = 17},
  [6689] = {.lex_state = 117, .external_lex_state = 17},
  [6690] = {.lex_state = 117, .external_lex_state = 17},
  [6691] = {.lex_state = 117, .external_lex_state = 17},
  [6692] = {.lex_state = 117, .external_lex_state = 17},
  [6693] = {.lex_state = 117, .external_lex_state = 17},
  [6694] = {.lex_state = 117, .external_lex_state = 17},
  [6695] = {.lex_state = 117, .external_lex_state = 17},
  [6696] = {.lex_state = 117, .external_lex_state = 17},
  [6697] = {.lex_state = 117, .external_lex_state = 17},
  [6698] = {.lex_state = 117, .external_lex_state = 17},
  [6699] = {.lex_state = 117, .external_lex_state = 17},
  [6700] = {.lex_state = 117, .external_lex_state = 17},
  [6701] = {.lex_state = 117, .external_lex_state = 17},
  [6702] = {.lex_state = 117, .external_lex_state = 17},
  [6703] = {.lex_state = 117, .external_lex_state = 17},
  [6704] = {.lex_state = 117, .external_lex_state = 17},
  [6705] = {.lex_state = 117, .external_lex_state = 17},
  [6706] = {.lex_state = 117, .external_lex_state = 17},
  [6707] = {.lex_state = 117, .external_lex_state = 17},
  [6708] = {.lex_state = 117, .external_lex_state = 17},
  [6709] = {.lex_state = 117, .external_lex_state = 17},
  [6710] = {.lex_state = 117, .external_lex_state = 17},
  [6711] = {.lex_state = 117, .external_lex_state = 17},
  [6712] = {.lex_state = 117, .external_lex_state = 17},
  [6713] = {.lex_state = 117, .external_lex_state = 17},
  [6714] = {.lex_state = 117, .external_lex_state = 17},
  [6715] = {.lex_state = 117, .external_lex_state = 17},
  [6716] = {.lex_state = 117, .external_lex_state = 17},
  [6717] = {.lex_state = 117, .external_lex_state = 17},
  [6718] = {.lex_state = 117, .external_lex_state = 17},
  [6719] = {.lex_state = 117, .external_lex_state = 17},
  [6720] = {.lex_state = 117, .external_lex_state = 17},
  [6721] = {.lex_state = 117, .external_lex_state = 17},
  [6722] = {.lex_state = 117, .external_lex_state = 17},
  [6723] = {.lex_state = 117, .external_lex_state = 17},
  [6724] = {.lex_state = 117, .external_lex_state = 17},
  [6725] = {.lex_state = 117, .external_lex_state = 17},
  [6726] = {.lex_state = 117, .external_lex_state = 17},
  [6727] = {.lex_state = 117, .external_lex_state = 17},
  [6728] = {.lex_state = 117, .external_lex_state = 17},
  [6729] = {.lex_state = 117, .external_lex_state = 17},
  [6730] = {.lex_state = 117, .external_lex_state = 17},
  [6731] = {.lex_state = 117, .external_lex_state = 17},
  [6732] = {.lex_state = 117, .external_lex_state = 17},
  [6733] = {.lex_state = 117, .external_lex_state = 17},
  [6734] = {.lex_state = 117, .external_lex_state = 17},
  [6735] = {.lex_state = 117, .external_lex_state = 17},
  [6736] = {.lex_state = 117, .external_lex_state = 17},
  [6737] = {.lex_state = 117, .external_lex_state = 17},
  [6738] = {.lex_state = 117, .external_lex_state = 17},
  [6739] = {.lex_state = 117, .external_lex_state = 17},
  [6740] = {.lex_state = 117, .external_lex_state = 17},
  [6741] = {.lex_state = 117, .external_lex_state = 17},
  [6742] = {.lex_state = 117, .external_lex_state = 17},
  [6743] = {.lex_state = 117, .external_lex_state = 17},
  [6744] = {.lex_state = 117, .external_lex_state = 17},
  [6745] = {.lex_state = 117, .external_lex_state = 2},
  [6746] = {.lex_state = 117, .external_lex_state = 14},
  [6747] = {.lex_state = 117, .external_lex_state = 17},
  [6748] = {.lex_state = 117, .external_lex_state = 17},
  [6749] = {.lex_state = 117, .external_lex_state = 17},
  [6750] = {.lex_state = 117, .external_lex_state = 17},
  [6751] = {.lex_state = 117, .external_lex_state = 17},
  [6752] = {.lex_state = 117, .external_lex_state = 17},
  [6753] = {.lex_state = 117, .external_lex_state = 17},
  [6754] = {.lex_state = 117, .external_lex_state = 17},
  [6755] = {.lex_state = 117, .external_lex_state = 17},
  [6756] = {.lex_state = 117, .external_lex_state = 17},
  [6757] = {.lex_state = 117, .external_lex_state = 17},
  [6758] = {.lex_state = 117, .external_lex_state = 17},
  [6759] = {.lex_state = 117, .external_lex_state = 17},
  [6760] = {.lex_state = 117, .external_lex_state = 17},
  [6761] = {.lex_state = 117, .external_lex_state = 17},
  [6762] = {.lex_state = 117, .external_lex_state = 17},
  [6763] = {.lex_state = 117, .external_lex_state = 17},
  [6764] = {.lex_state = 117, .external_lex_state = 17},
  [6765] = {.lex_state = 117, .external_lex_state = 17},
  [6766] = {.lex_state = 117, .external_lex_state = 17},
  [6767] = {.lex_state = 12},
  [6768] = {.lex_state = 117, .external_lex_state = 17},
  [6769] = {.lex_state = 117, .external_lex_state = 17},
  [6770] = {.lex_state = 117, .external_lex_state = 17},
  [6771] = {.lex_state = 117, .external_lex_state = 17},
  [6772] = {.lex_state = 117, .external_lex_state = 17},
  [6773] = {.lex_state = 117, .external_lex_state = 17},
  [6774] = {.lex_state = 117, .external_lex_state = 17},
  [6775] = {.lex_state = 117, .external_lex_state = 17},
  [6776] = {.lex_state = 117, .external_lex_state = 17},
  [6777] = {.lex_state = 117, .external_lex_state = 17},
  [6778] = {.lex_state = 117, .external_lex_state = 17},
  [6779] = {.lex_state = 117, .external_lex_state = 17},
  [6780] = {.lex_state = 117, .external_lex_state = 17},
  [6781] = {.lex_state = 117, .external_lex_state = 17},
  [6782] = {.lex_state = 117, .external_lex_state = 17},
  [6783] = {.lex_state = 117, .external_lex_state = 17},
  [6784] = {.lex_state = 117, .external_lex_state = 17},
  [6785] = {.lex_state = 12},
  [6786] = {.lex_state = 12},
  [6787] = {.lex_state = 117, .external_lex_state = 17},
  [6788] = {.lex_state = 117, .external_lex_state = 17},
  [6789] = {.lex_state = 117, .external_lex_state = 17},
  [6790] = {.lex_state = 117, .external_lex_state = 17},
  [6791] = {.lex_state = 117, .external_lex_state = 17},
  [6792] = {.lex_state = 117, .external_lex_state = 17},
  [6793] = {.lex_state = 117, .external_lex_state = 17},
  [6794] = {.lex_state = 117, .external_lex_state = 17},
  [6795] = {.lex_state = 117, .external_lex_state = 17},
  [6796] = {.lex_state = 117, .external_lex_state = 17},
  [6797] = {.lex_state = 117, .external_lex_state = 17},
  [6798] = {.lex_state = 117, .external_lex_state = 17},
  [6799] = {.lex_state = 117, .external_lex_state = 17},
  [6800] = {.lex_state = 117, .external_lex_state = 17},
  [6801] = {.lex_state = 117, .external_lex_state = 17},
  [6802] = {.lex_state = 117, .external_lex_state = 17},
  [6803] = {.lex_state = 117, .external_lex_state = 17},
  [6804] = {.lex_state = 117, .external_lex_state = 17},
  [6805] = {.lex_state = 117, .external_lex_state = 17},
  [6806] = {.lex_state = 117, .external_lex_state = 17},
  [6807] = {.lex_state = 117, .external_lex_state = 17},
  [6808] = {.lex_state = 117, .external_lex_state = 17},
  [6809] = {.lex_state = 117, .external_lex_state = 17},
  [6810] = {.lex_state = 117, .external_lex_state = 17},
  [6811] = {.lex_state = 117, .external_lex_state = 17},
  [6812] = {.lex_state = 12},
  [6813] = {.lex_state = 12},
  [6814] = {.lex_state = 117, .external_lex_state = 17},
  [6815] = {.lex_state = 117, .external_lex_state = 17},
  [6816] = {.lex_state = 117, .external_lex_state = 17},
  [6817] = {.lex_state = 117, .external_lex_state = 17},
  [6818] = {.lex_state = 117, .external_lex_state = 17},
  [6819] = {.lex_state = 117, .external_lex_state = 17},
  [6820] = {.lex_state = 117, .external_lex_state = 17},
  [6821] = {.lex_state = 117, .external_lex_state = 17},
  [6822] = {.lex_state = 117, .external_lex_state = 17},
  [6823] = {.lex_state = 117, .external_lex_state = 17},
  [6824] = {.lex_state = 117, .external_lex_state = 17},
  [6825] = {.lex_state = 117, .external_lex_state = 17},
  [6826] = {.lex_state = 117, .external_lex_state = 17},
  [6827] = {.lex_state = 117, .external_lex_state = 17},
  [6828] = {.lex_state = 117, .external_lex_state = 17},
  [6829] = {.lex_state = 117, .external_lex_state = 17},
  [6830] = {.lex_state = 117, .external_lex_state = 17},
  [6831] = {.lex_state = 117, .external_lex_state = 17},
  [6832] = {.lex_state = 117, .external_lex_state = 17},
  [6833] = {.lex_state = 117, .external_lex_state = 17},
  [6834] = {.lex_state = 117, .external_lex_state = 17},
  [6835] = {.lex_state = 117, .external_lex_state = 17},
  [6836] = {.lex_state = 117, .external_lex_state = 17},
  [6837] = {.lex_state = 117, .external_lex_state = 17},
  [6838] = {.lex_state = 12},
  [6839] = {.lex_state = 12},
  [6840] = {.lex_state = 117, .external_lex_state = 17},
  [6841] = {.lex_state = 117, .external_lex_state = 17},
  [6842] = {.lex_state = 117, .external_lex_state = 17},
  [6843] = {.lex_state = 12},
  [6844] = {.lex_state = 12},
  [6845] = {.lex_state = 117, .external_lex_state = 17},
  [6846] = {.lex_state = 12},
  [6847] = {.lex_state = 12},
  [6848] = {.lex_state = 12},
  [6849] = {.lex_state = 12},
  [6850] = {.lex_state = 12},
  [6851] = {.lex_state = 12},
  [6852] = {.lex_state = 12},
  [6853] = {.lex_state = 117, .external_lex_state = 17},
  [6854] = {.lex_state = 117, .external_lex_state = 17},
  [6855] = {.lex_state = 117, .external_lex_state = 17},
  [6856] = {.lex_state = 117, .external_lex_state = 17},
  [6857] = {.lex_state = 117, .external_lex_state = 17},
  [6858] = {.lex_state = 6},
  [6859] = {.lex_state = 117, .external_lex_state = 17},
  [6860] = {.lex_state = 117, .external_lex_state = 17},
  [6861] = {.lex_state = 117, .external_lex_state = 17},
  [6862] = {.lex_state = 117, .external_lex_state = 17},
  [6863] = {.lex_state = 117, .external_lex_state = 17},
  [6864] = {.lex_state = 117, .external_lex_state = 17},
  [6865] = {.lex_state = 117, .external_lex_state = 17},
  [6866] = {.lex_state = 117, .external_lex_state = 17},
  [6867] = {.lex_state = 117, .external_lex_state = 17},
  [6868] = {.lex_state = 117, .external_lex_state = 17},
  [6869] = {.lex_state = 117, .external_lex_state = 17},
  [6870] = {.lex_state = 117, .external_lex_state = 17},
  [6871] = {.lex_state = 117, .external_lex_state = 17},
  [6872] = {.lex_state = 117, .external_lex_state = 17},
  [6873] = {.lex_state = 117, .external_lex_state = 17},
  [6874] = {.lex_state = 117, .external_lex_state = 17},
  [6875] = {.lex_state = 117, .external_lex_state = 17},
  [6876] = {.lex_state = 117, .external_lex_state = 17},
  [6877] = {.lex_state = 117, .external_lex_state = 2},
  [6878] = {.lex_state = 117, .external_lex_state = 17},
  [6879] = {.lex_state = 12},
  [6880] = {.lex_state = 117, .external_lex_state = 17},
  [6881] = {.lex_state = 6},
  [6882] = {.lex_state = 117, .external_lex_state = 17},
  [6883] = {.lex_state = 117, .external_lex_state = 17},
  [6884] = {.lex_state = 117, .external_lex_state = 17},
  [6885] = {.lex_state = 117, .external_lex_state = 17},
  [6886] = {.lex_state = 117, .external_lex_state = 17},
  [6887] = {.lex_state = 117, .external_lex_state = 17},
  [6888] = {.lex_state = 117, .external_lex_state = 17},
  [6889] = {.lex_state = 117, .external_lex_state = 17},
  [6890] = {.lex_state = 117, .external_lex_state = 17},
  [6891] = {.lex_state = 117, .external_lex_state = 17},
  [6892] = {.lex_state = 117, .external_lex_state = 17},
  [6893] = {.lex_state = 117, .external_lex_state = 17},
  [6894] = {.lex_state = 117, .external_lex_state = 17},
  [6895] = {.lex_state = 117, .external_lex_state = 17},
  [6896] = {.lex_state = 117, .external_lex_state = 17},
  [6897] = {.lex_state = 117, .external_lex_state = 17},
  [6898] = {.lex_state = 117, .external_lex_state = 17},
  [6899] = {.lex_state = 117, .external_lex_state = 17},
  [6900] = {.lex_state = 117, .external_lex_state = 17},
  [6901] = {.lex_state = 117, .external_lex_state = 17},
  [6902] = {.lex_state = 117, .external_lex_state = 17},
  [6903] = {.lex_state = 117, .external_lex_state = 17},
  [6904] = {.lex_state = 117, .external_lex_state = 17},
  [6905] = {.lex_state = 117, .external_lex_state = 17},
  [6906] = {.lex_state = 117, .external_lex_state = 17},
  [6907] = {.lex_state = 117, .external_lex_state = 17},
  [6908] = {.lex_state = 117, .external_lex_state = 17},
  [6909] = {.lex_state = 117, .external_lex_state = 17},
  [6910] = {.lex_state = 117, .external_lex_state = 17},
  [6911] = {.lex_state = 117, .external_lex_state = 17},
  [6912] = {.lex_state = 117, .external_lex_state = 17},
  [6913] = {.lex_state = 117, .external_lex_state = 17},
  [6914] = {.lex_state = 117, .external_lex_state = 17},
  [6915] = {.lex_state = 117, .external_lex_state = 17},
  [6916] = {.lex_state = 117, .external_lex_state = 17},
  [6917] = {.lex_state = 117, .external_lex_state = 17},
  [6918] = {.lex_state = 117, .external_lex_state = 17},
  [6919] = {.lex_state = 117, .external_lex_state = 17},
  [6920] = {.lex_state = 117, .external_lex_state = 17},
  [6921] = {.lex_state = 117, .external_lex_state = 17},
  [6922] = {.lex_state = 117, .external_lex_state = 17},
  [6923] = {.lex_state = 117, .external_lex_state = 17},
  [6924] = {.lex_state = 117, .external_lex_state = 17},
  [6925] = {.lex_state = 117, .external_lex_state = 17},
  [6926] = {.lex_state = 117, .external_lex_state = 17},
  [6927] = {.lex_state = 117, .external_lex_state = 17},
  [6928] = {.lex_state = 117, .external_lex_state = 17},
  [6929] = {.lex_state = 117, .external_lex_state = 17},
  [6930] = {.lex_state = 117, .external_lex_state = 17},
  [6931] = {.lex_state = 117, .external_lex_state = 17},
  [6932] = {.lex_state = 117, .external_lex_state = 17},
  [6933] = {.lex_state = 117, .external_lex_state = 17},
  [6934] = {.lex_state = 117, .external_lex_state = 17},
  [6935] = {.lex_state = 117, .external_lex_state = 17},
  [6936] = {.lex_state = 117, .external_lex_state = 17},
  [6937] = {.lex_state = 117, .external_lex_state = 17},
  [6938] = {.lex_state = 117, .external_lex_state = 17},
  [6939] = {.lex_state = 117, .external_lex_state = 17},
  [6940] = {.lex_state = 117, .external_lex_state = 17},
  [6941] = {.lex_state = 117, .external_lex_state = 17},
  [6942] = {.lex_state = 117, .external_lex_state = 17},
  [6943] = {.lex_state = 117, .external_lex_state = 17},
  [6944] = {.lex_state = 117, .external_lex_state = 17},
  [6945] = {.lex_state = 117, .external_lex_state = 17},
  [6946] = {.lex_state = 117, .external_lex_state = 17},
  [6947] = {.lex_state = 117, .external_lex_state = 17},
  [6948] = {.lex_state = 117, .external_lex_state = 17},
  [6949] = {.lex_state = 117, .external_lex_state = 17},
  [6950] = {.lex_state = 117, .external_lex_state = 17},
  [6951] = {.lex_state = 117, .external_lex_state = 17},
  [6952] = {.lex_state = 117, .external_lex_state = 17},
  [6953] = {.lex_state = 117, .external_lex_state = 17},
  [6954] = {.lex_state = 117, .external_lex_state = 17},
  [6955] = {.lex_state = 117, .external_lex_state = 17},
  [6956] = {.lex_state = 117, .external_lex_state = 17},
  [6957] = {.lex_state = 117, .external_lex_state = 17},
  [6958] = {.lex_state = 117, .external_lex_state = 17},
  [6959] = {.lex_state = 117, .external_lex_state = 17},
  [6960] = {.lex_state = 117, .external_lex_state = 17},
  [6961] = {.lex_state = 117, .external_lex_state = 17},
  [6962] = {.lex_state = 117, .external_lex_state = 17},
  [6963] = {.lex_state = 117, .external_lex_state = 17},
  [6964] = {.lex_state = 117, .external_lex_state = 17},
  [6965] = {.lex_state = 117, .external_lex_state = 17},
  [6966] = {.lex_state = 117, .external_lex_state = 17},
  [6967] = {.lex_state = 117, .external_lex_state = 17},
  [6968] = {.lex_state = 117, .external_lex_state = 17},
  [6969] = {.lex_state = 117, .external_lex_state = 17},
  [6970] = {.lex_state = 117, .external_lex_state = 17},
  [6971] = {.lex_state = 117, .external_lex_state = 17},
  [6972] = {.lex_state = 117, .external_lex_state = 17},
  [6973] = {.lex_state = 117, .external_lex_state = 17},
  [6974] = {.lex_state = 117, .external_lex_state = 17},
  [6975] = {.lex_state = 117, .external_lex_state = 17},
  [6976] = {.lex_state = 117, .external_lex_state = 17},
  [6977] = {.lex_state = 117, .external_lex_state = 17},
  [6978] = {.lex_state = 117, .external_lex_state = 17},
  [6979] = {.lex_state = 117, .external_lex_state = 17},
  [6980] = {.lex_state = 117, .external_lex_state = 17},
  [6981] = {.lex_state = 117, .external_lex_state = 17},
  [6982] = {.lex_state = 117, .external_lex_state = 17},
  [6983] = {.lex_state = 117, .external_lex_state = 17},
  [6984] = {.lex_state = 117, .external_lex_state = 17},
  [6985] = {.lex_state = 117, .external_lex_state = 17},
  [6986] = {.lex_state = 117, .external_lex_state = 17},
  [6987] = {.lex_state = 117, .external_lex_state = 17},
  [6988] = {.lex_state = 117, .external_lex_state = 17},
  [6989] = {.lex_state = 117, .external_lex_state = 17},
  [6990] = {.lex_state = 117, .external_lex_state = 17},
  [6991] = {.lex_state = 117, .external_lex_state = 17},
  [6992] = {.lex_state = 117, .external_lex_state = 17},
  [6993] = {.lex_state = 117, .external_lex_state = 17},
  [6994] = {.lex_state = 117, .external_lex_state = 17},
  [6995] = {.lex_state = 117, .external_lex_state = 17},
  [6996] = {.lex_state = 117, .external_lex_state = 17},
  [6997] = {.lex_state = 117, .external_lex_state = 17},
  [6998] = {.lex_state = 117, .external_lex_state = 17},
  [6999] = {.lex_state = 117, .external_lex_state = 17},
  [7000] = {.lex_state = 117, .external_lex_state = 17},
  [7001] = {.lex_state = 117, .external_lex_state = 17},
  [7002] = {.lex_state = 117, .external_lex_state = 17},
  [7003] = {.lex_state = 117, .external_lex_state = 17},
  [7004] = {.lex_state = 117, .external_lex_state = 17},
  [7005] = {.lex_state = 117, .external_lex_state = 17},
  [7006] = {.lex_state = 117, .external_lex_state = 17},
  [7007] = {.lex_state = 117, .external_lex_state = 17},
  [7008] = {.lex_state = 117, .external_lex_state = 17},
  [7009] = {.lex_state = 117, .external_lex_state = 17},
  [7010] = {.lex_state = 117, .external_lex_state = 17},
  [7011] = {.lex_state = 117, .external_lex_state = 17},
  [7012] = {.lex_state = 117, .external_lex_state = 17},
  [7013] = {.lex_state = 117, .external_lex_state = 17},
  [7014] = {.lex_state = 117, .external_lex_state = 17},
  [7015] = {.lex_state = 117, .external_lex_state = 17},
  [7016] = {.lex_state = 117, .external_lex_state = 17},
  [7017] = {.lex_state = 117, .external_lex_state = 17},
  [7018] = {.lex_state = 117, .external_lex_state = 17},
  [7019] = {.lex_state = 117, .external_lex_state = 17},
  [7020] = {.lex_state = 117, .external_lex_state = 17},
  [7021] = {.lex_state = 117, .external_lex_state = 17},
  [7022] = {.lex_state = 117, .external_lex_state = 17},
  [7023] = {.lex_state = 117, .external_lex_state = 17},
  [7024] = {.lex_state = 117, .external_lex_state = 17},
  [7025] = {.lex_state = 117, .external_lex_state = 17},
  [7026] = {.lex_state = 117, .external_lex_state = 17},
  [7027] = {.lex_state = 117, .external_lex_state = 17},
  [7028] = {.lex_state = 117, .external_lex_state = 17},
  [7029] = {.lex_state = 117, .external_lex_state = 17},
  [7030] = {.lex_state = 117, .external_lex_state = 17},
  [7031] = {.lex_state = 117, .external_lex_state = 17},
  [7032] = {.lex_state = 117, .external_lex_state = 17},
  [7033] = {.lex_state = 117, .external_lex_state = 17},
  [7034] = {.lex_state = 117, .external_lex_state = 17},
  [7035] = {.lex_state = 117, .external_lex_state = 17},
  [7036] = {.lex_state = 117, .external_lex_state = 17},
  [7037] = {.lex_state = 117, .external_lex_state = 17},
  [7038] = {.lex_state = 117, .external_lex_state = 17},
  [7039] = {.lex_state = 117, .external_lex_state = 17},
  [7040] = {.lex_state = 117, .external_lex_state = 17},
  [7041] = {.lex_state = 117, .external_lex_state = 17},
  [7042] = {.lex_state = 117, .external_lex_state = 17},
  [7043] = {.lex_state = 117, .external_lex_state = 17},
  [7044] = {.lex_state = 117, .external_lex_state = 17},
  [7045] = {.lex_state = 117, .external_lex_state = 17},
  [7046] = {.lex_state = 117, .external_lex_state = 17},
  [7047] = {.lex_state = 117, .external_lex_state = 17},
  [7048] = {.lex_state = 117, .external_lex_state = 17},
  [7049] = {.lex_state = 117, .external_lex_state = 17},
  [7050] = {.lex_state = 117, .external_lex_state = 17},
  [7051] = {.lex_state = 117, .external_lex_state = 17},
  [7052] = {.lex_state = 117, .external_lex_state = 17},
  [7053] = {.lex_state = 117, .external_lex_state = 17},
  [7054] = {.lex_state = 117, .external_lex_state = 17},
  [7055] = {.lex_state = 117, .external_lex_state = 17},
  [7056] = {.lex_state = 117, .external_lex_state = 17},
  [7057] = {.lex_state = 117, .external_lex_state = 17},
  [7058] = {.lex_state = 117, .external_lex_state = 17},
  [7059] = {.lex_state = 117, .external_lex_state = 17},
  [7060] = {.lex_state = 117, .external_lex_state = 17},
  [7061] = {.lex_state = 117, .external_lex_state = 17},
  [7062] = {.lex_state = 117, .external_lex_state = 17},
  [7063] = {.lex_state = 117, .external_lex_state = 17},
  [7064] = {.lex_state = 117, .external_lex_state = 17},
  [7065] = {.lex_state = 117, .external_lex_state = 17},
  [7066] = {.lex_state = 117, .external_lex_state = 17},
  [7067] = {.lex_state = 117, .external_lex_state = 17},
  [7068] = {.lex_state = 117, .external_lex_state = 17},
  [7069] = {.lex_state = 117, .external_lex_state = 17},
  [7070] = {.lex_state = 117, .external_lex_state = 17},
  [7071] = {.lex_state = 117, .external_lex_state = 17},
  [7072] = {.lex_state = 117, .external_lex_state = 17},
  [7073] = {.lex_state = 117, .external_lex_state = 17},
  [7074] = {.lex_state = 117, .external_lex_state = 17},
  [7075] = {.lex_state = 117, .external_lex_state = 17},
  [7076] = {.lex_state = 117, .external_lex_state = 17},
  [7077] = {.lex_state = 117, .external_lex_state = 17},
  [7078] = {.lex_state = 117, .external_lex_state = 17},
  [7079] = {.lex_state = 117, .external_lex_state = 17},
  [7080] = {.lex_state = 117, .external_lex_state = 17},
  [7081] = {.lex_state = 117, .external_lex_state = 17},
  [7082] = {.lex_state = 117, .external_lex_state = 17},
  [7083] = {.lex_state = 117, .external_lex_state = 17},
  [7084] = {.lex_state = 117, .external_lex_state = 17},
  [7085] = {.lex_state = 117, .external_lex_state = 17},
  [7086] = {.lex_state = 117, .external_lex_state = 17},
  [7087] = {.lex_state = 117, .external_lex_state = 17},
  [7088] = {.lex_state = 117, .external_lex_state = 17},
  [7089] = {.lex_state = 117, .external_lex_state = 17},
  [7090] = {.lex_state = 117, .external_lex_state = 17},
  [7091] = {.lex_state = 117, .external_lex_state = 17},
  [7092] = {.lex_state = 117, .external_lex_state = 17},
  [7093] = {.lex_state = 117, .external_lex_state = 17},
  [7094] = {.lex_state = 117, .external_lex_state = 17},
  [7095] = {.lex_state = 117, .external_lex_state = 17},
  [7096] = {.lex_state = 117, .external_lex_state = 17},
  [7097] = {.lex_state = 117, .external_lex_state = 17},
  [7098] = {.lex_state = 117, .external_lex_state = 17},
  [7099] = {.lex_state = 117, .external_lex_state = 17},
  [7100] = {.lex_state = 117, .external_lex_state = 17},
  [7101] = {.lex_state = 117, .external_lex_state = 17},
  [7102] = {.lex_state = 117, .external_lex_state = 17},
  [7103] = {.lex_state = 117, .external_lex_state = 17},
  [7104] = {.lex_state = 117, .external_lex_state = 17},
  [7105] = {.lex_state = 117, .external_lex_state = 17},
  [7106] = {.lex_state = 117, .external_lex_state = 17},
  [7107] = {.lex_state = 10, .external_lex_state = 22},
  [7108] = {.lex_state = 6},
  [7109] = {.lex_state = 6},
  [7110] = {.lex_state = 6},
  [7111] = {.lex_state = 3, .external_lex_state = 12},
  [7112] = {.lex_state = 10, .external_lex_state = 12},
  [7113] = {.lex_state = 6, .external_lex_state = 22},
  [7114] = {.lex_state = 117, .external_lex_state = 15},
  [7115] = {.lex_state = 117, .external_lex_state = 15},
  [7116] = {.lex_state = 6},
  [7117] = {.lex_state = 3, .external_lex_state = 12},
  [7118] = {.lex_state = 10, .external_lex_state = 12},
  [7119] = {.lex_state = 3, .external_lex_state = 12},
  [7120] = {.lex_state = 6},
  [7121] = {.lex_state = 6},
  [7122] = {.lex_state = 3, .external_lex_state = 12},
  [7123] = {.lex_state = 10, .external_lex_state = 12},
  [7124] = {.lex_state = 3, .external_lex_state = 12},
  [7125] = {.lex_state = 117, .external_lex_state = 8},
  [7126] = {.lex_state = 117, .external_lex_state = 8},
  [7127] = {.lex_state = 117, .external_lex_state = 15},
  [7128] = {.lex_state = 117, .external_lex_state = 16},
  [7129] = {.lex_state = 117, .external_lex_state = 23},
  [7130] = {.lex_state = 117, .external_lex_state = 16},
  [7131] = {.lex_state = 117, .external_lex_state = 16},
  [7132] = {.lex_state = 117, .external_lex_state = 16},
  [7133] = {.lex_state = 117, .external_lex_state = 15},
  [7134] = {.lex_state = 117, .external_lex_state = 23},
  [7135] = {.lex_state = 117, .external_lex_state = 16},
  [7136] = {.lex_state = 117, .external_lex_state = 16},
  [7137] = {.lex_state = 117, .external_lex_state = 15},
  [7138] = {.lex_state = 117, .external_lex_state = 15},
  [7139] = {.lex_state = 6},
  [7140] = {.lex_state = 10, .external_lex_state = 12},
  [7141] = {.lex_state = 12},
  [7142] = {.lex_state = 10},
  [7143] = {.lex_state = 117, .external_lex_state = 8},
  [7144] = {.lex_state = 117, .external_lex_state = 15},
  [7145] = {.lex_state = 10},
  [7146] = {.lex_state = 117, .external_lex_state = 16},
  [7147] = {.lex_state = 117, .external_lex_state = 23},
  [7148] = {.lex_state = 117, .external_lex_state = 8},
  [7149] = {.lex_state = 117, .external_lex_state = 23},
  [7150] = {.lex_state = 6},
  [7151] = {.lex_state = 10},
  [7152] = {.lex_state = 117, .external_lex_state = 8},
  [7153] = {.lex_state = 117, .external_lex_state = 16},
  [7154] = {.lex_state = 117, .external_lex_state = 8},
  [7155] = {.lex_state = 117, .external_lex_state = 19},
  [7156] = {.lex_state = 117, .external_lex_state = 16},
  [7157] = {.lex_state = 6},
  [7158] = {.lex_state = 117, .external_lex_state = 16},
  [7159] = {.lex_state = 117, .external_lex_state = 16},
  [7160] = {.lex_state = 117, .external_lex_state = 16},
  [7161] = {.lex_state = 117, .external_lex_state = 16},
  [7162] = {.lex_state = 117, .external_lex_state = 8},
  [7163] = {.lex_state = 117, .external_lex_state = 15},
  [7164] = {.lex_state = 117, .external_lex_state = 16},
  [7165] = {.lex_state = 6},
  [7166] = {.lex_state = 117, .external_lex_state = 8},
  [7167] = {.lex_state = 117, .external_lex_state = 16},
  [7168] = {.lex_state = 117, .external_lex_state = 8},
  [7169] = {.lex_state = 10},
  [7170] = {.lex_state = 117, .external_lex_state = 8},
  [7171] = {.lex_state = 117, .external_lex_state = 8},
  [7172] = {.lex_state = 117, .external_lex_state = 8},
  [7173] = {.lex_state = 117, .external_lex_state = 16},
  [7174] = {.lex_state = 117, .external_lex_state = 8},
  [7175] = {.lex_state = 10, .external_lex_state = 12},
  [7176] = {.lex_state = 12},
  [7177] = {.lex_state = 117, .external_lex_state = 16},
  [7178] = {.lex_state = 117, .external_lex_state = 15},
  [7179] = {.lex_state = 117, .external_lex_state = 19},
  [7180] = {.lex_state = 117, .external_lex_state = 15},
  [7181] = {.lex_state = 6},
  [7182] = {.lex_state = 117, .external_lex_state = 8},
  [7183] = {.lex_state = 117, .external_lex_state = 23},
  [7184] = {.lex_state = 117, .external_lex_state = 16},
  [7185] = {.lex_state = 6},
  [7186] = {.lex_state = 3, .external_lex_state = 18},
  [7187] = {.lex_state = 117, .external_lex_state = 2},
  [7188] = {.lex_state = 6},
  [7189] = {.lex_state = 6},
  [7190] = {.lex_state = 9},
  [7191] = {.lex_state = 6},
  [7192] = {.lex_state = 3, .external_lex_state = 18},
  [7193] = {.lex_state = 6},
  [7194] = {.lex_state = 117, .external_lex_state = 2},
  [7195] = {.lex_state = 6},
  [7196] = {.lex_state = 117, .external_lex_state = 2},
  [7197] = {.lex_state = 117, .external_lex_state = 2},
  [7198] = {.lex_state = 6},
  [7199] = {.lex_state = 6},
  [7200] = {.lex_state = 117, .external_lex_state = 2},
  [7201] = {.lex_state = 117, .external_lex_state = 2},
  [7202] = {.lex_state = 117, .external_lex_state = 2},
  [7203] = {.lex_state = 117, .external_lex_state = 2},
  [7204] = {.lex_state = 6},
  [7205] = {.lex_state = 6},
  [7206] = {.lex_state = 117, .external_lex_state = 2},
  [7207] = {.lex_state = 117, .external_lex_state = 2},
  [7208] = {.lex_state = 6},
  [7209] = {.lex_state = 117, .external_lex_state = 15},
  [7210] = {.lex_state = 6},
  [7211] = {.lex_state = 6},
  [7212] = {.lex_state = 117, .external_lex_state = 2},
  [7213] = {.lex_state = 117, .external_lex_state = 2},
  [7214] = {.lex_state = 6},
  [7215] = {.lex_state = 6},
  [7216] = {.lex_state = 117, .external_lex_state = 2},
  [7217] = {.lex_state = 117, .external_lex_state = 2},
  [7218] = {.lex_state = 6},
  [7219] = {.lex_state = 6},
  [7220] = {.lex_state = 117, .external_lex_state = 15},
  [7221] = {.lex_state = 6},
  [7222] = {.lex_state = 117, .external_lex_state = 15},
  [7223] = {.lex_state = 6},
  [7224] = {.lex_state = 117, .external_lex_state = 2},
  [7225] = {.lex_state = 6},
  [7226] = {.lex_state = 6},
  [7227] = {.lex_state = 6},
  [7228] = {.lex_state = 6},
  [7229] = {.lex_state = 117, .external_lex_state = 2},
  [7230] = {.lex_state = 117, .external_lex_state = 15},
  [7231] = {.lex_state = 6},
  [7232] = {.lex_state = 117, .external_lex_state = 2},
  [7233] = {.lex_state = 117, .external_lex_state = 2},
  [7234] = {.lex_state = 6},
  [7235] = {.lex_state = 117, .external_lex_state = 2},
  [7236] = {.lex_state = 117, .external_lex_state = 2},
  [7237] = {.lex_state = 117, .external_lex_state = 2},
  [7238] = {.lex_state = 117, .external_lex_state = 2},
  [7239] = {.lex_state = 117, .external_lex_state = 2},
  [7240] = {.lex_state = 117, .external_lex_state = 2},
  [7241] = {.lex_state = 117, .external_lex_state = 2},
  [7242] = {.lex_state = 117, .external_lex_state = 2},
  [7243] = {.lex_state = 117, .external_lex_state = 2},
  [7244] = {.lex_state = 6},
  [7245] = {.lex_state = 10},
  [7246] = {.lex_state = 6},
  [7247] = {.lex_state = 117, .external_lex_state = 2},
  [7248] = {.lex_state = 117, .external_lex_state = 2},
  [7249] = {.lex_state = 117, .external_lex_state = 2},
  [7250] = {.lex_state = 6},
  [7251] = {.lex_state = 117, .external_lex_state = 2},
  [7252] = {.lex_state = 3, .external_lex_state = 18},
  [7253] = {.lex_state = 117, .external_lex_state = 2},
  [7254] = {.lex_state = 117, .external_lex_state = 2},
  [7255] = {.lex_state = 117, .external_lex_state = 2},
  [7256] = {.lex_state = 117, .external_lex_state = 2},
  [7257] = {.lex_state = 117, .external_lex_state = 2},
  [7258] = {.lex_state = 117, .external_lex_state = 2},
  [7259] = {.lex_state = 117, .external_lex_state = 2},
  [7260] = {.lex_state = 117, .external_lex_state = 2},
  [7261] = {.lex_state = 117, .external_lex_state = 2},
  [7262] = {.lex_state = 117, .external_lex_state = 2},
  [7263] = {.lex_state = 117, .external_lex_state = 2},
  [7264] = {.lex_state = 6},
  [7265] = {.lex_state = 117, .external_lex_state = 2},
  [7266] = {.lex_state = 117, .external_lex_state = 2},
  [7267] = {.lex_state = 117, .external_lex_state = 2},
  [7268] = {.lex_state = 117, .external_lex_state = 2},
  [7269] = {.lex_state = 3, .external_lex_state = 18},
  [7270] = {.lex_state = 117, .external_lex_state = 15},
  [7271] = {.lex_state = 10, .external_lex_state = 12},
  [7272] = {.lex_state = 117, .external_lex_state = 15},
  [7273] = {.lex_state = 10, .external_lex_state = 12},
  [7274] = {.lex_state = 10, .external_lex_state = 12},
  [7275] = {.lex_state = 117, .external_lex_state = 15},
  [7276] = {.lex_state = 117, .external_lex_state = 18},
  [7277] = {.lex_state = 117, .external_lex_state = 15},
  [7278] = {.lex_state = 117, .external_lex_state = 15},
  [7279] = {.lex_state = 117, .external_lex_state = 15},
  [7280] = {.lex_state = 117, .external_lex_state = 15},
  [7281] = {.lex_state = 117, .external_lex_state = 15},
  [7282] = {.lex_state = 117, .external_lex_state = 12},
  [7283] = {.lex_state = 117, .external_lex_state = 12},
  [7284] = {.lex_state = 117, .external_lex_state = 12},
  [7285] = {.lex_state = 117, .external_lex_state = 12},
  [7286] = {.lex_state = 117, .external_lex_state = 12},
  [7287] = {.lex_state = 117, .external_lex_state = 12},
  [7288] = {.lex_state = 117, .external_lex_state = 12},
  [7289] = {.lex_state = 117, .external_lex_state = 12},
  [7290] = {.lex_state = 117, .external_lex_state = 12},
  [7291] = {.lex_state = 117, .external_lex_state = 12},
  [7292] = {.lex_state = 117, .external_lex_state = 12},
  [7293] = {.lex_state = 117, .external_lex_state = 12},
  [7294] = {.lex_state = 117, .external_lex_state = 12},
  [7295] = {.lex_state = 117, .external_lex_state = 12},
  [7296] = {.lex_state = 117, .external_lex_state = 12},
  [7297] = {.lex_state = 117, .external_lex_state = 12},
  [7298] = {.lex_state = 117, .external_lex_state = 12},
  [7299] = {.lex_state = 117, .external_lex_state = 12},
  [7300] = {.lex_state = 117, .external_lex_state = 12},
  [7301] = {.lex_state = 117, .external_lex_state = 12},
  [7302] = {.lex_state = 117, .external_lex_state = 12},
  [7303] = {.lex_state = 117, .external_lex_state = 12},
  [7304] = {.lex_state = 117, .external_lex_state = 12},
  [7305] = {.lex_state = 117, .external_lex_state = 12},
  [7306] = {.lex_state = 117, .external_lex_state = 12},
  [7307] = {.lex_state = 117, .external_lex_state = 12},
  [7308] = {.lex_state = 117, .external_lex_state = 12},
  [7309] = {.lex_state = 117, .external_lex_state = 12},
  [7310] = {.lex_state = 117, .external_lex_state = 12},
  [7311] = {.lex_state = 117, .external_lex_state = 12},
  [7312] = {.lex_state = 117, .external_lex_state = 12},
  [7313] = {.lex_state = 117, .external_lex_state = 12},
  [7314] = {.lex_state = 117, .external_lex_state = 12},
  [7315] = {.lex_state = 117, .external_lex_state = 12},
  [7316] = {.lex_state = 117, .external_lex_state = 12},
  [7317] = {.lex_state = 117, .external_lex_state = 12},
  [7318] = {.lex_state = 117, .external_lex_state = 12},
  [7319] = {.lex_state = 117, .external_lex_state = 12},
  [7320] = {.lex_state = 117, .external_lex_state = 12},
  [7321] = {.lex_state = 117, .external_lex_state = 12},
  [7322] = {.lex_state = 117, .external_lex_state = 12},
  [7323] = {.lex_state = 117, .external_lex_state = 12},
  [7324] = {.lex_state = 117, .external_lex_state = 12},
  [7325] = {.lex_state = 117, .external_lex_state = 12},
  [7326] = {.lex_state = 117, .external_lex_state = 12},
  [7327] = {.lex_state = 117, .external_lex_state = 12},
  [7328] = {.lex_state = 117, .external_lex_state = 12},
  [7329] = {.lex_state = 117, .external_lex_state = 12},
  [7330] = {.lex_state = 117, .external_lex_state = 12},
  [7331] = {.lex_state = 117, .external_lex_state = 12},
  [7332] = {.lex_state = 117, .external_lex_state = 12},
  [7333] = {.lex_state = 117, .external_lex_state = 12},
  [7334] = {.lex_state = 117, .external_lex_state = 12},
  [7335] = {.lex_state = 117, .external_lex_state = 12},
  [7336] = {.lex_state = 117, .external_lex_state = 12},
  [7337] = {.lex_state = 117, .external_lex_state = 12},
  [7338] = {.lex_state = 117, .external_lex_state = 12},
  [7339] = {.lex_state = 117, .external_lex_state = 12},
  [7340] = {.lex_state = 117, .external_lex_state = 12},
  [7341] = {.lex_state = 117, .external_lex_state = 12},
  [7342] = {.lex_state = 117, .external_lex_state = 12},
  [7343] = {.lex_state = 117, .external_lex_state = 12},
  [7344] = {.lex_state = 117, .external_lex_state = 12},
  [7345] = {.lex_state = 117, .external_lex_state = 12},
  [7346] = {.lex_state = 117, .external_lex_state = 12},
  [7347] = {.lex_state = 117, .external_lex_state = 12},
  [7348] = {.lex_state = 117, .external_lex_state = 12},
  [7349] = {.lex_state = 117, .external_lex_state = 12},
  [7350] = {.lex_state = 117, .external_lex_state = 12},
  [7351] = {.lex_state = 117, .external_lex_state = 12},
  [7352] = {.lex_state = 117, .external_lex_state = 12},
  [7353] = {.lex_state = 117, .external_lex_state = 12},
  [7354] = {.lex_state = 117, .external_lex_state = 12},
  [7355] = {.lex_state = 117, .external_lex_state = 12},
  [7356] = {.lex_state = 117, .external_lex_state = 12},
  [7357] = {.lex_state = 117, .external_lex_state = 12},
  [7358] = {.lex_state = 117, .external_lex_state = 12},
  [7359] = {.lex_state = 117, .external_lex_state = 12},
  [7360] = {.lex_state = 117, .external_lex_state = 12},
  [7361] = {.lex_state = 117, .external_lex_state = 12},
  [7362] = {.lex_state = 117, .external_lex_state = 12},
  [7363] = {.lex_state = 117, .external_lex_state = 12},
  [7364] = {.lex_state = 117, .external_lex_state = 12},
  [7365] = {.lex_state = 117, .external_lex_state = 12},
  [7366] = {.lex_state = 117, .external_lex_state = 12},
  [7367] = {.lex_state = 117, .external_lex_state = 12},
  [7368] = {.lex_state = 117, .external_lex_state = 12},
  [7369] = {.lex_state = 117, .external_lex_state = 12},
  [7370] = {.lex_state = 117, .external_lex_state = 12},
  [7371] = {.lex_state = 117, .external_lex_state = 12},
  [7372] = {.lex_state = 117, .external_lex_state = 12},
  [7373] = {.lex_state = 117, .external_lex_state = 12},
  [7374] = {.lex_state = 117, .external_lex_state = 12},
  [7375] = {.lex_state = 117, .external_lex_state = 12},
  [7376] = {.lex_state = 117, .external_lex_state = 12},
  [7377] = {.lex_state = 117, .external_lex_state = 12},
  [7378] = {.lex_state = 117, .external_lex_state = 12},
  [7379] = {.lex_state = 117, .external_lex_state = 12},
  [7380] = {.lex_state = 117, .external_lex_state = 12},
  [7381] = {.lex_state = 117, .external_lex_state = 12},
  [7382] = {.lex_state = 117, .external_lex_state = 12},
  [7383] = {.lex_state = 117, .external_lex_state = 12},
  [7384] = {.lex_state = 117, .external_lex_state = 12},
  [7385] = {.lex_state = 117, .external_lex_state = 12},
  [7386] = {.lex_state = 117, .external_lex_state = 12},
  [7387] = {.lex_state = 117, .external_lex_state = 12},
  [7388] = {.lex_state = 117, .external_lex_state = 12},
  [7389] = {.lex_state = 117, .external_lex_state = 12},
  [7390] = {.lex_state = 117, .external_lex_state = 12},
  [7391] = {.lex_state = 117, .external_lex_state = 12},
  [7392] = {.lex_state = 117, .external_lex_state = 12},
  [7393] = {.lex_state = 117, .external_lex_state = 12},
  [7394] = {.lex_state = 117, .external_lex_state = 12},
  [7395] = {.lex_state = 117, .external_lex_state = 12},
  [7396] = {.lex_state = 117, .external_lex_state = 12},
  [7397] = {.lex_state = 117, .external_lex_state = 12},
  [7398] = {.lex_state = 117, .external_lex_state = 12},
  [7399] = {.lex_state = 117, .external_lex_state = 12},
  [7400] = {.lex_state = 117, .external_lex_state = 12},
  [7401] = {.lex_state = 117, .external_lex_state = 12},
  [7402] = {.lex_state = 117, .external_lex_state = 12},
  [7403] = {.lex_state = 117, .external_lex_state = 12},
  [7404] = {.lex_state = 117, .external_lex_state = 12},
  [7405] = {.lex_state = 117, .external_lex_state = 12},
  [7406] = {.lex_state = 117, .external_lex_state = 12},
  [7407] = {.lex_state = 117, .external_lex_state = 12},
  [7408] = {.lex_state = 117, .external_lex_state = 12},
  [7409] = {.lex_state = 117, .external_lex_state = 15},
  [7410] = {.lex_state = 117, .external_lex_state = 23},
  [7411] = {.lex_state = 117, .external_lex_state = 15},
  [7412] = {.lex_state = 117, .external_lex_state = 12},
  [7413] = {.lex_state = 117, .external_lex_state = 23},
  [7414] = {.lex_state = 117, .external_lex_state = 23},
  [7415] = {.lex_state = 117, .external_lex_state = 23},
  [7416] = {.lex_state = 117, .external_lex_state = 23},
  [7417] = {.lex_state = 6},
  [7418] = {.lex_state = 117, .external_lex_state = 23},
  [7419] = {.lex_state = 117, .external_lex_state = 23},
  [7420] = {.lex_state = 117, .external_lex_state = 23},
  [7421] = {.lex_state = 117, .external_lex_state = 23},
  [7422] = {.lex_state = 117, .external_lex_state = 23},
  [7423] = {.lex_state = 117, .external_lex_state = 23},
  [7424] = {.lex_state = 117, .external_lex_state = 12},
  [7425] = {.lex_state = 117, .external_lex_state = 23},
  [7426] = {.lex_state = 117, .external_lex_state = 23},
  [7427] = {.lex_state = 117, .external_lex_state = 23},
  [7428] = {.lex_state = 117, .external_lex_state = 23},
  [7429] = {.lex_state = 117, .external_lex_state = 23},
  [7430] = {.lex_state = 117, .external_lex_state = 23},
  [7431] = {.lex_state = 117, .external_lex_state = 23},
  [7432] = {.lex_state = 117, .external_lex_state = 23},
  [7433] = {.lex_state = 117, .external_lex_state = 23},
  [7434] = {.lex_state = 117, .external_lex_state = 23},
  [7435] = {.lex_state = 117, .external_lex_state = 23},
  [7436] = {.lex_state = 6},
  [7437] = {.lex_state = 117, .external_lex_state = 23},
  [7438] = {.lex_state = 117, .external_lex_state = 23},
  [7439] = {.lex_state = 117, .external_lex_state = 16},
  [7440] = {.lex_state = 117, .external_lex_state = 12},
  [7441] = {.lex_state = 117, .external_lex_state = 12},
  [7442] = {.lex_state = 117, .external_lex_state = 12},
  [7443] = {.lex_state = 117, .external_lex_state = 12},
  [7444] = {.lex_state = 117, .external_lex_state = 12},
  [7445] = {.lex_state = 117, .external_lex_state = 12},
  [7446] = {.lex_state = 117, .external_lex_state = 12},
  [7447] = {.lex_state = 117, .external_lex_state = 16},
  [7448] = {.lex_state = 117, .external_lex_state = 16},
  [7449] = {.lex_state = 117, .external_lex_state = 12},
  [7450] = {.lex_state = 117, .external_lex_state = 16},
  [7451] = {.lex_state = 117, .external_lex_state = 12},
  [7452] = {.lex_state = 117, .external_lex_state = 12},
  [7453] = {.lex_state = 117, .external_lex_state = 12},
  [7454] = {.lex_state = 117, .external_lex_state = 12},
  [7455] = {.lex_state = 117, .external_lex_state = 12},
  [7456] = {.lex_state = 117, .external_lex_state = 12},
  [7457] = {.lex_state = 117, .external_lex_state = 12},
  [7458] = {.lex_state = 117, .external_lex_state = 12},
  [7459] = {.lex_state = 117, .external_lex_state = 12},
  [7460] = {.lex_state = 117, .external_lex_state = 12},
  [7461] = {.lex_state = 117, .external_lex_state = 12},
  [7462] = {.lex_state = 117, .external_lex_state = 12},
  [7463] = {.lex_state = 117, .external_lex_state = 12},
  [7464] = {.lex_state = 117, .external_lex_state = 12},
  [7465] = {.lex_state = 117, .external_lex_state = 12},
  [7466] = {.lex_state = 117, .external_lex_state = 12},
  [7467] = {.lex_state = 117, .external_lex_state = 12},
  [7468] = {.lex_state = 117, .external_lex_state = 12},
  [7469] = {.lex_state = 117, .external_lex_state = 12},
  [7470] = {.lex_state = 117, .external_lex_state = 12},
  [7471] = {.lex_state = 117, .external_lex_state = 12},
  [7472] = {.lex_state = 117, .external_lex_state = 12},
  [7473] = {.lex_state = 117, .external_lex_state = 12},
  [7474] = {.lex_state = 117, .external_lex_state = 12},
  [7475] = {.lex_state = 117, .external_lex_state = 12},
  [7476] = {.lex_state = 117, .external_lex_state = 12},
  [7477] = {.lex_state = 117, .external_lex_state = 12},
  [7478] = {.lex_state = 117, .external_lex_state = 23},
  [7479] = {.lex_state = 117, .external_lex_state = 23},
  [7480] = {.lex_state = 117, .external_lex_state = 23},
  [7481] = {.lex_state = 117, .external_lex_state = 23},
  [7482] = {.lex_state = 117, .external_lex_state = 23},
  [7483] = {.lex_state = 117, .external_lex_state = 23},
  [7484] = {.lex_state = 117, .external_lex_state = 23},
  [7485] = {.lex_state = 117, .external_lex_state = 23},
  [7486] = {.lex_state = 117, .external_lex_state = 23},
  [7487] = {.lex_state = 117, .external_lex_state = 23},
  [7488] = {.lex_state = 117, .external_lex_state = 23},
  [7489] = {.lex_state = 117, .external_lex_state = 23},
  [7490] = {.lex_state = 117, .external_lex_state = 23},
  [7491] = {.lex_state = 117, .external_lex_state = 23},
  [7492] = {.lex_state = 117, .external_lex_state = 23},
  [7493] = {.lex_state = 117, .external_lex_state = 23},
  [7494] = {.lex_state = 117, .external_lex_state = 23},
  [7495] = {.lex_state = 117, .external_lex_state = 23},
  [7496] = {.lex_state = 117, .external_lex_state = 23},
  [7497] = {.lex_state = 117, .external_lex_state = 23},
  [7498] = {.lex_state = 117, .external_lex_state = 23},
  [7499] = {.lex_state = 117, .external_lex_state = 23},
  [7500] = {.lex_state = 117, .external_lex_state = 23},
  [7501] = {.lex_state = 117, .external_lex_state = 12},
  [7502] = {.lex_state = 6},
  [7503] = {.lex_state = 117, .external_lex_state = 12},
  [7504] = {.lex_state = 117, .external_lex_state = 12},
  [7505] = {.lex_state = 117, .external_lex_state = 12},
  [7506] = {.lex_state = 117, .external_lex_state = 12},
  [7507] = {.lex_state = 117, .external_lex_state = 12},
  [7508] = {.lex_state = 117, .external_lex_state = 12},
  [7509] = {.lex_state = 117, .external_lex_state = 12},
  [7510] = {.lex_state = 117, .external_lex_state = 12},
  [7511] = {.lex_state = 117, .external_lex_state = 12},
  [7512] = {.lex_state = 117, .external_lex_state = 12},
  [7513] = {.lex_state = 117, .external_lex_state = 12},
  [7514] = {.lex_state = 117, .external_lex_state = 12},
  [7515] = {.lex_state = 117, .external_lex_state = 12},
  [7516] = {.lex_state = 117, .external_lex_state = 12},
  [7517] = {.lex_state = 117, .external_lex_state = 12},
  [7518] = {.lex_state = 117, .external_lex_state = 12},
  [7519] = {.lex_state = 117, .external_lex_state = 12},
  [7520] = {.lex_state = 117, .external_lex_state = 12},
  [7521] = {.lex_state = 117, .external_lex_state = 12},
  [7522] = {.lex_state = 117, .external_lex_state = 12},
  [7523] = {.lex_state = 117, .external_lex_state = 12},
  [7524] = {.lex_state = 117, .external_lex_state = 12},
  [7525] = {.lex_state = 117, .external_lex_state = 12},
  [7526] = {.lex_state = 117, .external_lex_state = 23},
  [7527] = {.lex_state = 117, .external_lex_state = 12},
  [7528] = {.lex_state = 117, .external_lex_state = 12},
  [7529] = {.lex_state = 117, .external_lex_state = 2},
  [7530] = {.lex_state = 6},
  [7531] = {.lex_state = 117, .external_lex_state = 2},
  [7532] = {.lex_state = 117, .external_lex_state = 12},
  [7533] = {.lex_state = 117, .external_lex_state = 12},
  [7534] = {.lex_state = 6},
  [7535] = {.lex_state = 6},
  [7536] = {.lex_state = 6},
  [7537] = {.lex_state = 6},
  [7538] = {.lex_state = 6},
  [7539] = {.lex_state = 6},
  [7540] = {.lex_state = 6},
  [7541] = {.lex_state = 6},
  [7542] = {.lex_state = 6},
  [7543] = {.lex_state = 6},
  [7544] = {.lex_state = 6},
  [7545] = {.lex_state = 6},
  [7546] = {.lex_state = 6},
  [7547] = {.lex_state = 6},
  [7548] = {.lex_state = 6},
  [7549] = {.lex_state = 6},
  [7550] = {.lex_state = 6},
  [7551] = {.lex_state = 6},
  [7552] = {.lex_state = 6},
  [7553] = {.lex_state = 6},
  [7554] = {.lex_state = 117, .external_lex_state = 12},
  [7555] = {.lex_state = 117, .external_lex_state = 12},
  [7556] = {.lex_state = 117, .external_lex_state = 12},
  [7557] = {.lex_state = 117, .external_lex_state = 2},
  [7558] = {.lex_state = 117, .external_lex_state = 2},
  [7559] = {.lex_state = 117, .external_lex_state = 2},
  [7560] = {.lex_state = 117, .external_lex_state = 2},
  [7561] = {.lex_state = 117, .external_lex_state = 12},
  [7562] = {.lex_state = 117, .external_lex_state = 12},
  [7563] = {.lex_state = 117, .external_lex_state = 12},
  [7564] = {.lex_state = 117, .external_lex_state = 2},
  [7565] = {.lex_state = 117, .external_lex_state = 2},
  [7566] = {.lex_state = 117, .external_lex_state = 2},
  [7567] = {.lex_state = 117, .external_lex_state = 12},
  [7568] = {.lex_state = 117, .external_lex_state = 2},
  [7569] = {.lex_state = 117, .external_lex_state = 2},
  [7570] = {.lex_state = 117, .external_lex_state = 2},
  [7571] = {.lex_state = 117, .external_lex_state = 2},
  [7572] = {.lex_state = 117, .external_lex_state = 2},
  [7573] = {.lex_state = 117, .external_lex_state = 2},
  [7574] = {.lex_state = 117, .external_lex_state = 12},
  [7575] = {.lex_state = 117, .external_lex_state = 2},
  [7576] = {.lex_state = 117, .external_lex_state = 2},
  [7577] = {.lex_state = 117, .external_lex_state = 2},
  [7578] = {.lex_state = 117, .external_lex_state = 2},
  [7579] = {.lex_state = 117, .external_lex_state = 2},
  [7580] = {.lex_state = 117, .external_lex_state = 2},
  [7581] = {.lex_state = 117, .external_lex_state = 2},
  [7582] = {.lex_state = 117, .external_lex_state = 2},
  [7583] = {.lex_state = 117, .external_lex_state = 2},
  [7584] = {.lex_state = 117, .external_lex_state = 2},
  [7585] = {.lex_state = 6},
  [7586] = {.lex_state = 117, .external_lex_state = 12},
  [7587] = {.lex_state = 117, .external_lex_state = 12},
  [7588] = {.lex_state = 6},
  [7589] = {.lex_state = 117, .external_lex_state = 12},
  [7590] = {.lex_state = 117, .external_lex_state = 12},
  [7591] = {.lex_state = 117, .external_lex_state = 12},
  [7592] = {.lex_state = 117, .external_lex_state = 12},
  [7593] = {.lex_state = 117, .external_lex_state = 12},
  [7594] = {.lex_state = 117, .external_lex_state = 12},
  [7595] = {.lex_state = 117, .external_lex_state = 12},
  [7596] = {.lex_state = 117, .external_lex_state = 12},
  [7597] = {.lex_state = 117, .external_lex_state = 12},
  [7598] = {.lex_state = 117, .external_lex_state = 12},
  [7599] = {.lex_state = 117, .external_lex_state = 12},
  [7600] = {.lex_state = 117, .external_lex_state = 12},
  [7601] = {.lex_state = 117, .external_lex_state = 12},
  [7602] = {.lex_state = 117, .external_lex_state = 12},
  [7603] = {.lex_state = 117, .external_lex_state = 12},
  [7604] = {.lex_state = 117, .external_lex_state = 12},
  [7605] = {.lex_state = 117, .external_lex_state = 12},
  [7606] = {.lex_state = 117, .external_lex_state = 12},
  [7607] = {.lex_state = 117, .external_lex_state = 2},
  [7608] = {.lex_state = 117, .external_lex_state = 2},
  [7609] = {.lex_state = 117, .external_lex_state = 12},
  [7610] = {.lex_state = 117, .external_lex_state = 12},
  [7611] = {.lex_state = 117, .external_lex_state = 12},
  [7612] = {.lex_state = 117, .external_lex_state = 12},
  [7613] = {.lex_state = 117, .external_lex_state = 12},
  [7614] = {.lex_state = 117, .external_lex_state = 12},
  [7615] = {.lex_state = 117, .external_lex_state = 12},
  [7616] = {.lex_state = 117, .external_lex_state = 12},
  [7617] = {.lex_state = 117, .external_lex_state = 12},
  [7618] = {.lex_state = 117, .external_lex_state = 12},
  [7619] = {.lex_state = 117, .external_lex_state = 12},
  [7620] = {.lex_state = 117, .external_lex_state = 12},
  [7621] = {.lex_state = 117, .external_lex_state = 12},
  [7622] = {.lex_state = 117, .external_lex_state = 12},
  [7623] = {.lex_state = 117, .external_lex_state = 12},
  [7624] = {.lex_state = 117, .external_lex_state = 12},
  [7625] = {.lex_state = 117, .external_lex_state = 12},
  [7626] = {.lex_state = 117, .external_lex_state = 12},
  [7627] = {.lex_state = 117, .external_lex_state = 12},
  [7628] = {.lex_state = 117, .external_lex_state = 12},
  [7629] = {.lex_state = 117, .external_lex_state = 12},
  [7630] = {.lex_state = 117, .external_lex_state = 12},
  [7631] = {.lex_state = 117, .external_lex_state = 12},
  [7632] = {.lex_state = 117, .external_lex_state = 12},
  [7633] = {.lex_state = 117, .external_lex_state = 12},
  [7634] = {.lex_state = 117, .external_lex_state = 12},
  [7635] = {.lex_state = 117, .external_lex_state = 12},
  [7636] = {.lex_state = 117, .external_lex_state = 12},
  [7637] = {.lex_state = 117, .external_lex_state = 12},
  [7638] = {.lex_state = 117, .external_lex_state = 12},
  [7639] = {.lex_state = 117, .external_lex_state = 12},
  [7640] = {.lex_state = 117, .external_lex_state = 12},
  [7641] = {.lex_state = 117, .external_lex_state = 12},
  [7642] = {.lex_state = 117, .external_lex_state = 12},
  [7643] = {.lex_state = 117, .external_lex_state = 12},
  [7644] = {.lex_state = 117, .external_lex_state = 12},
  [7645] = {.lex_state = 117, .external_lex_state = 12},
  [7646] = {.lex_state = 117, .external_lex_state = 12},
  [7647] = {.lex_state = 117, .external_lex_state = 12},
  [7648] = {.lex_state = 117, .external_lex_state = 12},
  [7649] = {.lex_state = 117, .external_lex_state = 12},
  [7650] = {.lex_state = 117, .external_lex_state = 12},
  [7651] = {.lex_state = 117, .external_lex_state = 12},
  [7652] = {.lex_state = 117, .external_lex_state = 12},
  [7653] = {.lex_state = 117, .external_lex_state = 12},
  [7654] = {.lex_state = 117, .external_lex_state = 12},
  [7655] = {.lex_state = 117, .external_lex_state = 12},
  [7656] = {.lex_state = 117, .external_lex_state = 12},
  [7657] = {.lex_state = 117, .external_lex_state = 12},
  [7658] = {.lex_state = 117, .external_lex_state = 12},
  [7659] = {.lex_state = 117, .external_lex_state = 12},
  [7660] = {.lex_state = 117, .external_lex_state = 12},
  [7661] = {.lex_state = 117, .external_lex_state = 12},
  [7662] = {.lex_state = 117, .external_lex_state = 12},
  [7663] = {.lex_state = 117, .external_lex_state = 12},
  [7664] = {.lex_state = 117, .external_lex_state = 2},
  [7665] = {.lex_state = 6},
  [7666] = {.lex_state = 117, .external_lex_state = 12},
  [7667] = {.lex_state = 117, .external_lex_state = 12},
  [7668] = {.lex_state = 117, .external_lex_state = 12},
  [7669] = {.lex_state = 117, .external_lex_state = 12},
  [7670] = {.lex_state = 117, .external_lex_state = 12},
  [7671] = {.lex_state = 117, .external_lex_state = 12},
  [7672] = {.lex_state = 117, .external_lex_state = 12},
  [7673] = {.lex_state = 117, .external_lex_state = 12},
  [7674] = {.lex_state = 117, .external_lex_state = 12},
  [7675] = {.lex_state = 117, .external_lex_state = 12},
  [7676] = {.lex_state = 117, .external_lex_state = 12},
  [7677] = {.lex_state = 117, .external_lex_state = 12},
  [7678] = {.lex_state = 117, .external_lex_state = 12},
  [7679] = {.lex_state = 117, .external_lex_state = 12},
  [7680] = {.lex_state = 117, .external_lex_state = 12},
  [7681] = {.lex_state = 117, .external_lex_state = 12},
  [7682] = {.lex_state = 117, .external_lex_state = 12},
  [7683] = {.lex_state = 117, .external_lex_state = 12},
  [7684] = {.lex_state = 117, .external_lex_state = 12},
  [7685] = {.lex_state = 117, .external_lex_state = 12},
  [7686] = {.lex_state = 117, .external_lex_state = 12},
  [7687] = {.lex_state = 117, .external_lex_state = 12},
  [7688] = {.lex_state = 117, .external_lex_state = 12},
  [7689] = {.lex_state = 117, .external_lex_state = 12},
  [7690] = {.lex_state = 117, .external_lex_state = 12},
  [7691] = {.lex_state = 117, .external_lex_state = 12},
  [7692] = {.lex_state = 117, .external_lex_state = 12},
  [7693] = {.lex_state = 117, .external_lex_state = 12},
  [7694] = {.lex_state = 117, .external_lex_state = 12},
  [7695] = {.lex_state = 117, .external_lex_state = 12},
  [7696] = {.lex_state = 117, .external_lex_state = 12},
  [7697] = {.lex_state = 117, .external_lex_state = 12},
  [7698] = {.lex_state = 117, .external_lex_state = 12},
  [7699] = {.lex_state = 117, .external_lex_state = 12},
  [7700] = {.lex_state = 117, .external_lex_state = 12},
  [7701] = {.lex_state = 117, .external_lex_state = 12},
  [7702] = {.lex_state = 117, .external_lex_state = 12},
  [7703] = {.lex_state = 117, .external_lex_state = 12},
  [7704] = {.lex_state = 117, .external_lex_state = 12},
  [7705] = {.lex_state = 117, .external_lex_state = 12},
  [7706] = {.lex_state = 117, .external_lex_state = 12},
  [7707] = {.lex_state = 117, .external_lex_state = 12},
  [7708] = {.lex_state = 117, .external_lex_state = 12},
  [7709] = {.lex_state = 117, .external_lex_state = 12},
  [7710] = {.lex_state = 117, .external_lex_state = 12},
  [7711] = {.lex_state = 117, .external_lex_state = 12},
  [7712] = {.lex_state = 117, .external_lex_state = 12},
  [7713] = {.lex_state = 117, .external_lex_state = 12},
  [7714] = {.lex_state = 117, .external_lex_state = 12},
  [7715] = {.lex_state = 117, .external_lex_state = 12},
  [7716] = {.lex_state = 117, .external_lex_state = 12},
  [7717] = {.lex_state = 117, .external_lex_state = 12},
  [7718] = {.lex_state = 117, .external_lex_state = 12},
  [7719] = {.lex_state = 117, .external_lex_state = 12},
  [7720] = {.lex_state = 117, .external_lex_state = 12},
  [7721] = {.lex_state = 117, .external_lex_state = 12},
  [7722] = {.lex_state = 117, .external_lex_state = 12},
  [7723] = {.lex_state = 117, .external_lex_state = 12},
  [7724] = {.lex_state = 117, .external_lex_state = 12},
  [7725] = {.lex_state = 117, .external_lex_state = 12},
  [7726] = {.lex_state = 117, .external_lex_state = 12},
  [7727] = {.lex_state = 117, .external_lex_state = 12},
  [7728] = {.lex_state = 117, .external_lex_state = 12},
  [7729] = {.lex_state = 117, .external_lex_state = 12},
  [7730] = {.lex_state = 117, .external_lex_state = 12},
  [7731] = {.lex_state = 117, .external_lex_state = 12},
  [7732] = {.lex_state = 117, .external_lex_state = 12},
  [7733] = {.lex_state = 117, .external_lex_state = 12},
  [7734] = {.lex_state = 117, .external_lex_state = 12},
  [7735] = {.lex_state = 117, .external_lex_state = 12},
  [7736] = {.lex_state = 117, .external_lex_state = 12},
  [7737] = {.lex_state = 117, .external_lex_state = 12},
  [7738] = {.lex_state = 117, .external_lex_state = 12},
  [7739] = {.lex_state = 117, .external_lex_state = 12},
  [7740] = {.lex_state = 117, .external_lex_state = 12},
  [7741] = {.lex_state = 117, .external_lex_state = 12},
  [7742] = {.lex_state = 117, .external_lex_state = 2},
  [7743] = {.lex_state = 117, .external_lex_state = 12},
  [7744] = {.lex_state = 117, .external_lex_state = 12},
  [7745] = {.lex_state = 117, .external_lex_state = 12},
  [7746] = {.lex_state = 117, .external_lex_state = 12},
  [7747] = {.lex_state = 117, .external_lex_state = 12},
  [7748] = {.lex_state = 117, .external_lex_state = 12},
  [7749] = {.lex_state = 117, .external_lex_state = 12},
  [7750] = {.lex_state = 117, .external_lex_state = 12},
  [7751] = {.lex_state = 117, .external_lex_state = 12},
  [7752] = {.lex_state = 117, .external_lex_state = 12},
  [7753] = {.lex_state = 117, .external_lex_state = 12},
  [7754] = {.lex_state = 117, .external_lex_state = 12},
  [7755] = {.lex_state = 117, .external_lex_state = 12},
  [7756] = {.lex_state = 117, .external_lex_state = 12},
  [7757] = {.lex_state = 117, .external_lex_state = 12},
  [7758] = {.lex_state = 117, .external_lex_state = 12},
  [7759] = {.lex_state = 117, .external_lex_state = 12},
  [7760] = {.lex_state = 117, .external_lex_state = 12},
  [7761] = {.lex_state = 117, .external_lex_state = 12},
  [7762] = {.lex_state = 117, .external_lex_state = 12},
  [7763] = {.lex_state = 117, .external_lex_state = 12},
  [7764] = {.lex_state = 117, .external_lex_state = 12},
  [7765] = {.lex_state = 117, .external_lex_state = 12},
  [7766] = {.lex_state = 117, .external_lex_state = 12},
  [7767] = {.lex_state = 117, .external_lex_state = 12},
  [7768] = {.lex_state = 117, .external_lex_state = 12},
  [7769] = {.lex_state = 117, .external_lex_state = 12},
  [7770] = {.lex_state = 117, .external_lex_state = 12},
  [7771] = {.lex_state = 117, .external_lex_state = 12},
  [7772] = {.lex_state = 117, .external_lex_state = 12},
  [7773] = {.lex_state = 117, .external_lex_state = 12},
  [7774] = {.lex_state = 6},
  [7775] = {.lex_state = 117, .external_lex_state = 12},
  [7776] = {.lex_state = 117, .external_lex_state = 12},
  [7777] = {.lex_state = 117, .external_lex_state = 12},
  [7778] = {.lex_state = 117, .external_lex_state = 12},
  [7779] = {.lex_state = 117, .external_lex_state = 12},
  [7780] = {.lex_state = 117, .external_lex_state = 12},
  [7781] = {.lex_state = 117, .external_lex_state = 12},
  [7782] = {.lex_state = 117, .external_lex_state = 12},
  [7783] = {.lex_state = 117, .external_lex_state = 12},
  [7784] = {.lex_state = 117, .external_lex_state = 12},
  [7785] = {.lex_state = 117, .external_lex_state = 12},
  [7786] = {.lex_state = 117, .external_lex_state = 12},
  [7787] = {.lex_state = 117, .external_lex_state = 12},
  [7788] = {.lex_state = 117, .external_lex_state = 12},
  [7789] = {.lex_state = 117, .external_lex_state = 12},
  [7790] = {.lex_state = 117, .external_lex_state = 12},
  [7791] = {.lex_state = 117, .external_lex_state = 12},
  [7792] = {.lex_state = 117, .external_lex_state = 12},
  [7793] = {.lex_state = 117, .external_lex_state = 12},
  [7794] = {.lex_state = 117, .external_lex_state = 12},
  [7795] = {.lex_state = 117, .external_lex_state = 12},
  [7796] = {.lex_state = 117, .external_lex_state = 12},
  [7797] = {.lex_state = 117, .external_lex_state = 12},
  [7798] = {.lex_state = 117, .external_lex_state = 12},
  [7799] = {.lex_state = 117, .external_lex_state = 12},
  [7800] = {.lex_state = 117, .external_lex_state = 12},
  [7801] = {.lex_state = 117, .external_lex_state = 12},
  [7802] = {.lex_state = 117, .external_lex_state = 12},
  [7803] = {.lex_state = 117, .external_lex_state = 12},
  [7804] = {.lex_state = 117, .external_lex_state = 12},
  [7805] = {.lex_state = 117, .external_lex_state = 12},
  [7806] = {.lex_state = 117, .external_lex_state = 12},
  [7807] = {.lex_state = 117, .external_lex_state = 12},
  [7808] = {.lex_state = 117, .external_lex_state = 12},
  [7809] = {.lex_state = 117, .external_lex_state = 12},
  [7810] = {.lex_state = 117, .external_lex_state = 12},
  [7811] = {.lex_state = 117, .external_lex_state = 12},
  [7812] = {.lex_state = 117, .external_lex_state = 12},
  [7813] = {.lex_state = 117, .external_lex_state = 12},
  [7814] = {.lex_state = 117, .external_lex_state = 12},
  [7815] = {.lex_state = 117, .external_lex_state = 12},
  [7816] = {.lex_state = 117, .external_lex_state = 12},
  [7817] = {.lex_state = 117, .external_lex_state = 12},
  [7818] = {.lex_state = 117, .external_lex_state = 12},
  [7819] = {.lex_state = 117, .external_lex_state = 12},
  [7820] = {.lex_state = 117, .external_lex_state = 12},
  [7821] = {.lex_state = 117, .external_lex_state = 12},
  [7822] = {.lex_state = 117, .external_lex_state = 12},
  [7823] = {.lex_state = 117, .external_lex_state = 12},
  [7824] = {.lex_state = 117, .external_lex_state = 12},
  [7825] = {.lex_state = 117, .external_lex_state = 12},
  [7826] = {.lex_state = 117, .external_lex_state = 12},
  [7827] = {.lex_state = 117, .external_lex_state = 12},
  [7828] = {.lex_state = 117, .external_lex_state = 12},
  [7829] = {.lex_state = 117, .external_lex_state = 12},
  [7830] = {.lex_state = 117, .external_lex_state = 12},
  [7831] = {.lex_state = 117, .external_lex_state = 12},
  [7832] = {.lex_state = 117, .external_lex_state = 12},
  [7833] = {.lex_state = 117, .external_lex_state = 12},
  [7834] = {.lex_state = 117, .external_lex_state = 12},
  [7835] = {.lex_state = 117, .external_lex_state = 12},
  [7836] = {.lex_state = 117, .external_lex_state = 12},
  [7837] = {.lex_state = 117, .external_lex_state = 12},
  [7838] = {.lex_state = 117, .external_lex_state = 12},
  [7839] = {.lex_state = 117, .external_lex_state = 12},
  [7840] = {.lex_state = 117, .external_lex_state = 12},
  [7841] = {.lex_state = 117, .external_lex_state = 12},
  [7842] = {.lex_state = 117, .external_lex_state = 12},
  [7843] = {.lex_state = 117, .external_lex_state = 12},
  [7844] = {.lex_state = 117, .external_lex_state = 12},
  [7845] = {.lex_state = 117, .external_lex_state = 12},
  [7846] = {.lex_state = 117, .external_lex_state = 12},
  [7847] = {.lex_state = 117, .external_lex_state = 12},
  [7848] = {.lex_state = 117, .external_lex_state = 12},
  [7849] = {.lex_state = 117, .external_lex_state = 12},
  [7850] = {.lex_state = 117, .external_lex_state = 12},
  [7851] = {.lex_state = 117, .external_lex_state = 12},
  [7852] = {.lex_state = 117, .external_lex_state = 12},
  [7853] = {.lex_state = 117, .external_lex_state = 12},
  [7854] = {.lex_state = 117, .external_lex_state = 12},
  [7855] = {.lex_state = 117, .external_lex_state = 12},
  [7856] = {.lex_state = 117, .external_lex_state = 12},
  [7857] = {.lex_state = 117, .external_lex_state = 12},
  [7858] = {.lex_state = 117, .external_lex_state = 12},
  [7859] = {.lex_state = 117, .external_lex_state = 12},
  [7860] = {.lex_state = 117, .external_lex_state = 12},
  [7861] = {.lex_state = 117, .external_lex_state = 12},
  [7862] = {.lex_state = 117, .external_lex_state = 12},
  [7863] = {.lex_state = 117, .external_lex_state = 12},
  [7864] = {.lex_state = 117, .external_lex_state = 12},
  [7865] = {.lex_state = 117, .external_lex_state = 12},
  [7866] = {.lex_state = 117, .external_lex_state = 12},
  [7867] = {.lex_state = 117, .external_lex_state = 12},
  [7868] = {.lex_state = 117, .external_lex_state = 12},
  [7869] = {.lex_state = 117, .external_lex_state = 12},
  [7870] = {.lex_state = 117, .external_lex_state = 12},
  [7871] = {.lex_state = 117, .external_lex_state = 12},
  [7872] = {.lex_state = 117, .external_lex_state = 12},
  [7873] = {.lex_state = 117, .external_lex_state = 12},
  [7874] = {.lex_state = 117, .external_lex_state = 12},
  [7875] = {.lex_state = 117, .external_lex_state = 12},
  [7876] = {.lex_state = 117, .external_lex_state = 12},
  [7877] = {.lex_state = 117, .external_lex_state = 12},
  [7878] = {.lex_state = 117, .external_lex_state = 12},
  [7879] = {.lex_state = 117, .external_lex_state = 12},
  [7880] = {.lex_state = 117, .external_lex_state = 2},
  [7881] = {.lex_state = 117, .external_lex_state = 23},
  [7882] = {.lex_state = 6},
  [7883] = {.lex_state = 117, .external_lex_state = 23},
  [7884] = {.lex_state = 117, .external_lex_state = 23},
  [7885] = {.lex_state = 117, .external_lex_state = 12},
  [7886] = {.lex_state = 117, .external_lex_state = 23},
  [7887] = {.lex_state = 117, .external_lex_state = 23},
  [7888] = {.lex_state = 117, .external_lex_state = 12},
  [7889] = {.lex_state = 117, .external_lex_state = 15},
  [7890] = {.lex_state = 117, .external_lex_state = 23},
  [7891] = {.lex_state = 117, .external_lex_state = 23},
  [7892] = {.lex_state = 117, .external_lex_state = 23},
  [7893] = {.lex_state = 117, .external_lex_state = 23},
  [7894] = {.lex_state = 117, .external_lex_state = 12},
  [7895] = {.lex_state = 117, .external_lex_state = 23},
  [7896] = {.lex_state = 117, .external_lex_state = 23},
  [7897] = {.lex_state = 117, .external_lex_state = 23},
  [7898] = {.lex_state = 117, .external_lex_state = 23},
  [7899] = {.lex_state = 6},
  [7900] = {.lex_state = 117, .external_lex_state = 2},
  [7901] = {.lex_state = 117, .external_lex_state = 15},
  [7902] = {.lex_state = 117, .external_lex_state = 12},
  [7903] = {.lex_state = 117, .external_lex_state = 12},
  [7904] = {.lex_state = 117, .external_lex_state = 12},
  [7905] = {.lex_state = 117, .external_lex_state = 15},
  [7906] = {.lex_state = 117, .external_lex_state = 12},
  [7907] = {.lex_state = 117, .external_lex_state = 12},
  [7908] = {.lex_state = 117, .external_lex_state = 12},
  [7909] = {.lex_state = 117, .external_lex_state = 12},
  [7910] = {.lex_state = 117, .external_lex_state = 12},
  [7911] = {.lex_state = 117, .external_lex_state = 12},
  [7912] = {.lex_state = 117, .external_lex_state = 12},
  [7913] = {.lex_state = 117, .external_lex_state = 12},
  [7914] = {.lex_state = 117, .external_lex_state = 12},
  [7915] = {.lex_state = 117, .external_lex_state = 12},
  [7916] = {.lex_state = 117, .external_lex_state = 12},
  [7917] = {.lex_state = 117, .external_lex_state = 12},
  [7918] = {.lex_state = 117, .external_lex_state = 12},
  [7919] = {.lex_state = 117, .external_lex_state = 12},
  [7920] = {.lex_state = 117, .external_lex_state = 12},
  [7921] = {.lex_state = 117, .external_lex_state = 12},
  [7922] = {.lex_state = 117, .external_lex_state = 12},
  [7923] = {.lex_state = 117, .external_lex_state = 12},
  [7924] = {.lex_state = 117, .external_lex_state = 12},
  [7925] = {.lex_state = 117, .external_lex_state = 12},
  [7926] = {.lex_state = 117, .external_lex_state = 12},
  [7927] = {.lex_state = 117, .external_lex_state = 12},
  [7928] = {.lex_state = 117, .external_lex_state = 12},
  [7929] = {.lex_state = 117, .external_lex_state = 12},
  [7930] = {.lex_state = 117, .external_lex_state = 12},
  [7931] = {.lex_state = 117, .external_lex_state = 12},
  [7932] = {.lex_state = 117, .external_lex_state = 12},
  [7933] = {.lex_state = 117, .external_lex_state = 12},
  [7934] = {.lex_state = 117, .external_lex_state = 12},
  [7935] = {.lex_state = 117, .external_lex_state = 12},
  [7936] = {.lex_state = 117, .external_lex_state = 12},
  [7937] = {.lex_state = 117, .external_lex_state = 16},
  [7938] = {.lex_state = 117, .external_lex_state = 15},
  [7939] = {.lex_state = 117, .external_lex_state = 15},
  [7940] = {.lex_state = 117, .external_lex_state = 15},
  [7941] = {.lex_state = 117, .external_lex_state = 15},
  [7942] = {.lex_state = 117, .external_lex_state = 15},
  [7943] = {.lex_state = 117, .external_lex_state = 15},
  [7944] = {.lex_state = 117, .external_lex_state = 15},
  [7945] = {.lex_state = 117, .external_lex_state = 15},
  [7946] = {.lex_state = 117, .external_lex_state = 15},
  [7947] = {.lex_state = 117, .external_lex_state = 10},
  [7948] = {.lex_state = 117, .external_lex_state = 15},
  [7949] = {.lex_state = 117, .external_lex_state = 15},
  [7950] = {.lex_state = 117, .external_lex_state = 15},
  [7951] = {.lex_state = 117, .external_lex_state = 15},
  [7952] = {.lex_state = 117, .external_lex_state = 10},
  [7953] = {.lex_state = 117, .external_lex_state = 15},
  [7954] = {.lex_state = 117, .external_lex_state = 20},
  [7955] = {.lex_state = 117, .external_lex_state = 15},
  [7956] = {.lex_state = 117, .external_lex_state = 15},
  [7957] = {.lex_state = 117, .external_lex_state = 15},
  [7958] = {.lex_state = 117, .external_lex_state = 15},
  [7959] = {.lex_state = 117, .external_lex_state = 15},
  [7960] = {.lex_state = 117, .external_lex_state = 15},
  [7961] = {.lex_state = 117, .external_lex_state = 20},
  [7962] = {.lex_state = 117, .external_lex_state = 10},
  [7963] = {.lex_state = 117, .external_lex_state = 15},
  [7964] = {.lex_state = 117, .external_lex_state = 15},
  [7965] = {.lex_state = 117, .external_lex_state = 15},
  [7966] = {.lex_state = 117, .external_lex_state = 15},
  [7967] = {.lex_state = 117, .external_lex_state = 20},
  [7968] = {.lex_state = 117, .external_lex_state = 15},
  [7969] = {.lex_state = 6},
  [7970] = {.lex_state = 117, .external_lex_state = 18},
  [7971] = {.lex_state = 117, .external_lex_state = 20},
  [7972] = {.lex_state = 117, .external_lex_state = 10},
  [7973] = {.lex_state = 117, .external_lex_state = 15},
  [7974] = {.lex_state = 117, .external_lex_state = 15},
  [7975] = {.lex_state = 117, .external_lex_state = 15},
  [7976] = {.lex_state = 117, .external_lex_state = 15},
  [7977] = {.lex_state = 117, .external_lex_state = 10},
  [7978] = {.lex_state = 117, .external_lex_state = 15},
  [7979] = {.lex_state = 117, .external_lex_state = 10},
  [7980] = {.lex_state = 117, .external_lex_state = 10},
  [7981] = {.lex_state = 117, .external_lex_state = 10},
  [7982] = {.lex_state = 117, .external_lex_state = 10},
  [7983] = {.lex_state = 117, .external_lex_state = 15},
  [7984] = {.lex_state = 117, .external_lex_state = 20},
  [7985] = {.lex_state = 117, .external_lex_state = 20},
  [7986] = {.lex_state = 117, .external_lex_state = 15},
  [7987] = {.lex_state = 117, .external_lex_state = 15},
  [7988] = {.lex_state = 117, .external_lex_state = 15},
  [7989] = {.lex_state = 117, .external_lex_state = 15},
  [7990] = {.lex_state = 117, .external_lex_state = 10},
  [7991] = {.lex_state = 117, .external_lex_state = 15},
  [7992] = {.lex_state = 117, .external_lex_state = 20},
  [7993] = {.lex_state = 117, .external_lex_state = 20},
  [7994] = {.lex_state = 117, .external_lex_state = 20},
  [7995] = {.lex_state = 117, .external_lex_state = 20},
  [7996] = {.lex_state = 117, .external_lex_state = 15},
  [7997] = {.lex_state = 117, .external_lex_state = 16},
  [7998] = {.lex_state = 117, .external_lex_state = 15},
  [7999] = {.lex_state = 117, .external_lex_state = 15},
  [8000] = {.lex_state = 117, .external_lex_state = 15},
  [8001] = {.lex_state = 117, .external_lex_state = 20},
  [8002] = {.lex_state = 117, .external_lex_state = 16},
  [8003] = {.lex_state = 10, .external_lex_state = 12},
  [8004] = {.lex_state = 117, .external_lex_state = 15},
  [8005] = {.lex_state = 117, .external_lex_state = 16},
  [8006] = {.lex_state = 117, .external_lex_state = 15},
  [8007] = {.lex_state = 117, .external_lex_state = 20},
  [8008] = {.lex_state = 117, .external_lex_state = 16},
  [8009] = {.lex_state = 117, .external_lex_state = 15},
  [8010] = {.lex_state = 117, .external_lex_state = 15},
  [8011] = {.lex_state = 117, .external_lex_state = 15},
  [8012] = {.lex_state = 117, .external_lex_state = 15},
  [8013] = {.lex_state = 117, .external_lex_state = 15},
  [8014] = {.lex_state = 117, .external_lex_state = 15},
  [8015] = {.lex_state = 117, .external_lex_state = 15},
  [8016] = {.lex_state = 117, .external_lex_state = 15},
  [8017] = {.lex_state = 117, .external_lex_state = 15},
  [8018] = {.lex_state = 117, .external_lex_state = 15},
  [8019] = {.lex_state = 117, .external_lex_state = 15},
  [8020] = {.lex_state = 117, .external_lex_state = 15},
  [8021] = {.lex_state = 117, .external_lex_state = 15},
  [8022] = {.lex_state = 117, .external_lex_state = 15},
  [8023] = {.lex_state = 117, .external_lex_state = 15},
  [8024] = {.lex_state = 117, .external_lex_state = 20},
  [8025] = {.lex_state = 117, .external_lex_state = 20},
  [8026] = {.lex_state = 117, .external_lex_state = 20},
  [8027] = {.lex_state = 117, .external_lex_state = 15},
  [8028] = {.lex_state = 117, .external_lex_state = 20},
  [8029] = {.lex_state = 117, .external_lex_state = 16},
  [8030] = {.lex_state = 117, .external_lex_state = 12},
  [8031] = {.lex_state = 117, .external_lex_state = 10},
  [8032] = {.lex_state = 117, .external_lex_state = 10},
  [8033] = {.lex_state = 117, .external_lex_state = 10},
  [8034] = {.lex_state = 117, .external_lex_state = 16},
  [8035] = {.lex_state = 117, .external_lex_state = 18},
  [8036] = {.lex_state = 117, .external_lex_state = 10},
  [8037] = {.lex_state = 117, .external_lex_state = 18},
  [8038] = {.lex_state = 117, .external_lex_state = 12},
  [8039] = {.lex_state = 117, .external_lex_state = 18},
  [8040] = {.lex_state = 117, .external_lex_state = 18},
  [8041] = {.lex_state = 117, .external_lex_state = 18},
  [8042] = {.lex_state = 117, .external_lex_state = 16},
  [8043] = {.lex_state = 117, .external_lex_state = 16},
  [8044] = {.lex_state = 117, .external_lex_state = 12},
  [8045] = {.lex_state = 117, .external_lex_state = 16},
  [8046] = {.lex_state = 117, .external_lex_state = 12},
  [8047] = {.lex_state = 117, .external_lex_state = 10},
  [8048] = {.lex_state = 117, .external_lex_state = 10},
  [8049] = {.lex_state = 117, .external_lex_state = 12},
  [8050] = {.lex_state = 117, .external_lex_state = 12},
  [8051] = {.lex_state = 117, .external_lex_state = 10},
  [8052] = {.lex_state = 117, .external_lex_state = 10},
  [8053] = {.lex_state = 117, .external_lex_state = 10},
  [8054] = {.lex_state = 117, .external_lex_state = 12},
  [8055] = {.lex_state = 117, .external_lex_state = 12},
  [8056] = {.lex_state = 117, .external_lex_state = 12},
  [8057] = {.lex_state = 117, .external_lex_state = 12},
  [8058] = {.lex_state = 117, .external_lex_state = 10},
  [8059] = {.lex_state = 117, .external_lex_state = 12},
  [8060] = {.lex_state = 117, .external_lex_state = 12},
  [8061] = {.lex_state = 117, .external_lex_state = 16},
  [8062] = {.lex_state = 117, .external_lex_state = 16},
  [8063] = {.lex_state = 117, .external_lex_state = 12},
  [8064] = {.lex_state = 117, .external_lex_state = 12},
  [8065] = {.lex_state = 117, .external_lex_state = 18},
  [8066] = {.lex_state = 117, .external_lex_state = 12},
  [8067] = {.lex_state = 117, .external_lex_state = 12},
  [8068] = {.lex_state = 117, .external_lex_state = 16},
  [8069] = {.lex_state = 117, .external_lex_state = 18},
  [8070] = {.lex_state = 117, .external_lex_state = 10},
  [8071] = {.lex_state = 117, .external_lex_state = 10},
  [8072] = {.lex_state = 117, .external_lex_state = 12},
  [8073] = {.lex_state = 117, .external_lex_state = 12},
  [8074] = {.lex_state = 117, .external_lex_state = 12},
  [8075] = {.lex_state = 117, .external_lex_state = 16},
  [8076] = {.lex_state = 117, .external_lex_state = 12},
  [8077] = {.lex_state = 117, .external_lex_state = 18},
  [8078] = {.lex_state = 117, .external_lex_state = 12},
  [8079] = {.lex_state = 117, .external_lex_state = 18},
  [8080] = {.lex_state = 117, .external_lex_state = 18},
  [8081] = {.lex_state = 117, .external_lex_state = 12},
  [8082] = {.lex_state = 117, .external_lex_state = 12},
  [8083] = {.lex_state = 117, .external_lex_state = 10},
  [8084] = {.lex_state = 117, .external_lex_state = 10},
  [8085] = {.lex_state = 117, .external_lex_state = 10},
  [8086] = {.lex_state = 117, .external_lex_state = 10},
  [8087] = {.lex_state = 117, .external_lex_state = 16},
  [8088] = {.lex_state = 117, .external_lex_state = 10},
  [8089] = {.lex_state = 117, .external_lex_state = 10},
  [8090] = {.lex_state = 117, .external_lex_state = 10},
  [8091] = {.lex_state = 117, .external_lex_state = 10},
  [8092] = {.lex_state = 117, .external_lex_state = 10},
  [8093] = {.lex_state = 117, .external_lex_state = 12},
  [8094] = {.lex_state = 117, .external_lex_state = 10},
  [8095] = {.lex_state = 117, .external_lex_state = 12},
  [8096] = {.lex_state = 117, .external_lex_state = 12},
  [8097] = {.lex_state = 117, .external_lex_state = 16},
  [8098] = {.lex_state = 117, .external_lex_state = 18},
  [8099] = {.lex_state = 117, .external_lex_state = 12},
  [8100] = {.lex_state = 117, .external_lex_state = 12},
  [8101] = {.lex_state = 117, .external_lex_state = 10},
  [8102] = {.lex_state = 117, .external_lex_state = 12},
  [8103] = {.lex_state = 117, .external_lex_state = 10},
  [8104] = {.lex_state = 117, .external_lex_state = 10},
  [8105] = {.lex_state = 117, .external_lex_state = 12},
  [8106] = {.lex_state = 117, .external_lex_state = 12},
  [8107] = {.lex_state = 117, .external_lex_state = 10},
  [8108] = {.lex_state = 117, .external_lex_state = 10},
  [8109] = {.lex_state = 117, .external_lex_state = 10},
  [8110] = {.lex_state = 117, .external_lex_state = 12},
  [8111] = {.lex_state = 117, .external_lex_state = 10},
  [8112] = {.lex_state = 117, .external_lex_state = 10},
  [8113] = {.lex_state = 117, .external_lex_state = 16},
  [8114] = {.lex_state = 117, .external_lex_state = 16},
  [8115] = {.lex_state = 117, .external_lex_state = 16},
  [8116] = {.lex_state = 117, .external_lex_state = 12},
  [8117] = {.lex_state = 117, .external_lex_state = 12},
  [8118] = {.lex_state = 117, .external_lex_state = 12},
  [8119] = {.lex_state = 117, .external_lex_state = 12},
  [8120] = {.lex_state = 10},
  [8121] = {.lex_state = 117, .external_lex_state = 12},
  [8122] = {.lex_state = 6},
  [8123] = {.lex_state = 6},
  [8124] = {.lex_state = 6},
  [8125] = {.lex_state = 6},
  [8126] = {.lex_state = 117, .external_lex_state = 12},
  [8127] = {.lex_state = 117, .external_lex_state = 12},
  [8128] = {.lex_state = 117, .external_lex_state = 16},
  [8129] = {.lex_state = 117, .external_lex_state = 16},
  [8130] = {.lex_state = 117, .external_lex_state = 16},
  [8131] = {.lex_state = 117, .external_lex_state = 16},
  [8132] = {.lex_state = 117, .external_lex_state = 16},
  [8133] = {.lex_state = 117, .external_lex_state = 16},
  [8134] = {.lex_state = 117, .external_lex_state = 16},
  [8135] = {.lex_state = 117, .external_lex_state = 16},
  [8136] = {.lex_state = 117, .external_lex_state = 12},
  [8137] = {.lex_state = 117, .external_lex_state = 16},
  [8138] = {.lex_state = 117, .external_lex_state = 12},
  [8139] = {.lex_state = 117, .external_lex_state = 12},
  [8140] = {.lex_state = 117, .external_lex_state = 16},
  [8141] = {.lex_state = 117, .external_lex_state = 16},
  [8142] = {.lex_state = 117, .external_lex_state = 16},
  [8143] = {.lex_state = 117, .external_lex_state = 16},
  [8144] = {.lex_state = 117, .external_lex_state = 16},
  [8145] = {.lex_state = 117, .external_lex_state = 16},
  [8146] = {.lex_state = 117, .external_lex_state = 16},
  [8147] = {.lex_state = 117, .external_lex_state = 12},
  [8148] = {.lex_state = 117, .external_lex_state = 16},
  [8149] = {.lex_state = 6},
  [8150] = {.lex_state = 117, .external_lex_state = 17},
  [8151] = {.lex_state = 117},
  [8152] = {.lex_state = 117, .external_lex_state = 23},
  [8153] = {.lex_state = 3, .external_lex_state = 10},
  [8154] = {.lex_state = 117, .external_lex_state = 12},
  [8155] = {.lex_state = 117, .external_lex_state = 12},
  [8156] = {.lex_state = 117, .external_lex_state = 23},
  [8157] = {.lex_state = 117, .external_lex_state = 12},
  [8158] = {.lex_state = 3, .external_lex_state = 10},
  [8159] = {.lex_state = 3, .external_lex_state = 10},
  [8160] = {.lex_state = 3, .external_lex_state = 10},
  [8161] = {.lex_state = 117, .external_lex_state = 23},
  [8162] = {.lex_state = 117, .external_lex_state = 23},
  [8163] = {.lex_state = 117, .external_lex_state = 23},
  [8164] = {.lex_state = 117, .external_lex_state = 23},
  [8165] = {.lex_state = 117, .external_lex_state = 23},
  [8166] = {.lex_state = 117, .external_lex_state = 23},
  [8167] = {.lex_state = 117, .external_lex_state = 23},
  [8168] = {.lex_state = 117, .external_lex_state = 23},
  [8169] = {.lex_state = 117, .external_lex_state = 23},
  [8170] = {.lex_state = 117, .external_lex_state = 23},
  [8171] = {.lex_state = 117, .external_lex_state = 23},
  [8172] = {.lex_state = 117, .external_lex_state = 23},
  [8173] = {.lex_state = 117, .external_lex_state = 23},
  [8174] = {.lex_state = 117, .external_lex_state = 23},
  [8175] = {.lex_state = 117, .external_lex_state = 23},
  [8176] = {.lex_state = 117, .external_lex_state = 23},
  [8177] = {.lex_state = 117, .external_lex_state = 23},
  [8178] = {.lex_state = 117, .external_lex_state = 23},
  [8179] = {.lex_state = 117, .external_lex_state = 23},
  [8180] = {.lex_state = 117, .external_lex_state = 23},
  [8181] = {.lex_state = 117, .external_lex_state = 23},
  [8182] = {.lex_state = 117, .external_lex_state = 23},
  [8183] = {.lex_state = 117, .external_lex_state = 23},
  [8184] = {.lex_state = 117, .external_lex_state = 23},
  [8185] = {.lex_state = 6},
  [8186] = {.lex_state = 117, .external_lex_state = 23},
  [8187] = {.lex_state = 117, .external_lex_state = 23},
  [8188] = {.lex_state = 117, .external_lex_state = 23},
  [8189] = {.lex_state = 117, .external_lex_state = 23},
  [8190] = {.lex_state = 117, .external_lex_state = 23},
  [8191] = {.lex_state = 117, .external_lex_state = 23},
  [8192] = {.lex_state = 117, .external_lex_state = 23},
  [8193] = {.lex_state = 117, .external_lex_state = 23},
  [8194] = {.lex_state = 117, .external_lex_state = 23},
  [8195] = {.lex_state = 117, .external_lex_state = 23},
  [8196] = {.lex_state = 117, .external_lex_state = 12},
  [8197] = {.lex_state = 117, .external_lex_state = 23},
  [8198] = {.lex_state = 117, .external_lex_state = 23},
  [8199] = {.lex_state = 117, .external_lex_state = 23},
  [8200] = {.lex_state = 117, .external_lex_state = 23},
  [8201] = {.lex_state = 6, .external_lex_state = 2},
  [8202] = {.lex_state = 117, .external_lex_state = 23},
  [8203] = {.lex_state = 117, .external_lex_state = 23},
  [8204] = {.lex_state = 117, .external_lex_state = 23},
  [8205] = {.lex_state = 117, .external_lex_state = 23},
  [8206] = {.lex_state = 117, .external_lex_state = 23},
  [8207] = {.lex_state = 117, .external_lex_state = 23},
  [8208] = {.lex_state = 117, .external_lex_state = 23},
  [8209] = {.lex_state = 117, .external_lex_state = 23},
  [8210] = {.lex_state = 117, .external_lex_state = 23},
  [8211] = {.lex_state = 117, .external_lex_state = 23},
  [8212] = {.lex_state = 117, .external_lex_state = 10},
  [8213] = {.lex_state = 117, .external_lex_state = 12},
  [8214] = {.lex_state = 117},
  [8215] = {.lex_state = 6},
  [8216] = {.lex_state = 6},
  [8217] = {.lex_state = 6},
  [8218] = {.lex_state = 6},
  [8219] = {.lex_state = 6},
  [8220] = {.lex_state = 117, .external_lex_state = 12},
  [8221] = {.lex_state = 117, .external_lex_state = 23},
  [8222] = {.lex_state = 117, .external_lex_state = 23},
  [8223] = {.lex_state = 117, .external_lex_state = 23},
  [8224] = {.lex_state = 117, .external_lex_state = 12},
  [8225] = {.lex_state = 117, .external_lex_state = 12},
  [8226] = {.lex_state = 117, .external_lex_state = 23},
  [8227] = {.lex_state = 117, .external_lex_state = 23},
  [8228] = {.lex_state = 6, .external_lex_state = 2},
  [8229] = {.lex_state = 117, .external_lex_state = 12},
  [8230] = {.lex_state = 117, .external_lex_state = 23},
  [8231] = {.lex_state = 117, .external_lex_state = 23},
  [8232] = {.lex_state = 117, .external_lex_state = 23},
  [8233] = {.lex_state = 117, .external_lex_state = 23},
  [8234] = {.lex_state = 117, .external_lex_state = 12},
  [8235] = {.lex_state = 117, .external_lex_state = 23},
  [8236] = {.lex_state = 117, .external_lex_state = 23},
  [8237] = {.lex_state = 117, .external_lex_state = 10},
  [8238] = {.lex_state = 6},
  [8239] = {.lex_state = 6, .external_lex_state = 2},
  [8240] = {.lex_state = 117, .external_lex_state = 10},
  [8241] = {.lex_state = 6},
  [8242] = {.lex_state = 117, .external_lex_state = 10},
  [8243] = {.lex_state = 3, .external_lex_state = 10},
  [8244] = {.lex_state = 6},
  [8245] = {.lex_state = 117, .external_lex_state = 10},
  [8246] = {.lex_state = 6},
  [8247] = {.lex_state = 6},
  [8248] = {.lex_state = 3, .external_lex_state = 10},
  [8249] = {.lex_state = 6},
  [8250] = {.lex_state = 6},
  [8251] = {.lex_state = 3, .external_lex_state = 10},
  [8252] = {.lex_state = 3, .external_lex_state = 10},
  [8253] = {.lex_state = 3, .external_lex_state = 10},
  [8254] = {.lex_state = 6},
  [8255] = {.lex_state = 6, .external_lex_state = 2},
  [8256] = {.lex_state = 6},
  [8257] = {.lex_state = 6},
  [8258] = {.lex_state = 6},
  [8259] = {.lex_state = 6},
  [8260] = {.lex_state = 6},
  [8261] = {.lex_state = 6},
  [8262] = {.lex_state = 6},
  [8263] = {.lex_state = 6},
  [8264] = {.lex_state = 6},
  [8265] = {.lex_state = 6},
  [8266] = {.lex_state = 6},
  [8267] = {.lex_state = 6},
  [8268] = {.lex_state = 6, .external_lex_state = 2},
  [8269] = {.lex_state = 6},
  [8270] = {.lex_state = 6},
  [8271] = {.lex_state = 6},
  [8272] = {.lex_state = 6},
  [8273] = {.lex_state = 6},
  [8274] = {.lex_state = 6},
  [8275] = {.lex_state = 6},
  [8276] = {.lex_state = 6},
  [8277] = {.lex_state = 6},
  [8278] = {.lex_state = 6},
  [8279] = {.lex_state = 6},
  [8280] = {.lex_state = 6},
  [8281] = {.lex_state = 6},
  [8282] = {.lex_state = 6},
  [8283] = {.lex_state = 6},
  [8284] = {.lex_state = 6},
  [8285] = {.lex_state = 6, .external_lex_state = 2},
  [8286] = {.lex_state = 6},
  [8287] = {.lex_state = 3, .external_lex_state = 10},
  [8288] = {.lex_state = 10},
  [8289] = {.lex_state = 6},
  [8290] = {.lex_state = 117, .external_lex_state = 15},
  [8291] = {.lex_state = 117, .external_lex_state = 15},
  [8292] = {.lex_state = 117, .external_lex_state = 15},
  [8293] = {.lex_state = 117, .external_lex_state = 15},
  [8294] = {.lex_state = 117, .external_lex_state = 15},
  [8295] = {.lex_state = 117, .external_lex_state = 15},
  [8296] = {.lex_state = 117, .external_lex_state = 15},
  [8297] = {.lex_state = 6},
  [8298] = {.lex_state = 117, .external_lex_state = 15},
  [8299] = {.lex_state = 117, .external_lex_state = 15},
  [8300] = {.lex_state = 117, .external_lex_state = 15},
  [8301] = {.lex_state = 117, .external_lex_state = 10},
  [8302] = {.lex_state = 6},
  [8303] = {.lex_state = 6},
  [8304] = {.lex_state = 117, .external_lex_state = 15},
  [8305] = {.lex_state = 117, .external_lex_state = 15},
  [8306] = {.lex_state = 117, .external_lex_state = 15},
  [8307] = {.lex_state = 6},
  [8308] = {.lex_state = 117, .external_lex_state = 15},
  [8309] = {.lex_state = 117, .external_lex_state = 10},
  [8310] = {.lex_state = 117, .external_lex_state = 15},
  [8311] = {.lex_state = 117, .external_lex_state = 15},
  [8312] = {.lex_state = 6},
  [8313] = {.lex_state = 117, .external_lex_state = 15},
  [8314] = {.lex_state = 117, .external_lex_state = 15},
  [8315] = {.lex_state = 117, .external_lex_state = 10},
  [8316] = {.lex_state = 117, .external_lex_state = 15},
  [8317] = {.lex_state = 10},
  [8318] = {.lex_state = 117, .external_lex_state = 15},
  [8319] = {.lex_state = 117, .external_lex_state = 15},
  [8320] = {.lex_state = 6},
  [8321] = {.lex_state = 117, .external_lex_state = 25},
  [8322] = {.lex_state = 117, .external_lex_state = 10},
  [8323] = {.lex_state = 117, .external_lex_state = 15},
  [8324] = {.lex_state = 117, .external_lex_state = 15},
  [8325] = {.lex_state = 117, .external_lex_state = 25},
  [8326] = {.lex_state = 6},
  [8327] = {.lex_state = 6},
  [8328] = {.lex_state = 117, .external_lex_state = 15},
  [8329] = {.lex_state = 117, .external_lex_state = 15},
  [8330] = {.lex_state = 117, .external_lex_state = 15},
  [8331] = {.lex_state = 117, .external_lex_state = 15},
  [8332] = {.lex_state = 117, .external_lex_state = 15},
  [8333] = {.lex_state = 6},
  [8334] = {.lex_state = 117, .external_lex_state = 25},
  [8335] = {.lex_state = 117, .external_lex_state = 25},
  [8336] = {.lex_state = 6},
  [8337] = {.lex_state = 117, .external_lex_state = 15},
  [8338] = {.lex_state = 6},
  [8339] = {.lex_state = 117, .external_lex_state = 25},
  [8340] = {.lex_state = 117, .external_lex_state = 15},
  [8341] = {.lex_state = 6},
  [8342] = {.lex_state = 117, .external_lex_state = 10},
  [8343] = {.lex_state = 117, .external_lex_state = 10},
  [8344] = {.lex_state = 117, .external_lex_state = 15},
  [8345] = {.lex_state = 117, .external_lex_state = 15},
  [8346] = {.lex_state = 117, .external_lex_state = 15},
  [8347] = {.lex_state = 117, .external_lex_state = 15},
  [8348] = {.lex_state = 117, .external_lex_state = 15},
  [8349] = {.lex_state = 117, .external_lex_state = 10},
  [8350] = {.lex_state = 117, .external_lex_state = 10},
  [8351] = {.lex_state = 117, .external_lex_state = 15},
  [8352] = {.lex_state = 117, .external_lex_state = 15},
  [8353] = {.lex_state = 6},
  [8354] = {.lex_state = 6},
  [8355] = {.lex_state = 117, .external_lex_state = 15},
  [8356] = {.lex_state = 117, .external_lex_state = 10},
  [8357] = {.lex_state = 117, .external_lex_state = 10},
  [8358] = {.lex_state = 117, .external_lex_state = 10},
  [8359] = {.lex_state = 6},
  [8360] = {.lex_state = 6},
  [8361] = {.lex_state = 6},
  [8362] = {.lex_state = 6},
  [8363] = {.lex_state = 117, .external_lex_state = 10},
  [8364] = {.lex_state = 117, .external_lex_state = 15},
  [8365] = {.lex_state = 6},
  [8366] = {.lex_state = 6},
  [8367] = {.lex_state = 6},
  [8368] = {.lex_state = 6},
  [8369] = {.lex_state = 6},
  [8370] = {.lex_state = 6},
  [8371] = {.lex_state = 117, .external_lex_state = 10},
  [8372] = {.lex_state = 6},
  [8373] = {.lex_state = 6},
  [8374] = {.lex_state = 6},
  [8375] = {.lex_state = 6},
  [8376] = {.lex_state = 6},
  [8377] = {.lex_state = 6},
  [8378] = {.lex_state = 6},
  [8379] = {.lex_state = 6},
  [8380] = {.lex_state = 6},
  [8381] = {.lex_state = 6},
  [8382] = {.lex_state = 6},
  [8383] = {.lex_state = 6},
  [8384] = {.lex_state = 117, .external_lex_state = 15},
  [8385] = {.lex_state = 6},
  [8386] = {.lex_state = 6},
  [8387] = {.lex_state = 117, .external_lex_state = 15},
  [8388] = {.lex_state = 6},
  [8389] = {.lex_state = 6},
  [8390] = {.lex_state = 6},
  [8391] = {.lex_state = 117, .external_lex_state = 15},
  [8392] = {.lex_state = 6},
  [8393] = {.lex_state = 6},
  [8394] = {.lex_state = 6},
  [8395] = {.lex_state = 6},
  [8396] = {.lex_state = 6},
  [8397] = {.lex_state = 6},
  [8398] = {.lex_state = 6},
  [8399] = {.lex_state = 6},
  [8400] = {.lex_state = 6},
  [8401] = {.lex_state = 117, .external_lex_state = 15},
  [8402] = {.lex_state = 117, .external_lex_state = 15},
  [8403] = {.lex_state = 117, .external_lex_state = 15},
  [8404] = {.lex_state = 117, .external_lex_state = 15},
  [8405] = {.lex_state = 117, .external_lex_state = 10},
  [8406] = {.lex_state = 6},
  [8407] = {.lex_state = 117, .external_lex_state = 10},
  [8408] = {.lex_state = 117, .external_lex_state = 10},
  [8409] = {.lex_state = 117, .external_lex_state = 10},
  [8410] = {.lex_state = 117, .external_lex_state = 15},
  [8411] = {.lex_state = 117, .external_lex_state = 15},
  [8412] = {.lex_state = 117, .external_lex_state = 15},
  [8413] = {.lex_state = 117, .external_lex_state = 15},
  [8414] = {.lex_state = 117, .external_lex_state = 15},
  [8415] = {.lex_state = 6},
  [8416] = {.lex_state = 10},
  [8417] = {.lex_state = 117, .external_lex_state = 10},
  [8418] = {.lex_state = 117, .external_lex_state = 10},
  [8419] = {.lex_state = 6},
  [8420] = {.lex_state = 6},
  [8421] = {.lex_state = 117, .external_lex_state = 10},
  [8422] = {.lex_state = 117, .external_lex_state = 10},
  [8423] = {.lex_state = 117, .external_lex_state = 10},
  [8424] = {.lex_state = 117, .external_lex_state = 10},
  [8425] = {.lex_state = 117, .external_lex_state = 10},
  [8426] = {.lex_state = 117, .external_lex_state = 10},
  [8427] = {.lex_state = 117, .external_lex_state = 12},
  [8428] = {.lex_state = 117, .external_lex_state = 10},
  [8429] = {.lex_state = 117, .external_lex_state = 10},
  [8430] = {.lex_state = 117, .external_lex_state = 15},
  [8431] = {.lex_state = 117, .external_lex_state = 15},
  [8432] = {.lex_state = 117, .external_lex_state = 10},
  [8433] = {.lex_state = 117, .external_lex_state = 15},
  [8434] = {.lex_state = 6},
  [8435] = {.lex_state = 6},
  [8436] = {.lex_state = 6},
  [8437] = {.lex_state = 6},
  [8438] = {.lex_state = 6},
  [8439] = {.lex_state = 117, .external_lex_state = 15},
  [8440] = {.lex_state = 117, .external_lex_state = 15},
  [8441] = {.lex_state = 6},
  [8442] = {.lex_state = 6},
  [8443] = {.lex_state = 6},
  [8444] = {.lex_state = 117, .external_lex_state = 15},
  [8445] = {.lex_state = 117, .external_lex_state = 15},
  [8446] = {.lex_state = 6},
  [8447] = {.lex_state = 6},
  [8448] = {.lex_state = 6},
  [8449] = {.lex_state = 117, .external_lex_state = 10},
  [8450] = {.lex_state = 6},
  [8451] = {.lex_state = 6},
  [8452] = {.lex_state = 6},
  [8453] = {.lex_state = 6},
  [8454] = {.lex_state = 6},
  [8455] = {.lex_state = 6},
  [8456] = {.lex_state = 6},
  [8457] = {.lex_state = 6},
  [8458] = {.lex_state = 117, .external_lex_state = 15},
  [8459] = {.lex_state = 6},
  [8460] = {.lex_state = 6},
  [8461] = {.lex_state = 6},
  [8462] = {.lex_state = 6},
  [8463] = {.lex_state = 6},
  [8464] = {.lex_state = 6},
  [8465] = {.lex_state = 6},
  [8466] = {.lex_state = 6},
  [8467] = {.lex_state = 6},
  [8468] = {.lex_state = 6},
  [8469] = {.lex_state = 6},
  [8470] = {.lex_state = 6},
  [8471] = {.lex_state = 6},
  [8472] = {.lex_state = 6},
  [8473] = {.lex_state = 6},
  [8474] = {.lex_state = 6},
  [8475] = {.lex_state = 6},
  [8476] = {.lex_state = 117, .external_lex_state = 10},
  [8477] = {.lex_state = 117, .external_lex_state = 10},
  [8478] = {.lex_state = 117, .external_lex_state = 10},
  [8479] = {.lex_state = 117, .external_lex_state = 10},
  [8480] = {.lex_state = 117, .external_lex_state = 10},
  [8481] = {.lex_state = 117, .external_lex_state = 15},
  [8482] = {.lex_state = 6},
  [8483] = {.lex_state = 117, .external_lex_state = 10},
  [8484] = {.lex_state = 6},
  [8485] = {.lex_state = 6},
  [8486] = {.lex_state = 117, .external_lex_state = 15},
  [8487] = {.lex_state = 117, .external_lex_state = 10},
  [8488] = {.lex_state = 117, .external_lex_state = 10},
  [8489] = {.lex_state = 6},
  [8490] = {.lex_state = 6},
  [8491] = {.lex_state = 117, .external_lex_state = 10},
  [8492] = {.lex_state = 6},
  [8493] = {.lex_state = 6},
  [8494] = {.lex_state = 6},
  [8495] = {.lex_state = 6},
  [8496] = {.lex_state = 6},
  [8497] = {.lex_state = 6},
  [8498] = {.lex_state = 6},
  [8499] = {.lex_state = 6},
  [8500] = {.lex_state = 117, .external_lex_state = 10},
  [8501] = {.lex_state = 117, .external_lex_state = 10},
  [8502] = {.lex_state = 117, .external_lex_state = 10},
  [8503] = {.lex_state = 117, .external_lex_state = 10},
  [8504] = {.lex_state = 117, .external_lex_state = 10},
  [8505] = {.lex_state = 117, .external_lex_state = 10},
  [8506] = {.lex_state = 117, .external_lex_state = 10},
  [8507] = {.lex_state = 117, .external_lex_state = 15},
  [8508] = {.lex_state = 117, .external_lex_state = 10},
  [8509] = {.lex_state = 117, .external_lex_state = 15},
  [8510] = {.lex_state = 117, .external_lex_state = 10},
  [8511] = {.lex_state = 117, .external_lex_state = 15},
  [8512] = {.lex_state = 117, .external_lex_state = 10},
  [8513] = {.lex_state = 117, .external_lex_state = 10},
  [8514] = {.lex_state = 117, .external_lex_state = 10},
  [8515] = {.lex_state = 6},
  [8516] = {.lex_state = 117, .external_lex_state = 10},
  [8517] = {.lex_state = 6},
  [8518] = {.lex_state = 117, .external_lex_state = 10},
  [8519] = {.lex_state = 6},
  [8520] = {.lex_state = 6},
  [8521] = {.lex_state = 6},
  [8522] = {.lex_state = 6},
  [8523] = {.lex_state = 117, .external_lex_state = 15},
  [8524] = {.lex_state = 117, .external_lex_state = 10},
  [8525] = {.lex_state = 117, .external_lex_state = 15},
  [8526] = {.lex_state = 117, .external_lex_state = 15},
  [8527] = {.lex_state = 117, .external_lex_state = 15},
  [8528] = {.lex_state = 117, .external_lex_state = 15},
  [8529] = {.lex_state = 117, .external_lex_state = 15},
  [8530] = {.lex_state = 6},
  [8531] = {.lex_state = 6},
  [8532] = {.lex_state = 6},
  [8533] = {.lex_state = 6},
  [8534] = {.lex_state = 117, .external_lex_state = 10},
  [8535] = {.lex_state = 6},
  [8536] = {.lex_state = 6},
  [8537] = {.lex_state = 6},
  [8538] = {.lex_state = 6},
  [8539] = {.lex_state = 6},
  [8540] = {.lex_state = 117, .external_lex_state = 10},
  [8541] = {.lex_state = 6},
  [8542] = {.lex_state = 6},
  [8543] = {.lex_state = 6},
  [8544] = {.lex_state = 6},
  [8545] = {.lex_state = 6},
  [8546] = {.lex_state = 6},
  [8547] = {.lex_state = 6},
  [8548] = {.lex_state = 6},
  [8549] = {.lex_state = 117, .external_lex_state = 15},
  [8550] = {.lex_state = 6},
  [8551] = {.lex_state = 117, .external_lex_state = 15},
  [8552] = {.lex_state = 6},
  [8553] = {.lex_state = 6},
  [8554] = {.lex_state = 6},
  [8555] = {.lex_state = 117, .external_lex_state = 15},
  [8556] = {.lex_state = 117, .external_lex_state = 15},
  [8557] = {.lex_state = 6},
  [8558] = {.lex_state = 117, .external_lex_state = 15},
  [8559] = {.lex_state = 6},
  [8560] = {.lex_state = 6},
  [8561] = {.lex_state = 6},
  [8562] = {.lex_state = 6},
  [8563] = {.lex_state = 6},
  [8564] = {.lex_state = 6},
  [8565] = {.lex_state = 6},
  [8566] = {.lex_state = 6},
  [8567] = {.lex_state = 6},
  [8568] = {.lex_state = 6},
  [8569] = {.lex_state = 6},
  [8570] = {.lex_state = 6},
  [8571] = {.lex_state = 6},
  [8572] = {.lex_state = 6},
  [8573] = {.lex_state = 6},
  [8574] = {.lex_state = 6},
  [8575] = {.lex_state = 6},
  [8576] = {.lex_state = 6},
  [8577] = {.lex_state = 6},
  [8578] = {.lex_state = 6},
  [8579] = {.lex_state = 6},
  [8580] = {.lex_state = 6},
  [8581] = {.lex_state = 6},
  [8582] = {.lex_state = 6},
  [8583] = {.lex_state = 6},
  [8584] = {.lex_state = 6},
  [8585] = {.lex_state = 6},
  [8586] = {.lex_state = 6},
  [8587] = {.lex_state = 6},
  [8588] = {.lex_state = 6},
  [8589] = {.lex_state = 6},
  [8590] = {.lex_state = 6},
  [8591] = {.lex_state = 6},
  [8592] = {.lex_state = 6},
  [8593] = {.lex_state = 6},
  [8594] = {.lex_state = 6},
  [8595] = {.lex_state = 6},
  [8596] = {.lex_state = 6},
  [8597] = {.lex_state = 6},
  [8598] = {.lex_state = 6},
  [8599] = {.lex_state = 6},
  [8600] = {.lex_state = 6},
  [8601] = {.lex_state = 6},
  [8602] = {.lex_state = 6},
  [8603] = {.lex_state = 6},
  [8604] = {.lex_state = 6},
  [8605] = {.lex_state = 6},
  [8606] = {.lex_state = 6},
  [8607] = {.lex_state = 6},
  [8608] = {.lex_state = 6},
  [8609] = {.lex_state = 6},
  [8610] = {.lex_state = 117, .external_lex_state = 10},
  [8611] = {.lex_state = 117, .external_lex_state = 10},
  [8612] = {.lex_state = 6},
  [8613] = {.lex_state = 6},
  [8614] = {.lex_state = 6},
  [8615] = {.lex_state = 117, .external_lex_state = 10},
  [8616] = {.lex_state = 117, .external_lex_state = 10},
  [8617] = {.lex_state = 117, .external_lex_state = 10},
  [8618] = {.lex_state = 6},
  [8619] = {.lex_state = 6},
  [8620] = {.lex_state = 117, .external_lex_state = 15},
  [8621] = {.lex_state = 117, .external_lex_state = 10},
  [8622] = {.lex_state = 117, .external_lex_state = 10},
  [8623] = {.lex_state = 117, .external_lex_state = 10},
  [8624] = {.lex_state = 6},
  [8625] = {.lex_state = 117, .external_lex_state = 10},
  [8626] = {.lex_state = 6},
  [8627] = {.lex_state = 6},
  [8628] = {.lex_state = 6},
  [8629] = {.lex_state = 6},
  [8630] = {.lex_state = 6},
  [8631] = {.lex_state = 6},
  [8632] = {.lex_state = 6},
  [8633] = {.lex_state = 6},
  [8634] = {.lex_state = 6},
  [8635] = {.lex_state = 6},
  [8636] = {.lex_state = 6},
  [8637] = {.lex_state = 6},
  [8638] = {.lex_state = 6},
  [8639] = {.lex_state = 6},
  [8640] = {.lex_state = 6},
  [8641] = {.lex_state = 6},
  [8642] = {.lex_state = 6},
  [8643] = {.lex_state = 6},
  [8644] = {.lex_state = 117, .external_lex_state = 10},
  [8645] = {.lex_state = 6},
  [8646] = {.lex_state = 6},
  [8647] = {.lex_state = 6},
  [8648] = {.lex_state = 6},
  [8649] = {.lex_state = 6},
  [8650] = {.lex_state = 6},
  [8651] = {.lex_state = 6},
  [8652] = {.lex_state = 117, .external_lex_state = 10},
  [8653] = {.lex_state = 6},
  [8654] = {.lex_state = 6},
  [8655] = {.lex_state = 3, .external_lex_state = 12},
  [8656] = {.lex_state = 3, .external_lex_state = 12},
  [8657] = {.lex_state = 3, .external_lex_state = 12},
  [8658] = {.lex_state = 3, .external_lex_state = 12},
  [8659] = {.lex_state = 3, .external_lex_state = 12},
  [8660] = {.lex_state = 6},
  [8661] = {.lex_state = 6},
  [8662] = {.lex_state = 6},
  [8663] = {.lex_state = 6},
  [8664] = {.lex_state = 6},
  [8665] = {.lex_state = 6},
  [8666] = {.lex_state = 6},
  [8667] = {.lex_state = 6},
  [8668] = {.lex_state = 6},
  [8669] = {.lex_state = 6},
  [8670] = {.lex_state = 6},
  [8671] = {.lex_state = 117, .external_lex_state = 10},
  [8672] = {.lex_state = 6},
  [8673] = {.lex_state = 117, .external_lex_state = 10},
  [8674] = {.lex_state = 117, .external_lex_state = 10},
  [8675] = {.lex_state = 117, .external_lex_state = 10},
  [8676] = {.lex_state = 6},
  [8677] = {.lex_state = 6},
  [8678] = {.lex_state = 6},
  [8679] = {.lex_state = 6},
  [8680] = {.lex_state = 117, .external_lex_state = 10},
  [8681] = {.lex_state = 6},
  [8682] = {.lex_state = 6},
  [8683] = {.lex_state = 6},
  [8684] = {.lex_state = 6},
  [8685] = {.lex_state = 6},
  [8686] = {.lex_state = 117, .external_lex_state = 10},
  [8687] = {.lex_state = 6},
  [8688] = {.lex_state = 6},
  [8689] = {.lex_state = 15},
  [8690] = {.lex_state = 10, .external_lex_state = 15},
  [8691] = {.lex_state = 10, .external_lex_state = 15},
  [8692] = {.lex_state = 15},
  [8693] = {.lex_state = 10, .external_lex_state = 15},
  [8694] = {.lex_state = 6},
  [8695] = {.lex_state = 6},
  [8696] = {.lex_state = 15},
  [8697] = {.lex_state = 117, .external_lex_state = 10},
  [8698] = {.lex_state = 15},
  [8699] = {.lex_state = 15},
  [8700] = {.lex_state = 117, .external_lex_state = 10},
  [8701] = {.lex_state = 6},
  [8702] = {.lex_state = 6},
  [8703] = {.lex_state = 15},
  [8704] = {.lex_state = 117, .external_lex_state = 10},
  [8705] = {.lex_state = 6},
  [8706] = {.lex_state = 10, .external_lex_state = 15},
  [8707] = {.lex_state = 6},
  [8708] = {.lex_state = 6},
  [8709] = {.lex_state = 6},
  [8710] = {.lex_state = 117, .external_lex_state = 10},
  [8711] = {.lex_state = 6},
  [8712] = {.lex_state = 10, .external_lex_state = 15},
  [8713] = {.lex_state = 6},
  [8714] = {.lex_state = 6},
  [8715] = {.lex_state = 6},
  [8716] = {.lex_state = 6},
  [8717] = {.lex_state = 6},
  [8718] = {.lex_state = 6},
  [8719] = {.lex_state = 117, .external_lex_state = 10},
  [8720] = {.lex_state = 6},
  [8721] = {.lex_state = 6},
  [8722] = {.lex_state = 6},
  [8723] = {.lex_state = 6},
  [8724] = {.lex_state = 117, .external_lex_state = 19},
  [8725] = {.lex_state = 6},
  [8726] = {.lex_state = 6},
  [8727] = {.lex_state = 6},
  [8728] = {.lex_state = 6},
  [8729] = {.lex_state = 15},
  [8730] = {.lex_state = 6},
  [8731] = {.lex_state = 117, .external_lex_state = 19},
  [8732] = {.lex_state = 6},
  [8733] = {.lex_state = 6},
  [8734] = {.lex_state = 6},
  [8735] = {.lex_state = 6},
  [8736] = {.lex_state = 6},
  [8737] = {.lex_state = 117, .external_lex_state = 10},
  [8738] = {.lex_state = 117, .external_lex_state = 10},
  [8739] = {.lex_state = 117, .external_lex_state = 19},
  [8740] = {.lex_state = 6},
  [8741] = {.lex_state = 6},
  [8742] = {.lex_state = 6},
  [8743] = {.lex_state = 6},
  [8744] = {.lex_state = 15},
  [8745] = {.lex_state = 6},
  [8746] = {.lex_state = 6},
  [8747] = {.lex_state = 6},
  [8748] = {.lex_state = 10},
  [8749] = {.lex_state = 6},
  [8750] = {.lex_state = 117, .external_lex_state = 10},
  [8751] = {.lex_state = 6},
  [8752] = {.lex_state = 6},
  [8753] = {.lex_state = 117, .external_lex_state = 10},
  [8754] = {.lex_state = 6},
  [8755] = {.lex_state = 6},
  [8756] = {.lex_state = 6},
  [8757] = {.lex_state = 117, .external_lex_state = 19},
  [8758] = {.lex_state = 117, .external_lex_state = 19},
  [8759] = {.lex_state = 117, .external_lex_state = 19},
  [8760] = {.lex_state = 117, .external_lex_state = 10},
  [8761] = {.lex_state = 6},
  [8762] = {.lex_state = 6},
  [8763] = {.lex_state = 6},
  [8764] = {.lex_state = 6},
  [8765] = {.lex_state = 6},
  [8766] = {.lex_state = 6},
  [8767] = {.lex_state = 6},
  [8768] = {.lex_state = 117, .external_lex_state = 19},
  [8769] = {.lex_state = 6},
  [8770] = {.lex_state = 6},
  [8771] = {.lex_state = 6},
  [8772] = {.lex_state = 6},
  [8773] = {.lex_state = 6},
  [8774] = {.lex_state = 6},
  [8775] = {.lex_state = 117, .external_lex_state = 19},
  [8776] = {.lex_state = 117, .external_lex_state = 19},
  [8777] = {.lex_state = 117, .external_lex_state = 19},
  [8778] = {.lex_state = 6},
  [8779] = {.lex_state = 6},
  [8780] = {.lex_state = 6},
  [8781] = {.lex_state = 117, .external_lex_state = 10},
  [8782] = {.lex_state = 117, .external_lex_state = 10},
  [8783] = {.lex_state = 6},
  [8784] = {.lex_state = 117, .external_lex_state = 10},
  [8785] = {.lex_state = 9, .external_lex_state = 22},
  [8786] = {.lex_state = 117, .external_lex_state = 10},
  [8787] = {.lex_state = 117, .external_lex_state = 10},
  [8788] = {.lex_state = 117, .external_lex_state = 10},
  [8789] = {.lex_state = 117, .external_lex_state = 10},
  [8790] = {.lex_state = 6},
  [8791] = {.lex_state = 117, .external_lex_state = 10},
  [8792] = {.lex_state = 117, .external_lex_state = 10},
  [8793] = {.lex_state = 6},
  [8794] = {.lex_state = 117, .external_lex_state = 10},
  [8795] = {.lex_state = 6},
  [8796] = {.lex_state = 117, .external_lex_state = 10},
  [8797] = {.lex_state = 117, .external_lex_state = 10},
  [8798] = {.lex_state = 6},
  [8799] = {.lex_state = 6},
  [8800] = {.lex_state = 117, .external_lex_state = 10},
  [8801] = {.lex_state = 15},
  [8802] = {.lex_state = 6},
  [8803] = {.lex_state = 117, .external_lex_state = 10},
  [8804] = {.lex_state = 117, .external_lex_state = 10},
  [8805] = {.lex_state = 117, .external_lex_state = 10},
  [8806] = {.lex_state = 6},
  [8807] = {.lex_state = 117, .external_lex_state = 12},
  [8808] = {.lex_state = 117, .external_lex_state = 10},
  [8809] = {.lex_state = 117, .external_lex_state = 10},
  [8810] = {.lex_state = 117, .external_lex_state = 10},
  [8811] = {.lex_state = 117, .external_lex_state = 10},
  [8812] = {.lex_state = 117, .external_lex_state = 10},
  [8813] = {.lex_state = 117, .external_lex_state = 10},
  [8814] = {.lex_state = 117, .external_lex_state = 10},
  [8815] = {.lex_state = 117, .external_lex_state = 10},
  [8816] = {.lex_state = 117, .external_lex_state = 10},
  [8817] = {.lex_state = 6},
  [8818] = {.lex_state = 117, .external_lex_state = 10},
  [8819] = {.lex_state = 117, .external_lex_state = 10},
  [8820] = {.lex_state = 6},
  [8821] = {.lex_state = 6},
  [8822] = {.lex_state = 15},
  [8823] = {.lex_state = 117, .external_lex_state = 10},
  [8824] = {.lex_state = 6},
  [8825] = {.lex_state = 6},
  [8826] = {.lex_state = 15},
  [8827] = {.lex_state = 117, .external_lex_state = 10},
  [8828] = {.lex_state = 117, .external_lex_state = 10},
  [8829] = {.lex_state = 15},
  [8830] = {.lex_state = 15},
  [8831] = {.lex_state = 117, .external_lex_state = 12},
  [8832] = {.lex_state = 15},
  [8833] = {.lex_state = 6},
  [8834] = {.lex_state = 117, .external_lex_state = 10},
  [8835] = {.lex_state = 117, .external_lex_state = 12},
  [8836] = {.lex_state = 6},
  [8837] = {.lex_state = 6},
  [8838] = {.lex_state = 117, .external_lex_state = 10},
  [8839] = {.lex_state = 6},
  [8840] = {.lex_state = 6},
  [8841] = {.lex_state = 117, .external_lex_state = 10},
  [8842] = {.lex_state = 117, .external_lex_state = 10},
  [8843] = {.lex_state = 6},
  [8844] = {.lex_state = 6},
  [8845] = {.lex_state = 117, .external_lex_state = 10},
  [8846] = {.lex_state = 6},
  [8847] = {.lex_state = 117, .external_lex_state = 10},
  [8848] = {.lex_state = 117, .external_lex_state = 10},
  [8849] = {.lex_state = 117, .external_lex_state = 10},
  [8850] = {.lex_state = 6},
  [8851] = {.lex_state = 6},
  [8852] = {.lex_state = 117, .external_lex_state = 10},
  [8853] = {.lex_state = 6},
  [8854] = {.lex_state = 117, .external_lex_state = 10},
  [8855] = {.lex_state = 117, .external_lex_state = 10},
  [8856] = {.lex_state = 117, .external_lex_state = 10},
  [8857] = {.lex_state = 117, .external_lex_state = 12},
  [8858] = {.lex_state = 117, .external_lex_state = 12},
  [8859] = {.lex_state = 117, .external_lex_state = 12},
  [8860] = {.lex_state = 117, .external_lex_state = 12},
  [8861] = {.lex_state = 117, .external_lex_state = 12},
  [8862] = {.lex_state = 117, .external_lex_state = 12},
  [8863] = {.lex_state = 117, .external_lex_state = 12},
  [8864] = {.lex_state = 117, .external_lex_state = 12},
  [8865] = {.lex_state = 117, .external_lex_state = 12},
  [8866] = {.lex_state = 117, .external_lex_state = 12},
  [8867] = {.lex_state = 117, .external_lex_state = 12},
  [8868] = {.lex_state = 117, .external_lex_state = 12},
  [8869] = {.lex_state = 117, .external_lex_state = 12},
  [8870] = {.lex_state = 117, .external_lex_state = 12},
  [8871] = {.lex_state = 117, .external_lex_state = 12},
  [8872] = {.lex_state = 117, .external_lex_state = 12},
  [8873] = {.lex_state = 6},
  [8874] = {.lex_state = 117, .external_lex_state = 10},
  [8875] = {.lex_state = 117, .external_lex_state = 12},
  [8876] = {.lex_state = 117, .external_lex_state = 12},
  [8877] = {.lex_state = 117, .external_lex_state = 12},
  [8878] = {.lex_state = 117, .external_lex_state = 12},
  [8879] = {.lex_state = 117, .external_lex_state = 12},
  [8880] = {.lex_state = 117, .external_lex_state = 12},
  [8881] = {.lex_state = 117, .external_lex_state = 12},
  [8882] = {.lex_state = 117, .external_lex_state = 12},
  [8883] = {.lex_state = 117, .external_lex_state = 12},
  [8884] = {.lex_state = 117, .external_lex_state = 10},
  [8885] = {.lex_state = 117, .external_lex_state = 12},
  [8886] = {.lex_state = 117, .external_lex_state = 12},
  [8887] = {.lex_state = 117, .external_lex_state = 12},
  [8888] = {.lex_state = 117, .external_lex_state = 12},
  [8889] = {.lex_state = 117, .external_lex_state = 12},
  [8890] = {.lex_state = 117, .external_lex_state = 12},
  [8891] = {.lex_state = 117, .external_lex_state = 12},
  [8892] = {.lex_state = 117, .external_lex_state = 12},
  [8893] = {.lex_state = 117, .external_lex_state = 12},
  [8894] = {.lex_state = 117, .external_lex_state = 12},
  [8895] = {.lex_state = 117, .external_lex_state = 12},
  [8896] = {.lex_state = 10, .external_lex_state = 15},
  [8897] = {.lex_state = 117, .external_lex_state = 12},
  [8898] = {.lex_state = 117, .external_lex_state = 10},
  [8899] = {.lex_state = 117, .external_lex_state = 10},
  [8900] = {.lex_state = 117, .external_lex_state = 12},
  [8901] = {.lex_state = 117, .external_lex_state = 12},
  [8902] = {.lex_state = 6},
  [8903] = {.lex_state = 117, .external_lex_state = 12},
  [8904] = {.lex_state = 117, .external_lex_state = 12},
  [8905] = {.lex_state = 117, .external_lex_state = 12},
  [8906] = {.lex_state = 117, .external_lex_state = 12},
  [8907] = {.lex_state = 117, .external_lex_state = 12},
  [8908] = {.lex_state = 117, .external_lex_state = 12},
  [8909] = {.lex_state = 117, .external_lex_state = 12},
  [8910] = {.lex_state = 117, .external_lex_state = 12},
  [8911] = {.lex_state = 117, .external_lex_state = 12},
  [8912] = {.lex_state = 117, .external_lex_state = 12},
  [8913] = {.lex_state = 117, .external_lex_state = 12},
  [8914] = {.lex_state = 117, .external_lex_state = 12},
  [8915] = {.lex_state = 117, .external_lex_state = 12},
  [8916] = {.lex_state = 117, .external_lex_state = 12},
  [8917] = {.lex_state = 117, .external_lex_state = 12},
  [8918] = {.lex_state = 117, .external_lex_state = 12},
  [8919] = {.lex_state = 117, .external_lex_state = 12},
  [8920] = {.lex_state = 117, .external_lex_state = 12},
  [8921] = {.lex_state = 117, .external_lex_state = 12},
  [8922] = {.lex_state = 117, .external_lex_state = 12},
  [8923] = {.lex_state = 117, .external_lex_state = 12},
  [8924] = {.lex_state = 117, .external_lex_state = 12},
  [8925] = {.lex_state = 117, .external_lex_state = 12},
  [8926] = {.lex_state = 117, .external_lex_state = 12},
  [8927] = {.lex_state = 117, .external_lex_state = 12},
  [8928] = {.lex_state = 117, .external_lex_state = 12},
  [8929] = {.lex_state = 117, .external_lex_state = 12},
  [8930] = {.lex_state = 117, .external_lex_state = 12},
  [8931] = {.lex_state = 117, .external_lex_state = 12},
  [8932] = {.lex_state = 117, .external_lex_state = 12},
  [8933] = {.lex_state = 117, .external_lex_state = 12},
  [8934] = {.lex_state = 117, .external_lex_state = 12},
  [8935] = {.lex_state = 117, .external_lex_state = 12},
  [8936] = {.lex_state = 117, .external_lex_state = 12},
  [8937] = {.lex_state = 117, .external_lex_state = 12},
  [8938] = {.lex_state = 117, .external_lex_state = 10},
  [8939] = {.lex_state = 6},
  [8940] = {.lex_state = 117, .external_lex_state = 12},
  [8941] = {.lex_state = 117, .external_lex_state = 10},
  [8942] = {.lex_state = 117, .external_lex_state = 12},
  [8943] = {.lex_state = 117, .external_lex_state = 10},
  [8944] = {.lex_state = 117, .external_lex_state = 12},
  [8945] = {.lex_state = 117, .external_lex_state = 10},
  [8946] = {.lex_state = 117, .external_lex_state = 12},
  [8947] = {.lex_state = 117, .external_lex_state = 12},
  [8948] = {.lex_state = 117, .external_lex_state = 12},
  [8949] = {.lex_state = 117, .external_lex_state = 12},
  [8950] = {.lex_state = 117, .external_lex_state = 10},
  [8951] = {.lex_state = 117, .external_lex_state = 12},
  [8952] = {.lex_state = 117, .external_lex_state = 12},
  [8953] = {.lex_state = 117, .external_lex_state = 12},
  [8954] = {.lex_state = 117, .external_lex_state = 12},
  [8955] = {.lex_state = 117, .external_lex_state = 10},
  [8956] = {.lex_state = 117, .external_lex_state = 10},
  [8957] = {.lex_state = 117, .external_lex_state = 12},
  [8958] = {.lex_state = 117, .external_lex_state = 12},
  [8959] = {.lex_state = 117, .external_lex_state = 12},
  [8960] = {.lex_state = 117, .external_lex_state = 12},
  [8961] = {.lex_state = 117, .external_lex_state = 10},
  [8962] = {.lex_state = 117, .external_lex_state = 10},
  [8963] = {.lex_state = 117, .external_lex_state = 10},
  [8964] = {.lex_state = 117, .external_lex_state = 10},
  [8965] = {.lex_state = 117, .external_lex_state = 10},
  [8966] = {.lex_state = 117, .external_lex_state = 10},
  [8967] = {.lex_state = 117, .external_lex_state = 12},
  [8968] = {.lex_state = 117, .external_lex_state = 12},
  [8969] = {.lex_state = 117, .external_lex_state = 10},
  [8970] = {.lex_state = 117, .external_lex_state = 12},
  [8971] = {.lex_state = 117, .external_lex_state = 10},
  [8972] = {.lex_state = 117, .external_lex_state = 12},
  [8973] = {.lex_state = 117, .external_lex_state = 12},
  [8974] = {.lex_state = 117, .external_lex_state = 12},
  [8975] = {.lex_state = 117, .external_lex_state = 12},
  [8976] = {.lex_state = 117, .external_lex_state = 12},
  [8977] = {.lex_state = 117, .external_lex_state = 12},
  [8978] = {.lex_state = 117, .external_lex_state = 12},
  [8979] = {.lex_state = 117, .external_lex_state = 10},
  [8980] = {.lex_state = 117, .external_lex_state = 12},
  [8981] = {.lex_state = 117, .external_lex_state = 22},
  [8982] = {.lex_state = 117, .external_lex_state = 10},
  [8983] = {.lex_state = 10, .external_lex_state = 15},
  [8984] = {.lex_state = 117, .external_lex_state = 10},
  [8985] = {.lex_state = 117, .external_lex_state = 10},
  [8986] = {.lex_state = 117, .external_lex_state = 12},
  [8987] = {.lex_state = 117, .external_lex_state = 10},
  [8988] = {.lex_state = 117, .external_lex_state = 12},
  [8989] = {.lex_state = 117, .external_lex_state = 12},
  [8990] = {.lex_state = 117, .external_lex_state = 10},
  [8991] = {.lex_state = 117, .external_lex_state = 10},
  [8992] = {.lex_state = 117, .external_lex_state = 12},
  [8993] = {.lex_state = 117, .external_lex_state = 10},
  [8994] = {.lex_state = 117, .external_lex_state = 12},
  [8995] = {.lex_state = 117, .external_lex_state = 12},
  [8996] = {.lex_state = 117, .external_lex_state = 12},
  [8997] = {.lex_state = 117, .external_lex_state = 12},
  [8998] = {.lex_state = 117, .external_lex_state = 12},
  [8999] = {.lex_state = 117, .external_lex_state = 12},
  [9000] = {.lex_state = 117, .external_lex_state = 12},
  [9001] = {.lex_state = 117, .external_lex_state = 12},
  [9002] = {.lex_state = 117, .external_lex_state = 10},
  [9003] = {.lex_state = 10, .external_lex_state = 15},
  [9004] = {.lex_state = 117, .external_lex_state = 12},
  [9005] = {.lex_state = 117, .external_lex_state = 10},
  [9006] = {.lex_state = 117, .external_lex_state = 10},
  [9007] = {.lex_state = 117, .external_lex_state = 10},
  [9008] = {.lex_state = 117, .external_lex_state = 22},
  [9009] = {.lex_state = 117, .external_lex_state = 12},
  [9010] = {.lex_state = 117, .external_lex_state = 12},
  [9011] = {.lex_state = 117, .external_lex_state = 10},
  [9012] = {.lex_state = 117, .external_lex_state = 12},
  [9013] = {.lex_state = 117, .external_lex_state = 12},
  [9014] = {.lex_state = 117, .external_lex_state = 12},
  [9015] = {.lex_state = 117, .external_lex_state = 10},
  [9016] = {.lex_state = 117, .external_lex_state = 10},
  [9017] = {.lex_state = 117, .external_lex_state = 10},
  [9018] = {.lex_state = 117, .external_lex_state = 12},
  [9019] = {.lex_state = 117, .external_lex_state = 10},
  [9020] = {.lex_state = 117, .external_lex_state = 12},
  [9021] = {.lex_state = 117, .external_lex_state = 12},
  [9022] = {.lex_state = 117, .external_lex_state = 12},
  [9023] = {.lex_state = 117, .external_lex_state = 12},
  [9024] = {.lex_state = 117, .external_lex_state = 22},
  [9025] = {.lex_state = 117, .external_lex_state = 12},
  [9026] = {.lex_state = 117, .external_lex_state = 12},
  [9027] = {.lex_state = 117, .external_lex_state = 12},
  [9028] = {.lex_state = 117, .external_lex_state = 12},
  [9029] = {.lex_state = 117, .external_lex_state = 12},
  [9030] = {.lex_state = 117, .external_lex_state = 12},
  [9031] = {.lex_state = 117, .external_lex_state = 12},
  [9032] = {.lex_state = 117, .external_lex_state = 10},
  [9033] = {.lex_state = 117, .external_lex_state = 10},
  [9034] = {.lex_state = 117, .external_lex_state = 12},
  [9035] = {.lex_state = 117, .external_lex_state = 10},
  [9036] = {.lex_state = 117, .external_lex_state = 12},
  [9037] = {.lex_state = 117, .external_lex_state = 12},
  [9038] = {.lex_state = 117, .external_lex_state = 12},
  [9039] = {.lex_state = 117, .external_lex_state = 12},
  [9040] = {.lex_state = 117, .external_lex_state = 10},
  [9041] = {.lex_state = 117, .external_lex_state = 12},
  [9042] = {.lex_state = 117, .external_lex_state = 12},
  [9043] = {.lex_state = 117, .external_lex_state = 10},
  [9044] = {.lex_state = 117, .external_lex_state = 10},
  [9045] = {.lex_state = 117, .external_lex_state = 12},
  [9046] = {.lex_state = 117, .external_lex_state = 12},
  [9047] = {.lex_state = 117, .external_lex_state = 12},
  [9048] = {.lex_state = 117, .external_lex_state = 12},
  [9049] = {.lex_state = 117, .external_lex_state = 12},
  [9050] = {.lex_state = 117, .external_lex_state = 12},
  [9051] = {.lex_state = 117, .external_lex_state = 12},
  [9052] = {.lex_state = 117, .external_lex_state = 12},
  [9053] = {.lex_state = 117, .external_lex_state = 10},
  [9054] = {.lex_state = 117, .external_lex_state = 12},
  [9055] = {.lex_state = 117, .external_lex_state = 12},
  [9056] = {.lex_state = 117, .external_lex_state = 12},
  [9057] = {.lex_state = 117, .external_lex_state = 10},
  [9058] = {.lex_state = 117, .external_lex_state = 12},
  [9059] = {.lex_state = 117, .external_lex_state = 12},
  [9060] = {.lex_state = 6},
  [9061] = {.lex_state = 117, .external_lex_state = 12},
  [9062] = {.lex_state = 117, .external_lex_state = 12},
  [9063] = {.lex_state = 117, .external_lex_state = 12},
  [9064] = {.lex_state = 117, .external_lex_state = 12},
  [9065] = {.lex_state = 117, .external_lex_state = 12},
  [9066] = {.lex_state = 117, .external_lex_state = 12},
  [9067] = {.lex_state = 6},
  [9068] = {.lex_state = 117, .external_lex_state = 10},
  [9069] = {.lex_state = 117, .external_lex_state = 12},
  [9070] = {.lex_state = 117, .external_lex_state = 12},
  [9071] = {.lex_state = 117, .external_lex_state = 12},
  [9072] = {.lex_state = 117, .external_lex_state = 12},
  [9073] = {.lex_state = 117, .external_lex_state = 12},
  [9074] = {.lex_state = 117, .external_lex_state = 12},
  [9075] = {.lex_state = 117, .external_lex_state = 12},
  [9076] = {.lex_state = 117, .external_lex_state = 12},
  [9077] = {.lex_state = 117, .external_lex_state = 12},
  [9078] = {.lex_state = 117, .external_lex_state = 12},
  [9079] = {.lex_state = 117, .external_lex_state = 12},
  [9080] = {.lex_state = 117, .external_lex_state = 12},
  [9081] = {.lex_state = 117, .external_lex_state = 12},
  [9082] = {.lex_state = 117, .external_lex_state = 10},
  [9083] = {.lex_state = 117, .external_lex_state = 12},
  [9084] = {.lex_state = 117, .external_lex_state = 12},
  [9085] = {.lex_state = 117, .external_lex_state = 12},
  [9086] = {.lex_state = 117, .external_lex_state = 10},
  [9087] = {.lex_state = 117, .external_lex_state = 10},
  [9088] = {.lex_state = 117, .external_lex_state = 10},
  [9089] = {.lex_state = 117, .external_lex_state = 12},
  [9090] = {.lex_state = 117, .external_lex_state = 10},
  [9091] = {.lex_state = 117, .external_lex_state = 10},
  [9092] = {.lex_state = 117, .external_lex_state = 10},
  [9093] = {.lex_state = 117, .external_lex_state = 12},
  [9094] = {.lex_state = 117, .external_lex_state = 12},
  [9095] = {.lex_state = 6},
  [9096] = {.lex_state = 117, .external_lex_state = 10},
  [9097] = {.lex_state = 117, .external_lex_state = 12},
  [9098] = {.lex_state = 117, .external_lex_state = 12},
  [9099] = {.lex_state = 117, .external_lex_state = 12},
  [9100] = {.lex_state = 117, .external_lex_state = 10},
  [9101] = {.lex_state = 117, .external_lex_state = 12},
  [9102] = {.lex_state = 6},
  [9103] = {.lex_state = 117, .external_lex_state = 12},
  [9104] = {.lex_state = 117, .external_lex_state = 10},
  [9105] = {.lex_state = 117, .external_lex_state = 10},
  [9106] = {.lex_state = 117, .external_lex_state = 12},
  [9107] = {.lex_state = 117, .external_lex_state = 10},
  [9108] = {.lex_state = 117, .external_lex_state = 12},
  [9109] = {.lex_state = 117, .external_lex_state = 12},
  [9110] = {.lex_state = 117, .external_lex_state = 12},
  [9111] = {.lex_state = 117, .external_lex_state = 12},
  [9112] = {.lex_state = 117, .external_lex_state = 12},
  [9113] = {.lex_state = 117, .external_lex_state = 10},
  [9114] = {.lex_state = 6},
  [9115] = {.lex_state = 117, .external_lex_state = 12},
  [9116] = {.lex_state = 6},
  [9117] = {.lex_state = 117, .external_lex_state = 12},
  [9118] = {.lex_state = 117, .external_lex_state = 12},
  [9119] = {.lex_state = 117, .external_lex_state = 12},
  [9120] = {.lex_state = 117, .external_lex_state = 12},
  [9121] = {.lex_state = 117, .external_lex_state = 12},
  [9122] = {.lex_state = 117, .external_lex_state = 12},
  [9123] = {.lex_state = 117, .external_lex_state = 22},
  [9124] = {.lex_state = 117, .external_lex_state = 12},
  [9125] = {.lex_state = 117, .external_lex_state = 12},
  [9126] = {.lex_state = 117, .external_lex_state = 12},
  [9127] = {.lex_state = 117, .external_lex_state = 10},
  [9128] = {.lex_state = 117, .external_lex_state = 12},
  [9129] = {.lex_state = 6},
  [9130] = {.lex_state = 117, .external_lex_state = 10},
  [9131] = {.lex_state = 117, .external_lex_state = 10},
  [9132] = {.lex_state = 117, .external_lex_state = 12},
  [9133] = {.lex_state = 117, .external_lex_state = 10},
  [9134] = {.lex_state = 6},
  [9135] = {.lex_state = 117, .external_lex_state = 10},
  [9136] = {.lex_state = 117, .external_lex_state = 10},
  [9137] = {.lex_state = 117, .external_lex_state = 10},
  [9138] = {.lex_state = 117, .external_lex_state = 12},
  [9139] = {.lex_state = 117, .external_lex_state = 10},
  [9140] = {.lex_state = 117, .external_lex_state = 12},
  [9141] = {.lex_state = 117, .external_lex_state = 12},
  [9142] = {.lex_state = 117, .external_lex_state = 10},
  [9143] = {.lex_state = 117, .external_lex_state = 10},
  [9144] = {.lex_state = 117, .external_lex_state = 10},
  [9145] = {.lex_state = 117, .external_lex_state = 10},
  [9146] = {.lex_state = 117, .external_lex_state = 10},
  [9147] = {.lex_state = 117, .external_lex_state = 10},
  [9148] = {.lex_state = 117, .external_lex_state = 10},
  [9149] = {.lex_state = 117, .external_lex_state = 10},
  [9150] = {.lex_state = 117, .external_lex_state = 12},
  [9151] = {.lex_state = 117, .external_lex_state = 12},
  [9152] = {.lex_state = 117, .external_lex_state = 10},
  [9153] = {.lex_state = 117, .external_lex_state = 10},
  [9154] = {.lex_state = 117, .external_lex_state = 10},
  [9155] = {.lex_state = 117, .external_lex_state = 12},
  [9156] = {.lex_state = 117, .external_lex_state = 12},
  [9157] = {.lex_state = 117, .external_lex_state = 12},
  [9158] = {.lex_state = 117, .external_lex_state = 12},
  [9159] = {.lex_state = 117, .external_lex_state = 12},
  [9160] = {.lex_state = 117, .external_lex_state = 10},
  [9161] = {.lex_state = 117, .external_lex_state = 10},
  [9162] = {.lex_state = 117, .external_lex_state = 12},
  [9163] = {.lex_state = 117, .external_lex_state = 10},
  [9164] = {.lex_state = 117, .external_lex_state = 12},
  [9165] = {.lex_state = 117, .external_lex_state = 10},
  [9166] = {.lex_state = 117, .external_lex_state = 12},
  [9167] = {.lex_state = 117, .external_lex_state = 12},
  [9168] = {.lex_state = 117, .external_lex_state = 12},
  [9169] = {.lex_state = 117, .external_lex_state = 10},
  [9170] = {.lex_state = 117, .external_lex_state = 10},
  [9171] = {.lex_state = 117, .external_lex_state = 10},
  [9172] = {.lex_state = 117, .external_lex_state = 22},
  [9173] = {.lex_state = 117, .external_lex_state = 12},
  [9174] = {.lex_state = 117, .external_lex_state = 12},
  [9175] = {.lex_state = 117, .external_lex_state = 10},
  [9176] = {.lex_state = 117, .external_lex_state = 10},
  [9177] = {.lex_state = 117, .external_lex_state = 12},
  [9178] = {.lex_state = 117, .external_lex_state = 10},
  [9179] = {.lex_state = 117, .external_lex_state = 22},
  [9180] = {.lex_state = 117, .external_lex_state = 10},
  [9181] = {.lex_state = 117, .external_lex_state = 12},
  [9182] = {.lex_state = 117, .external_lex_state = 15},
  [9183] = {.lex_state = 117, .external_lex_state = 15},
  [9184] = {.lex_state = 117, .external_lex_state = 15},
  [9185] = {.lex_state = 117, .external_lex_state = 15},
  [9186] = {.lex_state = 117, .external_lex_state = 15},
  [9187] = {.lex_state = 117, .external_lex_state = 15},
  [9188] = {.lex_state = 117, .external_lex_state = 15},
  [9189] = {.lex_state = 117, .external_lex_state = 15},
  [9190] = {.lex_state = 117, .external_lex_state = 15},
  [9191] = {.lex_state = 117, .external_lex_state = 15},
  [9192] = {.lex_state = 117, .external_lex_state = 15},
  [9193] = {.lex_state = 117, .external_lex_state = 15},
  [9194] = {.lex_state = 117, .external_lex_state = 15},
  [9195] = {.lex_state = 117, .external_lex_state = 15},
  [9196] = {.lex_state = 117, .external_lex_state = 15},
  [9197] = {.lex_state = 117, .external_lex_state = 15},
  [9198] = {.lex_state = 117, .external_lex_state = 15},
  [9199] = {.lex_state = 117, .external_lex_state = 15},
  [9200] = {.lex_state = 117, .external_lex_state = 15},
  [9201] = {.lex_state = 117, .external_lex_state = 15},
  [9202] = {.lex_state = 117, .external_lex_state = 15},
  [9203] = {.lex_state = 117, .external_lex_state = 15},
  [9204] = {.lex_state = 117, .external_lex_state = 15},
  [9205] = {.lex_state = 117, .external_lex_state = 15},
  [9206] = {.lex_state = 117, .external_lex_state = 15},
  [9207] = {.lex_state = 117, .external_lex_state = 15},
  [9208] = {.lex_state = 117, .external_lex_state = 15},
  [9209] = {.lex_state = 117, .external_lex_state = 15},
  [9210] = {.lex_state = 117, .external_lex_state = 15},
  [9211] = {.lex_state = 117, .external_lex_state = 15},
  [9212] = {.lex_state = 117, .external_lex_state = 15},
  [9213] = {.lex_state = 117, .external_lex_state = 15},
  [9214] = {.lex_state = 117, .external_lex_state = 15},
  [9215] = {.lex_state = 117, .external_lex_state = 15},
  [9216] = {.lex_state = 117, .external_lex_state = 15},
  [9217] = {.lex_state = 117, .external_lex_state = 15},
  [9218] = {.lex_state = 117, .external_lex_state = 15},
  [9219] = {.lex_state = 117, .external_lex_state = 15},
  [9220] = {.lex_state = 117, .external_lex_state = 15},
  [9221] = {.lex_state = 117, .external_lex_state = 15},
  [9222] = {.lex_state = 117, .external_lex_state = 15},
  [9223] = {.lex_state = 117, .external_lex_state = 15},
  [9224] = {.lex_state = 117, .external_lex_state = 15},
  [9225] = {.lex_state = 117, .external_lex_state = 15},
  [9226] = {.lex_state = 117, .external_lex_state = 15},
  [9227] = {.lex_state = 117, .external_lex_state = 15},
  [9228] = {.lex_state = 117, .external_lex_state = 15},
  [9229] = {.lex_state = 117, .external_lex_state = 15},
  [9230] = {.lex_state = 117, .external_lex_state = 15},
  [9231] = {.lex_state = 117, .external_lex_state = 15},
  [9232] = {.lex_state = 117, .external_lex_state = 15},
  [9233] = {.lex_state = 117, .external_lex_state = 15},
  [9234] = {.lex_state = 117, .external_lex_state = 15},
  [9235] = {.lex_state = 117, .external_lex_state = 15},
  [9236] = {.lex_state = 117, .external_lex_state = 15},
  [9237] = {.lex_state = 117, .external_lex_state = 15},
  [9238] = {.lex_state = 117, .external_lex_state = 15},
  [9239] = {.lex_state = 117, .external_lex_state = 15},
  [9240] = {.lex_state = 117, .external_lex_state = 15},
  [9241] = {.lex_state = 117, .external_lex_state = 15},
  [9242] = {.lex_state = 117, .external_lex_state = 15},
  [9243] = {.lex_state = 117, .external_lex_state = 15},
  [9244] = {.lex_state = 117, .external_lex_state = 15},
  [9245] = {.lex_state = 117, .external_lex_state = 15},
  [9246] = {.lex_state = 117, .external_lex_state = 15},
  [9247] = {.lex_state = 117, .external_lex_state = 15},
  [9248] = {.lex_state = 117, .external_lex_state = 15},
  [9249] = {.lex_state = 117, .external_lex_state = 15},
  [9250] = {.lex_state = 117, .external_lex_state = 15},
  [9251] = {.lex_state = 117, .external_lex_state = 15},
  [9252] = {.lex_state = 117, .external_lex_state = 15},
  [9253] = {.lex_state = 117, .external_lex_state = 15},
  [9254] = {.lex_state = 117, .external_lex_state = 15},
  [9255] = {.lex_state = 117, .external_lex_state = 15},
  [9256] = {.lex_state = 117, .external_lex_state = 15},
  [9257] = {.lex_state = 117, .external_lex_state = 15},
  [9258] = {.lex_state = 117, .external_lex_state = 15},
  [9259] = {.lex_state = 117, .external_lex_state = 15},
  [9260] = {.lex_state = 117, .external_lex_state = 15},
  [9261] = {.lex_state = 117, .external_lex_state = 15},
  [9262] = {.lex_state = 117, .external_lex_state = 15},
  [9263] = {.lex_state = 117, .external_lex_state = 15},
  [9264] = {.lex_state = 117, .external_lex_state = 15},
  [9265] = {.lex_state = 117, .external_lex_state = 15},
  [9266] = {.lex_state = 117, .external_lex_state = 15},
  [9267] = {.lex_state = 117, .external_lex_state = 15},
  [9268] = {.lex_state = 117, .external_lex_state = 15},
  [9269] = {.lex_state = 117, .external_lex_state = 15},
  [9270] = {.lex_state = 117, .external_lex_state = 15},
  [9271] = {.lex_state = 117, .external_lex_state = 15},
  [9272] = {.lex_state = 117, .external_lex_state = 15},
  [9273] = {.lex_state = 117, .external_lex_state = 15},
  [9274] = {.lex_state = 117, .external_lex_state = 15},
  [9275] = {.lex_state = 117, .external_lex_state = 15},
  [9276] = {.lex_state = 117, .external_lex_state = 15},
  [9277] = {.lex_state = 117, .external_lex_state = 15},
  [9278] = {.lex_state = 117, .external_lex_state = 15},
  [9279] = {.lex_state = 117, .external_lex_state = 15},
  [9280] = {.lex_state = 117, .external_lex_state = 15},
  [9281] = {.lex_state = 117, .external_lex_state = 15},
  [9282] = {.lex_state = 117, .external_lex_state = 15},
  [9283] = {.lex_state = 117, .external_lex_state = 15},
  [9284] = {.lex_state = 117, .external_lex_state = 15},
  [9285] = {.lex_state = 117, .external_lex_state = 15},
  [9286] = {.lex_state = 117, .external_lex_state = 15},
  [9287] = {.lex_state = 117, .external_lex_state = 15},
  [9288] = {.lex_state = 117, .external_lex_state = 15},
  [9289] = {.lex_state = 117, .external_lex_state = 15},
  [9290] = {.lex_state = 117, .external_lex_state = 15},
  [9291] = {.lex_state = 117, .external_lex_state = 15},
  [9292] = {.lex_state = 117, .external_lex_state = 15},
  [9293] = {.lex_state = 117, .external_lex_state = 15},
  [9294] = {.lex_state = 117, .external_lex_state = 15},
  [9295] = {.lex_state = 117, .external_lex_state = 15},
  [9296] = {.lex_state = 117, .external_lex_state = 15},
  [9297] = {.lex_state = 117, .external_lex_state = 15},
  [9298] = {.lex_state = 117, .external_lex_state = 15},
  [9299] = {.lex_state = 117, .external_lex_state = 15},
  [9300] = {.lex_state = 117, .external_lex_state = 15},
  [9301] = {.lex_state = 117, .external_lex_state = 15},
  [9302] = {.lex_state = 117, .external_lex_state = 15},
  [9303] = {.lex_state = 117, .external_lex_state = 15},
  [9304] = {.lex_state = 117, .external_lex_state = 15},
  [9305] = {.lex_state = 117, .external_lex_state = 15},
  [9306] = {.lex_state = 117, .external_lex_state = 15},
  [9307] = {.lex_state = 117, .external_lex_state = 15},
  [9308] = {.lex_state = 117, .external_lex_state = 15},
  [9309] = {.lex_state = 117, .external_lex_state = 15},
  [9310] = {.lex_state = 117, .external_lex_state = 15},
  [9311] = {.lex_state = 117, .external_lex_state = 15},
  [9312] = {.lex_state = 117, .external_lex_state = 15},
  [9313] = {.lex_state = 117, .external_lex_state = 15},
  [9314] = {.lex_state = 117, .external_lex_state = 15},
  [9315] = {.lex_state = 117, .external_lex_state = 15},
  [9316] = {.lex_state = 117, .external_lex_state = 15},
  [9317] = {.lex_state = 117, .external_lex_state = 15},
  [9318] = {.lex_state = 117, .external_lex_state = 15},
  [9319] = {.lex_state = 117, .external_lex_state = 15},
  [9320] = {.lex_state = 117, .external_lex_state = 15},
  [9321] = {.lex_state = 117, .external_lex_state = 15},
  [9322] = {.lex_state = 117, .external_lex_state = 15},
  [9323] = {.lex_state = 117, .external_lex_state = 15},
  [9324] = {.lex_state = 117, .external_lex_state = 15},
  [9325] = {.lex_state = 117, .external_lex_state = 15},
  [9326] = {.lex_state = 117, .external_lex_state = 15},
  [9327] = {.lex_state = 117, .external_lex_state = 15},
  [9328] = {.lex_state = 117, .external_lex_state = 15},
  [9329] = {.lex_state = 117, .external_lex_state = 15},
  [9330] = {.lex_state = 117, .external_lex_state = 15},
  [9331] = {.lex_state = 117, .external_lex_state = 15},
  [9332] = {.lex_state = 117, .external_lex_state = 15},
  [9333] = {.lex_state = 117, .external_lex_state = 15},
  [9334] = {.lex_state = 117, .external_lex_state = 15},
  [9335] = {.lex_state = 117, .external_lex_state = 15},
  [9336] = {.lex_state = 117, .external_lex_state = 15},
  [9337] = {.lex_state = 117, .external_lex_state = 15},
  [9338] = {.lex_state = 117, .external_lex_state = 15},
  [9339] = {.lex_state = 117, .external_lex_state = 15},
  [9340] = {.lex_state = 117, .external_lex_state = 15},
  [9341] = {.lex_state = 117, .external_lex_state = 15},
  [9342] = {.lex_state = 117, .external_lex_state = 15},
  [9343] = {.lex_state = 117, .external_lex_state = 15},
  [9344] = {.lex_state = 117, .external_lex_state = 15},
  [9345] = {.lex_state = 117, .external_lex_state = 15},
  [9346] = {.lex_state = 117, .external_lex_state = 15},
  [9347] = {.lex_state = 117, .external_lex_state = 15},
  [9348] = {.lex_state = 117, .external_lex_state = 15},
  [9349] = {.lex_state = 117, .external_lex_state = 15},
  [9350] = {.lex_state = 117, .external_lex_state = 15},
  [9351] = {.lex_state = 117, .external_lex_state = 15},
  [9352] = {.lex_state = 117, .external_lex_state = 15},
  [9353] = {.lex_state = 117, .external_lex_state = 15},
  [9354] = {.lex_state = 117, .external_lex_state = 15},
  [9355] = {.lex_state = 117, .external_lex_state = 15},
  [9356] = {.lex_state = 117, .external_lex_state = 15},
  [9357] = {.lex_state = 117, .external_lex_state = 15},
  [9358] = {.lex_state = 117, .external_lex_state = 15},
  [9359] = {.lex_state = 117, .external_lex_state = 15},
  [9360] = {.lex_state = 117, .external_lex_state = 15},
  [9361] = {.lex_state = 117, .external_lex_state = 15},
  [9362] = {.lex_state = 117, .external_lex_state = 15},
  [9363] = {.lex_state = 117, .external_lex_state = 15},
  [9364] = {.lex_state = 117, .external_lex_state = 15},
  [9365] = {.lex_state = 117, .external_lex_state = 15},
  [9366] = {.lex_state = 117, .external_lex_state = 15},
  [9367] = {.lex_state = 117, .external_lex_state = 15},
  [9368] = {.lex_state = 117, .external_lex_state = 15},
  [9369] = {.lex_state = 117, .external_lex_state = 15},
  [9370] = {.lex_state = 117, .external_lex_state = 15},
  [9371] = {.lex_state = 117, .external_lex_state = 15},
  [9372] = {.lex_state = 117, .external_lex_state = 15},
  [9373] = {.lex_state = 117, .external_lex_state = 15},
  [9374] = {.lex_state = 117, .external_lex_state = 15},
  [9375] = {.lex_state = 117, .external_lex_state = 15},
  [9376] = {.lex_state = 117, .external_lex_state = 15},
  [9377] = {.lex_state = 117, .external_lex_state = 15},
  [9378] = {.lex_state = 117, .external_lex_state = 15},
  [9379] = {.lex_state = 117, .external_lex_state = 15},
  [9380] = {.lex_state = 117, .external_lex_state = 15},
  [9381] = {.lex_state = 117, .external_lex_state = 15},
  [9382] = {.lex_state = 117, .external_lex_state = 15},
  [9383] = {.lex_state = 117, .external_lex_state = 15},
  [9384] = {.lex_state = 117, .external_lex_state = 15},
  [9385] = {.lex_state = 117, .external_lex_state = 15},
  [9386] = {.lex_state = 117, .external_lex_state = 15},
  [9387] = {.lex_state = 117, .external_lex_state = 15},
  [9388] = {.lex_state = 117, .external_lex_state = 15},
  [9389] = {.lex_state = 117, .external_lex_state = 15},
  [9390] = {.lex_state = 117, .external_lex_state = 15},
  [9391] = {.lex_state = 117, .external_lex_state = 15},
  [9392] = {.lex_state = 117, .external_lex_state = 15},
  [9393] = {.lex_state = 117, .external_lex_state = 15},
  [9394] = {.lex_state = 117, .external_lex_state = 15},
  [9395] = {.lex_state = 117, .external_lex_state = 15},
  [9396] = {.lex_state = 117, .external_lex_state = 15},
  [9397] = {.lex_state = 117, .external_lex_state = 15},
  [9398] = {.lex_state = 117, .external_lex_state = 15},
  [9399] = {.lex_state = 117, .external_lex_state = 15},
  [9400] = {.lex_state = 117, .external_lex_state = 15},
  [9401] = {.lex_state = 117, .external_lex_state = 15},
  [9402] = {.lex_state = 117, .external_lex_state = 15},
  [9403] = {.lex_state = 117, .external_lex_state = 15},
  [9404] = {.lex_state = 117, .external_lex_state = 15},
  [9405] = {.lex_state = 117, .external_lex_state = 15},
  [9406] = {.lex_state = 117, .external_lex_state = 15},
  [9407] = {.lex_state = 117, .external_lex_state = 15},
  [9408] = {.lex_state = 117, .external_lex_state = 15},
  [9409] = {.lex_state = 117, .external_lex_state = 15},
  [9410] = {.lex_state = 117, .external_lex_state = 15},
  [9411] = {.lex_state = 117, .external_lex_state = 15},
  [9412] = {.lex_state = 117, .external_lex_state = 15},
  [9413] = {.lex_state = 117, .external_lex_state = 15},
  [9414] = {.lex_state = 117, .external_lex_state = 15},
  [9415] = {.lex_state = 117, .external_lex_state = 15},
  [9416] = {.lex_state = 117, .external_lex_state = 15},
  [9417] = {.lex_state = 117, .external_lex_state = 15},
  [9418] = {.lex_state = 117, .external_lex_state = 15},
  [9419] = {.lex_state = 117, .external_lex_state = 15},
  [9420] = {.lex_state = 117, .external_lex_state = 15},
  [9421] = {.lex_state = 117, .external_lex_state = 15},
  [9422] = {.lex_state = 117, .external_lex_state = 15},
  [9423] = {.lex_state = 117, .external_lex_state = 15},
  [9424] = {.lex_state = 117, .external_lex_state = 15},
  [9425] = {.lex_state = 117, .external_lex_state = 15},
  [9426] = {.lex_state = 117, .external_lex_state = 15},
  [9427] = {.lex_state = 117, .external_lex_state = 15},
  [9428] = {.lex_state = 117, .external_lex_state = 15},
  [9429] = {.lex_state = 117, .external_lex_state = 15},
  [9430] = {.lex_state = 117, .external_lex_state = 15},
  [9431] = {.lex_state = 117, .external_lex_state = 15},
  [9432] = {.lex_state = 117, .external_lex_state = 15},
  [9433] = {.lex_state = 117, .external_lex_state = 15},
  [9434] = {.lex_state = 117, .external_lex_state = 15},
  [9435] = {.lex_state = 117, .external_lex_state = 15},
  [9436] = {.lex_state = 117, .external_lex_state = 15},
  [9437] = {.lex_state = 117, .external_lex_state = 15},
  [9438] = {.lex_state = 117, .external_lex_state = 15},
  [9439] = {.lex_state = 117, .external_lex_state = 15},
  [9440] = {.lex_state = 117, .external_lex_state = 15},
  [9441] = {.lex_state = 117, .external_lex_state = 15},
  [9442] = {.lex_state = 117, .external_lex_state = 15},
  [9443] = {.lex_state = 117, .external_lex_state = 15},
  [9444] = {.lex_state = 117, .external_lex_state = 15},
  [9445] = {.lex_state = 117, .external_lex_state = 15},
  [9446] = {.lex_state = 117, .external_lex_state = 15},
  [9447] = {.lex_state = 117, .external_lex_state = 19},
  [9448] = {.lex_state = 117, .external_lex_state = 15},
  [9449] = {.lex_state = 117, .external_lex_state = 15},
  [9450] = {.lex_state = 117, .external_lex_state = 15},
  [9451] = {.lex_state = 117, .external_lex_state = 19},
  [9452] = {.lex_state = 117, .external_lex_state = 15},
  [9453] = {.lex_state = 117, .external_lex_state = 15},
  [9454] = {.lex_state = 117, .external_lex_state = 15},
  [9455] = {.lex_state = 117, .external_lex_state = 15},
  [9456] = {.lex_state = 117, .external_lex_state = 15},
  [9457] = {.lex_state = 117, .external_lex_state = 15},
  [9458] = {.lex_state = 117, .external_lex_state = 19},
  [9459] = {.lex_state = 117, .external_lex_state = 15},
  [9460] = {.lex_state = 117, .external_lex_state = 15},
  [9461] = {.lex_state = 117, .external_lex_state = 15},
  [9462] = {.lex_state = 117, .external_lex_state = 15},
  [9463] = {.lex_state = 117, .external_lex_state = 15},
  [9464] = {.lex_state = 117, .external_lex_state = 15},
  [9465] = {.lex_state = 117, .external_lex_state = 15},
  [9466] = {.lex_state = 117, .external_lex_state = 15},
  [9467] = {.lex_state = 117, .external_lex_state = 15},
  [9468] = {.lex_state = 117, .external_lex_state = 15},
  [9469] = {.lex_state = 117, .external_lex_state = 15},
  [9470] = {.lex_state = 117, .external_lex_state = 15},
  [9471] = {.lex_state = 117, .external_lex_state = 15},
  [9472] = {.lex_state = 117, .external_lex_state = 15},
  [9473] = {.lex_state = 117, .external_lex_state = 15},
  [9474] = {.lex_state = 117, .external_lex_state = 15},
  [9475] = {.lex_state = 117, .external_lex_state = 15},
  [9476] = {.lex_state = 117, .external_lex_state = 15},
  [9477] = {.lex_state = 117, .external_lex_state = 15},
  [9478] = {.lex_state = 117, .external_lex_state = 15},
  [9479] = {.lex_state = 117, .external_lex_state = 15},
  [9480] = {.lex_state = 117, .external_lex_state = 15},
  [9481] = {.lex_state = 117, .external_lex_state = 15},
  [9482] = {.lex_state = 117, .external_lex_state = 15},
  [9483] = {.lex_state = 117, .external_lex_state = 15},
  [9484] = {.lex_state = 117, .external_lex_state = 25},
  [9485] = {.lex_state = 117, .external_lex_state = 25},
  [9486] = {.lex_state = 117, .external_lex_state = 25},
  [9487] = {.lex_state = 117, .external_lex_state = 15},
  [9488] = {.lex_state = 117, .external_lex_state = 15},
  [9489] = {.lex_state = 117, .external_lex_state = 15},
  [9490] = {.lex_state = 117, .external_lex_state = 15},
  [9491] = {.lex_state = 117, .external_lex_state = 15},
  [9492] = {.lex_state = 117, .external_lex_state = 15},
  [9493] = {.lex_state = 117, .external_lex_state = 15},
  [9494] = {.lex_state = 117, .external_lex_state = 15},
  [9495] = {.lex_state = 117, .external_lex_state = 15},
  [9496] = {.lex_state = 117, .external_lex_state = 15},
  [9497] = {.lex_state = 117, .external_lex_state = 15},
  [9498] = {.lex_state = 117, .external_lex_state = 15},
  [9499] = {.lex_state = 117, .external_lex_state = 15},
  [9500] = {.lex_state = 117, .external_lex_state = 15},
  [9501] = {.lex_state = 117, .external_lex_state = 15},
  [9502] = {.lex_state = 117, .external_lex_state = 15},
  [9503] = {.lex_state = 117, .external_lex_state = 15},
  [9504] = {.lex_state = 117, .external_lex_state = 15},
  [9505] = {.lex_state = 117, .external_lex_state = 15},
  [9506] = {.lex_state = 117, .external_lex_state = 15},
  [9507] = {.lex_state = 117, .external_lex_state = 19},
  [9508] = {.lex_state = 117, .external_lex_state = 15},
  [9509] = {.lex_state = 117, .external_lex_state = 15},
  [9510] = {.lex_state = 117, .external_lex_state = 15},
  [9511] = {.lex_state = 117, .external_lex_state = 15},
  [9512] = {.lex_state = 117, .external_lex_state = 15},
  [9513] = {.lex_state = 117, .external_lex_state = 15},
  [9514] = {.lex_state = 117, .external_lex_state = 15},
  [9515] = {.lex_state = 117, .external_lex_state = 15},
  [9516] = {.lex_state = 117, .external_lex_state = 15},
  [9517] = {.lex_state = 117, .external_lex_state = 15},
  [9518] = {.lex_state = 117, .external_lex_state = 15},
  [9519] = {.lex_state = 117, .external_lex_state = 15},
  [9520] = {.lex_state = 117, .external_lex_state = 15},
  [9521] = {.lex_state = 117, .external_lex_state = 15},
  [9522] = {.lex_state = 117, .external_lex_state = 15},
  [9523] = {.lex_state = 117, .external_lex_state = 15},
  [9524] = {.lex_state = 117, .external_lex_state = 15},
  [9525] = {.lex_state = 117, .external_lex_state = 15},
  [9526] = {.lex_state = 117, .external_lex_state = 15},
  [9527] = {.lex_state = 117, .external_lex_state = 15},
  [9528] = {.lex_state = 117, .external_lex_state = 15},
  [9529] = {.lex_state = 117, .external_lex_state = 15},
  [9530] = {.lex_state = 117, .external_lex_state = 15},
  [9531] = {.lex_state = 117, .external_lex_state = 15},
  [9532] = {.lex_state = 117, .external_lex_state = 15},
  [9533] = {.lex_state = 117, .external_lex_state = 15},
  [9534] = {.lex_state = 117, .external_lex_state = 15},
  [9535] = {.lex_state = 117, .external_lex_state = 15},
  [9536] = {.lex_state = 117, .external_lex_state = 15},
  [9537] = {.lex_state = 117, .external_lex_state = 15},
  [9538] = {.lex_state = 117, .external_lex_state = 15},
  [9539] = {.lex_state = 117, .external_lex_state = 15},
  [9540] = {.lex_state = 117, .external_lex_state = 15},
  [9541] = {.lex_state = 117, .external_lex_state = 15},
  [9542] = {.lex_state = 117, .external_lex_state = 15},
  [9543] = {.lex_state = 117, .external_lex_state = 15},
  [9544] = {.lex_state = 117, .external_lex_state = 15},
  [9545] = {.lex_state = 117, .external_lex_state = 15},
  [9546] = {.lex_state = 117, .external_lex_state = 15},
  [9547] = {.lex_state = 117, .external_lex_state = 15},
  [9548] = {.lex_state = 117, .external_lex_state = 15},
  [9549] = {.lex_state = 117, .external_lex_state = 15},
  [9550] = {.lex_state = 117, .external_lex_state = 15},
  [9551] = {.lex_state = 117, .external_lex_state = 15},
  [9552] = {.lex_state = 117, .external_lex_state = 15},
  [9553] = {.lex_state = 117, .external_lex_state = 15},
  [9554] = {.lex_state = 117, .external_lex_state = 15},
  [9555] = {.lex_state = 117, .external_lex_state = 15},
  [9556] = {.lex_state = 117, .external_lex_state = 15},
  [9557] = {.lex_state = 117, .external_lex_state = 15},
  [9558] = {.lex_state = 117, .external_lex_state = 15},
  [9559] = {.lex_state = 117, .external_lex_state = 15},
  [9560] = {.lex_state = 117, .external_lex_state = 15},
  [9561] = {.lex_state = 117, .external_lex_state = 15},
  [9562] = {.lex_state = 117, .external_lex_state = 15},
  [9563] = {.lex_state = 117, .external_lex_state = 15},
  [9564] = {.lex_state = 117, .external_lex_state = 15},
  [9565] = {.lex_state = 117, .external_lex_state = 15},
  [9566] = {.lex_state = 117, .external_lex_state = 15},
  [9567] = {.lex_state = 117, .external_lex_state = 15},
  [9568] = {.lex_state = 117, .external_lex_state = 15},
  [9569] = {.lex_state = 117, .external_lex_state = 15},
  [9570] = {.lex_state = 117, .external_lex_state = 15},
  [9571] = {.lex_state = 117, .external_lex_state = 15},
  [9572] = {.lex_state = 117, .external_lex_state = 15},
  [9573] = {.lex_state = 117, .external_lex_state = 15},
  [9574] = {.lex_state = 117, .external_lex_state = 15},
  [9575] = {.lex_state = 117, .external_lex_state = 15},
  [9576] = {.lex_state = 117, .external_lex_state = 15},
  [9577] = {.lex_state = 117, .external_lex_state = 15},
  [9578] = {.lex_state = 117, .external_lex_state = 15},
  [9579] = {.lex_state = 117, .external_lex_state = 15},
  [9580] = {.lex_state = 117, .external_lex_state = 15},
  [9581] = {.lex_state = 117, .external_lex_state = 15},
  [9582] = {.lex_state = 117, .external_lex_state = 15},
  [9583] = {.lex_state = 117, .external_lex_state = 15},
  [9584] = {.lex_state = 117, .external_lex_state = 15},
  [9585] = {.lex_state = 117, .external_lex_state = 15},
  [9586] = {.lex_state = 117, .external_lex_state = 15},
  [9587] = {.lex_state = 117, .external_lex_state = 15},
  [9588] = {.lex_state = 117, .external_lex_state = 15},
  [9589] = {.lex_state = 117, .external_lex_state = 15},
  [9590] = {.lex_state = 117, .external_lex_state = 15},
  [9591] = {.lex_state = 117, .external_lex_state = 15},
  [9592] = {.lex_state = 117, .external_lex_state = 15},
  [9593] = {.lex_state = 117, .external_lex_state = 15},
  [9594] = {.lex_state = 117, .external_lex_state = 15},
  [9595] = {.lex_state = 117, .external_lex_state = 15},
  [9596] = {.lex_state = 117, .external_lex_state = 15},
  [9597] = {.lex_state = 117, .external_lex_state = 15},
  [9598] = {.lex_state = 117, .external_lex_state = 15},
  [9599] = {.lex_state = 117, .external_lex_state = 15},
  [9600] = {.lex_state = 117, .external_lex_state = 15},
  [9601] = {.lex_state = 117, .external_lex_state = 15},
  [9602] = {.lex_state = 117, .external_lex_state = 15},
  [9603] = {.lex_state = 117, .external_lex_state = 15},
  [9604] = {.lex_state = 117, .external_lex_state = 15},
  [9605] = {.lex_state = 117, .external_lex_state = 15},
  [9606] = {.lex_state = 117, .external_lex_state = 15},
  [9607] = {.lex_state = 117, .external_lex_state = 15},
  [9608] = {.lex_state = 117, .external_lex_state = 15},
  [9609] = {.lex_state = 117, .external_lex_state = 15},
  [9610] = {.lex_state = 117, .external_lex_state = 15},
  [9611] = {.lex_state = 117, .external_lex_state = 15},
  [9612] = {.lex_state = 117, .external_lex_state = 15},
  [9613] = {.lex_state = 117, .external_lex_state = 15},
  [9614] = {.lex_state = 117, .external_lex_state = 15},
  [9615] = {.lex_state = 117, .external_lex_state = 15},
  [9616] = {.lex_state = 117, .external_lex_state = 15},
  [9617] = {.lex_state = 117, .external_lex_state = 15},
  [9618] = {.lex_state = 117, .external_lex_state = 15},
  [9619] = {.lex_state = 117, .external_lex_state = 15},
  [9620] = {.lex_state = 117, .external_lex_state = 15},
  [9621] = {.lex_state = 117, .external_lex_state = 15},
  [9622] = {.lex_state = 117, .external_lex_state = 15},
  [9623] = {.lex_state = 117, .external_lex_state = 15},
  [9624] = {.lex_state = 117, .external_lex_state = 15},
  [9625] = {.lex_state = 117, .external_lex_state = 15},
  [9626] = {.lex_state = 117, .external_lex_state = 15},
  [9627] = {.lex_state = 117, .external_lex_state = 15},
  [9628] = {.lex_state = 117, .external_lex_state = 15},
  [9629] = {.lex_state = 117, .external_lex_state = 15},
  [9630] = {.lex_state = 117, .external_lex_state = 15},
  [9631] = {.lex_state = 117, .external_lex_state = 15},
  [9632] = {.lex_state = 117, .external_lex_state = 15},
  [9633] = {.lex_state = 117, .external_lex_state = 15},
  [9634] = {.lex_state = 117, .external_lex_state = 15},
  [9635] = {.lex_state = 117, .external_lex_state = 15},
  [9636] = {.lex_state = 117, .external_lex_state = 15},
  [9637] = {.lex_state = 117, .external_lex_state = 15},
  [9638] = {.lex_state = 117, .external_lex_state = 15},
  [9639] = {.lex_state = 117, .external_lex_state = 15},
  [9640] = {.lex_state = 117, .external_lex_state = 15},
  [9641] = {.lex_state = 117, .external_lex_state = 15},
  [9642] = {.lex_state = 117, .external_lex_state = 15},
  [9643] = {.lex_state = 117, .external_lex_state = 15},
  [9644] = {.lex_state = 117, .external_lex_state = 15},
  [9645] = {.lex_state = 117, .external_lex_state = 15},
  [9646] = {.lex_state = 117, .external_lex_state = 15},
  [9647] = {.lex_state = 117, .external_lex_state = 15},
  [9648] = {.lex_state = 117, .external_lex_state = 15},
  [9649] = {.lex_state = 117, .external_lex_state = 15},
  [9650] = {.lex_state = 117, .external_lex_state = 15},
  [9651] = {.lex_state = 117, .external_lex_state = 15},
  [9652] = {.lex_state = 117, .external_lex_state = 15},
  [9653] = {.lex_state = 117, .external_lex_state = 15},
  [9654] = {.lex_state = 117, .external_lex_state = 15},
  [9655] = {.lex_state = 117, .external_lex_state = 15},
  [9656] = {.lex_state = 117, .external_lex_state = 15},
  [9657] = {.lex_state = 117, .external_lex_state = 15},
  [9658] = {.lex_state = 117, .external_lex_state = 15},
  [9659] = {.lex_state = 117, .external_lex_state = 15},
  [9660] = {.lex_state = 117, .external_lex_state = 15},
  [9661] = {.lex_state = 117, .external_lex_state = 15},
  [9662] = {.lex_state = 117, .external_lex_state = 15},
  [9663] = {.lex_state = 117, .external_lex_state = 15},
  [9664] = {.lex_state = 117, .external_lex_state = 15},
  [9665] = {.lex_state = 117, .external_lex_state = 15},
  [9666] = {.lex_state = 117, .external_lex_state = 15},
  [9667] = {.lex_state = 117, .external_lex_state = 15},
  [9668] = {.lex_state = 117, .external_lex_state = 15},
  [9669] = {.lex_state = 117, .external_lex_state = 15},
  [9670] = {.lex_state = 117, .external_lex_state = 15},
  [9671] = {.lex_state = 117, .external_lex_state = 15},
  [9672] = {.lex_state = 117, .external_lex_state = 15},
  [9673] = {.lex_state = 117, .external_lex_state = 15},
  [9674] = {.lex_state = 117, .external_lex_state = 15},
  [9675] = {.lex_state = 117, .external_lex_state = 15},
  [9676] = {.lex_state = 117, .external_lex_state = 15},
  [9677] = {.lex_state = 117, .external_lex_state = 15},
  [9678] = {.lex_state = 117, .external_lex_state = 15},
  [9679] = {.lex_state = 117, .external_lex_state = 15},
  [9680] = {.lex_state = 117, .external_lex_state = 15},
  [9681] = {.lex_state = 117, .external_lex_state = 15},
  [9682] = {.lex_state = 117, .external_lex_state = 15},
  [9683] = {.lex_state = 117, .external_lex_state = 15},
  [9684] = {.lex_state = 117, .external_lex_state = 15},
  [9685] = {.lex_state = 117, .external_lex_state = 15},
  [9686] = {.lex_state = 117, .external_lex_state = 15},
  [9687] = {.lex_state = 117, .external_lex_state = 15},
  [9688] = {.lex_state = 117, .external_lex_state = 15},
  [9689] = {.lex_state = 117, .external_lex_state = 15},
  [9690] = {.lex_state = 117, .external_lex_state = 15},
  [9691] = {.lex_state = 117, .external_lex_state = 15},
  [9692] = {.lex_state = 117, .external_lex_state = 15},
  [9693] = {.lex_state = 117, .external_lex_state = 15},
  [9694] = {.lex_state = 117, .external_lex_state = 15},
  [9695] = {.lex_state = 117, .external_lex_state = 15},
  [9696] = {.lex_state = 117, .external_lex_state = 15},
  [9697] = {.lex_state = 117, .external_lex_state = 15},
  [9698] = {.lex_state = 117, .external_lex_state = 15},
  [9699] = {.lex_state = 117, .external_lex_state = 15},
  [9700] = {.lex_state = 117, .external_lex_state = 15},
  [9701] = {.lex_state = 117, .external_lex_state = 15},
  [9702] = {.lex_state = 117, .external_lex_state = 15},
  [9703] = {.lex_state = 117, .external_lex_state = 15},
  [9704] = {.lex_state = 117, .external_lex_state = 15},
  [9705] = {.lex_state = 117, .external_lex_state = 15},
  [9706] = {.lex_state = 117, .external_lex_state = 15},
  [9707] = {.lex_state = 117, .external_lex_state = 15},
  [9708] = {.lex_state = 117, .external_lex_state = 15},
  [9709] = {.lex_state = 117, .external_lex_state = 15},
  [9710] = {.lex_state = 117, .external_lex_state = 15},
  [9711] = {.lex_state = 117, .external_lex_state = 25},
  [9712] = {.lex_state = 117, .external_lex_state = 25},
  [9713] = {.lex_state = 117, .external_lex_state = 19},
  [9714] = {.lex_state = 117, .external_lex_state = 25},
  [9715] = {.lex_state = 117, .external_lex_state = 25},
  [9716] = {.lex_state = 117, .external_lex_state = 25},
  [9717] = {.lex_state = 117, .external_lex_state = 25},
  [9718] = {.lex_state = 117, .external_lex_state = 2},
  [9719] = {.lex_state = 117, .external_lex_state = 25},
  [9720] = {.lex_state = 117, .external_lex_state = 25},
  [9721] = {.lex_state = 117, .external_lex_state = 25},
  [9722] = {.lex_state = 117, .external_lex_state = 25},
  [9723] = {.lex_state = 117, .external_lex_state = 25},
  [9724] = {.lex_state = 117, .external_lex_state = 25},
  [9725] = {.lex_state = 117, .external_lex_state = 25},
  [9726] = {.lex_state = 117, .external_lex_state = 25},
  [9727] = {.lex_state = 117, .external_lex_state = 25},
  [9728] = {.lex_state = 117, .external_lex_state = 25},
  [9729] = {.lex_state = 117, .external_lex_state = 25},
  [9730] = {.lex_state = 117, .external_lex_state = 25},
  [9731] = {.lex_state = 117, .external_lex_state = 25},
  [9732] = {.lex_state = 117, .external_lex_state = 25},
  [9733] = {.lex_state = 117, .external_lex_state = 25},
  [9734] = {.lex_state = 117, .external_lex_state = 25},
  [9735] = {.lex_state = 117, .external_lex_state = 25},
  [9736] = {.lex_state = 117, .external_lex_state = 25},
  [9737] = {.lex_state = 117, .external_lex_state = 25},
  [9738] = {.lex_state = 117, .external_lex_state = 25},
  [9739] = {.lex_state = 117, .external_lex_state = 25},
  [9740] = {.lex_state = 117, .external_lex_state = 25},
  [9741] = {.lex_state = 117, .external_lex_state = 25},
  [9742] = {.lex_state = 117, .external_lex_state = 25},
  [9743] = {.lex_state = 117, .external_lex_state = 25},
  [9744] = {.lex_state = 117, .external_lex_state = 25},
  [9745] = {.lex_state = 117, .external_lex_state = 25},
  [9746] = {.lex_state = 117, .external_lex_state = 19},
  [9747] = {.lex_state = 117, .external_lex_state = 25},
  [9748] = {.lex_state = 117, .external_lex_state = 25},
  [9749] = {.lex_state = 117, .external_lex_state = 25},
  [9750] = {.lex_state = 117, .external_lex_state = 25},
  [9751] = {.lex_state = 10, .external_lex_state = 15},
  [9752] = {.lex_state = 117, .external_lex_state = 25},
  [9753] = {.lex_state = 117, .external_lex_state = 19},
  [9754] = {.lex_state = 117, .external_lex_state = 25},
  [9755] = {.lex_state = 117, .external_lex_state = 25},
  [9756] = {.lex_state = 117, .external_lex_state = 25},
  [9757] = {.lex_state = 117, .external_lex_state = 25},
  [9758] = {.lex_state = 117, .external_lex_state = 25},
  [9759] = {.lex_state = 117, .external_lex_state = 25},
  [9760] = {.lex_state = 117, .external_lex_state = 2},
  [9761] = {.lex_state = 117, .external_lex_state = 2},
  [9762] = {.lex_state = 117, .external_lex_state = 19},
  [9763] = {.lex_state = 117, .external_lex_state = 25},
  [9764] = {.lex_state = 117, .external_lex_state = 25},
  [9765] = {.lex_state = 117, .external_lex_state = 25},
  [9766] = {.lex_state = 117, .external_lex_state = 25},
  [9767] = {.lex_state = 117, .external_lex_state = 25},
  [9768] = {.lex_state = 117, .external_lex_state = 25},
  [9769] = {.lex_state = 117, .external_lex_state = 25},
  [9770] = {.lex_state = 117, .external_lex_state = 25},
  [9771] = {.lex_state = 117, .external_lex_state = 19},
  [9772] = {.lex_state = 117, .external_lex_state = 25},
  [9773] = {.lex_state = 117, .external_lex_state = 25},
  [9774] = {.lex_state = 117, .external_lex_state = 25},
  [9775] = {.lex_state = 117, .external_lex_state = 25},
  [9776] = {.lex_state = 117, .external_lex_state = 19},
  [9777] = {.lex_state = 117, .external_lex_state = 25},
  [9778] = {.lex_state = 117, .external_lex_state = 25},
  [9779] = {.lex_state = 117, .external_lex_state = 15},
  [9780] = {.lex_state = 117, .external_lex_state = 24},
  [9781] = {.lex_state = 117, .external_lex_state = 24},
  [9782] = {.lex_state = 117, .external_lex_state = 24},
  [9783] = {.lex_state = 117, .external_lex_state = 15},
  [9784] = {.lex_state = 117, .external_lex_state = 15},
  [9785] = {.lex_state = 117, .external_lex_state = 24},
  [9786] = {.lex_state = 117, .external_lex_state = 24},
  [9787] = {.lex_state = 117, .external_lex_state = 22},
  [9788] = {.lex_state = 117, .external_lex_state = 24},
  [9789] = {.lex_state = 117, .external_lex_state = 24},
  [9790] = {.lex_state = 117, .external_lex_state = 15},
  [9791] = {.lex_state = 117, .external_lex_state = 19},
  [9792] = {.lex_state = 117, .external_lex_state = 24},
  [9793] = {.lex_state = 117, .external_lex_state = 22},
  [9794] = {.lex_state = 117, .external_lex_state = 24},
  [9795] = {.lex_state = 117, .external_lex_state = 22},
  [9796] = {.lex_state = 117, .external_lex_state = 22},
  [9797] = {.lex_state = 117, .external_lex_state = 24},
  [9798] = {.lex_state = 117, .external_lex_state = 22},
  [9799] = {.lex_state = 117, .external_lex_state = 15},
  [9800] = {.lex_state = 117, .external_lex_state = 15},
  [9801] = {.lex_state = 117, .external_lex_state = 24},
  [9802] = {.lex_state = 117, .external_lex_state = 22},
  [9803] = {.lex_state = 117, .external_lex_state = 24},
  [9804] = {.lex_state = 117, .external_lex_state = 24},
  [9805] = {.lex_state = 117, .external_lex_state = 24},
  [9806] = {.lex_state = 117, .external_lex_state = 22},
  [9807] = {.lex_state = 117, .external_lex_state = 24},
  [9808] = {.lex_state = 117, .external_lex_state = 24},
  [9809] = {.lex_state = 117, .external_lex_state = 19},
  [9810] = {.lex_state = 117, .external_lex_state = 19},
  [9811] = {.lex_state = 117, .external_lex_state = 15},
  [9812] = {.lex_state = 117, .external_lex_state = 19},
  [9813] = {.lex_state = 117, .external_lex_state = 19},
  [9814] = {.lex_state = 117, .external_lex_state = 24},
  [9815] = {.lex_state = 117, .external_lex_state = 24},
  [9816] = {.lex_state = 117, .external_lex_state = 15},
  [9817] = {.lex_state = 117, .external_lex_state = 24},
  [9818] = {.lex_state = 117, .external_lex_state = 24},
  [9819] = {.lex_state = 117, .external_lex_state = 24},
  [9820] = {.lex_state = 117, .external_lex_state = 15},
  [9821] = {.lex_state = 117, .external_lex_state = 15},
  [9822] = {.lex_state = 117, .external_lex_state = 15},
  [9823] = {.lex_state = 117, .external_lex_state = 19},
  [9824] = {.lex_state = 117, .external_lex_state = 19},
  [9825] = {.lex_state = 117, .external_lex_state = 24},
  [9826] = {.lex_state = 117, .external_lex_state = 24},
  [9827] = {.lex_state = 117, .external_lex_state = 24},
  [9828] = {.lex_state = 117, .external_lex_state = 19},
  [9829] = {.lex_state = 117, .external_lex_state = 19},
  [9830] = {.lex_state = 117, .external_lex_state = 24},
  [9831] = {.lex_state = 117, .external_lex_state = 24},
  [9832] = {.lex_state = 117, .external_lex_state = 24},
  [9833] = {.lex_state = 117, .external_lex_state = 15},
  [9834] = {.lex_state = 117, .external_lex_state = 24},
  [9835] = {.lex_state = 117, .external_lex_state = 15},
  [9836] = {.lex_state = 117, .external_lex_state = 15},
  [9837] = {.lex_state = 117, .external_lex_state = 22},
  [9838] = {.lex_state = 117, .external_lex_state = 19},
  [9839] = {.lex_state = 117, .external_lex_state = 20},
  [9840] = {.lex_state = 117, .external_lex_state = 20},
  [9841] = {.lex_state = 117, .external_lex_state = 20},
  [9842] = {.lex_state = 117, .external_lex_state = 19},
  [9843] = {.lex_state = 117, .external_lex_state = 20},
  [9844] = {.lex_state = 117, .external_lex_state = 15},
  [9845] = {.lex_state = 117, .external_lex_state = 20},
  [9846] = {.lex_state = 3, .external_lex_state = 22},
  [9847] = {.lex_state = 117, .external_lex_state = 15},
  [9848] = {.lex_state = 117, .external_lex_state = 15},
  [9849] = {.lex_state = 117, .external_lex_state = 24},
  [9850] = {.lex_state = 117, .external_lex_state = 24},
  [9851] = {.lex_state = 117, .external_lex_state = 20},
  [9852] = {.lex_state = 117, .external_lex_state = 20},
  [9853] = {.lex_state = 117, .external_lex_state = 20},
  [9854] = {.lex_state = 117, .external_lex_state = 20},
  [9855] = {.lex_state = 117, .external_lex_state = 19},
  [9856] = {.lex_state = 117, .external_lex_state = 22},
  [9857] = {.lex_state = 3, .external_lex_state = 22},
  [9858] = {.lex_state = 117, .external_lex_state = 19},
  [9859] = {.lex_state = 117, .external_lex_state = 20},
  [9860] = {.lex_state = 117, .external_lex_state = 20},
  [9861] = {.lex_state = 117, .external_lex_state = 19},
  [9862] = {.lex_state = 117, .external_lex_state = 20},
  [9863] = {.lex_state = 117, .external_lex_state = 20},
  [9864] = {.lex_state = 117, .external_lex_state = 20},
  [9865] = {.lex_state = 117, .external_lex_state = 15},
  [9866] = {.lex_state = 117, .external_lex_state = 19},
  [9867] = {.lex_state = 117, .external_lex_state = 24},
  [9868] = {.lex_state = 3, .external_lex_state = 22},
  [9869] = {.lex_state = 117, .external_lex_state = 19},
  [9870] = {.lex_state = 117, .external_lex_state = 19},
  [9871] = {.lex_state = 117, .external_lex_state = 15},
  [9872] = {.lex_state = 117, .external_lex_state = 24},
  [9873] = {.lex_state = 117, .external_lex_state = 22},
  [9874] = {.lex_state = 117, .external_lex_state = 22},
  [9875] = {.lex_state = 117, .external_lex_state = 24},
  [9876] = {.lex_state = 117, .external_lex_state = 22},
  [9877] = {.lex_state = 117, .external_lex_state = 22},
  [9878] = {.lex_state = 117, .external_lex_state = 24},
  [9879] = {.lex_state = 117, .external_lex_state = 20},
  [9880] = {.lex_state = 117, .external_lex_state = 20},
  [9881] = {.lex_state = 117, .external_lex_state = 20},
  [9882] = {.lex_state = 117, .external_lex_state = 22},
  [9883] = {.lex_state = 117, .external_lex_state = 20},
  [9884] = {.lex_state = 117, .external_lex_state = 24},
  [9885] = {.lex_state = 117, .external_lex_state = 15},
  [9886] = {.lex_state = 117, .external_lex_state = 24},
  [9887] = {.lex_state = 117, .external_lex_state = 22},
  [9888] = {.lex_state = 117, .external_lex_state = 24},
  [9889] = {.lex_state = 117, .external_lex_state = 24},
  [9890] = {.lex_state = 117, .external_lex_state = 20},
  [9891] = {.lex_state = 117, .external_lex_state = 20},
  [9892] = {.lex_state = 117, .external_lex_state = 20},
  [9893] = {.lex_state = 117, .external_lex_state = 20},
  [9894] = {.lex_state = 117, .external_lex_state = 20},
  [9895] = {.lex_state = 117, .external_lex_state = 20},
  [9896] = {.lex_state = 117, .external_lex_state = 20},
  [9897] = {.lex_state = 117, .external_lex_state = 20},
  [9898] = {.lex_state = 117, .external_lex_state = 24},
  [9899] = {.lex_state = 117, .external_lex_state = 20},
  [9900] = {.lex_state = 117, .external_lex_state = 20},
  [9901] = {.lex_state = 117, .external_lex_state = 20},
  [9902] = {.lex_state = 117, .external_lex_state = 20},
  [9903] = {.lex_state = 117, .external_lex_state = 20},
  [9904] = {.lex_state = 117, .external_lex_state = 20},
  [9905] = {.lex_state = 117, .external_lex_state = 20},
  [9906] = {.lex_state = 117, .external_lex_state = 20},
  [9907] = {.lex_state = 117, .external_lex_state = 20},
  [9908] = {.lex_state = 117, .external_lex_state = 20},
  [9909] = {.lex_state = 117, .external_lex_state = 20},
  [9910] = {.lex_state = 117, .external_lex_state = 20},
  [9911] = {.lex_state = 117, .external_lex_state = 24},
  [9912] = {.lex_state = 117, .external_lex_state = 24},
  [9913] = {.lex_state = 117, .external_lex_state = 24},
  [9914] = {.lex_state = 117, .external_lex_state = 24},
  [9915] = {.lex_state = 117, .external_lex_state = 24},
  [9916] = {.lex_state = 117, .external_lex_state = 20},
  [9917] = {.lex_state = 117, .external_lex_state = 20},
  [9918] = {.lex_state = 117, .external_lex_state = 20},
  [9919] = {.lex_state = 3, .external_lex_state = 22},
  [9920] = {.lex_state = 3, .external_lex_state = 22},
  [9921] = {.lex_state = 117, .external_lex_state = 15},
  [9922] = {.lex_state = 117, .external_lex_state = 20},
  [9923] = {.lex_state = 117, .external_lex_state = 20},
  [9924] = {.lex_state = 117, .external_lex_state = 20},
  [9925] = {.lex_state = 117, .external_lex_state = 19},
  [9926] = {.lex_state = 117, .external_lex_state = 19},
  [9927] = {.lex_state = 117, .external_lex_state = 20},
  [9928] = {.lex_state = 117, .external_lex_state = 20},
  [9929] = {.lex_state = 117, .external_lex_state = 20},
  [9930] = {.lex_state = 117, .external_lex_state = 20},
  [9931] = {.lex_state = 117, .external_lex_state = 20},
  [9932] = {.lex_state = 117, .external_lex_state = 20},
  [9933] = {.lex_state = 117, .external_lex_state = 20},
  [9934] = {.lex_state = 117, .external_lex_state = 20},
  [9935] = {.lex_state = 117, .external_lex_state = 20},
  [9936] = {.lex_state = 117, .external_lex_state = 19},
  [9937] = {.lex_state = 117, .external_lex_state = 22},
  [9938] = {.lex_state = 117, .external_lex_state = 15},
  [9939] = {.lex_state = 117, .external_lex_state = 24},
  [9940] = {.lex_state = 117, .external_lex_state = 19},
  [9941] = {.lex_state = 117, .external_lex_state = 19},
  [9942] = {.lex_state = 117, .external_lex_state = 22},
  [9943] = {.lex_state = 117, .external_lex_state = 19},
  [9944] = {.lex_state = 117, .external_lex_state = 19},
  [9945] = {.lex_state = 117, .external_lex_state = 20},
  [9946] = {.lex_state = 117, .external_lex_state = 20},
  [9947] = {.lex_state = 117, .external_lex_state = 20},
  [9948] = {.lex_state = 117, .external_lex_state = 15},
  [9949] = {.lex_state = 117, .external_lex_state = 15},
  [9950] = {.lex_state = 117, .external_lex_state = 15},
  [9951] = {.lex_state = 117, .external_lex_state = 20},
  [9952] = {.lex_state = 117, .external_lex_state = 20},
  [9953] = {.lex_state = 117, .external_lex_state = 20},
  [9954] = {.lex_state = 117, .external_lex_state = 20},
  [9955] = {.lex_state = 117, .external_lex_state = 20},
  [9956] = {.lex_state = 117, .external_lex_state = 19},
  [9957] = {.lex_state = 117, .external_lex_state = 19},
  [9958] = {.lex_state = 117, .external_lex_state = 19},
  [9959] = {.lex_state = 117, .external_lex_state = 19},
  [9960] = {.lex_state = 117, .external_lex_state = 19},
  [9961] = {.lex_state = 117, .external_lex_state = 19},
  [9962] = {.lex_state = 117, .external_lex_state = 20},
  [9963] = {.lex_state = 117, .external_lex_state = 24},
  [9964] = {.lex_state = 117, .external_lex_state = 20},
  [9965] = {.lex_state = 117, .external_lex_state = 20},
  [9966] = {.lex_state = 117, .external_lex_state = 22},
  [9967] = {.lex_state = 117, .external_lex_state = 10},
  [9968] = {.lex_state = 117, .external_lex_state = 10},
  [9969] = {.lex_state = 117, .external_lex_state = 10},
  [9970] = {.lex_state = 117, .external_lex_state = 10},
  [9971] = {.lex_state = 117, .external_lex_state = 10},
  [9972] = {.lex_state = 117, .external_lex_state = 15},
  [9973] = {.lex_state = 117, .external_lex_state = 15},
  [9974] = {.lex_state = 117, .external_lex_state = 15},
  [9975] = {.lex_state = 117, .external_lex_state = 15},
  [9976] = {.lex_state = 117, .external_lex_state = 22},
  [9977] = {.lex_state = 117, .external_lex_state = 15},
  [9978] = {.lex_state = 117, .external_lex_state = 15},
  [9979] = {.lex_state = 117, .external_lex_state = 10},
  [9980] = {.lex_state = 117, .external_lex_state = 15},
  [9981] = {.lex_state = 117, .external_lex_state = 10},
  [9982] = {.lex_state = 117, .external_lex_state = 22},
  [9983] = {.lex_state = 117, .external_lex_state = 10},
  [9984] = {.lex_state = 117, .external_lex_state = 15},
  [9985] = {.lex_state = 117, .external_lex_state = 10},
  [9986] = {.lex_state = 117, .external_lex_state = 22},
  [9987] = {.lex_state = 117, .external_lex_state = 20},
  [9988] = {.lex_state = 117, .external_lex_state = 22},
  [9989] = {.lex_state = 3, .external_lex_state = 22},
  [9990] = {.lex_state = 117, .external_lex_state = 22},
  [9991] = {.lex_state = 117, .external_lex_state = 22},
  [9992] = {.lex_state = 117, .external_lex_state = 10},
  [9993] = {.lex_state = 117, .external_lex_state = 22},
  [9994] = {.lex_state = 117, .external_lex_state = 20},
  [9995] = {.lex_state = 117, .external_lex_state = 22},
  [9996] = {.lex_state = 117, .external_lex_state = 10},
  [9997] = {.lex_state = 117, .external_lex_state = 22},
  [9998] = {.lex_state = 117, .external_lex_state = 22},
  [9999] = {.lex_state = 3, .external_lex_state = 22},
  [10000] = {.lex_state = 117, .external_lex_state = 2},
  [10001] = {.lex_state = 117, .external_lex_state = 20},
  [10002] = {.lex_state = 117, .external_lex_state = 22},
  [10003] = {.lex_state = 117, .external_lex_state = 20},
  [10004] = {.lex_state = 3, .external_lex_state = 22},
  [10005] = {.lex_state = 117, .external_lex_state = 22},
  [10006] = {.lex_state = 117, .external_lex_state = 22},
  [10007] = {.lex_state = 117, .external_lex_state = 10},
  [10008] = {.lex_state = 117, .external_lex_state = 22},
  [10009] = {.lex_state = 117, .external_lex_state = 22},
  [10010] = {.lex_state = 117, .external_lex_state = 10},
  [10011] = {.lex_state = 3, .external_lex_state = 22},
  [10012] = {.lex_state = 117, .external_lex_state = 2},
  [10013] = {.lex_state = 117, .external_lex_state = 20},
  [10014] = {.lex_state = 117, .external_lex_state = 22},
  [10015] = {.lex_state = 117, .external_lex_state = 22},
  [10016] = {.lex_state = 117, .external_lex_state = 20},
  [10017] = {.lex_state = 117, .external_lex_state = 20},
  [10018] = {.lex_state = 117, .external_lex_state = 22},
  [10019] = {.lex_state = 117, .external_lex_state = 22},
  [10020] = {.lex_state = 117, .external_lex_state = 2},
  [10021] = {.lex_state = 3, .external_lex_state = 22},
  [10022] = {.lex_state = 117, .external_lex_state = 20},
  [10023] = {.lex_state = 117, .external_lex_state = 20},
  [10024] = {.lex_state = 117, .external_lex_state = 20},
  [10025] = {.lex_state = 117, .external_lex_state = 2},
  [10026] = {.lex_state = 117, .external_lex_state = 20},
  [10027] = {.lex_state = 117, .external_lex_state = 20},
  [10028] = {.lex_state = 117, .external_lex_state = 12},
  [10029] = {.lex_state = 117, .external_lex_state = 10},
  [10030] = {.lex_state = 117, .external_lex_state = 20},
  [10031] = {.lex_state = 117, .external_lex_state = 20},
  [10032] = {.lex_state = 117, .external_lex_state = 10},
  [10033] = {.lex_state = 117, .external_lex_state = 26},
  [10034] = {.lex_state = 117, .external_lex_state = 10},
  [10035] = {.lex_state = 117, .external_lex_state = 26},
  [10036] = {.lex_state = 117, .external_lex_state = 22},
  [10037] = {.lex_state = 117, .external_lex_state = 26},
  [10038] = {.lex_state = 117, .external_lex_state = 20},
  [10039] = {.lex_state = 117, .external_lex_state = 20},
  [10040] = {.lex_state = 117, .external_lex_state = 20},
  [10041] = {.lex_state = 117, .external_lex_state = 26},
  [10042] = {.lex_state = 117, .external_lex_state = 20},
  [10043] = {.lex_state = 117, .external_lex_state = 20},
  [10044] = {.lex_state = 117, .external_lex_state = 20},
  [10045] = {.lex_state = 117, .external_lex_state = 26},
  [10046] = {.lex_state = 117, .external_lex_state = 20},
  [10047] = {.lex_state = 117, .external_lex_state = 20},
  [10048] = {.lex_state = 117, .external_lex_state = 10},
  [10049] = {.lex_state = 117, .external_lex_state = 20},
  [10050] = {.lex_state = 117, .external_lex_state = 2},
  [10051] = {.lex_state = 117, .external_lex_state = 20},
  [10052] = {.lex_state = 117, .external_lex_state = 20},
  [10053] = {.lex_state = 117, .external_lex_state = 20},
  [10054] = {.lex_state = 9, .external_lex_state = 2},
  [10055] = {.lex_state = 117, .external_lex_state = 10},
  [10056] = {.lex_state = 117, .external_lex_state = 20},
  [10057] = {.lex_state = 117, .external_lex_state = 20},
  [10058] = {.lex_state = 117, .external_lex_state = 20},
  [10059] = {.lex_state = 117, .external_lex_state = 27},
  [10060] = {.lex_state = 117, .external_lex_state = 10},
  [10061] = {.lex_state = 117, .external_lex_state = 27},
  [10062] = {.lex_state = 117, .external_lex_state = 2},
  [10063] = {.lex_state = 117, .external_lex_state = 2},
  [10064] = {.lex_state = 117, .external_lex_state = 20},
  [10065] = {.lex_state = 117, .external_lex_state = 20},
  [10066] = {.lex_state = 117, .external_lex_state = 10},
  [10067] = {.lex_state = 117, .external_lex_state = 10},
  [10068] = {.lex_state = 117, .external_lex_state = 20},
  [10069] = {.lex_state = 9, .external_lex_state = 2},
  [10070] = {.lex_state = 117, .external_lex_state = 10},
  [10071] = {.lex_state = 117, .external_lex_state = 10},
  [10072] = {.lex_state = 9, .external_lex_state = 2},
  [10073] = {.lex_state = 9, .external_lex_state = 2},
  [10074] = {.lex_state = 117, .external_lex_state = 2},
  [10075] = {.lex_state = 117, .external_lex_state = 20},
  [10076] = {.lex_state = 9, .external_lex_state = 2},
  [10077] = {.lex_state = 117, .external_lex_state = 20},
  [10078] = {.lex_state = 117, .external_lex_state = 20},
  [10079] = {.lex_state = 117, .external_lex_state = 20},
  [10080] = {.lex_state = 9, .external_lex_state = 2},
  [10081] = {.lex_state = 9, .external_lex_state = 2},
  [10082] = {.lex_state = 117, .external_lex_state = 10},
  [10083] = {.lex_state = 117, .external_lex_state = 20},
  [10084] = {.lex_state = 117, .external_lex_state = 27},
  [10085] = {.lex_state = 117, .external_lex_state = 20},
  [10086] = {.lex_state = 117, .external_lex_state = 27},
  [10087] = {.lex_state = 117, .external_lex_state = 20},
  [10088] = {.lex_state = 117, .external_lex_state = 27},
  [10089] = {.lex_state = 117, .external_lex_state = 2},
  [10090] = {.lex_state = 117, .external_lex_state = 20},
  [10091] = {.lex_state = 9, .external_lex_state = 2},
  [10092] = {.lex_state = 117, .external_lex_state = 10},
  [10093] = {.lex_state = 117, .external_lex_state = 10},
  [10094] = {.lex_state = 117, .external_lex_state = 2},
  [10095] = {.lex_state = 117, .external_lex_state = 2},
  [10096] = {.lex_state = 117, .external_lex_state = 2},
  [10097] = {.lex_state = 117, .external_lex_state = 2},
  [10098] = {.lex_state = 117, .external_lex_state = 2},
  [10099] = {.lex_state = 117, .external_lex_state = 2},
  [10100] = {.lex_state = 117, .external_lex_state = 10},
  [10101] = {.lex_state = 117, .external_lex_state = 2},
  [10102] = {.lex_state = 117, .external_lex_state = 22},
  [10103] = {.lex_state = 117, .external_lex_state = 22},
  [10104] = {.lex_state = 117, .external_lex_state = 2},
  [10105] = {.lex_state = 117, .external_lex_state = 2},
  [10106] = {.lex_state = 117, .external_lex_state = 2},
  [10107] = {.lex_state = 117, .external_lex_state = 2},
  [10108] = {.lex_state = 117, .external_lex_state = 2},
  [10109] = {.lex_state = 117, .external_lex_state = 2},
  [10110] = {.lex_state = 117, .external_lex_state = 2},
  [10111] = {.lex_state = 117, .external_lex_state = 22},
  [10112] = {.lex_state = 117, .external_lex_state = 2},
  [10113] = {.lex_state = 117, .external_lex_state = 2},
  [10114] = {.lex_state = 117, .external_lex_state = 22},
  [10115] = {.lex_state = 117, .external_lex_state = 22},
  [10116] = {.lex_state = 117, .external_lex_state = 2},
  [10117] = {.lex_state = 117, .external_lex_state = 2},
  [10118] = {.lex_state = 117, .external_lex_state = 2},
  [10119] = {.lex_state = 117, .external_lex_state = 10},
  [10120] = {.lex_state = 117, .external_lex_state = 22},
  [10121] = {.lex_state = 117, .external_lex_state = 2},
  [10122] = {.lex_state = 117, .external_lex_state = 2},
  [10123] = {.lex_state = 117, .external_lex_state = 2},
  [10124] = {.lex_state = 117, .external_lex_state = 2},
  [10125] = {.lex_state = 117, .external_lex_state = 2},
  [10126] = {.lex_state = 117, .external_lex_state = 10},
  [10127] = {.lex_state = 117, .external_lex_state = 2},
  [10128] = {.lex_state = 117, .external_lex_state = 2},
  [10129] = {.lex_state = 117, .external_lex_state = 2},
  [10130] = {.lex_state = 117, .external_lex_state = 10},
  [10131] = {.lex_state = 117, .external_lex_state = 22},
  [10132] = {.lex_state = 117, .external_lex_state = 22},
  [10133] = {.lex_state = 117, .external_lex_state = 2},
  [10134] = {.lex_state = 117, .external_lex_state = 2},
  [10135] = {.lex_state = 117, .external_lex_state = 10},
  [10136] = {.lex_state = 117, .external_lex_state = 22},
  [10137] = {.lex_state = 117, .external_lex_state = 22},
  [10138] = {.lex_state = 117, .external_lex_state = 22},
  [10139] = {.lex_state = 117, .external_lex_state = 2},
  [10140] = {.lex_state = 117, .external_lex_state = 10},
  [10141] = {.lex_state = 117, .external_lex_state = 2},
  [10142] = {.lex_state = 117, .external_lex_state = 2},
  [10143] = {.lex_state = 117, .external_lex_state = 2},
  [10144] = {.lex_state = 117, .external_lex_state = 2},
  [10145] = {.lex_state = 117, .external_lex_state = 2},
  [10146] = {.lex_state = 117, .external_lex_state = 10},
  [10147] = {.lex_state = 117, .external_lex_state = 2},
  [10148] = {.lex_state = 117, .external_lex_state = 22},
  [10149] = {.lex_state = 117, .external_lex_state = 22},
  [10150] = {.lex_state = 117, .external_lex_state = 2},
  [10151] = {.lex_state = 117, .external_lex_state = 22},
  [10152] = {.lex_state = 117, .external_lex_state = 22},
  [10153] = {.lex_state = 117, .external_lex_state = 2},
  [10154] = {.lex_state = 117, .external_lex_state = 2},
  [10155] = {.lex_state = 117, .external_lex_state = 2},
  [10156] = {.lex_state = 117, .external_lex_state = 22},
  [10157] = {.lex_state = 117, .external_lex_state = 22},
  [10158] = {.lex_state = 117, .external_lex_state = 10},
  [10159] = {.lex_state = 117, .external_lex_state = 10},
  [10160] = {.lex_state = 117, .external_lex_state = 10},
  [10161] = {.lex_state = 117, .external_lex_state = 22},
  [10162] = {.lex_state = 117, .external_lex_state = 2},
  [10163] = {.lex_state = 117, .external_lex_state = 22},
  [10164] = {.lex_state = 117, .external_lex_state = 10},
  [10165] = {.lex_state = 117, .external_lex_state = 2},
  [10166] = {.lex_state = 117, .external_lex_state = 10},
  [10167] = {.lex_state = 117, .external_lex_state = 2},
  [10168] = {.lex_state = 117, .external_lex_state = 2},
  [10169] = {.lex_state = 117, .external_lex_state = 2},
  [10170] = {.lex_state = 117, .external_lex_state = 2},
  [10171] = {.lex_state = 117, .external_lex_state = 2},
  [10172] = {.lex_state = 117, .external_lex_state = 2},
  [10173] = {.lex_state = 117, .external_lex_state = 2},
  [10174] = {.lex_state = 117, .external_lex_state = 2},
  [10175] = {.lex_state = 117, .external_lex_state = 2},
  [10176] = {.lex_state = 117, .external_lex_state = 22},
  [10177] = {.lex_state = 117, .external_lex_state = 10},
  [10178] = {.lex_state = 117, .external_lex_state = 2},
  [10179] = {.lex_state = 117, .external_lex_state = 22},
  [10180] = {.lex_state = 117, .external_lex_state = 10},
  [10181] = {.lex_state = 117, .external_lex_state = 10},
  [10182] = {.lex_state = 117, .external_lex_state = 22},
  [10183] = {.lex_state = 117, .external_lex_state = 22},
  [10184] = {.lex_state = 117, .external_lex_state = 10},
  [10185] = {.lex_state = 117, .external_lex_state = 2},
  [10186] = {.lex_state = 117, .external_lex_state = 22},
  [10187] = {.lex_state = 117, .external_lex_state = 10},
  [10188] = {.lex_state = 117, .external_lex_state = 10},
  [10189] = {.lex_state = 117, .external_lex_state = 10},
  [10190] = {.lex_state = 117, .external_lex_state = 10},
  [10191] = {.lex_state = 117, .external_lex_state = 10},
  [10192] = {.lex_state = 117, .external_lex_state = 10},
  [10193] = {.lex_state = 117, .external_lex_state = 10},
  [10194] = {.lex_state = 117, .external_lex_state = 10},
  [10195] = {.lex_state = 117, .external_lex_state = 10},
  [10196] = {.lex_state = 117, .external_lex_state = 22},
  [10197] = {.lex_state = 117, .external_lex_state = 10},
  [10198] = {.lex_state = 117, .external_lex_state = 10},
  [10199] = {.lex_state = 117, .external_lex_state = 10},
  [10200] = {.lex_state = 117, .external_lex_state = 2},
  [10201] = {.lex_state = 117, .external_lex_state = 2},
  [10202] = {.lex_state = 117, .external_lex_state = 2},
  [10203] = {.lex_state = 117, .external_lex_state = 10},
  [10204] = {.lex_state = 117, .external_lex_state = 10},
  [10205] = {.lex_state = 117, .external_lex_state = 22},
  [10206] = {.lex_state = 117, .external_lex_state = 2},
  [10207] = {.lex_state = 117, .external_lex_state = 10},
  [10208] = {.lex_state = 117, .external_lex_state = 2},
  [10209] = {.lex_state = 117, .external_lex_state = 2},
  [10210] = {.lex_state = 117, .external_lex_state = 10},
  [10211] = {.lex_state = 117, .external_lex_state = 10},
  [10212] = {.lex_state = 117, .external_lex_state = 22},
  [10213] = {.lex_state = 117, .external_lex_state = 22},
  [10214] = {.lex_state = 117, .external_lex_state = 10},
  [10215] = {.lex_state = 117, .external_lex_state = 10},
  [10216] = {.lex_state = 117, .external_lex_state = 10},
  [10217] = {.lex_state = 117, .external_lex_state = 2},
  [10218] = {.lex_state = 117, .external_lex_state = 22},
  [10219] = {.lex_state = 117, .external_lex_state = 22},
  [10220] = {.lex_state = 117, .external_lex_state = 22},
  [10221] = {.lex_state = 117, .external_lex_state = 22},
  [10222] = {.lex_state = 117, .external_lex_state = 10},
  [10223] = {.lex_state = 117, .external_lex_state = 10},
  [10224] = {.lex_state = 117, .external_lex_state = 10},
  [10225] = {.lex_state = 117, .external_lex_state = 10},
  [10226] = {.lex_state = 117, .external_lex_state = 10},
  [10227] = {.lex_state = 117, .external_lex_state = 22},
  [10228] = {.lex_state = 117, .external_lex_state = 10},
  [10229] = {.lex_state = 117, .external_lex_state = 10},
  [10230] = {.lex_state = 117, .external_lex_state = 22},
  [10231] = {.lex_state = 117, .external_lex_state = 10},
  [10232] = {.lex_state = 117, .external_lex_state = 2},
  [10233] = {.lex_state = 117, .external_lex_state = 10},
  [10234] = {.lex_state = 117, .external_lex_state = 22},
  [10235] = {.lex_state = 117, .external_lex_state = 22},
  [10236] = {.lex_state = 117, .external_lex_state = 22},
  [10237] = {.lex_state = 117, .external_lex_state = 22},
  [10238] = {.lex_state = 117, .external_lex_state = 2},
  [10239] = {.lex_state = 117, .external_lex_state = 10},
  [10240] = {.lex_state = 117, .external_lex_state = 2},
  [10241] = {.lex_state = 117, .external_lex_state = 22},
  [10242] = {.lex_state = 117, .external_lex_state = 2},
  [10243] = {.lex_state = 117, .external_lex_state = 22},
  [10244] = {.lex_state = 117, .external_lex_state = 2},
  [10245] = {.lex_state = 117, .external_lex_state = 10},
  [10246] = {.lex_state = 117, .external_lex_state = 22},
  [10247] = {.lex_state = 117, .external_lex_state = 2},
  [10248] = {.lex_state = 117, .external_lex_state = 2},
  [10249] = {.lex_state = 117, .external_lex_state = 2},
  [10250] = {.lex_state = 117, .external_lex_state = 2},
  [10251] = {.lex_state = 117, .external_lex_state = 2},
  [10252] = {.lex_state = 117, .external_lex_state = 10},
  [10253] = {.lex_state = 117, .external_lex_state = 2},
  [10254] = {.lex_state = 117, .external_lex_state = 2},
  [10255] = {.lex_state = 117, .external_lex_state = 2},
  [10256] = {.lex_state = 117, .external_lex_state = 10},
  [10257] = {.lex_state = 117, .external_lex_state = 10},
  [10258] = {.lex_state = 117, .external_lex_state = 10},
  [10259] = {.lex_state = 117, .external_lex_state = 2},
  [10260] = {.lex_state = 117, .external_lex_state = 10},
  [10261] = {.lex_state = 117, .external_lex_state = 2},
  [10262] = {.lex_state = 117, .external_lex_state = 2},
  [10263] = {.lex_state = 117, .external_lex_state = 10},
  [10264] = {.lex_state = 117, .external_lex_state = 2},
  [10265] = {.lex_state = 117, .external_lex_state = 22},
  [10266] = {.lex_state = 117, .external_lex_state = 2},
  [10267] = {.lex_state = 117, .external_lex_state = 2},
  [10268] = {.lex_state = 117, .external_lex_state = 2},
  [10269] = {.lex_state = 117, .external_lex_state = 2},
  [10270] = {.lex_state = 117, .external_lex_state = 2},
  [10271] = {.lex_state = 117, .external_lex_state = 2},
  [10272] = {.lex_state = 117, .external_lex_state = 2},
  [10273] = {.lex_state = 117, .external_lex_state = 10},
  [10274] = {.lex_state = 117, .external_lex_state = 10},
  [10275] = {.lex_state = 117, .external_lex_state = 2},
  [10276] = {.lex_state = 117, .external_lex_state = 2},
  [10277] = {.lex_state = 117, .external_lex_state = 22},
  [10278] = {.lex_state = 117, .external_lex_state = 10},
  [10279] = {.lex_state = 117, .external_lex_state = 2},
  [10280] = {.lex_state = 117, .external_lex_state = 2},
  [10281] = {.lex_state = 117, .external_lex_state = 10},
  [10282] = {.lex_state = 117, .external_lex_state = 10},
  [10283] = {.lex_state = 117, .external_lex_state = 2},
  [10284] = {.lex_state = 117, .external_lex_state = 10},
  [10285] = {.lex_state = 117, .external_lex_state = 2},
  [10286] = {.lex_state = 117, .external_lex_state = 2},
  [10287] = {.lex_state = 117, .external_lex_state = 2},
  [10288] = {.lex_state = 117, .external_lex_state = 2},
  [10289] = {.lex_state = 117, .external_lex_state = 2},
  [10290] = {.lex_state = 117, .external_lex_state = 10},
  [10291] = {.lex_state = 117, .external_lex_state = 10},
  [10292] = {.lex_state = 117, .external_lex_state = 2},
  [10293] = {.lex_state = 117, .external_lex_state = 2},
  [10294] = {.lex_state = 117, .external_lex_state = 10},
  [10295] = {.lex_state = 117, .external_lex_state = 10},
  [10296] = {.lex_state = 117, .external_lex_state = 2},
  [10297] = {.lex_state = 117, .external_lex_state = 22},
  [10298] = {.lex_state = 117, .external_lex_state = 15},
  [10299] = {.lex_state = 9},
  [10300] = {.lex_state = 117, .external_lex_state = 15},
  [10301] = {.lex_state = 117, .external_lex_state = 15},
  [10302] = {.lex_state = 117, .external_lex_state = 10},
  [10303] = {.lex_state = 117, .external_lex_state = 15},
  [10304] = {.lex_state = 117, .external_lex_state = 15},
  [10305] = {.lex_state = 117, .external_lex_state = 15},
  [10306] = {.lex_state = 117, .external_lex_state = 15},
  [10307] = {.lex_state = 117, .external_lex_state = 15},
  [10308] = {.lex_state = 117, .external_lex_state = 15},
  [10309] = {.lex_state = 117, .external_lex_state = 15},
  [10310] = {.lex_state = 117, .external_lex_state = 15},
  [10311] = {.lex_state = 117, .external_lex_state = 15},
  [10312] = {.lex_state = 117, .external_lex_state = 15},
  [10313] = {.lex_state = 117, .external_lex_state = 15},
  [10314] = {.lex_state = 117, .external_lex_state = 15},
  [10315] = {.lex_state = 117, .external_lex_state = 15},
  [10316] = {.lex_state = 117, .external_lex_state = 15},
  [10317] = {.lex_state = 117, .external_lex_state = 15},
  [10318] = {.lex_state = 117, .external_lex_state = 15},
  [10319] = {.lex_state = 117, .external_lex_state = 15},
  [10320] = {.lex_state = 117, .external_lex_state = 15},
  [10321] = {.lex_state = 117, .external_lex_state = 15},
  [10322] = {.lex_state = 0, .external_lex_state = 22},
  [10323] = {.lex_state = 117, .external_lex_state = 15},
  [10324] = {.lex_state = 117, .external_lex_state = 15},
  [10325] = {.lex_state = 117, .external_lex_state = 10},
  [10326] = {.lex_state = 117, .external_lex_state = 15},
  [10327] = {.lex_state = 117, .external_lex_state = 15},
  [10328] = {.lex_state = 117, .external_lex_state = 15},
  [10329] = {.lex_state = 117, .external_lex_state = 15},
  [10330] = {.lex_state = 117, .external_lex_state = 15},
  [10331] = {.lex_state = 117, .external_lex_state = 15},
  [10332] = {.lex_state = 0, .external_lex_state = 22},
  [10333] = {.lex_state = 117, .external_lex_state = 15},
  [10334] = {.lex_state = 0, .external_lex_state = 22},
  [10335] = {.lex_state = 117, .external_lex_state = 22},
  [10336] = {.lex_state = 117, .external_lex_state = 22},
  [10337] = {.lex_state = 117, .external_lex_state = 10},
  [10338] = {.lex_state = 0, .external_lex_state = 22},
  [10339] = {.lex_state = 117, .external_lex_state = 15},
  [10340] = {.lex_state = 117},
  [10341] = {.lex_state = 10, .external_lex_state = 22},
  [10342] = {.lex_state = 10, .external_lex_state = 22},
  [10343] = {.lex_state = 10, .external_lex_state = 22},
  [10344] = {.lex_state = 117},
  [10345] = {.lex_state = 117},
  [10346] = {.lex_state = 0, .external_lex_state = 22},
  [10347] = {.lex_state = 0, .external_lex_state = 22},
  [10348] = {.lex_state = 117},
  [10349] = {.lex_state = 117, .external_lex_state = 10},
  [10350] = {.lex_state = 0, .external_lex_state = 22},
  [10351] = {.lex_state = 117, .external_lex_state = 15},
  [10352] = {.lex_state = 0, .external_lex_state = 22},
  [10353] = {.lex_state = 117, .external_lex_state = 15},
  [10354] = {.lex_state = 117},
  [10355] = {.lex_state = 117, .external_lex_state = 15},
  [10356] = {.lex_state = 0, .external_lex_state = 22},
  [10357] = {.lex_state = 0, .external_lex_state = 22},
  [10358] = {.lex_state = 0, .external_lex_state = 22},
  [10359] = {.lex_state = 117, .external_lex_state = 15},
  [10360] = {.lex_state = 117, .external_lex_state = 15},
  [10361] = {.lex_state = 117, .external_lex_state = 15},
  [10362] = {.lex_state = 117, .external_lex_state = 15},
  [10363] = {.lex_state = 117, .external_lex_state = 15},
  [10364] = {.lex_state = 117, .external_lex_state = 15},
  [10365] = {.lex_state = 117, .external_lex_state = 15},
  [10366] = {.lex_state = 117, .external_lex_state = 15},
  [10367] = {.lex_state = 117, .external_lex_state = 15},
  [10368] = {.lex_state = 117},
  [10369] = {.lex_state = 0, .external_lex_state = 22},
  [10370] = {.lex_state = 117},
  [10371] = {.lex_state = 117, .external_lex_state = 22},
  [10372] = {.lex_state = 117},
  [10373] = {.lex_state = 117, .external_lex_state = 15},
  [10374] = {.lex_state = 117, .external_lex_state = 15},
  [10375] = {.lex_state = 117, .external_lex_state = 15},
  [10376] = {.lex_state = 117, .external_lex_state = 15},
  [10377] = {.lex_state = 117, .external_lex_state = 15},
  [10378] = {.lex_state = 117, .external_lex_state = 15},
  [10379] = {.lex_state = 117, .external_lex_state = 15},
  [10380] = {.lex_state = 117, .external_lex_state = 15},
  [10381] = {.lex_state = 117},
  [10382] = {.lex_state = 117, .external_lex_state = 15},
  [10383] = {.lex_state = 117},
  [10384] = {.lex_state = 117, .external_lex_state = 15},
  [10385] = {.lex_state = 117},
  [10386] = {.lex_state = 117, .external_lex_state = 15},
  [10387] = {.lex_state = 0, .external_lex_state = 22},
  [10388] = {.lex_state = 117, .external_lex_state = 15},
  [10389] = {.lex_state = 0, .external_lex_state = 22},
  [10390] = {.lex_state = 117, .external_lex_state = 15},
  [10391] = {.lex_state = 117, .external_lex_state = 15},
  [10392] = {.lex_state = 117, .external_lex_state = 15},
  [10393] = {.lex_state = 117, .external_lex_state = 15},
  [10394] = {.lex_state = 117, .external_lex_state = 15},
  [10395] = {.lex_state = 117, .external_lex_state = 15},
  [10396] = {.lex_state = 117, .external_lex_state = 15},
  [10397] = {.lex_state = 117, .external_lex_state = 15},
  [10398] = {.lex_state = 117, .external_lex_state = 10},
  [10399] = {.lex_state = 117, .external_lex_state = 15},
  [10400] = {.lex_state = 117, .external_lex_state = 15},
  [10401] = {.lex_state = 117},
  [10402] = {.lex_state = 117, .external_lex_state = 15},
  [10403] = {.lex_state = 117, .external_lex_state = 15},
  [10404] = {.lex_state = 117, .external_lex_state = 15},
  [10405] = {.lex_state = 117, .external_lex_state = 15},
  [10406] = {.lex_state = 117},
  [10407] = {.lex_state = 117},
  [10408] = {.lex_state = 117},
  [10409] = {.lex_state = 117},
  [10410] = {.lex_state = 117},
  [10411] = {.lex_state = 117, .external_lex_state = 15},
  [10412] = {.lex_state = 117},
  [10413] = {.lex_state = 117},
  [10414] = {.lex_state = 117},
  [10415] = {.lex_state = 117, .external_lex_state = 15},
  [10416] = {.lex_state = 117, .external_lex_state = 15},
  [10417] = {.lex_state = 117, .external_lex_state = 15},
  [10418] = {.lex_state = 0, .external_lex_state = 22},
  [10419] = {.lex_state = 117, .external_lex_state = 15},
  [10420] = {.lex_state = 117},
  [10421] = {.lex_state = 0, .external_lex_state = 22},
  [10422] = {.lex_state = 117, .external_lex_state = 15},
  [10423] = {.lex_state = 117, .external_lex_state = 15},
  [10424] = {.lex_state = 117},
  [10425] = {.lex_state = 117, .external_lex_state = 15},
  [10426] = {.lex_state = 117},
  [10427] = {.lex_state = 117},
  [10428] = {.lex_state = 117, .external_lex_state = 15},
  [10429] = {.lex_state = 117},
  [10430] = {.lex_state = 0, .external_lex_state = 22},
  [10431] = {.lex_state = 117, .external_lex_state = 22},
  [10432] = {.lex_state = 0, .external_lex_state = 22},
  [10433] = {.lex_state = 6, .external_lex_state = 22},
  [10434] = {.lex_state = 117, .external_lex_state = 15},
  [10435] = {.lex_state = 117, .external_lex_state = 15},
  [10436] = {.lex_state = 117, .external_lex_state = 15},
  [10437] = {.lex_state = 117},
  [10438] = {.lex_state = 117},
  [10439] = {.lex_state = 0, .external_lex_state = 22},
  [10440] = {.lex_state = 117, .external_lex_state = 15},
  [10441] = {.lex_state = 117, .external_lex_state = 15},
  [10442] = {.lex_state = 117, .external_lex_state = 15},
  [10443] = {.lex_state = 117, .external_lex_state = 15},
  [10444] = {.lex_state = 117, .external_lex_state = 15},
  [10445] = {.lex_state = 117, .external_lex_state = 22},
  [10446] = {.lex_state = 117, .external_lex_state = 15},
  [10447] = {.lex_state = 0, .external_lex_state = 22},
  [10448] = {.lex_state = 0, .external_lex_state = 22},
  [10449] = {.lex_state = 0, .external_lex_state = 22},
  [10450] = {.lex_state = 117, .external_lex_state = 15},
  [10451] = {.lex_state = 117, .external_lex_state = 15},
  [10452] = {.lex_state = 117, .external_lex_state = 15},
  [10453] = {.lex_state = 117, .external_lex_state = 15},
  [10454] = {.lex_state = 117, .external_lex_state = 15},
  [10455] = {.lex_state = 117, .external_lex_state = 15},
  [10456] = {.lex_state = 117, .external_lex_state = 15},
  [10457] = {.lex_state = 117, .external_lex_state = 15},
  [10458] = {.lex_state = 117, .external_lex_state = 22},
  [10459] = {.lex_state = 117, .external_lex_state = 15},
  [10460] = {.lex_state = 117, .external_lex_state = 15},
  [10461] = {.lex_state = 117, .external_lex_state = 15},
  [10462] = {.lex_state = 0, .external_lex_state = 22},
  [10463] = {.lex_state = 0, .external_lex_state = 22},
  [10464] = {.lex_state = 117, .external_lex_state = 10},
  [10465] = {.lex_state = 117, .external_lex_state = 15},
  [10466] = {.lex_state = 117, .external_lex_state = 15},
  [10467] = {.lex_state = 117, .external_lex_state = 15},
  [10468] = {.lex_state = 117, .external_lex_state = 15},
  [10469] = {.lex_state = 117, .external_lex_state = 22},
  [10470] = {.lex_state = 117},
  [10471] = {.lex_state = 117, .external_lex_state = 15},
  [10472] = {.lex_state = 0, .external_lex_state = 22},
  [10473] = {.lex_state = 0, .external_lex_state = 22},
  [10474] = {.lex_state = 117, .external_lex_state = 22},
  [10475] = {.lex_state = 117, .external_lex_state = 15},
  [10476] = {.lex_state = 117},
  [10477] = {.lex_state = 117, .external_lex_state = 15},
  [10478] = {.lex_state = 0, .external_lex_state = 22},
  [10479] = {.lex_state = 117, .external_lex_state = 15},
  [10480] = {.lex_state = 117},
  [10481] = {.lex_state = 117},
  [10482] = {.lex_state = 117, .external_lex_state = 15},
  [10483] = {.lex_state = 117, .external_lex_state = 15},
  [10484] = {.lex_state = 117, .external_lex_state = 15},
  [10485] = {.lex_state = 117},
  [10486] = {.lex_state = 10, .external_lex_state = 22},
  [10487] = {.lex_state = 117, .external_lex_state = 22},
  [10488] = {.lex_state = 117, .external_lex_state = 15},
  [10489] = {.lex_state = 117, .external_lex_state = 15},
  [10490] = {.lex_state = 117, .external_lex_state = 15},
  [10491] = {.lex_state = 117, .external_lex_state = 15},
  [10492] = {.lex_state = 117},
  [10493] = {.lex_state = 117, .external_lex_state = 15},
  [10494] = {.lex_state = 117, .external_lex_state = 15},
  [10495] = {.lex_state = 117, .external_lex_state = 15},
  [10496] = {.lex_state = 117, .external_lex_state = 15},
  [10497] = {.lex_state = 117, .external_lex_state = 15},
  [10498] = {.lex_state = 117, .external_lex_state = 15},
  [10499] = {.lex_state = 117, .external_lex_state = 15},
  [10500] = {.lex_state = 117, .external_lex_state = 15},
  [10501] = {.lex_state = 117, .external_lex_state = 15},
  [10502] = {.lex_state = 117},
  [10503] = {.lex_state = 117, .external_lex_state = 15},
  [10504] = {.lex_state = 117, .external_lex_state = 15},
  [10505] = {.lex_state = 117, .external_lex_state = 15},
  [10506] = {.lex_state = 117, .external_lex_state = 15},
  [10507] = {.lex_state = 117, .external_lex_state = 15},
  [10508] = {.lex_state = 117, .external_lex_state = 15},
  [10509] = {.lex_state = 117, .external_lex_state = 15},
  [10510] = {.lex_state = 117, .external_lex_state = 22},
  [10511] = {.lex_state = 117, .external_lex_state = 22},
  [10512] = {.lex_state = 117, .external_lex_state = 15},
  [10513] = {.lex_state = 117, .external_lex_state = 15},
  [10514] = {.lex_state = 117, .external_lex_state = 15},
  [10515] = {.lex_state = 0, .external_lex_state = 22},
  [10516] = {.lex_state = 117, .external_lex_state = 22},
  [10517] = {.lex_state = 117, .external_lex_state = 15},
  [10518] = {.lex_state = 117, .external_lex_state = 15},
  [10519] = {.lex_state = 117, .external_lex_state = 15},
  [10520] = {.lex_state = 117, .external_lex_state = 15},
  [10521] = {.lex_state = 117, .external_lex_state = 22},
  [10522] = {.lex_state = 117, .external_lex_state = 22},
  [10523] = {.lex_state = 117, .external_lex_state = 15},
  [10524] = {.lex_state = 117},
  [10525] = {.lex_state = 117, .external_lex_state = 15},
  [10526] = {.lex_state = 117, .external_lex_state = 15},
  [10527] = {.lex_state = 117, .external_lex_state = 15},
  [10528] = {.lex_state = 117, .external_lex_state = 22},
  [10529] = {.lex_state = 117, .external_lex_state = 22},
  [10530] = {.lex_state = 117, .external_lex_state = 15},
  [10531] = {.lex_state = 117, .external_lex_state = 22},
  [10532] = {.lex_state = 117, .external_lex_state = 15},
  [10533] = {.lex_state = 117, .external_lex_state = 15},
  [10534] = {.lex_state = 117, .external_lex_state = 15},
  [10535] = {.lex_state = 0, .external_lex_state = 22},
  [10536] = {.lex_state = 117, .external_lex_state = 15},
  [10537] = {.lex_state = 117, .external_lex_state = 15},
  [10538] = {.lex_state = 117, .external_lex_state = 15},
  [10539] = {.lex_state = 0, .external_lex_state = 22},
  [10540] = {.lex_state = 117, .external_lex_state = 22},
  [10541] = {.lex_state = 117, .external_lex_state = 22},
  [10542] = {.lex_state = 0, .external_lex_state = 22},
  [10543] = {.lex_state = 117, .external_lex_state = 15},
  [10544] = {.lex_state = 0, .external_lex_state = 22},
  [10545] = {.lex_state = 117, .external_lex_state = 22},
  [10546] = {.lex_state = 117, .external_lex_state = 22},
  [10547] = {.lex_state = 117, .external_lex_state = 15},
  [10548] = {.lex_state = 117, .external_lex_state = 15},
  [10549] = {.lex_state = 117, .external_lex_state = 15},
  [10550] = {.lex_state = 0, .external_lex_state = 22},
  [10551] = {.lex_state = 117, .external_lex_state = 22},
  [10552] = {.lex_state = 117, .external_lex_state = 22},
  [10553] = {.lex_state = 117, .external_lex_state = 22},
  [10554] = {.lex_state = 117, .external_lex_state = 15},
  [10555] = {.lex_state = 117, .external_lex_state = 22},
  [10556] = {.lex_state = 117},
  [10557] = {.lex_state = 117, .external_lex_state = 15},
  [10558] = {.lex_state = 117, .external_lex_state = 15},
  [10559] = {.lex_state = 117, .external_lex_state = 15},
  [10560] = {.lex_state = 117, .external_lex_state = 15},
  [10561] = {.lex_state = 117, .external_lex_state = 15},
  [10562] = {.lex_state = 0, .external_lex_state = 22},
  [10563] = {.lex_state = 117, .external_lex_state = 15},
  [10564] = {.lex_state = 117, .external_lex_state = 15},
  [10565] = {.lex_state = 117, .external_lex_state = 15},
  [10566] = {.lex_state = 117, .external_lex_state = 15},
  [10567] = {.lex_state = 117, .external_lex_state = 15},
  [10568] = {.lex_state = 117, .external_lex_state = 15},
  [10569] = {.lex_state = 117, .external_lex_state = 15},
  [10570] = {.lex_state = 117, .external_lex_state = 15},
  [10571] = {.lex_state = 117, .external_lex_state = 15},
  [10572] = {.lex_state = 117, .external_lex_state = 15},
  [10573] = {.lex_state = 117, .external_lex_state = 15},
  [10574] = {.lex_state = 117, .external_lex_state = 15},
  [10575] = {.lex_state = 117, .external_lex_state = 15},
  [10576] = {.lex_state = 117, .external_lex_state = 15},
  [10577] = {.lex_state = 117, .external_lex_state = 15},
  [10578] = {.lex_state = 117, .external_lex_state = 15},
  [10579] = {.lex_state = 117, .external_lex_state = 15},
  [10580] = {.lex_state = 117, .external_lex_state = 15},
  [10581] = {.lex_state = 117, .external_lex_state = 15},
  [10582] = {.lex_state = 117, .external_lex_state = 15},
  [10583] = {.lex_state = 117, .external_lex_state = 15},
  [10584] = {.lex_state = 117, .external_lex_state = 15},
  [10585] = {.lex_state = 117},
  [10586] = {.lex_state = 117},
  [10587] = {.lex_state = 117},
  [10588] = {.lex_state = 117},
  [10589] = {.lex_state = 117, .external_lex_state = 15},
  [10590] = {.lex_state = 117, .external_lex_state = 15},
  [10591] = {.lex_state = 117, .external_lex_state = 15},
  [10592] = {.lex_state = 117, .external_lex_state = 15},
  [10593] = {.lex_state = 0, .external_lex_state = 22},
  [10594] = {.lex_state = 0, .external_lex_state = 22},
  [10595] = {.lex_state = 0, .external_lex_state = 22},
  [10596] = {.lex_state = 117, .external_lex_state = 15},
  [10597] = {.lex_state = 117, .external_lex_state = 15},
  [10598] = {.lex_state = 117, .external_lex_state = 15},
  [10599] = {.lex_state = 117, .external_lex_state = 15},
  [10600] = {.lex_state = 0, .external_lex_state = 22},
  [10601] = {.lex_state = 117},
  [10602] = {.lex_state = 117},
  [10603] = {.lex_state = 117, .external_lex_state = 15},
  [10604] = {.lex_state = 117},
  [10605] = {.lex_state = 0, .external_lex_state = 22},
  [10606] = {.lex_state = 117},
  [10607] = {.lex_state = 117, .external_lex_state = 15},
  [10608] = {.lex_state = 117, .external_lex_state = 15},
  [10609] = {.lex_state = 117, .external_lex_state = 15},
  [10610] = {.lex_state = 117, .external_lex_state = 15},
  [10611] = {.lex_state = 117, .external_lex_state = 15},
  [10612] = {.lex_state = 117, .external_lex_state = 15},
  [10613] = {.lex_state = 117, .external_lex_state = 15},
  [10614] = {.lex_state = 117, .external_lex_state = 15},
  [10615] = {.lex_state = 117, .external_lex_state = 15},
  [10616] = {.lex_state = 117, .external_lex_state = 15},
  [10617] = {.lex_state = 117, .external_lex_state = 15},
  [10618] = {.lex_state = 117, .external_lex_state = 22},
  [10619] = {.lex_state = 117, .external_lex_state = 15},
  [10620] = {.lex_state = 117, .external_lex_state = 15},
  [10621] = {.lex_state = 117, .external_lex_state = 15},
  [10622] = {.lex_state = 117, .external_lex_state = 15},
  [10623] = {.lex_state = 117, .external_lex_state = 10},
  [10624] = {.lex_state = 117, .external_lex_state = 15},
  [10625] = {.lex_state = 117, .external_lex_state = 15},
  [10626] = {.lex_state = 117, .external_lex_state = 15},
  [10627] = {.lex_state = 117, .external_lex_state = 15},
  [10628] = {.lex_state = 117, .external_lex_state = 15},
  [10629] = {.lex_state = 0, .external_lex_state = 22},
  [10630] = {.lex_state = 0, .external_lex_state = 22},
  [10631] = {.lex_state = 117},
  [10632] = {.lex_state = 0, .external_lex_state = 22},
  [10633] = {.lex_state = 117},
  [10634] = {.lex_state = 0, .external_lex_state = 22},
  [10635] = {.lex_state = 117},
  [10636] = {.lex_state = 117, .external_lex_state = 15},
  [10637] = {.lex_state = 117, .external_lex_state = 15},
  [10638] = {.lex_state = 117, .external_lex_state = 15},
  [10639] = {.lex_state = 0, .external_lex_state = 22},
  [10640] = {.lex_state = 0, .external_lex_state = 22},
  [10641] = {.lex_state = 117, .external_lex_state = 10},
  [10642] = {.lex_state = 117, .external_lex_state = 15},
  [10643] = {.lex_state = 117, .external_lex_state = 15},
  [10644] = {.lex_state = 117, .external_lex_state = 15},
  [10645] = {.lex_state = 117, .external_lex_state = 15},
  [10646] = {.lex_state = 117, .external_lex_state = 15},
  [10647] = {.lex_state = 117, .external_lex_state = 15},
  [10648] = {.lex_state = 117, .external_lex_state = 15},
  [10649] = {.lex_state = 117, .external_lex_state = 15},
  [10650] = {.lex_state = 0, .external_lex_state = 22},
  [10651] = {.lex_state = 0, .external_lex_state = 22},
  [10652] = {.lex_state = 0, .external_lex_state = 22},
  [10653] = {.lex_state = 0, .external_lex_state = 22},
  [10654] = {.lex_state = 0, .external_lex_state = 22},
  [10655] = {.lex_state = 0, .external_lex_state = 22},
  [10656] = {.lex_state = 0, .external_lex_state = 22},
  [10657] = {.lex_state = 0, .external_lex_state = 22},
  [10658] = {.lex_state = 0, .external_lex_state = 22},
  [10659] = {.lex_state = 0, .external_lex_state = 22},
  [10660] = {.lex_state = 0, .external_lex_state = 22},
  [10661] = {.lex_state = 0, .external_lex_state = 22},
  [10662] = {.lex_state = 0, .external_lex_state = 22},
  [10663] = {.lex_state = 0, .external_lex_state = 22},
  [10664] = {.lex_state = 0, .external_lex_state = 22},
  [10665] = {.lex_state = 0, .external_lex_state = 22},
  [10666] = {.lex_state = 0, .external_lex_state = 22},
  [10667] = {.lex_state = 0, .external_lex_state = 22},
  [10668] = {.lex_state = 0, .external_lex_state = 22},
  [10669] = {.lex_state = 0, .external_lex_state = 22},
  [10670] = {.lex_state = 0, .external_lex_state = 22},
  [10671] = {.lex_state = 0, .external_lex_state = 22},
  [10672] = {.lex_state = 0, .external_lex_state = 22},
  [10673] = {.lex_state = 0, .external_lex_state = 22},
  [10674] = {.lex_state = 0, .external_lex_state = 22},
  [10675] = {.lex_state = 0, .external_lex_state = 22},
  [10676] = {.lex_state = 0, .external_lex_state = 22},
  [10677] = {.lex_state = 0, .external_lex_state = 22},
  [10678] = {.lex_state = 0, .external_lex_state = 22},
  [10679] = {.lex_state = 0, .external_lex_state = 22},
  [10680] = {.lex_state = 0, .external_lex_state = 22},
  [10681] = {.lex_state = 0, .external_lex_state = 22},
  [10682] = {.lex_state = 0, .external_lex_state = 22},
  [10683] = {.lex_state = 0, .external_lex_state = 22},
  [10684] = {.lex_state = 0, .external_lex_state = 22},
  [10685] = {.lex_state = 0, .external_lex_state = 22},
  [10686] = {.lex_state = 0, .external_lex_state = 22},
  [10687] = {.lex_state = 0, .external_lex_state = 22},
  [10688] = {.lex_state = 0, .external_lex_state = 22},
  [10689] = {.lex_state = 0, .external_lex_state = 22},
  [10690] = {.lex_state = 0, .external_lex_state = 22},
  [10691] = {.lex_state = 0, .external_lex_state = 22},
  [10692] = {.lex_state = 0, .external_lex_state = 22},
  [10693] = {.lex_state = 0, .external_lex_state = 22},
  [10694] = {.lex_state = 0, .external_lex_state = 22},
  [10695] = {.lex_state = 0, .external_lex_state = 22},
  [10696] = {.lex_state = 0, .external_lex_state = 22},
  [10697] = {.lex_state = 0, .external_lex_state = 22},
  [10698] = {.lex_state = 0, .external_lex_state = 22},
  [10699] = {.lex_state = 0, .external_lex_state = 22},
  [10700] = {.lex_state = 0, .external_lex_state = 22},
  [10701] = {.lex_state = 0, .external_lex_state = 22},
  [10702] = {.lex_state = 0, .external_lex_state = 22},
  [10703] = {.lex_state = 0, .external_lex_state = 22},
  [10704] = {.lex_state = 0, .external_lex_state = 22},
  [10705] = {.lex_state = 0, .external_lex_state = 22},
  [10706] = {.lex_state = 0, .external_lex_state = 22},
  [10707] = {.lex_state = 0, .external_lex_state = 22},
  [10708] = {.lex_state = 0, .external_lex_state = 22},
  [10709] = {.lex_state = 0, .external_lex_state = 22},
  [10710] = {.lex_state = 0, .external_lex_state = 22},
  [10711] = {.lex_state = 0, .external_lex_state = 22},
  [10712] = {.lex_state = 0, .external_lex_state = 22},
  [10713] = {.lex_state = 0, .external_lex_state = 22},
  [10714] = {.lex_state = 0, .external_lex_state = 22},
  [10715] = {.lex_state = 0, .external_lex_state = 22},
  [10716] = {.lex_state = 0, .external_lex_state = 22},
  [10717] = {.lex_state = 0, .external_lex_state = 22},
  [10718] = {.lex_state = 0, .external_lex_state = 22},
  [10719] = {.lex_state = 0, .external_lex_state = 22},
  [10720] = {.lex_state = 0, .external_lex_state = 22},
  [10721] = {.lex_state = 0, .external_lex_state = 22},
  [10722] = {.lex_state = 0, .external_lex_state = 22},
  [10723] = {.lex_state = 0, .external_lex_state = 22},
  [10724] = {.lex_state = 0, .external_lex_state = 22},
  [10725] = {.lex_state = 0, .external_lex_state = 22},
  [10726] = {.lex_state = 0, .external_lex_state = 22},
  [10727] = {.lex_state = 0, .external_lex_state = 22},
  [10728] = {.lex_state = 0, .external_lex_state = 22},
  [10729] = {.lex_state = 0, .external_lex_state = 22},
  [10730] = {.lex_state = 0, .external_lex_state = 22},
  [10731] = {.lex_state = 0, .external_lex_state = 22},
  [10732] = {.lex_state = 0, .external_lex_state = 22},
  [10733] = {.lex_state = 0, .external_lex_state = 22},
  [10734] = {.lex_state = 0, .external_lex_state = 22},
  [10735] = {.lex_state = 0, .external_lex_state = 22},
  [10736] = {.lex_state = 0, .external_lex_state = 22},
  [10737] = {.lex_state = 0, .external_lex_state = 22},
  [10738] = {.lex_state = 0, .external_lex_state = 22},
  [10739] = {.lex_state = 0, .external_lex_state = 22},
  [10740] = {.lex_state = 0, .external_lex_state = 22},
  [10741] = {.lex_state = 0, .external_lex_state = 22},
  [10742] = {.lex_state = 0, .external_lex_state = 22},
  [10743] = {.lex_state = 0, .external_lex_state = 22},
  [10744] = {.lex_state = 0, .external_lex_state = 22},
  [10745] = {.lex_state = 0, .external_lex_state = 22},
  [10746] = {.lex_state = 0, .external_lex_state = 22},
  [10747] = {.lex_state = 0, .external_lex_state = 22},
  [10748] = {.lex_state = 0, .external_lex_state = 22},
  [10749] = {.lex_state = 0, .external_lex_state = 22},
  [10750] = {.lex_state = 0, .external_lex_state = 22},
  [10751] = {.lex_state = 0, .external_lex_state = 22},
  [10752] = {.lex_state = 0, .external_lex_state = 22},
  [10753] = {.lex_state = 0, .external_lex_state = 22},
  [10754] = {.lex_state = 0, .external_lex_state = 22},
  [10755] = {.lex_state = 0, .external_lex_state = 22},
  [10756] = {.lex_state = 0, .external_lex_state = 22},
  [10757] = {.lex_state = 0, .external_lex_state = 22},
  [10758] = {.lex_state = 0, .external_lex_state = 22},
  [10759] = {.lex_state = 0, .external_lex_state = 22},
  [10760] = {.lex_state = 0, .external_lex_state = 22},
  [10761] = {.lex_state = 0, .external_lex_state = 22},
  [10762] = {.lex_state = 0, .external_lex_state = 22},
  [10763] = {.lex_state = 0, .external_lex_state = 22},
  [10764] = {.lex_state = 0, .external_lex_state = 22},
  [10765] = {.lex_state = 0, .external_lex_state = 22},
  [10766] = {.lex_state = 0, .external_lex_state = 22},
  [10767] = {.lex_state = 0, .external_lex_state = 22},
  [10768] = {.lex_state = 0, .external_lex_state = 22},
  [10769] = {.lex_state = 0, .external_lex_state = 22},
  [10770] = {.lex_state = 0, .external_lex_state = 22},
  [10771] = {.lex_state = 0, .external_lex_state = 22},
  [10772] = {.lex_state = 0, .external_lex_state = 22},
  [10773] = {.lex_state = 0, .external_lex_state = 22},
  [10774] = {.lex_state = 0, .external_lex_state = 22},
  [10775] = {.lex_state = 0, .external_lex_state = 22},
  [10776] = {.lex_state = 0, .external_lex_state = 22},
  [10777] = {.lex_state = 0, .external_lex_state = 22},
  [10778] = {.lex_state = 0, .external_lex_state = 22},
  [10779] = {.lex_state = 0, .external_lex_state = 22},
  [10780] = {.lex_state = 0, .external_lex_state = 22},
  [10781] = {.lex_state = 0, .external_lex_state = 22},
  [10782] = {.lex_state = 0, .external_lex_state = 22},
  [10783] = {.lex_state = 0, .external_lex_state = 22},
  [10784] = {.lex_state = 0, .external_lex_state = 22},
  [10785] = {.lex_state = 0, .external_lex_state = 22},
  [10786] = {.lex_state = 0, .external_lex_state = 22},
  [10787] = {.lex_state = 0, .external_lex_state = 22},
  [10788] = {.lex_state = 0, .external_lex_state = 22},
  [10789] = {.lex_state = 0, .external_lex_state = 22},
  [10790] = {.lex_state = 0, .external_lex_state = 22},
  [10791] = {.lex_state = 0, .external_lex_state = 22},
  [10792] = {.lex_state = 0, .external_lex_state = 22},
  [10793] = {.lex_state = 0, .external_lex_state = 22},
  [10794] = {.lex_state = 0, .external_lex_state = 22},
  [10795] = {.lex_state = 0, .external_lex_state = 22},
  [10796] = {.lex_state = 0, .external_lex_state = 22},
  [10797] = {.lex_state = 0, .external_lex_state = 22},
  [10798] = {.lex_state = 0, .external_lex_state = 22},
  [10799] = {.lex_state = 0, .external_lex_state = 22},
  [10800] = {.lex_state = 0, .external_lex_state = 22},
  [10801] = {.lex_state = 0, .external_lex_state = 22},
  [10802] = {.lex_state = 0, .external_lex_state = 22},
  [10803] = {.lex_state = 0, .external_lex_state = 22},
  [10804] = {.lex_state = 0, .external_lex_state = 22},
  [10805] = {.lex_state = 0, .external_lex_state = 22},
  [10806] = {.lex_state = 0, .external_lex_state = 22},
  [10807] = {.lex_state = 0, .external_lex_state = 22},
  [10808] = {.lex_state = 0, .external_lex_state = 22},
  [10809] = {.lex_state = 0, .external_lex_state = 22},
  [10810] = {.lex_state = 0, .external_lex_state = 22},
  [10811] = {.lex_state = 0, .external_lex_state = 22},
  [10812] = {.lex_state = 117, .external_lex_state = 22},
  [10813] = {.lex_state = 0, .external_lex_state = 22},
  [10814] = {.lex_state = 0, .external_lex_state = 22},
  [10815] = {.lex_state = 0, .external_lex_state = 22},
  [10816] = {.lex_state = 0, .external_lex_state = 22},
  [10817] = {.lex_state = 0, .external_lex_state = 22},
  [10818] = {.lex_state = 0, .external_lex_state = 22},
  [10819] = {.lex_state = 0, .external_lex_state = 22},
  [10820] = {.lex_state = 0, .external_lex_state = 22},
  [10821] = {.lex_state = 0, .external_lex_state = 22},
  [10822] = {.lex_state = 0, .external_lex_state = 22},
  [10823] = {.lex_state = 0, .external_lex_state = 22},
  [10824] = {.lex_state = 0, .external_lex_state = 22},
  [10825] = {.lex_state = 0, .external_lex_state = 22},
  [10826] = {.lex_state = 0, .external_lex_state = 22},
  [10827] = {.lex_state = 0, .external_lex_state = 22},
  [10828] = {.lex_state = 0, .external_lex_state = 22},
  [10829] = {.lex_state = 0, .external_lex_state = 22},
  [10830] = {.lex_state = 0, .external_lex_state = 22},
  [10831] = {.lex_state = 0, .external_lex_state = 22},
  [10832] = {.lex_state = 0, .external_lex_state = 22},
  [10833] = {.lex_state = 0, .external_lex_state = 22},
  [10834] = {.lex_state = 0, .external_lex_state = 22},
  [10835] = {.lex_state = 0, .external_lex_state = 22},
  [10836] = {.lex_state = 0, .external_lex_state = 22},
  [10837] = {.lex_state = 0, .external_lex_state = 22},
  [10838] = {.lex_state = 0, .external_lex_state = 22},
  [10839] = {.lex_state = 0, .external_lex_state = 22},
  [10840] = {.lex_state = 0, .external_lex_state = 22},
  [10841] = {.lex_state = 0, .external_lex_state = 22},
  [10842] = {.lex_state = 0, .external_lex_state = 22},
  [10843] = {.lex_state = 0, .external_lex_state = 22},
  [10844] = {.lex_state = 0, .external_lex_state = 22},
  [10845] = {.lex_state = 0, .external_lex_state = 22},
  [10846] = {.lex_state = 0, .external_lex_state = 22},
  [10847] = {.lex_state = 0, .external_lex_state = 22},
  [10848] = {.lex_state = 0, .external_lex_state = 22},
  [10849] = {.lex_state = 0, .external_lex_state = 22},
  [10850] = {.lex_state = 0, .external_lex_state = 22},
  [10851] = {.lex_state = 0, .external_lex_state = 22},
  [10852] = {.lex_state = 0, .external_lex_state = 22},
  [10853] = {.lex_state = 0, .external_lex_state = 22},
  [10854] = {.lex_state = 0, .external_lex_state = 22},
  [10855] = {.lex_state = 0, .external_lex_state = 22},
  [10856] = {.lex_state = 0, .external_lex_state = 22},
  [10857] = {.lex_state = 0, .external_lex_state = 22},
  [10858] = {.lex_state = 0, .external_lex_state = 22},
  [10859] = {.lex_state = 0, .external_lex_state = 22},
  [10860] = {.lex_state = 0, .external_lex_state = 22},
  [10861] = {.lex_state = 0, .external_lex_state = 22},
  [10862] = {.lex_state = 0, .external_lex_state = 22},
  [10863] = {.lex_state = 0, .external_lex_state = 22},
  [10864] = {.lex_state = 0, .external_lex_state = 22},
  [10865] = {.lex_state = 0, .external_lex_state = 22},
  [10866] = {.lex_state = 0, .external_lex_state = 22},
  [10867] = {.lex_state = 0, .external_lex_state = 22},
  [10868] = {.lex_state = 0, .external_lex_state = 22},
  [10869] = {.lex_state = 0, .external_lex_state = 22},
  [10870] = {.lex_state = 117, .external_lex_state = 22},
  [10871] = {.lex_state = 0, .external_lex_state = 22},
  [10872] = {.lex_state = 0, .external_lex_state = 22},
  [10873] = {.lex_state = 0, .external_lex_state = 22},
  [10874] = {.lex_state = 0, .external_lex_state = 22},
  [10875] = {.lex_state = 0, .external_lex_state = 22},
  [10876] = {.lex_state = 0, .external_lex_state = 22},
  [10877] = {.lex_state = 0, .external_lex_state = 22},
  [10878] = {.lex_state = 0, .external_lex_state = 22},
  [10879] = {.lex_state = 0, .external_lex_state = 22},
  [10880] = {.lex_state = 0, .external_lex_state = 22},
  [10881] = {.lex_state = 0, .external_lex_state = 22},
  [10882] = {.lex_state = 0, .external_lex_state = 22},
  [10883] = {.lex_state = 0, .external_lex_state = 22},
  [10884] = {.lex_state = 0, .external_lex_state = 22},
  [10885] = {.lex_state = 0, .external_lex_state = 22},
  [10886] = {.lex_state = 0, .external_lex_state = 22},
  [10887] = {.lex_state = 0, .external_lex_state = 22},
  [10888] = {.lex_state = 0, .external_lex_state = 22},
  [10889] = {.lex_state = 0, .external_lex_state = 22},
  [10890] = {.lex_state = 0, .external_lex_state = 22},
  [10891] = {.lex_state = 0, .external_lex_state = 22},
  [10892] = {.lex_state = 0, .external_lex_state = 22},
  [10893] = {.lex_state = 0, .external_lex_state = 22},
  [10894] = {.lex_state = 117, .external_lex_state = 22},
  [10895] = {.lex_state = 0, .external_lex_state = 22},
  [10896] = {.lex_state = 0, .external_lex_state = 22},
  [10897] = {.lex_state = 0, .external_lex_state = 22},
  [10898] = {.lex_state = 0, .external_lex_state = 22},
  [10899] = {.lex_state = 0, .external_lex_state = 22},
  [10900] = {.lex_state = 0, .external_lex_state = 22},
  [10901] = {.lex_state = 0, .external_lex_state = 22},
  [10902] = {.lex_state = 0, .external_lex_state = 22},
  [10903] = {.lex_state = 0, .external_lex_state = 22},
  [10904] = {.lex_state = 0, .external_lex_state = 22},
  [10905] = {.lex_state = 0, .external_lex_state = 22},
  [10906] = {.lex_state = 0, .external_lex_state = 22},
  [10907] = {.lex_state = 0, .external_lex_state = 22},
  [10908] = {.lex_state = 0, .external_lex_state = 22},
  [10909] = {.lex_state = 0, .external_lex_state = 22},
  [10910] = {.lex_state = 0, .external_lex_state = 22},
  [10911] = {.lex_state = 0, .external_lex_state = 22},
  [10912] = {.lex_state = 0, .external_lex_state = 22},
  [10913] = {.lex_state = 0, .external_lex_state = 22},
  [10914] = {.lex_state = 0, .external_lex_state = 22},
  [10915] = {.lex_state = 0, .external_lex_state = 22},
  [10916] = {.lex_state = 0, .external_lex_state = 22},
  [10917] = {.lex_state = 0, .external_lex_state = 22},
  [10918] = {.lex_state = 0, .external_lex_state = 22},
  [10919] = {.lex_state = 0, .external_lex_state = 22},
  [10920] = {.lex_state = 0, .external_lex_state = 22},
  [10921] = {.lex_state = 0, .external_lex_state = 22},
  [10922] = {.lex_state = 0, .external_lex_state = 22},
  [10923] = {.lex_state = 0, .external_lex_state = 22},
  [10924] = {.lex_state = 0, .external_lex_state = 22},
  [10925] = {.lex_state = 0, .external_lex_state = 22},
  [10926] = {.lex_state = 0, .external_lex_state = 22},
  [10927] = {.lex_state = 0, .external_lex_state = 22},
  [10928] = {.lex_state = 0, .external_lex_state = 22},
  [10929] = {.lex_state = 0, .external_lex_state = 22},
  [10930] = {.lex_state = 0, .external_lex_state = 22},
  [10931] = {.lex_state = 0, .external_lex_state = 22},
  [10932] = {.lex_state = 0, .external_lex_state = 22},
  [10933] = {.lex_state = 117, .external_lex_state = 2},
  [10934] = {.lex_state = 0, .external_lex_state = 22},
  [10935] = {.lex_state = 0, .external_lex_state = 22},
  [10936] = {.lex_state = 117, .external_lex_state = 26},
  [10937] = {.lex_state = 0, .external_lex_state = 22},
  [10938] = {.lex_state = 0, .external_lex_state = 22},
  [10939] = {.lex_state = 0, .external_lex_state = 22},
  [10940] = {.lex_state = 0, .external_lex_state = 22},
  [10941] = {.lex_state = 0, .external_lex_state = 22},
  [10942] = {.lex_state = 0, .external_lex_state = 22},
  [10943] = {.lex_state = 0, .external_lex_state = 22},
  [10944] = {.lex_state = 0, .external_lex_state = 22},
  [10945] = {.lex_state = 0, .external_lex_state = 22},
  [10946] = {.lex_state = 0, .external_lex_state = 22},
  [10947] = {.lex_state = 0, .external_lex_state = 22},
  [10948] = {.lex_state = 0, .external_lex_state = 22},
  [10949] = {.lex_state = 0, .external_lex_state = 22},
  [10950] = {.lex_state = 0, .external_lex_state = 22},
  [10951] = {.lex_state = 0, .external_lex_state = 22},
  [10952] = {.lex_state = 0, .external_lex_state = 22},
  [10953] = {.lex_state = 0, .external_lex_state = 22},
  [10954] = {.lex_state = 0, .external_lex_state = 22},
  [10955] = {.lex_state = 0, .external_lex_state = 22},
  [10956] = {.lex_state = 0, .external_lex_state = 22},
  [10957] = {.lex_state = 0, .external_lex_state = 22},
  [10958] = {.lex_state = 0, .external_lex_state = 22},
  [10959] = {.lex_state = 0, .external_lex_state = 22},
  [10960] = {.lex_state = 0, .external_lex_state = 22},
  [10961] = {.lex_state = 0, .external_lex_state = 22},
  [10962] = {.lex_state = 0, .external_lex_state = 22},
  [10963] = {.lex_state = 0, .external_lex_state = 22},
  [10964] = {.lex_state = 0, .external_lex_state = 22},
  [10965] = {.lex_state = 0, .external_lex_state = 22},
  [10966] = {.lex_state = 10, .external_lex_state = 22},
  [10967] = {.lex_state = 0, .external_lex_state = 22},
  [10968] = {.lex_state = 0, .external_lex_state = 22},
  [10969] = {.lex_state = 0, .external_lex_state = 22},
  [10970] = {.lex_state = 0, .external_lex_state = 22},
  [10971] = {.lex_state = 0, .external_lex_state = 22},
  [10972] = {.lex_state = 0, .external_lex_state = 22},
  [10973] = {.lex_state = 0, .external_lex_state = 22},
  [10974] = {.lex_state = 0, .external_lex_state = 22},
  [10975] = {.lex_state = 0, .external_lex_state = 22},
  [10976] = {.lex_state = 0, .external_lex_state = 22},
  [10977] = {.lex_state = 0, .external_lex_state = 22},
  [10978] = {.lex_state = 0, .external_lex_state = 22},
  [10979] = {.lex_state = 0, .external_lex_state = 22},
  [10980] = {.lex_state = 0, .external_lex_state = 22},
  [10981] = {.lex_state = 0, .external_lex_state = 22},
  [10982] = {.lex_state = 117, .external_lex_state = 26},
  [10983] = {.lex_state = 0, .external_lex_state = 22},
  [10984] = {.lex_state = 0, .external_lex_state = 22},
  [10985] = {.lex_state = 0, .external_lex_state = 22},
  [10986] = {.lex_state = 0, .external_lex_state = 22},
  [10987] = {.lex_state = 0, .external_lex_state = 22},
  [10988] = {.lex_state = 0, .external_lex_state = 22},
  [10989] = {.lex_state = 0, .external_lex_state = 22},
  [10990] = {.lex_state = 117},
  [10991] = {.lex_state = 0, .external_lex_state = 22},
  [10992] = {.lex_state = 0, .external_lex_state = 22},
  [10993] = {.lex_state = 0, .external_lex_state = 22},
  [10994] = {.lex_state = 0, .external_lex_state = 22},
  [10995] = {.lex_state = 0, .external_lex_state = 22},
  [10996] = {.lex_state = 0, .external_lex_state = 22},
  [10997] = {.lex_state = 0, .external_lex_state = 22},
  [10998] = {.lex_state = 0, .external_lex_state = 22},
  [10999] = {.lex_state = 0, .external_lex_state = 22},
  [11000] = {.lex_state = 0, .external_lex_state = 22},
  [11001] = {.lex_state = 0, .external_lex_state = 22},
  [11002] = {.lex_state = 0, .external_lex_state = 22},
  [11003] = {.lex_state = 0, .external_lex_state = 22},
  [11004] = {.lex_state = 0, .external_lex_state = 22},
  [11005] = {.lex_state = 0, .external_lex_state = 22},
  [11006] = {.lex_state = 0, .external_lex_state = 22},
  [11007] = {.lex_state = 0, .external_lex_state = 22},
  [11008] = {.lex_state = 0, .external_lex_state = 22},
  [11009] = {.lex_state = 0, .external_lex_state = 22},
  [11010] = {.lex_state = 0, .external_lex_state = 22},
  [11011] = {.lex_state = 0, .external_lex_state = 22},
  [11012] = {.lex_state = 0, .external_lex_state = 22},
  [11013] = {.lex_state = 0, .external_lex_state = 22},
  [11014] = {.lex_state = 0, .external_lex_state = 22},
  [11015] = {.lex_state = 0, .external_lex_state = 22},
  [11016] = {.lex_state = 0, .external_lex_state = 22},
  [11017] = {.lex_state = 0, .external_lex_state = 22},
  [11018] = {.lex_state = 0, .external_lex_state = 22},
  [11019] = {.lex_state = 0, .external_lex_state = 22},
  [11020] = {.lex_state = 0, .external_lex_state = 22},
  [11021] = {.lex_state = 0, .external_lex_state = 22},
  [11022] = {.lex_state = 0, .external_lex_state = 22},
  [11023] = {.lex_state = 0, .external_lex_state = 22},
  [11024] = {.lex_state = 117, .external_lex_state = 26},
  [11025] = {.lex_state = 0, .external_lex_state = 22},
  [11026] = {.lex_state = 0, .external_lex_state = 22},
  [11027] = {.lex_state = 0, .external_lex_state = 22},
  [11028] = {.lex_state = 0, .external_lex_state = 22},
  [11029] = {.lex_state = 0, .external_lex_state = 22},
  [11030] = {.lex_state = 0, .external_lex_state = 22},
  [11031] = {.lex_state = 0, .external_lex_state = 22},
  [11032] = {.lex_state = 0, .external_lex_state = 22},
  [11033] = {.lex_state = 0, .external_lex_state = 22},
  [11034] = {.lex_state = 0, .external_lex_state = 22},
  [11035] = {.lex_state = 0, .external_lex_state = 22},
  [11036] = {.lex_state = 117, .external_lex_state = 26},
  [11037] = {.lex_state = 117, .external_lex_state = 22},
  [11038] = {.lex_state = 117, .external_lex_state = 26},
  [11039] = {.lex_state = 117},
  [11040] = {.lex_state = 117},
  [11041] = {.lex_state = 0, .external_lex_state = 22},
  [11042] = {.lex_state = 0, .external_lex_state = 22},
  [11043] = {.lex_state = 117},
  [11044] = {.lex_state = 117, .external_lex_state = 2},
  [11045] = {.lex_state = 117},
  [11046] = {.lex_state = 117, .external_lex_state = 26},
  [11047] = {.lex_state = 117, .external_lex_state = 26},
  [11048] = {.lex_state = 117, .external_lex_state = 27},
  [11049] = {.lex_state = 117, .external_lex_state = 26},
  [11050] = {.lex_state = 117},
  [11051] = {.lex_state = 0, .external_lex_state = 22},
  [11052] = {.lex_state = 117, .external_lex_state = 26},
  [11053] = {.lex_state = 117, .external_lex_state = 26},
  [11054] = {.lex_state = 117, .external_lex_state = 26},
  [11055] = {.lex_state = 117, .external_lex_state = 27},
  [11056] = {.lex_state = 117},
  [11057] = {.lex_state = 117, .external_lex_state = 26},
  [11058] = {.lex_state = 117, .external_lex_state = 26},
  [11059] = {.lex_state = 117, .external_lex_state = 26},
  [11060] = {.lex_state = 117, .external_lex_state = 26},
  [11061] = {.lex_state = 117, .external_lex_state = 22},
  [11062] = {.lex_state = 117, .external_lex_state = 26},
  [11063] = {.lex_state = 117, .external_lex_state = 26},
  [11064] = {.lex_state = 117, .external_lex_state = 26},
  [11065] = {.lex_state = 117, .external_lex_state = 26},
  [11066] = {.lex_state = 117, .external_lex_state = 26},
  [11067] = {.lex_state = 117},
  [11068] = {.lex_state = 117, .external_lex_state = 26},
  [11069] = {.lex_state = 117, .external_lex_state = 26},
  [11070] = {.lex_state = 117, .external_lex_state = 26},
  [11071] = {.lex_state = 117, .external_lex_state = 26},
  [11072] = {.lex_state = 117, .external_lex_state = 22},
  [11073] = {.lex_state = 117, .external_lex_state = 27},
  [11074] = {.lex_state = 117, .external_lex_state = 26},
  [11075] = {.lex_state = 117, .external_lex_state = 26},
  [11076] = {.lex_state = 117, .external_lex_state = 26},
  [11077] = {.lex_state = 117, .external_lex_state = 26},
  [11078] = {.lex_state = 117, .external_lex_state = 26},
  [11079] = {.lex_state = 117, .external_lex_state = 26},
  [11080] = {.lex_state = 117, .external_lex_state = 26},
  [11081] = {.lex_state = 117, .external_lex_state = 26},
  [11082] = {.lex_state = 117, .external_lex_state = 26},
  [11083] = {.lex_state = 117, .external_lex_state = 26},
  [11084] = {.lex_state = 117, .external_lex_state = 26},
  [11085] = {.lex_state = 117, .external_lex_state = 22},
  [11086] = {.lex_state = 117, .external_lex_state = 26},
  [11087] = {.lex_state = 117, .external_lex_state = 26},
  [11088] = {.lex_state = 117, .external_lex_state = 26},
  [11089] = {.lex_state = 117, .external_lex_state = 26},
  [11090] = {.lex_state = 117, .external_lex_state = 26},
  [11091] = {.lex_state = 117, .external_lex_state = 26},
  [11092] = {.lex_state = 117, .external_lex_state = 26},
  [11093] = {.lex_state = 117, .external_lex_state = 26},
  [11094] = {.lex_state = 117, .external_lex_state = 2},
  [11095] = {.lex_state = 117, .external_lex_state = 26},
  [11096] = {.lex_state = 117, .external_lex_state = 26},
  [11097] = {.lex_state = 117, .external_lex_state = 26},
  [11098] = {.lex_state = 117, .external_lex_state = 26},
  [11099] = {.lex_state = 117, .external_lex_state = 26},
  [11100] = {.lex_state = 117, .external_lex_state = 26},
  [11101] = {.lex_state = 117, .external_lex_state = 26},
  [11102] = {.lex_state = 117, .external_lex_state = 26},
  [11103] = {.lex_state = 0, .external_lex_state = 22},
  [11104] = {.lex_state = 0, .external_lex_state = 22},
  [11105] = {.lex_state = 0, .external_lex_state = 22},
  [11106] = {.lex_state = 117},
  [11107] = {.lex_state = 117, .external_lex_state = 22},
  [11108] = {.lex_state = 117},
  [11109] = {.lex_state = 117, .external_lex_state = 26},
  [11110] = {.lex_state = 0, .external_lex_state = 22},
  [11111] = {.lex_state = 0, .external_lex_state = 22},
  [11112] = {.lex_state = 117},
  [11113] = {.lex_state = 117, .external_lex_state = 26},
  [11114] = {.lex_state = 117, .external_lex_state = 22},
  [11115] = {.lex_state = 117, .external_lex_state = 26},
  [11116] = {.lex_state = 117, .external_lex_state = 26},
  [11117] = {.lex_state = 117, .external_lex_state = 26},
  [11118] = {.lex_state = 117},
  [11119] = {.lex_state = 117, .external_lex_state = 26},
  [11120] = {.lex_state = 117, .external_lex_state = 22},
  [11121] = {.lex_state = 117, .external_lex_state = 22},
  [11122] = {.lex_state = 117, .external_lex_state = 26},
  [11123] = {.lex_state = 117, .external_lex_state = 26},
  [11124] = {.lex_state = 117, .external_lex_state = 26},
  [11125] = {.lex_state = 117, .external_lex_state = 26},
  [11126] = {.lex_state = 117, .external_lex_state = 27},
  [11127] = {.lex_state = 117, .external_lex_state = 27},
  [11128] = {.lex_state = 117, .external_lex_state = 22},
  [11129] = {.lex_state = 117, .external_lex_state = 27},
  [11130] = {.lex_state = 117, .external_lex_state = 27},
  [11131] = {.lex_state = 0, .external_lex_state = 22},
  [11132] = {.lex_state = 0, .external_lex_state = 22},
  [11133] = {.lex_state = 117, .external_lex_state = 27},
  [11134] = {.lex_state = 117, .external_lex_state = 27},
  [11135] = {.lex_state = 0, .external_lex_state = 22},
  [11136] = {.lex_state = 0, .external_lex_state = 22},
  [11137] = {.lex_state = 0, .external_lex_state = 22},
  [11138] = {.lex_state = 0, .external_lex_state = 22},
  [11139] = {.lex_state = 117, .external_lex_state = 27},
  [11140] = {.lex_state = 0, .external_lex_state = 22},
  [11141] = {.lex_state = 117, .external_lex_state = 27},
  [11142] = {.lex_state = 0, .external_lex_state = 22},
  [11143] = {.lex_state = 0, .external_lex_state = 22},
  [11144] = {.lex_state = 0, .external_lex_state = 22},
  [11145] = {.lex_state = 0, .external_lex_state = 22},
  [11146] = {.lex_state = 117, .external_lex_state = 27},
  [11147] = {.lex_state = 117, .external_lex_state = 2},
  [11148] = {.lex_state = 0, .external_lex_state = 22},
  [11149] = {.lex_state = 117, .external_lex_state = 2},
  [11150] = {.lex_state = 117, .external_lex_state = 2},
  [11151] = {.lex_state = 117, .external_lex_state = 2},
  [11152] = {.lex_state = 0, .external_lex_state = 22},
  [11153] = {.lex_state = 17, .external_lex_state = 22},
  [11154] = {.lex_state = 0, .external_lex_state = 22},
  [11155] = {.lex_state = 0, .external_lex_state = 22},
  [11156] = {.lex_state = 117},
  [11157] = {.lex_state = 117, .external_lex_state = 2},
  [11158] = {.lex_state = 117, .external_lex_state = 2},
  [11159] = {.lex_state = 117, .external_lex_state = 27},
  [11160] = {.lex_state = 117, .external_lex_state = 2},
  [11161] = {.lex_state = 0, .external_lex_state = 22},
  [11162] = {.lex_state = 117, .external_lex_state = 27},
  [11163] = {.lex_state = 117},
  [11164] = {.lex_state = 117, .external_lex_state = 27},
  [11165] = {.lex_state = 117, .external_lex_state = 27},
  [11166] = {.lex_state = 117},
  [11167] = {.lex_state = 117},
  [11168] = {.lex_state = 117, .external_lex_state = 2},
  [11169] = {.lex_state = 117, .external_lex_state = 27},
  [11170] = {.lex_state = 0, .external_lex_state = 22},
  [11171] = {.lex_state = 117, .external_lex_state = 2},
  [11172] = {.lex_state = 0, .external_lex_state = 22},
  [11173] = {.lex_state = 0, .external_lex_state = 22},
  [11174] = {.lex_state = 117, .external_lex_state = 27},
  [11175] = {.lex_state = 0, .external_lex_state = 22},
  [11176] = {.lex_state = 117},
  [11177] = {.lex_state = 0, .external_lex_state = 22},
  [11178] = {.lex_state = 0, .external_lex_state = 22},
  [11179] = {.lex_state = 117, .external_lex_state = 27},
  [11180] = {.lex_state = 117, .external_lex_state = 27},
  [11181] = {.lex_state = 117, .external_lex_state = 22},
  [11182] = {.lex_state = 117, .external_lex_state = 27},
  [11183] = {.lex_state = 0, .external_lex_state = 22},
  [11184] = {.lex_state = 0, .external_lex_state = 22},
  [11185] = {.lex_state = 117, .external_lex_state = 27},
  [11186] = {.lex_state = 117, .external_lex_state = 27},
  [11187] = {.lex_state = 117, .external_lex_state = 27},
  [11188] = {.lex_state = 117, .external_lex_state = 27},
  [11189] = {.lex_state = 0, .external_lex_state = 22},
  [11190] = {.lex_state = 0, .external_lex_state = 22},
  [11191] = {.lex_state = 117},
  [11192] = {.lex_state = 117, .external_lex_state = 22},
  [11193] = {.lex_state = 117, .external_lex_state = 27},
  [11194] = {.lex_state = 117},
  [11195] = {.lex_state = 117, .external_lex_state = 2},
  [11196] = {.lex_state = 0, .external_lex_state = 22},
  [11197] = {.lex_state = 117, .external_lex_state = 27},
  [11198] = {.lex_state = 117, .external_lex_state = 27},
  [11199] = {.lex_state = 0, .external_lex_state = 22},
  [11200] = {.lex_state = 117},
  [11201] = {.lex_state = 117, .external_lex_state = 27},
  [11202] = {.lex_state = 117, .external_lex_state = 22},
  [11203] = {.lex_state = 117, .external_lex_state = 2},
  [11204] = {.lex_state = 117, .external_lex_state = 2},
  [11205] = {.lex_state = 117, .external_lex_state = 27},
  [11206] = {.lex_state = 117, .external_lex_state = 27},
  [11207] = {.lex_state = 117, .external_lex_state = 27},
  [11208] = {.lex_state = 117, .external_lex_state = 27},
  [11209] = {.lex_state = 117, .external_lex_state = 27},
  [11210] = {.lex_state = 117, .external_lex_state = 27},
  [11211] = {.lex_state = 117},
  [11212] = {.lex_state = 117, .external_lex_state = 27},
  [11213] = {.lex_state = 117, .external_lex_state = 27},
  [11214] = {.lex_state = 0, .external_lex_state = 22},
  [11215] = {.lex_state = 0, .external_lex_state = 22},
  [11216] = {.lex_state = 17, .external_lex_state = 22},
  [11217] = {.lex_state = 117},
  [11218] = {.lex_state = 117},
  [11219] = {.lex_state = 0, .external_lex_state = 22},
  [11220] = {.lex_state = 17, .external_lex_state = 22},
  [11221] = {.lex_state = 0, .external_lex_state = 22},
  [11222] = {.lex_state = 117, .external_lex_state = 2},
  [11223] = {.lex_state = 117, .external_lex_state = 27},
  [11224] = {.lex_state = 0, .external_lex_state = 22},
  [11225] = {.lex_state = 0, .external_lex_state = 22},
  [11226] = {.lex_state = 117, .external_lex_state = 27},
  [11227] = {.lex_state = 117, .external_lex_state = 27},
  [11228] = {.lex_state = 0, .external_lex_state = 22},
  [11229] = {.lex_state = 0, .external_lex_state = 22},
  [11230] = {.lex_state = 0, .external_lex_state = 22},
  [11231] = {.lex_state = 0, .external_lex_state = 22},
  [11232] = {.lex_state = 117},
  [11233] = {.lex_state = 0, .external_lex_state = 22},
  [11234] = {.lex_state = 117, .external_lex_state = 27},
  [11235] = {.lex_state = 117, .external_lex_state = 27},
  [11236] = {.lex_state = 0, .external_lex_state = 22},
  [11237] = {.lex_state = 0, .external_lex_state = 22},
  [11238] = {.lex_state = 117, .external_lex_state = 22},
  [11239] = {.lex_state = 117, .external_lex_state = 2},
  [11240] = {.lex_state = 117},
  [11241] = {.lex_state = 117, .external_lex_state = 22},
  [11242] = {.lex_state = 117, .external_lex_state = 27},
  [11243] = {.lex_state = 117, .external_lex_state = 27},
  [11244] = {.lex_state = 117, .external_lex_state = 27},
  [11245] = {.lex_state = 117, .external_lex_state = 27},
  [11246] = {.lex_state = 0, .external_lex_state = 22},
  [11247] = {.lex_state = 0, .external_lex_state = 22},
  [11248] = {.lex_state = 117, .external_lex_state = 27},
  [11249] = {.lex_state = 117, .external_lex_state = 27},
  [11250] = {.lex_state = 117, .external_lex_state = 27},
  [11251] = {.lex_state = 117, .external_lex_state = 27},
  [11252] = {.lex_state = 117, .external_lex_state = 27},
  [11253] = {.lex_state = 117, .external_lex_state = 27},
  [11254] = {.lex_state = 117, .external_lex_state = 27},
  [11255] = {.lex_state = 0, .external_lex_state = 22},
  [11256] = {.lex_state = 117, .external_lex_state = 27},
  [11257] = {.lex_state = 117, .external_lex_state = 27},
  [11258] = {.lex_state = 117, .external_lex_state = 27},
  [11259] = {.lex_state = 117, .external_lex_state = 27},
  [11260] = {.lex_state = 117, .external_lex_state = 27},
  [11261] = {.lex_state = 117, .external_lex_state = 27},
  [11262] = {.lex_state = 117, .external_lex_state = 27},
  [11263] = {.lex_state = 0, .external_lex_state = 22},
  [11264] = {.lex_state = 117, .external_lex_state = 27},
  [11265] = {.lex_state = 0, .external_lex_state = 22},
  [11266] = {.lex_state = 12},
  [11267] = {.lex_state = 12},
  [11268] = {.lex_state = 0, .external_lex_state = 22},
  [11269] = {.lex_state = 12},
  [11270] = {.lex_state = 117, .external_lex_state = 2},
  [11271] = {.lex_state = 12},
  [11272] = {.lex_state = 117, .external_lex_state = 2},
  [11273] = {.lex_state = 12},
  [11274] = {.lex_state = 117, .external_lex_state = 2},
  [11275] = {.lex_state = 12},
  [11276] = {.lex_state = 0, .external_lex_state = 22},
  [11277] = {.lex_state = 117, .external_lex_state = 2},
  [11278] = {.lex_state = 117, .external_lex_state = 2},
  [11279] = {.lex_state = 0, .external_lex_state = 22},
  [11280] = {.lex_state = 117, .external_lex_state = 10},
  [11281] = {.lex_state = 0, .external_lex_state = 22},
  [11282] = {.lex_state = 0, .external_lex_state = 22},
  [11283] = {.lex_state = 0, .external_lex_state = 22},
  [11284] = {.lex_state = 0, .external_lex_state = 22},
  [11285] = {.lex_state = 12},
  [11286] = {.lex_state = 0, .external_lex_state = 22},
  [11287] = {.lex_state = 0, .external_lex_state = 22},
  [11288] = {.lex_state = 0, .external_lex_state = 22},
  [11289] = {.lex_state = 0, .external_lex_state = 22},
  [11290] = {.lex_state = 0, .external_lex_state = 22},
  [11291] = {.lex_state = 12},
  [11292] = {.lex_state = 9},
  [11293] = {.lex_state = 0, .external_lex_state = 22},
  [11294] = {.lex_state = 0, .external_lex_state = 22},
  [11295] = {.lex_state = 0, .external_lex_state = 22},
  [11296] = {.lex_state = 117, .external_lex_state = 10},
  [11297] = {.lex_state = 117, .external_lex_state = 10},
  [11298] = {.lex_state = 12},
  [11299] = {.lex_state = 117},
  [11300] = {.lex_state = 0, .external_lex_state = 22},
  [11301] = {.lex_state = 0, .external_lex_state = 22},
  [11302] = {.lex_state = 0, .external_lex_state = 22},
  [11303] = {.lex_state = 0, .external_lex_state = 22},
  [11304] = {.lex_state = 117, .external_lex_state = 10},
  [11305] = {.lex_state = 117, .external_lex_state = 2},
  [11306] = {.lex_state = 9},
  [11307] = {.lex_state = 0, .external_lex_state = 22},
  [11308] = {.lex_state = 0, .external_lex_state = 22},
  [11309] = {.lex_state = 117},
  [11310] = {.lex_state = 0, .external_lex_state = 22},
  [11311] = {.lex_state = 0, .external_lex_state = 22},
  [11312] = {.lex_state = 0, .external_lex_state = 22},
  [11313] = {.lex_state = 0, .external_lex_state = 22},
  [11314] = {.lex_state = 0, .external_lex_state = 22},
  [11315] = {.lex_state = 117, .external_lex_state = 10},
  [11316] = {.lex_state = 117, .external_lex_state = 10},
  [11317] = {.lex_state = 0, .external_lex_state = 22},
  [11318] = {.lex_state = 117, .external_lex_state = 2},
  [11319] = {.lex_state = 0, .external_lex_state = 22},
  [11320] = {.lex_state = 12},
  [11321] = {.lex_state = 9},
  [11322] = {.lex_state = 0, .external_lex_state = 22},
  [11323] = {.lex_state = 0, .external_lex_state = 22},
  [11324] = {.lex_state = 0, .external_lex_state = 22},
  [11325] = {.lex_state = 0, .external_lex_state = 22},
  [11326] = {.lex_state = 12},
  [11327] = {.lex_state = 117, .external_lex_state = 2},
  [11328] = {.lex_state = 117, .external_lex_state = 2},
  [11329] = {.lex_state = 0, .external_lex_state = 22},
  [11330] = {.lex_state = 117},
  [11331] = {.lex_state = 117, .external_lex_state = 2},
  [11332] = {.lex_state = 0, .external_lex_state = 22},
  [11333] = {.lex_state = 0, .external_lex_state = 22},
  [11334] = {.lex_state = 12},
  [11335] = {.lex_state = 0, .external_lex_state = 22},
  [11336] = {.lex_state = 0, .external_lex_state = 22},
  [11337] = {.lex_state = 117, .external_lex_state = 2},
  [11338] = {.lex_state = 0, .external_lex_state = 22},
  [11339] = {.lex_state = 117, .external_lex_state = 2},
  [11340] = {.lex_state = 0, .external_lex_state = 22},
  [11341] = {.lex_state = 12},
  [11342] = {.lex_state = 9},
  [11343] = {.lex_state = 0, .external_lex_state = 22},
  [11344] = {.lex_state = 117, .external_lex_state = 2},
  [11345] = {.lex_state = 0, .external_lex_state = 22},
  [11346] = {.lex_state = 0, .external_lex_state = 22},
  [11347] = {.lex_state = 0, .external_lex_state = 22},
  [11348] = {.lex_state = 9},
  [11349] = {.lex_state = 117, .external_lex_state = 2},
  [11350] = {.lex_state = 0, .external_lex_state = 22},
  [11351] = {.lex_state = 0, .external_lex_state = 22},
  [11352] = {.lex_state = 117, .external_lex_state = 2},
  [11353] = {.lex_state = 0, .external_lex_state = 22},
  [11354] = {.lex_state = 0, .external_lex_state = 22},
  [11355] = {.lex_state = 117, .external_lex_state = 2},
  [11356] = {.lex_state = 9},
  [11357] = {.lex_state = 0, .external_lex_state = 22},
  [11358] = {.lex_state = 0, .external_lex_state = 22},
  [11359] = {.lex_state = 9},
  [11360] = {.lex_state = 0, .external_lex_state = 22},
  [11361] = {.lex_state = 9},
  [11362] = {.lex_state = 117, .external_lex_state = 10},
  [11363] = {.lex_state = 0, .external_lex_state = 22},
  [11364] = {.lex_state = 12},
  [11365] = {.lex_state = 9},
  [11366] = {.lex_state = 117, .external_lex_state = 10},
  [11367] = {.lex_state = 0, .external_lex_state = 22},
  [11368] = {.lex_state = 0, .external_lex_state = 22},
  [11369] = {.lex_state = 117, .external_lex_state = 2},
  [11370] = {.lex_state = 0, .external_lex_state = 22},
  [11371] = {.lex_state = 117, .external_lex_state = 10},
  [11372] = {.lex_state = 9},
  [11373] = {.lex_state = 0, .external_lex_state = 22},
  [11374] = {.lex_state = 12},
  [11375] = {.lex_state = 117, .external_lex_state = 2},
  [11376] = {.lex_state = 0, .external_lex_state = 22},
  [11377] = {.lex_state = 0, .external_lex_state = 22},
  [11378] = {.lex_state = 0, .external_lex_state = 22},
  [11379] = {.lex_state = 117, .external_lex_state = 10},
  [11380] = {.lex_state = 117, .external_lex_state = 10},
  [11381] = {.lex_state = 117, .external_lex_state = 10},
  [11382] = {.lex_state = 0, .external_lex_state = 22},
  [11383] = {.lex_state = 0, .external_lex_state = 22},
  [11384] = {.lex_state = 0, .external_lex_state = 22},
  [11385] = {.lex_state = 0, .external_lex_state = 22},
  [11386] = {.lex_state = 0, .external_lex_state = 22},
  [11387] = {.lex_state = 0, .external_lex_state = 22},
  [11388] = {.lex_state = 0, .external_lex_state = 22},
  [11389] = {.lex_state = 0, .external_lex_state = 22},
  [11390] = {.lex_state = 0, .external_lex_state = 22},
  [11391] = {.lex_state = 117, .external_lex_state = 24},
  [11392] = {.lex_state = 117, .external_lex_state = 24},
  [11393] = {.lex_state = 0, .external_lex_state = 22},
  [11394] = {.lex_state = 12},
  [11395] = {.lex_state = 117, .external_lex_state = 24},
  [11396] = {.lex_state = 0, .external_lex_state = 22},
  [11397] = {.lex_state = 12},
  [11398] = {.lex_state = 0, .external_lex_state = 22},
  [11399] = {.lex_state = 12},
  [11400] = {.lex_state = 117, .external_lex_state = 24},
  [11401] = {.lex_state = 117, .external_lex_state = 24},
  [11402] = {.lex_state = 117},
  [11403] = {.lex_state = 0, .external_lex_state = 22},
  [11404] = {.lex_state = 117, .external_lex_state = 24},
  [11405] = {.lex_state = 0, .external_lex_state = 22},
  [11406] = {.lex_state = 117, .external_lex_state = 24},
  [11407] = {.lex_state = 12},
  [11408] = {.lex_state = 0, .external_lex_state = 22},
  [11409] = {.lex_state = 0, .external_lex_state = 22},
  [11410] = {.lex_state = 12},
  [11411] = {.lex_state = 117},
  [11412] = {.lex_state = 117, .external_lex_state = 24},
  [11413] = {.lex_state = 0, .external_lex_state = 22},
  [11414] = {.lex_state = 117, .external_lex_state = 24},
  [11415] = {.lex_state = 0, .external_lex_state = 22},
  [11416] = {.lex_state = 0, .external_lex_state = 22},
  [11417] = {.lex_state = 12},
  [11418] = {.lex_state = 117, .external_lex_state = 24},
  [11419] = {.lex_state = 117, .external_lex_state = 24},
  [11420] = {.lex_state = 0, .external_lex_state = 22},
  [11421] = {.lex_state = 12},
  [11422] = {.lex_state = 12},
  [11423] = {.lex_state = 117, .external_lex_state = 24},
  [11424] = {.lex_state = 12},
  [11425] = {.lex_state = 0, .external_lex_state = 22},
  [11426] = {.lex_state = 12},
  [11427] = {.lex_state = 0, .external_lex_state = 22},
  [11428] = {.lex_state = 117, .external_lex_state = 24},
  [11429] = {.lex_state = 117, .external_lex_state = 24},
  [11430] = {.lex_state = 117, .external_lex_state = 24},
  [11431] = {.lex_state = 117, .external_lex_state = 24},
  [11432] = {.lex_state = 117, .external_lex_state = 24},
  [11433] = {.lex_state = 0, .external_lex_state = 22},
  [11434] = {.lex_state = 0, .external_lex_state = 22},
  [11435] = {.lex_state = 0, .external_lex_state = 22},
  [11436] = {.lex_state = 117},
  [11437] = {.lex_state = 117, .external_lex_state = 24},
  [11438] = {.lex_state = 117, .external_lex_state = 24},
  [11439] = {.lex_state = 12},
  [11440] = {.lex_state = 12},
  [11441] = {.lex_state = 12},
  [11442] = {.lex_state = 117, .external_lex_state = 24},
  [11443] = {.lex_state = 117, .external_lex_state = 24},
  [11444] = {.lex_state = 117, .external_lex_state = 24},
  [11445] = {.lex_state = 117, .external_lex_state = 24},
  [11446] = {.lex_state = 0, .external_lex_state = 22},
  [11447] = {.lex_state = 117, .external_lex_state = 24},
  [11448] = {.lex_state = 117, .external_lex_state = 24},
  [11449] = {.lex_state = 0, .external_lex_state = 22},
  [11450] = {.lex_state = 12},
  [11451] = {.lex_state = 117, .external_lex_state = 24},
  [11452] = {.lex_state = 117, .external_lex_state = 24},
  [11453] = {.lex_state = 117, .external_lex_state = 24},
  [11454] = {.lex_state = 12},
  [11455] = {.lex_state = 0, .external_lex_state = 22},
  [11456] = {.lex_state = 0, .external_lex_state = 22},
  [11457] = {.lex_state = 117, .external_lex_state = 24},
  [11458] = {.lex_state = 117, .external_lex_state = 24},
  [11459] = {.lex_state = 0, .external_lex_state = 22},
  [11460] = {.lex_state = 117, .external_lex_state = 24},
  [11461] = {.lex_state = 0, .external_lex_state = 22},
  [11462] = {.lex_state = 0, .external_lex_state = 22},
  [11463] = {.lex_state = 117, .external_lex_state = 24},
  [11464] = {.lex_state = 117, .external_lex_state = 24},
  [11465] = {.lex_state = 117, .external_lex_state = 24},
  [11466] = {.lex_state = 0, .external_lex_state = 22},
  [11467] = {.lex_state = 117, .external_lex_state = 24},
  [11468] = {.lex_state = 117, .external_lex_state = 24},
  [11469] = {.lex_state = 117, .external_lex_state = 24},
  [11470] = {.lex_state = 117, .external_lex_state = 24},
  [11471] = {.lex_state = 117, .external_lex_state = 24},
  [11472] = {.lex_state = 117, .external_lex_state = 24},
  [11473] = {.lex_state = 117, .external_lex_state = 24},
  [11474] = {.lex_state = 117, .external_lex_state = 24},
  [11475] = {.lex_state = 117, .external_lex_state = 24},
  [11476] = {.lex_state = 117, .external_lex_state = 24},
  [11477] = {.lex_state = 117, .external_lex_state = 24},
  [11478] = {.lex_state = 117, .external_lex_state = 24},
  [11479] = {.lex_state = 117, .external_lex_state = 24},
  [11480] = {.lex_state = 117, .external_lex_state = 24},
  [11481] = {.lex_state = 117, .external_lex_state = 24},
  [11482] = {.lex_state = 117, .external_lex_state = 24},
  [11483] = {.lex_state = 117, .external_lex_state = 24},
  [11484] = {.lex_state = 12},
  [11485] = {.lex_state = 12},
  [11486] = {.lex_state = 117, .external_lex_state = 24},
  [11487] = {.lex_state = 12},
  [11488] = {.lex_state = 117, .external_lex_state = 24},
  [11489] = {.lex_state = 12},
  [11490] = {.lex_state = 117, .external_lex_state = 24},
  [11491] = {.lex_state = 0, .external_lex_state = 22},
  [11492] = {.lex_state = 0, .external_lex_state = 22},
  [11493] = {.lex_state = 0, .external_lex_state = 22},
  [11494] = {.lex_state = 0, .external_lex_state = 22},
  [11495] = {.lex_state = 12},
  [11496] = {.lex_state = 117, .external_lex_state = 24},
  [11497] = {.lex_state = 117, .external_lex_state = 24},
  [11498] = {.lex_state = 12},
  [11499] = {.lex_state = 12},
  [11500] = {.lex_state = 117, .external_lex_state = 24},
  [11501] = {.lex_state = 0, .external_lex_state = 22},
  [11502] = {.lex_state = 0, .external_lex_state = 22},
  [11503] = {.lex_state = 117, .external_lex_state = 24},
  [11504] = {.lex_state = 117, .external_lex_state = 24},
  [11505] = {.lex_state = 0, .external_lex_state = 22},
  [11506] = {.lex_state = 12},
  [11507] = {.lex_state = 117, .external_lex_state = 24},
  [11508] = {.lex_state = 0, .external_lex_state = 22},
  [11509] = {.lex_state = 12},
  [11510] = {.lex_state = 12},
  [11511] = {.lex_state = 117, .external_lex_state = 24},
  [11512] = {.lex_state = 117, .external_lex_state = 24},
  [11513] = {.lex_state = 0, .external_lex_state = 22},
  [11514] = {.lex_state = 0, .external_lex_state = 22},
  [11515] = {.lex_state = 0, .external_lex_state = 22},
  [11516] = {.lex_state = 117, .external_lex_state = 24},
  [11517] = {.lex_state = 117, .external_lex_state = 24},
  [11518] = {.lex_state = 12},
  [11519] = {.lex_state = 117, .external_lex_state = 24},
  [11520] = {.lex_state = 12},
  [11521] = {.lex_state = 117, .external_lex_state = 24},
  [11522] = {.lex_state = 12},
  [11523] = {.lex_state = 117, .external_lex_state = 24},
  [11524] = {.lex_state = 0, .external_lex_state = 22},
  [11525] = {.lex_state = 117, .external_lex_state = 24},
  [11526] = {.lex_state = 0, .external_lex_state = 22},
  [11527] = {.lex_state = 0, .external_lex_state = 22},
  [11528] = {.lex_state = 117, .external_lex_state = 24},
  [11529] = {.lex_state = 117, .external_lex_state = 24},
  [11530] = {.lex_state = 0, .external_lex_state = 22},
  [11531] = {.lex_state = 0, .external_lex_state = 22},
  [11532] = {.lex_state = 117, .external_lex_state = 24},
  [11533] = {.lex_state = 0, .external_lex_state = 22},
  [11534] = {.lex_state = 117, .external_lex_state = 24},
  [11535] = {.lex_state = 117, .external_lex_state = 24},
  [11536] = {.lex_state = 117, .external_lex_state = 24},
  [11537] = {.lex_state = 117, .external_lex_state = 24},
  [11538] = {.lex_state = 117, .external_lex_state = 24},
  [11539] = {.lex_state = 117, .external_lex_state = 24},
  [11540] = {.lex_state = 117, .external_lex_state = 24},
  [11541] = {.lex_state = 117, .external_lex_state = 24},
  [11542] = {.lex_state = 117, .external_lex_state = 24},
  [11543] = {.lex_state = 117, .external_lex_state = 24},
  [11544] = {.lex_state = 0, .external_lex_state = 22},
  [11545] = {.lex_state = 12},
  [11546] = {.lex_state = 12},
  [11547] = {.lex_state = 117, .external_lex_state = 24},
  [11548] = {.lex_state = 117, .external_lex_state = 24},
  [11549] = {.lex_state = 0, .external_lex_state = 22},
  [11550] = {.lex_state = 117, .external_lex_state = 24},
  [11551] = {.lex_state = 117, .external_lex_state = 24},
  [11552] = {.lex_state = 0, .external_lex_state = 22},
  [11553] = {.lex_state = 117, .external_lex_state = 24},
  [11554] = {.lex_state = 117, .external_lex_state = 24},
  [11555] = {.lex_state = 117, .external_lex_state = 24},
  [11556] = {.lex_state = 117, .external_lex_state = 24},
  [11557] = {.lex_state = 0, .external_lex_state = 22},
  [11558] = {.lex_state = 0, .external_lex_state = 22},
  [11559] = {.lex_state = 0, .external_lex_state = 22},
  [11560] = {.lex_state = 12},
  [11561] = {.lex_state = 12},
  [11562] = {.lex_state = 117, .external_lex_state = 24},
  [11563] = {.lex_state = 12},
  [11564] = {.lex_state = 117, .external_lex_state = 24},
  [11565] = {.lex_state = 117, .external_lex_state = 24},
  [11566] = {.lex_state = 117, .external_lex_state = 24},
  [11567] = {.lex_state = 117, .external_lex_state = 24},
  [11568] = {.lex_state = 0, .external_lex_state = 22},
  [11569] = {.lex_state = 117, .external_lex_state = 24},
  [11570] = {.lex_state = 0, .external_lex_state = 22},
  [11571] = {.lex_state = 117, .external_lex_state = 24},
  [11572] = {.lex_state = 117, .external_lex_state = 24},
  [11573] = {.lex_state = 0, .external_lex_state = 22},
  [11574] = {.lex_state = 0, .external_lex_state = 22},
  [11575] = {.lex_state = 0, .external_lex_state = 22},
  [11576] = {.lex_state = 117, .external_lex_state = 24},
  [11577] = {.lex_state = 0, .external_lex_state = 22},
  [11578] = {.lex_state = 0, .external_lex_state = 22},
  [11579] = {.lex_state = 0, .external_lex_state = 22},
  [11580] = {.lex_state = 117, .external_lex_state = 24},
  [11581] = {.lex_state = 0, .external_lex_state = 22},
  [11582] = {.lex_state = 117, .external_lex_state = 24},
  [11583] = {.lex_state = 117},
  [11584] = {.lex_state = 0, .external_lex_state = 22},
  [11585] = {.lex_state = 117, .external_lex_state = 24},
  [11586] = {.lex_state = 117, .external_lex_state = 24},
  [11587] = {.lex_state = 0, .external_lex_state = 22},
  [11588] = {.lex_state = 117},
  [11589] = {.lex_state = 117, .external_lex_state = 24},
  [11590] = {.lex_state = 12},
  [11591] = {.lex_state = 12},
  [11592] = {.lex_state = 117, .external_lex_state = 24},
  [11593] = {.lex_state = 117, .external_lex_state = 24},
  [11594] = {.lex_state = 117, .external_lex_state = 24},
  [11595] = {.lex_state = 0, .external_lex_state = 22},
  [11596] = {.lex_state = 117},
  [11597] = {.lex_state = 0, .external_lex_state = 22},
  [11598] = {.lex_state = 0, .external_lex_state = 22},
  [11599] = {.lex_state = 0, .external_lex_state = 22},
  [11600] = {.lex_state = 0, .external_lex_state = 22},
  [11601] = {.lex_state = 0, .external_lex_state = 22},
  [11602] = {.lex_state = 0, .external_lex_state = 22},
  [11603] = {.lex_state = 0, .external_lex_state = 22},
  [11604] = {.lex_state = 117, .external_lex_state = 24},
  [11605] = {.lex_state = 117, .external_lex_state = 24},
  [11606] = {.lex_state = 0, .external_lex_state = 22},
  [11607] = {.lex_state = 0, .external_lex_state = 22},
  [11608] = {.lex_state = 117, .external_lex_state = 24},
  [11609] = {.lex_state = 117, .external_lex_state = 24},
  [11610] = {.lex_state = 117, .external_lex_state = 24},
  [11611] = {.lex_state = 12},
  [11612] = {.lex_state = 117, .external_lex_state = 24},
  [11613] = {.lex_state = 12},
  [11614] = {.lex_state = 117, .external_lex_state = 24},
  [11615] = {.lex_state = 117, .external_lex_state = 24},
  [11616] = {.lex_state = 117, .external_lex_state = 24},
  [11617] = {.lex_state = 117, .external_lex_state = 24},
  [11618] = {.lex_state = 117},
  [11619] = {.lex_state = 117, .external_lex_state = 2},
  [11620] = {.lex_state = 117, .external_lex_state = 24},
  [11621] = {.lex_state = 117, .external_lex_state = 24},
  [11622] = {.lex_state = 117, .external_lex_state = 24},
  [11623] = {.lex_state = 117, .external_lex_state = 24},
  [11624] = {.lex_state = 117, .external_lex_state = 24},
  [11625] = {.lex_state = 117, .external_lex_state = 24},
  [11626] = {.lex_state = 117, .external_lex_state = 24},
  [11627] = {.lex_state = 117, .external_lex_state = 24},
  [11628] = {.lex_state = 117, .external_lex_state = 24},
  [11629] = {.lex_state = 117, .external_lex_state = 24},
  [11630] = {.lex_state = 117, .external_lex_state = 24},
  [11631] = {.lex_state = 117, .external_lex_state = 24},
  [11632] = {.lex_state = 0, .external_lex_state = 22},
  [11633] = {.lex_state = 117, .external_lex_state = 24},
  [11634] = {.lex_state = 117, .external_lex_state = 24},
  [11635] = {.lex_state = 117, .external_lex_state = 24},
  [11636] = {.lex_state = 0, .external_lex_state = 22},
  [11637] = {.lex_state = 117, .external_lex_state = 24},
  [11638] = {.lex_state = 117, .external_lex_state = 22},
  [11639] = {.lex_state = 0, .external_lex_state = 22},
  [11640] = {.lex_state = 117, .external_lex_state = 24},
  [11641] = {.lex_state = 117, .external_lex_state = 22},
  [11642] = {.lex_state = 117},
  [11643] = {.lex_state = 117, .external_lex_state = 24},
  [11644] = {.lex_state = 117},
  [11645] = {.lex_state = 117, .external_lex_state = 24},
  [11646] = {.lex_state = 117, .external_lex_state = 24},
  [11647] = {.lex_state = 117, .external_lex_state = 24},
  [11648] = {.lex_state = 117},
  [11649] = {.lex_state = 117},
  [11650] = {.lex_state = 117},
  [11651] = {.lex_state = 117, .external_lex_state = 24},
  [11652] = {.lex_state = 117, .external_lex_state = 24},
  [11653] = {.lex_state = 117, .external_lex_state = 24},
  [11654] = {.lex_state = 0, .external_lex_state = 22},
  [11655] = {.lex_state = 117, .external_lex_state = 24},
  [11656] = {.lex_state = 117, .external_lex_state = 24},
  [11657] = {.lex_state = 117, .external_lex_state = 24},
  [11658] = {.lex_state = 117, .external_lex_state = 24},
  [11659] = {.lex_state = 117, .external_lex_state = 24},
  [11660] = {.lex_state = 117, .external_lex_state = 24},
  [11661] = {.lex_state = 117, .external_lex_state = 22},
  [11662] = {.lex_state = 117},
  [11663] = {.lex_state = 117, .external_lex_state = 24},
  [11664] = {.lex_state = 117, .external_lex_state = 24},
  [11665] = {.lex_state = 117, .external_lex_state = 24},
  [11666] = {.lex_state = 117, .external_lex_state = 24},
  [11667] = {.lex_state = 117, .external_lex_state = 24},
  [11668] = {.lex_state = 117, .external_lex_state = 24},
  [11669] = {.lex_state = 117, .external_lex_state = 24},
  [11670] = {.lex_state = 117, .external_lex_state = 24},
  [11671] = {.lex_state = 117, .external_lex_state = 24},
  [11672] = {.lex_state = 117, .external_lex_state = 24},
  [11673] = {.lex_state = 117},
  [11674] = {.lex_state = 117, .external_lex_state = 24},
  [11675] = {.lex_state = 117, .external_lex_state = 24},
  [11676] = {.lex_state = 117, .external_lex_state = 24},
  [11677] = {.lex_state = 117, .external_lex_state = 24},
  [11678] = {.lex_state = 117, .external_lex_state = 24},
  [11679] = {.lex_state = 117, .external_lex_state = 24},
  [11680] = {.lex_state = 117, .external_lex_state = 24},
  [11681] = {.lex_state = 117, .external_lex_state = 24},
  [11682] = {.lex_state = 117, .external_lex_state = 2},
  [11683] = {.lex_state = 117, .external_lex_state = 24},
  [11684] = {.lex_state = 117, .external_lex_state = 24},
  [11685] = {.lex_state = 117, .external_lex_state = 24},
  [11686] = {.lex_state = 117},
  [11687] = {.lex_state = 117, .external_lex_state = 24},
  [11688] = {.lex_state = 117, .external_lex_state = 24},
  [11689] = {.lex_state = 117, .external_lex_state = 24},
  [11690] = {.lex_state = 117, .external_lex_state = 24},
  [11691] = {.lex_state = 0, .external_lex_state = 22},
  [11692] = {.lex_state = 117, .external_lex_state = 24},
  [11693] = {.lex_state = 117, .external_lex_state = 24},
  [11694] = {.lex_state = 0, .external_lex_state = 22},
  [11695] = {.lex_state = 117},
  [11696] = {.lex_state = 117, .external_lex_state = 2},
  [11697] = {.lex_state = 117},
  [11698] = {.lex_state = 117},
  [11699] = {.lex_state = 12},
  [11700] = {.lex_state = 117, .external_lex_state = 2},
  [11701] = {.lex_state = 117, .external_lex_state = 24},
  [11702] = {.lex_state = 117, .external_lex_state = 24},
  [11703] = {.lex_state = 117},
  [11704] = {.lex_state = 117, .external_lex_state = 24},
  [11705] = {.lex_state = 117, .external_lex_state = 24},
  [11706] = {.lex_state = 117, .external_lex_state = 24},
  [11707] = {.lex_state = 117, .external_lex_state = 24},
  [11708] = {.lex_state = 117, .external_lex_state = 24},
  [11709] = {.lex_state = 117, .external_lex_state = 24},
  [11710] = {.lex_state = 117, .external_lex_state = 24},
  [11711] = {.lex_state = 117, .external_lex_state = 24},
  [11712] = {.lex_state = 117, .external_lex_state = 24},
  [11713] = {.lex_state = 117, .external_lex_state = 24},
  [11714] = {.lex_state = 117, .external_lex_state = 24},
  [11715] = {.lex_state = 117, .external_lex_state = 24},
  [11716] = {.lex_state = 117, .external_lex_state = 24},
  [11717] = {.lex_state = 0, .external_lex_state = 22},
  [11718] = {.lex_state = 117, .external_lex_state = 24},
  [11719] = {.lex_state = 117, .external_lex_state = 24},
  [11720] = {.lex_state = 117, .external_lex_state = 24},
  [11721] = {.lex_state = 117, .external_lex_state = 24},
  [11722] = {.lex_state = 117, .external_lex_state = 24},
  [11723] = {.lex_state = 117},
  [11724] = {.lex_state = 117},
  [11725] = {.lex_state = 117, .external_lex_state = 2},
  [11726] = {.lex_state = 117, .external_lex_state = 2},
  [11727] = {.lex_state = 117, .external_lex_state = 24},
  [11728] = {.lex_state = 117, .external_lex_state = 24},
  [11729] = {.lex_state = 117, .external_lex_state = 24},
  [11730] = {.lex_state = 117},
  [11731] = {.lex_state = 117, .external_lex_state = 24},
  [11732] = {.lex_state = 117, .external_lex_state = 24},
  [11733] = {.lex_state = 117},
  [11734] = {.lex_state = 117, .external_lex_state = 24},
  [11735] = {.lex_state = 0, .external_lex_state = 22},
  [11736] = {.lex_state = 117, .external_lex_state = 24},
  [11737] = {.lex_state = 117, .external_lex_state = 24},
  [11738] = {.lex_state = 117, .external_lex_state = 2},
  [11739] = {.lex_state = 0, .external_lex_state = 22},
  [11740] = {.lex_state = 117},
  [11741] = {.lex_state = 117, .external_lex_state = 24},
  [11742] = {.lex_state = 117, .external_lex_state = 2},
  [11743] = {.lex_state = 0, .external_lex_state = 22},
  [11744] = {.lex_state = 117},
  [11745] = {.lex_state = 117, .external_lex_state = 24},
  [11746] = {.lex_state = 117, .external_lex_state = 24},
  [11747] = {.lex_state = 117, .external_lex_state = 22},
  [11748] = {.lex_state = 117, .external_lex_state = 24},
  [11749] = {.lex_state = 117, .external_lex_state = 2},
  [11750] = {.lex_state = 117, .external_lex_state = 24},
  [11751] = {.lex_state = 117},
  [11752] = {.lex_state = 117, .external_lex_state = 24},
  [11753] = {.lex_state = 117, .external_lex_state = 24},
  [11754] = {.lex_state = 117},
  [11755] = {.lex_state = 117, .external_lex_state = 24},
  [11756] = {.lex_state = 117, .external_lex_state = 24},
  [11757] = {.lex_state = 117, .external_lex_state = 24},
  [11758] = {.lex_state = 117, .external_lex_state = 24},
  [11759] = {.lex_state = 117, .external_lex_state = 2},
  [11760] = {.lex_state = 117, .external_lex_state = 24},
  [11761] = {.lex_state = 117, .external_lex_state = 24},
  [11762] = {.lex_state = 117, .external_lex_state = 24},
  [11763] = {.lex_state = 117, .external_lex_state = 2},
  [11764] = {.lex_state = 117, .external_lex_state = 22},
  [11765] = {.lex_state = 117},
  [11766] = {.lex_state = 117, .external_lex_state = 22},
  [11767] = {.lex_state = 117, .external_lex_state = 24},
  [11768] = {.lex_state = 117, .external_lex_state = 24},
  [11769] = {.lex_state = 117},
  [11770] = {.lex_state = 117},
  [11771] = {.lex_state = 117, .external_lex_state = 24},
  [11772] = {.lex_state = 117, .external_lex_state = 24},
  [11773] = {.lex_state = 117, .external_lex_state = 24},
  [11774] = {.lex_state = 117, .external_lex_state = 24},
  [11775] = {.lex_state = 117},
  [11776] = {.lex_state = 117, .external_lex_state = 24},
  [11777] = {.lex_state = 117, .external_lex_state = 24},
  [11778] = {.lex_state = 117, .external_lex_state = 24},
  [11779] = {.lex_state = 117, .external_lex_state = 24},
  [11780] = {.lex_state = 117, .external_lex_state = 24},
  [11781] = {.lex_state = 117, .external_lex_state = 24},
  [11782] = {.lex_state = 117, .external_lex_state = 24},
  [11783] = {.lex_state = 117, .external_lex_state = 24},
  [11784] = {.lex_state = 117, .external_lex_state = 24},
  [11785] = {.lex_state = 117, .external_lex_state = 2},
  [11786] = {.lex_state = 117, .external_lex_state = 24},
  [11787] = {.lex_state = 117, .external_lex_state = 24},
  [11788] = {.lex_state = 117},
  [11789] = {.lex_state = 117},
  [11790] = {.lex_state = 117},
  [11791] = {.lex_state = 117, .external_lex_state = 2},
  [11792] = {.lex_state = 117},
  [11793] = {.lex_state = 117},
  [11794] = {.lex_state = 117},
  [11795] = {.lex_state = 117, .external_lex_state = 24},
  [11796] = {.lex_state = 117},
  [11797] = {.lex_state = 117},
  [11798] = {.lex_state = 117, .external_lex_state = 24},
  [11799] = {.lex_state = 117},
  [11800] = {.lex_state = 117, .external_lex_state = 24},
  [11801] = {.lex_state = 117},
  [11802] = {.lex_state = 117, .external_lex_state = 24},
  [11803] = {.lex_state = 117},
  [11804] = {.lex_state = 117},
  [11805] = {.lex_state = 117},
  [11806] = {.lex_state = 117, .external_lex_state = 24},
  [11807] = {.lex_state = 117},
  [11808] = {.lex_state = 117},
  [11809] = {.lex_state = 117},
  [11810] = {.lex_state = 117},
  [11811] = {.lex_state = 117},
  [11812] = {.lex_state = 117, .external_lex_state = 24},
  [11813] = {.lex_state = 117, .external_lex_state = 2},
  [11814] = {.lex_state = 117, .external_lex_state = 24},
  [11815] = {.lex_state = 117},
  [11816] = {.lex_state = 117, .external_lex_state = 24},
  [11817] = {.lex_state = 117},
  [11818] = {.lex_state = 117, .external_lex_state = 24},
  [11819] = {.lex_state = 117, .external_lex_state = 24},
  [11820] = {.lex_state = 117},
  [11821] = {.lex_state = 117, .external_lex_state = 24},
  [11822] = {.lex_state = 117, .external_lex_state = 24},
  [11823] = {.lex_state = 117, .external_lex_state = 24},
  [11824] = {.lex_state = 117, .external_lex_state = 24},
  [11825] = {.lex_state = 117},
  [11826] = {.lex_state = 117},
  [11827] = {.lex_state = 117},
  [11828] = {.lex_state = 117},
  [11829] = {.lex_state = 117},
  [11830] = {.lex_state = 117, .external_lex_state = 2},
  [11831] = {.lex_state = 117},
  [11832] = {.lex_state = 117},
  [11833] = {.lex_state = 117},
  [11834] = {.lex_state = 117},
  [11835] = {.lex_state = 117},
  [11836] = {.lex_state = 117},
  [11837] = {.lex_state = 117, .external_lex_state = 24},
  [11838] = {.lex_state = 117, .external_lex_state = 24},
  [11839] = {.lex_state = 117},
  [11840] = {.lex_state = 117},
  [11841] = {.lex_state = 117},
  [11842] = {.lex_state = 117, .external_lex_state = 24},
  [11843] = {.lex_state = 117, .external_lex_state = 2},
  [11844] = {.lex_state = 117, .external_lex_state = 24},
  [11845] = {.lex_state = 117},
  [11846] = {.lex_state = 117},
  [11847] = {.lex_state = 117, .external_lex_state = 24},
  [11848] = {.lex_state = 117},
  [11849] = {.lex_state = 117},
  [11850] = {.lex_state = 117},
  [11851] = {.lex_state = 117},
  [11852] = {.lex_state = 117, .external_lex_state = 24},
  [11853] = {.lex_state = 117},
  [11854] = {.lex_state = 117},
  [11855] = {.lex_state = 117},
  [11856] = {.lex_state = 117, .external_lex_state = 24},
  [11857] = {.lex_state = 117},
  [11858] = {.lex_state = 117},
  [11859] = {.lex_state = 117},
  [11860] = {.lex_state = 117},
  [11861] = {.lex_state = 117},
  [11862] = {.lex_state = 117},
  [11863] = {.lex_state = 117},
  [11864] = {.lex_state = 117},
  [11865] = {.lex_state = 117},
  [11866] = {.lex_state = 117},
  [11867] = {.lex_state = 117},
  [11868] = {.lex_state = 117},
  [11869] = {.lex_state = 117},
  [11870] = {.lex_state = 117},
  [11871] = {.lex_state = 117},
  [11872] = {.lex_state = 117},
  [11873] = {.lex_state = 117},
  [11874] = {.lex_state = 117},
  [11875] = {.lex_state = 117},
  [11876] = {.lex_state = 117},
  [11877] = {.lex_state = 117},
  [11878] = {.lex_state = 117},
  [11879] = {.lex_state = 117},
  [11880] = {.lex_state = 117},
  [11881] = {.lex_state = 117},
  [11882] = {.lex_state = 117},
  [11883] = {.lex_state = 117},
  [11884] = {.lex_state = 117},
  [11885] = {.lex_state = 117},
  [11886] = {.lex_state = 117},
  [11887] = {.lex_state = 117},
  [11888] = {.lex_state = 117},
  [11889] = {.lex_state = 117},
  [11890] = {.lex_state = 117},
  [11891] = {.lex_state = 117},
  [11892] = {.lex_state = 117},
  [11893] = {.lex_state = 117},
  [11894] = {.lex_state = 117},
  [11895] = {.lex_state = 117},
  [11896] = {.lex_state = 117},
  [11897] = {.lex_state = 117, .external_lex_state = 24},
  [11898] = {.lex_state = 117},
  [11899] = {.lex_state = 117, .external_lex_state = 24},
  [11900] = {.lex_state = 117, .external_lex_state = 24},
  [11901] = {.lex_state = 117, .external_lex_state = 24},
  [11902] = {.lex_state = 117, .external_lex_state = 24},
  [11903] = {.lex_state = 117},
  [11904] = {.lex_state = 117},
  [11905] = {.lex_state = 117},
  [11906] = {.lex_state = 117, .external_lex_state = 24},
  [11907] = {.lex_state = 117},
  [11908] = {.lex_state = 117},
  [11909] = {.lex_state = 117},
  [11910] = {.lex_state = 117},
  [11911] = {.lex_state = 117},
  [11912] = {.lex_state = 117, .external_lex_state = 24},
  [11913] = {.lex_state = 117},
  [11914] = {.lex_state = 117},
  [11915] = {.lex_state = 117},
  [11916] = {.lex_state = 117},
  [11917] = {.lex_state = 117},
  [11918] = {.lex_state = 117},
  [11919] = {.lex_state = 117},
  [11920] = {.lex_state = 117},
  [11921] = {.lex_state = 117},
  [11922] = {.lex_state = 117},
  [11923] = {.lex_state = 117},
  [11924] = {.lex_state = 117},
  [11925] = {.lex_state = 117},
  [11926] = {.lex_state = 117},
  [11927] = {.lex_state = 117},
  [11928] = {.lex_state = 117},
  [11929] = {.lex_state = 117},
  [11930] = {.lex_state = 117},
  [11931] = {.lex_state = 117},
  [11932] = {.lex_state = 117},
  [11933] = {.lex_state = 117, .external_lex_state = 24},
  [11934] = {.lex_state = 117},
  [11935] = {.lex_state = 117},
  [11936] = {.lex_state = 117},
  [11937] = {.lex_state = 117, .external_lex_state = 24},
  [11938] = {.lex_state = 117, .external_lex_state = 2},
  [11939] = {.lex_state = 117},
  [11940] = {.lex_state = 117},
  [11941] = {.lex_state = 117},
  [11942] = {.lex_state = 117, .external_lex_state = 24},
  [11943] = {.lex_state = 117, .external_lex_state = 24},
  [11944] = {.lex_state = 117, .external_lex_state = 24},
  [11945] = {.lex_state = 117, .external_lex_state = 24},
  [11946] = {.lex_state = 117},
  [11947] = {.lex_state = 117},
  [11948] = {.lex_state = 117, .external_lex_state = 24},
  [11949] = {.lex_state = 117},
  [11950] = {.lex_state = 117},
  [11951] = {.lex_state = 117},
  [11952] = {.lex_state = 117},
  [11953] = {.lex_state = 117},
  [11954] = {.lex_state = 117, .external_lex_state = 2},
  [11955] = {.lex_state = 117},
  [11956] = {.lex_state = 117},
  [11957] = {.lex_state = 117},
  [11958] = {.lex_state = 117},
  [11959] = {.lex_state = 117},
  [11960] = {.lex_state = 117},
  [11961] = {.lex_state = 117},
  [11962] = {.lex_state = 117},
  [11963] = {.lex_state = 9},
  [11964] = {.lex_state = 117},
  [11965] = {.lex_state = 117, .external_lex_state = 24},
  [11966] = {.lex_state = 117},
  [11967] = {.lex_state = 117},
  [11968] = {.lex_state = 117},
  [11969] = {.lex_state = 117},
  [11970] = {.lex_state = 117},
  [11971] = {.lex_state = 117},
  [11972] = {.lex_state = 117},
  [11973] = {.lex_state = 117, .external_lex_state = 24},
  [11974] = {.lex_state = 117},
  [11975] = {.lex_state = 117},
  [11976] = {.lex_state = 117},
  [11977] = {.lex_state = 117, .external_lex_state = 24},
  [11978] = {.lex_state = 117, .external_lex_state = 24},
  [11979] = {.lex_state = 117},
  [11980] = {.lex_state = 117},
  [11981] = {.lex_state = 117},
  [11982] = {.lex_state = 117, .external_lex_state = 24},
  [11983] = {.lex_state = 117, .external_lex_state = 24},
  [11984] = {.lex_state = 117},
  [11985] = {.lex_state = 117},
  [11986] = {.lex_state = 117},
  [11987] = {.lex_state = 117},
  [11988] = {.lex_state = 117},
  [11989] = {.lex_state = 117, .external_lex_state = 24},
  [11990] = {.lex_state = 117},
  [11991] = {.lex_state = 117, .external_lex_state = 24},
  [11992] = {.lex_state = 117},
  [11993] = {.lex_state = 117},
  [11994] = {.lex_state = 117},
  [11995] = {.lex_state = 117},
  [11996] = {.lex_state = 117},
  [11997] = {.lex_state = 117},
  [11998] = {.lex_state = 117},
  [11999] = {.lex_state = 117},
  [12000] = {.lex_state = 117},
  [12001] = {.lex_state = 117},
  [12002] = {.lex_state = 117},
  [12003] = {.lex_state = 117},
  [12004] = {.lex_state = 117},
  [12005] = {.lex_state = 117, .external_lex_state = 24},
  [12006] = {.lex_state = 117},
  [12007] = {.lex_state = 117},
  [12008] = {.lex_state = 117, .external_lex_state = 24},
  [12009] = {.lex_state = 117, .external_lex_state = 24},
  [12010] = {.lex_state = 117},
  [12011] = {.lex_state = 117},
  [12012] = {.lex_state = 117},
  [12013] = {.lex_state = 117},
  [12014] = {.lex_state = 117, .external_lex_state = 24},
  [12015] = {.lex_state = 117},
  [12016] = {.lex_state = 117},
  [12017] = {.lex_state = 117},
  [12018] = {.lex_state = 117},
  [12019] = {.lex_state = 117},
  [12020] = {.lex_state = 117},
  [12021] = {.lex_state = 117},
  [12022] = {.lex_state = 117},
  [12023] = {.lex_state = 117},
  [12024] = {.lex_state = 117},
  [12025] = {.lex_state = 117, .external_lex_state = 24},
  [12026] = {.lex_state = 117, .external_lex_state = 24},
  [12027] = {.lex_state = 117, .external_lex_state = 24},
  [12028] = {.lex_state = 117},
  [12029] = {.lex_state = 117},
  [12030] = {.lex_state = 117},
  [12031] = {.lex_state = 117},
  [12032] = {.lex_state = 117},
  [12033] = {.lex_state = 117},
  [12034] = {.lex_state = 117},
  [12035] = {.lex_state = 117},
  [12036] = {.lex_state = 117},
  [12037] = {.lex_state = 117, .external_lex_state = 24},
  [12038] = {.lex_state = 117},
  [12039] = {.lex_state = 117},
  [12040] = {.lex_state = 117, .external_lex_state = 24},
  [12041] = {.lex_state = 117},
  [12042] = {.lex_state = 117, .external_lex_state = 24},
  [12043] = {.lex_state = 117},
  [12044] = {.lex_state = 117},
  [12045] = {.lex_state = 117},
  [12046] = {.lex_state = 117},
  [12047] = {.lex_state = 117},
  [12048] = {.lex_state = 117},
  [12049] = {.lex_state = 117},
  [12050] = {.lex_state = 117},
  [12051] = {.lex_state = 117},
  [12052] = {.lex_state = 117, .external_lex_state = 2},
  [12053] = {.lex_state = 117},
  [12054] = {.lex_state = 117},
  [12055] = {.lex_state = 117, .external_lex_state = 24},
  [12056] = {.lex_state = 117, .external_lex_state = 24},
  [12057] = {.lex_state = 117},
  [12058] = {.lex_state = 117},
  [12059] = {.lex_state = 117},
  [12060] = {.lex_state = 117, .external_lex_state = 24},
  [12061] = {.lex_state = 117},
  [12062] = {.lex_state = 117},
  [12063] = {.lex_state = 117},
  [12064] = {.lex_state = 117},
  [12065] = {.lex_state = 117},
  [12066] = {.lex_state = 117},
  [12067] = {.lex_state = 117},
  [12068] = {.lex_state = 117},
  [12069] = {.lex_state = 117},
  [12070] = {.lex_state = 117},
  [12071] = {.lex_state = 117, .external_lex_state = 2},
  [12072] = {.lex_state = 117},
  [12073] = {.lex_state = 117},
  [12074] = {.lex_state = 117, .external_lex_state = 24},
  [12075] = {.lex_state = 117},
  [12076] = {.lex_state = 117, .external_lex_state = 24},
  [12077] = {.lex_state = 117},
  [12078] = {.lex_state = 117},
  [12079] = {.lex_state = 117, .external_lex_state = 24},
  [12080] = {.lex_state = 117},
  [12081] = {.lex_state = 117, .external_lex_state = 2},
  [12082] = {.lex_state = 117},
  [12083] = {.lex_state = 117, .external_lex_state = 24},
  [12084] = {.lex_state = 117, .external_lex_state = 24},
  [12085] = {.lex_state = 117, .external_lex_state = 24},
  [12086] = {.lex_state = 117},
  [12087] = {.lex_state = 9},
  [12088] = {.lex_state = 117},
  [12089] = {.lex_state = 117},
  [12090] = {.lex_state = 117},
  [12091] = {.lex_state = 117, .external_lex_state = 24},
  [12092] = {.lex_state = 117, .external_lex_state = 24},
  [12093] = {.lex_state = 117},
  [12094] = {.lex_state = 117},
  [12095] = {.lex_state = 117, .external_lex_state = 24},
  [12096] = {.lex_state = 117},
  [12097] = {.lex_state = 117},
  [12098] = {.lex_state = 117},
  [12099] = {.lex_state = 117, .external_lex_state = 24},
  [12100] = {.lex_state = 117},
  [12101] = {.lex_state = 117},
  [12102] = {.lex_state = 117},
  [12103] = {.lex_state = 117},
  [12104] = {.lex_state = 117},
  [12105] = {.lex_state = 117},
  [12106] = {.lex_state = 117},
  [12107] = {.lex_state = 117, .external_lex_state = 2},
  [12108] = {.lex_state = 117, .external_lex_state = 24},
  [12109] = {.lex_state = 117},
  [12110] = {.lex_state = 117},
  [12111] = {.lex_state = 117},
  [12112] = {.lex_state = 117},
  [12113] = {.lex_state = 117},
  [12114] = {.lex_state = 117},
  [12115] = {.lex_state = 117},
  [12116] = {.lex_state = 117},
  [12117] = {.lex_state = 117},
  [12118] = {.lex_state = 117},
  [12119] = {.lex_state = 117, .external_lex_state = 24},
  [12120] = {.lex_state = 117},
  [12121] = {.lex_state = 117, .external_lex_state = 24},
  [12122] = {.lex_state = 117},
  [12123] = {.lex_state = 117},
  [12124] = {.lex_state = 117},
  [12125] = {.lex_state = 117, .external_lex_state = 24},
  [12126] = {.lex_state = 117},
  [12127] = {.lex_state = 117},
  [12128] = {.lex_state = 117},
  [12129] = {.lex_state = 117},
  [12130] = {.lex_state = 117},
  [12131] = {.lex_state = 117},
  [12132] = {.lex_state = 117},
  [12133] = {.lex_state = 117},
  [12134] = {.lex_state = 117},
  [12135] = {.lex_state = 117, .external_lex_state = 24},
  [12136] = {.lex_state = 117},
  [12137] = {.lex_state = 117},
  [12138] = {.lex_state = 117},
  [12139] = {.lex_state = 117},
  [12140] = {.lex_state = 117},
  [12141] = {.lex_state = 117},
  [12142] = {.lex_state = 117},
  [12143] = {.lex_state = 117},
  [12144] = {.lex_state = 117},
  [12145] = {.lex_state = 117},
  [12146] = {.lex_state = 117},
  [12147] = {.lex_state = 117},
  [12148] = {.lex_state = 117},
  [12149] = {.lex_state = 117, .external_lex_state = 24},
  [12150] = {.lex_state = 117, .external_lex_state = 24},
  [12151] = {.lex_state = 117},
  [12152] = {.lex_state = 117},
  [12153] = {.lex_state = 117},
  [12154] = {.lex_state = 117},
  [12155] = {.lex_state = 117},
  [12156] = {.lex_state = 117},
  [12157] = {.lex_state = 117},
  [12158] = {.lex_state = 117},
  [12159] = {.lex_state = 117},
  [12160] = {.lex_state = 117},
  [12161] = {.lex_state = 117},
  [12162] = {.lex_state = 117},
  [12163] = {.lex_state = 117},
  [12164] = {.lex_state = 117},
  [12165] = {.lex_state = 117},
  [12166] = {.lex_state = 117},
  [12167] = {.lex_state = 117},
  [12168] = {.lex_state = 117},
  [12169] = {.lex_state = 117},
  [12170] = {.lex_state = 117},
  [12171] = {.lex_state = 117},
  [12172] = {.lex_state = 117},
  [12173] = {.lex_state = 117},
  [12174] = {.lex_state = 117},
  [12175] = {.lex_state = 117},
  [12176] = {.lex_state = 117},
  [12177] = {.lex_state = 117, .external_lex_state = 24},
  [12178] = {.lex_state = 117},
  [12179] = {.lex_state = 117},
  [12180] = {.lex_state = 117, .external_lex_state = 24},
  [12181] = {.lex_state = 117, .external_lex_state = 24},
  [12182] = {.lex_state = 117},
  [12183] = {.lex_state = 117},
  [12184] = {.lex_state = 117, .external_lex_state = 2},
  [12185] = {.lex_state = 117},
  [12186] = {.lex_state = 117},
  [12187] = {.lex_state = 117},
  [12188] = {.lex_state = 117},
  [12189] = {.lex_state = 117},
  [12190] = {.lex_state = 117},
  [12191] = {.lex_state = 117},
  [12192] = {.lex_state = 117},
  [12193] = {.lex_state = 117},
  [12194] = {.lex_state = 117},
  [12195] = {.lex_state = 117},
  [12196] = {.lex_state = 117},
  [12197] = {.lex_state = 117},
  [12198] = {.lex_state = 117},
  [12199] = {.lex_state = 117, .external_lex_state = 24},
  [12200] = {.lex_state = 117},
  [12201] = {.lex_state = 117},
  [12202] = {.lex_state = 117},
  [12203] = {.lex_state = 117, .external_lex_state = 24},
  [12204] = {.lex_state = 117},
  [12205] = {.lex_state = 117},
  [12206] = {.lex_state = 117},
  [12207] = {.lex_state = 117},
  [12208] = {.lex_state = 117},
  [12209] = {.lex_state = 117},
  [12210] = {.lex_state = 117},
  [12211] = {.lex_state = 117},
  [12212] = {.lex_state = 117, .external_lex_state = 24},
  [12213] = {.lex_state = 117},
  [12214] = {.lex_state = 117},
  [12215] = {.lex_state = 117},
  [12216] = {.lex_state = 117},
  [12217] = {.lex_state = 117},
  [12218] = {.lex_state = 117},
  [12219] = {.lex_state = 117},
  [12220] = {.lex_state = 117},
  [12221] = {.lex_state = 117},
  [12222] = {.lex_state = 117},
  [12223] = {.lex_state = 117},
  [12224] = {.lex_state = 117},
  [12225] = {.lex_state = 117},
  [12226] = {.lex_state = 117},
  [12227] = {.lex_state = 117, .external_lex_state = 24},
  [12228] = {.lex_state = 117, .external_lex_state = 24},
  [12229] = {.lex_state = 117, .external_lex_state = 24},
  [12230] = {.lex_state = 117, .external_lex_state = 24},
  [12231] = {.lex_state = 117},
  [12232] = {.lex_state = 117},
  [12233] = {.lex_state = 117},
  [12234] = {.lex_state = 117, .external_lex_state = 24},
  [12235] = {.lex_state = 117},
  [12236] = {.lex_state = 117},
  [12237] = {.lex_state = 117, .external_lex_state = 24},
  [12238] = {.lex_state = 117},
  [12239] = {.lex_state = 117},
  [12240] = {.lex_state = 117},
  [12241] = {.lex_state = 117},
  [12242] = {.lex_state = 117, .external_lex_state = 24},
  [12243] = {.lex_state = 117},
  [12244] = {.lex_state = 117, .external_lex_state = 24},
  [12245] = {.lex_state = 117},
  [12246] = {.lex_state = 117, .external_lex_state = 24},
  [12247] = {.lex_state = 117, .external_lex_state = 24},
  [12248] = {.lex_state = 117},
  [12249] = {.lex_state = 117, .external_lex_state = 24},
  [12250] = {.lex_state = 117},
  [12251] = {.lex_state = 117},
  [12252] = {.lex_state = 117},
  [12253] = {.lex_state = 117, .external_lex_state = 24},
  [12254] = {.lex_state = 117},
  [12255] = {.lex_state = 117, .external_lex_state = 24},
  [12256] = {.lex_state = 117},
  [12257] = {.lex_state = 117},
  [12258] = {.lex_state = 117},
  [12259] = {.lex_state = 117},
  [12260] = {.lex_state = 117},
  [12261] = {.lex_state = 117},
  [12262] = {.lex_state = 117},
  [12263] = {.lex_state = 117},
  [12264] = {.lex_state = 117},
  [12265] = {.lex_state = 117},
  [12266] = {.lex_state = 117},
  [12267] = {.lex_state = 117},
  [12268] = {.lex_state = 117, .external_lex_state = 24},
  [12269] = {.lex_state = 117},
  [12270] = {.lex_state = 117, .external_lex_state = 24},
  [12271] = {.lex_state = 117},
  [12272] = {.lex_state = 117, .external_lex_state = 24},
  [12273] = {.lex_state = 117, .external_lex_state = 24},
  [12274] = {.lex_state = 117, .external_lex_state = 24},
  [12275] = {.lex_state = 117},
  [12276] = {.lex_state = 117},
  [12277] = {.lex_state = 117, .external_lex_state = 24},
  [12278] = {.lex_state = 117},
  [12279] = {.lex_state = 117},
  [12280] = {.lex_state = 117, .external_lex_state = 24},
  [12281] = {.lex_state = 117},
  [12282] = {.lex_state = 117, .external_lex_state = 24},
  [12283] = {.lex_state = 117, .external_lex_state = 24},
  [12284] = {.lex_state = 117, .external_lex_state = 24},
  [12285] = {.lex_state = 117},
  [12286] = {.lex_state = 117},
  [12287] = {.lex_state = 117, .external_lex_state = 24},
  [12288] = {.lex_state = 117},
  [12289] = {.lex_state = 117},
  [12290] = {.lex_state = 117, .external_lex_state = 24},
  [12291] = {.lex_state = 117},
  [12292] = {.lex_state = 117},
  [12293] = {.lex_state = 117, .external_lex_state = 24},
  [12294] = {.lex_state = 117, .external_lex_state = 24},
  [12295] = {.lex_state = 117, .external_lex_state = 24},
  [12296] = {.lex_state = 117},
  [12297] = {.lex_state = 117, .external_lex_state = 24},
  [12298] = {.lex_state = 117},
  [12299] = {.lex_state = 117},
  [12300] = {.lex_state = 117},
  [12301] = {.lex_state = 117, .external_lex_state = 24},
  [12302] = {.lex_state = 117},
  [12303] = {.lex_state = 117, .external_lex_state = 24},
  [12304] = {.lex_state = 117, .external_lex_state = 24},
  [12305] = {.lex_state = 117, .external_lex_state = 24},
  [12306] = {.lex_state = 117, .external_lex_state = 22},
  [12307] = {.lex_state = 117, .external_lex_state = 22},
  [12308] = {.lex_state = 117, .external_lex_state = 22},
  [12309] = {.lex_state = 117, .external_lex_state = 22},
  [12310] = {.lex_state = 117, .external_lex_state = 22},
  [12311] = {.lex_state = 117, .external_lex_state = 22},
  [12312] = {.lex_state = 117, .external_lex_state = 22},
  [12313] = {.lex_state = 117, .external_lex_state = 22},
  [12314] = {.lex_state = 117},
  [12315] = {.lex_state = 117, .external_lex_state = 24},
  [12316] = {.lex_state = 117, .external_lex_state = 24},
  [12317] = {.lex_state = 117, .external_lex_state = 24},
  [12318] = {.lex_state = 117, .external_lex_state = 24},
  [12319] = {.lex_state = 117, .external_lex_state = 2},
  [12320] = {.lex_state = 117, .external_lex_state = 24},
  [12321] = {.lex_state = 117, .external_lex_state = 24},
  [12322] = {.lex_state = 117, .external_lex_state = 24},
  [12323] = {.lex_state = 117, .external_lex_state = 22},
  [12324] = {.lex_state = 117, .external_lex_state = 2},
  [12325] = {.lex_state = 117, .external_lex_state = 24},
  [12326] = {.lex_state = 117, .external_lex_state = 24},
  [12327] = {.lex_state = 117, .external_lex_state = 24},
  [12328] = {.lex_state = 12},
  [12329] = {.lex_state = 117, .external_lex_state = 24},
  [12330] = {.lex_state = 117, .external_lex_state = 24},
  [12331] = {.lex_state = 117, .external_lex_state = 24},
  [12332] = {.lex_state = 117, .external_lex_state = 24},
  [12333] = {.lex_state = 117, .external_lex_state = 24},
  [12334] = {.lex_state = 117, .external_lex_state = 24},
  [12335] = {.lex_state = 117, .external_lex_state = 24},
  [12336] = {.lex_state = 117, .external_lex_state = 2},
  [12337] = {.lex_state = 117, .external_lex_state = 24},
  [12338] = {.lex_state = 117, .external_lex_state = 2},
  [12339] = {.lex_state = 117, .external_lex_state = 2},
  [12340] = {.lex_state = 117, .external_lex_state = 2},
  [12341] = {.lex_state = 117, .external_lex_state = 2},
  [12342] = {.lex_state = 117, .external_lex_state = 22},
  [12343] = {.lex_state = 117, .external_lex_state = 2},
  [12344] = {.lex_state = 117, .external_lex_state = 24},
  [12345] = {.lex_state = 117, .external_lex_state = 24},
  [12346] = {.lex_state = 117, .external_lex_state = 24},
  [12347] = {.lex_state = 117, .external_lex_state = 24},
  [12348] = {.lex_state = 117, .external_lex_state = 24},
  [12349] = {.lex_state = 117, .external_lex_state = 24},
  [12350] = {.lex_state = 117, .external_lex_state = 24},
  [12351] = {.lex_state = 117, .external_lex_state = 24},
  [12352] = {.lex_state = 117, .external_lex_state = 24},
  [12353] = {.lex_state = 117, .external_lex_state = 24},
  [12354] = {.lex_state = 117, .external_lex_state = 24},
  [12355] = {.lex_state = 117, .external_lex_state = 24},
  [12356] = {.lex_state = 117, .external_lex_state = 24},
  [12357] = {.lex_state = 117, .external_lex_state = 24},
  [12358] = {.lex_state = 117, .external_lex_state = 24},
  [12359] = {.lex_state = 117, .external_lex_state = 24},
  [12360] = {.lex_state = 117, .external_lex_state = 24},
  [12361] = {.lex_state = 117, .external_lex_state = 24},
  [12362] = {.lex_state = 117, .external_lex_state = 24},
  [12363] = {.lex_state = 117, .external_lex_state = 24},
  [12364] = {.lex_state = 117, .external_lex_state = 24},
  [12365] = {.lex_state = 117, .external_lex_state = 24},
  [12366] = {.lex_state = 117, .external_lex_state = 22},
  [12367] = {.lex_state = 117, .external_lex_state = 24},
  [12368] = {.lex_state = 117, .external_lex_state = 24},
  [12369] = {.lex_state = 117, .external_lex_state = 2},
  [12370] = {.lex_state = 117, .external_lex_state = 2},
  [12371] = {.lex_state = 117, .external_lex_state = 22},
  [12372] = {.lex_state = 117, .external_lex_state = 22},
  [12373] = {.lex_state = 117, .external_lex_state = 22},
  [12374] = {.lex_state = 117, .external_lex_state = 22},
  [12375] = {.lex_state = 117, .external_lex_state = 22},
  [12376] = {.lex_state = 117, .external_lex_state = 22},
  [12377] = {.lex_state = 117, .external_lex_state = 22},
  [12378] = {.lex_state = 117, .external_lex_state = 22},
  [12379] = {.lex_state = 117, .external_lex_state = 22},
  [12380] = {.lex_state = 117, .external_lex_state = 22},
  [12381] = {.lex_state = 117, .external_lex_state = 22},
  [12382] = {.lex_state = 117, .external_lex_state = 22},
  [12383] = {.lex_state = 117, .external_lex_state = 22},
  [12384] = {.lex_state = 117, .external_lex_state = 24},
  [12385] = {.lex_state = 117, .external_lex_state = 24},
  [12386] = {.lex_state = 117, .external_lex_state = 2},
  [12387] = {.lex_state = 117, .external_lex_state = 2},
  [12388] = {.lex_state = 117, .external_lex_state = 2},
  [12389] = {.lex_state = 117, .external_lex_state = 2},
  [12390] = {.lex_state = 117, .external_lex_state = 2},
  [12391] = {.lex_state = 117, .external_lex_state = 24},
  [12392] = {.lex_state = 117, .external_lex_state = 22},
  [12393] = {.lex_state = 117, .external_lex_state = 22},
  [12394] = {.lex_state = 117, .external_lex_state = 24},
  [12395] = {.lex_state = 117, .external_lex_state = 22},
  [12396] = {.lex_state = 117, .external_lex_state = 24},
  [12397] = {.lex_state = 117, .external_lex_state = 24},
  [12398] = {.lex_state = 117, .external_lex_state = 22},
  [12399] = {.lex_state = 117, .external_lex_state = 22},
  [12400] = {.lex_state = 117, .external_lex_state = 22},
  [12401] = {.lex_state = 117, .external_lex_state = 22},
  [12402] = {.lex_state = 117, .external_lex_state = 22},
  [12403] = {.lex_state = 117, .external_lex_state = 22},
  [12404] = {.lex_state = 117, .external_lex_state = 22},
  [12405] = {.lex_state = 117, .external_lex_state = 22},
  [12406] = {.lex_state = 117, .external_lex_state = 22},
  [12407] = {.lex_state = 117, .external_lex_state = 22},
  [12408] = {.lex_state = 117, .external_lex_state = 22},
  [12409] = {.lex_state = 117, .external_lex_state = 22},
  [12410] = {.lex_state = 117, .external_lex_state = 2},
  [12411] = {.lex_state = 117, .external_lex_state = 22},
  [12412] = {.lex_state = 117, .external_lex_state = 24},
  [12413] = {.lex_state = 117, .external_lex_state = 24},
  [12414] = {.lex_state = 117, .external_lex_state = 2},
  [12415] = {.lex_state = 117, .external_lex_state = 22},
  [12416] = {.lex_state = 117, .external_lex_state = 24},
  [12417] = {.lex_state = 117, .external_lex_state = 24},
  [12418] = {.lex_state = 117, .external_lex_state = 2},
  [12419] = {.lex_state = 117, .external_lex_state = 2},
  [12420] = {.lex_state = 117, .external_lex_state = 22},
  [12421] = {.lex_state = 117, .external_lex_state = 22},
  [12422] = {.lex_state = 117, .external_lex_state = 24},
  [12423] = {.lex_state = 117, .external_lex_state = 24},
  [12424] = {.lex_state = 117, .external_lex_state = 24},
  [12425] = {.lex_state = 117, .external_lex_state = 24},
  [12426] = {.lex_state = 117, .external_lex_state = 24},
  [12427] = {.lex_state = 117, .external_lex_state = 24},
  [12428] = {.lex_state = 117, .external_lex_state = 22},
  [12429] = {.lex_state = 117, .external_lex_state = 24},
  [12430] = {.lex_state = 117},
  [12431] = {.lex_state = 117, .external_lex_state = 22},
  [12432] = {.lex_state = 117, .external_lex_state = 22},
  [12433] = {.lex_state = 117, .external_lex_state = 2},
  [12434] = {.lex_state = 117, .external_lex_state = 2},
  [12435] = {.lex_state = 117, .external_lex_state = 2},
  [12436] = {.lex_state = 117, .external_lex_state = 2},
  [12437] = {.lex_state = 117, .external_lex_state = 2},
  [12438] = {.lex_state = 117},
  [12439] = {.lex_state = 117, .external_lex_state = 22},
  [12440] = {.lex_state = 117, .external_lex_state = 22},
  [12441] = {.lex_state = 117, .external_lex_state = 24},
  [12442] = {.lex_state = 117, .external_lex_state = 2},
  [12443] = {.lex_state = 117, .external_lex_state = 24},
  [12444] = {.lex_state = 117, .external_lex_state = 2},
  [12445] = {.lex_state = 117, .external_lex_state = 2},
  [12446] = {.lex_state = 117, .external_lex_state = 24},
  [12447] = {.lex_state = 117, .external_lex_state = 2},
  [12448] = {.lex_state = 117, .external_lex_state = 2},
  [12449] = {.lex_state = 117, .external_lex_state = 2},
  [12450] = {.lex_state = 117, .external_lex_state = 22},
  [12451] = {.lex_state = 117, .external_lex_state = 24},
  [12452] = {.lex_state = 117, .external_lex_state = 24},
  [12453] = {.lex_state = 117, .external_lex_state = 22},
  [12454] = {.lex_state = 117},
  [12455] = {.lex_state = 117, .external_lex_state = 24},
  [12456] = {.lex_state = 117, .external_lex_state = 24},
  [12457] = {.lex_state = 117, .external_lex_state = 24},
  [12458] = {.lex_state = 117, .external_lex_state = 24},
  [12459] = {.lex_state = 117, .external_lex_state = 24},
  [12460] = {.lex_state = 117},
  [12461] = {.lex_state = 117, .external_lex_state = 24},
  [12462] = {.lex_state = 117, .external_lex_state = 24},
  [12463] = {.lex_state = 117, .external_lex_state = 24},
  [12464] = {.lex_state = 117, .external_lex_state = 24},
  [12465] = {.lex_state = 117},
  [12466] = {.lex_state = 117, .external_lex_state = 24},
  [12467] = {.lex_state = 117, .external_lex_state = 24},
  [12468] = {.lex_state = 117, .external_lex_state = 24},
  [12469] = {.lex_state = 117, .external_lex_state = 24},
  [12470] = {.lex_state = 117},
  [12471] = {.lex_state = 117, .external_lex_state = 24},
  [12472] = {.lex_state = 117},
  [12473] = {.lex_state = 117, .external_lex_state = 24},
  [12474] = {.lex_state = 117, .external_lex_state = 24},
  [12475] = {.lex_state = 117},
  [12476] = {.lex_state = 117},
  [12477] = {.lex_state = 117, .external_lex_state = 24},
  [12478] = {.lex_state = 117, .external_lex_state = 24},
  [12479] = {.lex_state = 117},
  [12480] = {.lex_state = 117},
  [12481] = {.lex_state = 117},
  [12482] = {.lex_state = 117},
  [12483] = {.lex_state = 117},
  [12484] = {.lex_state = 117, .external_lex_state = 24},
  [12485] = {.lex_state = 117},
  [12486] = {.lex_state = 117, .external_lex_state = 24},
  [12487] = {.lex_state = 117},
  [12488] = {.lex_state = 117},
  [12489] = {.lex_state = 117, .external_lex_state = 24},
  [12490] = {.lex_state = 117, .external_lex_state = 24},
  [12491] = {.lex_state = 117, .external_lex_state = 24},
  [12492] = {.lex_state = 117},
  [12493] = {.lex_state = 117, .external_lex_state = 24},
  [12494] = {.lex_state = 117, .external_lex_state = 24},
  [12495] = {.lex_state = 117, .external_lex_state = 24},
  [12496] = {.lex_state = 117, .external_lex_state = 24},
  [12497] = {.lex_state = 117, .external_lex_state = 24},
  [12498] = {.lex_state = 117, .external_lex_state = 24},
  [12499] = {.lex_state = 117, .external_lex_state = 24},
  [12500] = {.lex_state = 117},
  [12501] = {.lex_state = 117},
  [12502] = {.lex_state = 117, .external_lex_state = 24},
  [12503] = {.lex_state = 0, .external_lex_state = 22},
  [12504] = {.lex_state = 117, .external_lex_state = 2},
  [12505] = {.lex_state = 0, .external_lex_state = 22},
  [12506] = {.lex_state = 117, .external_lex_state = 2},
  [12507] = {.lex_state = 117, .external_lex_state = 2},
  [12508] = {.lex_state = 117, .external_lex_state = 2},
  [12509] = {.lex_state = 0, .external_lex_state = 22},
  [12510] = {.lex_state = 0, .external_lex_state = 22},
  [12511] = {.lex_state = 0, .external_lex_state = 22},
  [12512] = {.lex_state = 0, .external_lex_state = 22},
  [12513] = {.lex_state = 0, .external_lex_state = 22},
  [12514] = {.lex_state = 0, .external_lex_state = 22},
  [12515] = {.lex_state = 0, .external_lex_state = 22},
  [12516] = {.lex_state = 0, .external_lex_state = 22},
  [12517] = {.lex_state = 0, .external_lex_state = 22},
  [12518] = {.lex_state = 0, .external_lex_state = 22},
  [12519] = {.lex_state = 0, .external_lex_state = 22},
  [12520] = {.lex_state = 0, .external_lex_state = 22},
  [12521] = {.lex_state = 0, .external_lex_state = 22},
  [12522] = {.lex_state = 0, .external_lex_state = 22},
  [12523] = {.lex_state = 0, .external_lex_state = 22},
  [12524] = {.lex_state = 0, .external_lex_state = 22},
  [12525] = {.lex_state = 0, .external_lex_state = 22},
  [12526] = {.lex_state = 0, .external_lex_state = 22},
  [12527] = {.lex_state = 0, .external_lex_state = 22},
  [12528] = {.lex_state = 0, .external_lex_state = 22},
  [12529] = {.lex_state = 0, .external_lex_state = 22},
  [12530] = {.lex_state = 0, .external_lex_state = 22},
  [12531] = {.lex_state = 0, .external_lex_state = 22},
  [12532] = {.lex_state = 0, .external_lex_state = 22},
  [12533] = {.lex_state = 0, .external_lex_state = 22},
  [12534] = {.lex_state = 0, .external_lex_state = 22},
  [12535] = {.lex_state = 0, .external_lex_state = 22},
  [12536] = {.lex_state = 0, .external_lex_state = 22},
  [12537] = {.lex_state = 0, .external_lex_state = 22},
  [12538] = {.lex_state = 0, .external_lex_state = 22},
  [12539] = {.lex_state = 0, .external_lex_state = 22},
  [12540] = {.lex_state = 0, .external_lex_state = 22},
  [12541] = {.lex_state = 0, .external_lex_state = 22},
  [12542] = {.lex_state = 0, .external_lex_state = 22},
  [12543] = {.lex_state = 0, .external_lex_state = 22},
  [12544] = {.lex_state = 0, .external_lex_state = 22},
  [12545] = {.lex_state = 0, .external_lex_state = 22},
  [12546] = {.lex_state = 0, .external_lex_state = 22},
  [12547] = {.lex_state = 0, .external_lex_state = 22},
  [12548] = {.lex_state = 0, .external_lex_state = 22},
  [12549] = {.lex_state = 0, .external_lex_state = 22},
  [12550] = {.lex_state = 0, .external_lex_state = 22},
  [12551] = {.lex_state = 0, .external_lex_state = 22},
  [12552] = {.lex_state = 0, .external_lex_state = 22},
  [12553] = {.lex_state = 0, .external_lex_state = 22},
  [12554] = {.lex_state = 0, .external_lex_state = 22},
  [12555] = {.lex_state = 0, .external_lex_state = 22},
  [12556] = {.lex_state = 0, .external_lex_state = 22},
  [12557] = {.lex_state = 0, .external_lex_state = 22},
  [12558] = {.lex_state = 0, .external_lex_state = 22},
  [12559] = {.lex_state = 0, .external_lex_state = 22},
  [12560] = {.lex_state = 0, .external_lex_state = 22},
  [12561] = {.lex_state = 0, .external_lex_state = 22},
  [12562] = {.lex_state = 0, .external_lex_state = 22},
  [12563] = {.lex_state = 0, .external_lex_state = 22},
  [12564] = {.lex_state = 0, .external_lex_state = 22},
  [12565] = {.lex_state = 0, .external_lex_state = 22},
  [12566] = {.lex_state = 0, .external_lex_state = 22},
  [12567] = {.lex_state = 0, .external_lex_state = 22},
  [12568] = {.lex_state = 0, .external_lex_state = 22},
  [12569] = {.lex_state = 0, .external_lex_state = 22},
  [12570] = {.lex_state = 0, .external_lex_state = 22},
  [12571] = {.lex_state = 0, .external_lex_state = 22},
  [12572] = {.lex_state = 0, .external_lex_state = 22},
  [12573] = {.lex_state = 0, .external_lex_state = 22},
  [12574] = {.lex_state = 0, .external_lex_state = 22},
  [12575] = {.lex_state = 0, .external_lex_state = 22},
  [12576] = {.lex_state = 0, .external_lex_state = 22},
  [12577] = {.lex_state = 0, .external_lex_state = 22},
  [12578] = {.lex_state = 0, .external_lex_state = 22},
  [12579] = {.lex_state = 0, .external_lex_state = 22},
  [12580] = {.lex_state = 0, .external_lex_state = 22},
  [12581] = {.lex_state = 0, .external_lex_state = 22},
  [12582] = {.lex_state = 0, .external_lex_state = 22},
  [12583] = {.lex_state = 0, .external_lex_state = 22},
  [12584] = {.lex_state = 0, .external_lex_state = 22},
  [12585] = {.lex_state = 0, .external_lex_state = 22},
  [12586] = {.lex_state = 0, .external_lex_state = 22},
  [12587] = {.lex_state = 0, .external_lex_state = 22},
  [12588] = {.lex_state = 0, .external_lex_state = 22},
  [12589] = {.lex_state = 0, .external_lex_state = 22},
  [12590] = {.lex_state = 0, .external_lex_state = 22},
  [12591] = {.lex_state = 0, .external_lex_state = 22},
  [12592] = {.lex_state = 0, .external_lex_state = 22},
  [12593] = {.lex_state = 0, .external_lex_state = 22},
  [12594] = {.lex_state = 0, .external_lex_state = 22},
  [12595] = {.lex_state = 0, .external_lex_state = 22},
  [12596] = {.lex_state = 0, .external_lex_state = 22},
  [12597] = {.lex_state = 0, .external_lex_state = 22},
  [12598] = {.lex_state = 0, .external_lex_state = 22},
  [12599] = {.lex_state = 0, .external_lex_state = 22},
  [12600] = {.lex_state = 117},
  [12601] = {.lex_state = 0, .external_lex_state = 22},
  [12602] = {.lex_state = 0, .external_lex_state = 22},
  [12603] = {.lex_state = 0, .external_lex_state = 22},
  [12604] = {.lex_state = 0, .external_lex_state = 22},
  [12605] = {.lex_state = 0, .external_lex_state = 22},
  [12606] = {.lex_state = 0, .external_lex_state = 22},
  [12607] = {.lex_state = 0, .external_lex_state = 22},
  [12608] = {.lex_state = 0, .external_lex_state = 22},
  [12609] = {.lex_state = 0, .external_lex_state = 22},
  [12610] = {.lex_state = 0, .external_lex_state = 22},
  [12611] = {.lex_state = 0, .external_lex_state = 22},
  [12612] = {.lex_state = 0, .external_lex_state = 22},
  [12613] = {.lex_state = 0, .external_lex_state = 22},
  [12614] = {.lex_state = 0, .external_lex_state = 22},
  [12615] = {.lex_state = 0, .external_lex_state = 22},
  [12616] = {.lex_state = 0, .external_lex_state = 22},
  [12617] = {.lex_state = 0, .external_lex_state = 22},
  [12618] = {.lex_state = 0, .external_lex_state = 22},
  [12619] = {.lex_state = 0, .external_lex_state = 22},
  [12620] = {.lex_state = 0, .external_lex_state = 22},
  [12621] = {.lex_state = 0, .external_lex_state = 22},
  [12622] = {.lex_state = 0, .external_lex_state = 22},
  [12623] = {.lex_state = 0, .external_lex_state = 22},
  [12624] = {.lex_state = 0, .external_lex_state = 22},
  [12625] = {.lex_state = 0, .external_lex_state = 22},
  [12626] = {.lex_state = 0, .external_lex_state = 22},
  [12627] = {.lex_state = 0, .external_lex_state = 22},
  [12628] = {.lex_state = 0, .external_lex_state = 22},
  [12629] = {.lex_state = 0, .external_lex_state = 22},
  [12630] = {.lex_state = 0, .external_lex_state = 22},
  [12631] = {.lex_state = 0, .external_lex_state = 22},
  [12632] = {.lex_state = 0, .external_lex_state = 22},
  [12633] = {.lex_state = 0, .external_lex_state = 22},
  [12634] = {.lex_state = 0, .external_lex_state = 22},
  [12635] = {.lex_state = 0, .external_lex_state = 22},
  [12636] = {.lex_state = 0, .external_lex_state = 22},
  [12637] = {.lex_state = 0, .external_lex_state = 22},
  [12638] = {.lex_state = 0, .external_lex_state = 22},
  [12639] = {.lex_state = 0, .external_lex_state = 22},
  [12640] = {.lex_state = 0, .external_lex_state = 22},
  [12641] = {.lex_state = 0, .external_lex_state = 22},
  [12642] = {.lex_state = 0, .external_lex_state = 22},
  [12643] = {.lex_state = 0, .external_lex_state = 22},
  [12644] = {.lex_state = 0, .external_lex_state = 22},
  [12645] = {.lex_state = 0, .external_lex_state = 22},
  [12646] = {.lex_state = 0, .external_lex_state = 22},
  [12647] = {.lex_state = 0, .external_lex_state = 22},
  [12648] = {.lex_state = 0, .external_lex_state = 22},
  [12649] = {.lex_state = 0, .external_lex_state = 22},
  [12650] = {.lex_state = 0, .external_lex_state = 22},
  [12651] = {.lex_state = 0, .external_lex_state = 22},
  [12652] = {.lex_state = 0, .external_lex_state = 22},
  [12653] = {.lex_state = 0, .external_lex_state = 22},
  [12654] = {.lex_state = 0, .external_lex_state = 22},
  [12655] = {.lex_state = 0, .external_lex_state = 22},
  [12656] = {.lex_state = 0, .external_lex_state = 22},
  [12657] = {.lex_state = 0, .external_lex_state = 22},
  [12658] = {.lex_state = 0, .external_lex_state = 22},
  [12659] = {.lex_state = 0, .external_lex_state = 22},
  [12660] = {.lex_state = 0, .external_lex_state = 22},
  [12661] = {.lex_state = 0, .external_lex_state = 22},
  [12662] = {.lex_state = 0, .external_lex_state = 22},
  [12663] = {.lex_state = 0, .external_lex_state = 22},
  [12664] = {.lex_state = 0, .external_lex_state = 22},
  [12665] = {.lex_state = 0, .external_lex_state = 22},
  [12666] = {.lex_state = 0, .external_lex_state = 22},
  [12667] = {.lex_state = 0, .external_lex_state = 22},
  [12668] = {.lex_state = 0, .external_lex_state = 22},
  [12669] = {.lex_state = 0, .external_lex_state = 22},
  [12670] = {.lex_state = 0, .external_lex_state = 22},
  [12671] = {.lex_state = 0, .external_lex_state = 22},
  [12672] = {.lex_state = 0, .external_lex_state = 22},
  [12673] = {.lex_state = 0, .external_lex_state = 22},
  [12674] = {.lex_state = 0, .external_lex_state = 22},
  [12675] = {.lex_state = 0, .external_lex_state = 22},
  [12676] = {.lex_state = 0, .external_lex_state = 22},
  [12677] = {.lex_state = 0, .external_lex_state = 22},
  [12678] = {.lex_state = 0, .external_lex_state = 22},
  [12679] = {.lex_state = 0, .external_lex_state = 22},
  [12680] = {.lex_state = 0, .external_lex_state = 22},
  [12681] = {.lex_state = 0, .external_lex_state = 22},
  [12682] = {.lex_state = 0, .external_lex_state = 22},
  [12683] = {.lex_state = 0, .external_lex_state = 22},
  [12684] = {.lex_state = 0, .external_lex_state = 22},
  [12685] = {.lex_state = 0, .external_lex_state = 22},
  [12686] = {.lex_state = 0, .external_lex_state = 22},
  [12687] = {.lex_state = 0, .external_lex_state = 22},
  [12688] = {.lex_state = 0, .external_lex_state = 22},
  [12689] = {.lex_state = 0, .external_lex_state = 22},
  [12690] = {.lex_state = 0, .external_lex_state = 22},
  [12691] = {.lex_state = 0, .external_lex_state = 22},
  [12692] = {.lex_state = 0, .external_lex_state = 22},
  [12693] = {.lex_state = 0, .external_lex_state = 22},
  [12694] = {.lex_state = 0, .external_lex_state = 22},
  [12695] = {.lex_state = 0, .external_lex_state = 22},
  [12696] = {.lex_state = 0, .external_lex_state = 22},
  [12697] = {.lex_state = 0, .external_lex_state = 22},
  [12698] = {.lex_state = 0, .external_lex_state = 22},
  [12699] = {.lex_state = 0, .external_lex_state = 22},
  [12700] = {.lex_state = 0, .external_lex_state = 22},
  [12701] = {.lex_state = 0, .external_lex_state = 22},
  [12702] = {.lex_state = 0, .external_lex_state = 22},
  [12703] = {.lex_state = 0, .external_lex_state = 22},
  [12704] = {.lex_state = 0, .external_lex_state = 22},
  [12705] = {.lex_state = 0, .external_lex_state = 22},
  [12706] = {.lex_state = 0, .external_lex_state = 22},
  [12707] = {.lex_state = 0, .external_lex_state = 22},
  [12708] = {.lex_state = 0, .external_lex_state = 22},
  [12709] = {.lex_state = 0, .external_lex_state = 22},
  [12710] = {.lex_state = 0, .external_lex_state = 22},
  [12711] = {.lex_state = 0, .external_lex_state = 22},
  [12712] = {.lex_state = 0, .external_lex_state = 22},
  [12713] = {.lex_state = 0, .external_lex_state = 22},
  [12714] = {.lex_state = 0, .external_lex_state = 22},
  [12715] = {.lex_state = 0, .external_lex_state = 22},
  [12716] = {.lex_state = 0, .external_lex_state = 22},
  [12717] = {.lex_state = 0, .external_lex_state = 22},
  [12718] = {.lex_state = 0, .external_lex_state = 22},
  [12719] = {.lex_state = 0, .external_lex_state = 22},
  [12720] = {.lex_state = 0, .external_lex_state = 22},
  [12721] = {.lex_state = 0, .external_lex_state = 22},
  [12722] = {.lex_state = 0, .external_lex_state = 22},
  [12723] = {.lex_state = 0, .external_lex_state = 22},
  [12724] = {.lex_state = 0, .external_lex_state = 22},
  [12725] = {.lex_state = 0, .external_lex_state = 22},
  [12726] = {.lex_state = 0, .external_lex_state = 22},
  [12727] = {.lex_state = 0, .external_lex_state = 22},
  [12728] = {.lex_state = 0, .external_lex_state = 22},
  [12729] = {.lex_state = 0, .external_lex_state = 22},
  [12730] = {.lex_state = 0, .external_lex_state = 22},
  [12731] = {.lex_state = 0, .external_lex_state = 22},
  [12732] = {.lex_state = 0, .external_lex_state = 22},
  [12733] = {.lex_state = 0, .external_lex_state = 22},
  [12734] = {.lex_state = 0, .external_lex_state = 22},
  [12735] = {.lex_state = 0, .external_lex_state = 22},
  [12736] = {.lex_state = 0, .external_lex_state = 22},
  [12737] = {.lex_state = 0, .external_lex_state = 22},
  [12738] = {.lex_state = 0, .external_lex_state = 22},
  [12739] = {.lex_state = 0, .external_lex_state = 22},
  [12740] = {.lex_state = 0, .external_lex_state = 22},
  [12741] = {.lex_state = 0, .external_lex_state = 22},
  [12742] = {.lex_state = 0, .external_lex_state = 22},
  [12743] = {.lex_state = 0, .external_lex_state = 22},
  [12744] = {.lex_state = 0, .external_lex_state = 22},
  [12745] = {.lex_state = 0, .external_lex_state = 22},
  [12746] = {.lex_state = 0, .external_lex_state = 22},
  [12747] = {.lex_state = 0, .external_lex_state = 22},
  [12748] = {.lex_state = 0, .external_lex_state = 22},
  [12749] = {.lex_state = 0, .external_lex_state = 22},
  [12750] = {.lex_state = 0, .external_lex_state = 22},
  [12751] = {.lex_state = 0, .external_lex_state = 22},
  [12752] = {.lex_state = 0, .external_lex_state = 22},
  [12753] = {.lex_state = 0, .external_lex_state = 22},
  [12754] = {.lex_state = 0, .external_lex_state = 22},
  [12755] = {.lex_state = 0, .external_lex_state = 22},
  [12756] = {.lex_state = 0, .external_lex_state = 22},
  [12757] = {.lex_state = 0, .external_lex_state = 22},
  [12758] = {.lex_state = 0, .external_lex_state = 22},
  [12759] = {.lex_state = 0, .external_lex_state = 22},
  [12760] = {.lex_state = 0, .external_lex_state = 22},
  [12761] = {.lex_state = 0, .external_lex_state = 22},
  [12762] = {.lex_state = 0, .external_lex_state = 22},
  [12763] = {.lex_state = 0, .external_lex_state = 22},
  [12764] = {.lex_state = 0, .external_lex_state = 22},
  [12765] = {.lex_state = 0, .external_lex_state = 22},
  [12766] = {.lex_state = 0, .external_lex_state = 22},
  [12767] = {.lex_state = 0, .external_lex_state = 22},
  [12768] = {.lex_state = 0, .external_lex_state = 22},
  [12769] = {.lex_state = 0, .external_lex_state = 22},
  [12770] = {.lex_state = 0, .external_lex_state = 22},
  [12771] = {.lex_state = 0, .external_lex_state = 22},
  [12772] = {.lex_state = 0, .external_lex_state = 22},
  [12773] = {.lex_state = 0, .external_lex_state = 22},
  [12774] = {.lex_state = 0, .external_lex_state = 22},
  [12775] = {.lex_state = 0, .external_lex_state = 22},
  [12776] = {.lex_state = 0, .external_lex_state = 22},
  [12777] = {.lex_state = 0, .external_lex_state = 22},
  [12778] = {.lex_state = 0, .external_lex_state = 22},
  [12779] = {.lex_state = 0, .external_lex_state = 22},
  [12780] = {.lex_state = 0, .external_lex_state = 22},
  [12781] = {.lex_state = 0, .external_lex_state = 22},
  [12782] = {.lex_state = 0, .external_lex_state = 22},
  [12783] = {.lex_state = 0, .external_lex_state = 22},
  [12784] = {.lex_state = 0, .external_lex_state = 22},
  [12785] = {.lex_state = 0, .external_lex_state = 22},
  [12786] = {.lex_state = 0, .external_lex_state = 22},
  [12787] = {.lex_state = 0, .external_lex_state = 22},
  [12788] = {.lex_state = 0, .external_lex_state = 22},
  [12789] = {.lex_state = 0, .external_lex_state = 22},
  [12790] = {.lex_state = 0, .external_lex_state = 22},
  [12791] = {.lex_state = 0, .external_lex_state = 22},
  [12792] = {.lex_state = 0, .external_lex_state = 22},
  [12793] = {.lex_state = 0, .external_lex_state = 22},
  [12794] = {.lex_state = 0, .external_lex_state = 22},
  [12795] = {.lex_state = 0, .external_lex_state = 22},
  [12796] = {.lex_state = 0, .external_lex_state = 22},
  [12797] = {.lex_state = 0, .external_lex_state = 22},
  [12798] = {.lex_state = 0, .external_lex_state = 22},
  [12799] = {.lex_state = 0, .external_lex_state = 22},
  [12800] = {.lex_state = 0, .external_lex_state = 22},
  [12801] = {.lex_state = 0, .external_lex_state = 22},
  [12802] = {.lex_state = 0, .external_lex_state = 22},
  [12803] = {.lex_state = 0, .external_lex_state = 22},
  [12804] = {.lex_state = 0, .external_lex_state = 22},
  [12805] = {.lex_state = 0, .external_lex_state = 22},
  [12806] = {.lex_state = 0, .external_lex_state = 22},
  [12807] = {.lex_state = 0, .external_lex_state = 22},
  [12808] = {.lex_state = 0, .external_lex_state = 22},
  [12809] = {.lex_state = 0, .external_lex_state = 22},
  [12810] = {.lex_state = 0, .external_lex_state = 22},
  [12811] = {.lex_state = 0, .external_lex_state = 22},
  [12812] = {.lex_state = 0, .external_lex_state = 22},
  [12813] = {.lex_state = 0, .external_lex_state = 22},
  [12814] = {.lex_state = 0, .external_lex_state = 22},
  [12815] = {.lex_state = 0, .external_lex_state = 22},
  [12816] = {.lex_state = 0, .external_lex_state = 22},
  [12817] = {.lex_state = 0, .external_lex_state = 22},
  [12818] = {.lex_state = 0, .external_lex_state = 22},
  [12819] = {.lex_state = 0, .external_lex_state = 22},
  [12820] = {.lex_state = 0, .external_lex_state = 22},
  [12821] = {.lex_state = 0, .external_lex_state = 22},
  [12822] = {.lex_state = 0, .external_lex_state = 22},
  [12823] = {.lex_state = 0, .external_lex_state = 22},
  [12824] = {.lex_state = 0, .external_lex_state = 22},
  [12825] = {.lex_state = 0, .external_lex_state = 22},
  [12826] = {.lex_state = 0, .external_lex_state = 22},
  [12827] = {.lex_state = 0, .external_lex_state = 22},
  [12828] = {.lex_state = 0, .external_lex_state = 22},
  [12829] = {.lex_state = 0, .external_lex_state = 22},
  [12830] = {.lex_state = 0, .external_lex_state = 22},
  [12831] = {.lex_state = 0, .external_lex_state = 22},
  [12832] = {.lex_state = 0, .external_lex_state = 22},
  [12833] = {.lex_state = 0, .external_lex_state = 22},
  [12834] = {.lex_state = 0, .external_lex_state = 22},
  [12835] = {.lex_state = 0, .external_lex_state = 22},
  [12836] = {.lex_state = 0, .external_lex_state = 22},
  [12837] = {.lex_state = 0, .external_lex_state = 22},
  [12838] = {.lex_state = 0, .external_lex_state = 22},
  [12839] = {.lex_state = 0, .external_lex_state = 22},
  [12840] = {.lex_state = 0, .external_lex_state = 22},
  [12841] = {.lex_state = 0, .external_lex_state = 22},
  [12842] = {.lex_state = 0, .external_lex_state = 22},
  [12843] = {.lex_state = 0, .external_lex_state = 22},
  [12844] = {.lex_state = 0, .external_lex_state = 22},
  [12845] = {.lex_state = 0, .external_lex_state = 22},
  [12846] = {.lex_state = 0, .external_lex_state = 22},
  [12847] = {.lex_state = 0, .external_lex_state = 22},
  [12848] = {.lex_state = 0, .external_lex_state = 22},
  [12849] = {.lex_state = 0, .external_lex_state = 22},
  [12850] = {.lex_state = 0, .external_lex_state = 22},
  [12851] = {.lex_state = 0, .external_lex_state = 22},
  [12852] = {.lex_state = 0, .external_lex_state = 22},
  [12853] = {.lex_state = 0, .external_lex_state = 22},
  [12854] = {.lex_state = 0, .external_lex_state = 22},
  [12855] = {.lex_state = 0, .external_lex_state = 22},
  [12856] = {.lex_state = 0, .external_lex_state = 22},
  [12857] = {.lex_state = 0, .external_lex_state = 22},
  [12858] = {.lex_state = 0, .external_lex_state = 22},
  [12859] = {.lex_state = 0, .external_lex_state = 22},
  [12860] = {.lex_state = 0, .external_lex_state = 22},
  [12861] = {.lex_state = 0, .external_lex_state = 22},
  [12862] = {.lex_state = 0, .external_lex_state = 22},
  [12863] = {.lex_state = 0, .external_lex_state = 22},
  [12864] = {.lex_state = 0, .external_lex_state = 22},
  [12865] = {.lex_state = 0, .external_lex_state = 22},
  [12866] = {.lex_state = 0, .external_lex_state = 22},
  [12867] = {.lex_state = 0, .external_lex_state = 22},
  [12868] = {.lex_state = 0, .external_lex_state = 22},
  [12869] = {.lex_state = 0, .external_lex_state = 22},
  [12870] = {.lex_state = 0, .external_lex_state = 22},
  [12871] = {.lex_state = 0, .external_lex_state = 22},
  [12872] = {.lex_state = 0, .external_lex_state = 22},
  [12873] = {.lex_state = 0, .external_lex_state = 22},
  [12874] = {.lex_state = 0, .external_lex_state = 22},
  [12875] = {.lex_state = 0, .external_lex_state = 22},
  [12876] = {.lex_state = 0, .external_lex_state = 22},
  [12877] = {.lex_state = 0, .external_lex_state = 22},
  [12878] = {.lex_state = 0, .external_lex_state = 22},
  [12879] = {.lex_state = 117, .external_lex_state = 2},
  [12880] = {.lex_state = 0, .external_lex_state = 22},
  [12881] = {.lex_state = 0, .external_lex_state = 22},
  [12882] = {.lex_state = 117},
  [12883] = {.lex_state = 0, .external_lex_state = 22},
  [12884] = {.lex_state = 0, .external_lex_state = 22},
  [12885] = {.lex_state = 0, .external_lex_state = 22},
  [12886] = {.lex_state = 0, .external_lex_state = 22},
  [12887] = {.lex_state = 0, .external_lex_state = 22},
  [12888] = {.lex_state = 0, .external_lex_state = 22},
  [12889] = {.lex_state = 0, .external_lex_state = 22},
  [12890] = {.lex_state = 0, .external_lex_state = 22},
  [12891] = {.lex_state = 0, .external_lex_state = 22},
  [12892] = {.lex_state = 0, .external_lex_state = 22},
  [12893] = {.lex_state = 0, .external_lex_state = 22},
  [12894] = {.lex_state = 0, .external_lex_state = 22},
  [12895] = {.lex_state = 0, .external_lex_state = 22},
  [12896] = {.lex_state = 0, .external_lex_state = 22},
  [12897] = {.lex_state = 0, .external_lex_state = 22},
  [12898] = {.lex_state = 0, .external_lex_state = 22},
  [12899] = {.lex_state = 0, .external_lex_state = 22},
  [12900] = {.lex_state = 0, .external_lex_state = 22},
  [12901] = {.lex_state = 0, .external_lex_state = 22},
  [12902] = {.lex_state = 0, .external_lex_state = 22},
  [12903] = {.lex_state = 0, .external_lex_state = 22},
  [12904] = {.lex_state = 0, .external_lex_state = 22},
  [12905] = {.lex_state = 0, .external_lex_state = 22},
  [12906] = {.lex_state = 0, .external_lex_state = 22},
  [12907] = {.lex_state = 0, .external_lex_state = 22},
  [12908] = {.lex_state = 0, .external_lex_state = 22},
  [12909] = {.lex_state = 0, .external_lex_state = 22},
  [12910] = {.lex_state = 0, .external_lex_state = 22},
  [12911] = {.lex_state = 0, .external_lex_state = 22},
  [12912] = {.lex_state = 0, .external_lex_state = 22},
  [12913] = {.lex_state = 0, .external_lex_state = 22},
  [12914] = {.lex_state = 0, .external_lex_state = 22},
  [12915] = {.lex_state = 0, .external_lex_state = 22},
  [12916] = {.lex_state = 117},
  [12917] = {.lex_state = 0, .external_lex_state = 22},
  [12918] = {.lex_state = 0, .external_lex_state = 22},
  [12919] = {.lex_state = 0, .external_lex_state = 22},
  [12920] = {.lex_state = 0, .external_lex_state = 22},
  [12921] = {.lex_state = 0, .external_lex_state = 22},
  [12922] = {.lex_state = 0, .external_lex_state = 22},
  [12923] = {.lex_state = 0, .external_lex_state = 22},
  [12924] = {.lex_state = 0, .external_lex_state = 22},
  [12925] = {.lex_state = 0, .external_lex_state = 22},
  [12926] = {.lex_state = 0, .external_lex_state = 22},
  [12927] = {.lex_state = 0, .external_lex_state = 22},
  [12928] = {.lex_state = 0, .external_lex_state = 22},
  [12929] = {.lex_state = 0, .external_lex_state = 22},
  [12930] = {.lex_state = 0, .external_lex_state = 22},
  [12931] = {.lex_state = 0, .external_lex_state = 22},
  [12932] = {.lex_state = 0, .external_lex_state = 22},
  [12933] = {.lex_state = 0, .external_lex_state = 22},
  [12934] = {.lex_state = 0, .external_lex_state = 22},
  [12935] = {.lex_state = 0, .external_lex_state = 22},
  [12936] = {.lex_state = 0, .external_lex_state = 22},
  [12937] = {.lex_state = 0, .external_lex_state = 22},
  [12938] = {.lex_state = 0, .external_lex_state = 22},
  [12939] = {.lex_state = 0, .external_lex_state = 22},
  [12940] = {.lex_state = 0, .external_lex_state = 22},
  [12941] = {.lex_state = 0, .external_lex_state = 22},
  [12942] = {.lex_state = 0, .external_lex_state = 22},
  [12943] = {.lex_state = 0, .external_lex_state = 22},
  [12944] = {.lex_state = 0, .external_lex_state = 22},
  [12945] = {.lex_state = 0, .external_lex_state = 22},
  [12946] = {.lex_state = 0, .external_lex_state = 22},
  [12947] = {.lex_state = 0, .external_lex_state = 22},
  [12948] = {.lex_state = 0, .external_lex_state = 22},
  [12949] = {.lex_state = 0, .external_lex_state = 22},
  [12950] = {.lex_state = 0, .external_lex_state = 22},
  [12951] = {.lex_state = 0, .external_lex_state = 22},
  [12952] = {.lex_state = 0, .external_lex_state = 22},
  [12953] = {.lex_state = 0, .external_lex_state = 22},
  [12954] = {.lex_state = 0, .external_lex_state = 22},
  [12955] = {.lex_state = 0, .external_lex_state = 22},
  [12956] = {.lex_state = 0, .external_lex_state = 22},
  [12957] = {.lex_state = 0, .external_lex_state = 22},
  [12958] = {.lex_state = 0, .external_lex_state = 22},
  [12959] = {.lex_state = 0, .external_lex_state = 22},
  [12960] = {.lex_state = 0, .external_lex_state = 22},
  [12961] = {.lex_state = 0, .external_lex_state = 22},
  [12962] = {.lex_state = 0, .external_lex_state = 22},
  [12963] = {.lex_state = 0, .external_lex_state = 22},
  [12964] = {.lex_state = 0, .external_lex_state = 22},
  [12965] = {.lex_state = 117},
  [12966] = {.lex_state = 0, .external_lex_state = 22},
  [12967] = {.lex_state = 0, .external_lex_state = 22},
  [12968] = {.lex_state = 0, .external_lex_state = 22},
  [12969] = {.lex_state = 0, .external_lex_state = 22},
  [12970] = {.lex_state = 0, .external_lex_state = 22},
  [12971] = {.lex_state = 0, .external_lex_state = 22},
  [12972] = {.lex_state = 0, .external_lex_state = 22},
  [12973] = {.lex_state = 0, .external_lex_state = 22},
  [12974] = {.lex_state = 0, .external_lex_state = 22},
  [12975] = {.lex_state = 0, .external_lex_state = 22},
  [12976] = {.lex_state = 0, .external_lex_state = 22},
  [12977] = {.lex_state = 0, .external_lex_state = 22},
  [12978] = {.lex_state = 0, .external_lex_state = 22},
  [12979] = {.lex_state = 0, .external_lex_state = 22},
  [12980] = {.lex_state = 0, .external_lex_state = 22},
  [12981] = {.lex_state = 0, .external_lex_state = 22},
  [12982] = {.lex_state = 0, .external_lex_state = 22},
  [12983] = {.lex_state = 0, .external_lex_state = 22},
  [12984] = {.lex_state = 0, .external_lex_state = 22},
  [12985] = {.lex_state = 0, .external_lex_state = 22},
  [12986] = {.lex_state = 0, .external_lex_state = 22},
  [12987] = {.lex_state = 0, .external_lex_state = 22},
  [12988] = {.lex_state = 0, .external_lex_state = 22},
  [12989] = {.lex_state = 0, .external_lex_state = 22},
  [12990] = {.lex_state = 0, .external_lex_state = 22},
  [12991] = {.lex_state = 0, .external_lex_state = 22},
  [12992] = {.lex_state = 0, .external_lex_state = 22},
  [12993] = {.lex_state = 0, .external_lex_state = 22},
  [12994] = {.lex_state = 0, .external_lex_state = 22},
  [12995] = {.lex_state = 0, .external_lex_state = 22},
  [12996] = {.lex_state = 0, .external_lex_state = 22},
  [12997] = {.lex_state = 0, .external_lex_state = 22},
  [12998] = {.lex_state = 0, .external_lex_state = 22},
  [12999] = {.lex_state = 0, .external_lex_state = 22},
  [13000] = {.lex_state = 6, .external_lex_state = 2},
  [13001] = {.lex_state = 0, .external_lex_state = 22},
  [13002] = {.lex_state = 117},
  [13003] = {.lex_state = 0, .external_lex_state = 22},
  [13004] = {.lex_state = 0, .external_lex_state = 22},
  [13005] = {.lex_state = 0, .external_lex_state = 22},
  [13006] = {.lex_state = 0, .external_lex_state = 22},
  [13007] = {.lex_state = 0, .external_lex_state = 22},
  [13008] = {.lex_state = 0, .external_lex_state = 22},
  [13009] = {.lex_state = 0, .external_lex_state = 22},
  [13010] = {.lex_state = 0, .external_lex_state = 22},
  [13011] = {.lex_state = 0, .external_lex_state = 22},
  [13012] = {.lex_state = 0, .external_lex_state = 22},
  [13013] = {.lex_state = 0, .external_lex_state = 22},
  [13014] = {.lex_state = 0, .external_lex_state = 22},
  [13015] = {.lex_state = 0, .external_lex_state = 22},
  [13016] = {.lex_state = 0, .external_lex_state = 22},
  [13017] = {.lex_state = 0, .external_lex_state = 22},
  [13018] = {.lex_state = 0, .external_lex_state = 22},
  [13019] = {.lex_state = 0, .external_lex_state = 22},
  [13020] = {.lex_state = 0, .external_lex_state = 22},
  [13021] = {.lex_state = 0, .external_lex_state = 22},
  [13022] = {.lex_state = 0, .external_lex_state = 22},
  [13023] = {.lex_state = 0, .external_lex_state = 22},
  [13024] = {.lex_state = 0, .external_lex_state = 22},
  [13025] = {.lex_state = 0, .external_lex_state = 22},
  [13026] = {.lex_state = 0, .external_lex_state = 22},
  [13027] = {.lex_state = 0, .external_lex_state = 22},
  [13028] = {.lex_state = 0, .external_lex_state = 22},
  [13029] = {.lex_state = 0, .external_lex_state = 22},
  [13030] = {.lex_state = 0, .external_lex_state = 22},
  [13031] = {.lex_state = 0, .external_lex_state = 22},
  [13032] = {.lex_state = 0, .external_lex_state = 22},
  [13033] = {.lex_state = 0, .external_lex_state = 22},
  [13034] = {.lex_state = 0, .external_lex_state = 22},
  [13035] = {.lex_state = 0, .external_lex_state = 22},
  [13036] = {.lex_state = 0, .external_lex_state = 22},
  [13037] = {.lex_state = 0, .external_lex_state = 22},
  [13038] = {.lex_state = 0, .external_lex_state = 22},
  [13039] = {.lex_state = 0, .external_lex_state = 22},
  [13040] = {.lex_state = 0, .external_lex_state = 22},
  [13041] = {.lex_state = 0, .external_lex_state = 22},
  [13042] = {.lex_state = 0, .external_lex_state = 22},
  [13043] = {.lex_state = 0, .external_lex_state = 22},
  [13044] = {.lex_state = 0, .external_lex_state = 22},
  [13045] = {.lex_state = 0, .external_lex_state = 22},
  [13046] = {.lex_state = 0, .external_lex_state = 22},
  [13047] = {.lex_state = 0, .external_lex_state = 22},
  [13048] = {.lex_state = 0, .external_lex_state = 22},
  [13049] = {.lex_state = 0, .external_lex_state = 22},
  [13050] = {.lex_state = 0, .external_lex_state = 22},
  [13051] = {.lex_state = 0, .external_lex_state = 22},
  [13052] = {.lex_state = 0, .external_lex_state = 22},
  [13053] = {.lex_state = 0, .external_lex_state = 22},
  [13054] = {.lex_state = 0, .external_lex_state = 22},
  [13055] = {.lex_state = 0, .external_lex_state = 22},
  [13056] = {.lex_state = 0, .external_lex_state = 22},
  [13057] = {.lex_state = 0, .external_lex_state = 22},
  [13058] = {.lex_state = 0, .external_lex_state = 22},
  [13059] = {.lex_state = 0, .external_lex_state = 22},
  [13060] = {.lex_state = 0, .external_lex_state = 22},
  [13061] = {.lex_state = 0, .external_lex_state = 22},
  [13062] = {.lex_state = 0, .external_lex_state = 22},
  [13063] = {.lex_state = 0, .external_lex_state = 22},
  [13064] = {.lex_state = 0, .external_lex_state = 22},
  [13065] = {.lex_state = 0, .external_lex_state = 22},
  [13066] = {.lex_state = 0, .external_lex_state = 22},
  [13067] = {.lex_state = 0, .external_lex_state = 22},
  [13068] = {.lex_state = 0, .external_lex_state = 22},
  [13069] = {.lex_state = 0, .external_lex_state = 22},
  [13070] = {.lex_state = 0, .external_lex_state = 22},
  [13071] = {.lex_state = 0, .external_lex_state = 22},
  [13072] = {.lex_state = 0, .external_lex_state = 22},
  [13073] = {.lex_state = 0, .external_lex_state = 22},
  [13074] = {.lex_state = 0, .external_lex_state = 22},
  [13075] = {.lex_state = 0, .external_lex_state = 22},
  [13076] = {.lex_state = 0, .external_lex_state = 22},
  [13077] = {.lex_state = 0, .external_lex_state = 22},
  [13078] = {.lex_state = 0, .external_lex_state = 22},
  [13079] = {.lex_state = 0, .external_lex_state = 22},
  [13080] = {.lex_state = 0, .external_lex_state = 22},
  [13081] = {.lex_state = 0, .external_lex_state = 22},
  [13082] = {.lex_state = 0, .external_lex_state = 22},
  [13083] = {.lex_state = 0, .external_lex_state = 22},
  [13084] = {.lex_state = 0, .external_lex_state = 22},
  [13085] = {.lex_state = 0, .external_lex_state = 22},
  [13086] = {.lex_state = 0, .external_lex_state = 22},
  [13087] = {.lex_state = 0, .external_lex_state = 22},
  [13088] = {.lex_state = 0, .external_lex_state = 22},
  [13089] = {.lex_state = 0, .external_lex_state = 22},
  [13090] = {.lex_state = 0, .external_lex_state = 22},
  [13091] = {.lex_state = 0, .external_lex_state = 22},
  [13092] = {.lex_state = 0, .external_lex_state = 22},
  [13093] = {.lex_state = 0, .external_lex_state = 22},
  [13094] = {.lex_state = 0, .external_lex_state = 22},
  [13095] = {.lex_state = 0, .external_lex_state = 22},
  [13096] = {.lex_state = 0, .external_lex_state = 22},
  [13097] = {.lex_state = 0, .external_lex_state = 22},
  [13098] = {.lex_state = 0, .external_lex_state = 22},
  [13099] = {.lex_state = 0, .external_lex_state = 22},
  [13100] = {.lex_state = 0, .external_lex_state = 22},
  [13101] = {.lex_state = 0, .external_lex_state = 22},
  [13102] = {.lex_state = 0, .external_lex_state = 22},
  [13103] = {.lex_state = 0, .external_lex_state = 22},
  [13104] = {.lex_state = 0, .external_lex_state = 22},
  [13105] = {.lex_state = 0, .external_lex_state = 22},
  [13106] = {.lex_state = 0, .external_lex_state = 22},
  [13107] = {.lex_state = 0, .external_lex_state = 22},
  [13108] = {.lex_state = 0, .external_lex_state = 22},
  [13109] = {.lex_state = 0, .external_lex_state = 22},
  [13110] = {.lex_state = 0, .external_lex_state = 22},
  [13111] = {.lex_state = 0, .external_lex_state = 22},
  [13112] = {.lex_state = 0, .external_lex_state = 22},
  [13113] = {.lex_state = 0, .external_lex_state = 22},
  [13114] = {.lex_state = 0, .external_lex_state = 22},
  [13115] = {.lex_state = 0, .external_lex_state = 22},
  [13116] = {.lex_state = 0, .external_lex_state = 22},
  [13117] = {.lex_state = 0, .external_lex_state = 22},
  [13118] = {.lex_state = 0, .external_lex_state = 22},
  [13119] = {.lex_state = 0, .external_lex_state = 22},
  [13120] = {.lex_state = 0, .external_lex_state = 22},
  [13121] = {.lex_state = 0, .external_lex_state = 22},
  [13122] = {.lex_state = 0, .external_lex_state = 22},
  [13123] = {.lex_state = 0, .external_lex_state = 22},
  [13124] = {.lex_state = 0, .external_lex_state = 22},
  [13125] = {.lex_state = 0, .external_lex_state = 22},
  [13126] = {.lex_state = 0, .external_lex_state = 22},
  [13127] = {.lex_state = 0, .external_lex_state = 22},
  [13128] = {.lex_state = 0, .external_lex_state = 22},
  [13129] = {.lex_state = 0, .external_lex_state = 22},
  [13130] = {.lex_state = 0, .external_lex_state = 22},
  [13131] = {.lex_state = 0, .external_lex_state = 22},
  [13132] = {.lex_state = 0, .external_lex_state = 22},
  [13133] = {.lex_state = 0, .external_lex_state = 22},
  [13134] = {.lex_state = 0, .external_lex_state = 22},
  [13135] = {.lex_state = 0, .external_lex_state = 22},
  [13136] = {.lex_state = 0, .external_lex_state = 22},
  [13137] = {.lex_state = 0, .external_lex_state = 22},
  [13138] = {.lex_state = 0, .external_lex_state = 22},
  [13139] = {.lex_state = 0, .external_lex_state = 22},
  [13140] = {.lex_state = 0, .external_lex_state = 22},
  [13141] = {.lex_state = 0, .external_lex_state = 22},
  [13142] = {.lex_state = 0, .external_lex_state = 22},
  [13143] = {.lex_state = 0, .external_lex_state = 22},
  [13144] = {.lex_state = 0, .external_lex_state = 22},
  [13145] = {.lex_state = 0, .external_lex_state = 22},
  [13146] = {.lex_state = 0, .external_lex_state = 22},
  [13147] = {.lex_state = 0, .external_lex_state = 22},
  [13148] = {.lex_state = 0, .external_lex_state = 22},
  [13149] = {.lex_state = 0, .external_lex_state = 22},
  [13150] = {.lex_state = 0, .external_lex_state = 22},
  [13151] = {.lex_state = 0, .external_lex_state = 22},
  [13152] = {.lex_state = 0, .external_lex_state = 22},
  [13153] = {.lex_state = 0, .external_lex_state = 22},
  [13154] = {.lex_state = 0, .external_lex_state = 22},
  [13155] = {.lex_state = 0, .external_lex_state = 22},
  [13156] = {.lex_state = 0, .external_lex_state = 22},
  [13157] = {.lex_state = 0, .external_lex_state = 22},
  [13158] = {.lex_state = 117},
  [13159] = {.lex_state = 0, .external_lex_state = 22},
  [13160] = {.lex_state = 117},
  [13161] = {.lex_state = 0, .external_lex_state = 22},
  [13162] = {.lex_state = 0, .external_lex_state = 22},
  [13163] = {.lex_state = 0, .external_lex_state = 22},
  [13164] = {.lex_state = 0, .external_lex_state = 22},
  [13165] = {.lex_state = 0, .external_lex_state = 22},
  [13166] = {.lex_state = 0, .external_lex_state = 22},
  [13167] = {.lex_state = 0, .external_lex_state = 22},
  [13168] = {.lex_state = 117},
  [13169] = {.lex_state = 0, .external_lex_state = 22},
  [13170] = {.lex_state = 117},
  [13171] = {.lex_state = 117, .external_lex_state = 2},
  [13172] = {.lex_state = 0, .external_lex_state = 22},
  [13173] = {.lex_state = 0, .external_lex_state = 22},
  [13174] = {.lex_state = 0, .external_lex_state = 22},
  [13175] = {.lex_state = 0, .external_lex_state = 22},
  [13176] = {.lex_state = 117, .external_lex_state = 2},
  [13177] = {.lex_state = 0, .external_lex_state = 22},
  [13178] = {.lex_state = 117},
  [13179] = {.lex_state = 0, .external_lex_state = 22},
  [13180] = {.lex_state = 117},
  [13181] = {.lex_state = 0, .external_lex_state = 22},
  [13182] = {.lex_state = 0, .external_lex_state = 22},
  [13183] = {.lex_state = 0, .external_lex_state = 22},
  [13184] = {.lex_state = 0, .external_lex_state = 22},
  [13185] = {.lex_state = 0, .external_lex_state = 22},
  [13186] = {.lex_state = 0, .external_lex_state = 22},
  [13187] = {.lex_state = 0, .external_lex_state = 22},
  [13188] = {.lex_state = 0, .external_lex_state = 22},
  [13189] = {.lex_state = 0, .external_lex_state = 22},
  [13190] = {.lex_state = 0, .external_lex_state = 22},
  [13191] = {.lex_state = 0, .external_lex_state = 22},
  [13192] = {.lex_state = 0, .external_lex_state = 22},
  [13193] = {.lex_state = 0, .external_lex_state = 22},
  [13194] = {.lex_state = 0, .external_lex_state = 22},
  [13195] = {.lex_state = 117},
  [13196] = {.lex_state = 0, .external_lex_state = 22},
  [13197] = {.lex_state = 117},
  [13198] = {.lex_state = 0, .external_lex_state = 22},
  [13199] = {.lex_state = 0, .external_lex_state = 22},
  [13200] = {.lex_state = 0, .external_lex_state = 22},
  [13201] = {.lex_state = 0, .external_lex_state = 22},
  [13202] = {.lex_state = 0, .external_lex_state = 22},
  [13203] = {.lex_state = 0, .external_lex_state = 22},
  [13204] = {.lex_state = 117},
  [13205] = {.lex_state = 117},
  [13206] = {.lex_state = 0, .external_lex_state = 22},
  [13207] = {.lex_state = 0, .external_lex_state = 22},
  [13208] = {.lex_state = 0, .external_lex_state = 22},
  [13209] = {.lex_state = 0, .external_lex_state = 22},
  [13210] = {.lex_state = 0, .external_lex_state = 22},
  [13211] = {.lex_state = 0, .external_lex_state = 22},
  [13212] = {.lex_state = 0, .external_lex_state = 22},
  [13213] = {.lex_state = 0, .external_lex_state = 22},
  [13214] = {.lex_state = 0, .external_lex_state = 22},
  [13215] = {.lex_state = 0, .external_lex_state = 22},
  [13216] = {.lex_state = 117},
  [13217] = {.lex_state = 117},
  [13218] = {.lex_state = 0, .external_lex_state = 22},
  [13219] = {.lex_state = 0, .external_lex_state = 22},
  [13220] = {.lex_state = 0, .external_lex_state = 22},
  [13221] = {.lex_state = 0, .external_lex_state = 22},
  [13222] = {.lex_state = 0, .external_lex_state = 22},
  [13223] = {.lex_state = 117},
  [13224] = {.lex_state = 117},
  [13225] = {.lex_state = 0, .external_lex_state = 22},
  [13226] = {.lex_state = 117},
  [13227] = {.lex_state = 117},
  [13228] = {.lex_state = 0, .external_lex_state = 22},
  [13229] = {.lex_state = 0, .external_lex_state = 22},
  [13230] = {.lex_state = 117},
  [13231] = {.lex_state = 117},
  [13232] = {.lex_state = 117},
  [13233] = {.lex_state = 117},
  [13234] = {.lex_state = 117},
  [13235] = {.lex_state = 117},
  [13236] = {.lex_state = 0, .external_lex_state = 22},
  [13237] = {.lex_state = 0, .external_lex_state = 22},
  [13238] = {.lex_state = 0, .external_lex_state = 22},
  [13239] = {.lex_state = 0, .external_lex_state = 22},
  [13240] = {.lex_state = 0, .external_lex_state = 22},
  [13241] = {.lex_state = 0, .external_lex_state = 22},
  [13242] = {.lex_state = 0, .external_lex_state = 22},
  [13243] = {.lex_state = 0, .external_lex_state = 22},
  [13244] = {.lex_state = 0, .external_lex_state = 22},
  [13245] = {.lex_state = 0, .external_lex_state = 22},
  [13246] = {.lex_state = 0, .external_lex_state = 22},
  [13247] = {.lex_state = 0, .external_lex_state = 22},
  [13248] = {.lex_state = 0, .external_lex_state = 22},
  [13249] = {.lex_state = 0, .external_lex_state = 22},
  [13250] = {.lex_state = 0, .external_lex_state = 22},
  [13251] = {.lex_state = 0, .external_lex_state = 22},
  [13252] = {.lex_state = 0, .external_lex_state = 22},
  [13253] = {.lex_state = 0, .external_lex_state = 22},
  [13254] = {.lex_state = 117},
  [13255] = {.lex_state = 0, .external_lex_state = 22},
  [13256] = {.lex_state = 0, .external_lex_state = 22},
  [13257] = {.lex_state = 0, .external_lex_state = 22},
  [13258] = {.lex_state = 0, .external_lex_state = 22},
  [13259] = {.lex_state = 0, .external_lex_state = 22},
  [13260] = {.lex_state = 0, .external_lex_state = 22},
  [13261] = {.lex_state = 0, .external_lex_state = 22},
  [13262] = {.lex_state = 0, .external_lex_state = 22},
  [13263] = {.lex_state = 0, .external_lex_state = 22},
  [13264] = {.lex_state = 0, .external_lex_state = 22},
  [13265] = {.lex_state = 0, .external_lex_state = 22},
  [13266] = {.lex_state = 0, .external_lex_state = 22},
  [13267] = {.lex_state = 0, .external_lex_state = 22},
  [13268] = {.lex_state = 0, .external_lex_state = 22},
  [13269] = {.lex_state = 0, .external_lex_state = 22},
  [13270] = {.lex_state = 0, .external_lex_state = 22},
  [13271] = {.lex_state = 0, .external_lex_state = 22},
  [13272] = {.lex_state = 0, .external_lex_state = 22},
  [13273] = {.lex_state = 0, .external_lex_state = 22},
  [13274] = {.lex_state = 0, .external_lex_state = 22},
  [13275] = {.lex_state = 0, .external_lex_state = 22},
  [13276] = {.lex_state = 0, .external_lex_state = 22},
  [13277] = {.lex_state = 0, .external_lex_state = 22},
  [13278] = {.lex_state = 0, .external_lex_state = 22},
  [13279] = {.lex_state = 0, .external_lex_state = 22},
  [13280] = {.lex_state = 0, .external_lex_state = 22},
  [13281] = {.lex_state = 0, .external_lex_state = 22},
  [13282] = {.lex_state = 0, .external_lex_state = 22},
  [13283] = {.lex_state = 0, .external_lex_state = 22},
  [13284] = {.lex_state = 0, .external_lex_state = 22},
  [13285] = {.lex_state = 0, .external_lex_state = 22},
  [13286] = {.lex_state = 0, .external_lex_state = 22},
  [13287] = {.lex_state = 0, .external_lex_state = 22},
  [13288] = {.lex_state = 0, .external_lex_state = 22},
  [13289] = {.lex_state = 0, .external_lex_state = 22},
  [13290] = {.lex_state = 0, .external_lex_state = 22},
  [13291] = {.lex_state = 0, .external_lex_state = 22},
  [13292] = {.lex_state = 0, .external_lex_state = 22},
  [13293] = {.lex_state = 0, .external_lex_state = 22},
  [13294] = {.lex_state = 0, .external_lex_state = 22},
  [13295] = {.lex_state = 0, .external_lex_state = 22},
  [13296] = {.lex_state = 0, .external_lex_state = 22},
  [13297] = {.lex_state = 0, .external_lex_state = 22},
  [13298] = {.lex_state = 0, .external_lex_state = 22},
  [13299] = {.lex_state = 0, .external_lex_state = 22},
  [13300] = {.lex_state = 0, .external_lex_state = 22},
  [13301] = {.lex_state = 0, .external_lex_state = 22},
  [13302] = {.lex_state = 0, .external_lex_state = 22},
  [13303] = {.lex_state = 117, .external_lex_state = 2},
  [13304] = {.lex_state = 0, .external_lex_state = 22},
  [13305] = {.lex_state = 0, .external_lex_state = 22},
  [13306] = {.lex_state = 0, .external_lex_state = 22},
  [13307] = {.lex_state = 0, .external_lex_state = 22},
  [13308] = {.lex_state = 0, .external_lex_state = 22},
  [13309] = {.lex_state = 0, .external_lex_state = 22},
  [13310] = {.lex_state = 0, .external_lex_state = 22},
  [13311] = {.lex_state = 0, .external_lex_state = 22},
  [13312] = {.lex_state = 0, .external_lex_state = 22},
  [13313] = {.lex_state = 117},
  [13314] = {.lex_state = 0, .external_lex_state = 22},
  [13315] = {.lex_state = 0, .external_lex_state = 22},
  [13316] = {.lex_state = 0, .external_lex_state = 22},
  [13317] = {.lex_state = 0, .external_lex_state = 22},
  [13318] = {.lex_state = 117},
  [13319] = {.lex_state = 0, .external_lex_state = 22},
  [13320] = {.lex_state = 0, .external_lex_state = 22},
  [13321] = {.lex_state = 0, .external_lex_state = 22},
  [13322] = {.lex_state = 0, .external_lex_state = 22},
  [13323] = {.lex_state = 0, .external_lex_state = 22},
  [13324] = {.lex_state = 0, .external_lex_state = 22},
  [13325] = {.lex_state = 0, .external_lex_state = 22},
  [13326] = {.lex_state = 0, .external_lex_state = 22},
  [13327] = {.lex_state = 0, .external_lex_state = 22},
  [13328] = {.lex_state = 0, .external_lex_state = 22},
  [13329] = {.lex_state = 0, .external_lex_state = 22},
  [13330] = {.lex_state = 0, .external_lex_state = 22},
  [13331] = {.lex_state = 0, .external_lex_state = 22},
  [13332] = {.lex_state = 0, .external_lex_state = 22},
  [13333] = {.lex_state = 0, .external_lex_state = 22},
  [13334] = {.lex_state = 0, .external_lex_state = 22},
  [13335] = {.lex_state = 0, .external_lex_state = 22},
  [13336] = {.lex_state = 0, .external_lex_state = 22},
  [13337] = {.lex_state = 0, .external_lex_state = 22},
  [13338] = {.lex_state = 0, .external_lex_state = 22},
  [13339] = {.lex_state = 0, .external_lex_state = 22},
  [13340] = {.lex_state = 0, .external_lex_state = 22},
  [13341] = {.lex_state = 0, .external_lex_state = 22},
  [13342] = {.lex_state = 0, .external_lex_state = 22},
  [13343] = {.lex_state = 0, .external_lex_state = 22},
  [13344] = {.lex_state = 0, .external_lex_state = 22},
  [13345] = {.lex_state = 0, .external_lex_state = 22},
  [13346] = {.lex_state = 0, .external_lex_state = 22},
  [13347] = {.lex_state = 0, .external_lex_state = 22},
  [13348] = {.lex_state = 0, .external_lex_state = 22},
  [13349] = {.lex_state = 0, .external_lex_state = 22},
  [13350] = {.lex_state = 0, .external_lex_state = 22},
  [13351] = {.lex_state = 0, .external_lex_state = 22},
  [13352] = {.lex_state = 0, .external_lex_state = 22},
  [13353] = {.lex_state = 0, .external_lex_state = 22},
  [13354] = {.lex_state = 0, .external_lex_state = 22},
  [13355] = {.lex_state = 0, .external_lex_state = 22},
  [13356] = {.lex_state = 0, .external_lex_state = 22},
  [13357] = {.lex_state = 0, .external_lex_state = 22},
  [13358] = {.lex_state = 0, .external_lex_state = 22},
  [13359] = {.lex_state = 0, .external_lex_state = 22},
  [13360] = {.lex_state = 0, .external_lex_state = 22},
  [13361] = {.lex_state = 0, .external_lex_state = 22},
  [13362] = {.lex_state = 0, .external_lex_state = 22},
  [13363] = {.lex_state = 0, .external_lex_state = 22},
  [13364] = {.lex_state = 0, .external_lex_state = 22},
  [13365] = {.lex_state = 0, .external_lex_state = 22},
  [13366] = {.lex_state = 0, .external_lex_state = 22},
  [13367] = {.lex_state = 0, .external_lex_state = 22},
  [13368] = {.lex_state = 0, .external_lex_state = 22},
  [13369] = {.lex_state = 0, .external_lex_state = 22},
  [13370] = {.lex_state = 0, .external_lex_state = 22},
  [13371] = {.lex_state = 0, .external_lex_state = 22},
  [13372] = {.lex_state = 117},
  [13373] = {.lex_state = 117},
  [13374] = {.lex_state = 0, .external_lex_state = 22},
  [13375] = {.lex_state = 0, .external_lex_state = 22},
  [13376] = {.lex_state = 0, .external_lex_state = 22},
  [13377] = {.lex_state = 0, .external_lex_state = 22},
  [13378] = {.lex_state = 0, .external_lex_state = 22},
  [13379] = {.lex_state = 0, .external_lex_state = 22},
  [13380] = {.lex_state = 0, .external_lex_state = 22},
  [13381] = {.lex_state = 0, .external_lex_state = 22},
  [13382] = {.lex_state = 0, .external_lex_state = 22},
  [13383] = {.lex_state = 0, .external_lex_state = 22},
  [13384] = {.lex_state = 0, .external_lex_state = 22},
  [13385] = {.lex_state = 0, .external_lex_state = 22},
  [13386] = {.lex_state = 0, .external_lex_state = 22},
  [13387] = {.lex_state = 0, .external_lex_state = 22},
  [13388] = {.lex_state = 117},
  [13389] = {.lex_state = 6, .external_lex_state = 2},
  [13390] = {.lex_state = 0, .external_lex_state = 22},
  [13391] = {.lex_state = 0, .external_lex_state = 22},
  [13392] = {.lex_state = 0, .external_lex_state = 22},
  [13393] = {.lex_state = 0, .external_lex_state = 22},
  [13394] = {.lex_state = 0, .external_lex_state = 22},
  [13395] = {.lex_state = 0, .external_lex_state = 22},
  [13396] = {.lex_state = 0, .external_lex_state = 22},
  [13397] = {.lex_state = 0, .external_lex_state = 22},
  [13398] = {.lex_state = 0, .external_lex_state = 22},
  [13399] = {.lex_state = 0, .external_lex_state = 22},
  [13400] = {.lex_state = 0, .external_lex_state = 22},
  [13401] = {.lex_state = 117},
  [13402] = {.lex_state = 0, .external_lex_state = 22},
  [13403] = {.lex_state = 0, .external_lex_state = 22},
  [13404] = {.lex_state = 0, .external_lex_state = 22},
  [13405] = {.lex_state = 0, .external_lex_state = 22},
  [13406] = {.lex_state = 0, .external_lex_state = 22},
  [13407] = {.lex_state = 0, .external_lex_state = 22},
  [13408] = {.lex_state = 0, .external_lex_state = 22},
  [13409] = {.lex_state = 0, .external_lex_state = 22},
  [13410] = {.lex_state = 0, .external_lex_state = 22},
  [13411] = {.lex_state = 0, .external_lex_state = 22},
  [13412] = {.lex_state = 117},
  [13413] = {.lex_state = 117},
  [13414] = {.lex_state = 0, .external_lex_state = 22},
  [13415] = {.lex_state = 0, .external_lex_state = 22},
  [13416] = {.lex_state = 117},
  [13417] = {.lex_state = 0, .external_lex_state = 22},
  [13418] = {.lex_state = 0, .external_lex_state = 22},
  [13419] = {.lex_state = 0, .external_lex_state = 22},
  [13420] = {.lex_state = 0, .external_lex_state = 22},
  [13421] = {.lex_state = 0, .external_lex_state = 22},
  [13422] = {.lex_state = 0, .external_lex_state = 22},
  [13423] = {.lex_state = 0, .external_lex_state = 22},
  [13424] = {.lex_state = 0, .external_lex_state = 22},
  [13425] = {.lex_state = 0, .external_lex_state = 22},
  [13426] = {.lex_state = 0, .external_lex_state = 22},
  [13427] = {.lex_state = 0, .external_lex_state = 22},
  [13428] = {.lex_state = 0, .external_lex_state = 22},
  [13429] = {.lex_state = 0, .external_lex_state = 22},
  [13430] = {.lex_state = 0, .external_lex_state = 22},
  [13431] = {.lex_state = 0, .external_lex_state = 22},
  [13432] = {.lex_state = 0, .external_lex_state = 22},
  [13433] = {.lex_state = 0, .external_lex_state = 22},
  [13434] = {.lex_state = 0, .external_lex_state = 22},
  [13435] = {.lex_state = 0, .external_lex_state = 22},
  [13436] = {.lex_state = 0, .external_lex_state = 22},
  [13437] = {.lex_state = 0, .external_lex_state = 22},
  [13438] = {.lex_state = 0, .external_lex_state = 22},
  [13439] = {.lex_state = 0, .external_lex_state = 22},
  [13440] = {.lex_state = 0, .external_lex_state = 22},
  [13441] = {.lex_state = 0, .external_lex_state = 22},
  [13442] = {.lex_state = 0, .external_lex_state = 22},
  [13443] = {.lex_state = 0, .external_lex_state = 22},
  [13444] = {.lex_state = 0, .external_lex_state = 22},
  [13445] = {.lex_state = 0, .external_lex_state = 22},
  [13446] = {.lex_state = 0, .external_lex_state = 22},
  [13447] = {.lex_state = 0, .external_lex_state = 22},
  [13448] = {.lex_state = 0, .external_lex_state = 22},
  [13449] = {.lex_state = 0, .external_lex_state = 22},
  [13450] = {.lex_state = 0, .external_lex_state = 22},
  [13451] = {.lex_state = 0, .external_lex_state = 22},
  [13452] = {.lex_state = 0, .external_lex_state = 22},
  [13453] = {.lex_state = 0, .external_lex_state = 22},
  [13454] = {.lex_state = 0, .external_lex_state = 22},
  [13455] = {.lex_state = 117, .external_lex_state = 28},
  [13456] = {.lex_state = 0, .external_lex_state = 22},
  [13457] = {.lex_state = 0, .external_lex_state = 22},
  [13458] = {.lex_state = 117, .external_lex_state = 28},
  [13459] = {.lex_state = 117},
  [13460] = {.lex_state = 117},
  [13461] = {.lex_state = 117},
  [13462] = {.lex_state = 117},
  [13463] = {.lex_state = 0, .external_lex_state = 22},
  [13464] = {.lex_state = 117, .external_lex_state = 2},
  [13465] = {.lex_state = 0, .external_lex_state = 22},
  [13466] = {.lex_state = 0, .external_lex_state = 22},
  [13467] = {.lex_state = 0, .external_lex_state = 22},
  [13468] = {.lex_state = 117, .external_lex_state = 2},
  [13469] = {.lex_state = 0, .external_lex_state = 22},
  [13470] = {.lex_state = 0, .external_lex_state = 22},
  [13471] = {.lex_state = 0, .external_lex_state = 22},
  [13472] = {.lex_state = 0, .external_lex_state = 22},
  [13473] = {.lex_state = 0, .external_lex_state = 22},
  [13474] = {.lex_state = 0, .external_lex_state = 22},
  [13475] = {.lex_state = 0, .external_lex_state = 22},
  [13476] = {.lex_state = 0, .external_lex_state = 22},
  [13477] = {.lex_state = 0, .external_lex_state = 22},
  [13478] = {.lex_state = 0, .external_lex_state = 22},
  [13479] = {.lex_state = 0, .external_lex_state = 22},
  [13480] = {.lex_state = 0, .external_lex_state = 22},
  [13481] = {.lex_state = 0, .external_lex_state = 22},
  [13482] = {.lex_state = 0, .external_lex_state = 22},
  [13483] = {.lex_state = 0, .external_lex_state = 22},
  [13484] = {.lex_state = 0, .external_lex_state = 22},
  [13485] = {.lex_state = 0, .external_lex_state = 22},
  [13486] = {.lex_state = 0, .external_lex_state = 22},
  [13487] = {.lex_state = 117},
  [13488] = {.lex_state = 117},
  [13489] = {.lex_state = 0, .external_lex_state = 22},
  [13490] = {.lex_state = 0, .external_lex_state = 22},
  [13491] = {.lex_state = 0, .external_lex_state = 22},
  [13492] = {.lex_state = 0, .external_lex_state = 22},
  [13493] = {.lex_state = 0, .external_lex_state = 22},
  [13494] = {.lex_state = 0, .external_lex_state = 22},
  [13495] = {.lex_state = 0, .external_lex_state = 22},
  [13496] = {.lex_state = 0, .external_lex_state = 22},
  [13497] = {.lex_state = 0, .external_lex_state = 22},
  [13498] = {.lex_state = 0, .external_lex_state = 22},
  [13499] = {.lex_state = 0, .external_lex_state = 22},
  [13500] = {.lex_state = 117, .external_lex_state = 28},
  [13501] = {.lex_state = 0, .external_lex_state = 22},
  [13502] = {.lex_state = 0, .external_lex_state = 22},
  [13503] = {.lex_state = 0, .external_lex_state = 22},
  [13504] = {.lex_state = 0, .external_lex_state = 22},
  [13505] = {.lex_state = 0, .external_lex_state = 22},
  [13506] = {.lex_state = 0, .external_lex_state = 22},
  [13507] = {.lex_state = 0, .external_lex_state = 22},
  [13508] = {.lex_state = 117},
  [13509] = {.lex_state = 0, .external_lex_state = 22},
  [13510] = {.lex_state = 0, .external_lex_state = 22},
  [13511] = {.lex_state = 0, .external_lex_state = 22},
  [13512] = {.lex_state = 0, .external_lex_state = 22},
  [13513] = {.lex_state = 0, .external_lex_state = 22},
  [13514] = {.lex_state = 117},
  [13515] = {.lex_state = 117},
  [13516] = {.lex_state = 117, .external_lex_state = 28},
  [13517] = {.lex_state = 0, .external_lex_state = 22},
  [13518] = {.lex_state = 0, .external_lex_state = 22},
  [13519] = {.lex_state = 117},
  [13520] = {.lex_state = 117},
  [13521] = {.lex_state = 0, .external_lex_state = 22},
  [13522] = {.lex_state = 0, .external_lex_state = 22},
  [13523] = {.lex_state = 117, .external_lex_state = 2},
  [13524] = {.lex_state = 0, .external_lex_state = 22},
  [13525] = {.lex_state = 0, .external_lex_state = 22},
  [13526] = {.lex_state = 0, .external_lex_state = 22},
  [13527] = {.lex_state = 0, .external_lex_state = 22},
  [13528] = {.lex_state = 0, .external_lex_state = 22},
  [13529] = {.lex_state = 0, .external_lex_state = 22},
  [13530] = {.lex_state = 0, .external_lex_state = 22},
  [13531] = {.lex_state = 0, .external_lex_state = 22},
  [13532] = {.lex_state = 0, .external_lex_state = 22},
  [13533] = {.lex_state = 0, .external_lex_state = 22},
  [13534] = {.lex_state = 0, .external_lex_state = 22},
  [13535] = {.lex_state = 0, .external_lex_state = 22},
  [13536] = {.lex_state = 0, .external_lex_state = 22},
  [13537] = {.lex_state = 0, .external_lex_state = 22},
  [13538] = {.lex_state = 0, .external_lex_state = 22},
  [13539] = {.lex_state = 0, .external_lex_state = 22},
  [13540] = {.lex_state = 0, .external_lex_state = 22},
  [13541] = {.lex_state = 117},
  [13542] = {.lex_state = 117},
  [13543] = {.lex_state = 0, .external_lex_state = 22},
  [13544] = {.lex_state = 0, .external_lex_state = 22},
  [13545] = {.lex_state = 0, .external_lex_state = 22},
  [13546] = {.lex_state = 0, .external_lex_state = 22},
  [13547] = {.lex_state = 0, .external_lex_state = 22},
  [13548] = {.lex_state = 0, .external_lex_state = 22},
  [13549] = {.lex_state = 0, .external_lex_state = 22},
  [13550] = {.lex_state = 0, .external_lex_state = 22},
  [13551] = {.lex_state = 0, .external_lex_state = 22},
  [13552] = {.lex_state = 0, .external_lex_state = 22},
  [13553] = {.lex_state = 0, .external_lex_state = 22},
  [13554] = {.lex_state = 0, .external_lex_state = 22},
  [13555] = {.lex_state = 0, .external_lex_state = 22},
  [13556] = {.lex_state = 0, .external_lex_state = 22},
  [13557] = {.lex_state = 0, .external_lex_state = 22},
  [13558] = {.lex_state = 0, .external_lex_state = 22},
  [13559] = {.lex_state = 0, .external_lex_state = 22},
  [13560] = {.lex_state = 0, .external_lex_state = 22},
  [13561] = {.lex_state = 117},
  [13562] = {.lex_state = 117},
  [13563] = {.lex_state = 0, .external_lex_state = 22},
  [13564] = {.lex_state = 0, .external_lex_state = 22},
  [13565] = {.lex_state = 0, .external_lex_state = 22},
  [13566] = {.lex_state = 0, .external_lex_state = 22},
  [13567] = {.lex_state = 0, .external_lex_state = 22},
  [13568] = {.lex_state = 0, .external_lex_state = 22},
  [13569] = {.lex_state = 0, .external_lex_state = 22},
  [13570] = {.lex_state = 0, .external_lex_state = 22},
  [13571] = {.lex_state = 0, .external_lex_state = 22},
  [13572] = {.lex_state = 0, .external_lex_state = 22},
  [13573] = {.lex_state = 0, .external_lex_state = 22},
  [13574] = {.lex_state = 0, .external_lex_state = 22},
  [13575] = {.lex_state = 0, .external_lex_state = 22},
  [13576] = {.lex_state = 0, .external_lex_state = 22},
  [13577] = {.lex_state = 0, .external_lex_state = 22},
  [13578] = {.lex_state = 0, .external_lex_state = 22},
  [13579] = {.lex_state = 117},
  [13580] = {.lex_state = 117},
  [13581] = {.lex_state = 0, .external_lex_state = 22},
  [13582] = {.lex_state = 0, .external_lex_state = 22},
  [13583] = {.lex_state = 0, .external_lex_state = 22},
  [13584] = {.lex_state = 0, .external_lex_state = 22},
  [13585] = {.lex_state = 0, .external_lex_state = 22},
  [13586] = {.lex_state = 0, .external_lex_state = 22},
  [13587] = {.lex_state = 0, .external_lex_state = 22},
  [13588] = {.lex_state = 0, .external_lex_state = 22},
  [13589] = {.lex_state = 0, .external_lex_state = 22},
  [13590] = {.lex_state = 0, .external_lex_state = 22},
  [13591] = {.lex_state = 0, .external_lex_state = 22},
  [13592] = {.lex_state = 0, .external_lex_state = 22},
  [13593] = {.lex_state = 0, .external_lex_state = 22},
  [13594] = {.lex_state = 0, .external_lex_state = 22},
  [13595] = {.lex_state = 117},
  [13596] = {.lex_state = 0, .external_lex_state = 22},
  [13597] = {.lex_state = 0, .external_lex_state = 22},
  [13598] = {.lex_state = 0, .external_lex_state = 22},
  [13599] = {.lex_state = 0, .external_lex_state = 22},
  [13600] = {.lex_state = 0, .external_lex_state = 22},
  [13601] = {.lex_state = 0, .external_lex_state = 22},
  [13602] = {.lex_state = 0, .external_lex_state = 22},
  [13603] = {.lex_state = 0, .external_lex_state = 22},
  [13604] = {.lex_state = 0, .external_lex_state = 22},
  [13605] = {.lex_state = 0, .external_lex_state = 22},
  [13606] = {.lex_state = 0, .external_lex_state = 22},
  [13607] = {.lex_state = 0, .external_lex_state = 22},
  [13608] = {.lex_state = 0, .external_lex_state = 22},
  [13609] = {.lex_state = 0, .external_lex_state = 22},
  [13610] = {.lex_state = 0, .external_lex_state = 22},
  [13611] = {.lex_state = 0, .external_lex_state = 22},
  [13612] = {.lex_state = 117},
  [13613] = {.lex_state = 0, .external_lex_state = 22},
  [13614] = {.lex_state = 0, .external_lex_state = 22},
  [13615] = {.lex_state = 0, .external_lex_state = 22},
  [13616] = {.lex_state = 0, .external_lex_state = 22},
  [13617] = {.lex_state = 0, .external_lex_state = 22},
  [13618] = {.lex_state = 0, .external_lex_state = 22},
  [13619] = {.lex_state = 0, .external_lex_state = 22},
  [13620] = {.lex_state = 0, .external_lex_state = 22},
  [13621] = {.lex_state = 0, .external_lex_state = 22},
  [13622] = {.lex_state = 0, .external_lex_state = 22},
  [13623] = {.lex_state = 0, .external_lex_state = 22},
  [13624] = {.lex_state = 0, .external_lex_state = 22},
  [13625] = {.lex_state = 0, .external_lex_state = 22},
  [13626] = {.lex_state = 0, .external_lex_state = 22},
  [13627] = {.lex_state = 0, .external_lex_state = 22},
  [13628] = {.lex_state = 0, .external_lex_state = 22},
  [13629] = {.lex_state = 0, .external_lex_state = 22},
  [13630] = {.lex_state = 0, .external_lex_state = 22},
  [13631] = {.lex_state = 0, .external_lex_state = 22},
  [13632] = {.lex_state = 0, .external_lex_state = 22},
  [13633] = {.lex_state = 0, .external_lex_state = 22},
  [13634] = {.lex_state = 0, .external_lex_state = 22},
  [13635] = {.lex_state = 0, .external_lex_state = 22},
  [13636] = {.lex_state = 0, .external_lex_state = 22},
  [13637] = {.lex_state = 0, .external_lex_state = 22},
  [13638] = {.lex_state = 0, .external_lex_state = 22},
  [13639] = {.lex_state = 0, .external_lex_state = 22},
  [13640] = {.lex_state = 0, .external_lex_state = 22},
  [13641] = {.lex_state = 0, .external_lex_state = 22},
  [13642] = {.lex_state = 0, .external_lex_state = 22},
  [13643] = {.lex_state = 0, .external_lex_state = 22},
  [13644] = {.lex_state = 0, .external_lex_state = 22},
  [13645] = {.lex_state = 0, .external_lex_state = 22},
  [13646] = {.lex_state = 0, .external_lex_state = 22},
  [13647] = {.lex_state = 0, .external_lex_state = 22},
  [13648] = {.lex_state = 0, .external_lex_state = 22},
  [13649] = {.lex_state = 0, .external_lex_state = 22},
  [13650] = {.lex_state = 0, .external_lex_state = 22},
  [13651] = {.lex_state = 0, .external_lex_state = 22},
  [13652] = {.lex_state = 0, .external_lex_state = 22},
  [13653] = {.lex_state = 0, .external_lex_state = 22},
  [13654] = {.lex_state = 0, .external_lex_state = 22},
  [13655] = {.lex_state = 0, .external_lex_state = 22},
  [13656] = {.lex_state = 0, .external_lex_state = 22},
  [13657] = {.lex_state = 0, .external_lex_state = 22},
  [13658] = {.lex_state = 0, .external_lex_state = 22},
  [13659] = {.lex_state = 0, .external_lex_state = 22},
  [13660] = {.lex_state = 0, .external_lex_state = 22},
  [13661] = {.lex_state = 0, .external_lex_state = 22},
  [13662] = {.lex_state = 0, .external_lex_state = 22},
  [13663] = {.lex_state = 0, .external_lex_state = 22},
  [13664] = {.lex_state = 0, .external_lex_state = 22},
  [13665] = {.lex_state = 0, .external_lex_state = 22},
  [13666] = {.lex_state = 0, .external_lex_state = 22},
  [13667] = {.lex_state = 0, .external_lex_state = 22},
  [13668] = {.lex_state = 0, .external_lex_state = 22},
  [13669] = {.lex_state = 0, .external_lex_state = 22},
  [13670] = {.lex_state = 0, .external_lex_state = 22},
  [13671] = {.lex_state = 0, .external_lex_state = 22},
  [13672] = {.lex_state = 0, .external_lex_state = 22},
  [13673] = {.lex_state = 0, .external_lex_state = 22},
  [13674] = {.lex_state = 0, .external_lex_state = 22},
  [13675] = {.lex_state = 0, .external_lex_state = 22},
  [13676] = {.lex_state = 0, .external_lex_state = 22},
  [13677] = {.lex_state = 0, .external_lex_state = 22},
  [13678] = {.lex_state = 0, .external_lex_state = 22},
  [13679] = {.lex_state = 0, .external_lex_state = 22},
  [13680] = {.lex_state = 0, .external_lex_state = 22},
  [13681] = {.lex_state = 0, .external_lex_state = 22},
  [13682] = {.lex_state = 0, .external_lex_state = 22},
  [13683] = {.lex_state = 0, .external_lex_state = 22},
  [13684] = {.lex_state = 0, .external_lex_state = 22},
  [13685] = {.lex_state = 0, .external_lex_state = 22},
  [13686] = {.lex_state = 117},
  [13687] = {.lex_state = 0, .external_lex_state = 22},
  [13688] = {.lex_state = 0, .external_lex_state = 22},
  [13689] = {.lex_state = 117},
  [13690] = {.lex_state = 0, .external_lex_state = 22},
  [13691] = {.lex_state = 0, .external_lex_state = 22},
  [13692] = {.lex_state = 0, .external_lex_state = 22},
  [13693] = {.lex_state = 0, .external_lex_state = 22},
  [13694] = {.lex_state = 0, .external_lex_state = 22},
  [13695] = {.lex_state = 0, .external_lex_state = 22},
  [13696] = {.lex_state = 117},
  [13697] = {.lex_state = 117},
  [13698] = {.lex_state = 117},
  [13699] = {.lex_state = 0, .external_lex_state = 22},
  [13700] = {.lex_state = 0, .external_lex_state = 22},
  [13701] = {.lex_state = 117, .external_lex_state = 2},
  [13702] = {.lex_state = 0, .external_lex_state = 22},
  [13703] = {.lex_state = 0, .external_lex_state = 22},
  [13704] = {.lex_state = 0, .external_lex_state = 22},
  [13705] = {.lex_state = 0, .external_lex_state = 22},
  [13706] = {.lex_state = 0, .external_lex_state = 22},
  [13707] = {.lex_state = 0, .external_lex_state = 22},
  [13708] = {.lex_state = 0, .external_lex_state = 22},
  [13709] = {.lex_state = 0, .external_lex_state = 22},
  [13710] = {.lex_state = 0, .external_lex_state = 22},
  [13711] = {.lex_state = 0, .external_lex_state = 22},
  [13712] = {.lex_state = 0, .external_lex_state = 22},
  [13713] = {.lex_state = 0, .external_lex_state = 22},
  [13714] = {.lex_state = 0, .external_lex_state = 22},
  [13715] = {.lex_state = 0, .external_lex_state = 22},
  [13716] = {.lex_state = 0, .external_lex_state = 22},
  [13717] = {.lex_state = 0, .external_lex_state = 22},
  [13718] = {.lex_state = 117, .external_lex_state = 2},
  [13719] = {.lex_state = 0, .external_lex_state = 22},
  [13720] = {.lex_state = 0, .external_lex_state = 22},
  [13721] = {.lex_state = 0, .external_lex_state = 22},
  [13722] = {.lex_state = 0, .external_lex_state = 22},
  [13723] = {.lex_state = 0, .external_lex_state = 22},
  [13724] = {.lex_state = 0, .external_lex_state = 22},
  [13725] = {.lex_state = 0, .external_lex_state = 22},
  [13726] = {.lex_state = 0, .external_lex_state = 22},
  [13727] = {.lex_state = 0, .external_lex_state = 22},
  [13728] = {.lex_state = 0, .external_lex_state = 22},
  [13729] = {.lex_state = 0, .external_lex_state = 22},
  [13730] = {.lex_state = 0, .external_lex_state = 22},
  [13731] = {.lex_state = 0, .external_lex_state = 22},
  [13732] = {.lex_state = 0, .external_lex_state = 22},
  [13733] = {.lex_state = 0, .external_lex_state = 22},
  [13734] = {.lex_state = 0, .external_lex_state = 22},
  [13735] = {.lex_state = 0, .external_lex_state = 22},
  [13736] = {.lex_state = 0, .external_lex_state = 22},
  [13737] = {.lex_state = 0, .external_lex_state = 22},
  [13738] = {.lex_state = 0, .external_lex_state = 22},
  [13739] = {.lex_state = 0, .external_lex_state = 22},
  [13740] = {.lex_state = 0, .external_lex_state = 22},
  [13741] = {.lex_state = 117},
  [13742] = {.lex_state = 0, .external_lex_state = 22},
  [13743] = {.lex_state = 0, .external_lex_state = 22},
  [13744] = {.lex_state = 117, .external_lex_state = 2},
  [13745] = {.lex_state = 0, .external_lex_state = 22},
  [13746] = {.lex_state = 0, .external_lex_state = 22},
  [13747] = {.lex_state = 0, .external_lex_state = 22},
  [13748] = {.lex_state = 0, .external_lex_state = 22},
  [13749] = {.lex_state = 0, .external_lex_state = 22},
  [13750] = {.lex_state = 0, .external_lex_state = 22},
  [13751] = {.lex_state = 0, .external_lex_state = 22},
  [13752] = {.lex_state = 0, .external_lex_state = 22},
  [13753] = {.lex_state = 0, .external_lex_state = 22},
  [13754] = {.lex_state = 0, .external_lex_state = 22},
  [13755] = {.lex_state = 0, .external_lex_state = 22},
  [13756] = {.lex_state = 0, .external_lex_state = 22},
  [13757] = {.lex_state = 0, .external_lex_state = 22},
  [13758] = {.lex_state = 0, .external_lex_state = 22},
  [13759] = {.lex_state = 0, .external_lex_state = 22},
  [13760] = {.lex_state = 0, .external_lex_state = 22},
  [13761] = {.lex_state = 0, .external_lex_state = 22},
  [13762] = {.lex_state = 0, .external_lex_state = 22},
  [13763] = {.lex_state = 0, .external_lex_state = 22},
  [13764] = {.lex_state = 0, .external_lex_state = 22},
  [13765] = {.lex_state = 0, .external_lex_state = 22},
  [13766] = {.lex_state = 0, .external_lex_state = 22},
  [13767] = {.lex_state = 0, .external_lex_state = 22},
  [13768] = {.lex_state = 0, .external_lex_state = 22},
  [13769] = {.lex_state = 0, .external_lex_state = 22},
  [13770] = {.lex_state = 0, .external_lex_state = 22},
  [13771] = {.lex_state = 0, .external_lex_state = 22},
  [13772] = {.lex_state = 0, .external_lex_state = 22},
  [13773] = {.lex_state = 0, .external_lex_state = 22},
  [13774] = {.lex_state = 0, .external_lex_state = 22},
  [13775] = {.lex_state = 0, .external_lex_state = 22},
  [13776] = {.lex_state = 0, .external_lex_state = 22},
  [13777] = {.lex_state = 0, .external_lex_state = 22},
  [13778] = {.lex_state = 0, .external_lex_state = 22},
  [13779] = {.lex_state = 0, .external_lex_state = 22},
  [13780] = {.lex_state = 0, .external_lex_state = 22},
  [13781] = {.lex_state = 0, .external_lex_state = 22},
  [13782] = {.lex_state = 0, .external_lex_state = 22},
  [13783] = {.lex_state = 0, .external_lex_state = 22},
  [13784] = {.lex_state = 117},
  [13785] = {.lex_state = 0, .external_lex_state = 22},
  [13786] = {.lex_state = 0, .external_lex_state = 22},
  [13787] = {.lex_state = 0, .external_lex_state = 22},
  [13788] = {.lex_state = 117},
  [13789] = {.lex_state = 0},
  [13790] = {.lex_state = 0, .external_lex_state = 22},
  [13791] = {.lex_state = 0, .external_lex_state = 22},
  [13792] = {.lex_state = 117, .external_lex_state = 2},
  [13793] = {.lex_state = 117},
  [13794] = {.lex_state = 0, .external_lex_state = 22},
  [13795] = {.lex_state = 0, .external_lex_state = 22},
  [13796] = {.lex_state = 117},
  [13797] = {.lex_state = 0, .external_lex_state = 22},
  [13798] = {.lex_state = 117, .external_lex_state = 2},
  [13799] = {.lex_state = 0, .external_lex_state = 22},
  [13800] = {.lex_state = 0, .external_lex_state = 22},
  [13801] = {.lex_state = 0, .external_lex_state = 22},
  [13802] = {.lex_state = 0, .external_lex_state = 22},
  [13803] = {.lex_state = 0, .external_lex_state = 22},
  [13804] = {.lex_state = 0, .external_lex_state = 22},
  [13805] = {.lex_state = 117},
  [13806] = {.lex_state = 0, .external_lex_state = 22},
  [13807] = {.lex_state = 0, .external_lex_state = 22},
  [13808] = {.lex_state = 0, .external_lex_state = 22},
  [13809] = {.lex_state = 0, .external_lex_state = 22},
  [13810] = {.lex_state = 0, .external_lex_state = 22},
  [13811] = {.lex_state = 0, .external_lex_state = 22},
  [13812] = {.lex_state = 0, .external_lex_state = 22},
  [13813] = {.lex_state = 0, .external_lex_state = 22},
  [13814] = {.lex_state = 0, .external_lex_state = 22},
  [13815] = {.lex_state = 0, .external_lex_state = 22},
  [13816] = {.lex_state = 0, .external_lex_state = 22},
  [13817] = {.lex_state = 0, .external_lex_state = 22},
  [13818] = {.lex_state = 0, .external_lex_state = 22},
  [13819] = {.lex_state = 0, .external_lex_state = 22},
  [13820] = {.lex_state = 0, .external_lex_state = 22},
  [13821] = {.lex_state = 0, .external_lex_state = 22},
  [13822] = {.lex_state = 0, .external_lex_state = 22},
  [13823] = {.lex_state = 0, .external_lex_state = 22},
  [13824] = {.lex_state = 0, .external_lex_state = 22},
  [13825] = {.lex_state = 0, .external_lex_state = 22},
  [13826] = {.lex_state = 0, .external_lex_state = 22},
  [13827] = {.lex_state = 0, .external_lex_state = 22},
  [13828] = {.lex_state = 0, .external_lex_state = 22},
  [13829] = {.lex_state = 0, .external_lex_state = 22},
  [13830] = {.lex_state = 0, .external_lex_state = 22},
  [13831] = {.lex_state = 0, .external_lex_state = 22},
  [13832] = {.lex_state = 0, .external_lex_state = 22},
  [13833] = {.lex_state = 0, .external_lex_state = 22},
  [13834] = {.lex_state = 0, .external_lex_state = 22},
  [13835] = {.lex_state = 0, .external_lex_state = 22},
  [13836] = {.lex_state = 0, .external_lex_state = 22},
  [13837] = {.lex_state = 0, .external_lex_state = 22},
  [13838] = {.lex_state = 0, .external_lex_state = 22},
  [13839] = {.lex_state = 0, .external_lex_state = 22},
  [13840] = {.lex_state = 0, .external_lex_state = 22},
  [13841] = {.lex_state = 0, .external_lex_state = 22},
  [13842] = {.lex_state = 0, .external_lex_state = 22},
  [13843] = {.lex_state = 0, .external_lex_state = 22},
  [13844] = {.lex_state = 0, .external_lex_state = 22},
  [13845] = {.lex_state = 0, .external_lex_state = 22},
  [13846] = {.lex_state = 0, .external_lex_state = 22},
  [13847] = {.lex_state = 0, .external_lex_state = 22},
  [13848] = {.lex_state = 0, .external_lex_state = 22},
  [13849] = {.lex_state = 0, .external_lex_state = 22},
  [13850] = {.lex_state = 0, .external_lex_state = 22},
  [13851] = {.lex_state = 0, .external_lex_state = 22},
  [13852] = {.lex_state = 0, .external_lex_state = 22},
  [13853] = {.lex_state = 117, .external_lex_state = 28},
  [13854] = {.lex_state = 0, .external_lex_state = 22},
  [13855] = {.lex_state = 0, .external_lex_state = 22},
  [13856] = {.lex_state = 0, .external_lex_state = 22},
  [13857] = {.lex_state = 0, .external_lex_state = 22},
  [13858] = {.lex_state = 0, .external_lex_state = 22},
  [13859] = {.lex_state = 0, .external_lex_state = 22},
  [13860] = {.lex_state = 0, .external_lex_state = 22},
  [13861] = {.lex_state = 0, .external_lex_state = 22},
  [13862] = {.lex_state = 0, .external_lex_state = 22},
  [13863] = {.lex_state = 0, .external_lex_state = 22},
  [13864] = {.lex_state = 0, .external_lex_state = 22},
  [13865] = {.lex_state = 0, .external_lex_state = 22},
  [13866] = {.lex_state = 0, .external_lex_state = 22},
  [13867] = {.lex_state = 0, .external_lex_state = 22},
  [13868] = {.lex_state = 0, .external_lex_state = 22},
  [13869] = {.lex_state = 0, .external_lex_state = 22},
  [13870] = {.lex_state = 0, .external_lex_state = 22},
  [13871] = {.lex_state = 0, .external_lex_state = 22},
  [13872] = {.lex_state = 0, .external_lex_state = 22},
  [13873] = {.lex_state = 0, .external_lex_state = 22},
  [13874] = {.lex_state = 0, .external_lex_state = 22},
  [13875] = {.lex_state = 0, .external_lex_state = 22},
  [13876] = {.lex_state = 0, .external_lex_state = 22},
  [13877] = {.lex_state = 0, .external_lex_state = 22},
  [13878] = {.lex_state = 0, .external_lex_state = 22},
  [13879] = {.lex_state = 0, .external_lex_state = 22},
  [13880] = {.lex_state = 0, .external_lex_state = 22},
  [13881] = {.lex_state = 117},
  [13882] = {.lex_state = 0, .external_lex_state = 22},
  [13883] = {.lex_state = 0, .external_lex_state = 22},
  [13884] = {.lex_state = 0, .external_lex_state = 22},
  [13885] = {.lex_state = 0, .external_lex_state = 22},
  [13886] = {.lex_state = 0, .external_lex_state = 22},
  [13887] = {.lex_state = 0, .external_lex_state = 22},
  [13888] = {.lex_state = 0, .external_lex_state = 22},
  [13889] = {.lex_state = 0, .external_lex_state = 22},
  [13890] = {.lex_state = 0, .external_lex_state = 22},
  [13891] = {.lex_state = 0, .external_lex_state = 22},
  [13892] = {.lex_state = 0, .external_lex_state = 22},
  [13893] = {.lex_state = 0, .external_lex_state = 22},
  [13894] = {.lex_state = 0, .external_lex_state = 22},
  [13895] = {.lex_state = 0, .external_lex_state = 22},
  [13896] = {.lex_state = 0, .external_lex_state = 22},
  [13897] = {.lex_state = 0, .external_lex_state = 22},
  [13898] = {.lex_state = 0, .external_lex_state = 22},
  [13899] = {.lex_state = 0, .external_lex_state = 22},
  [13900] = {.lex_state = 0, .external_lex_state = 22},
  [13901] = {.lex_state = 0, .external_lex_state = 22},
  [13902] = {.lex_state = 0, .external_lex_state = 22},
  [13903] = {.lex_state = 0, .external_lex_state = 22},
  [13904] = {.lex_state = 0, .external_lex_state = 22},
  [13905] = {.lex_state = 0, .external_lex_state = 22},
  [13906] = {.lex_state = 0, .external_lex_state = 22},
  [13907] = {.lex_state = 0, .external_lex_state = 22},
  [13908] = {.lex_state = 0, .external_lex_state = 22},
  [13909] = {.lex_state = 0, .external_lex_state = 22},
  [13910] = {.lex_state = 0, .external_lex_state = 22},
  [13911] = {.lex_state = 0, .external_lex_state = 22},
  [13912] = {.lex_state = 0, .external_lex_state = 22},
  [13913] = {.lex_state = 0, .external_lex_state = 22},
  [13914] = {.lex_state = 0, .external_lex_state = 22},
  [13915] = {.lex_state = 117},
  [13916] = {.lex_state = 0, .external_lex_state = 22},
  [13917] = {.lex_state = 0, .external_lex_state = 22},
  [13918] = {.lex_state = 117},
  [13919] = {.lex_state = 0, .external_lex_state = 22},
  [13920] = {.lex_state = 0, .external_lex_state = 22},
  [13921] = {.lex_state = 0, .external_lex_state = 22},
  [13922] = {.lex_state = 0, .external_lex_state = 22},
  [13923] = {.lex_state = 0, .external_lex_state = 22},
  [13924] = {.lex_state = 0, .external_lex_state = 22},
  [13925] = {.lex_state = 0, .external_lex_state = 22},
  [13926] = {.lex_state = 0, .external_lex_state = 22},
  [13927] = {.lex_state = 0, .external_lex_state = 22},
  [13928] = {.lex_state = 0, .external_lex_state = 22},
  [13929] = {.lex_state = 0, .external_lex_state = 22},
  [13930] = {.lex_state = 0, .external_lex_state = 22},
  [13931] = {.lex_state = 0, .external_lex_state = 22},
  [13932] = {.lex_state = 0, .external_lex_state = 22},
  [13933] = {.lex_state = 0, .external_lex_state = 22},
  [13934] = {.lex_state = 0, .external_lex_state = 22},
  [13935] = {.lex_state = 0, .external_lex_state = 22},
  [13936] = {.lex_state = 0, .external_lex_state = 22},
  [13937] = {.lex_state = 0, .external_lex_state = 22},
  [13938] = {.lex_state = 0, .external_lex_state = 22},
  [13939] = {.lex_state = 0, .external_lex_state = 22},
  [13940] = {.lex_state = 0, .external_lex_state = 22},
  [13941] = {.lex_state = 0, .external_lex_state = 22},
  [13942] = {.lex_state = 0, .external_lex_state = 22},
  [13943] = {.lex_state = 0, .external_lex_state = 22},
  [13944] = {.lex_state = 0, .external_lex_state = 22},
  [13945] = {.lex_state = 0, .external_lex_state = 22},
  [13946] = {.lex_state = 0, .external_lex_state = 22},
  [13947] = {.lex_state = 0, .external_lex_state = 22},
  [13948] = {.lex_state = 0, .external_lex_state = 22},
  [13949] = {.lex_state = 0, .external_lex_state = 22},
  [13950] = {.lex_state = 0, .external_lex_state = 22},
  [13951] = {.lex_state = 0, .external_lex_state = 22},
  [13952] = {.lex_state = 0, .external_lex_state = 22},
  [13953] = {.lex_state = 0, .external_lex_state = 22},
  [13954] = {.lex_state = 0, .external_lex_state = 22},
  [13955] = {.lex_state = 0, .external_lex_state = 22},
  [13956] = {.lex_state = 0, .external_lex_state = 22},
  [13957] = {.lex_state = 0, .external_lex_state = 22},
  [13958] = {.lex_state = 0, .external_lex_state = 22},
  [13959] = {.lex_state = 0, .external_lex_state = 22},
  [13960] = {.lex_state = 0, .external_lex_state = 22},
  [13961] = {.lex_state = 0, .external_lex_state = 22},
  [13962] = {.lex_state = 0, .external_lex_state = 22},
  [13963] = {.lex_state = 0, .external_lex_state = 22},
  [13964] = {.lex_state = 0, .external_lex_state = 22},
  [13965] = {.lex_state = 0, .external_lex_state = 22},
  [13966] = {.lex_state = 0, .external_lex_state = 22},
  [13967] = {.lex_state = 0, .external_lex_state = 22},
  [13968] = {.lex_state = 0, .external_lex_state = 22},
  [13969] = {.lex_state = 0, .external_lex_state = 22},
  [13970] = {.lex_state = 0, .external_lex_state = 22},
  [13971] = {.lex_state = 0, .external_lex_state = 22},
  [13972] = {.lex_state = 0, .external_lex_state = 22},
  [13973] = {.lex_state = 0, .external_lex_state = 22},
  [13974] = {.lex_state = 0, .external_lex_state = 22},
  [13975] = {.lex_state = 0, .external_lex_state = 22},
  [13976] = {.lex_state = 0, .external_lex_state = 22},
  [13977] = {.lex_state = 0, .external_lex_state = 22},
  [13978] = {.lex_state = 0, .external_lex_state = 22},
  [13979] = {.lex_state = 0, .external_lex_state = 22},
  [13980] = {.lex_state = 0, .external_lex_state = 22},
  [13981] = {.lex_state = 0, .external_lex_state = 22},
  [13982] = {.lex_state = 0, .external_lex_state = 22},
  [13983] = {.lex_state = 0, .external_lex_state = 22},
  [13984] = {.lex_state = 0, .external_lex_state = 22},
  [13985] = {.lex_state = 0, .external_lex_state = 22},
  [13986] = {.lex_state = 0, .external_lex_state = 22},
  [13987] = {.lex_state = 0, .external_lex_state = 22},
  [13988] = {.lex_state = 0, .external_lex_state = 22},
  [13989] = {.lex_state = 0, .external_lex_state = 22},
  [13990] = {.lex_state = 0, .external_lex_state = 22},
  [13991] = {.lex_state = 0, .external_lex_state = 22},
  [13992] = {.lex_state = 0, .external_lex_state = 22},
  [13993] = {.lex_state = 0, .external_lex_state = 22},
  [13994] = {.lex_state = 0, .external_lex_state = 22},
  [13995] = {.lex_state = 0, .external_lex_state = 22},
  [13996] = {.lex_state = 0, .external_lex_state = 22},
  [13997] = {.lex_state = 0, .external_lex_state = 22},
  [13998] = {.lex_state = 0, .external_lex_state = 22},
  [13999] = {.lex_state = 0, .external_lex_state = 22},
  [14000] = {.lex_state = 0, .external_lex_state = 22},
  [14001] = {.lex_state = 0, .external_lex_state = 22},
  [14002] = {.lex_state = 0, .external_lex_state = 22},
  [14003] = {.lex_state = 0, .external_lex_state = 22},
  [14004] = {.lex_state = 0, .external_lex_state = 22},
  [14005] = {.lex_state = 0, .external_lex_state = 22},
  [14006] = {.lex_state = 0, .external_lex_state = 22},
  [14007] = {.lex_state = 0, .external_lex_state = 22},
  [14008] = {.lex_state = 0, .external_lex_state = 22},
  [14009] = {.lex_state = 0, .external_lex_state = 22},
  [14010] = {.lex_state = 0, .external_lex_state = 22},
  [14011] = {.lex_state = 0, .external_lex_state = 22},
  [14012] = {.lex_state = 0, .external_lex_state = 22},
  [14013] = {.lex_state = 0, .external_lex_state = 22},
  [14014] = {.lex_state = 0, .external_lex_state = 22},
  [14015] = {.lex_state = 0, .external_lex_state = 22},
  [14016] = {.lex_state = 0, .external_lex_state = 22},
  [14017] = {.lex_state = 0, .external_lex_state = 22},
  [14018] = {.lex_state = 0, .external_lex_state = 22},
  [14019] = {.lex_state = 0, .external_lex_state = 22},
  [14020] = {.lex_state = 0, .external_lex_state = 22},
  [14021] = {.lex_state = 0, .external_lex_state = 22},
  [14022] = {.lex_state = 0, .external_lex_state = 22},
  [14023] = {.lex_state = 0, .external_lex_state = 22},
  [14024] = {.lex_state = 0, .external_lex_state = 22},
  [14025] = {.lex_state = 0, .external_lex_state = 22},
  [14026] = {.lex_state = 0, .external_lex_state = 22},
  [14027] = {.lex_state = 0, .external_lex_state = 22},
  [14028] = {.lex_state = 0, .external_lex_state = 22},
  [14029] = {.lex_state = 0, .external_lex_state = 22},
  [14030] = {.lex_state = 0, .external_lex_state = 22},
  [14031] = {.lex_state = 0, .external_lex_state = 22},
  [14032] = {.lex_state = 0, .external_lex_state = 22},
  [14033] = {.lex_state = 0, .external_lex_state = 22},
  [14034] = {.lex_state = 0, .external_lex_state = 22},
  [14035] = {.lex_state = 0, .external_lex_state = 22},
  [14036] = {.lex_state = 0, .external_lex_state = 22},
  [14037] = {.lex_state = 0, .external_lex_state = 22},
  [14038] = {.lex_state = 0, .external_lex_state = 22},
  [14039] = {.lex_state = 0, .external_lex_state = 22},
  [14040] = {.lex_state = 0, .external_lex_state = 22},
  [14041] = {.lex_state = 0, .external_lex_state = 22},
  [14042] = {.lex_state = 0, .external_lex_state = 22},
  [14043] = {.lex_state = 0, .external_lex_state = 22},
  [14044] = {.lex_state = 0, .external_lex_state = 22},
  [14045] = {.lex_state = 0, .external_lex_state = 22},
  [14046] = {.lex_state = 0, .external_lex_state = 22},
  [14047] = {.lex_state = 0, .external_lex_state = 22},
  [14048] = {.lex_state = 0, .external_lex_state = 22},
  [14049] = {.lex_state = 0, .external_lex_state = 22},
  [14050] = {.lex_state = 0, .external_lex_state = 22},
  [14051] = {.lex_state = 0, .external_lex_state = 22},
  [14052] = {.lex_state = 0, .external_lex_state = 22},
  [14053] = {.lex_state = 0, .external_lex_state = 22},
  [14054] = {.lex_state = 0, .external_lex_state = 22},
  [14055] = {.lex_state = 0, .external_lex_state = 22},
  [14056] = {.lex_state = 0, .external_lex_state = 22},
  [14057] = {.lex_state = 0, .external_lex_state = 22},
  [14058] = {.lex_state = 0, .external_lex_state = 22},
  [14059] = {.lex_state = 0, .external_lex_state = 22},
  [14060] = {.lex_state = 117},
  [14061] = {.lex_state = 0, .external_lex_state = 22},
  [14062] = {.lex_state = 117},
  [14063] = {.lex_state = 117},
  [14064] = {.lex_state = 0, .external_lex_state = 22},
  [14065] = {.lex_state = 0, .external_lex_state = 22},
  [14066] = {.lex_state = 0, .external_lex_state = 22},
  [14067] = {.lex_state = 0, .external_lex_state = 22},
  [14068] = {.lex_state = 0, .external_lex_state = 22},
  [14069] = {.lex_state = 0, .external_lex_state = 22},
  [14070] = {.lex_state = 0, .external_lex_state = 22},
  [14071] = {.lex_state = 0, .external_lex_state = 22},
  [14072] = {.lex_state = 0, .external_lex_state = 22},
  [14073] = {.lex_state = 0, .external_lex_state = 22},
  [14074] = {.lex_state = 0, .external_lex_state = 22},
  [14075] = {.lex_state = 0, .external_lex_state = 22},
  [14076] = {.lex_state = 0, .external_lex_state = 22},
  [14077] = {.lex_state = 0, .external_lex_state = 22},
  [14078] = {.lex_state = 0, .external_lex_state = 22},
  [14079] = {.lex_state = 0, .external_lex_state = 22},
  [14080] = {.lex_state = 0, .external_lex_state = 22},
  [14081] = {.lex_state = 0, .external_lex_state = 22},
  [14082] = {.lex_state = 0, .external_lex_state = 22},
  [14083] = {.lex_state = 0, .external_lex_state = 22},
  [14084] = {.lex_state = 0, .external_lex_state = 22},
  [14085] = {.lex_state = 0, .external_lex_state = 22},
  [14086] = {.lex_state = 0, .external_lex_state = 22},
  [14087] = {.lex_state = 0, .external_lex_state = 22},
  [14088] = {.lex_state = 0, .external_lex_state = 22},
  [14089] = {.lex_state = 0, .external_lex_state = 22},
  [14090] = {.lex_state = 117},
  [14091] = {.lex_state = 117},
  [14092] = {.lex_state = 117},
  [14093] = {.lex_state = 0, .external_lex_state = 22},
  [14094] = {.lex_state = 117},
  [14095] = {.lex_state = 117},
  [14096] = {.lex_state = 0, .external_lex_state = 22},
  [14097] = {.lex_state = 0, .external_lex_state = 22},
  [14098] = {.lex_state = 117, .external_lex_state = 2},
  [14099] = {.lex_state = 0, .external_lex_state = 22},
  [14100] = {.lex_state = 0, .external_lex_state = 22},
  [14101] = {.lex_state = 0, .external_lex_state = 22},
  [14102] = {.lex_state = 0, .external_lex_state = 22},
  [14103] = {.lex_state = 0, .external_lex_state = 22},
  [14104] = {.lex_state = 0, .external_lex_state = 22},
  [14105] = {.lex_state = 0, .external_lex_state = 22},
  [14106] = {.lex_state = 0, .external_lex_state = 22},
  [14107] = {.lex_state = 0, .external_lex_state = 22},
  [14108] = {.lex_state = 0, .external_lex_state = 22},
  [14109] = {.lex_state = 0, .external_lex_state = 22},
  [14110] = {.lex_state = 0, .external_lex_state = 22},
  [14111] = {.lex_state = 0, .external_lex_state = 22},
  [14112] = {.lex_state = 0, .external_lex_state = 22},
  [14113] = {.lex_state = 0, .external_lex_state = 22},
  [14114] = {.lex_state = 0, .external_lex_state = 22},
  [14115] = {.lex_state = 0, .external_lex_state = 22},
  [14116] = {.lex_state = 0, .external_lex_state = 22},
  [14117] = {.lex_state = 0, .external_lex_state = 22},
  [14118] = {.lex_state = 0, .external_lex_state = 22},
  [14119] = {.lex_state = 0, .external_lex_state = 22},
  [14120] = {.lex_state = 0, .external_lex_state = 22},
  [14121] = {.lex_state = 0, .external_lex_state = 22},
  [14122] = {.lex_state = 0, .external_lex_state = 22},
  [14123] = {.lex_state = 0, .external_lex_state = 22},
  [14124] = {.lex_state = 0, .external_lex_state = 22},
  [14125] = {.lex_state = 0, .external_lex_state = 22},
  [14126] = {.lex_state = 0, .external_lex_state = 22},
  [14127] = {.lex_state = 0, .external_lex_state = 22},
  [14128] = {.lex_state = 117, .external_lex_state = 28},
  [14129] = {.lex_state = 0, .external_lex_state = 22},
  [14130] = {.lex_state = 0, .external_lex_state = 22},
  [14131] = {.lex_state = 0, .external_lex_state = 22},
  [14132] = {.lex_state = 0, .external_lex_state = 22},
  [14133] = {.lex_state = 0, .external_lex_state = 22},
  [14134] = {.lex_state = 117, .external_lex_state = 28},
  [14135] = {.lex_state = 0, .external_lex_state = 22},
  [14136] = {.lex_state = 0, .external_lex_state = 22},
  [14137] = {.lex_state = 0, .external_lex_state = 22},
  [14138] = {.lex_state = 0, .external_lex_state = 22},
  [14139] = {.lex_state = 117},
  [14140] = {.lex_state = 117},
  [14141] = {.lex_state = 117},
  [14142] = {.lex_state = 117},
  [14143] = {.lex_state = 117},
  [14144] = {.lex_state = 117},
  [14145] = {.lex_state = 0, .external_lex_state = 22},
  [14146] = {.lex_state = 117},
  [14147] = {.lex_state = 117},
  [14148] = {.lex_state = 0, .external_lex_state = 22},
  [14149] = {.lex_state = 0, .external_lex_state = 22},
  [14150] = {.lex_state = 117, .external_lex_state = 28},
  [14151] = {.lex_state = 117, .external_lex_state = 2},
  [14152] = {.lex_state = 0, .external_lex_state = 22},
  [14153] = {.lex_state = 0, .external_lex_state = 22},
  [14154] = {.lex_state = 0, .external_lex_state = 22},
  [14155] = {.lex_state = 0, .external_lex_state = 22},
  [14156] = {.lex_state = 0, .external_lex_state = 22},
  [14157] = {.lex_state = 0, .external_lex_state = 22},
  [14158] = {.lex_state = 0, .external_lex_state = 22},
  [14159] = {.lex_state = 0, .external_lex_state = 22},
  [14160] = {.lex_state = 0, .external_lex_state = 22},
  [14161] = {.lex_state = 0, .external_lex_state = 22},
  [14162] = {.lex_state = 0, .external_lex_state = 22},
  [14163] = {.lex_state = 0, .external_lex_state = 22},
  [14164] = {.lex_state = 0, .external_lex_state = 22},
  [14165] = {.lex_state = 0, .external_lex_state = 22},
  [14166] = {.lex_state = 0, .external_lex_state = 22},
  [14167] = {.lex_state = 0, .external_lex_state = 22},
  [14168] = {.lex_state = 0, .external_lex_state = 22},
  [14169] = {.lex_state = 0, .external_lex_state = 22},
  [14170] = {.lex_state = 0, .external_lex_state = 22},
  [14171] = {.lex_state = 0, .external_lex_state = 22},
  [14172] = {.lex_state = 0, .external_lex_state = 22},
  [14173] = {.lex_state = 0, .external_lex_state = 22},
  [14174] = {.lex_state = 0, .external_lex_state = 22},
  [14175] = {.lex_state = 0, .external_lex_state = 22},
  [14176] = {.lex_state = 0, .external_lex_state = 22},
  [14177] = {.lex_state = 0, .external_lex_state = 22},
  [14178] = {.lex_state = 0, .external_lex_state = 22},
  [14179] = {.lex_state = 0, .external_lex_state = 22},
  [14180] = {.lex_state = 0, .external_lex_state = 22},
  [14181] = {.lex_state = 0, .external_lex_state = 22},
  [14182] = {.lex_state = 0, .external_lex_state = 22},
  [14183] = {.lex_state = 0, .external_lex_state = 22},
  [14184] = {.lex_state = 0, .external_lex_state = 22},
  [14185] = {.lex_state = 0, .external_lex_state = 22},
  [14186] = {.lex_state = 0, .external_lex_state = 22},
  [14187] = {.lex_state = 0, .external_lex_state = 22},
  [14188] = {.lex_state = 0, .external_lex_state = 22},
  [14189] = {.lex_state = 0, .external_lex_state = 22},
  [14190] = {.lex_state = 0, .external_lex_state = 22},
  [14191] = {.lex_state = 0, .external_lex_state = 22},
  [14192] = {.lex_state = 0, .external_lex_state = 22},
  [14193] = {.lex_state = 0, .external_lex_state = 22},
  [14194] = {.lex_state = 0, .external_lex_state = 22},
  [14195] = {.lex_state = 0, .external_lex_state = 22},
  [14196] = {.lex_state = 0, .external_lex_state = 22},
  [14197] = {.lex_state = 0, .external_lex_state = 22},
  [14198] = {.lex_state = 0, .external_lex_state = 22},
  [14199] = {.lex_state = 0, .external_lex_state = 22},
  [14200] = {.lex_state = 0, .external_lex_state = 22},
  [14201] = {.lex_state = 0, .external_lex_state = 22},
  [14202] = {.lex_state = 0, .external_lex_state = 22},
  [14203] = {.lex_state = 0, .external_lex_state = 22},
  [14204] = {.lex_state = 0, .external_lex_state = 22},
  [14205] = {.lex_state = 0, .external_lex_state = 22},
  [14206] = {.lex_state = 0, .external_lex_state = 22},
  [14207] = {.lex_state = 0, .external_lex_state = 22},
  [14208] = {.lex_state = 0, .external_lex_state = 22},
  [14209] = {.lex_state = 0, .external_lex_state = 22},
  [14210] = {.lex_state = 0, .external_lex_state = 22},
  [14211] = {.lex_state = 0, .external_lex_state = 22},
  [14212] = {.lex_state = 0, .external_lex_state = 22},
  [14213] = {.lex_state = 0, .external_lex_state = 22},
  [14214] = {.lex_state = 0, .external_lex_state = 22},
  [14215] = {.lex_state = 0, .external_lex_state = 22},
  [14216] = {.lex_state = 0, .external_lex_state = 22},
  [14217] = {.lex_state = 0, .external_lex_state = 22},
  [14218] = {.lex_state = 0, .external_lex_state = 22},
  [14219] = {.lex_state = 0, .external_lex_state = 22},
  [14220] = {.lex_state = 0, .external_lex_state = 22},
  [14221] = {.lex_state = 0, .external_lex_state = 22},
  [14222] = {.lex_state = 0, .external_lex_state = 22},
  [14223] = {.lex_state = 0, .external_lex_state = 22},
  [14224] = {.lex_state = 0, .external_lex_state = 22},
  [14225] = {.lex_state = 0, .external_lex_state = 22},
  [14226] = {.lex_state = 0, .external_lex_state = 22},
  [14227] = {.lex_state = 0, .external_lex_state = 22},
  [14228] = {.lex_state = 0, .external_lex_state = 22},
  [14229] = {.lex_state = 0, .external_lex_state = 22},
  [14230] = {.lex_state = 0, .external_lex_state = 22},
  [14231] = {.lex_state = 117, .external_lex_state = 2},
  [14232] = {.lex_state = 0, .external_lex_state = 22},
  [14233] = {.lex_state = 0, .external_lex_state = 22},
  [14234] = {.lex_state = 0, .external_lex_state = 22},
  [14235] = {.lex_state = 0, .external_lex_state = 22},
  [14236] = {.lex_state = 0, .external_lex_state = 22},
  [14237] = {.lex_state = 0, .external_lex_state = 22},
  [14238] = {.lex_state = 0, .external_lex_state = 22},
  [14239] = {.lex_state = 117, .external_lex_state = 2},
  [14240] = {.lex_state = 0, .external_lex_state = 22},
  [14241] = {.lex_state = 0, .external_lex_state = 22},
  [14242] = {.lex_state = 0, .external_lex_state = 22},
  [14243] = {.lex_state = 0, .external_lex_state = 22},
  [14244] = {.lex_state = 0, .external_lex_state = 22},
  [14245] = {.lex_state = 117, .external_lex_state = 2},
  [14246] = {.lex_state = 0, .external_lex_state = 22},
  [14247] = {.lex_state = 0, .external_lex_state = 22},
  [14248] = {.lex_state = 0, .external_lex_state = 22},
  [14249] = {.lex_state = 0, .external_lex_state = 22},
  [14250] = {.lex_state = 0, .external_lex_state = 22},
  [14251] = {.lex_state = 0, .external_lex_state = 22},
  [14252] = {.lex_state = 0, .external_lex_state = 22},
  [14253] = {.lex_state = 0, .external_lex_state = 22},
  [14254] = {.lex_state = 0, .external_lex_state = 22},
  [14255] = {.lex_state = 0, .external_lex_state = 22},
  [14256] = {.lex_state = 0, .external_lex_state = 22},
  [14257] = {.lex_state = 117, .external_lex_state = 2},
  [14258] = {.lex_state = 0, .external_lex_state = 22},
  [14259] = {.lex_state = 0, .external_lex_state = 22},
  [14260] = {.lex_state = 0, .external_lex_state = 22},
  [14261] = {.lex_state = 0, .external_lex_state = 22},
  [14262] = {.lex_state = 0, .external_lex_state = 22},
  [14263] = {.lex_state = 0, .external_lex_state = 22},
  [14264] = {.lex_state = 117, .external_lex_state = 2},
  [14265] = {.lex_state = 117, .external_lex_state = 2},
  [14266] = {.lex_state = 0, .external_lex_state = 22},
  [14267] = {.lex_state = 0, .external_lex_state = 22},
  [14268] = {.lex_state = 0, .external_lex_state = 22},
  [14269] = {.lex_state = 0, .external_lex_state = 22},
  [14270] = {.lex_state = 0, .external_lex_state = 22},
  [14271] = {.lex_state = 0, .external_lex_state = 22},
  [14272] = {.lex_state = 0, .external_lex_state = 22},
  [14273] = {.lex_state = 0, .external_lex_state = 22},
  [14274] = {.lex_state = 0, .external_lex_state = 22},
  [14275] = {.lex_state = 0, .external_lex_state = 22},
  [14276] = {.lex_state = 0, .external_lex_state = 22},
  [14277] = {.lex_state = 0, .external_lex_state = 22},
  [14278] = {.lex_state = 0, .external_lex_state = 22},
  [14279] = {.lex_state = 0, .external_lex_state = 22},
  [14280] = {.lex_state = 0, .external_lex_state = 22},
  [14281] = {.lex_state = 0, .external_lex_state = 22},
  [14282] = {.lex_state = 0, .external_lex_state = 22},
  [14283] = {.lex_state = 0, .external_lex_state = 22},
  [14284] = {.lex_state = 0, .external_lex_state = 22},
  [14285] = {.lex_state = 0, .external_lex_state = 22},
  [14286] = {.lex_state = 0, .external_lex_state = 22},
  [14287] = {.lex_state = 0, .external_lex_state = 22},
  [14288] = {.lex_state = 0, .external_lex_state = 22},
  [14289] = {.lex_state = 0, .external_lex_state = 22},
  [14290] = {.lex_state = 0, .external_lex_state = 22},
  [14291] = {.lex_state = 0, .external_lex_state = 22},
  [14292] = {.lex_state = 0, .external_lex_state = 22},
  [14293] = {.lex_state = 0, .external_lex_state = 22},
  [14294] = {.lex_state = 0, .external_lex_state = 22},
  [14295] = {.lex_state = 0, .external_lex_state = 22},
  [14296] = {.lex_state = 0, .external_lex_state = 22},
  [14297] = {.lex_state = 0, .external_lex_state = 22},
  [14298] = {.lex_state = 0, .external_lex_state = 22},
  [14299] = {.lex_state = 0, .external_lex_state = 22},
  [14300] = {.lex_state = 0, .external_lex_state = 22},
  [14301] = {.lex_state = 0, .external_lex_state = 22},
  [14302] = {.lex_state = 0, .external_lex_state = 22},
  [14303] = {.lex_state = 0, .external_lex_state = 22},
  [14304] = {.lex_state = 0, .external_lex_state = 22},
  [14305] = {.lex_state = 0, .external_lex_state = 22},
  [14306] = {.lex_state = 0, .external_lex_state = 22},
  [14307] = {.lex_state = 0, .external_lex_state = 22},
  [14308] = {.lex_state = 0, .external_lex_state = 22},
  [14309] = {.lex_state = 0, .external_lex_state = 22},
  [14310] = {.lex_state = 0, .external_lex_state = 22},
  [14311] = {.lex_state = 0, .external_lex_state = 22},
  [14312] = {.lex_state = 0, .external_lex_state = 22},
  [14313] = {.lex_state = 0, .external_lex_state = 22},
  [14314] = {.lex_state = 0, .external_lex_state = 22},
  [14315] = {.lex_state = 0, .external_lex_state = 22},
  [14316] = {.lex_state = 0, .external_lex_state = 22},
  [14317] = {.lex_state = 0, .external_lex_state = 22},
  [14318] = {.lex_state = 0, .external_lex_state = 22},
  [14319] = {.lex_state = 0, .external_lex_state = 22},
  [14320] = {.lex_state = 0, .external_lex_state = 22},
  [14321] = {.lex_state = 0, .external_lex_state = 22},
  [14322] = {.lex_state = 0, .external_lex_state = 22},
  [14323] = {.lex_state = 0, .external_lex_state = 22},
  [14324] = {.lex_state = 0, .external_lex_state = 22},
  [14325] = {.lex_state = 0, .external_lex_state = 22},
  [14326] = {.lex_state = 0, .external_lex_state = 22},
  [14327] = {.lex_state = 0, .external_lex_state = 22},
  [14328] = {.lex_state = 0, .external_lex_state = 22},
  [14329] = {.lex_state = 0, .external_lex_state = 22},
  [14330] = {.lex_state = 0, .external_lex_state = 22},
  [14331] = {.lex_state = 0, .external_lex_state = 22},
  [14332] = {.lex_state = 0, .external_lex_state = 22},
  [14333] = {.lex_state = 0, .external_lex_state = 22},
  [14334] = {.lex_state = 0, .external_lex_state = 22},
  [14335] = {.lex_state = 0, .external_lex_state = 22},
  [14336] = {.lex_state = 117},
  [14337] = {.lex_state = 0, .external_lex_state = 22},
  [14338] = {.lex_state = 0, .external_lex_state = 22},
  [14339] = {.lex_state = 0, .external_lex_state = 22},
  [14340] = {.lex_state = 0, .external_lex_state = 22},
  [14341] = {.lex_state = 0, .external_lex_state = 22},
  [14342] = {.lex_state = 0, .external_lex_state = 22},
  [14343] = {.lex_state = 0, .external_lex_state = 22},
  [14344] = {.lex_state = 0, .external_lex_state = 22},
  [14345] = {.lex_state = 0, .external_lex_state = 22},
  [14346] = {.lex_state = 0, .external_lex_state = 22},
  [14347] = {.lex_state = 0, .external_lex_state = 22},
  [14348] = {.lex_state = 0, .external_lex_state = 22},
  [14349] = {.lex_state = 0, .external_lex_state = 22},
  [14350] = {.lex_state = 0, .external_lex_state = 22},
  [14351] = {.lex_state = 0, .external_lex_state = 22},
  [14352] = {.lex_state = 0, .external_lex_state = 22},
  [14353] = {.lex_state = 0, .external_lex_state = 22},
  [14354] = {.lex_state = 0, .external_lex_state = 22},
  [14355] = {.lex_state = 0, .external_lex_state = 22},
  [14356] = {.lex_state = 0, .external_lex_state = 22},
  [14357] = {.lex_state = 0, .external_lex_state = 22},
  [14358] = {.lex_state = 0, .external_lex_state = 22},
  [14359] = {.lex_state = 0, .external_lex_state = 22},
  [14360] = {.lex_state = 0, .external_lex_state = 22},
  [14361] = {.lex_state = 0, .external_lex_state = 22},
  [14362] = {.lex_state = 0, .external_lex_state = 22},
  [14363] = {.lex_state = 0, .external_lex_state = 22},
  [14364] = {.lex_state = 0, .external_lex_state = 22},
  [14365] = {.lex_state = 0, .external_lex_state = 22},
  [14366] = {.lex_state = 0, .external_lex_state = 22},
  [14367] = {.lex_state = 0, .external_lex_state = 22},
  [14368] = {.lex_state = 0, .external_lex_state = 22},
  [14369] = {.lex_state = 0, .external_lex_state = 22},
  [14370] = {.lex_state = 0, .external_lex_state = 22},
  [14371] = {.lex_state = 0, .external_lex_state = 22},
  [14372] = {.lex_state = 0, .external_lex_state = 22},
  [14373] = {.lex_state = 0, .external_lex_state = 22},
  [14374] = {.lex_state = 0, .external_lex_state = 22},
  [14375] = {.lex_state = 0, .external_lex_state = 22},
  [14376] = {.lex_state = 0, .external_lex_state = 22},
  [14377] = {.lex_state = 0, .external_lex_state = 22},
  [14378] = {.lex_state = 0, .external_lex_state = 22},
  [14379] = {.lex_state = 117},
  [14380] = {.lex_state = 0, .external_lex_state = 22},
  [14381] = {.lex_state = 117},
  [14382] = {.lex_state = 0, .external_lex_state = 22},
  [14383] = {.lex_state = 0, .external_lex_state = 22},
  [14384] = {.lex_state = 0, .external_lex_state = 22},
  [14385] = {.lex_state = 0, .external_lex_state = 22},
  [14386] = {.lex_state = 0, .external_lex_state = 22},
  [14387] = {.lex_state = 0, .external_lex_state = 22},
  [14388] = {.lex_state = 0, .external_lex_state = 22},
  [14389] = {.lex_state = 0, .external_lex_state = 22},
  [14390] = {.lex_state = 0, .external_lex_state = 22},
  [14391] = {.lex_state = 0, .external_lex_state = 22},
  [14392] = {.lex_state = 0, .external_lex_state = 22},
  [14393] = {.lex_state = 0, .external_lex_state = 22},
  [14394] = {.lex_state = 117},
  [14395] = {.lex_state = 0, .external_lex_state = 22},
  [14396] = {.lex_state = 0, .external_lex_state = 22},
  [14397] = {.lex_state = 0, .external_lex_state = 22},
  [14398] = {.lex_state = 0, .external_lex_state = 22},
  [14399] = {.lex_state = 0, .external_lex_state = 22},
  [14400] = {.lex_state = 0, .external_lex_state = 22},
  [14401] = {.lex_state = 117},
  [14402] = {.lex_state = 117},
  [14403] = {.lex_state = 0, .external_lex_state = 22},
  [14404] = {.lex_state = 0, .external_lex_state = 22},
  [14405] = {.lex_state = 0, .external_lex_state = 22},
  [14406] = {.lex_state = 0, .external_lex_state = 22},
  [14407] = {.lex_state = 0, .external_lex_state = 22},
  [14408] = {.lex_state = 0, .external_lex_state = 22},
  [14409] = {.lex_state = 0, .external_lex_state = 22},
  [14410] = {.lex_state = 0, .external_lex_state = 22},
  [14411] = {.lex_state = 0, .external_lex_state = 22},
  [14412] = {.lex_state = 0, .external_lex_state = 22},
  [14413] = {.lex_state = 0, .external_lex_state = 22},
  [14414] = {.lex_state = 0, .external_lex_state = 22},
  [14415] = {.lex_state = 0, .external_lex_state = 22},
  [14416] = {.lex_state = 0, .external_lex_state = 22},
  [14417] = {.lex_state = 0, .external_lex_state = 22},
  [14418] = {.lex_state = 0, .external_lex_state = 22},
  [14419] = {.lex_state = 0, .external_lex_state = 22},
  [14420] = {.lex_state = 0, .external_lex_state = 22},
  [14421] = {.lex_state = 0, .external_lex_state = 22},
  [14422] = {.lex_state = 0, .external_lex_state = 22},
  [14423] = {.lex_state = 0, .external_lex_state = 22},
  [14424] = {.lex_state = 0, .external_lex_state = 22},
  [14425] = {.lex_state = 0, .external_lex_state = 22},
  [14426] = {.lex_state = 0, .external_lex_state = 22},
  [14427] = {.lex_state = 0, .external_lex_state = 22},
  [14428] = {.lex_state = 0, .external_lex_state = 22},
  [14429] = {.lex_state = 0, .external_lex_state = 22},
  [14430] = {.lex_state = 0, .external_lex_state = 22},
  [14431] = {.lex_state = 0, .external_lex_state = 22},
  [14432] = {.lex_state = 0, .external_lex_state = 22},
  [14433] = {.lex_state = 0, .external_lex_state = 22},
  [14434] = {.lex_state = 0, .external_lex_state = 22},
  [14435] = {.lex_state = 0, .external_lex_state = 22},
  [14436] = {.lex_state = 0, .external_lex_state = 22},
  [14437] = {.lex_state = 0, .external_lex_state = 22},
  [14438] = {.lex_state = 0, .external_lex_state = 22},
  [14439] = {.lex_state = 0, .external_lex_state = 22},
  [14440] = {.lex_state = 0, .external_lex_state = 22},
  [14441] = {.lex_state = 0, .external_lex_state = 22},
  [14442] = {.lex_state = 0, .external_lex_state = 22},
  [14443] = {.lex_state = 0, .external_lex_state = 22},
  [14444] = {.lex_state = 0, .external_lex_state = 22},
  [14445] = {.lex_state = 0, .external_lex_state = 22},
  [14446] = {.lex_state = 0, .external_lex_state = 22},
  [14447] = {.lex_state = 0, .external_lex_state = 22},
  [14448] = {.lex_state = 0, .external_lex_state = 22},
  [14449] = {.lex_state = 0, .external_lex_state = 22},
  [14450] = {.lex_state = 0, .external_lex_state = 22},
  [14451] = {.lex_state = 0, .external_lex_state = 22},
  [14452] = {.lex_state = 0, .external_lex_state = 22},
  [14453] = {.lex_state = 0, .external_lex_state = 22},
  [14454] = {.lex_state = 0, .external_lex_state = 22},
  [14455] = {.lex_state = 0, .external_lex_state = 22},
  [14456] = {.lex_state = 0, .external_lex_state = 22},
  [14457] = {.lex_state = 0, .external_lex_state = 22},
  [14458] = {.lex_state = 0, .external_lex_state = 22},
  [14459] = {.lex_state = 0, .external_lex_state = 22},
  [14460] = {.lex_state = 0, .external_lex_state = 22},
  [14461] = {.lex_state = 0, .external_lex_state = 22},
  [14462] = {.lex_state = 0, .external_lex_state = 22},
  [14463] = {.lex_state = 0, .external_lex_state = 22},
  [14464] = {.lex_state = 0, .external_lex_state = 22},
  [14465] = {.lex_state = 0, .external_lex_state = 22},
  [14466] = {.lex_state = 0, .external_lex_state = 22},
  [14467] = {.lex_state = 0, .external_lex_state = 22},
  [14468] = {.lex_state = 0, .external_lex_state = 22},
  [14469] = {.lex_state = 0, .external_lex_state = 22},
  [14470] = {.lex_state = 0, .external_lex_state = 22},
  [14471] = {.lex_state = 0, .external_lex_state = 22},
  [14472] = {.lex_state = 0, .external_lex_state = 22},
  [14473] = {.lex_state = 0, .external_lex_state = 22},
  [14474] = {.lex_state = 0, .external_lex_state = 22},
  [14475] = {.lex_state = 0, .external_lex_state = 22},
  [14476] = {.lex_state = 0, .external_lex_state = 22},
  [14477] = {.lex_state = 0, .external_lex_state = 22},
  [14478] = {.lex_state = 0, .external_lex_state = 22},
  [14479] = {.lex_state = 0, .external_lex_state = 22},
  [14480] = {.lex_state = 0, .external_lex_state = 22},
  [14481] = {.lex_state = 0, .external_lex_state = 22},
  [14482] = {.lex_state = 0, .external_lex_state = 22},
  [14483] = {.lex_state = 0, .external_lex_state = 22},
  [14484] = {.lex_state = 0, .external_lex_state = 22},
  [14485] = {.lex_state = 0, .external_lex_state = 22},
  [14486] = {.lex_state = 0, .external_lex_state = 22},
  [14487] = {.lex_state = 117},
  [14488] = {.lex_state = 0, .external_lex_state = 22},
  [14489] = {.lex_state = 0, .external_lex_state = 22},
  [14490] = {.lex_state = 0, .external_lex_state = 22},
  [14491] = {.lex_state = 0, .external_lex_state = 22},
  [14492] = {.lex_state = 0, .external_lex_state = 22},
  [14493] = {.lex_state = 117},
  [14494] = {.lex_state = 0, .external_lex_state = 22},
  [14495] = {.lex_state = 117},
  [14496] = {.lex_state = 117, .external_lex_state = 2},
  [14497] = {.lex_state = 0, .external_lex_state = 22},
  [14498] = {.lex_state = 0, .external_lex_state = 22},
  [14499] = {.lex_state = 117, .external_lex_state = 2},
  [14500] = {.lex_state = 0, .external_lex_state = 22},
  [14501] = {.lex_state = 117},
  [14502] = {.lex_state = 117},
  [14503] = {.lex_state = 0, .external_lex_state = 22},
  [14504] = {.lex_state = 0, .external_lex_state = 22},
  [14505] = {.lex_state = 117},
  [14506] = {.lex_state = 0, .external_lex_state = 22},
  [14507] = {.lex_state = 0, .external_lex_state = 22},
  [14508] = {.lex_state = 0, .external_lex_state = 22},
  [14509] = {.lex_state = 117},
  [14510] = {.lex_state = 117},
  [14511] = {.lex_state = 117},
  [14512] = {.lex_state = 117, .external_lex_state = 28},
  [14513] = {.lex_state = 0, .external_lex_state = 22},
  [14514] = {.lex_state = 117},
  [14515] = {.lex_state = 117},
  [14516] = {.lex_state = 0, .external_lex_state = 22},
  [14517] = {.lex_state = 117, .external_lex_state = 2},
  [14518] = {.lex_state = 0, .external_lex_state = 22},
  [14519] = {.lex_state = 117, .external_lex_state = 28},
  [14520] = {.lex_state = 0, .external_lex_state = 22},
  [14521] = {.lex_state = 117, .external_lex_state = 2},
  [14522] = {.lex_state = 0, .external_lex_state = 22},
  [14523] = {.lex_state = 0, .external_lex_state = 22},
  [14524] = {.lex_state = 0, .external_lex_state = 22},
  [14525] = {.lex_state = 0, .external_lex_state = 22},
  [14526] = {.lex_state = 0, .external_lex_state = 22},
  [14527] = {.lex_state = 117},
  [14528] = {.lex_state = 0, .external_lex_state = 22},
  [14529] = {.lex_state = 0, .external_lex_state = 22},
  [14530] = {.lex_state = 117},
  [14531] = {.lex_state = 0, .external_lex_state = 22},
  [14532] = {.lex_state = 117, .external_lex_state = 2},
  [14533] = {.lex_state = 117, .external_lex_state = 2},
  [14534] = {.lex_state = 0, .external_lex_state = 22},
  [14535] = {.lex_state = 0, .external_lex_state = 22},
  [14536] = {.lex_state = 117},
  [14537] = {.lex_state = 0, .external_lex_state = 22},
  [14538] = {.lex_state = 117, .external_lex_state = 28},
  [14539] = {.lex_state = 0, .external_lex_state = 22},
  [14540] = {.lex_state = 117, .external_lex_state = 2},
  [14541] = {.lex_state = 0, .external_lex_state = 22},
  [14542] = {.lex_state = 0, .external_lex_state = 22},
  [14543] = {.lex_state = 117, .external_lex_state = 2},
  [14544] = {.lex_state = 0, .external_lex_state = 22},
  [14545] = {.lex_state = 117, .external_lex_state = 2},
  [14546] = {.lex_state = 0, .external_lex_state = 22},
  [14547] = {.lex_state = 0, .external_lex_state = 22},
  [14548] = {.lex_state = 0, .external_lex_state = 22},
  [14549] = {.lex_state = 0, .external_lex_state = 22},
  [14550] = {.lex_state = 117, .external_lex_state = 28},
  [14551] = {.lex_state = 0, .external_lex_state = 22},
  [14552] = {.lex_state = 0, .external_lex_state = 22},
  [14553] = {.lex_state = 0, .external_lex_state = 22},
  [14554] = {.lex_state = 0, .external_lex_state = 22},
  [14555] = {.lex_state = 0, .external_lex_state = 22},
  [14556] = {.lex_state = 0, .external_lex_state = 22},
  [14557] = {.lex_state = 0, .external_lex_state = 22},
  [14558] = {.lex_state = 0, .external_lex_state = 22},
  [14559] = {.lex_state = 0, .external_lex_state = 22},
  [14560] = {.lex_state = 0, .external_lex_state = 22},
  [14561] = {.lex_state = 0, .external_lex_state = 22},
  [14562] = {.lex_state = 0, .external_lex_state = 22},
  [14563] = {.lex_state = 0, .external_lex_state = 22},
  [14564] = {.lex_state = 0, .external_lex_state = 22},
  [14565] = {.lex_state = 117, .external_lex_state = 2},
  [14566] = {.lex_state = 0, .external_lex_state = 22},
  [14567] = {.lex_state = 0, .external_lex_state = 22},
  [14568] = {.lex_state = 0, .external_lex_state = 22},
  [14569] = {.lex_state = 0, .external_lex_state = 22},
  [14570] = {.lex_state = 0, .external_lex_state = 22},
  [14571] = {.lex_state = 0, .external_lex_state = 22},
  [14572] = {.lex_state = 0, .external_lex_state = 22},
  [14573] = {.lex_state = 0, .external_lex_state = 22},
  [14574] = {.lex_state = 0, .external_lex_state = 22},
  [14575] = {.lex_state = 0, .external_lex_state = 22},
  [14576] = {.lex_state = 0, .external_lex_state = 22},
  [14577] = {.lex_state = 0, .external_lex_state = 22},
  [14578] = {.lex_state = 0, .external_lex_state = 22},
  [14579] = {.lex_state = 117},
  [14580] = {.lex_state = 117},
  [14581] = {.lex_state = 117},
  [14582] = {.lex_state = 117},
  [14583] = {.lex_state = 0, .external_lex_state = 22},
  [14584] = {.lex_state = 0, .external_lex_state = 22},
  [14585] = {.lex_state = 0, .external_lex_state = 22},
  [14586] = {.lex_state = 117},
  [14587] = {.lex_state = 0, .external_lex_state = 22},
  [14588] = {.lex_state = 117, .external_lex_state = 2},
  [14589] = {.lex_state = 0, .external_lex_state = 22},
  [14590] = {.lex_state = 117, .external_lex_state = 28},
  [14591] = {.lex_state = 0, .external_lex_state = 22},
  [14592] = {.lex_state = 117},
  [14593] = {.lex_state = 0, .external_lex_state = 22},
  [14594] = {.lex_state = 0, .external_lex_state = 22},
  [14595] = {.lex_state = 0, .external_lex_state = 22},
  [14596] = {.lex_state = 0},
  [14597] = {.lex_state = 117},
  [14598] = {.lex_state = 117},
  [14599] = {.lex_state = 0, .external_lex_state = 22},
  [14600] = {.lex_state = 0, .external_lex_state = 22},
  [14601] = {.lex_state = 0},
  [14602] = {.lex_state = 0},
  [14603] = {.lex_state = 0},
  [14604] = {.lex_state = 0},
  [14605] = {.lex_state = 0},
  [14606] = {.lex_state = 0},
  [14607] = {.lex_state = 0},
  [14608] = {.lex_state = 0},
  [14609] = {.lex_state = 0},
  [14610] = {.lex_state = 0},
  [14611] = {.lex_state = 0},
  [14612] = {.lex_state = 0},
  [14613] = {.lex_state = 0},
  [14614] = {.lex_state = 0},
  [14615] = {.lex_state = 0},
  [14616] = {.lex_state = 0},
  [14617] = {.lex_state = 0},
  [14618] = {.lex_state = 0},
  [14619] = {.lex_state = 0},
  [14620] = {.lex_state = 0, .external_lex_state = 22},
  [14621] = {.lex_state = 0, .external_lex_state = 22},
  [14622] = {.lex_state = 0, .external_lex_state = 22},
  [14623] = {.lex_state = 0, .external_lex_state = 22},
  [14624] = {.lex_state = 0, .external_lex_state = 22},
  [14625] = {.lex_state = 0, .external_lex_state = 22},
  [14626] = {.lex_state = 0, .external_lex_state = 22},
  [14627] = {.lex_state = 0, .external_lex_state = 22},
  [14628] = {.lex_state = 0, .external_lex_state = 22},
  [14629] = {.lex_state = 0, .external_lex_state = 22},
  [14630] = {.lex_state = 0, .external_lex_state = 22},
  [14631] = {.lex_state = 117},
  [14632] = {.lex_state = 0, .external_lex_state = 22},
  [14633] = {.lex_state = 0, .external_lex_state = 22},
  [14634] = {.lex_state = 0, .external_lex_state = 22},
  [14635] = {.lex_state = 0, .external_lex_state = 22},
  [14636] = {.lex_state = 0, .external_lex_state = 22},
  [14637] = {.lex_state = 0, .external_lex_state = 22},
  [14638] = {.lex_state = 0, .external_lex_state = 22},
  [14639] = {.lex_state = 0, .external_lex_state = 22},
  [14640] = {.lex_state = 0, .external_lex_state = 22},
  [14641] = {.lex_state = 0, .external_lex_state = 22},
  [14642] = {.lex_state = 0, .external_lex_state = 22},
  [14643] = {.lex_state = 0, .external_lex_state = 22},
  [14644] = {.lex_state = 0, .external_lex_state = 22},
  [14645] = {.lex_state = 0, .external_lex_state = 22},
  [14646] = {.lex_state = 0, .external_lex_state = 22},
  [14647] = {.lex_state = 0, .external_lex_state = 22},
  [14648] = {.lex_state = 0, .external_lex_state = 22},
  [14649] = {.lex_state = 117},
  [14650] = {.lex_state = 0, .external_lex_state = 22},
  [14651] = {.lex_state = 0, .external_lex_state = 22},
  [14652] = {.lex_state = 0, .external_lex_state = 22},
  [14653] = {.lex_state = 0, .external_lex_state = 22},
  [14654] = {.lex_state = 0, .external_lex_state = 22},
  [14655] = {.lex_state = 0, .external_lex_state = 22},
  [14656] = {.lex_state = 0, .external_lex_state = 22},
  [14657] = {.lex_state = 0, .external_lex_state = 22},
  [14658] = {.lex_state = 0, .external_lex_state = 22},
  [14659] = {.lex_state = 0, .external_lex_state = 22},
  [14660] = {.lex_state = 0, .external_lex_state = 22},
  [14661] = {.lex_state = 0, .external_lex_state = 22},
  [14662] = {.lex_state = 0, .external_lex_state = 22},
  [14663] = {.lex_state = 0, .external_lex_state = 22},
  [14664] = {.lex_state = 0, .external_lex_state = 22},
  [14665] = {.lex_state = 0, .external_lex_state = 22},
  [14666] = {.lex_state = 0, .external_lex_state = 22},
  [14667] = {.lex_state = 0, .external_lex_state = 22},
  [14668] = {.lex_state = 0, .external_lex_state = 22},
  [14669] = {.lex_state = 0, .external_lex_state = 22},
  [14670] = {.lex_state = 0, .external_lex_state = 22},
  [14671] = {.lex_state = 0, .external_lex_state = 22},
  [14672] = {.lex_state = 0, .external_lex_state = 22},
  [14673] = {.lex_state = 0, .external_lex_state = 22},
  [14674] = {.lex_state = 0, .external_lex_state = 22},
  [14675] = {.lex_state = 0, .external_lex_state = 22},
  [14676] = {.lex_state = 117},
  [14677] = {.lex_state = 117, .external_lex_state = 2},
  [14678] = {.lex_state = 0, .external_lex_state = 22},
  [14679] = {.lex_state = 0},
  [14680] = {.lex_state = 117},
  [14681] = {.lex_state = 117},
  [14682] = {.lex_state = 117},
  [14683] = {.lex_state = 117},
  [14684] = {.lex_state = 117},
  [14685] = {.lex_state = 0},
  [14686] = {.lex_state = 0, .external_lex_state = 2},
  [14687] = {.lex_state = 117},
  [14688] = {.lex_state = 117, .external_lex_state = 2},
  [14689] = {.lex_state = 117, .external_lex_state = 2},
  [14690] = {.lex_state = 0},
  [14691] = {.lex_state = 117},
  [14692] = {.lex_state = 0, .external_lex_state = 2},
  [14693] = {.lex_state = 117, .external_lex_state = 2},
  [14694] = {.lex_state = 0, .external_lex_state = 2},
  [14695] = {.lex_state = 0, .external_lex_state = 2},
  [14696] = {.lex_state = 0},
  [14697] = {.lex_state = 0},
  [14698] = {.lex_state = 0},
  [14699] = {.lex_state = 0},
  [14700] = {.lex_state = 117, .external_lex_state = 2},
  [14701] = {.lex_state = 117},
  [14702] = {.lex_state = 0},
  [14703] = {.lex_state = 0},
  [14704] = {.lex_state = 0},
  [14705] = {.lex_state = 0},
  [14706] = {.lex_state = 0},
  [14707] = {.lex_state = 0},
  [14708] = {.lex_state = 0},
  [14709] = {.lex_state = 0},
  [14710] = {.lex_state = 117, .external_lex_state = 2},
  [14711] = {.lex_state = 117},
  [14712] = {.lex_state = 0, .external_lex_state = 2},
  [14713] = {.lex_state = 117},
  [14714] = {.lex_state = 117},
  [14715] = {.lex_state = 117, .external_lex_state = 2},
  [14716] = {.lex_state = 0},
  [14717] = {.lex_state = 117},
  [14718] = {.lex_state = 0},
  [14719] = {.lex_state = 117},
  [14720] = {.lex_state = 117},
  [14721] = {.lex_state = 0},
  [14722] = {.lex_state = 0},
  [14723] = {.lex_state = 0},
  [14724] = {.lex_state = 0},
  [14725] = {.lex_state = 0},
  [14726] = {.lex_state = 0},
  [14727] = {.lex_state = 0},
  [14728] = {.lex_state = 0},
  [14729] = {.lex_state = 0},
  [14730] = {.lex_state = 0},
  [14731] = {.lex_state = 0},
  [14732] = {.lex_state = 0},
  [14733] = {.lex_state = 0},
  [14734] = {.lex_state = 0},
  [14735] = {.lex_state = 0},
  [14736] = {.lex_state = 0},
  [14737] = {.lex_state = 0},
  [14738] = {.lex_state = 0},
  [14739] = {.lex_state = 117},
  [14740] = {.lex_state = 117},
  [14741] = {.lex_state = 117},
  [14742] = {.lex_state = 0},
  [14743] = {.lex_state = 0, .external_lex_state = 2},
  [14744] = {.lex_state = 0, .external_lex_state = 22},
  [14745] = {.lex_state = 117},
  [14746] = {.lex_state = 117, .external_lex_state = 2},
  [14747] = {.lex_state = 0, .external_lex_state = 2},
  [14748] = {.lex_state = 0},
  [14749] = {.lex_state = 117},
  [14750] = {.lex_state = 0},
  [14751] = {.lex_state = 0},
  [14752] = {.lex_state = 117},
  [14753] = {.lex_state = 117},
  [14754] = {.lex_state = 117},
  [14755] = {.lex_state = 117},
  [14756] = {.lex_state = 0},
  [14757] = {.lex_state = 117, .external_lex_state = 2},
  [14758] = {.lex_state = 117},
  [14759] = {.lex_state = 117},
  [14760] = {.lex_state = 117, .external_lex_state = 2},
  [14761] = {.lex_state = 0},
  [14762] = {.lex_state = 117},
  [14763] = {.lex_state = 117},
  [14764] = {.lex_state = 117},
  [14765] = {.lex_state = 117},
  [14766] = {.lex_state = 117},
  [14767] = {.lex_state = 117},
  [14768] = {.lex_state = 117},
  [14769] = {.lex_state = 117},
  [14770] = {.lex_state = 117},
  [14771] = {.lex_state = 117},
  [14772] = {.lex_state = 117},
  [14773] = {.lex_state = 117},
  [14774] = {.lex_state = 117},
  [14775] = {.lex_state = 117},
  [14776] = {.lex_state = 117},
  [14777] = {.lex_state = 117},
  [14778] = {.lex_state = 117},
  [14779] = {.lex_state = 117},
  [14780] = {.lex_state = 117},
  [14781] = {.lex_state = 117},
  [14782] = {.lex_state = 117},
  [14783] = {.lex_state = 117},
  [14784] = {.lex_state = 117},
  [14785] = {.lex_state = 117},
  [14786] = {.lex_state = 117},
  [14787] = {.lex_state = 117},
  [14788] = {.lex_state = 117},
  [14789] = {.lex_state = 117},
  [14790] = {.lex_state = 117},
  [14791] = {.lex_state = 117},
  [14792] = {.lex_state = 117},
  [14793] = {.lex_state = 117},
  [14794] = {.lex_state = 117},
  [14795] = {.lex_state = 117},
  [14796] = {.lex_state = 117},
  [14797] = {.lex_state = 117},
  [14798] = {.lex_state = 117},
  [14799] = {.lex_state = 117},
  [14800] = {.lex_state = 117},
  [14801] = {.lex_state = 117},
  [14802] = {.lex_state = 117},
  [14803] = {.lex_state = 117},
  [14804] = {.lex_state = 117},
  [14805] = {.lex_state = 117},
  [14806] = {.lex_state = 117},
  [14807] = {.lex_state = 117},
  [14808] = {.lex_state = 117},
  [14809] = {.lex_state = 117},
  [14810] = {.lex_state = 117},
  [14811] = {.lex_state = 117},
  [14812] = {.lex_state = 117},
  [14813] = {.lex_state = 117},
  [14814] = {.lex_state = 117},
  [14815] = {.lex_state = 117},
  [14816] = {.lex_state = 117},
  [14817] = {.lex_state = 117},
  [14818] = {.lex_state = 117},
  [14819] = {.lex_state = 117},
  [14820] = {.lex_state = 117},
  [14821] = {.lex_state = 117},
  [14822] = {.lex_state = 117},
  [14823] = {.lex_state = 117},
  [14824] = {.lex_state = 117},
  [14825] = {.lex_state = 117},
  [14826] = {.lex_state = 117},
  [14827] = {.lex_state = 117},
  [14828] = {.lex_state = 117},
  [14829] = {.lex_state = 117},
  [14830] = {.lex_state = 117},
  [14831] = {.lex_state = 117},
  [14832] = {.lex_state = 117},
  [14833] = {.lex_state = 117},
  [14834] = {.lex_state = 117},
  [14835] = {.lex_state = 117},
  [14836] = {.lex_state = 117},
  [14837] = {.lex_state = 117},
  [14838] = {.lex_state = 117},
  [14839] = {.lex_state = 117},
  [14840] = {.lex_state = 117},
  [14841] = {.lex_state = 117},
  [14842] = {.lex_state = 117},
  [14843] = {.lex_state = 117},
  [14844] = {.lex_state = 0, .external_lex_state = 2},
  [14845] = {.lex_state = 117},
  [14846] = {.lex_state = 117},
  [14847] = {.lex_state = 117},
  [14848] = {.lex_state = 117},
  [14849] = {.lex_state = 117},
  [14850] = {.lex_state = 117},
  [14851] = {.lex_state = 6},
  [14852] = {.lex_state = 117},
  [14853] = {.lex_state = 117},
  [14854] = {.lex_state = 117},
  [14855] = {.lex_state = 117},
  [14856] = {.lex_state = 5},
  [14857] = {.lex_state = 117},
  [14858] = {.lex_state = 117},
  [14859] = {.lex_state = 117},
  [14860] = {.lex_state = 5},
  [14861] = {.lex_state = 117},
  [14862] = {.lex_state = 117},
  [14863] = {.lex_state = 117},
  [14864] = {.lex_state = 117},
  [14865] = {.lex_state = 117},
  [14866] = {.lex_state = 117},
  [14867] = {.lex_state = 117},
  [14868] = {.lex_state = 117},
  [14869] = {.lex_state = 117},
  [14870] = {.lex_state = 117},
  [14871] = {.lex_state = 117},
  [14872] = {.lex_state = 117},
  [14873] = {.lex_state = 117},
  [14874] = {.lex_state = 117},
  [14875] = {.lex_state = 117},
  [14876] = {.lex_state = 117},
  [14877] = {.lex_state = 117},
  [14878] = {.lex_state = 117},
  [14879] = {.lex_state = 117},
  [14880] = {.lex_state = 117},
  [14881] = {.lex_state = 117},
  [14882] = {.lex_state = 117},
  [14883] = {.lex_state = 117},
  [14884] = {.lex_state = 117},
  [14885] = {.lex_state = 117},
  [14886] = {.lex_state = 117},
  [14887] = {.lex_state = 117},
  [14888] = {.lex_state = 117},
  [14889] = {.lex_state = 117},
  [14890] = {.lex_state = 117},
  [14891] = {.lex_state = 117},
  [14892] = {.lex_state = 117},
  [14893] = {.lex_state = 117},
  [14894] = {.lex_state = 117},
  [14895] = {.lex_state = 117},
  [14896] = {.lex_state = 117},
  [14897] = {.lex_state = 117},
  [14898] = {.lex_state = 117},
  [14899] = {.lex_state = 117},
  [14900] = {.lex_state = 117},
  [14901] = {.lex_state = 117},
  [14902] = {.lex_state = 117},
  [14903] = {.lex_state = 117},
  [14904] = {.lex_state = 117},
  [14905] = {.lex_state = 117},
  [14906] = {.lex_state = 117},
  [14907] = {.lex_state = 117},
  [14908] = {.lex_state = 117},
  [14909] = {.lex_state = 117},
  [14910] = {.lex_state = 117},
  [14911] = {.lex_state = 117},
  [14912] = {.lex_state = 117},
  [14913] = {.lex_state = 117},
  [14914] = {.lex_state = 117},
  [14915] = {.lex_state = 117},
  [14916] = {.lex_state = 117},
  [14917] = {.lex_state = 12},
  [14918] = {.lex_state = 117},
  [14919] = {.lex_state = 117},
  [14920] = {.lex_state = 117},
  [14921] = {.lex_state = 117},
  [14922] = {.lex_state = 117},
  [14923] = {.lex_state = 117},
  [14924] = {.lex_state = 117},
  [14925] = {.lex_state = 117},
  [14926] = {.lex_state = 117},
  [14927] = {.lex_state = 117},
  [14928] = {.lex_state = 117},
  [14929] = {.lex_state = 117},
  [14930] = {.lex_state = 117},
  [14931] = {.lex_state = 117},
  [14932] = {.lex_state = 117},
  [14933] = {.lex_state = 117},
  [14934] = {.lex_state = 117},
  [14935] = {.lex_state = 117},
  [14936] = {.lex_state = 6},
  [14937] = {.lex_state = 117},
  [14938] = {.lex_state = 117},
  [14939] = {.lex_state = 117},
  [14940] = {.lex_state = 117},
  [14941] = {.lex_state = 117},
  [14942] = {.lex_state = 117},
  [14943] = {.lex_state = 117},
  [14944] = {.lex_state = 117},
  [14945] = {.lex_state = 117},
  [14946] = {.lex_state = 117},
  [14947] = {.lex_state = 117},
  [14948] = {.lex_state = 117},
  [14949] = {.lex_state = 117},
  [14950] = {.lex_state = 0},
  [14951] = {.lex_state = 0, .external_lex_state = 2},
  [14952] = {.lex_state = 117},
  [14953] = {.lex_state = 117},
  [14954] = {.lex_state = 117},
  [14955] = {.lex_state = 117},
  [14956] = {.lex_state = 117},
  [14957] = {.lex_state = 117},
  [14958] = {.lex_state = 0},
  [14959] = {.lex_state = 117},
  [14960] = {.lex_state = 117},
  [14961] = {.lex_state = 117},
  [14962] = {.lex_state = 117},
  [14963] = {.lex_state = 117},
  [14964] = {.lex_state = 117},
  [14965] = {.lex_state = 117},
  [14966] = {.lex_state = 12},
  [14967] = {.lex_state = 0},
  [14968] = {.lex_state = 117},
  [14969] = {.lex_state = 117},
  [14970] = {.lex_state = 117},
  [14971] = {.lex_state = 117},
  [14972] = {.lex_state = 117},
  [14973] = {.lex_state = 117},
  [14974] = {.lex_state = 117},
  [14975] = {.lex_state = 117},
  [14976] = {.lex_state = 117},
  [14977] = {.lex_state = 117},
  [14978] = {.lex_state = 117},
  [14979] = {.lex_state = 117},
  [14980] = {.lex_state = 117},
  [14981] = {.lex_state = 117},
  [14982] = {.lex_state = 117},
  [14983] = {.lex_state = 117},
  [14984] = {.lex_state = 117},
  [14985] = {.lex_state = 117},
  [14986] = {.lex_state = 117},
  [14987] = {.lex_state = 117},
  [14988] = {.lex_state = 117},
  [14989] = {.lex_state = 117},
  [14990] = {.lex_state = 117},
  [14991] = {.lex_state = 0},
  [14992] = {.lex_state = 117},
  [14993] = {.lex_state = 117},
  [14994] = {.lex_state = 117},
  [14995] = {.lex_state = 117},
  [14996] = {.lex_state = 117},
  [14997] = {.lex_state = 117},
  [14998] = {.lex_state = 117},
  [14999] = {.lex_state = 117},
  [15000] = {.lex_state = 0},
  [15001] = {.lex_state = 117},
  [15002] = {.lex_state = 117},
  [15003] = {.lex_state = 117},
  [15004] = {.lex_state = 117},
  [15005] = {.lex_state = 117},
  [15006] = {.lex_state = 0, .external_lex_state = 2},
  [15007] = {.lex_state = 117},
  [15008] = {.lex_state = 117},
  [15009] = {.lex_state = 117},
  [15010] = {.lex_state = 117},
  [15011] = {.lex_state = 117},
  [15012] = {.lex_state = 117},
  [15013] = {.lex_state = 117},
  [15014] = {.lex_state = 117},
  [15015] = {.lex_state = 117},
  [15016] = {.lex_state = 117},
  [15017] = {.lex_state = 117},
  [15018] = {.lex_state = 117},
  [15019] = {.lex_state = 117},
  [15020] = {.lex_state = 117},
  [15021] = {.lex_state = 117},
  [15022] = {.lex_state = 117},
  [15023] = {.lex_state = 117},
  [15024] = {.lex_state = 117},
  [15025] = {.lex_state = 117},
  [15026] = {.lex_state = 117},
  [15027] = {.lex_state = 117},
  [15028] = {.lex_state = 117},
  [15029] = {.lex_state = 117},
  [15030] = {.lex_state = 117},
  [15031] = {.lex_state = 117},
  [15032] = {.lex_state = 117},
  [15033] = {.lex_state = 117},
  [15034] = {.lex_state = 117},
  [15035] = {.lex_state = 117},
  [15036] = {.lex_state = 117},
  [15037] = {.lex_state = 117},
  [15038] = {.lex_state = 117},
  [15039] = {.lex_state = 117},
  [15040] = {.lex_state = 117},
  [15041] = {.lex_state = 117},
  [15042] = {.lex_state = 117},
  [15043] = {.lex_state = 117},
  [15044] = {.lex_state = 117},
  [15045] = {.lex_state = 117},
  [15046] = {.lex_state = 117},
  [15047] = {.lex_state = 117},
  [15048] = {.lex_state = 117},
  [15049] = {.lex_state = 117},
  [15050] = {.lex_state = 117},
  [15051] = {.lex_state = 117},
  [15052] = {.lex_state = 117},
  [15053] = {.lex_state = 117},
  [15054] = {.lex_state = 117},
  [15055] = {.lex_state = 117},
  [15056] = {.lex_state = 117},
  [15057] = {.lex_state = 117},
  [15058] = {.lex_state = 117},
  [15059] = {.lex_state = 117},
  [15060] = {.lex_state = 117},
  [15061] = {.lex_state = 117},
  [15062] = {.lex_state = 117},
  [15063] = {.lex_state = 117},
  [15064] = {.lex_state = 117},
  [15065] = {.lex_state = 117},
  [15066] = {.lex_state = 117},
  [15067] = {.lex_state = 117},
  [15068] = {.lex_state = 117},
  [15069] = {.lex_state = 117},
  [15070] = {.lex_state = 117},
  [15071] = {.lex_state = 117},
  [15072] = {.lex_state = 117},
  [15073] = {.lex_state = 117},
  [15074] = {.lex_state = 117},
  [15075] = {.lex_state = 117},
  [15076] = {.lex_state = 117},
  [15077] = {.lex_state = 117},
  [15078] = {.lex_state = 117},
  [15079] = {.lex_state = 117},
  [15080] = {.lex_state = 117},
  [15081] = {.lex_state = 117},
  [15082] = {.lex_state = 117},
  [15083] = {.lex_state = 117},
  [15084] = {.lex_state = 117},
  [15085] = {.lex_state = 117},
  [15086] = {.lex_state = 117},
  [15087] = {.lex_state = 117},
  [15088] = {.lex_state = 117},
  [15089] = {.lex_state = 117},
  [15090] = {.lex_state = 117},
  [15091] = {.lex_state = 117},
  [15092] = {.lex_state = 117},
  [15093] = {.lex_state = 117},
  [15094] = {.lex_state = 117},
  [15095] = {.lex_state = 117},
  [15096] = {.lex_state = 117},
  [15097] = {.lex_state = 117},
  [15098] = {.lex_state = 117},
  [15099] = {.lex_state = 117},
  [15100] = {.lex_state = 117},
  [15101] = {.lex_state = 117},
  [15102] = {.lex_state = 117},
  [15103] = {.lex_state = 117},
  [15104] = {.lex_state = 117},
  [15105] = {.lex_state = 117},
  [15106] = {.lex_state = 117},
  [15107] = {.lex_state = 117},
  [15108] = {.lex_state = 117},
  [15109] = {.lex_state = 117},
  [15110] = {.lex_state = 117},
  [15111] = {.lex_state = 10},
  [15112] = {.lex_state = 117},
  [15113] = {.lex_state = 117},
  [15114] = {.lex_state = 117},
  [15115] = {.lex_state = 117},
  [15116] = {.lex_state = 117},
  [15117] = {.lex_state = 117},
  [15118] = {.lex_state = 117},
  [15119] = {.lex_state = 117},
  [15120] = {.lex_state = 117},
  [15121] = {.lex_state = 117},
  [15122] = {.lex_state = 117, .external_lex_state = 28},
  [15123] = {.lex_state = 117},
  [15124] = {.lex_state = 117},
  [15125] = {.lex_state = 117},
  [15126] = {.lex_state = 117},
  [15127] = {.lex_state = 117},
  [15128] = {.lex_state = 117},
  [15129] = {.lex_state = 117},
  [15130] = {.lex_state = 117},
  [15131] = {.lex_state = 117},
  [15132] = {.lex_state = 117},
  [15133] = {.lex_state = 117},
  [15134] = {.lex_state = 117},
  [15135] = {.lex_state = 117},
  [15136] = {.lex_state = 117},
  [15137] = {.lex_state = 117},
  [15138] = {.lex_state = 117},
  [15139] = {.lex_state = 117},
  [15140] = {.lex_state = 117},
  [15141] = {.lex_state = 117},
  [15142] = {.lex_state = 117},
  [15143] = {.lex_state = 117},
  [15144] = {.lex_state = 117},
  [15145] = {.lex_state = 117},
  [15146] = {.lex_state = 117},
  [15147] = {.lex_state = 117},
  [15148] = {.lex_state = 117},
  [15149] = {.lex_state = 117},
  [15150] = {.lex_state = 117},
  [15151] = {.lex_state = 117},
  [15152] = {.lex_state = 117},
  [15153] = {.lex_state = 117},
  [15154] = {.lex_state = 117},
  [15155] = {.lex_state = 117},
  [15156] = {.lex_state = 117},
  [15157] = {.lex_state = 117},
  [15158] = {.lex_state = 117},
  [15159] = {.lex_state = 117},
  [15160] = {.lex_state = 117},
  [15161] = {.lex_state = 117},
  [15162] = {.lex_state = 117},
  [15163] = {.lex_state = 117},
  [15164] = {.lex_state = 117},
  [15165] = {.lex_state = 117},
  [15166] = {.lex_state = 117},
  [15167] = {.lex_state = 117},
  [15168] = {.lex_state = 117},
  [15169] = {.lex_state = 117},
  [15170] = {.lex_state = 117},
  [15171] = {.lex_state = 117},
  [15172] = {.lex_state = 117},
  [15173] = {.lex_state = 117},
  [15174] = {.lex_state = 117},
  [15175] = {.lex_state = 117},
  [15176] = {.lex_state = 117},
  [15177] = {.lex_state = 117},
  [15178] = {.lex_state = 117},
  [15179] = {.lex_state = 117},
  [15180] = {.lex_state = 117},
  [15181] = {.lex_state = 117},
  [15182] = {.lex_state = 117},
  [15183] = {.lex_state = 117},
  [15184] = {.lex_state = 117},
  [15185] = {.lex_state = 117},
  [15186] = {.lex_state = 117},
  [15187] = {.lex_state = 117},
  [15188] = {.lex_state = 117},
  [15189] = {.lex_state = 117},
  [15190] = {.lex_state = 117},
  [15191] = {.lex_state = 117, .external_lex_state = 28},
  [15192] = {.lex_state = 117},
  [15193] = {.lex_state = 117},
  [15194] = {.lex_state = 117},
  [15195] = {.lex_state = 117},
  [15196] = {.lex_state = 117},
  [15197] = {.lex_state = 117},
  [15198] = {.lex_state = 117},
  [15199] = {.lex_state = 117},
  [15200] = {.lex_state = 117, .external_lex_state = 28},
  [15201] = {.lex_state = 117},
  [15202] = {.lex_state = 117},
  [15203] = {.lex_state = 117},
  [15204] = {.lex_state = 117},
  [15205] = {.lex_state = 117},
  [15206] = {.lex_state = 117},
  [15207] = {.lex_state = 117, .external_lex_state = 28},
  [15208] = {.lex_state = 117},
  [15209] = {.lex_state = 117},
  [15210] = {.lex_state = 117},
  [15211] = {.lex_state = 117},
  [15212] = {.lex_state = 117},
  [15213] = {.lex_state = 117},
  [15214] = {.lex_state = 117, .external_lex_state = 28},
  [15215] = {.lex_state = 117},
  [15216] = {.lex_state = 117},
  [15217] = {.lex_state = 117},
  [15218] = {.lex_state = 117},
  [15219] = {.lex_state = 117},
  [15220] = {.lex_state = 117},
  [15221] = {.lex_state = 117},
  [15222] = {.lex_state = 117},
  [15223] = {.lex_state = 117},
  [15224] = {.lex_state = 117},
  [15225] = {.lex_state = 117},
  [15226] = {.lex_state = 117},
  [15227] = {.lex_state = 117},
  [15228] = {.lex_state = 117},
  [15229] = {.lex_state = 117},
  [15230] = {.lex_state = 117},
  [15231] = {.lex_state = 117},
  [15232] = {.lex_state = 117},
  [15233] = {.lex_state = 117},
  [15234] = {.lex_state = 117},
  [15235] = {.lex_state = 117},
  [15236] = {.lex_state = 117},
  [15237] = {.lex_state = 117},
  [15238] = {.lex_state = 117},
  [15239] = {.lex_state = 117},
  [15240] = {.lex_state = 117},
  [15241] = {.lex_state = 117},
  [15242] = {.lex_state = 117},
  [15243] = {.lex_state = 117},
  [15244] = {.lex_state = 117},
  [15245] = {.lex_state = 117},
  [15246] = {.lex_state = 117},
  [15247] = {.lex_state = 117},
  [15248] = {.lex_state = 117},
  [15249] = {.lex_state = 117},
  [15250] = {.lex_state = 117},
  [15251] = {.lex_state = 0},
  [15252] = {.lex_state = 117},
  [15253] = {.lex_state = 117},
  [15254] = {.lex_state = 117},
  [15255] = {.lex_state = 117},
  [15256] = {.lex_state = 117},
  [15257] = {.lex_state = 117},
  [15258] = {.lex_state = 117},
  [15259] = {.lex_state = 117},
  [15260] = {.lex_state = 117},
  [15261] = {.lex_state = 117},
  [15262] = {.lex_state = 117},
  [15263] = {.lex_state = 117},
  [15264] = {.lex_state = 117},
  [15265] = {.lex_state = 117},
  [15266] = {.lex_state = 117},
  [15267] = {.lex_state = 117},
  [15268] = {.lex_state = 117},
  [15269] = {.lex_state = 117},
  [15270] = {.lex_state = 117},
  [15271] = {.lex_state = 117},
  [15272] = {.lex_state = 117},
  [15273] = {.lex_state = 117},
  [15274] = {.lex_state = 117},
  [15275] = {.lex_state = 117},
  [15276] = {.lex_state = 117},
  [15277] = {.lex_state = 117},
  [15278] = {.lex_state = 117},
  [15279] = {.lex_state = 117},
  [15280] = {.lex_state = 117},
  [15281] = {.lex_state = 117},
  [15282] = {.lex_state = 117},
  [15283] = {.lex_state = 117},
  [15284] = {.lex_state = 117},
  [15285] = {.lex_state = 117},
  [15286] = {.lex_state = 117},
  [15287] = {.lex_state = 117},
  [15288] = {.lex_state = 117},
  [15289] = {.lex_state = 117},
  [15290] = {.lex_state = 117},
  [15291] = {.lex_state = 117},
  [15292] = {.lex_state = 117},
  [15293] = {.lex_state = 117},
  [15294] = {.lex_state = 117},
  [15295] = {.lex_state = 117},
  [15296] = {.lex_state = 117},
  [15297] = {.lex_state = 117},
  [15298] = {.lex_state = 117},
  [15299] = {.lex_state = 117},
  [15300] = {.lex_state = 117},
  [15301] = {.lex_state = 117},
  [15302] = {.lex_state = 117},
  [15303] = {.lex_state = 117},
  [15304] = {.lex_state = 117},
  [15305] = {.lex_state = 117},
  [15306] = {.lex_state = 117},
  [15307] = {.lex_state = 117},
  [15308] = {.lex_state = 117},
  [15309] = {.lex_state = 117},
  [15310] = {.lex_state = 117},
  [15311] = {.lex_state = 117},
  [15312] = {.lex_state = 117},
  [15313] = {.lex_state = 117},
  [15314] = {.lex_state = 117},
  [15315] = {.lex_state = 117},
  [15316] = {.lex_state = 117},
  [15317] = {.lex_state = 117},
  [15318] = {.lex_state = 117},
  [15319] = {.lex_state = 117},
  [15320] = {.lex_state = 117},
  [15321] = {.lex_state = 117},
  [15322] = {.lex_state = 117},
  [15323] = {.lex_state = 117},
  [15324] = {.lex_state = 117},
  [15325] = {.lex_state = 117},
  [15326] = {.lex_state = 117},
  [15327] = {.lex_state = 117},
  [15328] = {.lex_state = 117},
  [15329] = {.lex_state = 117},
  [15330] = {.lex_state = 117},
  [15331] = {.lex_state = 117},
  [15332] = {.lex_state = 117},
  [15333] = {.lex_state = 117},
  [15334] = {.lex_state = 117},
  [15335] = {.lex_state = 117},
  [15336] = {.lex_state = 117},
  [15337] = {.lex_state = 117},
  [15338] = {.lex_state = 117},
  [15339] = {.lex_state = 117},
  [15340] = {.lex_state = 117},
  [15341] = {.lex_state = 117},
  [15342] = {.lex_state = 117},
  [15343] = {.lex_state = 117},
  [15344] = {.lex_state = 117},
  [15345] = {.lex_state = 117},
  [15346] = {.lex_state = 117},
  [15347] = {.lex_state = 117},
  [15348] = {.lex_state = 117},
  [15349] = {.lex_state = 117},
  [15350] = {.lex_state = 117},
  [15351] = {.lex_state = 117},
  [15352] = {.lex_state = 117},
  [15353] = {.lex_state = 117},
  [15354] = {.lex_state = 117},
  [15355] = {.lex_state = 117},
  [15356] = {.lex_state = 117},
  [15357] = {.lex_state = 117},
  [15358] = {.lex_state = 117},
  [15359] = {.lex_state = 117},
  [15360] = {.lex_state = 117},
  [15361] = {.lex_state = 117},
  [15362] = {.lex_state = 117},
  [15363] = {.lex_state = 117},
  [15364] = {.lex_state = 117},
  [15365] = {.lex_state = 117},
  [15366] = {.lex_state = 117},
  [15367] = {.lex_state = 117},
  [15368] = {.lex_state = 117},
  [15369] = {.lex_state = 117},
  [15370] = {.lex_state = 117},
  [15371] = {.lex_state = 117},
  [15372] = {.lex_state = 117},
  [15373] = {.lex_state = 117},
  [15374] = {.lex_state = 117},
  [15375] = {.lex_state = 117},
  [15376] = {.lex_state = 117},
  [15377] = {.lex_state = 117},
  [15378] = {.lex_state = 117},
  [15379] = {.lex_state = 117},
  [15380] = {.lex_state = 117},
  [15381] = {.lex_state = 117},
  [15382] = {.lex_state = 117},
  [15383] = {.lex_state = 117},
  [15384] = {.lex_state = 117},
  [15385] = {.lex_state = 117},
  [15386] = {.lex_state = 117},
  [15387] = {.lex_state = 117},
  [15388] = {.lex_state = 117},
  [15389] = {.lex_state = 117},
  [15390] = {.lex_state = 117},
  [15391] = {.lex_state = 117},
  [15392] = {.lex_state = 117},
  [15393] = {.lex_state = 117},
  [15394] = {.lex_state = 117},
  [15395] = {.lex_state = 117},
  [15396] = {.lex_state = 117},
  [15397] = {.lex_state = 117},
  [15398] = {.lex_state = 117},
  [15399] = {.lex_state = 117},
  [15400] = {.lex_state = 117},
  [15401] = {.lex_state = 117},
  [15402] = {.lex_state = 117},
  [15403] = {.lex_state = 117},
  [15404] = {.lex_state = 117},
  [15405] = {.lex_state = 117},
  [15406] = {.lex_state = 117},
  [15407] = {.lex_state = 117},
  [15408] = {.lex_state = 117},
  [15409] = {.lex_state = 117},
  [15410] = {.lex_state = 117},
  [15411] = {.lex_state = 117},
  [15412] = {.lex_state = 117},
  [15413] = {.lex_state = 117},
  [15414] = {.lex_state = 117},
  [15415] = {.lex_state = 117},
  [15416] = {.lex_state = 117},
  [15417] = {.lex_state = 117},
  [15418] = {.lex_state = 117},
  [15419] = {.lex_state = 117},
  [15420] = {.lex_state = 117},
  [15421] = {.lex_state = 117},
  [15422] = {.lex_state = 117},
  [15423] = {.lex_state = 117},
  [15424] = {.lex_state = 117},
  [15425] = {.lex_state = 117},
  [15426] = {.lex_state = 117},
  [15427] = {.lex_state = 117},
  [15428] = {.lex_state = 117},
  [15429] = {.lex_state = 117},
  [15430] = {.lex_state = 117},
  [15431] = {.lex_state = 117},
  [15432] = {.lex_state = 117},
  [15433] = {.lex_state = 117},
  [15434] = {.lex_state = 117},
  [15435] = {.lex_state = 117},
  [15436] = {.lex_state = 117},
  [15437] = {.lex_state = 117},
  [15438] = {.lex_state = 117},
  [15439] = {.lex_state = 117},
  [15440] = {.lex_state = 117},
  [15441] = {.lex_state = 117},
  [15442] = {.lex_state = 117},
  [15443] = {.lex_state = 117},
  [15444] = {.lex_state = 117},
  [15445] = {.lex_state = 0},
  [15446] = {.lex_state = 117, .external_lex_state = 29},
  [15447] = {.lex_state = 0},
  [15448] = {.lex_state = 117, .external_lex_state = 29},
  [15449] = {.lex_state = 117, .external_lex_state = 29},
  [15450] = {.lex_state = 117, .external_lex_state = 29},
  [15451] = {.lex_state = 117, .external_lex_state = 29},
  [15452] = {.lex_state = 117, .external_lex_state = 29},
  [15453] = {.lex_state = 117, .external_lex_state = 29},
  [15454] = {.lex_state = 117, .external_lex_state = 29},
  [15455] = {.lex_state = 117, .external_lex_state = 29},
  [15456] = {.lex_state = 117, .external_lex_state = 29},
  [15457] = {.lex_state = 117, .external_lex_state = 29},
  [15458] = {.lex_state = 0},
  [15459] = {.lex_state = 117, .external_lex_state = 29},
  [15460] = {.lex_state = 117, .external_lex_state = 29},
  [15461] = {.lex_state = 117, .external_lex_state = 29},
  [15462] = {.lex_state = 117, .external_lex_state = 29},
  [15463] = {.lex_state = 117, .external_lex_state = 29},
  [15464] = {.lex_state = 117, .external_lex_state = 29},
  [15465] = {.lex_state = 117, .external_lex_state = 29},
  [15466] = {.lex_state = 117, .external_lex_state = 29},
  [15467] = {.lex_state = 117, .external_lex_state = 29},
  [15468] = {.lex_state = 117, .external_lex_state = 29},
  [15469] = {.lex_state = 117, .external_lex_state = 29},
  [15470] = {.lex_state = 117, .external_lex_state = 29},
  [15471] = {.lex_state = 0},
  [15472] = {.lex_state = 117, .external_lex_state = 29},
  [15473] = {.lex_state = 117, .external_lex_state = 29},
  [15474] = {.lex_state = 117, .external_lex_state = 29},
  [15475] = {.lex_state = 117, .external_lex_state = 29},
  [15476] = {.lex_state = 117, .external_lex_state = 29},
  [15477] = {.lex_state = 117, .external_lex_state = 29},
  [15478] = {.lex_state = 117, .external_lex_state = 29},
  [15479] = {.lex_state = 117, .external_lex_state = 29},
  [15480] = {.lex_state = 117, .external_lex_state = 29},
  [15481] = {.lex_state = 117, .external_lex_state = 29},
  [15482] = {.lex_state = 117, .external_lex_state = 29},
  [15483] = {.lex_state = 0},
  [15484] = {.lex_state = 117, .external_lex_state = 29},
  [15485] = {.lex_state = 0},
  [15486] = {.lex_state = 117, .external_lex_state = 29},
  [15487] = {.lex_state = 0},
  [15488] = {.lex_state = 117, .external_lex_state = 29},
  [15489] = {.lex_state = 117, .external_lex_state = 29},
  [15490] = {.lex_state = 117, .external_lex_state = 29},
  [15491] = {.lex_state = 0},
  [15492] = {.lex_state = 0},
  [15493] = {.lex_state = 117},
  [15494] = {.lex_state = 117, .external_lex_state = 29},
  [15495] = {.lex_state = 0},
  [15496] = {.lex_state = 117, .external_lex_state = 29},
  [15497] = {.lex_state = 117, .external_lex_state = 29},
  [15498] = {.lex_state = 117, .external_lex_state = 29},
  [15499] = {.lex_state = 0},
  [15500] = {.lex_state = 117, .external_lex_state = 29},
  [15501] = {.lex_state = 117, .external_lex_state = 29},
  [15502] = {.lex_state = 117, .external_lex_state = 29},
  [15503] = {.lex_state = 117, .external_lex_state = 29},
  [15504] = {.lex_state = 117, .external_lex_state = 29},
  [15505] = {.lex_state = 117, .external_lex_state = 29},
  [15506] = {.lex_state = 117, .external_lex_state = 29},
  [15507] = {.lex_state = 117, .external_lex_state = 29},
  [15508] = {.lex_state = 117, .external_lex_state = 29},
  [15509] = {.lex_state = 117, .external_lex_state = 29},
  [15510] = {.lex_state = 117, .external_lex_state = 29},
  [15511] = {.lex_state = 117, .external_lex_state = 29},
  [15512] = {.lex_state = 117, .external_lex_state = 29},
  [15513] = {.lex_state = 117, .external_lex_state = 29},
  [15514] = {.lex_state = 117, .external_lex_state = 29},
  [15515] = {.lex_state = 0},
  [15516] = {.lex_state = 117},
  [15517] = {.lex_state = 117},
  [15518] = {.lex_state = 117},
  [15519] = {.lex_state = 0},
  [15520] = {.lex_state = 117},
  [15521] = {.lex_state = 117},
  [15522] = {.lex_state = 0},
  [15523] = {.lex_state = 117, .external_lex_state = 29},
  [15524] = {.lex_state = 117, .external_lex_state = 29},
  [15525] = {.lex_state = 117, .external_lex_state = 29},
  [15526] = {.lex_state = 0},
  [15527] = {.lex_state = 117},
  [15528] = {.lex_state = 117, .external_lex_state = 29},
  [15529] = {.lex_state = 0},
  [15530] = {.lex_state = 0},
  [15531] = {.lex_state = 117, .external_lex_state = 29},
  [15532] = {.lex_state = 117},
  [15533] = {.lex_state = 117, .external_lex_state = 29},
  [15534] = {.lex_state = 117, .external_lex_state = 29},
  [15535] = {.lex_state = 0},
  [15536] = {.lex_state = 117, .external_lex_state = 29},
  [15537] = {.lex_state = 117, .external_lex_state = 29},
  [15538] = {.lex_state = 117, .external_lex_state = 29},
  [15539] = {.lex_state = 117, .external_lex_state = 29},
  [15540] = {.lex_state = 117, .external_lex_state = 29},
  [15541] = {.lex_state = 117, .external_lex_state = 29},
  [15542] = {.lex_state = 117, .external_lex_state = 29},
  [15543] = {.lex_state = 117, .external_lex_state = 29},
  [15544] = {.lex_state = 117},
  [15545] = {.lex_state = 117, .external_lex_state = 29},
  [15546] = {.lex_state = 117, .external_lex_state = 29},
  [15547] = {.lex_state = 117},
  [15548] = {.lex_state = 117, .external_lex_state = 29},
  [15549] = {.lex_state = 117, .external_lex_state = 29},
  [15550] = {.lex_state = 117, .external_lex_state = 29},
  [15551] = {.lex_state = 9},
  [15552] = {.lex_state = 117, .external_lex_state = 29},
  [15553] = {.lex_state = 117, .external_lex_state = 29},
  [15554] = {.lex_state = 117, .external_lex_state = 29},
  [15555] = {.lex_state = 117},
  [15556] = {.lex_state = 0},
  [15557] = {.lex_state = 0},
  [15558] = {.lex_state = 117, .external_lex_state = 29},
  [15559] = {.lex_state = 117, .external_lex_state = 29},
  [15560] = {.lex_state = 0},
  [15561] = {.lex_state = 117, .external_lex_state = 29},
  [15562] = {.lex_state = 117, .external_lex_state = 29},
  [15563] = {.lex_state = 0},
  [15564] = {.lex_state = 117, .external_lex_state = 29},
  [15565] = {.lex_state = 117, .external_lex_state = 29},
  [15566] = {.lex_state = 117, .external_lex_state = 29},
  [15567] = {.lex_state = 117},
  [15568] = {.lex_state = 0},
  [15569] = {.lex_state = 117, .external_lex_state = 29},
  [15570] = {.lex_state = 117, .external_lex_state = 29},
  [15571] = {.lex_state = 0},
  [15572] = {.lex_state = 0},
  [15573] = {.lex_state = 117, .external_lex_state = 29},
  [15574] = {.lex_state = 117, .external_lex_state = 29},
  [15575] = {.lex_state = 117, .external_lex_state = 29},
  [15576] = {.lex_state = 117, .external_lex_state = 29},
  [15577] = {.lex_state = 117, .external_lex_state = 29},
  [15578] = {.lex_state = 117, .external_lex_state = 29},
  [15579] = {.lex_state = 117, .external_lex_state = 29},
  [15580] = {.lex_state = 117, .external_lex_state = 29},
  [15581] = {.lex_state = 117, .external_lex_state = 29},
  [15582] = {.lex_state = 117, .external_lex_state = 29},
  [15583] = {.lex_state = 117, .external_lex_state = 29},
  [15584] = {.lex_state = 117, .external_lex_state = 29},
  [15585] = {.lex_state = 117, .external_lex_state = 29},
  [15586] = {.lex_state = 117, .external_lex_state = 29},
  [15587] = {.lex_state = 13},
  [15588] = {.lex_state = 117, .external_lex_state = 29},
  [15589] = {.lex_state = 117, .external_lex_state = 29},
  [15590] = {.lex_state = 117},
  [15591] = {.lex_state = 117, .external_lex_state = 29},
  [15592] = {.lex_state = 117, .external_lex_state = 29},
  [15593] = {.lex_state = 117, .external_lex_state = 29},
  [15594] = {.lex_state = 117, .external_lex_state = 29},
  [15595] = {.lex_state = 0},
  [15596] = {.lex_state = 117, .external_lex_state = 29},
  [15597] = {.lex_state = 117, .external_lex_state = 29},
  [15598] = {.lex_state = 117, .external_lex_state = 29},
  [15599] = {.lex_state = 117, .external_lex_state = 29},
  [15600] = {.lex_state = 117, .external_lex_state = 29},
  [15601] = {.lex_state = 117, .external_lex_state = 29},
  [15602] = {.lex_state = 117, .external_lex_state = 29},
  [15603] = {.lex_state = 0},
  [15604] = {.lex_state = 117, .external_lex_state = 29},
  [15605] = {.lex_state = 117, .external_lex_state = 29},
  [15606] = {.lex_state = 0},
  [15607] = {.lex_state = 117, .external_lex_state = 29},
  [15608] = {.lex_state = 117, .external_lex_state = 29},
  [15609] = {.lex_state = 0},
  [15610] = {.lex_state = 0},
  [15611] = {.lex_state = 117, .external_lex_state = 29},
  [15612] = {.lex_state = 117, .external_lex_state = 29},
  [15613] = {.lex_state = 117, .external_lex_state = 29},
  [15614] = {.lex_state = 117, .external_lex_state = 29},
  [15615] = {.lex_state = 117, .external_lex_state = 29},
  [15616] = {.lex_state = 117, .external_lex_state = 29},
  [15617] = {.lex_state = 117, .external_lex_state = 29},
  [15618] = {.lex_state = 117, .external_lex_state = 29},
  [15619] = {.lex_state = 0},
  [15620] = {.lex_state = 0},
  [15621] = {.lex_state = 117, .external_lex_state = 29},
  [15622] = {.lex_state = 117, .external_lex_state = 29},
  [15623] = {.lex_state = 117, .external_lex_state = 29},
  [15624] = {.lex_state = 0},
  [15625] = {.lex_state = 117, .external_lex_state = 29},
  [15626] = {.lex_state = 117, .external_lex_state = 29},
  [15627] = {.lex_state = 117, .external_lex_state = 29},
  [15628] = {.lex_state = 117},
  [15629] = {.lex_state = 117, .external_lex_state = 29},
  [15630] = {.lex_state = 117, .external_lex_state = 29},
  [15631] = {.lex_state = 0},
  [15632] = {.lex_state = 0},
  [15633] = {.lex_state = 117, .external_lex_state = 29},
  [15634] = {.lex_state = 117, .external_lex_state = 29},
  [15635] = {.lex_state = 0},
  [15636] = {.lex_state = 117, .external_lex_state = 29},
  [15637] = {.lex_state = 117, .external_lex_state = 29},
  [15638] = {.lex_state = 117, .external_lex_state = 29},
  [15639] = {.lex_state = 117, .external_lex_state = 29},
  [15640] = {.lex_state = 117, .external_lex_state = 29},
  [15641] = {.lex_state = 117, .external_lex_state = 29},
  [15642] = {.lex_state = 117, .external_lex_state = 29},
  [15643] = {.lex_state = 117, .external_lex_state = 29},
  [15644] = {.lex_state = 117, .external_lex_state = 29},
  [15645] = {.lex_state = 117, .external_lex_state = 29},
  [15646] = {.lex_state = 117, .external_lex_state = 29},
  [15647] = {.lex_state = 0},
  [15648] = {.lex_state = 117, .external_lex_state = 29},
  [15649] = {.lex_state = 0},
  [15650] = {.lex_state = 117, .external_lex_state = 29},
  [15651] = {.lex_state = 0},
  [15652] = {.lex_state = 117, .external_lex_state = 29},
  [15653] = {.lex_state = 117},
  [15654] = {.lex_state = 0},
  [15655] = {.lex_state = 117, .external_lex_state = 29},
  [15656] = {.lex_state = 117, .external_lex_state = 29},
  [15657] = {.lex_state = 0},
  [15658] = {.lex_state = 0},
  [15659] = {.lex_state = 117, .external_lex_state = 29},
  [15660] = {.lex_state = 117, .external_lex_state = 29},
  [15661] = {.lex_state = 117, .external_lex_state = 29},
  [15662] = {.lex_state = 117},
  [15663] = {.lex_state = 117, .external_lex_state = 29},
  [15664] = {.lex_state = 117, .external_lex_state = 29},
  [15665] = {.lex_state = 117, .external_lex_state = 29},
  [15666] = {.lex_state = 0},
  [15667] = {.lex_state = 0},
  [15668] = {.lex_state = 117, .external_lex_state = 29},
  [15669] = {.lex_state = 117, .external_lex_state = 29},
  [15670] = {.lex_state = 117, .external_lex_state = 29},
  [15671] = {.lex_state = 117, .external_lex_state = 29},
  [15672] = {.lex_state = 0},
  [15673] = {.lex_state = 117, .external_lex_state = 29},
  [15674] = {.lex_state = 0},
  [15675] = {.lex_state = 117, .external_lex_state = 29},
  [15676] = {.lex_state = 117, .external_lex_state = 29},
  [15677] = {.lex_state = 0},
  [15678] = {.lex_state = 0},
  [15679] = {.lex_state = 117, .external_lex_state = 29},
  [15680] = {.lex_state = 0},
  [15681] = {.lex_state = 117, .external_lex_state = 29},
  [15682] = {.lex_state = 117, .external_lex_state = 29},
  [15683] = {.lex_state = 117, .external_lex_state = 29},
  [15684] = {.lex_state = 0},
  [15685] = {.lex_state = 0},
  [15686] = {.lex_state = 117, .external_lex_state = 29},
  [15687] = {.lex_state = 117, .external_lex_state = 29},
  [15688] = {.lex_state = 117, .external_lex_state = 29},
  [15689] = {.lex_state = 117, .external_lex_state = 29},
  [15690] = {.lex_state = 117, .external_lex_state = 29},
  [15691] = {.lex_state = 117, .external_lex_state = 29},
  [15692] = {.lex_state = 117, .external_lex_state = 29},
  [15693] = {.lex_state = 117, .external_lex_state = 29},
  [15694] = {.lex_state = 0},
  [15695] = {.lex_state = 0},
  [15696] = {.lex_state = 117, .external_lex_state = 29},
  [15697] = {.lex_state = 117, .external_lex_state = 29},
  [15698] = {.lex_state = 117, .external_lex_state = 29},
  [15699] = {.lex_state = 117, .external_lex_state = 29},
  [15700] = {.lex_state = 117, .external_lex_state = 29},
  [15701] = {.lex_state = 117, .external_lex_state = 29},
  [15702] = {.lex_state = 117, .external_lex_state = 29},
  [15703] = {.lex_state = 117, .external_lex_state = 29},
  [15704] = {.lex_state = 117, .external_lex_state = 29},
  [15705] = {.lex_state = 0},
  [15706] = {.lex_state = 117, .external_lex_state = 29},
  [15707] = {.lex_state = 117, .external_lex_state = 29},
  [15708] = {.lex_state = 0},
  [15709] = {.lex_state = 117, .external_lex_state = 29},
  [15710] = {.lex_state = 117, .external_lex_state = 29},
  [15711] = {.lex_state = 117, .external_lex_state = 29},
  [15712] = {.lex_state = 0},
  [15713] = {.lex_state = 117, .external_lex_state = 29},
  [15714] = {.lex_state = 0},
  [15715] = {.lex_state = 117, .external_lex_state = 29},
  [15716] = {.lex_state = 117, .external_lex_state = 29},
  [15717] = {.lex_state = 117, .external_lex_state = 29},
  [15718] = {.lex_state = 117, .external_lex_state = 29},
  [15719] = {.lex_state = 117, .external_lex_state = 29},
  [15720] = {.lex_state = 117, .external_lex_state = 29},
  [15721] = {.lex_state = 117, .external_lex_state = 29},
  [15722] = {.lex_state = 117, .external_lex_state = 29},
  [15723] = {.lex_state = 117, .external_lex_state = 29},
  [15724] = {.lex_state = 117, .external_lex_state = 29},
  [15725] = {.lex_state = 117, .external_lex_state = 29},
  [15726] = {.lex_state = 117, .external_lex_state = 29},
  [15727] = {.lex_state = 117, .external_lex_state = 29},
  [15728] = {.lex_state = 117, .external_lex_state = 29},
  [15729] = {.lex_state = 117, .external_lex_state = 29},
  [15730] = {.lex_state = 117, .external_lex_state = 29},
  [15731] = {.lex_state = 117, .external_lex_state = 29},
  [15732] = {.lex_state = 117, .external_lex_state = 29},
  [15733] = {.lex_state = 117, .external_lex_state = 29},
  [15734] = {.lex_state = 117},
  [15735] = {.lex_state = 117, .external_lex_state = 29},
  [15736] = {.lex_state = 117, .external_lex_state = 29},
  [15737] = {.lex_state = 117},
  [15738] = {.lex_state = 117, .external_lex_state = 29},
  [15739] = {.lex_state = 117, .external_lex_state = 29},
  [15740] = {.lex_state = 117},
  [15741] = {.lex_state = 117, .external_lex_state = 29},
  [15742] = {.lex_state = 117, .external_lex_state = 29},
  [15743] = {.lex_state = 117},
  [15744] = {.lex_state = 117, .external_lex_state = 29},
  [15745] = {.lex_state = 117, .external_lex_state = 29},
  [15746] = {.lex_state = 117, .external_lex_state = 29},
  [15747] = {.lex_state = 117, .external_lex_state = 29},
  [15748] = {.lex_state = 117, .external_lex_state = 29},
  [15749] = {.lex_state = 117, .external_lex_state = 29},
  [15750] = {.lex_state = 117, .external_lex_state = 29},
  [15751] = {.lex_state = 117, .external_lex_state = 29},
  [15752] = {.lex_state = 117, .external_lex_state = 29},
  [15753] = {.lex_state = 117, .external_lex_state = 29},
  [15754] = {.lex_state = 117, .external_lex_state = 29},
  [15755] = {.lex_state = 117, .external_lex_state = 29},
  [15756] = {.lex_state = 117, .external_lex_state = 29},
  [15757] = {.lex_state = 0},
  [15758] = {.lex_state = 117, .external_lex_state = 29},
  [15759] = {.lex_state = 117, .external_lex_state = 29},
  [15760] = {.lex_state = 117},
  [15761] = {.lex_state = 17},
  [15762] = {.lex_state = 0},
  [15763] = {.lex_state = 117, .external_lex_state = 29},
  [15764] = {.lex_state = 117, .external_lex_state = 29},
  [15765] = {.lex_state = 117, .external_lex_state = 29},
  [15766] = {.lex_state = 117, .external_lex_state = 29},
  [15767] = {.lex_state = 117, .external_lex_state = 29},
  [15768] = {.lex_state = 117, .external_lex_state = 29},
  [15769] = {.lex_state = 117, .external_lex_state = 29},
  [15770] = {.lex_state = 117, .external_lex_state = 29},
  [15771] = {.lex_state = 117, .external_lex_state = 29},
  [15772] = {.lex_state = 117, .external_lex_state = 29},
  [15773] = {.lex_state = 117, .external_lex_state = 29},
  [15774] = {.lex_state = 117, .external_lex_state = 29},
  [15775] = {.lex_state = 117, .external_lex_state = 29},
  [15776] = {.lex_state = 117, .external_lex_state = 29},
  [15777] = {.lex_state = 117, .external_lex_state = 29},
  [15778] = {.lex_state = 117, .external_lex_state = 29},
  [15779] = {.lex_state = 117, .external_lex_state = 29},
  [15780] = {.lex_state = 117, .external_lex_state = 29},
  [15781] = {.lex_state = 117, .external_lex_state = 29},
  [15782] = {.lex_state = 117, .external_lex_state = 29},
  [15783] = {.lex_state = 117, .external_lex_state = 29},
  [15784] = {.lex_state = 117, .external_lex_state = 29},
  [15785] = {.lex_state = 117, .external_lex_state = 29},
  [15786] = {.lex_state = 117, .external_lex_state = 29},
  [15787] = {.lex_state = 117, .external_lex_state = 29},
  [15788] = {.lex_state = 117, .external_lex_state = 29},
  [15789] = {.lex_state = 117, .external_lex_state = 29},
  [15790] = {.lex_state = 117, .external_lex_state = 29},
  [15791] = {.lex_state = 117, .external_lex_state = 29},
  [15792] = {.lex_state = 117, .external_lex_state = 29},
  [15793] = {.lex_state = 117, .external_lex_state = 29},
  [15794] = {.lex_state = 117, .external_lex_state = 29},
  [15795] = {.lex_state = 117, .external_lex_state = 29},
  [15796] = {.lex_state = 117, .external_lex_state = 29},
  [15797] = {.lex_state = 0},
  [15798] = {.lex_state = 117, .external_lex_state = 29},
  [15799] = {.lex_state = 117, .external_lex_state = 29},
  [15800] = {.lex_state = 117, .external_lex_state = 29},
  [15801] = {.lex_state = 117, .external_lex_state = 29},
  [15802] = {.lex_state = 0},
  [15803] = {.lex_state = 117, .external_lex_state = 29},
  [15804] = {.lex_state = 117, .external_lex_state = 29},
  [15805] = {.lex_state = 117, .external_lex_state = 29},
  [15806] = {.lex_state = 117, .external_lex_state = 29},
  [15807] = {.lex_state = 117, .external_lex_state = 29},
  [15808] = {.lex_state = 117, .external_lex_state = 29},
  [15809] = {.lex_state = 117, .external_lex_state = 29},
  [15810] = {.lex_state = 117, .external_lex_state = 29},
  [15811] = {.lex_state = 117, .external_lex_state = 29},
  [15812] = {.lex_state = 117, .external_lex_state = 29},
  [15813] = {.lex_state = 117, .external_lex_state = 29},
  [15814] = {.lex_state = 117, .external_lex_state = 29},
  [15815] = {.lex_state = 117, .external_lex_state = 29},
  [15816] = {.lex_state = 117, .external_lex_state = 29},
  [15817] = {.lex_state = 117, .external_lex_state = 29},
  [15818] = {.lex_state = 117, .external_lex_state = 29},
  [15819] = {.lex_state = 117, .external_lex_state = 29},
  [15820] = {.lex_state = 117},
  [15821] = {.lex_state = 117},
  [15822] = {.lex_state = 0},
  [15823] = {.lex_state = 117, .external_lex_state = 29},
  [15824] = {.lex_state = 0},
  [15825] = {.lex_state = 117},
  [15826] = {.lex_state = 117, .external_lex_state = 29},
  [15827] = {.lex_state = 117, .external_lex_state = 29},
  [15828] = {.lex_state = 117, .external_lex_state = 29},
  [15829] = {.lex_state = 117, .external_lex_state = 29},
  [15830] = {.lex_state = 0},
  [15831] = {.lex_state = 117, .external_lex_state = 29},
  [15832] = {.lex_state = 117, .external_lex_state = 29},
  [15833] = {.lex_state = 0},
  [15834] = {.lex_state = 117, .external_lex_state = 29},
  [15835] = {.lex_state = 117, .external_lex_state = 29},
  [15836] = {.lex_state = 117, .external_lex_state = 29},
  [15837] = {.lex_state = 117, .external_lex_state = 29},
  [15838] = {.lex_state = 117, .external_lex_state = 29},
  [15839] = {.lex_state = 117, .external_lex_state = 29},
  [15840] = {.lex_state = 117, .external_lex_state = 29},
  [15841] = {.lex_state = 117, .external_lex_state = 29},
  [15842] = {.lex_state = 117},
  [15843] = {.lex_state = 117, .external_lex_state = 29},
  [15844] = {.lex_state = 117, .external_lex_state = 29},
  [15845] = {.lex_state = 117},
  [15846] = {.lex_state = 0},
  [15847] = {.lex_state = 0},
  [15848] = {.lex_state = 0},
  [15849] = {.lex_state = 117, .external_lex_state = 29},
  [15850] = {.lex_state = 117, .external_lex_state = 29},
  [15851] = {.lex_state = 0},
  [15852] = {.lex_state = 117, .external_lex_state = 29},
  [15853] = {.lex_state = 117, .external_lex_state = 29},
  [15854] = {.lex_state = 117, .external_lex_state = 29},
  [15855] = {.lex_state = 117, .external_lex_state = 29},
  [15856] = {.lex_state = 117, .external_lex_state = 29},
  [15857] = {.lex_state = 0},
  [15858] = {.lex_state = 117, .external_lex_state = 29},
  [15859] = {.lex_state = 117, .external_lex_state = 29},
  [15860] = {.lex_state = 117, .external_lex_state = 29},
  [15861] = {.lex_state = 117, .external_lex_state = 29},
  [15862] = {.lex_state = 0},
  [15863] = {.lex_state = 117},
  [15864] = {.lex_state = 0},
  [15865] = {.lex_state = 117, .external_lex_state = 29},
  [15866] = {.lex_state = 117, .external_lex_state = 29},
  [15867] = {.lex_state = 117, .external_lex_state = 29},
  [15868] = {.lex_state = 117, .external_lex_state = 29},
  [15869] = {.lex_state = 117, .external_lex_state = 29},
  [15870] = {.lex_state = 0},
  [15871] = {.lex_state = 117, .external_lex_state = 29},
  [15872] = {.lex_state = 117, .external_lex_state = 29},
  [15873] = {.lex_state = 117, .external_lex_state = 29},
  [15874] = {.lex_state = 117, .external_lex_state = 29},
  [15875] = {.lex_state = 117, .external_lex_state = 29},
  [15876] = {.lex_state = 0},
  [15877] = {.lex_state = 117},
  [15878] = {.lex_state = 117, .external_lex_state = 29},
  [15879] = {.lex_state = 0},
  [15880] = {.lex_state = 117},
  [15881] = {.lex_state = 117, .external_lex_state = 29},
  [15882] = {.lex_state = 117, .external_lex_state = 29},
  [15883] = {.lex_state = 117, .external_lex_state = 29},
  [15884] = {.lex_state = 117, .external_lex_state = 29},
  [15885] = {.lex_state = 117, .external_lex_state = 29},
  [15886] = {.lex_state = 117, .external_lex_state = 29},
  [15887] = {.lex_state = 117, .external_lex_state = 29},
  [15888] = {.lex_state = 117, .external_lex_state = 29},
  [15889] = {.lex_state = 0},
  [15890] = {.lex_state = 117, .external_lex_state = 29},
  [15891] = {.lex_state = 117, .external_lex_state = 29},
  [15892] = {.lex_state = 117, .external_lex_state = 29},
  [15893] = {.lex_state = 0},
  [15894] = {.lex_state = 117, .external_lex_state = 29},
  [15895] = {.lex_state = 117, .external_lex_state = 29},
  [15896] = {.lex_state = 117, .external_lex_state = 29},
  [15897] = {.lex_state = 117, .external_lex_state = 29},
  [15898] = {.lex_state = 117, .external_lex_state = 29},
  [15899] = {.lex_state = 117, .external_lex_state = 29},
  [15900] = {.lex_state = 117},
  [15901] = {.lex_state = 117, .external_lex_state = 29},
  [15902] = {.lex_state = 117, .external_lex_state = 29},
  [15903] = {.lex_state = 117},
  [15904] = {.lex_state = 117, .external_lex_state = 29},
  [15905] = {.lex_state = 117, .external_lex_state = 29},
  [15906] = {.lex_state = 117, .external_lex_state = 29},
  [15907] = {.lex_state = 117, .external_lex_state = 29},
  [15908] = {.lex_state = 117},
  [15909] = {.lex_state = 117, .external_lex_state = 29},
  [15910] = {.lex_state = 117, .external_lex_state = 29},
  [15911] = {.lex_state = 117},
  [15912] = {.lex_state = 117},
  [15913] = {.lex_state = 117, .external_lex_state = 29},
  [15914] = {.lex_state = 117, .external_lex_state = 29},
  [15915] = {.lex_state = 0},
  [15916] = {.lex_state = 117, .external_lex_state = 29},
  [15917] = {.lex_state = 117},
  [15918] = {.lex_state = 117},
  [15919] = {.lex_state = 117},
  [15920] = {.lex_state = 117, .external_lex_state = 29},
  [15921] = {.lex_state = 117},
  [15922] = {.lex_state = 117, .external_lex_state = 29},
  [15923] = {.lex_state = 117, .external_lex_state = 29},
  [15924] = {.lex_state = 117, .external_lex_state = 29},
  [15925] = {.lex_state = 117, .external_lex_state = 29},
  [15926] = {.lex_state = 117, .external_lex_state = 29},
  [15927] = {.lex_state = 0},
  [15928] = {.lex_state = 117, .external_lex_state = 29},
  [15929] = {.lex_state = 117},
  [15930] = {.lex_state = 117, .external_lex_state = 29},
  [15931] = {.lex_state = 0},
  [15932] = {.lex_state = 117},
  [15933] = {.lex_state = 0},
  [15934] = {.lex_state = 117},
  [15935] = {.lex_state = 117},
  [15936] = {.lex_state = 117},
  [15937] = {.lex_state = 0},
  [15938] = {.lex_state = 0},
  [15939] = {.lex_state = 13},
  [15940] = {.lex_state = 117, .external_lex_state = 29},
  [15941] = {.lex_state = 0},
  [15942] = {.lex_state = 117, .external_lex_state = 29},
  [15943] = {.lex_state = 0},
  [15944] = {.lex_state = 0},
  [15945] = {.lex_state = 117, .external_lex_state = 29},
  [15946] = {.lex_state = 117, .external_lex_state = 29},
  [15947] = {.lex_state = 117, .external_lex_state = 29},
  [15948] = {.lex_state = 117, .external_lex_state = 29},
  [15949] = {.lex_state = 117},
  [15950] = {.lex_state = 0},
  [15951] = {.lex_state = 117, .external_lex_state = 29},
  [15952] = {.lex_state = 0},
  [15953] = {.lex_state = 117, .external_lex_state = 29},
  [15954] = {.lex_state = 117, .external_lex_state = 29},
  [15955] = {.lex_state = 117, .external_lex_state = 29},
  [15956] = {.lex_state = 117, .external_lex_state = 29},
  [15957] = {.lex_state = 117, .external_lex_state = 29},
  [15958] = {.lex_state = 117, .external_lex_state = 29},
  [15959] = {.lex_state = 117, .external_lex_state = 29},
  [15960] = {.lex_state = 117, .external_lex_state = 29},
  [15961] = {.lex_state = 117, .external_lex_state = 29},
  [15962] = {.lex_state = 117, .external_lex_state = 29},
  [15963] = {.lex_state = 117, .external_lex_state = 29},
  [15964] = {.lex_state = 117, .external_lex_state = 29},
  [15965] = {.lex_state = 117, .external_lex_state = 29},
  [15966] = {.lex_state = 0},
  [15967] = {.lex_state = 0},
  [15968] = {.lex_state = 117, .external_lex_state = 29},
  [15969] = {.lex_state = 117, .external_lex_state = 29},
  [15970] = {.lex_state = 0},
  [15971] = {.lex_state = 117, .external_lex_state = 29},
  [15972] = {.lex_state = 117, .external_lex_state = 29},
  [15973] = {.lex_state = 0},
  [15974] = {.lex_state = 117},
  [15975] = {.lex_state = 0},
  [15976] = {.lex_state = 117, .external_lex_state = 29},
  [15977] = {.lex_state = 117, .external_lex_state = 29},
  [15978] = {.lex_state = 117, .external_lex_state = 29},
  [15979] = {.lex_state = 117, .external_lex_state = 29},
  [15980] = {.lex_state = 117, .external_lex_state = 29},
  [15981] = {.lex_state = 117, .external_lex_state = 29},
  [15982] = {.lex_state = 117, .external_lex_state = 29},
  [15983] = {.lex_state = 117, .external_lex_state = 29},
  [15984] = {.lex_state = 117, .external_lex_state = 29},
  [15985] = {.lex_state = 117, .external_lex_state = 29},
  [15986] = {.lex_state = 0},
  [15987] = {.lex_state = 0},
  [15988] = {.lex_state = 117, .external_lex_state = 29},
  [15989] = {.lex_state = 117, .external_lex_state = 29},
  [15990] = {.lex_state = 117, .external_lex_state = 29},
  [15991] = {.lex_state = 117, .external_lex_state = 29},
  [15992] = {.lex_state = 117, .external_lex_state = 29},
  [15993] = {.lex_state = 117, .external_lex_state = 29},
  [15994] = {.lex_state = 117, .external_lex_state = 29},
  [15995] = {.lex_state = 117, .external_lex_state = 29},
  [15996] = {.lex_state = 117, .external_lex_state = 29},
  [15997] = {.lex_state = 117, .external_lex_state = 29},
  [15998] = {.lex_state = 117, .external_lex_state = 29},
  [15999] = {.lex_state = 117, .external_lex_state = 29},
  [16000] = {.lex_state = 0},
  [16001] = {.lex_state = 117, .external_lex_state = 29},
  [16002] = {.lex_state = 117, .external_lex_state = 29},
  [16003] = {.lex_state = 13},
  [16004] = {.lex_state = 0},
  [16005] = {.lex_state = 117, .external_lex_state = 29},
  [16006] = {.lex_state = 0},
  [16007] = {.lex_state = 0},
  [16008] = {.lex_state = 117, .external_lex_state = 29},
  [16009] = {.lex_state = 117, .external_lex_state = 29},
  [16010] = {.lex_state = 0},
  [16011] = {.lex_state = 117, .external_lex_state = 29},
  [16012] = {.lex_state = 117, .external_lex_state = 29},
  [16013] = {.lex_state = 117, .external_lex_state = 29},
  [16014] = {.lex_state = 117, .external_lex_state = 29},
  [16015] = {.lex_state = 117, .external_lex_state = 29},
  [16016] = {.lex_state = 0},
  [16017] = {.lex_state = 117, .external_lex_state = 29},
  [16018] = {.lex_state = 117, .external_lex_state = 29},
  [16019] = {.lex_state = 117},
  [16020] = {.lex_state = 117, .external_lex_state = 29},
  [16021] = {.lex_state = 0},
  [16022] = {.lex_state = 0},
  [16023] = {.lex_state = 117, .external_lex_state = 29},
  [16024] = {.lex_state = 117, .external_lex_state = 29},
  [16025] = {.lex_state = 13},
  [16026] = {.lex_state = 117, .external_lex_state = 29},
  [16027] = {.lex_state = 117, .external_lex_state = 29},
  [16028] = {.lex_state = 117, .external_lex_state = 29},
  [16029] = {.lex_state = 117, .external_lex_state = 29},
  [16030] = {.lex_state = 117, .external_lex_state = 29},
  [16031] = {.lex_state = 117, .external_lex_state = 29},
  [16032] = {.lex_state = 117, .external_lex_state = 29},
  [16033] = {.lex_state = 117, .external_lex_state = 29},
  [16034] = {.lex_state = 117, .external_lex_state = 29},
  [16035] = {.lex_state = 0},
  [16036] = {.lex_state = 117, .external_lex_state = 29},
  [16037] = {.lex_state = 117, .external_lex_state = 29},
  [16038] = {.lex_state = 117, .external_lex_state = 29},
  [16039] = {.lex_state = 0},
  [16040] = {.lex_state = 117, .external_lex_state = 29},
  [16041] = {.lex_state = 117, .external_lex_state = 29},
  [16042] = {.lex_state = 117, .external_lex_state = 29},
  [16043] = {.lex_state = 117, .external_lex_state = 29},
  [16044] = {.lex_state = 117, .external_lex_state = 29},
  [16045] = {.lex_state = 0},
  [16046] = {.lex_state = 13},
  [16047] = {.lex_state = 117, .external_lex_state = 29},
  [16048] = {.lex_state = 117, .external_lex_state = 29},
  [16049] = {.lex_state = 117, .external_lex_state = 29},
  [16050] = {.lex_state = 117, .external_lex_state = 29},
  [16051] = {.lex_state = 117, .external_lex_state = 29},
  [16052] = {.lex_state = 117, .external_lex_state = 29},
  [16053] = {.lex_state = 117, .external_lex_state = 29},
  [16054] = {.lex_state = 117, .external_lex_state = 29},
  [16055] = {.lex_state = 117, .external_lex_state = 29},
  [16056] = {.lex_state = 13},
  [16057] = {.lex_state = 117, .external_lex_state = 29},
  [16058] = {.lex_state = 0},
  [16059] = {.lex_state = 117, .external_lex_state = 29},
  [16060] = {.lex_state = 117, .external_lex_state = 29},
  [16061] = {.lex_state = 117, .external_lex_state = 29},
  [16062] = {.lex_state = 117, .external_lex_state = 29},
  [16063] = {.lex_state = 117, .external_lex_state = 29},
  [16064] = {.lex_state = 117, .external_lex_state = 29},
  [16065] = {.lex_state = 117, .external_lex_state = 29},
  [16066] = {.lex_state = 117, .external_lex_state = 29},
  [16067] = {.lex_state = 13},
  [16068] = {.lex_state = 0},
  [16069] = {.lex_state = 117, .external_lex_state = 29},
  [16070] = {.lex_state = 117, .external_lex_state = 29},
  [16071] = {.lex_state = 117, .external_lex_state = 29},
  [16072] = {.lex_state = 117, .external_lex_state = 29},
  [16073] = {.lex_state = 117, .external_lex_state = 29},
  [16074] = {.lex_state = 117, .external_lex_state = 29},
  [16075] = {.lex_state = 117, .external_lex_state = 29},
  [16076] = {.lex_state = 117, .external_lex_state = 29},
  [16077] = {.lex_state = 0},
  [16078] = {.lex_state = 117, .external_lex_state = 29},
  [16079] = {.lex_state = 117, .external_lex_state = 29},
  [16080] = {.lex_state = 117, .external_lex_state = 29},
  [16081] = {.lex_state = 0},
  [16082] = {.lex_state = 117, .external_lex_state = 29},
  [16083] = {.lex_state = 117, .external_lex_state = 29},
  [16084] = {.lex_state = 0},
  [16085] = {.lex_state = 0},
  [16086] = {.lex_state = 117, .external_lex_state = 29},
  [16087] = {.lex_state = 117, .external_lex_state = 29},
  [16088] = {.lex_state = 117, .external_lex_state = 29},
  [16089] = {.lex_state = 117, .external_lex_state = 29},
  [16090] = {.lex_state = 117, .external_lex_state = 29},
  [16091] = {.lex_state = 0},
  [16092] = {.lex_state = 117, .external_lex_state = 29},
  [16093] = {.lex_state = 117, .external_lex_state = 29},
  [16094] = {.lex_state = 117, .external_lex_state = 29},
  [16095] = {.lex_state = 117, .external_lex_state = 29},
  [16096] = {.lex_state = 0},
  [16097] = {.lex_state = 0},
  [16098] = {.lex_state = 0},
  [16099] = {.lex_state = 117, .external_lex_state = 29},
  [16100] = {.lex_state = 117, .external_lex_state = 29},
  [16101] = {.lex_state = 117, .external_lex_state = 29},
  [16102] = {.lex_state = 117, .external_lex_state = 29},
  [16103] = {.lex_state = 117, .external_lex_state = 29},
  [16104] = {.lex_state = 117, .external_lex_state = 29},
  [16105] = {.lex_state = 117, .external_lex_state = 29},
  [16106] = {.lex_state = 117, .external_lex_state = 29},
  [16107] = {.lex_state = 117, .external_lex_state = 29},
  [16108] = {.lex_state = 117, .external_lex_state = 29},
  [16109] = {.lex_state = 117, .external_lex_state = 29},
  [16110] = {.lex_state = 117, .external_lex_state = 29},
  [16111] = {.lex_state = 117, .external_lex_state = 29},
  [16112] = {.lex_state = 117, .external_lex_state = 29},
  [16113] = {.lex_state = 117},
  [16114] = {.lex_state = 117, .external_lex_state = 29},
  [16115] = {.lex_state = 0},
  [16116] = {.lex_state = 0},
  [16117] = {.lex_state = 117, .external_lex_state = 29},
  [16118] = {.lex_state = 117, .external_lex_state = 29},
  [16119] = {.lex_state = 117, .external_lex_state = 29},
  [16120] = {.lex_state = 117, .external_lex_state = 29},
  [16121] = {.lex_state = 117, .external_lex_state = 29},
  [16122] = {.lex_state = 0},
  [16123] = {.lex_state = 117, .external_lex_state = 29},
  [16124] = {.lex_state = 117, .external_lex_state = 29},
  [16125] = {.lex_state = 117, .external_lex_state = 29},
  [16126] = {.lex_state = 117, .external_lex_state = 29},
  [16127] = {.lex_state = 117, .external_lex_state = 29},
  [16128] = {.lex_state = 117, .external_lex_state = 29},
  [16129] = {.lex_state = 117, .external_lex_state = 29},
  [16130] = {.lex_state = 117, .external_lex_state = 29},
  [16131] = {.lex_state = 117, .external_lex_state = 29},
  [16132] = {.lex_state = 117, .external_lex_state = 29},
  [16133] = {.lex_state = 117, .external_lex_state = 29},
  [16134] = {.lex_state = 117, .external_lex_state = 29},
  [16135] = {.lex_state = 117, .external_lex_state = 29},
  [16136] = {.lex_state = 117, .external_lex_state = 29},
  [16137] = {.lex_state = 117, .external_lex_state = 29},
  [16138] = {.lex_state = 117, .external_lex_state = 29},
  [16139] = {.lex_state = 117, .external_lex_state = 29},
  [16140] = {.lex_state = 117, .external_lex_state = 29},
  [16141] = {.lex_state = 0},
  [16142] = {.lex_state = 117, .external_lex_state = 29},
  [16143] = {.lex_state = 117, .external_lex_state = 29},
  [16144] = {.lex_state = 117, .external_lex_state = 29},
  [16145] = {.lex_state = 117, .external_lex_state = 29},
  [16146] = {.lex_state = 117, .external_lex_state = 29},
  [16147] = {.lex_state = 117, .external_lex_state = 29},
  [16148] = {.lex_state = 117, .external_lex_state = 29},
  [16149] = {.lex_state = 117, .external_lex_state = 29},
  [16150] = {.lex_state = 117, .external_lex_state = 29},
  [16151] = {.lex_state = 117, .external_lex_state = 29},
  [16152] = {.lex_state = 117, .external_lex_state = 29},
  [16153] = {.lex_state = 117, .external_lex_state = 29},
  [16154] = {.lex_state = 117, .external_lex_state = 29},
  [16155] = {.lex_state = 0},
  [16156] = {.lex_state = 0},
  [16157] = {.lex_state = 117, .external_lex_state = 29},
  [16158] = {.lex_state = 117, .external_lex_state = 29},
  [16159] = {.lex_state = 117, .external_lex_state = 29},
  [16160] = {.lex_state = 117, .external_lex_state = 29},
  [16161] = {.lex_state = 117, .external_lex_state = 29},
  [16162] = {.lex_state = 117, .external_lex_state = 29},
  [16163] = {.lex_state = 117, .external_lex_state = 29},
  [16164] = {.lex_state = 117, .external_lex_state = 29},
  [16165] = {.lex_state = 117, .external_lex_state = 29},
  [16166] = {.lex_state = 117, .external_lex_state = 29},
  [16167] = {.lex_state = 117, .external_lex_state = 29},
  [16168] = {.lex_state = 117, .external_lex_state = 29},
  [16169] = {.lex_state = 117, .external_lex_state = 29},
  [16170] = {.lex_state = 117, .external_lex_state = 29},
  [16171] = {.lex_state = 117, .external_lex_state = 29},
  [16172] = {.lex_state = 117, .external_lex_state = 29},
  [16173] = {.lex_state = 117, .external_lex_state = 29},
  [16174] = {.lex_state = 117, .external_lex_state = 29},
  [16175] = {.lex_state = 117, .external_lex_state = 29},
  [16176] = {.lex_state = 117, .external_lex_state = 29},
  [16177] = {.lex_state = 117, .external_lex_state = 29},
  [16178] = {.lex_state = 117, .external_lex_state = 29},
  [16179] = {.lex_state = 0},
  [16180] = {.lex_state = 117, .external_lex_state = 29},
  [16181] = {.lex_state = 117, .external_lex_state = 29},
  [16182] = {.lex_state = 0},
  [16183] = {.lex_state = 117, .external_lex_state = 29},
  [16184] = {.lex_state = 117, .external_lex_state = 29},
  [16185] = {.lex_state = 117, .external_lex_state = 29},
  [16186] = {.lex_state = 117, .external_lex_state = 29},
  [16187] = {.lex_state = 117, .external_lex_state = 29},
  [16188] = {.lex_state = 117, .external_lex_state = 29},
  [16189] = {.lex_state = 0},
  [16190] = {.lex_state = 117, .external_lex_state = 29},
  [16191] = {.lex_state = 117, .external_lex_state = 29},
  [16192] = {.lex_state = 117},
  [16193] = {.lex_state = 117, .external_lex_state = 29},
  [16194] = {.lex_state = 117, .external_lex_state = 29},
  [16195] = {.lex_state = 117, .external_lex_state = 29},
  [16196] = {.lex_state = 117, .external_lex_state = 29},
  [16197] = {.lex_state = 117, .external_lex_state = 29},
  [16198] = {.lex_state = 117, .external_lex_state = 29},
  [16199] = {.lex_state = 117, .external_lex_state = 29},
  [16200] = {.lex_state = 117, .external_lex_state = 29},
  [16201] = {.lex_state = 117, .external_lex_state = 29},
  [16202] = {.lex_state = 117, .external_lex_state = 29},
  [16203] = {.lex_state = 117, .external_lex_state = 29},
  [16204] = {.lex_state = 117, .external_lex_state = 29},
  [16205] = {.lex_state = 117, .external_lex_state = 29},
  [16206] = {.lex_state = 117, .external_lex_state = 29},
  [16207] = {.lex_state = 117, .external_lex_state = 29},
  [16208] = {.lex_state = 117, .external_lex_state = 29},
  [16209] = {.lex_state = 117, .external_lex_state = 29},
  [16210] = {.lex_state = 117, .external_lex_state = 29},
  [16211] = {.lex_state = 0},
  [16212] = {.lex_state = 117, .external_lex_state = 29},
  [16213] = {.lex_state = 117, .external_lex_state = 29},
  [16214] = {.lex_state = 117, .external_lex_state = 29},
  [16215] = {.lex_state = 117, .external_lex_state = 29},
  [16216] = {.lex_state = 117},
  [16217] = {.lex_state = 0},
  [16218] = {.lex_state = 117, .external_lex_state = 29},
  [16219] = {.lex_state = 0},
  [16220] = {.lex_state = 117, .external_lex_state = 29},
  [16221] = {.lex_state = 117, .external_lex_state = 29},
  [16222] = {.lex_state = 117, .external_lex_state = 29},
  [16223] = {.lex_state = 117, .external_lex_state = 29},
  [16224] = {.lex_state = 117, .external_lex_state = 29},
  [16225] = {.lex_state = 117, .external_lex_state = 29},
  [16226] = {.lex_state = 117, .external_lex_state = 29},
  [16227] = {.lex_state = 117, .external_lex_state = 29},
  [16228] = {.lex_state = 117, .external_lex_state = 29},
  [16229] = {.lex_state = 117, .external_lex_state = 29},
  [16230] = {.lex_state = 0},
  [16231] = {.lex_state = 117, .external_lex_state = 29},
  [16232] = {.lex_state = 117, .external_lex_state = 29},
  [16233] = {.lex_state = 117, .external_lex_state = 29},
  [16234] = {.lex_state = 117, .external_lex_state = 29},
  [16235] = {.lex_state = 117, .external_lex_state = 29},
  [16236] = {.lex_state = 117, .external_lex_state = 29},
  [16237] = {.lex_state = 117, .external_lex_state = 29},
  [16238] = {.lex_state = 117, .external_lex_state = 29},
  [16239] = {.lex_state = 117},
  [16240] = {.lex_state = 117, .external_lex_state = 29},
  [16241] = {.lex_state = 117, .external_lex_state = 29},
  [16242] = {.lex_state = 117, .external_lex_state = 29},
  [16243] = {.lex_state = 117, .external_lex_state = 29},
  [16244] = {.lex_state = 117, .external_lex_state = 29},
  [16245] = {.lex_state = 117, .external_lex_state = 29},
  [16246] = {.lex_state = 117, .external_lex_state = 29},
  [16247] = {.lex_state = 117, .external_lex_state = 29},
  [16248] = {.lex_state = 117, .external_lex_state = 29},
  [16249] = {.lex_state = 117, .external_lex_state = 29},
  [16250] = {.lex_state = 117, .external_lex_state = 29},
  [16251] = {.lex_state = 117, .external_lex_state = 29},
  [16252] = {.lex_state = 117, .external_lex_state = 29},
  [16253] = {.lex_state = 117, .external_lex_state = 29},
  [16254] = {.lex_state = 117, .external_lex_state = 29},
  [16255] = {.lex_state = 117, .external_lex_state = 29},
  [16256] = {.lex_state = 117, .external_lex_state = 29},
  [16257] = {.lex_state = 117, .external_lex_state = 29},
  [16258] = {.lex_state = 117, .external_lex_state = 29},
  [16259] = {.lex_state = 117, .external_lex_state = 29},
  [16260] = {.lex_state = 117, .external_lex_state = 29},
  [16261] = {.lex_state = 117, .external_lex_state = 29},
  [16262] = {.lex_state = 117, .external_lex_state = 29},
  [16263] = {.lex_state = 117, .external_lex_state = 29},
  [16264] = {.lex_state = 117, .external_lex_state = 29},
  [16265] = {.lex_state = 117, .external_lex_state = 29},
  [16266] = {.lex_state = 117, .external_lex_state = 29},
  [16267] = {.lex_state = 117, .external_lex_state = 29},
  [16268] = {.lex_state = 117, .external_lex_state = 29},
  [16269] = {.lex_state = 117, .external_lex_state = 29},
  [16270] = {.lex_state = 117, .external_lex_state = 29},
  [16271] = {.lex_state = 117, .external_lex_state = 29},
  [16272] = {.lex_state = 117, .external_lex_state = 29},
  [16273] = {.lex_state = 117, .external_lex_state = 29},
  [16274] = {.lex_state = 117, .external_lex_state = 29},
  [16275] = {.lex_state = 117, .external_lex_state = 29},
  [16276] = {.lex_state = 117, .external_lex_state = 29},
  [16277] = {.lex_state = 117, .external_lex_state = 29},
  [16278] = {.lex_state = 117, .external_lex_state = 29},
  [16279] = {.lex_state = 117, .external_lex_state = 29},
  [16280] = {.lex_state = 117, .external_lex_state = 29},
  [16281] = {.lex_state = 117, .external_lex_state = 29},
  [16282] = {.lex_state = 117, .external_lex_state = 29},
  [16283] = {.lex_state = 117, .external_lex_state = 29},
  [16284] = {.lex_state = 117, .external_lex_state = 29},
  [16285] = {.lex_state = 117, .external_lex_state = 29},
  [16286] = {.lex_state = 117, .external_lex_state = 29},
  [16287] = {.lex_state = 117, .external_lex_state = 29},
  [16288] = {.lex_state = 117, .external_lex_state = 29},
  [16289] = {.lex_state = 117, .external_lex_state = 29},
  [16290] = {.lex_state = 117, .external_lex_state = 29},
  [16291] = {.lex_state = 117, .external_lex_state = 29},
  [16292] = {.lex_state = 117, .external_lex_state = 29},
  [16293] = {.lex_state = 117, .external_lex_state = 29},
  [16294] = {.lex_state = 117, .external_lex_state = 29},
  [16295] = {.lex_state = 117, .external_lex_state = 29},
  [16296] = {.lex_state = 117, .external_lex_state = 29},
  [16297] = {.lex_state = 117, .external_lex_state = 29},
  [16298] = {.lex_state = 117, .external_lex_state = 29},
  [16299] = {.lex_state = 117, .external_lex_state = 29},
  [16300] = {.lex_state = 117, .external_lex_state = 29},
  [16301] = {.lex_state = 117, .external_lex_state = 29},
  [16302] = {.lex_state = 117, .external_lex_state = 29},
  [16303] = {.lex_state = 117, .external_lex_state = 29},
  [16304] = {.lex_state = 117, .external_lex_state = 29},
  [16305] = {.lex_state = 117, .external_lex_state = 29},
  [16306] = {.lex_state = 117, .external_lex_state = 29},
  [16307] = {.lex_state = 117, .external_lex_state = 29},
  [16308] = {.lex_state = 117, .external_lex_state = 29},
  [16309] = {.lex_state = 117, .external_lex_state = 29},
  [16310] = {.lex_state = 117, .external_lex_state = 29},
  [16311] = {.lex_state = 117, .external_lex_state = 29},
  [16312] = {.lex_state = 117, .external_lex_state = 29},
  [16313] = {.lex_state = 117, .external_lex_state = 29},
  [16314] = {.lex_state = 117, .external_lex_state = 29},
  [16315] = {.lex_state = 117, .external_lex_state = 29},
  [16316] = {.lex_state = 117, .external_lex_state = 29},
  [16317] = {.lex_state = 117, .external_lex_state = 29},
  [16318] = {.lex_state = 117, .external_lex_state = 29},
  [16319] = {.lex_state = 117, .external_lex_state = 29},
  [16320] = {.lex_state = 117, .external_lex_state = 29},
  [16321] = {.lex_state = 117, .external_lex_state = 29},
  [16322] = {.lex_state = 117, .external_lex_state = 29},
  [16323] = {.lex_state = 117, .external_lex_state = 29},
  [16324] = {.lex_state = 117, .external_lex_state = 29},
  [16325] = {.lex_state = 117, .external_lex_state = 29},
  [16326] = {.lex_state = 117, .external_lex_state = 29},
  [16327] = {.lex_state = 117, .external_lex_state = 29},
  [16328] = {.lex_state = 117, .external_lex_state = 29},
  [16329] = {.lex_state = 117, .external_lex_state = 29},
  [16330] = {.lex_state = 117, .external_lex_state = 29},
  [16331] = {.lex_state = 117, .external_lex_state = 29},
  [16332] = {.lex_state = 117, .external_lex_state = 29},
  [16333] = {.lex_state = 117, .external_lex_state = 29},
  [16334] = {.lex_state = 117, .external_lex_state = 29},
  [16335] = {.lex_state = 117, .external_lex_state = 29},
  [16336] = {.lex_state = 117, .external_lex_state = 29},
  [16337] = {.lex_state = 117, .external_lex_state = 29},
  [16338] = {.lex_state = 117, .external_lex_state = 29},
  [16339] = {.lex_state = 117, .external_lex_state = 29},
  [16340] = {.lex_state = 0},
  [16341] = {.lex_state = 117, .external_lex_state = 29},
  [16342] = {.lex_state = 117, .external_lex_state = 29},
  [16343] = {.lex_state = 117, .external_lex_state = 29},
  [16344] = {.lex_state = 117, .external_lex_state = 29},
  [16345] = {.lex_state = 117, .external_lex_state = 29},
  [16346] = {.lex_state = 117, .external_lex_state = 29},
  [16347] = {.lex_state = 117, .external_lex_state = 29},
  [16348] = {.lex_state = 117, .external_lex_state = 29},
  [16349] = {.lex_state = 117, .external_lex_state = 29},
  [16350] = {.lex_state = 117, .external_lex_state = 29},
  [16351] = {.lex_state = 117, .external_lex_state = 29},
  [16352] = {.lex_state = 117, .external_lex_state = 29},
  [16353] = {.lex_state = 117, .external_lex_state = 29},
  [16354] = {.lex_state = 0},
  [16355] = {.lex_state = 117, .external_lex_state = 29},
  [16356] = {.lex_state = 117, .external_lex_state = 29},
  [16357] = {.lex_state = 0},
  [16358] = {.lex_state = 117, .external_lex_state = 29},
  [16359] = {.lex_state = 117, .external_lex_state = 29},
  [16360] = {.lex_state = 117, .external_lex_state = 29},
  [16361] = {.lex_state = 117, .external_lex_state = 29},
  [16362] = {.lex_state = 117, .external_lex_state = 29},
  [16363] = {.lex_state = 117, .external_lex_state = 29},
  [16364] = {.lex_state = 117, .external_lex_state = 29},
  [16365] = {.lex_state = 117, .external_lex_state = 29},
  [16366] = {.lex_state = 117, .external_lex_state = 29},
  [16367] = {.lex_state = 117, .external_lex_state = 29},
  [16368] = {.lex_state = 117, .external_lex_state = 29},
  [16369] = {.lex_state = 117, .external_lex_state = 29},
  [16370] = {.lex_state = 117, .external_lex_state = 29},
  [16371] = {.lex_state = 117, .external_lex_state = 29},
  [16372] = {.lex_state = 117, .external_lex_state = 29},
  [16373] = {.lex_state = 117, .external_lex_state = 29},
  [16374] = {.lex_state = 117, .external_lex_state = 29},
  [16375] = {.lex_state = 117, .external_lex_state = 29},
  [16376] = {.lex_state = 117, .external_lex_state = 29},
  [16377] = {.lex_state = 117, .external_lex_state = 29},
  [16378] = {.lex_state = 117, .external_lex_state = 29},
  [16379] = {.lex_state = 117, .external_lex_state = 29},
  [16380] = {.lex_state = 117, .external_lex_state = 29},
  [16381] = {.lex_state = 117, .external_lex_state = 29},
  [16382] = {.lex_state = 117, .external_lex_state = 29},
  [16383] = {.lex_state = 117, .external_lex_state = 29},
  [16384] = {.lex_state = 117, .external_lex_state = 29},
  [16385] = {.lex_state = 117, .external_lex_state = 29},
  [16386] = {.lex_state = 117, .external_lex_state = 29},
  [16387] = {.lex_state = 117, .external_lex_state = 29},
  [16388] = {.lex_state = 117, .external_lex_state = 29},
  [16389] = {.lex_state = 117, .external_lex_state = 29},
  [16390] = {.lex_state = 117, .external_lex_state = 29},
  [16391] = {.lex_state = 117, .external_lex_state = 29},
  [16392] = {.lex_state = 117, .external_lex_state = 29},
  [16393] = {.lex_state = 117, .external_lex_state = 29},
  [16394] = {.lex_state = 117, .external_lex_state = 29},
  [16395] = {.lex_state = 117, .external_lex_state = 29},
  [16396] = {.lex_state = 117, .external_lex_state = 29},
  [16397] = {.lex_state = 117, .external_lex_state = 29},
  [16398] = {.lex_state = 117, .external_lex_state = 29},
  [16399] = {.lex_state = 117, .external_lex_state = 29},
  [16400] = {.lex_state = 117, .external_lex_state = 29},
  [16401] = {.lex_state = 117, .external_lex_state = 29},
  [16402] = {.lex_state = 117, .external_lex_state = 29},
  [16403] = {.lex_state = 117, .external_lex_state = 29},
  [16404] = {.lex_state = 117, .external_lex_state = 29},
  [16405] = {.lex_state = 117, .external_lex_state = 29},
  [16406] = {.lex_state = 117, .external_lex_state = 29},
  [16407] = {.lex_state = 117, .external_lex_state = 29},
  [16408] = {.lex_state = 117, .external_lex_state = 29},
  [16409] = {.lex_state = 117, .external_lex_state = 29},
  [16410] = {.lex_state = 117, .external_lex_state = 29},
  [16411] = {.lex_state = 117, .external_lex_state = 29},
  [16412] = {.lex_state = 117, .external_lex_state = 29},
  [16413] = {.lex_state = 117, .external_lex_state = 29},
  [16414] = {.lex_state = 117, .external_lex_state = 29},
  [16415] = {.lex_state = 117, .external_lex_state = 29},
  [16416] = {.lex_state = 117, .external_lex_state = 29},
  [16417] = {.lex_state = 117, .external_lex_state = 29},
  [16418] = {.lex_state = 117, .external_lex_state = 29},
  [16419] = {.lex_state = 117, .external_lex_state = 29},
  [16420] = {.lex_state = 117, .external_lex_state = 29},
  [16421] = {.lex_state = 117, .external_lex_state = 29},
  [16422] = {.lex_state = 117, .external_lex_state = 29},
  [16423] = {.lex_state = 117, .external_lex_state = 29},
  [16424] = {.lex_state = 117, .external_lex_state = 29},
  [16425] = {.lex_state = 117, .external_lex_state = 29},
  [16426] = {.lex_state = 117, .external_lex_state = 29},
  [16427] = {.lex_state = 117, .external_lex_state = 29},
  [16428] = {.lex_state = 117, .external_lex_state = 29},
  [16429] = {.lex_state = 117, .external_lex_state = 29},
  [16430] = {.lex_state = 117, .external_lex_state = 29},
  [16431] = {.lex_state = 117, .external_lex_state = 29},
  [16432] = {.lex_state = 117, .external_lex_state = 29},
  [16433] = {.lex_state = 117, .external_lex_state = 29},
  [16434] = {.lex_state = 117, .external_lex_state = 29},
  [16435] = {.lex_state = 117, .external_lex_state = 29},
  [16436] = {.lex_state = 0},
  [16437] = {.lex_state = 117, .external_lex_state = 29},
  [16438] = {.lex_state = 0},
  [16439] = {.lex_state = 0},
  [16440] = {.lex_state = 0},
  [16441] = {.lex_state = 117},
  [16442] = {.lex_state = 17},
  [16443] = {.lex_state = 0},
  [16444] = {.lex_state = 117},
  [16445] = {.lex_state = 0},
  [16446] = {.lex_state = 117},
  [16447] = {.lex_state = 117},
  [16448] = {.lex_state = 17},
  [16449] = {.lex_state = 0},
  [16450] = {.lex_state = 117},
  [16451] = {.lex_state = 0},
  [16452] = {.lex_state = 0},
  [16453] = {.lex_state = 0},
  [16454] = {.lex_state = 117, .external_lex_state = 29},
  [16455] = {.lex_state = 117, .external_lex_state = 29},
  [16456] = {.lex_state = 117},
  [16457] = {.lex_state = 117},
  [16458] = {.lex_state = 0},
  [16459] = {.lex_state = 117},
  [16460] = {.lex_state = 117},
  [16461] = {.lex_state = 0},
  [16462] = {.lex_state = 0},
  [16463] = {.lex_state = 117},
  [16464] = {.lex_state = 117},
  [16465] = {.lex_state = 0},
  [16466] = {.lex_state = 0},
  [16467] = {.lex_state = 0},
  [16468] = {.lex_state = 117, .external_lex_state = 29},
  [16469] = {.lex_state = 117},
  [16470] = {.lex_state = 0},
  [16471] = {.lex_state = 0},
  [16472] = {.lex_state = 0},
  [16473] = {.lex_state = 0},
  [16474] = {.lex_state = 0},
  [16475] = {.lex_state = 0},
  [16476] = {.lex_state = 117},
  [16477] = {.lex_state = 117},
  [16478] = {.lex_state = 117},
  [16479] = {.lex_state = 117},
  [16480] = {.lex_state = 117},
  [16481] = {.lex_state = 117},
  [16482] = {.lex_state = 117},
  [16483] = {.lex_state = 117},
  [16484] = {.lex_state = 117},
  [16485] = {.lex_state = 0},
  [16486] = {.lex_state = 0},
  [16487] = {.lex_state = 117},
  [16488] = {.lex_state = 0},
  [16489] = {.lex_state = 117},
  [16490] = {.lex_state = 0},
  [16491] = {.lex_state = 117},
  [16492] = {.lex_state = 117},
  [16493] = {.lex_state = 117},
  [16494] = {.lex_state = 117},
  [16495] = {.lex_state = 117},
  [16496] = {.lex_state = 0},
  [16497] = {.lex_state = 117},
  [16498] = {.lex_state = 0},
  [16499] = {.lex_state = 117},
  [16500] = {.lex_state = 117},
  [16501] = {.lex_state = 117},
  [16502] = {.lex_state = 117},
  [16503] = {.lex_state = 0},
  [16504] = {.lex_state = 117, .external_lex_state = 29},
  [16505] = {.lex_state = 0},
  [16506] = {.lex_state = 117},
  [16507] = {.lex_state = 117},
  [16508] = {.lex_state = 117},
  [16509] = {.lex_state = 117},
  [16510] = {.lex_state = 117},
  [16511] = {.lex_state = 117, .external_lex_state = 29},
  [16512] = {.lex_state = 0},
  [16513] = {.lex_state = 117},
  [16514] = {.lex_state = 117},
  [16515] = {.lex_state = 0},
  [16516] = {.lex_state = 0},
  [16517] = {.lex_state = 117},
  [16518] = {.lex_state = 0},
  [16519] = {.lex_state = 0},
  [16520] = {.lex_state = 117},
  [16521] = {.lex_state = 117},
  [16522] = {.lex_state = 0},
  [16523] = {.lex_state = 0},
  [16524] = {.lex_state = 0},
  [16525] = {.lex_state = 117},
  [16526] = {.lex_state = 117},
  [16527] = {.lex_state = 117},
  [16528] = {.lex_state = 117},
  [16529] = {.lex_state = 0},
  [16530] = {.lex_state = 0},
  [16531] = {.lex_state = 117},
  [16532] = {.lex_state = 117},
  [16533] = {.lex_state = 0},
  [16534] = {.lex_state = 117},
  [16535] = {.lex_state = 117},
  [16536] = {.lex_state = 0},
  [16537] = {.lex_state = 0, .external_lex_state = 28},
  [16538] = {.lex_state = 117},
  [16539] = {.lex_state = 0},
  [16540] = {.lex_state = 117},
  [16541] = {.lex_state = 117},
  [16542] = {.lex_state = 117},
  [16543] = {.lex_state = 117, .external_lex_state = 29},
  [16544] = {.lex_state = 0},
  [16545] = {.lex_state = 0},
  [16546] = {.lex_state = 117},
  [16547] = {.lex_state = 0},
  [16548] = {.lex_state = 0},
  [16549] = {.lex_state = 0, .external_lex_state = 28},
  [16550] = {.lex_state = 117},
  [16551] = {.lex_state = 117},
  [16552] = {.lex_state = 117},
  [16553] = {.lex_state = 117},
  [16554] = {.lex_state = 0},
  [16555] = {.lex_state = 17},
  [16556] = {.lex_state = 117},
  [16557] = {.lex_state = 0},
  [16558] = {.lex_state = 0},
  [16559] = {.lex_state = 117},
  [16560] = {.lex_state = 117},
  [16561] = {.lex_state = 117},
  [16562] = {.lex_state = 117},
  [16563] = {.lex_state = 0},
  [16564] = {.lex_state = 0},
  [16565] = {.lex_state = 0},
  [16566] = {.lex_state = 117},
  [16567] = {.lex_state = 0},
  [16568] = {.lex_state = 0},
  [16569] = {.lex_state = 117},
  [16570] = {.lex_state = 0},
  [16571] = {.lex_state = 10},
  [16572] = {.lex_state = 0},
  [16573] = {.lex_state = 117},
  [16574] = {.lex_state = 0},
  [16575] = {.lex_state = 117},
  [16576] = {.lex_state = 0},
  [16577] = {.lex_state = 0},
  [16578] = {.lex_state = 0},
  [16579] = {.lex_state = 117},
  [16580] = {.lex_state = 117},
  [16581] = {.lex_state = 17},
  [16582] = {.lex_state = 0},
  [16583] = {.lex_state = 0},
  [16584] = {.lex_state = 117},
  [16585] = {.lex_state = 17},
  [16586] = {.lex_state = 117},
  [16587] = {.lex_state = 17},
  [16588] = {.lex_state = 117},
  [16589] = {.lex_state = 17},
  [16590] = {.lex_state = 0},
  [16591] = {.lex_state = 117},
  [16592] = {.lex_state = 117},
  [16593] = {.lex_state = 0},
  [16594] = {.lex_state = 117},
  [16595] = {.lex_state = 0},
  [16596] = {.lex_state = 117},
  [16597] = {.lex_state = 16},
  [16598] = {.lex_state = 117},
  [16599] = {.lex_state = 0},
  [16600] = {.lex_state = 117},
  [16601] = {.lex_state = 0},
  [16602] = {.lex_state = 17},
  [16603] = {.lex_state = 117},
  [16604] = {.lex_state = 117},
  [16605] = {.lex_state = 117},
  [16606] = {.lex_state = 0},
  [16607] = {.lex_state = 117},
  [16608] = {.lex_state = 117},
  [16609] = {.lex_state = 117},
  [16610] = {.lex_state = 117},
  [16611] = {.lex_state = 0},
  [16612] = {.lex_state = 117},
  [16613] = {.lex_state = 117},
  [16614] = {.lex_state = 0},
  [16615] = {.lex_state = 117},
  [16616] = {.lex_state = 117},
  [16617] = {.lex_state = 117},
  [16618] = {.lex_state = 0},
  [16619] = {.lex_state = 117},
  [16620] = {.lex_state = 117},
  [16621] = {.lex_state = 117},
  [16622] = {.lex_state = 117},
  [16623] = {.lex_state = 117},
  [16624] = {.lex_state = 10},
  [16625] = {.lex_state = 117},
  [16626] = {.lex_state = 117},
  [16627] = {.lex_state = 117},
  [16628] = {.lex_state = 117},
  [16629] = {.lex_state = 10},
  [16630] = {.lex_state = 117},
  [16631] = {.lex_state = 117},
  [16632] = {.lex_state = 0},
  [16633] = {.lex_state = 0},
  [16634] = {.lex_state = 0},
  [16635] = {.lex_state = 117},
  [16636] = {.lex_state = 117},
  [16637] = {.lex_state = 0},
  [16638] = {.lex_state = 10},
  [16639] = {.lex_state = 17},
  [16640] = {.lex_state = 17},
  [16641] = {.lex_state = 0},
  [16642] = {.lex_state = 117},
  [16643] = {.lex_state = 117},
  [16644] = {.lex_state = 0},
  [16645] = {.lex_state = 0},
  [16646] = {.lex_state = 117},
  [16647] = {.lex_state = 0},
  [16648] = {.lex_state = 117},
  [16649] = {.lex_state = 117},
  [16650] = {.lex_state = 117},
  [16651] = {.lex_state = 0},
  [16652] = {.lex_state = 0},
  [16653] = {.lex_state = 10},
  [16654] = {.lex_state = 17},
  [16655] = {.lex_state = 117},
  [16656] = {.lex_state = 0},
  [16657] = {.lex_state = 0},
  [16658] = {.lex_state = 117},
  [16659] = {.lex_state = 117},
  [16660] = {.lex_state = 117},
  [16661] = {.lex_state = 0},
  [16662] = {.lex_state = 117},
  [16663] = {.lex_state = 0},
  [16664] = {.lex_state = 0},
  [16665] = {.lex_state = 0},
  [16666] = {.lex_state = 0},
  [16667] = {.lex_state = 0},
  [16668] = {.lex_state = 0},
  [16669] = {.lex_state = 117},
  [16670] = {.lex_state = 0},
  [16671] = {.lex_state = 0},
  [16672] = {.lex_state = 117},
  [16673] = {.lex_state = 0},
  [16674] = {.lex_state = 117},
  [16675] = {.lex_state = 0},
  [16676] = {.lex_state = 0},
  [16677] = {.lex_state = 117},
  [16678] = {.lex_state = 10},
  [16679] = {.lex_state = 0},
  [16680] = {.lex_state = 0},
  [16681] = {.lex_state = 0},
  [16682] = {.lex_state = 0},
  [16683] = {.lex_state = 0},
  [16684] = {.lex_state = 0},
  [16685] = {.lex_state = 0},
  [16686] = {.lex_state = 0},
  [16687] = {.lex_state = 0},
  [16688] = {.lex_state = 117},
  [16689] = {.lex_state = 117},
  [16690] = {.lex_state = 0},
  [16691] = {.lex_state = 0},
  [16692] = {.lex_state = 0},
  [16693] = {.lex_state = 0},
  [16694] = {.lex_state = 10},
  [16695] = {.lex_state = 117},
  [16696] = {.lex_state = 117},
  [16697] = {.lex_state = 117},
  [16698] = {.lex_state = 0},
  [16699] = {.lex_state = 117},
  [16700] = {.lex_state = 0},
  [16701] = {.lex_state = 117},
  [16702] = {.lex_state = 117},
  [16703] = {.lex_state = 0},
  [16704] = {.lex_state = 117},
  [16705] = {.lex_state = 117},
  [16706] = {.lex_state = 117},
  [16707] = {.lex_state = 117},
  [16708] = {.lex_state = 117},
  [16709] = {.lex_state = 117},
  [16710] = {.lex_state = 0},
  [16711] = {.lex_state = 117},
  [16712] = {.lex_state = 0},
  [16713] = {.lex_state = 10},
  [16714] = {.lex_state = 117},
  [16715] = {.lex_state = 17},
  [16716] = {.lex_state = 117},
  [16717] = {.lex_state = 117},
  [16718] = {.lex_state = 117},
  [16719] = {.lex_state = 117},
  [16720] = {.lex_state = 117},
  [16721] = {.lex_state = 117},
  [16722] = {.lex_state = 0},
  [16723] = {.lex_state = 117},
  [16724] = {.lex_state = 117},
  [16725] = {.lex_state = 0},
  [16726] = {.lex_state = 117},
  [16727] = {.lex_state = 0},
  [16728] = {.lex_state = 117},
  [16729] = {.lex_state = 117},
  [16730] = {.lex_state = 117},
  [16731] = {.lex_state = 117},
  [16732] = {.lex_state = 117},
  [16733] = {.lex_state = 117},
  [16734] = {.lex_state = 117},
  [16735] = {.lex_state = 117},
  [16736] = {.lex_state = 117},
  [16737] = {.lex_state = 117},
  [16738] = {.lex_state = 0},
  [16739] = {.lex_state = 117},
  [16740] = {.lex_state = 0},
  [16741] = {.lex_state = 0, .external_lex_state = 28},
  [16742] = {.lex_state = 117},
  [16743] = {.lex_state = 0},
  [16744] = {.lex_state = 0},
  [16745] = {.lex_state = 117},
  [16746] = {.lex_state = 10},
  [16747] = {.lex_state = 117},
  [16748] = {.lex_state = 0},
  [16749] = {.lex_state = 117},
  [16750] = {.lex_state = 0},
  [16751] = {.lex_state = 0},
  [16752] = {.lex_state = 117},
  [16753] = {.lex_state = 0},
  [16754] = {.lex_state = 0},
  [16755] = {.lex_state = 0},
  [16756] = {.lex_state = 0},
  [16757] = {.lex_state = 10},
  [16758] = {.lex_state = 0},
  [16759] = {.lex_state = 0},
  [16760] = {.lex_state = 0},
  [16761] = {.lex_state = 117},
  [16762] = {.lex_state = 0},
  [16763] = {.lex_state = 0},
  [16764] = {.lex_state = 0},
  [16765] = {.lex_state = 0},
  [16766] = {.lex_state = 0},
  [16767] = {.lex_state = 117},
  [16768] = {.lex_state = 0},
  [16769] = {.lex_state = 117},
  [16770] = {.lex_state = 117},
  [16771] = {.lex_state = 117},
  [16772] = {.lex_state = 0},
  [16773] = {.lex_state = 117},
  [16774] = {.lex_state = 0},
  [16775] = {.lex_state = 117},
  [16776] = {.lex_state = 0},
  [16777] = {.lex_state = 0},
  [16778] = {.lex_state = 0},
  [16779] = {.lex_state = 0},
  [16780] = {.lex_state = 117},
  [16781] = {.lex_state = 117},
  [16782] = {.lex_state = 117},
  [16783] = {.lex_state = 117},
  [16784] = {.lex_state = 0},
  [16785] = {.lex_state = 117},
  [16786] = {.lex_state = 117},
  [16787] = {.lex_state = 117},
  [16788] = {.lex_state = 117},
  [16789] = {.lex_state = 10},
  [16790] = {.lex_state = 117},
  [16791] = {.lex_state = 0},
  [16792] = {.lex_state = 117},
  [16793] = {.lex_state = 117},
  [16794] = {.lex_state = 117},
  [16795] = {.lex_state = 117},
  [16796] = {.lex_state = 0},
  [16797] = {.lex_state = 117},
  [16798] = {.lex_state = 117},
  [16799] = {.lex_state = 10},
  [16800] = {.lex_state = 0},
  [16801] = {.lex_state = 117},
  [16802] = {.lex_state = 0},
  [16803] = {.lex_state = 117},
  [16804] = {.lex_state = 117},
  [16805] = {.lex_state = 117},
  [16806] = {.lex_state = 0},
  [16807] = {.lex_state = 117},
  [16808] = {.lex_state = 0},
  [16809] = {.lex_state = 117},
  [16810] = {.lex_state = 0},
  [16811] = {.lex_state = 0},
  [16812] = {.lex_state = 117},
  [16813] = {.lex_state = 0},
  [16814] = {.lex_state = 0},
  [16815] = {.lex_state = 10},
  [16816] = {.lex_state = 10},
  [16817] = {.lex_state = 0},
  [16818] = {.lex_state = 0},
  [16819] = {.lex_state = 117},
  [16820] = {.lex_state = 0},
  [16821] = {.lex_state = 117},
  [16822] = {.lex_state = 0},
  [16823] = {.lex_state = 117},
  [16824] = {.lex_state = 0},
  [16825] = {.lex_state = 117},
  [16826] = {.lex_state = 117},
  [16827] = {.lex_state = 117},
  [16828] = {.lex_state = 117},
  [16829] = {.lex_state = 117},
  [16830] = {.lex_state = 0},
  [16831] = {.lex_state = 117},
  [16832] = {.lex_state = 117},
  [16833] = {.lex_state = 0},
  [16834] = {.lex_state = 117},
  [16835] = {.lex_state = 0},
  [16836] = {.lex_state = 117},
  [16837] = {.lex_state = 117},
  [16838] = {.lex_state = 117},
  [16839] = {.lex_state = 117},
  [16840] = {.lex_state = 16},
  [16841] = {.lex_state = 117},
  [16842] = {.lex_state = 117},
  [16843] = {.lex_state = 0},
  [16844] = {.lex_state = 117},
  [16845] = {.lex_state = 0},
  [16846] = {.lex_state = 117},
  [16847] = {.lex_state = 117},
  [16848] = {.lex_state = 117},
  [16849] = {.lex_state = 117},
  [16850] = {.lex_state = 117},
  [16851] = {.lex_state = 117},
  [16852] = {.lex_state = 117},
  [16853] = {.lex_state = 117},
  [16854] = {.lex_state = 117},
  [16855] = {.lex_state = 0},
  [16856] = {.lex_state = 117},
  [16857] = {.lex_state = 117},
  [16858] = {.lex_state = 10},
  [16859] = {.lex_state = 0},
  [16860] = {.lex_state = 0},
  [16861] = {.lex_state = 0},
  [16862] = {.lex_state = 0},
  [16863] = {.lex_state = 0},
  [16864] = {.lex_state = 117},
  [16865] = {.lex_state = 117},
  [16866] = {.lex_state = 10},
  [16867] = {.lex_state = 0},
  [16868] = {.lex_state = 0},
  [16869] = {.lex_state = 0},
  [16870] = {.lex_state = 0},
  [16871] = {.lex_state = 10},
  [16872] = {.lex_state = 117},
  [16873] = {.lex_state = 0},
  [16874] = {.lex_state = 0},
  [16875] = {.lex_state = 117},
  [16876] = {.lex_state = 117},
  [16877] = {.lex_state = 0},
  [16878] = {.lex_state = 117},
  [16879] = {.lex_state = 0},
  [16880] = {.lex_state = 117},
  [16881] = {.lex_state = 0},
  [16882] = {.lex_state = 0},
  [16883] = {.lex_state = 0},
  [16884] = {.lex_state = 0},
  [16885] = {.lex_state = 117},
  [16886] = {.lex_state = 117},
  [16887] = {.lex_state = 117},
  [16888] = {.lex_state = 117},
  [16889] = {.lex_state = 0},
  [16890] = {.lex_state = 117},
  [16891] = {.lex_state = 117},
  [16892] = {.lex_state = 0},
  [16893] = {.lex_state = 117},
  [16894] = {.lex_state = 117},
  [16895] = {.lex_state = 117},
  [16896] = {.lex_state = 0},
  [16897] = {.lex_state = 117},
  [16898] = {.lex_state = 117},
  [16899] = {.lex_state = 117},
  [16900] = {.lex_state = 117},
  [16901] = {.lex_state = 0},
  [16902] = {.lex_state = 117},
  [16903] = {.lex_state = 117},
  [16904] = {.lex_state = 117},
  [16905] = {.lex_state = 117},
  [16906] = {.lex_state = 117},
  [16907] = {.lex_state = 0},
  [16908] = {.lex_state = 0},
  [16909] = {.lex_state = 0},
  [16910] = {.lex_state = 0},
  [16911] = {.lex_state = 0},
  [16912] = {.lex_state = 10},
  [16913] = {.lex_state = 0},
  [16914] = {.lex_state = 0},
  [16915] = {.lex_state = 0},
  [16916] = {.lex_state = 0},
  [16917] = {.lex_state = 0},
  [16918] = {.lex_state = 117},
  [16919] = {.lex_state = 0},
  [16920] = {.lex_state = 0},
  [16921] = {.lex_state = 117},
  [16922] = {.lex_state = 117},
  [16923] = {.lex_state = 0},
  [16924] = {.lex_state = 117},
  [16925] = {.lex_state = 0},
  [16926] = {.lex_state = 117},
  [16927] = {.lex_state = 0},
  [16928] = {.lex_state = 117},
  [16929] = {.lex_state = 0},
  [16930] = {.lex_state = 0},
  [16931] = {.lex_state = 117},
  [16932] = {.lex_state = 117},
  [16933] = {.lex_state = 117},
  [16934] = {.lex_state = 117},
  [16935] = {.lex_state = 0},
  [16936] = {.lex_state = 117},
  [16937] = {.lex_state = 117},
  [16938] = {.lex_state = 0},
  [16939] = {.lex_state = 117},
  [16940] = {.lex_state = 0},
  [16941] = {.lex_state = 117},
  [16942] = {.lex_state = 117},
  [16943] = {.lex_state = 117},
  [16944] = {.lex_state = 117},
  [16945] = {.lex_state = 117},
  [16946] = {.lex_state = 117},
  [16947] = {.lex_state = 0},
  [16948] = {.lex_state = 117},
  [16949] = {.lex_state = 117},
  [16950] = {.lex_state = 117},
  [16951] = {.lex_state = 0},
  [16952] = {.lex_state = 0},
  [16953] = {.lex_state = 0},
  [16954] = {.lex_state = 10},
  [16955] = {.lex_state = 0},
  [16956] = {.lex_state = 0},
  [16957] = {.lex_state = 117},
  [16958] = {.lex_state = 117},
  [16959] = {.lex_state = 117},
  [16960] = {.lex_state = 117},
  [16961] = {.lex_state = 0},
  [16962] = {.lex_state = 0},
  [16963] = {.lex_state = 10},
  [16964] = {.lex_state = 0},
  [16965] = {.lex_state = 0},
  [16966] = {.lex_state = 117},
  [16967] = {.lex_state = 117},
  [16968] = {.lex_state = 117},
  [16969] = {.lex_state = 117},
  [16970] = {.lex_state = 0},
  [16971] = {.lex_state = 0},
  [16972] = {.lex_state = 10},
  [16973] = {.lex_state = 0},
  [16974] = {.lex_state = 0},
  [16975] = {.lex_state = 117},
  [16976] = {.lex_state = 117},
  [16977] = {.lex_state = 117},
  [16978] = {.lex_state = 117},
  [16979] = {.lex_state = 10},
  [16980] = {.lex_state = 0},
  [16981] = {.lex_state = 0},
  [16982] = {.lex_state = 117},
  [16983] = {.lex_state = 117},
  [16984] = {.lex_state = 117},
  [16985] = {.lex_state = 117},
  [16986] = {.lex_state = 10},
  [16987] = {.lex_state = 0},
  [16988] = {.lex_state = 0},
  [16989] = {.lex_state = 117},
  [16990] = {.lex_state = 117},
  [16991] = {.lex_state = 117},
  [16992] = {.lex_state = 117},
  [16993] = {.lex_state = 10},
  [16994] = {.lex_state = 117},
  [16995] = {.lex_state = 117},
  [16996] = {.lex_state = 117},
  [16997] = {.lex_state = 117},
  [16998] = {.lex_state = 10},
  [16999] = {.lex_state = 117},
  [17000] = {.lex_state = 117},
  [17001] = {.lex_state = 117},
  [17002] = {.lex_state = 117},
  [17003] = {.lex_state = 117},
  [17004] = {.lex_state = 117},
  [17005] = {.lex_state = 117},
  [17006] = {.lex_state = 117},
  [17007] = {.lex_state = 117},
  [17008] = {.lex_state = 117},
  [17009] = {.lex_state = 117},
  [17010] = {.lex_state = 117},
  [17011] = {.lex_state = 117},
  [17012] = {.lex_state = 117},
  [17013] = {.lex_state = 117},
  [17014] = {.lex_state = 117},
  [17015] = {.lex_state = 117},
  [17016] = {.lex_state = 117},
  [17017] = {.lex_state = 117},
  [17018] = {.lex_state = 117},
  [17019] = {.lex_state = 117},
  [17020] = {.lex_state = 117},
  [17021] = {.lex_state = 117},
  [17022] = {.lex_state = 117},
  [17023] = {.lex_state = 10},
  [17024] = {.lex_state = 10},
  [17025] = {.lex_state = 10},
  [17026] = {.lex_state = 10},
  [17027] = {.lex_state = 10},
  [17028] = {.lex_state = 10},
  [17029] = {.lex_state = 10},
  [17030] = {.lex_state = 10},
  [17031] = {.lex_state = 117},
  [17032] = {.lex_state = 117},
  [17033] = {.lex_state = 0},
  [17034] = {.lex_state = 0},
  [17035] = {.lex_state = 117},
  [17036] = {.lex_state = 117},
  [17037] = {.lex_state = 117},
  [17038] = {.lex_state = 117},
  [17039] = {.lex_state = 117},
  [17040] = {.lex_state = 0},
  [17041] = {.lex_state = 0},
  [17042] = {.lex_state = 117},
  [17043] = {.lex_state = 117},
  [17044] = {.lex_state = 117},
  [17045] = {.lex_state = 0},
  [17046] = {.lex_state = 10},
  [17047] = {.lex_state = 117},
  [17048] = {.lex_state = 117},
  [17049] = {.lex_state = 0},
  [17050] = {.lex_state = 0},
  [17051] = {.lex_state = 117},
  [17052] = {.lex_state = 0},
  [17053] = {.lex_state = 117},
  [17054] = {.lex_state = 117},
  [17055] = {.lex_state = 117},
  [17056] = {.lex_state = 0},
  [17057] = {.lex_state = 117},
  [17058] = {.lex_state = 0},
  [17059] = {.lex_state = 0},
  [17060] = {.lex_state = 17},
  [17061] = {.lex_state = 117},
  [17062] = {.lex_state = 0},
  [17063] = {.lex_state = 0},
  [17064] = {.lex_state = 117},
  [17065] = {.lex_state = 10},
  [17066] = {.lex_state = 10},
  [17067] = {.lex_state = 0},
  [17068] = {.lex_state = 117},
  [17069] = {.lex_state = 117},
  [17070] = {.lex_state = 117},
  [17071] = {.lex_state = 0},
  [17072] = {.lex_state = 0},
  [17073] = {.lex_state = 0},
  [17074] = {.lex_state = 0},
  [17075] = {.lex_state = 0},
  [17076] = {.lex_state = 0},
  [17077] = {.lex_state = 117},
  [17078] = {.lex_state = 10},
  [17079] = {.lex_state = 0},
  [17080] = {.lex_state = 10},
  [17081] = {.lex_state = 117},
  [17082] = {.lex_state = 117},
  [17083] = {.lex_state = 0},
  [17084] = {.lex_state = 0},
  [17085] = {.lex_state = 0},
  [17086] = {.lex_state = 0},
  [17087] = {.lex_state = 10},
  [17088] = {.lex_state = 117},
  [17089] = {.lex_state = 0},
  [17090] = {.lex_state = 10},
  [17091] = {.lex_state = 10},
  [17092] = {.lex_state = 0},
  [17093] = {.lex_state = 117},
  [17094] = {.lex_state = 0},
  [17095] = {.lex_state = 0},
  [17096] = {.lex_state = 117},
  [17097] = {.lex_state = 0},
  [17098] = {.lex_state = 0},
  [17099] = {.lex_state = 0},
  [17100] = {.lex_state = 117},
  [17101] = {.lex_state = 0},
  [17102] = {.lex_state = 0},
  [17103] = {.lex_state = 0},
  [17104] = {.lex_state = 0},
  [17105] = {.lex_state = 0},
  [17106] = {.lex_state = 117},
  [17107] = {.lex_state = 0},
  [17108] = {.lex_state = 117},
  [17109] = {.lex_state = 0},
  [17110] = {.lex_state = 0},
  [17111] = {.lex_state = 117},
  [17112] = {.lex_state = 0},
  [17113] = {.lex_state = 0},
  [17114] = {.lex_state = 117},
  [17115] = {.lex_state = 0},
  [17116] = {.lex_state = 0},
  [17117] = {.lex_state = 0},
  [17118] = {.lex_state = 0},
  [17119] = {.lex_state = 17},
  [17120] = {.lex_state = 0},
  [17121] = {.lex_state = 0},
  [17122] = {.lex_state = 0},
  [17123] = {.lex_state = 117},
  [17124] = {.lex_state = 117},
  [17125] = {.lex_state = 0},
  [17126] = {.lex_state = 0},
  [17127] = {.lex_state = 0},
  [17128] = {.lex_state = 0},
  [17129] = {.lex_state = 0},
  [17130] = {.lex_state = 0},
  [17131] = {.lex_state = 0},
  [17132] = {.lex_state = 0},
  [17133] = {.lex_state = 0},
  [17134] = {.lex_state = 0},
  [17135] = {.lex_state = 0},
  [17136] = {.lex_state = 0},
  [17137] = {.lex_state = 0},
  [17138] = {.lex_state = 0},
  [17139] = {.lex_state = 0},
  [17140] = {.lex_state = 0},
  [17141] = {.lex_state = 117},
  [17142] = {.lex_state = 0},
  [17143] = {.lex_state = 0},
  [17144] = {.lex_state = 10},
  [17145] = {.lex_state = 0},
  [17146] = {.lex_state = 0},
  [17147] = {.lex_state = 0},
  [17148] = {.lex_state = 117},
  [17149] = {.lex_state = 117},
  [17150] = {.lex_state = 0},
  [17151] = {.lex_state = 0},
  [17152] = {.lex_state = 0},
  [17153] = {.lex_state = 117},
  [17154] = {.lex_state = 0},
  [17155] = {.lex_state = 0},
  [17156] = {.lex_state = 117},
  [17157] = {.lex_state = 0},
  [17158] = {.lex_state = 0},
  [17159] = {.lex_state = 0},
  [17160] = {.lex_state = 0},
  [17161] = {.lex_state = 0},
  [17162] = {.lex_state = 10},
  [17163] = {.lex_state = 0},
  [17164] = {.lex_state = 117},
  [17165] = {.lex_state = 10},
  [17166] = {.lex_state = 117},
  [17167] = {.lex_state = 0},
  [17168] = {.lex_state = 0},
  [17169] = {.lex_state = 0},
  [17170] = {.lex_state = 117},
  [17171] = {.lex_state = 0},
  [17172] = {.lex_state = 10},
  [17173] = {.lex_state = 0},
  [17174] = {.lex_state = 0},
  [17175] = {.lex_state = 0},
  [17176] = {.lex_state = 0},
  [17177] = {.lex_state = 0},
  [17178] = {.lex_state = 0},
  [17179] = {.lex_state = 0},
  [17180] = {.lex_state = 0},
  [17181] = {.lex_state = 10},
  [17182] = {.lex_state = 10},
  [17183] = {.lex_state = 0},
  [17184] = {.lex_state = 0},
  [17185] = {.lex_state = 0},
  [17186] = {.lex_state = 0},
  [17187] = {.lex_state = 0},
  [17188] = {.lex_state = 0},
  [17189] = {.lex_state = 0},
  [17190] = {.lex_state = 0},
  [17191] = {.lex_state = 117},
  [17192] = {.lex_state = 117},
  [17193] = {.lex_state = 17},
  [17194] = {.lex_state = 0},
  [17195] = {.lex_state = 0},
  [17196] = {.lex_state = 0},
  [17197] = {.lex_state = 0},
  [17198] = {.lex_state = 0},
  [17199] = {.lex_state = 117},
  [17200] = {.lex_state = 0},
  [17201] = {.lex_state = 0},
  [17202] = {.lex_state = 17},
  [17203] = {.lex_state = 16},
  [17204] = {.lex_state = 0},
  [17205] = {.lex_state = 0},
  [17206] = {.lex_state = 117},
  [17207] = {.lex_state = 0},
  [17208] = {.lex_state = 0},
  [17209] = {.lex_state = 0},
  [17210] = {.lex_state = 0},
  [17211] = {.lex_state = 0},
  [17212] = {.lex_state = 0},
  [17213] = {.lex_state = 10},
  [17214] = {.lex_state = 10},
  [17215] = {.lex_state = 10},
  [17216] = {.lex_state = 0},
  [17217] = {.lex_state = 117},
  [17218] = {.lex_state = 117},
  [17219] = {.lex_state = 0},
  [17220] = {.lex_state = 0},
  [17221] = {.lex_state = 0},
  [17222] = {.lex_state = 117},
  [17223] = {.lex_state = 117},
  [17224] = {.lex_state = 0},
  [17225] = {.lex_state = 117},
  [17226] = {.lex_state = 0},
  [17227] = {.lex_state = 117},
  [17228] = {.lex_state = 0},
  [17229] = {.lex_state = 0},
  [17230] = {.lex_state = 0},
  [17231] = {.lex_state = 117},
  [17232] = {.lex_state = 10},
  [17233] = {.lex_state = 10},
  [17234] = {.lex_state = 0},
  [17235] = {.lex_state = 10},
  [17236] = {.lex_state = 0},
  [17237] = {.lex_state = 0},
  [17238] = {.lex_state = 117},
  [17239] = {.lex_state = 0},
  [17240] = {.lex_state = 117},
  [17241] = {.lex_state = 0},
  [17242] = {.lex_state = 0},
  [17243] = {.lex_state = 117},
  [17244] = {.lex_state = 117},
  [17245] = {.lex_state = 0},
  [17246] = {.lex_state = 0},
  [17247] = {.lex_state = 0},
  [17248] = {.lex_state = 0},
  [17249] = {.lex_state = 10},
  [17250] = {.lex_state = 0},
  [17251] = {.lex_state = 0},
  [17252] = {.lex_state = 117},
  [17253] = {.lex_state = 117},
  [17254] = {.lex_state = 117},
  [17255] = {.lex_state = 0},
  [17256] = {.lex_state = 0},
  [17257] = {.lex_state = 0},
  [17258] = {.lex_state = 0},
  [17259] = {.lex_state = 17},
  [17260] = {.lex_state = 117},
  [17261] = {.lex_state = 0},
  [17262] = {.lex_state = 0},
  [17263] = {.lex_state = 17},
  [17264] = {.lex_state = 0},
  [17265] = {.lex_state = 117},
  [17266] = {.lex_state = 0},
  [17267] = {.lex_state = 0},
  [17268] = {.lex_state = 0},
  [17269] = {.lex_state = 0},
  [17270] = {.lex_state = 0},
  [17271] = {.lex_state = 117},
  [17272] = {.lex_state = 0},
  [17273] = {.lex_state = 0},
  [17274] = {.lex_state = 117},
  [17275] = {.lex_state = 0},
  [17276] = {.lex_state = 0},
  [17277] = {.lex_state = 0},
  [17278] = {.lex_state = 0},
  [17279] = {.lex_state = 10},
  [17280] = {.lex_state = 0},
  [17281] = {.lex_state = 0},
  [17282] = {.lex_state = 10},
  [17283] = {.lex_state = 0},
  [17284] = {.lex_state = 0},
  [17285] = {.lex_state = 0},
  [17286] = {.lex_state = 0},
  [17287] = {.lex_state = 117},
  [17288] = {.lex_state = 117},
  [17289] = {.lex_state = 17},
  [17290] = {.lex_state = 117},
  [17291] = {.lex_state = 0},
  [17292] = {.lex_state = 117},
  [17293] = {.lex_state = 0},
  [17294] = {.lex_state = 117},
  [17295] = {.lex_state = 0},
  [17296] = {.lex_state = 0},
  [17297] = {.lex_state = 0},
  [17298] = {.lex_state = 0},
  [17299] = {.lex_state = 0},
  [17300] = {.lex_state = 117},
  [17301] = {.lex_state = 0},
  [17302] = {.lex_state = 0},
  [17303] = {.lex_state = 0},
  [17304] = {.lex_state = 117},
  [17305] = {.lex_state = 117},
  [17306] = {.lex_state = 0},
  [17307] = {.lex_state = 0},
  [17308] = {.lex_state = 0},
  [17309] = {.lex_state = 0},
  [17310] = {.lex_state = 0},
  [17311] = {.lex_state = 0},
  [17312] = {.lex_state = 10},
  [17313] = {.lex_state = 0},
  [17314] = {.lex_state = 0},
  [17315] = {.lex_state = 0},
  [17316] = {.lex_state = 0},
  [17317] = {.lex_state = 0},
  [17318] = {.lex_state = 10},
  [17319] = {.lex_state = 117},
  [17320] = {.lex_state = 0},
  [17321] = {.lex_state = 0},
  [17322] = {.lex_state = 0},
  [17323] = {.lex_state = 0},
  [17324] = {.lex_state = 10},
  [17325] = {.lex_state = 0},
  [17326] = {.lex_state = 117},
  [17327] = {.lex_state = 117},
  [17328] = {.lex_state = 117},
  [17329] = {.lex_state = 0},
  [17330] = {.lex_state = 0},
  [17331] = {.lex_state = 117},
  [17332] = {.lex_state = 117},
  [17333] = {.lex_state = 0},
  [17334] = {.lex_state = 0},
  [17335] = {.lex_state = 17},
  [17336] = {.lex_state = 0},
  [17337] = {.lex_state = 0},
  [17338] = {.lex_state = 0},
  [17339] = {.lex_state = 117},
  [17340] = {.lex_state = 10},
  [17341] = {.lex_state = 10},
  [17342] = {.lex_state = 117},
  [17343] = {.lex_state = 117},
  [17344] = {.lex_state = 0},
  [17345] = {.lex_state = 0},
  [17346] = {.lex_state = 10},
  [17347] = {.lex_state = 0},
  [17348] = {.lex_state = 0},
  [17349] = {.lex_state = 0},
  [17350] = {.lex_state = 10},
  [17351] = {.lex_state = 0},
  [17352] = {.lex_state = 117},
  [17353] = {.lex_state = 0},
  [17354] = {.lex_state = 0},
  [17355] = {.lex_state = 0},
  [17356] = {.lex_state = 0},
  [17357] = {.lex_state = 0},
  [17358] = {.lex_state = 0},
  [17359] = {.lex_state = 0},
  [17360] = {.lex_state = 0},
  [17361] = {.lex_state = 0},
  [17362] = {.lex_state = 117},
  [17363] = {.lex_state = 10},
  [17364] = {.lex_state = 117},
  [17365] = {.lex_state = 117},
  [17366] = {.lex_state = 10},
  [17367] = {.lex_state = 0},
  [17368] = {.lex_state = 117},
  [17369] = {.lex_state = 117},
  [17370] = {.lex_state = 0},
  [17371] = {.lex_state = 0},
  [17372] = {.lex_state = 0},
  [17373] = {.lex_state = 0},
  [17374] = {.lex_state = 17},
  [17375] = {.lex_state = 117},
  [17376] = {.lex_state = 0},
  [17377] = {.lex_state = 0},
  [17378] = {.lex_state = 16},
  [17379] = {.lex_state = 17},
  [17380] = {.lex_state = 0},
  [17381] = {.lex_state = 0},
  [17382] = {.lex_state = 0},
  [17383] = {.lex_state = 0},
  [17384] = {.lex_state = 0},
  [17385] = {.lex_state = 117},
  [17386] = {.lex_state = 0},
  [17387] = {.lex_state = 117},
  [17388] = {.lex_state = 0},
  [17389] = {.lex_state = 117},
  [17390] = {.lex_state = 117},
  [17391] = {.lex_state = 0},
  [17392] = {.lex_state = 17},
  [17393] = {.lex_state = 10},
  [17394] = {.lex_state = 0},
  [17395] = {.lex_state = 0},
  [17396] = {.lex_state = 0},
  [17397] = {.lex_state = 117},
  [17398] = {.lex_state = 0},
  [17399] = {.lex_state = 0},
  [17400] = {.lex_state = 117},
  [17401] = {.lex_state = 17},
  [17402] = {.lex_state = 117},
  [17403] = {.lex_state = 0},
  [17404] = {.lex_state = 10},
  [17405] = {.lex_state = 10},
  [17406] = {.lex_state = 117},
  [17407] = {.lex_state = 0},
  [17408] = {.lex_state = 0},
  [17409] = {.lex_state = 0},
  [17410] = {.lex_state = 0},
  [17411] = {.lex_state = 0},
  [17412] = {.lex_state = 117},
  [17413] = {.lex_state = 117},
  [17414] = {.lex_state = 0},
  [17415] = {.lex_state = 0},
  [17416] = {.lex_state = 117},
  [17417] = {.lex_state = 0},
  [17418] = {.lex_state = 17},
  [17419] = {.lex_state = 17},
  [17420] = {.lex_state = 0},
  [17421] = {.lex_state = 0},
  [17422] = {.lex_state = 0},
  [17423] = {.lex_state = 0},
  [17424] = {.lex_state = 117},
  [17425] = {.lex_state = 0},
  [17426] = {.lex_state = 117},
  [17427] = {.lex_state = 0},
  [17428] = {.lex_state = 0},
  [17429] = {.lex_state = 0},
  [17430] = {.lex_state = 0},
  [17431] = {.lex_state = 0},
  [17432] = {.lex_state = 0},
  [17433] = {.lex_state = 0},
  [17434] = {.lex_state = 17},
  [17435] = {.lex_state = 0},
  [17436] = {.lex_state = 0},
  [17437] = {.lex_state = 0},
  [17438] = {.lex_state = 10},
  [17439] = {.lex_state = 117},
  [17440] = {.lex_state = 0},
  [17441] = {.lex_state = 0},
  [17442] = {.lex_state = 0},
  [17443] = {.lex_state = 17},
  [17444] = {.lex_state = 0},
  [17445] = {.lex_state = 0},
  [17446] = {.lex_state = 0},
  [17447] = {.lex_state = 17},
  [17448] = {.lex_state = 0},
  [17449] = {.lex_state = 0},
  [17450] = {.lex_state = 0},
  [17451] = {.lex_state = 17},
  [17452] = {.lex_state = 0},
  [17453] = {.lex_state = 10},
  [17454] = {.lex_state = 0},
  [17455] = {.lex_state = 0},
  [17456] = {.lex_state = 17},
  [17457] = {.lex_state = 0},
  [17458] = {.lex_state = 17},
  [17459] = {.lex_state = 0},
  [17460] = {.lex_state = 0},
  [17461] = {.lex_state = 0},
  [17462] = {.lex_state = 117},
  [17463] = {.lex_state = 10},
  [17464] = {.lex_state = 0},
  [17465] = {.lex_state = 17},
  [17466] = {.lex_state = 0},
  [17467] = {.lex_state = 117},
  [17468] = {.lex_state = 16},
  [17469] = {.lex_state = 10},
  [17470] = {.lex_state = 0},
  [17471] = {.lex_state = 0},
  [17472] = {.lex_state = 17},
  [17473] = {.lex_state = 117},
  [17474] = {.lex_state = 117},
  [17475] = {.lex_state = 0},
  [17476] = {.lex_state = 0},
  [17477] = {.lex_state = 0},
  [17478] = {.lex_state = 0},
  [17479] = {.lex_state = 17},
  [17480] = {.lex_state = 0},
  [17481] = {.lex_state = 0},
  [17482] = {.lex_state = 0},
  [17483] = {.lex_state = 117},
  [17484] = {.lex_state = 16},
  [17485] = {.lex_state = 0},
  [17486] = {.lex_state = 17},
  [17487] = {.lex_state = 17},
  [17488] = {.lex_state = 0},
  [17489] = {.lex_state = 0},
  [17490] = {.lex_state = 117},
  [17491] = {.lex_state = 117},
  [17492] = {.lex_state = 0},
  [17493] = {.lex_state = 0},
  [17494] = {.lex_state = 0},
  [17495] = {.lex_state = 10},
  [17496] = {.lex_state = 17},
  [17497] = {.lex_state = 0},
  [17498] = {.lex_state = 0},
  [17499] = {.lex_state = 117},
  [17500] = {.lex_state = 17},
  [17501] = {.lex_state = 0},
  [17502] = {.lex_state = 0},
  [17503] = {.lex_state = 16},
  [17504] = {.lex_state = 0},
  [17505] = {.lex_state = 117},
  [17506] = {.lex_state = 117},
  [17507] = {.lex_state = 17},
  [17508] = {.lex_state = 0},
  [17509] = {.lex_state = 117},
  [17510] = {.lex_state = 0},
  [17511] = {.lex_state = 0},
  [17512] = {.lex_state = 10},
  [17513] = {.lex_state = 0},
  [17514] = {.lex_state = 117},
  [17515] = {.lex_state = 0},
  [17516] = {.lex_state = 0},
  [17517] = {.lex_state = 0},
  [17518] = {.lex_state = 0},
  [17519] = {.lex_state = 0},
  [17520] = {.lex_state = 0},
  [17521] = {.lex_state = 0},
  [17522] = {.lex_state = 0},
  [17523] = {.lex_state = 0},
  [17524] = {.lex_state = 117},
  [17525] = {.lex_state = 0},
  [17526] = {.lex_state = 0},
  [17527] = {.lex_state = 0},
  [17528] = {.lex_state = 0},
  [17529] = {.lex_state = 117},
  [17530] = {.lex_state = 117},
  [17531] = {.lex_state = 117},
  [17532] = {.lex_state = 0},
  [17533] = {.lex_state = 117},
  [17534] = {.lex_state = 0},
  [17535] = {.lex_state = 0},
  [17536] = {.lex_state = 0},
  [17537] = {.lex_state = 117},
  [17538] = {.lex_state = 117},
  [17539] = {.lex_state = 117},
  [17540] = {.lex_state = 117},
  [17541] = {.lex_state = 117},
  [17542] = {.lex_state = 117},
  [17543] = {.lex_state = 117},
  [17544] = {.lex_state = 117},
  [17545] = {.lex_state = 117},
  [17546] = {.lex_state = 117},
  [17547] = {.lex_state = 117},
  [17548] = {.lex_state = 117},
  [17549] = {.lex_state = 117},
  [17550] = {.lex_state = 0},
  [17551] = {.lex_state = 117},
  [17552] = {.lex_state = 117},
  [17553] = {.lex_state = 117},
  [17554] = {.lex_state = 117},
  [17555] = {.lex_state = 117},
  [17556] = {.lex_state = 117},
  [17557] = {.lex_state = 117},
  [17558] = {.lex_state = 117},
  [17559] = {.lex_state = 117},
  [17560] = {.lex_state = 117},
  [17561] = {.lex_state = 117},
  [17562] = {.lex_state = 117},
  [17563] = {.lex_state = 117},
  [17564] = {.lex_state = 117},
  [17565] = {.lex_state = 117},
  [17566] = {.lex_state = 117},
  [17567] = {.lex_state = 117},
  [17568] = {.lex_state = 0},
  [17569] = {.lex_state = 0},
  [17570] = {.lex_state = 17},
  [17571] = {.lex_state = 117},
  [17572] = {.lex_state = 0},
  [17573] = {.lex_state = 117},
  [17574] = {.lex_state = 0},
  [17575] = {.lex_state = 0},
  [17576] = {.lex_state = 0},
  [17577] = {.lex_state = 0},
  [17578] = {.lex_state = 0},
  [17579] = {.lex_state = 0},
  [17580] = {.lex_state = 0},
  [17581] = {.lex_state = 0},
  [17582] = {.lex_state = 0},
  [17583] = {.lex_state = 0},
  [17584] = {.lex_state = 0},
  [17585] = {.lex_state = 0},
  [17586] = {.lex_state = 0},
  [17587] = {.lex_state = 0},
  [17588] = {.lex_state = 117},
  [17589] = {.lex_state = 0},
  [17590] = {.lex_state = 0},
  [17591] = {.lex_state = 117},
  [17592] = {.lex_state = 117},
  [17593] = {.lex_state = 117},
  [17594] = {.lex_state = 117},
  [17595] = {.lex_state = 117},
  [17596] = {.lex_state = 0},
  [17597] = {.lex_state = 0},
  [17598] = {.lex_state = 117},
  [17599] = {.lex_state = 0},
  [17600] = {.lex_state = 117},
  [17601] = {.lex_state = 117},
  [17602] = {.lex_state = 117},
  [17603] = {.lex_state = 117},
  [17604] = {.lex_state = 0},
  [17605] = {.lex_state = 0},
  [17606] = {.lex_state = 0},
  [17607] = {.lex_state = 0},
  [17608] = {.lex_state = 0},
  [17609] = {.lex_state = 117},
  [17610] = {.lex_state = 0},
  [17611] = {.lex_state = 0},
  [17612] = {.lex_state = 117},
  [17613] = {.lex_state = 0},
  [17614] = {.lex_state = 117},
  [17615] = {.lex_state = 117},
  [17616] = {.lex_state = 0},
  [17617] = {.lex_state = 0},
  [17618] = {.lex_state = 0},
  [17619] = {.lex_state = 117},
  [17620] = {.lex_state = 0},
  [17621] = {.lex_state = 0},
  [17622] = {.lex_state = 0},
  [17623] = {.lex_state = 0},
  [17624] = {.lex_state = 117},
  [17625] = {.lex_state = 117},
  [17626] = {.lex_state = 117},
  [17627] = {.lex_state = 117},
  [17628] = {.lex_state = 0},
  [17629] = {.lex_state = 117},
  [17630] = {.lex_state = 117},
  [17631] = {.lex_state = 117},
  [17632] = {.lex_state = 117},
  [17633] = {.lex_state = 117},
  [17634] = {.lex_state = 117},
  [17635] = {.lex_state = 117},
  [17636] = {.lex_state = 117},
  [17637] = {.lex_state = 117},
  [17638] = {.lex_state = 117},
  [17639] = {.lex_state = 117},
  [17640] = {.lex_state = 117},
  [17641] = {.lex_state = 117},
  [17642] = {.lex_state = 117},
  [17643] = {.lex_state = 117},
  [17644] = {.lex_state = 117},
  [17645] = {.lex_state = 117},
  [17646] = {.lex_state = 117},
  [17647] = {.lex_state = 117},
  [17648] = {.lex_state = 117},
  [17649] = {.lex_state = 117},
  [17650] = {.lex_state = 117},
  [17651] = {.lex_state = 117},
  [17652] = {.lex_state = 117},
  [17653] = {.lex_state = 117},
  [17654] = {.lex_state = 117},
  [17655] = {.lex_state = 117},
  [17656] = {.lex_state = 0},
  [17657] = {.lex_state = 0},
  [17658] = {.lex_state = 0},
  [17659] = {.lex_state = 0},
  [17660] = {.lex_state = 0},
  [17661] = {.lex_state = 0},
  [17662] = {.lex_state = 0},
  [17663] = {.lex_state = 0},
  [17664] = {.lex_state = 0},
  [17665] = {.lex_state = 117},
  [17666] = {.lex_state = 117},
  [17667] = {.lex_state = 0},
  [17668] = {.lex_state = 117},
  [17669] = {.lex_state = 0},
  [17670] = {.lex_state = 0},
  [17671] = {.lex_state = 0},
  [17672] = {.lex_state = 117},
  [17673] = {.lex_state = 0},
  [17674] = {.lex_state = 0},
  [17675] = {.lex_state = 0},
  [17676] = {.lex_state = 0},
  [17677] = {.lex_state = 0},
  [17678] = {.lex_state = 117},
  [17679] = {.lex_state = 0},
  [17680] = {.lex_state = 0},
  [17681] = {.lex_state = 0},
  [17682] = {.lex_state = 0},
  [17683] = {.lex_state = 117},
  [17684] = {.lex_state = 117},
  [17685] = {.lex_state = 117},
  [17686] = {.lex_state = 0},
  [17687] = {.lex_state = 117},
  [17688] = {.lex_state = 117},
  [17689] = {.lex_state = 117},
  [17690] = {.lex_state = 117},
  [17691] = {.lex_state = 117},
  [17692] = {.lex_state = 117},
  [17693] = {.lex_state = 117},
  [17694] = {.lex_state = 117},
  [17695] = {.lex_state = 117},
  [17696] = {.lex_state = 117},
  [17697] = {.lex_state = 117},
  [17698] = {.lex_state = 117},
  [17699] = {.lex_state = 117},
  [17700] = {.lex_state = 117},
  [17701] = {.lex_state = 117},
  [17702] = {.lex_state = 117},
  [17703] = {.lex_state = 0},
  [17704] = {.lex_state = 0},
  [17705] = {.lex_state = 0},
  [17706] = {.lex_state = 0},
  [17707] = {.lex_state = 0},
  [17708] = {.lex_state = 117},
  [17709] = {.lex_state = 0},
  [17710] = {.lex_state = 117},
  [17711] = {.lex_state = 117},
  [17712] = {.lex_state = 0},
  [17713] = {.lex_state = 0},
  [17714] = {.lex_state = 0},
  [17715] = {.lex_state = 0},
  [17716] = {.lex_state = 0},
  [17717] = {.lex_state = 0},
  [17718] = {.lex_state = 0},
  [17719] = {.lex_state = 117},
  [17720] = {.lex_state = 117},
  [17721] = {.lex_state = 0},
  [17722] = {.lex_state = 0},
  [17723] = {.lex_state = 0},
  [17724] = {.lex_state = 0},
  [17725] = {.lex_state = 117},
  [17726] = {.lex_state = 117},
  [17727] = {.lex_state = 0},
  [17728] = {.lex_state = 117},
  [17729] = {.lex_state = 117},
  [17730] = {.lex_state = 117},
  [17731] = {.lex_state = 0},
  [17732] = {.lex_state = 0},
  [17733] = {.lex_state = 117},
  [17734] = {.lex_state = 0},
  [17735] = {.lex_state = 0},
  [17736] = {.lex_state = 117},
  [17737] = {.lex_state = 117},
  [17738] = {.lex_state = 17},
  [17739] = {.lex_state = 0},
  [17740] = {.lex_state = 0},
  [17741] = {.lex_state = 0},
  [17742] = {.lex_state = 117},
  [17743] = {.lex_state = 0},
  [17744] = {.lex_state = 117},
  [17745] = {.lex_state = 117},
  [17746] = {.lex_state = 0},
  [17747] = {.lex_state = 10},
  [17748] = {.lex_state = 0},
  [17749] = {.lex_state = 0},
  [17750] = {.lex_state = 0},
  [17751] = {.lex_state = 0},
  [17752] = {.lex_state = 0},
  [17753] = {.lex_state = 0},
  [17754] = {.lex_state = 0},
  [17755] = {.lex_state = 0},
  [17756] = {.lex_state = 0},
  [17757] = {.lex_state = 16},
  [17758] = {.lex_state = 117},
  [17759] = {.lex_state = 0},
  [17760] = {.lex_state = 117},
  [17761] = {.lex_state = 0},
  [17762] = {.lex_state = 0},
  [17763] = {.lex_state = 10},
  [17764] = {.lex_state = 117},
  [17765] = {.lex_state = 0},
  [17766] = {.lex_state = 0},
  [17767] = {.lex_state = 0},
  [17768] = {.lex_state = 0},
  [17769] = {.lex_state = 0},
  [17770] = {.lex_state = 117},
  [17771] = {.lex_state = 0},
  [17772] = {.lex_state = 10},
  [17773] = {.lex_state = 0},
  [17774] = {.lex_state = 0},
  [17775] = {.lex_state = 0},
  [17776] = {.lex_state = 0},
  [17777] = {.lex_state = 0},
  [17778] = {.lex_state = 0},
  [17779] = {.lex_state = 0},
  [17780] = {.lex_state = 0},
  [17781] = {.lex_state = 0},
  [17782] = {.lex_state = 117},
  [17783] = {.lex_state = 17},
  [17784] = {.lex_state = 0},
  [17785] = {.lex_state = 0},
  [17786] = {.lex_state = 0},
  [17787] = {.lex_state = 0},
  [17788] = {.lex_state = 0},
  [17789] = {.lex_state = 0},
  [17790] = {.lex_state = 0},
  [17791] = {.lex_state = 0},
  [17792] = {.lex_state = 0},
  [17793] = {.lex_state = 0},
  [17794] = {.lex_state = 0},
  [17795] = {.lex_state = 0},
  [17796] = {.lex_state = 0},
  [17797] = {.lex_state = 0},
  [17798] = {.lex_state = 0},
  [17799] = {.lex_state = 0},
  [17800] = {.lex_state = 0},
  [17801] = {.lex_state = 0},
  [17802] = {.lex_state = 0},
  [17803] = {.lex_state = 0},
  [17804] = {.lex_state = 0},
  [17805] = {.lex_state = 0},
  [17806] = {.lex_state = 0},
  [17807] = {.lex_state = 0},
  [17808] = {.lex_state = 0},
  [17809] = {.lex_state = 0},
  [17810] = {.lex_state = 0},
  [17811] = {.lex_state = 117},
  [17812] = {.lex_state = 10},
  [17813] = {.lex_state = 0},
  [17814] = {.lex_state = 0},
  [17815] = {.lex_state = 0},
  [17816] = {.lex_state = 0},
  [17817] = {.lex_state = 0},
  [17818] = {.lex_state = 0},
  [17819] = {.lex_state = 0},
  [17820] = {.lex_state = 0},
  [17821] = {.lex_state = 117},
  [17822] = {.lex_state = 17},
  [17823] = {.lex_state = 10},
  [17824] = {.lex_state = 10},
  [17825] = {.lex_state = 0},
  [17826] = {.lex_state = 0},
  [17827] = {.lex_state = 0},
  [17828] = {.lex_state = 10},
  [17829] = {.lex_state = 10},
  [17830] = {.lex_state = 10},
  [17831] = {.lex_state = 10},
  [17832] = {.lex_state = 10},
  [17833] = {.lex_state = 10},
  [17834] = {.lex_state = 10},
  [17835] = {.lex_state = 117},
  [17836] = {.lex_state = 117},
  [17837] = {.lex_state = 117},
  [17838] = {.lex_state = 117},
  [17839] = {.lex_state = 117},
  [17840] = {.lex_state = 17},
  [17841] = {.lex_state = 10},
  [17842] = {.lex_state = 0},
  [17843] = {.lex_state = 0},
  [17844] = {.lex_state = 0},
  [17845] = {.lex_state = 0},
  [17846] = {.lex_state = 0},
  [17847] = {.lex_state = 117},
  [17848] = {.lex_state = 117},
  [17849] = {.lex_state = 117},
  [17850] = {.lex_state = 0},
  [17851] = {.lex_state = 0},
  [17852] = {.lex_state = 17},
  [17853] = {.lex_state = 17},
  [17854] = {.lex_state = 0},
  [17855] = {.lex_state = 10},
  [17856] = {.lex_state = 117},
  [17857] = {.lex_state = 0},
  [17858] = {.lex_state = 0},
  [17859] = {.lex_state = 16},
  [17860] = {.lex_state = 0},
  [17861] = {.lex_state = 0},
  [17862] = {.lex_state = 0},
  [17863] = {.lex_state = 117},
  [17864] = {.lex_state = 10},
  [17865] = {.lex_state = 0},
  [17866] = {.lex_state = 0},
  [17867] = {.lex_state = 0},
  [17868] = {.lex_state = 10},
  [17869] = {.lex_state = 0},
  [17870] = {.lex_state = 0},
  [17871] = {.lex_state = 0},
  [17872] = {.lex_state = 10},
  [17873] = {.lex_state = 0},
  [17874] = {.lex_state = 0},
  [17875] = {.lex_state = 117},
  [17876] = {.lex_state = 10},
  [17877] = {.lex_state = 17},
  [17878] = {.lex_state = 117},
  [17879] = {.lex_state = 117},
  [17880] = {.lex_state = 0},
  [17881] = {.lex_state = 0},
  [17882] = {.lex_state = 0},
  [17883] = {.lex_state = 0},
  [17884] = {.lex_state = 10},
  [17885] = {.lex_state = 0},
  [17886] = {.lex_state = 0},
  [17887] = {.lex_state = 0},
  [17888] = {.lex_state = 0},
  [17889] = {.lex_state = 0},
  [17890] = {.lex_state = 0},
  [17891] = {.lex_state = 0},
  [17892] = {.lex_state = 0},
  [17893] = {.lex_state = 0},
  [17894] = {.lex_state = 0},
  [17895] = {.lex_state = 0},
  [17896] = {.lex_state = 0},
  [17897] = {.lex_state = 0},
  [17898] = {.lex_state = 0},
  [17899] = {.lex_state = 10},
  [17900] = {.lex_state = 17},
  [17901] = {.lex_state = 0},
  [17902] = {.lex_state = 117},
  [17903] = {.lex_state = 0},
  [17904] = {.lex_state = 0},
  [17905] = {.lex_state = 0},
  [17906] = {.lex_state = 0},
  [17907] = {.lex_state = 0},
  [17908] = {.lex_state = 0},
  [17909] = {.lex_state = 117},
  [17910] = {.lex_state = 0},
  [17911] = {.lex_state = 0},
  [17912] = {.lex_state = 0},
  [17913] = {.lex_state = 0},
  [17914] = {.lex_state = 0},
  [17915] = {.lex_state = 0},
  [17916] = {.lex_state = 0},
  [17917] = {.lex_state = 0},
  [17918] = {.lex_state = 117},
  [17919] = {.lex_state = 0},
  [17920] = {.lex_state = 10},
  [17921] = {.lex_state = 17},
  [17922] = {.lex_state = 0},
  [17923] = {.lex_state = 0},
  [17924] = {.lex_state = 0},
  [17925] = {.lex_state = 0},
  [17926] = {.lex_state = 0},
  [17927] = {.lex_state = 0},
  [17928] = {.lex_state = 10},
  [17929] = {.lex_state = 17},
  [17930] = {.lex_state = 0},
  [17931] = {.lex_state = 117},
  [17932] = {.lex_state = 10},
  [17933] = {.lex_state = 10},
  [17934] = {.lex_state = 0},
  [17935] = {.lex_state = 0},
  [17936] = {.lex_state = 0},
  [17937] = {.lex_state = 17},
  [17938] = {.lex_state = 0},
  [17939] = {.lex_state = 0},
  [17940] = {.lex_state = 17},
  [17941] = {.lex_state = 0},
  [17942] = {.lex_state = 0},
  [17943] = {.lex_state = 17},
  [17944] = {.lex_state = 0},
  [17945] = {.lex_state = 0},
  [17946] = {.lex_state = 17},
  [17947] = {.lex_state = 0},
  [17948] = {.lex_state = 0},
  [17949] = {.lex_state = 17},
  [17950] = {.lex_state = 0},
  [17951] = {.lex_state = 0},
  [17952] = {.lex_state = 17},
  [17953] = {.lex_state = 0},
  [17954] = {.lex_state = 0},
  [17955] = {.lex_state = 17},
  [17956] = {.lex_state = 117},
  [17957] = {.lex_state = 0},
  [17958] = {.lex_state = 17},
  [17959] = {.lex_state = 0},
  [17960] = {.lex_state = 0},
  [17961] = {.lex_state = 0},
  [17962] = {.lex_state = 0},
  [17963] = {.lex_state = 0},
  [17964] = {.lex_state = 0},
  [17965] = {.lex_state = 0},
  [17966] = {.lex_state = 0},
  [17967] = {.lex_state = 0},
  [17968] = {.lex_state = 0},
  [17969] = {.lex_state = 0},
  [17970] = {.lex_state = 0},
  [17971] = {.lex_state = 0},
  [17972] = {.lex_state = 0},
  [17973] = {.lex_state = 0},
  [17974] = {.lex_state = 10},
  [17975] = {.lex_state = 117},
  [17976] = {.lex_state = 10},
  [17977] = {.lex_state = 117},
  [17978] = {.lex_state = 0},
  [17979] = {.lex_state = 0},
  [17980] = {.lex_state = 117},
  [17981] = {.lex_state = 117},
  [17982] = {.lex_state = 117},
  [17983] = {.lex_state = 117},
  [17984] = {.lex_state = 117},
  [17985] = {.lex_state = 117},
  [17986] = {.lex_state = 117},
  [17987] = {.lex_state = 117},
  [17988] = {.lex_state = 117},
  [17989] = {.lex_state = 0},
  [17990] = {.lex_state = 0},
  [17991] = {.lex_state = 117},
  [17992] = {.lex_state = 0},
  [17993] = {.lex_state = 0},
  [17994] = {.lex_state = 0},
  [17995] = {.lex_state = 117},
  [17996] = {.lex_state = 117},
  [17997] = {.lex_state = 0},
  [17998] = {.lex_state = 0},
  [17999] = {.lex_state = 0},
  [18000] = {.lex_state = 117},
  [18001] = {.lex_state = 117},
  [18002] = {.lex_state = 117},
  [18003] = {.lex_state = 117},
  [18004] = {.lex_state = 117},
  [18005] = {.lex_state = 117},
  [18006] = {.lex_state = 117},
  [18007] = {.lex_state = 0},
  [18008] = {.lex_state = 117},
  [18009] = {.lex_state = 0},
  [18010] = {.lex_state = 0},
  [18011] = {.lex_state = 117},
  [18012] = {.lex_state = 0},
  [18013] = {.lex_state = 10},
  [18014] = {.lex_state = 117},
  [18015] = {.lex_state = 0},
  [18016] = {.lex_state = 117},
  [18017] = {.lex_state = 117},
  [18018] = {.lex_state = 117},
  [18019] = {.lex_state = 117},
  [18020] = {.lex_state = 117},
  [18021] = {.lex_state = 0},
  [18022] = {.lex_state = 10},
  [18023] = {.lex_state = 0},
  [18024] = {.lex_state = 0},
  [18025] = {.lex_state = 0},
  [18026] = {.lex_state = 0},
  [18027] = {.lex_state = 117},
  [18028] = {.lex_state = 0},
  [18029] = {.lex_state = 0},
  [18030] = {.lex_state = 0},
  [18031] = {.lex_state = 0},
  [18032] = {.lex_state = 0},
  [18033] = {.lex_state = 0},
  [18034] = {.lex_state = 0},
  [18035] = {.lex_state = 0},
  [18036] = {.lex_state = 0},
  [18037] = {.lex_state = 0},
  [18038] = {.lex_state = 0},
  [18039] = {.lex_state = 0},
  [18040] = {.lex_state = 0},
  [18041] = {.lex_state = 0},
  [18042] = {.lex_state = 117},
  [18043] = {.lex_state = 0},
  [18044] = {.lex_state = 0},
  [18045] = {.lex_state = 0},
  [18046] = {.lex_state = 0},
  [18047] = {.lex_state = 117},
  [18048] = {.lex_state = 0},
  [18049] = {.lex_state = 0},
  [18050] = {.lex_state = 0},
  [18051] = {.lex_state = 0},
  [18052] = {.lex_state = 117},
  [18053] = {.lex_state = 10},
  [18054] = {.lex_state = 0},
  [18055] = {.lex_state = 0},
  [18056] = {.lex_state = 10},
  [18057] = {.lex_state = 0},
  [18058] = {.lex_state = 0},
  [18059] = {.lex_state = 0},
  [18060] = {.lex_state = 0},
  [18061] = {.lex_state = 0},
  [18062] = {.lex_state = 10},
  [18063] = {.lex_state = 0},
  [18064] = {.lex_state = 0},
  [18065] = {.lex_state = 10},
  [18066] = {.lex_state = 10},
  [18067] = {.lex_state = 0},
  [18068] = {.lex_state = 117},
  [18069] = {.lex_state = 117},
  [18070] = {.lex_state = 117},
  [18071] = {.lex_state = 10},
  [18072] = {.lex_state = 117},
  [18073] = {.lex_state = 10},
  [18074] = {.lex_state = 117},
  [18075] = {.lex_state = 0},
  [18076] = {.lex_state = 0},
  [18077] = {.lex_state = 0},
  [18078] = {.lex_state = 0},
  [18079] = {.lex_state = 0},
  [18080] = {.lex_state = 0},
  [18081] = {.lex_state = 117},
  [18082] = {.lex_state = 117},
  [18083] = {.lex_state = 17},
  [18084] = {.lex_state = 0},
  [18085] = {.lex_state = 0},
  [18086] = {.lex_state = 117},
  [18087] = {.lex_state = 0},
  [18088] = {.lex_state = 117},
  [18089] = {.lex_state = 117},
  [18090] = {.lex_state = 117},
  [18091] = {.lex_state = 0},
  [18092] = {.lex_state = 117},
  [18093] = {.lex_state = 117},
  [18094] = {.lex_state = 0},
  [18095] = {.lex_state = 117},
  [18096] = {.lex_state = 17},
  [18097] = {.lex_state = 117},
  [18098] = {.lex_state = 0},
  [18099] = {.lex_state = 0},
  [18100] = {.lex_state = 0},
  [18101] = {.lex_state = 117},
  [18102] = {.lex_state = 117},
  [18103] = {.lex_state = 0},
  [18104] = {.lex_state = 117},
  [18105] = {.lex_state = 117},
  [18106] = {.lex_state = 0},
  [18107] = {.lex_state = 117},
  [18108] = {.lex_state = 0},
  [18109] = {.lex_state = 117},
  [18110] = {.lex_state = 117},
  [18111] = {.lex_state = 0},
  [18112] = {.lex_state = 117},
  [18113] = {.lex_state = 117},
  [18114] = {.lex_state = 0},
  [18115] = {.lex_state = 117},
  [18116] = {.lex_state = 0},
  [18117] = {.lex_state = 117},
  [18118] = {.lex_state = 0},
  [18119] = {.lex_state = 117},
  [18120] = {.lex_state = 117},
  [18121] = {.lex_state = 10},
  [18122] = {.lex_state = 0},
  [18123] = {.lex_state = 0},
  [18124] = {.lex_state = 0},
  [18125] = {.lex_state = 117},
  [18126] = {.lex_state = 0},
  [18127] = {.lex_state = 117},
  [18128] = {.lex_state = 117},
  [18129] = {.lex_state = 117},
  [18130] = {.lex_state = 0},
  [18131] = {.lex_state = 117},
  [18132] = {.lex_state = 0},
  [18133] = {.lex_state = 0},
  [18134] = {.lex_state = 0},
  [18135] = {.lex_state = 0},
  [18136] = {.lex_state = 0},
  [18137] = {.lex_state = 0},
  [18138] = {.lex_state = 10},
  [18139] = {.lex_state = 117},
  [18140] = {.lex_state = 117},
  [18141] = {.lex_state = 0},
  [18142] = {.lex_state = 117},
  [18143] = {.lex_state = 117},
  [18144] = {.lex_state = 0},
  [18145] = {.lex_state = 117},
  [18146] = {.lex_state = 0},
  [18147] = {.lex_state = 0},
  [18148] = {.lex_state = 0},
  [18149] = {.lex_state = 0},
  [18150] = {.lex_state = 0},
  [18151] = {.lex_state = 0},
  [18152] = {.lex_state = 0},
  [18153] = {.lex_state = 0},
  [18154] = {.lex_state = 0},
  [18155] = {.lex_state = 10},
  [18156] = {.lex_state = 0},
  [18157] = {.lex_state = 0},
  [18158] = {.lex_state = 0},
  [18159] = {.lex_state = 0},
  [18160] = {.lex_state = 0},
  [18161] = {.lex_state = 117},
  [18162] = {.lex_state = 117},
  [18163] = {.lex_state = 0},
  [18164] = {.lex_state = 0},
  [18165] = {.lex_state = 0},
  [18166] = {.lex_state = 117},
  [18167] = {.lex_state = 0},
  [18168] = {.lex_state = 117},
  [18169] = {.lex_state = 0},
  [18170] = {.lex_state = 117},
  [18171] = {.lex_state = 0},
  [18172] = {.lex_state = 117},
  [18173] = {.lex_state = 117},
  [18174] = {.lex_state = 117},
  [18175] = {.lex_state = 10},
  [18176] = {.lex_state = 0},
  [18177] = {.lex_state = 0},
  [18178] = {.lex_state = 0},
  [18179] = {.lex_state = 0},
  [18180] = {.lex_state = 0},
  [18181] = {.lex_state = 0},
  [18182] = {.lex_state = 0},
  [18183] = {.lex_state = 0},
  [18184] = {.lex_state = 117},
  [18185] = {.lex_state = 117},
  [18186] = {.lex_state = 16},
  [18187] = {.lex_state = 117},
  [18188] = {.lex_state = 0},
  [18189] = {.lex_state = 0},
  [18190] = {.lex_state = 117},
  [18191] = {.lex_state = 0},
  [18192] = {.lex_state = 0},
  [18193] = {.lex_state = 0},
  [18194] = {.lex_state = 117},
  [18195] = {.lex_state = 117},
  [18196] = {.lex_state = 0},
  [18197] = {.lex_state = 117},
  [18198] = {.lex_state = 17},
  [18199] = {.lex_state = 0},
  [18200] = {.lex_state = 117},
  [18201] = {.lex_state = 0},
  [18202] = {.lex_state = 0},
  [18203] = {.lex_state = 117},
  [18204] = {.lex_state = 10},
  [18205] = {.lex_state = 117},
  [18206] = {.lex_state = 0},
  [18207] = {.lex_state = 0},
  [18208] = {.lex_state = 117},
  [18209] = {.lex_state = 117},
  [18210] = {.lex_state = 117},
  [18211] = {.lex_state = 0},
  [18212] = {.lex_state = 117},
  [18213] = {.lex_state = 117},
  [18214] = {.lex_state = 10},
  [18215] = {.lex_state = 0},
  [18216] = {.lex_state = 0},
  [18217] = {.lex_state = 10},
  [18218] = {.lex_state = 0},
  [18219] = {.lex_state = 0},
  [18220] = {.lex_state = 117},
  [18221] = {.lex_state = 117},
  [18222] = {.lex_state = 17},
  [18223] = {.lex_state = 117},
  [18224] = {.lex_state = 0},
  [18225] = {.lex_state = 0},
  [18226] = {.lex_state = 10},
  [18227] = {.lex_state = 0},
  [18228] = {.lex_state = 0},
  [18229] = {.lex_state = 0},
  [18230] = {.lex_state = 10},
  [18231] = {.lex_state = 0},
  [18232] = {.lex_state = 0},
  [18233] = {.lex_state = 0},
  [18234] = {.lex_state = 0},
  [18235] = {.lex_state = 0},
  [18236] = {.lex_state = 0},
  [18237] = {.lex_state = 0},
  [18238] = {.lex_state = 0},
  [18239] = {.lex_state = 0},
  [18240] = {.lex_state = 0},
  [18241] = {.lex_state = 0},
  [18242] = {.lex_state = 0},
  [18243] = {.lex_state = 0},
  [18244] = {.lex_state = 0},
  [18245] = {.lex_state = 0},
  [18246] = {.lex_state = 0},
  [18247] = {.lex_state = 0},
  [18248] = {.lex_state = 0},
  [18249] = {.lex_state = 0},
  [18250] = {.lex_state = 0},
  [18251] = {.lex_state = 0},
  [18252] = {.lex_state = 0},
  [18253] = {.lex_state = 0},
  [18254] = {.lex_state = 0},
  [18255] = {.lex_state = 0},
  [18256] = {.lex_state = 0},
  [18257] = {.lex_state = 0},
  [18258] = {.lex_state = 0},
  [18259] = {.lex_state = 117},
  [18260] = {.lex_state = 0},
  [18261] = {.lex_state = 0},
  [18262] = {.lex_state = 0},
  [18263] = {.lex_state = 0},
  [18264] = {.lex_state = 0},
  [18265] = {.lex_state = 17},
  [18266] = {.lex_state = 0},
  [18267] = {.lex_state = 0},
  [18268] = {.lex_state = 0},
  [18269] = {.lex_state = 0},
  [18270] = {.lex_state = 0},
  [18271] = {.lex_state = 0},
  [18272] = {.lex_state = 0},
  [18273] = {.lex_state = 0},
  [18274] = {.lex_state = 117},
  [18275] = {.lex_state = 117},
  [18276] = {.lex_state = 0},
  [18277] = {.lex_state = 0},
  [18278] = {.lex_state = 0},
  [18279] = {.lex_state = 0},
  [18280] = {.lex_state = 0},
  [18281] = {.lex_state = 0},
  [18282] = {.lex_state = 0},
  [18283] = {.lex_state = 0},
  [18284] = {.lex_state = 117},
  [18285] = {.lex_state = 0},
  [18286] = {.lex_state = 0},
  [18287] = {.lex_state = 0},
  [18288] = {.lex_state = 117},
  [18289] = {.lex_state = 117},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [aux_sym_interface_declaration_token1] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [aux_sym_interface_declaration_token2] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [aux_sym_boolean_token1] = ACTIONS(1),
    [aux_sym_boolean_token2] = ACTIONS(1),
    [sym_decimal] = ACTIONS(1),
    [aux_sym_ml_value_list_token1] = ACTIONS(1),
    [aux_sym_lookup_formula_token1] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [aux_sym_where_clause_token1] = ACTIONS(1),
    [aux_sym_where_condition_token1] = ACTIONS(1),
    [aux_sym_where_condition_token2] = ACTIONS(1),
    [aux_sym_where_condition_token3] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [aux_sym_filter_value_token1] = ACTIONS(1),
    [aux_sym_sorting_value_token1] = ACTIONS(1),
    [aux_sym_sorting_value_token2] = ACTIONS(1),
    [aux_sym_sorting_value_token3] = ACTIONS(1),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(1),
    [aux_sym_tabledata_permission_token1] = ACTIONS(1),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [sym_permission_type] = ACTIONS(1),
    [aux_sym_order_by_item_token1] = ACTIONS(1),
    [aux_sym_order_by_item_token2] = ACTIONS(1),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(1),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(1),
    [aux_sym_text_type_token1] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [aux_sym_code_type_token1] = ACTIONS(1),
    [aux_sym_option_type_token1] = ACTIONS(1),
    [aux_sym_record_type_token1] = ACTIONS(1),
    [aux_sym_object_reference_type_token1] = ACTIONS(1),
    [aux_sym_object_reference_type_token2] = ACTIONS(1),
    [aux_sym_array_type_token1] = ACTIONS(1),
    [aux_sym_array_type_token2] = ACTIONS(1),
    [aux_sym_list_type_token1] = ACTIONS(1),
    [aux_sym_dictionary_type_token1] = ACTIONS(1),
    [aux_sym_basic_type_token1] = ACTIONS(1),
    [aux_sym_basic_type_token2] = ACTIONS(1),
    [aux_sym_basic_type_token3] = ACTIONS(1),
    [aux_sym_basic_type_token4] = ACTIONS(1),
    [aux_sym_basic_type_token5] = ACTIONS(1),
    [aux_sym_basic_type_token6] = ACTIONS(1),
    [aux_sym_basic_type_token7] = ACTIONS(1),
    [aux_sym_basic_type_token8] = ACTIONS(1),
    [aux_sym_basic_type_token9] = ACTIONS(1),
    [aux_sym_basic_type_token10] = ACTIONS(1),
    [aux_sym_basic_type_token11] = ACTIONS(1),
    [aux_sym_basic_type_token12] = ACTIONS(1),
    [aux_sym_basic_type_token13] = ACTIONS(1),
    [aux_sym_basic_type_token14] = ACTIONS(1),
    [aux_sym_basic_type_token15] = ACTIONS(1),
    [aux_sym_basic_type_token16] = ACTIONS(1),
    [aux_sym_basic_type_token17] = ACTIONS(1),
    [aux_sym_basic_type_token18] = ACTIONS(1),
    [aux_sym_basic_type_token19] = ACTIONS(1),
    [aux_sym_basic_type_token20] = ACTIONS(1),
    [aux_sym_basic_type_token21] = ACTIONS(1),
    [aux_sym_basic_type_token22] = ACTIONS(1),
    [aux_sym_basic_type_token23] = ACTIONS(1),
    [aux_sym_basic_type_token24] = ACTIONS(1),
    [aux_sym_basic_type_token25] = ACTIONS(1),
    [aux_sym_basic_type_token26] = ACTIONS(1),
    [aux_sym_basic_type_token27] = ACTIONS(1),
    [aux_sym_basic_type_token28] = ACTIONS(1),
    [aux_sym_basic_type_token29] = ACTIONS(1),
    [aux_sym_basic_type_token30] = ACTIONS(1),
    [aux_sym_basic_type_token31] = ACTIONS(1),
    [aux_sym_basic_type_token32] = ACTIONS(1),
    [aux_sym_basic_type_token33] = ACTIONS(1),
    [aux_sym_basic_type_token34] = ACTIONS(1),
    [aux_sym_basic_type_token35] = ACTIONS(1),
    [aux_sym_basic_type_token36] = ACTIONS(1),
    [aux_sym_basic_type_token37] = ACTIONS(1),
    [aux_sym_basic_type_token38] = ACTIONS(1),
    [aux_sym_basic_type_token39] = ACTIONS(1),
    [aux_sym_basic_type_token40] = ACTIONS(1),
    [aux_sym_basic_type_token41] = ACTIONS(1),
    [aux_sym_basic_type_token42] = ACTIONS(1),
    [aux_sym_basic_type_token43] = ACTIONS(1),
    [aux_sym_basic_type_token44] = ACTIONS(1),
    [aux_sym_basic_type_token45] = ACTIONS(1),
    [aux_sym_basic_type_token46] = ACTIONS(1),
    [aux_sym_basic_type_token47] = ACTIONS(1),
    [aux_sym_basic_type_token48] = ACTIONS(1),
    [aux_sym_basic_type_token49] = ACTIONS(1),
    [aux_sym_basic_type_token50] = ACTIONS(1),
    [aux_sym_basic_type_token51] = ACTIONS(1),
    [aux_sym_basic_type_token52] = ACTIONS(1),
    [aux_sym_basic_type_token53] = ACTIONS(1),
    [aux_sym_basic_type_token54] = ACTIONS(1),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(1),
    [aux_sym_label_declaration_token1] = ACTIONS(1),
    [aux_sym_label_declaration_token2] = ACTIONS(1),
    [aux_sym_area_section_token1] = ACTIONS(1),
    [aux_sym_area_section_token2] = ACTIONS(1),
    [aux_sym_area_section_token3] = ACTIONS(1),
    [aux_sym_area_section_token4] = ACTIONS(1),
    [aux_sym_area_section_token5] = ACTIONS(1),
    [aux_sym_area_section_token6] = ACTIONS(1),
    [aux_sym_area_section_token7] = ACTIONS(1),
    [aux_sym_area_section_token8] = ACTIONS(1),
    [aux_sym_addafter_modification_token1] = ACTIONS(1),
    [aux_sym_addbefore_modification_token1] = ACTIONS(1),
    [aux_sym_modify_modification_token1] = ACTIONS(1),
    [aux_sym_movefirst_modification_token1] = ACTIONS(1),
    [aux_sym_movelast_modification_token1] = ACTIONS(1),
    [aux_sym_moveafter_modification_token1] = ACTIONS(1),
    [aux_sym_movebefore_modification_token1] = ACTIONS(1),
    [aux_sym_action_area_section_token1] = ACTIONS(1),
    [aux_sym_action_area_section_token2] = ACTIONS(1),
    [aux_sym_action_area_section_token3] = ACTIONS(1),
    [aux_sym_action_area_section_token4] = ACTIONS(1),
    [aux_sym_action_area_section_token5] = ACTIONS(1),
    [aux_sym_action_area_section_token6] = ACTIONS(1),
    [aux_sym_action_area_section_token7] = ACTIONS(1),
    [aux_sym_separator_action_token1] = ACTIONS(1),
    [aux_sym_actionref_declaration_token1] = ACTIONS(1),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(1),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(1),
    [aux_sym_customaction_declaration_token1] = ACTIONS(1),
    [aux_sym_add_dataset_modification_token1] = ACTIONS(1),
    [aux_sym_xmlport_element_token1] = ACTIONS(1),
    [aux_sym_xmlport_element_token2] = ACTIONS(1),
    [aux_sym_xmlport_element_token3] = ACTIONS(1),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(1),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(1),
    [aux_sym_assembly_declaration_token1] = ACTIONS(1),
    [aux_sym_type_declaration_token1] = ACTIONS(1),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_POUNDif] = ACTIONS(1),
    [anon_sym_POUNDIF] = ACTIONS(1),
    [anon_sym_POUNDIf] = ACTIONS(1),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_NOT] = ACTIONS(1),
    [anon_sym_Not] = ACTIONS(1),
    [anon_sym_POUNDelif] = ACTIONS(1),
    [anon_sym_POUNDELIF] = ACTIONS(1),
    [anon_sym_POUNDElif] = ACTIONS(1),
    [anon_sym_POUNDelse] = ACTIONS(1),
    [anon_sym_POUNDELSE] = ACTIONS(1),
    [anon_sym_POUNDElse] = ACTIONS(1),
    [anon_sym_POUNDelse2] = ACTIONS(1),
    [anon_sym_POUNDELSE2] = ACTIONS(1),
    [anon_sym_POUNDElse2] = ACTIONS(1),
    [anon_sym_POUNDendif] = ACTIONS(1),
    [anon_sym_POUNDENDIF] = ACTIONS(1),
    [anon_sym_POUNDEndif] = ACTIONS(1),
    [anon_sym_POUNDendif2] = ACTIONS(1),
    [anon_sym_POUNDENDIF2] = ACTIONS(1),
    [anon_sym_POUNDEndif2] = ACTIONS(1),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [aux_sym__expression_token1] = ACTIONS(1),
    [aux_sym__expression_token2] = ACTIONS(1),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_div] = ACTIONS(1),
    [anon_sym_DIV] = ACTIONS(1),
    [anon_sym_Div] = ACTIONS(1),
    [anon_sym_mod] = ACTIONS(1),
    [anon_sym_MOD] = ACTIONS(1),
    [anon_sym_Mod] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_GT] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_AND] = ACTIONS(1),
    [anon_sym_And] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_OR] = ACTIONS(1),
    [anon_sym_Or] = ACTIONS(1),
    [anon_sym_xor] = ACTIONS(1),
    [anon_sym_XOR] = ACTIONS(1),
    [anon_sym_Xor] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [sym_datetime_literal] = ACTIONS(1),
    [sym_date_literal] = ACTIONS(1),
    [sym_time_literal] = ACTIONS(1),
    [sym_biginteger_literal] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_IF] = ACTIONS(1),
    [anon_sym_If] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_THEN] = ACTIONS(1),
    [anon_sym_Then] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_ELSE] = ACTIONS(1),
    [anon_sym_Else] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_CASE] = ACTIONS(1),
    [anon_sym_Case] = ACTIONS(1),
    [anon_sym_of] = ACTIONS(1),
    [anon_sym_OF] = ACTIONS(1),
    [anon_sym_Of] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_FOR] = ACTIONS(1),
    [anon_sym_For] = ACTIONS(1),
    [anon_sym_foreach] = ACTIONS(1),
    [anon_sym_FOREACH] = ACTIONS(1),
    [anon_sym_Foreach] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_WHILE] = ACTIONS(1),
    [anon_sym_While] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_DO] = ACTIONS(1),
    [anon_sym_Do] = ACTIONS(1),
    [anon_sym_repeat] = ACTIONS(1),
    [anon_sym_REPEAT] = ACTIONS(1),
    [anon_sym_Repeat] = ACTIONS(1),
    [anon_sym_until] = ACTIONS(1),
    [anon_sym_UNTIL] = ACTIONS(1),
    [anon_sym_Until] = ACTIONS(1),
    [anon_sym_exit] = ACTIONS(1),
    [anon_sym_EXIT] = ACTIONS(1),
    [anon_sym_Exit] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_CONTINUE] = ACTIONS(1),
    [anon_sym_Continue] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_BREAK] = ACTIONS(1),
    [anon_sym_Break] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_WITH] = ACTIONS(1),
    [anon_sym_With] = ACTIONS(1),
    [sym_asserterror_keyword] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_IN] = ACTIONS(1),
    [anon_sym_In] = ACTIONS(1),
    [anon_sym_to] = ACTIONS(1),
    [anon_sym_TO] = ACTIONS(1),
    [anon_sym_To] = ACTIONS(1),
    [anon_sym_downto] = ACTIONS(1),
    [anon_sym_DOWNTO] = ACTIONS(1),
    [anon_sym_Downto] = ACTIONS(1),
    [sym_table_keyword] = ACTIONS(1),
    [anon_sym_tableextension] = ACTIONS(1),
    [anon_sym_TABLEEXTENSION] = ACTIONS(1),
    [anon_sym_Tableextension] = ACTIONS(1),
    [anon_sym_TableExtension] = ACTIONS(1),
    [anon_sym_tableExtension] = ACTIONS(1),
    [sym_page_keyword] = ACTIONS(1),
    [anon_sym_pageextension] = ACTIONS(1),
    [anon_sym_PAGEEXTENSION] = ACTIONS(1),
    [anon_sym_Pageextension] = ACTIONS(1),
    [anon_sym_PageExtension] = ACTIONS(1),
    [anon_sym_pageExtension] = ACTIONS(1),
    [anon_sym_codeunit] = ACTIONS(1),
    [anon_sym_CODEUNIT] = ACTIONS(1),
    [anon_sym_Codeunit] = ACTIONS(1),
    [anon_sym_CodeUnit] = ACTIONS(1),
    [anon_sym_COdeunit] = ACTIONS(1),
    [anon_sym_codeUnit] = ACTIONS(1),
    [sym_report_keyword] = ACTIONS(1),
    [anon_sym_reportextension] = ACTIONS(1),
    [anon_sym_REPORTEXTENSION] = ACTIONS(1),
    [anon_sym_Reportextension] = ACTIONS(1),
    [anon_sym_ReportExtension] = ACTIONS(1),
    [anon_sym_reportExtension] = ACTIONS(1),
    [sym_query_keyword] = ACTIONS(1),
    [anon_sym_xmlport] = ACTIONS(1),
    [anon_sym_XMLPORT] = ACTIONS(1),
    [anon_sym_Xmlport] = ACTIONS(1),
    [anon_sym_XMLport] = ACTIONS(1),
    [anon_sym_XMLPort] = ACTIONS(1),
    [anon_sym_XmlPort] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_ENUM] = ACTIONS(1),
    [anon_sym_Enum] = ACTIONS(1),
    [anon_sym_eNUM] = ACTIONS(1),
    [anon_sym_eNum] = ACTIONS(1),
    [anon_sym_ENum] = ACTIONS(1),
    [anon_sym_enumextension] = ACTIONS(1),
    [anon_sym_ENUMEXTENSION] = ACTIONS(1),
    [anon_sym_Enumextension] = ACTIONS(1),
    [anon_sym_EnumExtension] = ACTIONS(1),
    [anon_sym_enumExtension] = ACTIONS(1),
    [sym_interface_keyword] = ACTIONS(1),
    [anon_sym_controladdin] = ACTIONS(1),
    [anon_sym_CONTROLADDIN] = ACTIONS(1),
    [anon_sym_Controladdin] = ACTIONS(1),
    [anon_sym_ControlAddIn] = ACTIONS(1),
    [anon_sym_ControlAddin] = ACTIONS(1),
    [anon_sym_controlAddIn] = ACTIONS(1),
    [anon_sym_controlAddin] = ACTIONS(1),
    [anon_sym_dotnet] = ACTIONS(1),
    [anon_sym_DOTNET] = ACTIONS(1),
    [anon_sym_Dotnet] = ACTIONS(1),
    [anon_sym_DotNet] = ACTIONS(1),
    [anon_sym_dotNet] = ACTIONS(1),
    [sym_profile_keyword] = ACTIONS(1),
    [anon_sym_profileextension] = ACTIONS(1),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(1),
    [anon_sym_Profileextension] = ACTIONS(1),
    [anon_sym_ProfileExtension] = ACTIONS(1),
    [anon_sym_profileExtension] = ACTIONS(1),
    [anon_sym_permissionset] = ACTIONS(1),
    [anon_sym_PERMISSIONSET] = ACTIONS(1),
    [anon_sym_Permissionset] = ACTIONS(1),
    [anon_sym_PermissionSet] = ACTIONS(1),
    [anon_sym_permissionSet] = ACTIONS(1),
    [anon_sym_permissionsetextension] = ACTIONS(1),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(1),
    [anon_sym_Permissionsetextension] = ACTIONS(1),
    [anon_sym_PermissionSetExtension] = ACTIONS(1),
    [anon_sym_permissionSetExtension] = ACTIONS(1),
    [sym_entitlement_keyword] = ACTIONS(1),
    [anon_sym_pagecustomization] = ACTIONS(1),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(1),
    [anon_sym_Pagecustomization] = ACTIONS(1),
    [anon_sym_PageCustomization] = ACTIONS(1),
    [anon_sym_pageCustomization] = ACTIONS(1),
    [sym_namespace_keyword] = ACTIONS(1),
    [sym_using_keyword] = ACTIONS(1),
    [sym_implements_keyword] = ACTIONS(1),
    [sym_extends_keyword] = ACTIONS(1),
    [sym_customizes_keyword] = ACTIONS(1),
    [sym_procedure_keyword] = ACTIONS(1),
    [sym_trigger_keyword] = ACTIONS(1),
    [sym_var_keyword] = ACTIONS(1),
    [sym_local_keyword] = ACTIONS(1),
    [sym_internal_keyword] = ACTIONS(1),
    [sym_protected_keyword] = ACTIONS(1),
    [sym_event_keyword] = ACTIONS(1),
    [sym_temporary_keyword] = ACTIONS(1),
    [sym_fields_keyword] = ACTIONS(1),
    [sym_keys_keyword] = ACTIONS(1),
    [sym_key_keyword] = ACTIONS(1),
    [sym_fieldgroups_keyword] = ACTIONS(1),
    [sym_fieldgroup_keyword] = ACTIONS(1),
    [sym_actions_keyword] = ACTIONS(1),
    [sym_layout_keyword] = ACTIONS(1),
    [sym_area_keyword] = ACTIONS(1),
    [sym_group_keyword] = ACTIONS(1),
    [sym_repeater_keyword] = ACTIONS(1),
    [sym_cuegroup_keyword] = ACTIONS(1),
    [sym_fixed_keyword] = ACTIONS(1),
    [sym_grid_keyword] = ACTIONS(1),
    [sym_part_keyword] = ACTIONS(1),
    [sym_systempart_keyword] = ACTIONS(1),
    [sym_usercontrol_keyword] = ACTIONS(1),
    [sym_dataset_keyword] = ACTIONS(1),
    [sym_elements_keyword] = ACTIONS(1),
    [sym_dataitem_keyword] = ACTIONS(1),
    [sym_column_keyword] = ACTIONS(1),
    [sym_filter_keyword] = ACTIONS(1),
    [sym_labels_keyword] = ACTIONS(1),
    [sym_rendering_keyword] = ACTIONS(1),
    [sym_requestpage_keyword] = ACTIONS(1),
    [sym_schema_keyword] = ACTIONS(1),
    [sym_views_keyword] = ACTIONS(1),
    [sym_view_keyword] = ACTIONS(1),
    [sym_quoted_identifier] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1),
    [sym_verbatim_string] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
    [sym_property_name] = ACTIONS(1),
    [sym_continue_as_identifier] = ACTIONS(1),
    [sym_preproc_open] = ACTIONS(1),
    [sym_preproc_close] = ACTIONS(1),
    [sym_begin_keyword] = ACTIONS(1),
    [sym_end_keyword] = ACTIONS(1),
    [sym_preproc_split_begin] = ACTIONS(1),
    [sym_preproc_split_end] = ACTIONS(1),
    [sym_var_attribute_open] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(17449),
    [sym_preproc_conditional_object] = STATE(2090),
    [sym_namespace_declaration] = STATE(2087),
    [sym_using_statement] = STATE(2090),
    [sym__object] = STATE(2090),
    [sym_preproc_split_declaration] = STATE(2090),
    [sym_table_declaration] = STATE(2090),
    [sym_page_declaration] = STATE(2090),
    [sym_report_declaration] = STATE(2090),
    [sym_query_declaration] = STATE(2090),
    [sym_xmlport_declaration] = STATE(2090),
    [sym_permissionset_declaration] = STATE(2090),
    [sym_codeunit_declaration] = STATE(2090),
    [sym_enum_declaration] = STATE(2090),
    [sym_tableextension_declaration] = STATE(2090),
    [sym_pageextension_declaration] = STATE(2090),
    [sym_reportextension_declaration] = STATE(2090),
    [sym_enumextension_declaration] = STATE(2090),
    [sym_permissionsetextension_declaration] = STATE(2090),
    [sym_controladdin_declaration] = STATE(2090),
    [sym_profile_declaration] = STATE(2090),
    [sym_entitlement_declaration] = STATE(2090),
    [sym_profileextension_declaration] = STATE(2090),
    [sym_interface_declaration] = STATE(2090),
    [sym_pagecustomization_declaration] = STATE(2090),
    [sym_dotnet_declaration] = STATE(2090),
    [sym_preproc_if] = STATE(307),
    [sym_tableextension_keyword] = STATE(17066),
    [sym_pageextension_keyword] = STATE(17469),
    [sym_codeunit_keyword] = STATE(17512),
    [sym_reportextension_keyword] = STATE(17404),
    [sym_xmlport_keyword] = STATE(17405),
    [sym_enum_keyword] = STATE(17453),
    [sym_enumextension_keyword] = STATE(17340),
    [sym_controladdin_keyword] = STATE(12142),
    [sym_dotnet_keyword] = STATE(17810),
    [sym_profileextension_keyword] = STATE(12155),
    [sym_permissionset_keyword] = STATE(17872),
    [sym_permissionsetextension_keyword] = STATE(18217),
    [sym_pagecustomization_keyword] = STATE(12241),
    [aux_sym_source_file_repeat1] = STATE(2090),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(13),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(19),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(23),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(33),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(39),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(47),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(51),
    [sym_using_keyword] = ACTIONS(53),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
  },
  [STATE(2)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(71),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(119),
  },
  [STATE(4)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(145),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(121),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(5)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(146),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(123),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(6)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(132),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(125),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(7)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(127),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(8)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(135),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(129),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(9)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(131),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(10)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(133),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(11)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(135),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(12)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(137),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(13)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(139),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(14)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(141),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(15)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(143),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(16)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(145),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(17)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(147),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(18)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(149),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(19)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(151),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(20)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(153),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(21)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(155),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(22)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(157),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(23)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(159),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(24)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(161),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(25)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(163),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(26)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(133),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(165),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(27)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(134),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(167),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(28)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(136),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(169),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(29)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(171),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(30)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(137),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(173),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(31)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(175),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(32)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(177),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(33)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(179),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(34)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(181),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(35)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(183),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(36)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(185),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(37)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(187),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(38)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(189),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(39)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(191),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(40)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(193),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(41)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(195),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(42)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(197),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(43)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(199),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(44)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(201),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(45)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(203),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(46)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(205),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(47)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(207),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(48)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(138),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(209),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(49)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(139),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(211),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(50)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(131),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(213),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(51)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(215),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(52)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(140),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(217),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(53)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(219),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(54)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(221),
  },
  [STATE(55)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(223),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(56)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(225),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(57)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(227),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(58)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(229),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(59)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(231),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(60)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(233),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(61)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(235),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(62)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(237),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(63)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(239),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(64)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(241),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(65)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(243),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(66)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(245),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(67)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(247),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(68)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(249),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(69)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(141),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(251),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(70)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(142),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(253),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(71)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(143),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(255),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(72)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(257),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(73)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(144),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(259),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(74)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(261),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(75)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(263),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(76)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(265),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(77)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(267),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(78)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(269),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(79)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(271),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(80)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(273),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(81)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(275),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(82)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(277),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(83)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(279),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(84)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(281),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(85)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(283),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(86)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(285),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(87)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(287),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(88)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(289),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(89)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(291),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(90)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(293),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(91)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(295),
  },
  [STATE(92)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(297),
  },
  [STATE(93)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(299),
  },
  [STATE(94)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(301),
  },
  [STATE(95)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(303),
  },
  [STATE(96)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(305),
  },
  [STATE(97)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(307),
  },
  [STATE(98)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(309),
  },
  [STATE(99)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(311),
  },
  [STATE(100)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(313),
  },
  [STATE(101)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(315),
  },
  [STATE(102)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(317),
  },
  [STATE(103)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(319),
  },
  [STATE(104)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(321),
  },
  [STATE(105)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(323),
  },
  [STATE(106)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(325),
  },
  [STATE(107)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(327),
  },
  [STATE(108)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(329),
  },
  [STATE(109)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
    [sym_preproc_split_end] = ACTIONS(331),
  },
  [STATE(110)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(333),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(111)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2546),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15031),
    [sym_preproc_endif] = STATE(614),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(3405),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2547),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2548),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10714),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(347),
  },
  [STATE(112)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(288),
    [sym_preproc_endif] = STATE(2494),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10766),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13529),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10849),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4834),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(147),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10736),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(113)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2543),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15410),
    [sym_preproc_endif] = STATE(647),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(2587),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2544),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2545),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10826),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(351),
  },
  [STATE(114)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10996),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14563),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4828),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(115)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(262),
    [sym_preproc_endif] = STATE(3096),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10690),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14164),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10862),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4822),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(148),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10697),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(116)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2546),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15411),
    [sym_preproc_endif] = STATE(648),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(2588),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2547),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2548),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10827),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(351),
  },
  [STATE(117)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(287),
    [sym_preproc_endif] = STATE(3375),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10824),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13797),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10825),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4742),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(149),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10840),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(118)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2543),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15417),
    [sym_preproc_endif] = STATE(681),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(2919),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2544),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2545),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10784),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(353),
  },
  [STATE(119)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2546),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15418),
    [sym_preproc_endif] = STATE(682),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(2920),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2547),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2548),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10785),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(353),
  },
  [STATE(120)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(274),
    [sym_preproc_endif] = STATE(15247),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10878),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(14634),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10871),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4839),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(150),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10910),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(121)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2543),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15421),
    [sym_preproc_endif] = STATE(750),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(2919),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2544),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2545),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10684),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(353),
  },
  [STATE(122)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2546),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15422),
    [sym_preproc_endif] = STATE(751),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(2920),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2547),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2548),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10686),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(353),
  },
  [STATE(123)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2543),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15425),
    [sym_preproc_endif] = STATE(407),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(2587),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2544),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2545),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10837),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(351),
  },
  [STATE(124)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2546),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15426),
    [sym_preproc_endif] = STATE(408),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(2588),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2547),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2548),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10838),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(351),
  },
  [STATE(125)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2543),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15429),
    [sym_preproc_endif] = STATE(785),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(15132),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2544),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2545),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10901),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(357),
  },
  [STATE(126)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2546),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15430),
    [sym_preproc_endif] = STATE(786),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(15135),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2547),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2548),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10905),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(357),
  },
  [STATE(127)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(288),
    [sym_preproc_endif] = STATE(2494),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym__preproc_if_header] = STATE(10734),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym__preproc_guard_block] = STATE(13693),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym__preproc_call_prefix] = STATE(10849),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2724),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1868),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1868),
    [sym_subscript_expression] = STATE(1868),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1868),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4816),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(147),
    [aux_sym__preproc_guard_block_repeat1] = STATE(3962),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10736),
    [sym_identifier] = ACTIONS(55),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(128)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2543),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(15021),
    [sym_preproc_else] = STATE(15022),
    [sym_preproc_endif] = STATE(609),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_fragmented_else_tail] = STATE(3315),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2544),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2545),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_if_else_statement_repeat1] = STATE(10701),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(339),
    [anon_sym_POUNDELIF] = ACTIONS(339),
    [anon_sym_POUNDElif] = ACTIONS(339),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(347),
  },
  [STATE(129)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4365),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_elif] = STATE(3819),
    [sym_preproc_else] = STATE(3823),
    [sym_preproc_endif] = STATE(314),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4407),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4416),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [aux_sym_preproc_split_case_extended_repeat1] = STATE(10745),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [anon_sym_POUNDelif] = ACTIONS(375),
    [anon_sym_POUNDELIF] = ACTIONS(375),
    [anon_sym_POUNDElif] = ACTIONS(375),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(130)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4365),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_elif] = STATE(3819),
    [sym_preproc_else] = STATE(3812),
    [sym_preproc_endif] = STATE(383),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4407),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4416),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [aux_sym_preproc_split_case_extended_repeat1] = STATE(10730),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [anon_sym_POUNDelif] = ACTIONS(375),
    [anon_sym_POUNDELIF] = ACTIONS(375),
    [anon_sym_POUNDElif] = ACTIONS(375),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(131)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(393),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(132)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(395),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(133)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(397),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(134)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(399),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(135)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(401),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(136)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(403),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(137)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(405),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(138)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(407),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(139)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(409),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(140)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(411),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(141)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(413),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(142)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(415),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(143)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(417),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(144)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(419),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(145)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(421),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(146)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(423),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(147)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(286),
    [sym_preproc_endif] = STATE(2496),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4817),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10753),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(148)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(265),
    [sym_preproc_endif] = STATE(3101),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4823),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10977),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(149)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(282),
    [sym_preproc_endif] = STATE(3348),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4439),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10852),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(150)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elif] = STATE(162),
    [sym_preproc_else] = STATE(277),
    [sym_preproc_endif] = STATE(15113),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4829),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [aux_sym_preproc_conditional_statement_repeat1] = STATE(10780),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(151)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDelif] = ACTIONS(445),
    [anon_sym_POUNDELIF] = ACTIONS(445),
    [anon_sym_POUNDElif] = ACTIONS(445),
    [anon_sym_POUNDelse] = ACTIONS(445),
    [anon_sym_POUNDELSE] = ACTIONS(445),
    [anon_sym_POUNDElse] = ACTIONS(445),
    [anon_sym_POUNDelse2] = ACTIONS(445),
    [anon_sym_POUNDELSE2] = ACTIONS(445),
    [anon_sym_POUNDElse2] = ACTIONS(445),
    [anon_sym_POUNDendif] = ACTIONS(445),
    [anon_sym_POUNDENDIF] = ACTIONS(445),
    [anon_sym_POUNDEndif] = ACTIONS(445),
    [anon_sym_POUNDendif2] = ACTIONS(445),
    [anon_sym_POUNDENDIF2] = ACTIONS(445),
    [anon_sym_POUNDEndif2] = ACTIONS(445),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(445),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(152)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2376),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2366),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(469),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(471),
    [anon_sym_POUNDELIF] = ACTIONS(471),
    [anon_sym_POUNDElif] = ACTIONS(471),
    [anon_sym_POUNDelse] = ACTIONS(471),
    [anon_sym_POUNDELSE] = ACTIONS(471),
    [anon_sym_POUNDElse] = ACTIONS(471),
    [anon_sym_POUNDelse2] = ACTIONS(471),
    [anon_sym_POUNDELSE2] = ACTIONS(471),
    [anon_sym_POUNDElse2] = ACTIONS(471),
    [anon_sym_POUNDendif] = ACTIONS(471),
    [anon_sym_POUNDENDIF] = ACTIONS(471),
    [anon_sym_POUNDEndif] = ACTIONS(471),
    [anon_sym_POUNDendif2] = ACTIONS(471),
    [anon_sym_POUNDENDIF2] = ACTIONS(471),
    [anon_sym_POUNDEndif2] = ACTIONS(471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(471),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(473),
  },
  [STATE(153)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(11549),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(163),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(475),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(477),
    [anon_sym_POUNDELIF] = ACTIONS(477),
    [anon_sym_POUNDElif] = ACTIONS(477),
    [anon_sym_POUNDelse] = ACTIONS(477),
    [anon_sym_POUNDELSE] = ACTIONS(477),
    [anon_sym_POUNDElse] = ACTIONS(477),
    [anon_sym_POUNDelse2] = ACTIONS(477),
    [anon_sym_POUNDELSE2] = ACTIONS(477),
    [anon_sym_POUNDElse2] = ACTIONS(477),
    [anon_sym_POUNDendif] = ACTIONS(477),
    [anon_sym_POUNDENDIF] = ACTIONS(477),
    [anon_sym_POUNDEndif] = ACTIONS(477),
    [anon_sym_POUNDendif2] = ACTIONS(477),
    [anon_sym_POUNDENDIF2] = ACTIONS(477),
    [anon_sym_POUNDEndif2] = ACTIONS(477),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(477),
    [sym_begin_keyword] = ACTIONS(479),
  },
  [STATE(154)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2501),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2502),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(481),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(471),
    [anon_sym_POUNDELIF] = ACTIONS(471),
    [anon_sym_POUNDElif] = ACTIONS(471),
    [anon_sym_POUNDelse] = ACTIONS(471),
    [anon_sym_POUNDELSE] = ACTIONS(471),
    [anon_sym_POUNDElse] = ACTIONS(471),
    [anon_sym_POUNDelse2] = ACTIONS(471),
    [anon_sym_POUNDELSE2] = ACTIONS(471),
    [anon_sym_POUNDElse2] = ACTIONS(471),
    [anon_sym_POUNDendif] = ACTIONS(471),
    [anon_sym_POUNDENDIF] = ACTIONS(471),
    [anon_sym_POUNDEndif] = ACTIONS(471),
    [anon_sym_POUNDendif2] = ACTIONS(471),
    [anon_sym_POUNDENDIF2] = ACTIONS(471),
    [anon_sym_POUNDEndif2] = ACTIONS(471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(471),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(483),
  },
  [STATE(155)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDelif] = ACTIONS(485),
    [anon_sym_POUNDELIF] = ACTIONS(485),
    [anon_sym_POUNDElif] = ACTIONS(485),
    [anon_sym_POUNDelse] = ACTIONS(485),
    [anon_sym_POUNDELSE] = ACTIONS(485),
    [anon_sym_POUNDElse] = ACTIONS(485),
    [anon_sym_POUNDelse2] = ACTIONS(485),
    [anon_sym_POUNDELSE2] = ACTIONS(485),
    [anon_sym_POUNDElse2] = ACTIONS(485),
    [anon_sym_POUNDendif] = ACTIONS(485),
    [anon_sym_POUNDENDIF] = ACTIONS(485),
    [anon_sym_POUNDEndif] = ACTIONS(485),
    [anon_sym_POUNDendif2] = ACTIONS(485),
    [anon_sym_POUNDENDIF2] = ACTIONS(485),
    [anon_sym_POUNDEndif2] = ACTIONS(485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(485),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(156)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2465),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2466),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(487),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(471),
    [anon_sym_POUNDELIF] = ACTIONS(471),
    [anon_sym_POUNDElif] = ACTIONS(471),
    [anon_sym_POUNDelse] = ACTIONS(471),
    [anon_sym_POUNDELSE] = ACTIONS(471),
    [anon_sym_POUNDElse] = ACTIONS(471),
    [anon_sym_POUNDelse2] = ACTIONS(471),
    [anon_sym_POUNDELSE2] = ACTIONS(471),
    [anon_sym_POUNDElse2] = ACTIONS(471),
    [anon_sym_POUNDendif] = ACTIONS(471),
    [anon_sym_POUNDENDIF] = ACTIONS(471),
    [anon_sym_POUNDEndif] = ACTIONS(471),
    [anon_sym_POUNDendif2] = ACTIONS(471),
    [anon_sym_POUNDENDIF2] = ACTIONS(471),
    [anon_sym_POUNDEndif2] = ACTIONS(471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(471),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(489),
  },
  [STATE(157)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2503),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2504),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(491),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(471),
    [anon_sym_POUNDELIF] = ACTIONS(471),
    [anon_sym_POUNDElif] = ACTIONS(471),
    [anon_sym_POUNDelse] = ACTIONS(471),
    [anon_sym_POUNDELSE] = ACTIONS(471),
    [anon_sym_POUNDElse] = ACTIONS(471),
    [anon_sym_POUNDelse2] = ACTIONS(471),
    [anon_sym_POUNDELSE2] = ACTIONS(471),
    [anon_sym_POUNDElse2] = ACTIONS(471),
    [anon_sym_POUNDendif] = ACTIONS(471),
    [anon_sym_POUNDENDIF] = ACTIONS(471),
    [anon_sym_POUNDEndif] = ACTIONS(471),
    [anon_sym_POUNDendif2] = ACTIONS(471),
    [anon_sym_POUNDENDIF2] = ACTIONS(471),
    [anon_sym_POUNDEndif2] = ACTIONS(471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(471),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(493),
  },
  [STATE(158)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2605),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2606),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(481),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(471),
    [anon_sym_POUNDELIF] = ACTIONS(471),
    [anon_sym_POUNDElif] = ACTIONS(471),
    [anon_sym_POUNDelse] = ACTIONS(471),
    [anon_sym_POUNDELSE] = ACTIONS(471),
    [anon_sym_POUNDElse] = ACTIONS(471),
    [anon_sym_POUNDelse2] = ACTIONS(471),
    [anon_sym_POUNDELSE2] = ACTIONS(471),
    [anon_sym_POUNDElse2] = ACTIONS(471),
    [anon_sym_POUNDendif] = ACTIONS(471),
    [anon_sym_POUNDENDIF] = ACTIONS(471),
    [anon_sym_POUNDEndif] = ACTIONS(471),
    [anon_sym_POUNDendif2] = ACTIONS(471),
    [anon_sym_POUNDENDIF2] = ACTIONS(471),
    [anon_sym_POUNDEndif2] = ACTIONS(471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(471),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(483),
  },
  [STATE(159)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2498),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2499),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(487),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(471),
    [anon_sym_POUNDELIF] = ACTIONS(471),
    [anon_sym_POUNDElif] = ACTIONS(471),
    [anon_sym_POUNDelse] = ACTIONS(471),
    [anon_sym_POUNDELSE] = ACTIONS(471),
    [anon_sym_POUNDElse] = ACTIONS(471),
    [anon_sym_POUNDelse2] = ACTIONS(471),
    [anon_sym_POUNDELSE2] = ACTIONS(471),
    [anon_sym_POUNDElse2] = ACTIONS(471),
    [anon_sym_POUNDendif] = ACTIONS(471),
    [anon_sym_POUNDENDIF] = ACTIONS(471),
    [anon_sym_POUNDEndif] = ACTIONS(471),
    [anon_sym_POUNDendif2] = ACTIONS(471),
    [anon_sym_POUNDENDIF2] = ACTIONS(471),
    [anon_sym_POUNDEndif2] = ACTIONS(471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(471),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(489),
  },
  [STATE(160)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(495),
    [anon_sym_SEMI] = ACTIONS(498),
    [anon_sym_DASH] = ACTIONS(501),
    [aux_sym_boolean_token1] = ACTIONS(504),
    [aux_sym_boolean_token2] = ACTIONS(504),
    [sym_decimal] = ACTIONS(507),
    [anon_sym_LPAREN] = ACTIONS(510),
    [aux_sym_tabledata_permission_token2] = ACTIONS(513),
    [anon_sym_LBRACK] = ACTIONS(516),
    [aux_sym_record_type_token1] = ACTIONS(513),
    [aux_sym_basic_type_token21] = ACTIONS(513),
    [aux_sym_basic_type_token22] = ACTIONS(513),
    [aux_sym_basic_type_token48] = ACTIONS(513),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(519),
    [anon_sym_POUNDif] = ACTIONS(521),
    [anon_sym_POUNDIF] = ACTIONS(521),
    [anon_sym_POUNDIf] = ACTIONS(521),
    [anon_sym_not] = ACTIONS(524),
    [anon_sym_NOT] = ACTIONS(524),
    [anon_sym_Not] = ACTIONS(524),
    [anon_sym_POUNDelif] = ACTIONS(527),
    [anon_sym_POUNDELIF] = ACTIONS(527),
    [anon_sym_POUNDElif] = ACTIONS(527),
    [anon_sym_POUNDelse] = ACTIONS(527),
    [anon_sym_POUNDELSE] = ACTIONS(527),
    [anon_sym_POUNDElse] = ACTIONS(527),
    [anon_sym_POUNDelse2] = ACTIONS(527),
    [anon_sym_POUNDELSE2] = ACTIONS(527),
    [anon_sym_POUNDElse2] = ACTIONS(527),
    [anon_sym_POUNDendif] = ACTIONS(527),
    [anon_sym_POUNDENDIF] = ACTIONS(527),
    [anon_sym_POUNDEndif] = ACTIONS(527),
    [anon_sym_POUNDendif2] = ACTIONS(527),
    [anon_sym_POUNDENDIF2] = ACTIONS(527),
    [anon_sym_POUNDEndif2] = ACTIONS(527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(513),
    [aux_sym_keyword_identifier_token2] = ACTIONS(529),
    [anon_sym_PLUS] = ACTIONS(501),
    [sym_datetime_literal] = ACTIONS(532),
    [sym_date_literal] = ACTIONS(507),
    [sym_time_literal] = ACTIONS(507),
    [sym_biginteger_literal] = ACTIONS(532),
    [anon_sym_if] = ACTIONS(535),
    [anon_sym_IF] = ACTIONS(535),
    [anon_sym_If] = ACTIONS(535),
    [anon_sym_case] = ACTIONS(538),
    [anon_sym_CASE] = ACTIONS(538),
    [anon_sym_Case] = ACTIONS(538),
    [anon_sym_for] = ACTIONS(541),
    [anon_sym_FOR] = ACTIONS(541),
    [anon_sym_For] = ACTIONS(541),
    [anon_sym_foreach] = ACTIONS(544),
    [anon_sym_FOREACH] = ACTIONS(544),
    [anon_sym_Foreach] = ACTIONS(544),
    [anon_sym_while] = ACTIONS(547),
    [anon_sym_WHILE] = ACTIONS(547),
    [anon_sym_While] = ACTIONS(547),
    [anon_sym_repeat] = ACTIONS(550),
    [anon_sym_REPEAT] = ACTIONS(550),
    [anon_sym_Repeat] = ACTIONS(550),
    [anon_sym_exit] = ACTIONS(553),
    [anon_sym_EXIT] = ACTIONS(553),
    [anon_sym_Exit] = ACTIONS(553),
    [anon_sym_continue] = ACTIONS(556),
    [anon_sym_CONTINUE] = ACTIONS(556),
    [anon_sym_Continue] = ACTIONS(556),
    [anon_sym_break] = ACTIONS(559),
    [anon_sym_BREAK] = ACTIONS(559),
    [anon_sym_Break] = ACTIONS(559),
    [anon_sym_with] = ACTIONS(562),
    [anon_sym_WITH] = ACTIONS(562),
    [anon_sym_With] = ACTIONS(562),
    [sym_asserterror_keyword] = ACTIONS(565),
    [sym_page_keyword] = ACTIONS(529),
    [anon_sym_codeunit] = ACTIONS(568),
    [anon_sym_CODEUNIT] = ACTIONS(568),
    [anon_sym_Codeunit] = ACTIONS(568),
    [anon_sym_CodeUnit] = ACTIONS(568),
    [anon_sym_COdeunit] = ACTIONS(568),
    [anon_sym_codeUnit] = ACTIONS(568),
    [sym_report_keyword] = ACTIONS(529),
    [sym_query_keyword] = ACTIONS(529),
    [anon_sym_xmlport] = ACTIONS(571),
    [anon_sym_XMLPORT] = ACTIONS(571),
    [anon_sym_Xmlport] = ACTIONS(571),
    [anon_sym_XMLport] = ACTIONS(571),
    [anon_sym_XMLPort] = ACTIONS(571),
    [anon_sym_XmlPort] = ACTIONS(571),
    [anon_sym_enum] = ACTIONS(574),
    [anon_sym_ENUM] = ACTIONS(574),
    [anon_sym_Enum] = ACTIONS(574),
    [anon_sym_eNUM] = ACTIONS(574),
    [anon_sym_eNum] = ACTIONS(574),
    [anon_sym_ENum] = ACTIONS(574),
    [sym_quoted_identifier] = ACTIONS(577),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(532),
    [sym_verbatim_string] = ACTIONS(532),
    [sym_integer] = ACTIONS(507),
    [sym_continue_as_identifier] = ACTIONS(532),
    [sym_preproc_open] = ACTIONS(521),
    [sym_preproc_close] = ACTIONS(527),
  },
  [STATE(161)] = {
    [sym_boolean] = STATE(1817),
    [sym_option_member_list] = STATE(1852),
    [sym_option_member] = STATE(1784),
    [sym_keyword_identifier] = STATE(1817),
    [sym_codeunit_keyword] = STATE(1782),
    [sym_xmlport_keyword] = STATE(1782),
    [sym_enum_keyword] = STATE(1782),
    [sym_keyword_as_identifier] = STATE(1817),
    [aux_sym_option_member_list_repeat2] = STATE(164),
    [sym_identifier] = ACTIONS(580),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(586),
    [anon_sym_DASH] = ACTIONS(588),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(584),
    [anon_sym_LPAREN] = ACTIONS(582),
    [aux_sym_where_condition_token1] = ACTIONS(590),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(592),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_basic_type_token53] = ACTIONS(590),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(590),
    [aux_sym_separator_action_token1] = ACTIONS(590),
    [aux_sym_assembly_declaration_token1] = ACTIONS(590),
    [aux_sym_type_declaration_token1] = ACTIONS(590),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(584),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(584),
    [anon_sym_NOT] = ACTIONS(584),
    [anon_sym_Not] = ACTIONS(584),
    [anon_sym_POUNDelif] = ACTIONS(582),
    [anon_sym_POUNDELIF] = ACTIONS(582),
    [anon_sym_POUNDElif] = ACTIONS(582),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [anon_sym_POUNDendif] = ACTIONS(582),
    [anon_sym_POUNDENDIF] = ACTIONS(582),
    [anon_sym_POUNDEndif] = ACTIONS(582),
    [anon_sym_POUNDendif2] = ACTIONS(582),
    [anon_sym_POUNDENDIF2] = ACTIONS(582),
    [anon_sym_POUNDEndif2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(584),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [sym_datetime_literal] = ACTIONS(582),
    [sym_date_literal] = ACTIONS(584),
    [sym_time_literal] = ACTIONS(584),
    [sym_biginteger_literal] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(584),
    [anon_sym_IF] = ACTIONS(584),
    [anon_sym_If] = ACTIONS(584),
    [anon_sym_else] = ACTIONS(584),
    [anon_sym_ELSE] = ACTIONS(584),
    [anon_sym_Else] = ACTIONS(584),
    [anon_sym_case] = ACTIONS(584),
    [anon_sym_CASE] = ACTIONS(584),
    [anon_sym_Case] = ACTIONS(584),
    [anon_sym_for] = ACTIONS(584),
    [anon_sym_FOR] = ACTIONS(584),
    [anon_sym_For] = ACTIONS(584),
    [anon_sym_foreach] = ACTIONS(584),
    [anon_sym_FOREACH] = ACTIONS(584),
    [anon_sym_Foreach] = ACTIONS(584),
    [anon_sym_while] = ACTIONS(584),
    [anon_sym_WHILE] = ACTIONS(584),
    [anon_sym_While] = ACTIONS(584),
    [anon_sym_repeat] = ACTIONS(584),
    [anon_sym_REPEAT] = ACTIONS(584),
    [anon_sym_Repeat] = ACTIONS(584),
    [anon_sym_exit] = ACTIONS(584),
    [anon_sym_EXIT] = ACTIONS(584),
    [anon_sym_Exit] = ACTIONS(584),
    [anon_sym_continue] = ACTIONS(584),
    [anon_sym_CONTINUE] = ACTIONS(584),
    [anon_sym_Continue] = ACTIONS(584),
    [anon_sym_break] = ACTIONS(584),
    [anon_sym_BREAK] = ACTIONS(584),
    [anon_sym_Break] = ACTIONS(584),
    [anon_sym_with] = ACTIONS(584),
    [anon_sym_WITH] = ACTIONS(584),
    [anon_sym_With] = ACTIONS(584),
    [sym_asserterror_keyword] = ACTIONS(582),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(590),
    [sym_page_keyword] = ACTIONS(67),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(67),
    [sym_query_keyword] = ACTIONS(67),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_local_keyword] = ACTIONS(580),
    [sym_internal_keyword] = ACTIONS(580),
    [sym_protected_keyword] = ACTIONS(580),
    [sym_key_keyword] = ACTIONS(590),
    [sym_dataset_keyword] = ACTIONS(590),
    [sym_quoted_identifier] = ACTIONS(594),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(594),
    [sym_verbatim_string] = ACTIONS(582),
    [sym_integer] = ACTIONS(580),
    [sym_continue_as_identifier] = ACTIONS(582),
    [sym_preproc_open] = ACTIONS(582),
    [sym_preproc_close] = ACTIONS(582),
  },
  [STATE(162)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(165),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(596),
    [anon_sym_POUNDELIF] = ACTIONS(596),
    [anon_sym_POUNDElif] = ACTIONS(596),
    [anon_sym_POUNDelse] = ACTIONS(596),
    [anon_sym_POUNDELSE] = ACTIONS(596),
    [anon_sym_POUNDElse] = ACTIONS(596),
    [anon_sym_POUNDelse2] = ACTIONS(596),
    [anon_sym_POUNDELSE2] = ACTIONS(596),
    [anon_sym_POUNDElse2] = ACTIONS(596),
    [anon_sym_POUNDendif] = ACTIONS(596),
    [anon_sym_POUNDENDIF] = ACTIONS(596),
    [anon_sym_POUNDEndif] = ACTIONS(596),
    [anon_sym_POUNDendif2] = ACTIONS(596),
    [anon_sym_POUNDENDIF2] = ACTIONS(596),
    [anon_sym_POUNDEndif2] = ACTIONS(596),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(596),
  },
  [STATE(163)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(598),
    [anon_sym_POUNDELIF] = ACTIONS(598),
    [anon_sym_POUNDElif] = ACTIONS(598),
    [anon_sym_POUNDelse] = ACTIONS(598),
    [anon_sym_POUNDELSE] = ACTIONS(598),
    [anon_sym_POUNDElse] = ACTIONS(598),
    [anon_sym_POUNDelse2] = ACTIONS(598),
    [anon_sym_POUNDELSE2] = ACTIONS(598),
    [anon_sym_POUNDElse2] = ACTIONS(598),
    [anon_sym_POUNDendif] = ACTIONS(598),
    [anon_sym_POUNDENDIF] = ACTIONS(598),
    [anon_sym_POUNDEndif] = ACTIONS(598),
    [anon_sym_POUNDendif2] = ACTIONS(598),
    [anon_sym_POUNDENDIF2] = ACTIONS(598),
    [anon_sym_POUNDEndif2] = ACTIONS(598),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(598),
  },
  [STATE(164)] = {
    [sym_boolean] = STATE(1817),
    [sym_option_member] = STATE(1797),
    [sym_keyword_identifier] = STATE(1817),
    [sym_codeunit_keyword] = STATE(1782),
    [sym_xmlport_keyword] = STATE(1782),
    [sym_enum_keyword] = STATE(1782),
    [sym_keyword_as_identifier] = STATE(1817),
    [aux_sym_option_member_list_repeat2] = STATE(250),
    [sym_identifier] = ACTIONS(580),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(604),
    [anon_sym_DASH] = ACTIONS(588),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [aux_sym_where_condition_token1] = ACTIONS(590),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(592),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_basic_type_token53] = ACTIONS(590),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(590),
    [aux_sym_separator_action_token1] = ACTIONS(590),
    [aux_sym_assembly_declaration_token1] = ACTIONS(590),
    [aux_sym_type_declaration_token1] = ACTIONS(590),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(602),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(602),
    [anon_sym_IF] = ACTIONS(602),
    [anon_sym_If] = ACTIONS(602),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_case] = ACTIONS(602),
    [anon_sym_CASE] = ACTIONS(602),
    [anon_sym_Case] = ACTIONS(602),
    [anon_sym_for] = ACTIONS(602),
    [anon_sym_FOR] = ACTIONS(602),
    [anon_sym_For] = ACTIONS(602),
    [anon_sym_foreach] = ACTIONS(602),
    [anon_sym_FOREACH] = ACTIONS(602),
    [anon_sym_Foreach] = ACTIONS(602),
    [anon_sym_while] = ACTIONS(602),
    [anon_sym_WHILE] = ACTIONS(602),
    [anon_sym_While] = ACTIONS(602),
    [anon_sym_repeat] = ACTIONS(602),
    [anon_sym_REPEAT] = ACTIONS(602),
    [anon_sym_Repeat] = ACTIONS(602),
    [anon_sym_exit] = ACTIONS(602),
    [anon_sym_EXIT] = ACTIONS(602),
    [anon_sym_Exit] = ACTIONS(602),
    [anon_sym_continue] = ACTIONS(602),
    [anon_sym_CONTINUE] = ACTIONS(602),
    [anon_sym_Continue] = ACTIONS(602),
    [anon_sym_break] = ACTIONS(602),
    [anon_sym_BREAK] = ACTIONS(602),
    [anon_sym_Break] = ACTIONS(602),
    [anon_sym_with] = ACTIONS(602),
    [anon_sym_WITH] = ACTIONS(602),
    [anon_sym_With] = ACTIONS(602),
    [sym_asserterror_keyword] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(590),
    [sym_page_keyword] = ACTIONS(67),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(67),
    [sym_query_keyword] = ACTIONS(67),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_local_keyword] = ACTIONS(580),
    [sym_internal_keyword] = ACTIONS(580),
    [sym_protected_keyword] = ACTIONS(580),
    [sym_key_keyword] = ACTIONS(590),
    [sym_dataset_keyword] = ACTIONS(590),
    [sym_quoted_identifier] = ACTIONS(594),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(594),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(580),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
  },
  [STATE(165)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(606),
    [anon_sym_POUNDELIF] = ACTIONS(606),
    [anon_sym_POUNDElif] = ACTIONS(606),
    [anon_sym_POUNDelse] = ACTIONS(606),
    [anon_sym_POUNDELSE] = ACTIONS(606),
    [anon_sym_POUNDElse] = ACTIONS(606),
    [anon_sym_POUNDelse2] = ACTIONS(606),
    [anon_sym_POUNDELSE2] = ACTIONS(606),
    [anon_sym_POUNDElse2] = ACTIONS(606),
    [anon_sym_POUNDendif] = ACTIONS(606),
    [anon_sym_POUNDENDIF] = ACTIONS(606),
    [anon_sym_POUNDEndif] = ACTIONS(606),
    [anon_sym_POUNDendif2] = ACTIONS(606),
    [anon_sym_POUNDENDIF2] = ACTIONS(606),
    [anon_sym_POUNDEndif2] = ACTIONS(606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(606),
  },
  [STATE(166)] = {
    [sym_boolean] = STATE(1817),
    [sym_option_member] = STATE(1823),
    [sym_keyword_identifier] = STATE(1817),
    [sym_codeunit_keyword] = STATE(1782),
    [sym_xmlport_keyword] = STATE(1782),
    [sym_enum_keyword] = STATE(1782),
    [sym_keyword_as_identifier] = STATE(1817),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(615),
    [aux_sym_boolean_token1] = ACTIONS(618),
    [aux_sym_boolean_token2] = ACTIONS(618),
    [sym_decimal] = ACTIONS(613),
    [anon_sym_LPAREN] = ACTIONS(611),
    [aux_sym_where_condition_token1] = ACTIONS(590),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(621),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(621),
    [aux_sym_basic_type_token21] = ACTIONS(621),
    [aux_sym_basic_type_token22] = ACTIONS(624),
    [aux_sym_basic_type_token48] = ACTIONS(621),
    [aux_sym_basic_type_token53] = ACTIONS(590),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(590),
    [aux_sym_separator_action_token1] = ACTIONS(590),
    [aux_sym_assembly_declaration_token1] = ACTIONS(590),
    [aux_sym_type_declaration_token1] = ACTIONS(590),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(613),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [anon_sym_not] = ACTIONS(613),
    [anon_sym_NOT] = ACTIONS(613),
    [anon_sym_Not] = ACTIONS(613),
    [anon_sym_POUNDelif] = ACTIONS(611),
    [anon_sym_POUNDELIF] = ACTIONS(611),
    [anon_sym_POUNDElif] = ACTIONS(611),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [anon_sym_POUNDendif] = ACTIONS(611),
    [anon_sym_POUNDENDIF] = ACTIONS(611),
    [anon_sym_POUNDEndif] = ACTIONS(611),
    [anon_sym_POUNDendif2] = ACTIONS(611),
    [anon_sym_POUNDENDIF2] = ACTIONS(611),
    [anon_sym_POUNDEndif2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(613),
    [aux_sym_keyword_identifier_token1] = ACTIONS(621),
    [aux_sym_keyword_identifier_token2] = ACTIONS(621),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [sym_datetime_literal] = ACTIONS(611),
    [sym_date_literal] = ACTIONS(613),
    [sym_time_literal] = ACTIONS(613),
    [sym_biginteger_literal] = ACTIONS(611),
    [anon_sym_if] = ACTIONS(613),
    [anon_sym_IF] = ACTIONS(613),
    [anon_sym_If] = ACTIONS(613),
    [anon_sym_else] = ACTIONS(613),
    [anon_sym_ELSE] = ACTIONS(613),
    [anon_sym_Else] = ACTIONS(613),
    [anon_sym_case] = ACTIONS(613),
    [anon_sym_CASE] = ACTIONS(613),
    [anon_sym_Case] = ACTIONS(613),
    [anon_sym_for] = ACTIONS(613),
    [anon_sym_FOR] = ACTIONS(613),
    [anon_sym_For] = ACTIONS(613),
    [anon_sym_foreach] = ACTIONS(613),
    [anon_sym_FOREACH] = ACTIONS(613),
    [anon_sym_Foreach] = ACTIONS(613),
    [anon_sym_while] = ACTIONS(613),
    [anon_sym_WHILE] = ACTIONS(613),
    [anon_sym_While] = ACTIONS(613),
    [anon_sym_repeat] = ACTIONS(613),
    [anon_sym_REPEAT] = ACTIONS(613),
    [anon_sym_Repeat] = ACTIONS(613),
    [anon_sym_exit] = ACTIONS(613),
    [anon_sym_EXIT] = ACTIONS(613),
    [anon_sym_Exit] = ACTIONS(613),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_CONTINUE] = ACTIONS(613),
    [anon_sym_Continue] = ACTIONS(613),
    [anon_sym_break] = ACTIONS(613),
    [anon_sym_BREAK] = ACTIONS(613),
    [anon_sym_Break] = ACTIONS(613),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_WITH] = ACTIONS(613),
    [anon_sym_With] = ACTIONS(613),
    [sym_asserterror_keyword] = ACTIONS(611),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(590),
    [sym_page_keyword] = ACTIONS(621),
    [anon_sym_codeunit] = ACTIONS(627),
    [anon_sym_CODEUNIT] = ACTIONS(627),
    [anon_sym_Codeunit] = ACTIONS(627),
    [anon_sym_CodeUnit] = ACTIONS(627),
    [anon_sym_COdeunit] = ACTIONS(627),
    [anon_sym_codeUnit] = ACTIONS(627),
    [sym_report_keyword] = ACTIONS(621),
    [sym_query_keyword] = ACTIONS(621),
    [anon_sym_xmlport] = ACTIONS(630),
    [anon_sym_XMLPORT] = ACTIONS(630),
    [anon_sym_Xmlport] = ACTIONS(630),
    [anon_sym_XMLport] = ACTIONS(630),
    [anon_sym_XMLPort] = ACTIONS(630),
    [anon_sym_XmlPort] = ACTIONS(630),
    [anon_sym_enum] = ACTIONS(633),
    [anon_sym_ENUM] = ACTIONS(633),
    [anon_sym_Enum] = ACTIONS(633),
    [anon_sym_eNUM] = ACTIONS(633),
    [anon_sym_eNum] = ACTIONS(633),
    [anon_sym_ENum] = ACTIONS(633),
    [sym_local_keyword] = ACTIONS(580),
    [sym_internal_keyword] = ACTIONS(580),
    [sym_protected_keyword] = ACTIONS(580),
    [sym_key_keyword] = ACTIONS(590),
    [sym_dataset_keyword] = ACTIONS(590),
    [sym_quoted_identifier] = ACTIONS(636),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(636),
    [sym_verbatim_string] = ACTIONS(611),
    [sym_integer] = ACTIONS(608),
    [sym_continue_as_identifier] = ACTIONS(611),
    [sym_preproc_open] = ACTIONS(611),
    [sym_preproc_close] = ACTIONS(611),
  },
  [STATE(167)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_endif] = STATE(379),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(168)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_endif] = STATE(381),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(169)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_endif] = STATE(380),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(170)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_endif] = STATE(340),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(171)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_endif] = STATE(374),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(172)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_endif] = STATE(375),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(173)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_endif] = STATE(378),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(174)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_endif] = STATE(376),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(343),
    [anon_sym_POUNDENDIF] = ACTIONS(343),
    [anon_sym_POUNDEndif] = ACTIONS(343),
    [anon_sym_POUNDendif2] = ACTIONS(343),
    [anon_sym_POUNDENDIF2] = ACTIONS(343),
    [anon_sym_POUNDEndif2] = ACTIONS(343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(343),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(175)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1687),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(176)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1759),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(191),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(177)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1735),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2519),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(713),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(715),
  },
  [STATE(178)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1668),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(180),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(179)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(717),
    [anon_sym_SEMI] = ACTIONS(720),
    [anon_sym_DASH] = ACTIONS(723),
    [aux_sym_boolean_token1] = ACTIONS(726),
    [aux_sym_boolean_token2] = ACTIONS(726),
    [sym_decimal] = ACTIONS(729),
    [anon_sym_LPAREN] = ACTIONS(732),
    [aux_sym_tabledata_permission_token2] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(738),
    [aux_sym_record_type_token1] = ACTIONS(735),
    [aux_sym_basic_type_token21] = ACTIONS(735),
    [aux_sym_basic_type_token22] = ACTIONS(735),
    [aux_sym_basic_type_token48] = ACTIONS(735),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(519),
    [anon_sym_POUNDif] = ACTIONS(521),
    [anon_sym_POUNDIF] = ACTIONS(521),
    [anon_sym_POUNDIf] = ACTIONS(521),
    [anon_sym_not] = ACTIONS(741),
    [anon_sym_NOT] = ACTIONS(741),
    [anon_sym_Not] = ACTIONS(741),
    [anon_sym_POUNDelse] = ACTIONS(527),
    [anon_sym_POUNDELSE] = ACTIONS(527),
    [anon_sym_POUNDElse] = ACTIONS(527),
    [anon_sym_POUNDelse2] = ACTIONS(527),
    [anon_sym_POUNDELSE2] = ACTIONS(527),
    [anon_sym_POUNDElse2] = ACTIONS(527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(735),
    [aux_sym_keyword_identifier_token2] = ACTIONS(744),
    [anon_sym_PLUS] = ACTIONS(723),
    [sym_datetime_literal] = ACTIONS(747),
    [sym_date_literal] = ACTIONS(729),
    [sym_time_literal] = ACTIONS(729),
    [sym_biginteger_literal] = ACTIONS(747),
    [anon_sym_if] = ACTIONS(535),
    [anon_sym_IF] = ACTIONS(535),
    [anon_sym_If] = ACTIONS(535),
    [anon_sym_case] = ACTIONS(538),
    [anon_sym_CASE] = ACTIONS(538),
    [anon_sym_Case] = ACTIONS(538),
    [anon_sym_for] = ACTIONS(541),
    [anon_sym_FOR] = ACTIONS(541),
    [anon_sym_For] = ACTIONS(541),
    [anon_sym_foreach] = ACTIONS(544),
    [anon_sym_FOREACH] = ACTIONS(544),
    [anon_sym_Foreach] = ACTIONS(544),
    [anon_sym_while] = ACTIONS(547),
    [anon_sym_WHILE] = ACTIONS(547),
    [anon_sym_While] = ACTIONS(547),
    [anon_sym_repeat] = ACTIONS(550),
    [anon_sym_REPEAT] = ACTIONS(550),
    [anon_sym_Repeat] = ACTIONS(550),
    [anon_sym_until] = ACTIONS(519),
    [anon_sym_UNTIL] = ACTIONS(519),
    [anon_sym_Until] = ACTIONS(519),
    [anon_sym_exit] = ACTIONS(750),
    [anon_sym_EXIT] = ACTIONS(750),
    [anon_sym_Exit] = ACTIONS(750),
    [anon_sym_continue] = ACTIONS(753),
    [anon_sym_CONTINUE] = ACTIONS(753),
    [anon_sym_Continue] = ACTIONS(753),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_BREAK] = ACTIONS(756),
    [anon_sym_Break] = ACTIONS(756),
    [anon_sym_with] = ACTIONS(562),
    [anon_sym_WITH] = ACTIONS(562),
    [anon_sym_With] = ACTIONS(562),
    [sym_asserterror_keyword] = ACTIONS(759),
    [sym_page_keyword] = ACTIONS(744),
    [anon_sym_codeunit] = ACTIONS(762),
    [anon_sym_CODEUNIT] = ACTIONS(762),
    [anon_sym_Codeunit] = ACTIONS(762),
    [anon_sym_CodeUnit] = ACTIONS(762),
    [anon_sym_COdeunit] = ACTIONS(762),
    [anon_sym_codeUnit] = ACTIONS(762),
    [sym_report_keyword] = ACTIONS(744),
    [sym_query_keyword] = ACTIONS(744),
    [anon_sym_xmlport] = ACTIONS(765),
    [anon_sym_XMLPORT] = ACTIONS(765),
    [anon_sym_Xmlport] = ACTIONS(765),
    [anon_sym_XMLport] = ACTIONS(765),
    [anon_sym_XMLPort] = ACTIONS(765),
    [anon_sym_XmlPort] = ACTIONS(765),
    [anon_sym_enum] = ACTIONS(768),
    [anon_sym_ENUM] = ACTIONS(768),
    [anon_sym_Enum] = ACTIONS(768),
    [anon_sym_eNUM] = ACTIONS(768),
    [anon_sym_eNum] = ACTIONS(768),
    [anon_sym_ENum] = ACTIONS(768),
    [sym_quoted_identifier] = ACTIONS(771),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(747),
    [sym_verbatim_string] = ACTIONS(747),
    [sym_integer] = ACTIONS(729),
    [sym_continue_as_identifier] = ACTIONS(747),
    [sym_preproc_open] = ACTIONS(521),
  },
  [STATE(180)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1670),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2519),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(713),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(715),
  },
  [STATE(181)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1765),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(182)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1731),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(177),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(183)] = {
    [sym_boolean] = STATE(1933),
    [sym_option_member_list] = STATE(1982),
    [sym_option_member] = STATE(1903),
    [sym_keyword_identifier] = STATE(1933),
    [sym_codeunit_keyword] = STATE(1909),
    [sym_xmlport_keyword] = STATE(1909),
    [sym_enum_keyword] = STATE(1909),
    [sym_keyword_as_identifier] = STATE(1933),
    [aux_sym_option_member_list_repeat2] = STATE(235),
    [sym_identifier] = ACTIONS(774),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(776),
    [anon_sym_DASH] = ACTIONS(778),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(584),
    [anon_sym_LPAREN] = ACTIONS(582),
    [aux_sym_where_condition_token1] = ACTIONS(780),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(782),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_basic_type_token53] = ACTIONS(780),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(780),
    [aux_sym_separator_action_token1] = ACTIONS(780),
    [aux_sym_assembly_declaration_token1] = ACTIONS(780),
    [aux_sym_type_declaration_token1] = ACTIONS(780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(584),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(584),
    [anon_sym_NOT] = ACTIONS(584),
    [anon_sym_Not] = ACTIONS(584),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(584),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(649),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [sym_datetime_literal] = ACTIONS(582),
    [sym_date_literal] = ACTIONS(584),
    [sym_time_literal] = ACTIONS(584),
    [sym_biginteger_literal] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(584),
    [anon_sym_IF] = ACTIONS(584),
    [anon_sym_If] = ACTIONS(584),
    [anon_sym_else] = ACTIONS(584),
    [anon_sym_ELSE] = ACTIONS(584),
    [anon_sym_Else] = ACTIONS(584),
    [anon_sym_case] = ACTIONS(584),
    [anon_sym_CASE] = ACTIONS(584),
    [anon_sym_Case] = ACTIONS(584),
    [anon_sym_for] = ACTIONS(584),
    [anon_sym_FOR] = ACTIONS(584),
    [anon_sym_For] = ACTIONS(584),
    [anon_sym_foreach] = ACTIONS(584),
    [anon_sym_FOREACH] = ACTIONS(584),
    [anon_sym_Foreach] = ACTIONS(584),
    [anon_sym_while] = ACTIONS(584),
    [anon_sym_WHILE] = ACTIONS(584),
    [anon_sym_While] = ACTIONS(584),
    [anon_sym_repeat] = ACTIONS(584),
    [anon_sym_REPEAT] = ACTIONS(584),
    [anon_sym_Repeat] = ACTIONS(584),
    [anon_sym_until] = ACTIONS(584),
    [anon_sym_UNTIL] = ACTIONS(584),
    [anon_sym_Until] = ACTIONS(584),
    [anon_sym_exit] = ACTIONS(584),
    [anon_sym_EXIT] = ACTIONS(584),
    [anon_sym_Exit] = ACTIONS(584),
    [anon_sym_continue] = ACTIONS(584),
    [anon_sym_CONTINUE] = ACTIONS(584),
    [anon_sym_Continue] = ACTIONS(584),
    [anon_sym_break] = ACTIONS(584),
    [anon_sym_BREAK] = ACTIONS(584),
    [anon_sym_Break] = ACTIONS(584),
    [anon_sym_with] = ACTIONS(584),
    [anon_sym_WITH] = ACTIONS(584),
    [anon_sym_With] = ACTIONS(584),
    [sym_asserterror_keyword] = ACTIONS(582),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(780),
    [sym_page_keyword] = ACTIONS(649),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(649),
    [sym_query_keyword] = ACTIONS(649),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_local_keyword] = ACTIONS(774),
    [sym_internal_keyword] = ACTIONS(774),
    [sym_protected_keyword] = ACTIONS(774),
    [sym_key_keyword] = ACTIONS(780),
    [sym_dataset_keyword] = ACTIONS(780),
    [sym_quoted_identifier] = ACTIONS(784),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(784),
    [sym_verbatim_string] = ACTIONS(582),
    [sym_integer] = ACTIONS(774),
    [sym_continue_as_identifier] = ACTIONS(582),
    [sym_preproc_open] = ACTIONS(582),
  },
  [STATE(184)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1673),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(185)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1675),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(186)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1676),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(187)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1677),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(188)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1680),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(189)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1682),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(190)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1683),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(191)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1762),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2519),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(713),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(715),
  },
  [STATE(192)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1691),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(193)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1693),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(194)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1694),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(195)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1695),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(196)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1698),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(197)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1700),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(198)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1701),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(199)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1663),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(200)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1709),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(201)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1711),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(202)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1712),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(203)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1713),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(204)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1715),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(205)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1717),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(206)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1718),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(207)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1722),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(208)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1665),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(209)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1727),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(210)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1664),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(211)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1738),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(212)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1728),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(213)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1740),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(214),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(214)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1742),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2519),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(713),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(715),
  },
  [STATE(215)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1743),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(216),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(216)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1746),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2519),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(713),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(715),
  },
  [STATE(217)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1739),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(218)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1748),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(219),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(219)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1750),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2519),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(713),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(715),
  },
  [STATE(220)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1751),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(221),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(221)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1754),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2519),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(713),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(715),
  },
  [STATE(222)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1756),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(223),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(223)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_else] = STATE(1758),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2519),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(713),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(377),
    [anon_sym_POUNDELSE] = ACTIONS(377),
    [anon_sym_POUNDElse] = ACTIONS(377),
    [anon_sym_POUNDelse2] = ACTIONS(377),
    [anon_sym_POUNDELSE2] = ACTIONS(377),
    [anon_sym_POUNDElse2] = ACTIONS(377),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(715),
  },
  [STATE(224)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_endif] = STATE(1705),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(225)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14892),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14706),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(232),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(786),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(226)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14974),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14705),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(788),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(227)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14883),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14748),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(228),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(790),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(228)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14921),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14750),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(792),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(229)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14949),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14751),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(230),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(794),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(230)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14975),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14756),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(796),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(231)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14883),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14748),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(247),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(798),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(232)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14954),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14707),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(800),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(233)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14984),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14708),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(234),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(802),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(234)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14789),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14709),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(804),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(235)] = {
    [sym_boolean] = STATE(1933),
    [sym_option_member] = STATE(1887),
    [sym_keyword_identifier] = STATE(1933),
    [sym_codeunit_keyword] = STATE(1909),
    [sym_xmlport_keyword] = STATE(1909),
    [sym_enum_keyword] = STATE(1909),
    [sym_keyword_as_identifier] = STATE(1933),
    [aux_sym_option_member_list_repeat2] = STATE(584),
    [sym_identifier] = ACTIONS(774),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(806),
    [anon_sym_DASH] = ACTIONS(778),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [aux_sym_where_condition_token1] = ACTIONS(780),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(782),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_basic_type_token53] = ACTIONS(780),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(780),
    [aux_sym_separator_action_token1] = ACTIONS(780),
    [aux_sym_assembly_declaration_token1] = ACTIONS(780),
    [aux_sym_type_declaration_token1] = ACTIONS(780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(602),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(649),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(602),
    [anon_sym_IF] = ACTIONS(602),
    [anon_sym_If] = ACTIONS(602),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_case] = ACTIONS(602),
    [anon_sym_CASE] = ACTIONS(602),
    [anon_sym_Case] = ACTIONS(602),
    [anon_sym_for] = ACTIONS(602),
    [anon_sym_FOR] = ACTIONS(602),
    [anon_sym_For] = ACTIONS(602),
    [anon_sym_foreach] = ACTIONS(602),
    [anon_sym_FOREACH] = ACTIONS(602),
    [anon_sym_Foreach] = ACTIONS(602),
    [anon_sym_while] = ACTIONS(602),
    [anon_sym_WHILE] = ACTIONS(602),
    [anon_sym_While] = ACTIONS(602),
    [anon_sym_repeat] = ACTIONS(602),
    [anon_sym_REPEAT] = ACTIONS(602),
    [anon_sym_Repeat] = ACTIONS(602),
    [anon_sym_until] = ACTIONS(602),
    [anon_sym_UNTIL] = ACTIONS(602),
    [anon_sym_Until] = ACTIONS(602),
    [anon_sym_exit] = ACTIONS(602),
    [anon_sym_EXIT] = ACTIONS(602),
    [anon_sym_Exit] = ACTIONS(602),
    [anon_sym_continue] = ACTIONS(602),
    [anon_sym_CONTINUE] = ACTIONS(602),
    [anon_sym_Continue] = ACTIONS(602),
    [anon_sym_break] = ACTIONS(602),
    [anon_sym_BREAK] = ACTIONS(602),
    [anon_sym_Break] = ACTIONS(602),
    [anon_sym_with] = ACTIONS(602),
    [anon_sym_WITH] = ACTIONS(602),
    [anon_sym_With] = ACTIONS(602),
    [sym_asserterror_keyword] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(780),
    [sym_page_keyword] = ACTIONS(649),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(649),
    [sym_query_keyword] = ACTIONS(649),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_local_keyword] = ACTIONS(774),
    [sym_internal_keyword] = ACTIONS(774),
    [sym_protected_keyword] = ACTIONS(774),
    [sym_key_keyword] = ACTIONS(780),
    [sym_dataset_keyword] = ACTIONS(780),
    [sym_quoted_identifier] = ACTIONS(784),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(784),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(774),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
  },
  [STATE(236)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(15002),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14716),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(237),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(808),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(237)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14861),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14685),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(810),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(238)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14861),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14685),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(812),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(239)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14878),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14690),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(240),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(814),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(240)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14943),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14742),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(816),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(241)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14949),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14751),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(245),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(818),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(242)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14873),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14696),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(244),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(820),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(243)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14878),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14690),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(822),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(244)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14876),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14697),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(824),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(245)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14975),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14756),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(826),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(246)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14773),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14698),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(248),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(828),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(247)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14921),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14750),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(830),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(248)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14891),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14699),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(832),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(249)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14943),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14742),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(834),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(250)] = {
    [aux_sym_option_member_list_repeat2] = STATE(250),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_EQ] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(840),
    [anon_sym_DASH] = ACTIONS(836),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [sym_decimal] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(838),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(838),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [anon_sym_not] = ACTIONS(836),
    [anon_sym_NOT] = ACTIONS(836),
    [anon_sym_Not] = ACTIONS(836),
    [anon_sym_POUNDelif] = ACTIONS(838),
    [anon_sym_POUNDELIF] = ACTIONS(838),
    [anon_sym_POUNDElif] = ACTIONS(838),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [anon_sym_POUNDendif] = ACTIONS(838),
    [anon_sym_POUNDENDIF] = ACTIONS(838),
    [anon_sym_POUNDEndif] = ACTIONS(838),
    [anon_sym_POUNDendif2] = ACTIONS(838),
    [anon_sym_POUNDENDIF2] = ACTIONS(838),
    [anon_sym_POUNDEndif2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(838),
    [aux_sym__expression_token1] = ACTIONS(838),
    [aux_sym__expression_token2] = ACTIONS(836),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_div] = ACTIONS(836),
    [anon_sym_DIV] = ACTIONS(836),
    [anon_sym_Div] = ACTIONS(836),
    [anon_sym_mod] = ACTIONS(836),
    [anon_sym_MOD] = ACTIONS(836),
    [anon_sym_Mod] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_LT_GT] = ACTIONS(838),
    [anon_sym_and] = ACTIONS(836),
    [anon_sym_AND] = ACTIONS(836),
    [anon_sym_And] = ACTIONS(836),
    [anon_sym_or] = ACTIONS(836),
    [anon_sym_OR] = ACTIONS(836),
    [anon_sym_Or] = ACTIONS(836),
    [anon_sym_xor] = ACTIONS(836),
    [anon_sym_XOR] = ACTIONS(836),
    [anon_sym_Xor] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(838),
    [sym_datetime_literal] = ACTIONS(838),
    [sym_date_literal] = ACTIONS(836),
    [sym_time_literal] = ACTIONS(836),
    [sym_biginteger_literal] = ACTIONS(838),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_IF] = ACTIONS(836),
    [anon_sym_If] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_ELSE] = ACTIONS(836),
    [anon_sym_Else] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_CASE] = ACTIONS(836),
    [anon_sym_Case] = ACTIONS(836),
    [anon_sym_for] = ACTIONS(836),
    [anon_sym_FOR] = ACTIONS(836),
    [anon_sym_For] = ACTIONS(836),
    [anon_sym_foreach] = ACTIONS(836),
    [anon_sym_FOREACH] = ACTIONS(836),
    [anon_sym_Foreach] = ACTIONS(836),
    [anon_sym_while] = ACTIONS(836),
    [anon_sym_WHILE] = ACTIONS(836),
    [anon_sym_While] = ACTIONS(836),
    [anon_sym_repeat] = ACTIONS(836),
    [anon_sym_REPEAT] = ACTIONS(836),
    [anon_sym_Repeat] = ACTIONS(836),
    [anon_sym_exit] = ACTIONS(836),
    [anon_sym_EXIT] = ACTIONS(836),
    [anon_sym_Exit] = ACTIONS(836),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_CONTINUE] = ACTIONS(836),
    [anon_sym_Continue] = ACTIONS(836),
    [anon_sym_break] = ACTIONS(836),
    [anon_sym_BREAK] = ACTIONS(836),
    [anon_sym_Break] = ACTIONS(836),
    [anon_sym_with] = ACTIONS(836),
    [anon_sym_WITH] = ACTIONS(836),
    [anon_sym_With] = ACTIONS(836),
    [sym_asserterror_keyword] = ACTIONS(838),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_IN] = ACTIONS(836),
    [anon_sym_In] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_verbatim_string] = ACTIONS(838),
    [sym_integer] = ACTIONS(836),
    [sym_continue_as_identifier] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
    [sym_preproc_close] = ACTIONS(838),
  },
  [STATE(251)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(15002),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14716),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(238),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(843),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(252)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14959),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14702),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(253),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(845),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(253)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14964),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14703),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(847),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(254)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_else] = STATE(14965),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym__preproc_if_header] = STATE(14704),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4798),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(226),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(849),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(341),
    [anon_sym_POUNDELSE] = ACTIONS(341),
    [anon_sym_POUNDElse] = ACTIONS(341),
    [anon_sym_POUNDelse2] = ACTIONS(341),
    [anon_sym_POUNDELSE2] = ACTIONS(341),
    [anon_sym_POUNDElse2] = ACTIONS(341),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(255)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(15018),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(280),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(256)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2529),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(257)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2530),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(258)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2531),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(259)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2542),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(260)] = {
    [sym_boolean] = STATE(2033),
    [sym_option_member_list] = STATE(2056),
    [sym_option_member] = STATE(1942),
    [sym_keyword_identifier] = STATE(2033),
    [sym_codeunit_keyword] = STATE(1978),
    [sym_xmlport_keyword] = STATE(1978),
    [sym_enum_keyword] = STATE(1978),
    [sym_keyword_as_identifier] = STATE(2033),
    [aux_sym_option_member_list_repeat2] = STATE(291),
    [sym_identifier] = ACTIONS(851),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(853),
    [anon_sym_DASH] = ACTIONS(855),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(584),
    [anon_sym_LPAREN] = ACTIONS(582),
    [aux_sym_where_condition_token1] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(859),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_basic_type_token53] = ACTIONS(857),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(857),
    [aux_sym_separator_action_token1] = ACTIONS(857),
    [aux_sym_assembly_declaration_token1] = ACTIONS(857),
    [aux_sym_type_declaration_token1] = ACTIONS(857),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(584),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(584),
    [anon_sym_NOT] = ACTIONS(584),
    [anon_sym_Not] = ACTIONS(584),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(584),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(681),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [sym_datetime_literal] = ACTIONS(582),
    [sym_date_literal] = ACTIONS(584),
    [sym_time_literal] = ACTIONS(584),
    [sym_biginteger_literal] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(584),
    [anon_sym_IF] = ACTIONS(584),
    [anon_sym_If] = ACTIONS(584),
    [anon_sym_else] = ACTIONS(584),
    [anon_sym_ELSE] = ACTIONS(584),
    [anon_sym_Else] = ACTIONS(584),
    [anon_sym_case] = ACTIONS(584),
    [anon_sym_CASE] = ACTIONS(584),
    [anon_sym_Case] = ACTIONS(584),
    [anon_sym_for] = ACTIONS(584),
    [anon_sym_FOR] = ACTIONS(584),
    [anon_sym_For] = ACTIONS(584),
    [anon_sym_foreach] = ACTIONS(584),
    [anon_sym_FOREACH] = ACTIONS(584),
    [anon_sym_Foreach] = ACTIONS(584),
    [anon_sym_while] = ACTIONS(584),
    [anon_sym_WHILE] = ACTIONS(584),
    [anon_sym_While] = ACTIONS(584),
    [anon_sym_repeat] = ACTIONS(584),
    [anon_sym_REPEAT] = ACTIONS(584),
    [anon_sym_Repeat] = ACTIONS(584),
    [anon_sym_exit] = ACTIONS(584),
    [anon_sym_EXIT] = ACTIONS(584),
    [anon_sym_Exit] = ACTIONS(584),
    [anon_sym_continue] = ACTIONS(584),
    [anon_sym_CONTINUE] = ACTIONS(584),
    [anon_sym_Continue] = ACTIONS(584),
    [anon_sym_break] = ACTIONS(584),
    [anon_sym_BREAK] = ACTIONS(584),
    [anon_sym_Break] = ACTIONS(584),
    [anon_sym_with] = ACTIONS(584),
    [anon_sym_WITH] = ACTIONS(584),
    [anon_sym_With] = ACTIONS(584),
    [sym_asserterror_keyword] = ACTIONS(582),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(857),
    [sym_page_keyword] = ACTIONS(681),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(681),
    [sym_query_keyword] = ACTIONS(681),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_local_keyword] = ACTIONS(851),
    [sym_internal_keyword] = ACTIONS(851),
    [sym_protected_keyword] = ACTIONS(851),
    [sym_key_keyword] = ACTIONS(857),
    [sym_dataset_keyword] = ACTIONS(857),
    [sym_quoted_identifier] = ACTIONS(861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(861),
    [sym_verbatim_string] = ACTIONS(582),
    [sym_integer] = ACTIONS(851),
    [sym_continue_as_identifier] = ACTIONS(582),
    [sym_preproc_open] = ACTIONS(582),
    [sym_end_keyword] = ACTIONS(582),
  },
  [STATE(261)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3358),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(262)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3100),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(264),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(263)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(471),
    [anon_sym_POUNDELSE] = ACTIONS(471),
    [anon_sym_POUNDElse] = ACTIONS(471),
    [anon_sym_POUNDelse2] = ACTIONS(471),
    [anon_sym_POUNDELSE2] = ACTIONS(471),
    [anon_sym_POUNDElse2] = ACTIONS(471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(264)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3129),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(265)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3135),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(269),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(266)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3208),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(285),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(267)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3367),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(268)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3138),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(290),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(269)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2884),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(270)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2885),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(272),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(271)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2516),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(258),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(272)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2897),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(273)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(863),
    [anon_sym_SEMI] = ACTIONS(866),
    [anon_sym_DASH] = ACTIONS(869),
    [aux_sym_boolean_token1] = ACTIONS(872),
    [aux_sym_boolean_token2] = ACTIONS(872),
    [sym_decimal] = ACTIONS(875),
    [anon_sym_LPAREN] = ACTIONS(878),
    [aux_sym_tabledata_permission_token2] = ACTIONS(881),
    [anon_sym_LBRACK] = ACTIONS(884),
    [aux_sym_record_type_token1] = ACTIONS(881),
    [aux_sym_basic_type_token21] = ACTIONS(881),
    [aux_sym_basic_type_token22] = ACTIONS(881),
    [aux_sym_basic_type_token48] = ACTIONS(881),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(519),
    [anon_sym_POUNDif] = ACTIONS(521),
    [anon_sym_POUNDIF] = ACTIONS(521),
    [anon_sym_POUNDIf] = ACTIONS(521),
    [anon_sym_not] = ACTIONS(887),
    [anon_sym_NOT] = ACTIONS(887),
    [anon_sym_Not] = ACTIONS(887),
    [anon_sym_POUNDelse] = ACTIONS(527),
    [anon_sym_POUNDELSE] = ACTIONS(527),
    [anon_sym_POUNDElse] = ACTIONS(527),
    [anon_sym_POUNDelse2] = ACTIONS(527),
    [anon_sym_POUNDELSE2] = ACTIONS(527),
    [anon_sym_POUNDElse2] = ACTIONS(527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(881),
    [aux_sym_keyword_identifier_token2] = ACTIONS(890),
    [anon_sym_PLUS] = ACTIONS(869),
    [sym_datetime_literal] = ACTIONS(893),
    [sym_date_literal] = ACTIONS(875),
    [sym_time_literal] = ACTIONS(875),
    [sym_biginteger_literal] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(535),
    [anon_sym_IF] = ACTIONS(535),
    [anon_sym_If] = ACTIONS(535),
    [anon_sym_case] = ACTIONS(538),
    [anon_sym_CASE] = ACTIONS(538),
    [anon_sym_Case] = ACTIONS(538),
    [anon_sym_for] = ACTIONS(541),
    [anon_sym_FOR] = ACTIONS(541),
    [anon_sym_For] = ACTIONS(541),
    [anon_sym_foreach] = ACTIONS(544),
    [anon_sym_FOREACH] = ACTIONS(544),
    [anon_sym_Foreach] = ACTIONS(544),
    [anon_sym_while] = ACTIONS(547),
    [anon_sym_WHILE] = ACTIONS(547),
    [anon_sym_While] = ACTIONS(547),
    [anon_sym_repeat] = ACTIONS(550),
    [anon_sym_REPEAT] = ACTIONS(550),
    [anon_sym_Repeat] = ACTIONS(550),
    [anon_sym_exit] = ACTIONS(896),
    [anon_sym_EXIT] = ACTIONS(896),
    [anon_sym_Exit] = ACTIONS(896),
    [anon_sym_continue] = ACTIONS(899),
    [anon_sym_CONTINUE] = ACTIONS(899),
    [anon_sym_Continue] = ACTIONS(899),
    [anon_sym_break] = ACTIONS(902),
    [anon_sym_BREAK] = ACTIONS(902),
    [anon_sym_Break] = ACTIONS(902),
    [anon_sym_with] = ACTIONS(562),
    [anon_sym_WITH] = ACTIONS(562),
    [anon_sym_With] = ACTIONS(562),
    [sym_asserterror_keyword] = ACTIONS(905),
    [sym_page_keyword] = ACTIONS(890),
    [anon_sym_codeunit] = ACTIONS(908),
    [anon_sym_CODEUNIT] = ACTIONS(908),
    [anon_sym_Codeunit] = ACTIONS(908),
    [anon_sym_CodeUnit] = ACTIONS(908),
    [anon_sym_COdeunit] = ACTIONS(908),
    [anon_sym_codeUnit] = ACTIONS(908),
    [sym_report_keyword] = ACTIONS(890),
    [sym_query_keyword] = ACTIONS(890),
    [anon_sym_xmlport] = ACTIONS(911),
    [anon_sym_XMLPORT] = ACTIONS(911),
    [anon_sym_Xmlport] = ACTIONS(911),
    [anon_sym_XMLport] = ACTIONS(911),
    [anon_sym_XMLPort] = ACTIONS(911),
    [anon_sym_XmlPort] = ACTIONS(911),
    [anon_sym_enum] = ACTIONS(914),
    [anon_sym_ENUM] = ACTIONS(914),
    [anon_sym_Enum] = ACTIONS(914),
    [anon_sym_eNUM] = ACTIONS(914),
    [anon_sym_eNum] = ACTIONS(914),
    [anon_sym_ENum] = ACTIONS(914),
    [sym_quoted_identifier] = ACTIONS(917),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(893),
    [sym_verbatim_string] = ACTIONS(893),
    [sym_integer] = ACTIONS(875),
    [sym_continue_as_identifier] = ACTIONS(893),
    [sym_preproc_open] = ACTIONS(521),
    [sym_end_keyword] = ACTIONS(527),
  },
  [STATE(274)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(15110),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(276),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(275)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3215),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(276)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(15012),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(277)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(15016),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(278),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(278)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(15223),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(279)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(15226),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(281),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(280)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(15255),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(281)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(15402),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(282)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3213),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(284),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(283)] = {
    [sym_boolean] = STATE(1933),
    [sym_option_member] = STATE(1931),
    [sym_keyword_identifier] = STATE(1933),
    [sym_codeunit_keyword] = STATE(1909),
    [sym_xmlport_keyword] = STATE(1909),
    [sym_enum_keyword] = STATE(1909),
    [sym_keyword_as_identifier] = STATE(1933),
    [sym_identifier] = ACTIONS(920),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(923),
    [aux_sym_boolean_token1] = ACTIONS(926),
    [aux_sym_boolean_token2] = ACTIONS(926),
    [sym_decimal] = ACTIONS(613),
    [anon_sym_LPAREN] = ACTIONS(611),
    [aux_sym_where_condition_token1] = ACTIONS(780),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(929),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(929),
    [aux_sym_basic_type_token21] = ACTIONS(929),
    [aux_sym_basic_type_token22] = ACTIONS(932),
    [aux_sym_basic_type_token48] = ACTIONS(929),
    [aux_sym_basic_type_token53] = ACTIONS(780),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(780),
    [aux_sym_separator_action_token1] = ACTIONS(780),
    [aux_sym_assembly_declaration_token1] = ACTIONS(780),
    [aux_sym_type_declaration_token1] = ACTIONS(780),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(613),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [anon_sym_not] = ACTIONS(613),
    [anon_sym_NOT] = ACTIONS(613),
    [anon_sym_Not] = ACTIONS(613),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(613),
    [aux_sym_keyword_identifier_token1] = ACTIONS(929),
    [aux_sym_keyword_identifier_token2] = ACTIONS(929),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [sym_datetime_literal] = ACTIONS(611),
    [sym_date_literal] = ACTIONS(613),
    [sym_time_literal] = ACTIONS(613),
    [sym_biginteger_literal] = ACTIONS(611),
    [anon_sym_if] = ACTIONS(613),
    [anon_sym_IF] = ACTIONS(613),
    [anon_sym_If] = ACTIONS(613),
    [anon_sym_else] = ACTIONS(613),
    [anon_sym_ELSE] = ACTIONS(613),
    [anon_sym_Else] = ACTIONS(613),
    [anon_sym_case] = ACTIONS(613),
    [anon_sym_CASE] = ACTIONS(613),
    [anon_sym_Case] = ACTIONS(613),
    [anon_sym_for] = ACTIONS(613),
    [anon_sym_FOR] = ACTIONS(613),
    [anon_sym_For] = ACTIONS(613),
    [anon_sym_foreach] = ACTIONS(613),
    [anon_sym_FOREACH] = ACTIONS(613),
    [anon_sym_Foreach] = ACTIONS(613),
    [anon_sym_while] = ACTIONS(613),
    [anon_sym_WHILE] = ACTIONS(613),
    [anon_sym_While] = ACTIONS(613),
    [anon_sym_repeat] = ACTIONS(613),
    [anon_sym_REPEAT] = ACTIONS(613),
    [anon_sym_Repeat] = ACTIONS(613),
    [anon_sym_until] = ACTIONS(613),
    [anon_sym_UNTIL] = ACTIONS(613),
    [anon_sym_Until] = ACTIONS(613),
    [anon_sym_exit] = ACTIONS(613),
    [anon_sym_EXIT] = ACTIONS(613),
    [anon_sym_Exit] = ACTIONS(613),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_CONTINUE] = ACTIONS(613),
    [anon_sym_Continue] = ACTIONS(613),
    [anon_sym_break] = ACTIONS(613),
    [anon_sym_BREAK] = ACTIONS(613),
    [anon_sym_Break] = ACTIONS(613),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_WITH] = ACTIONS(613),
    [anon_sym_With] = ACTIONS(613),
    [sym_asserterror_keyword] = ACTIONS(611),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(780),
    [sym_page_keyword] = ACTIONS(929),
    [anon_sym_codeunit] = ACTIONS(935),
    [anon_sym_CODEUNIT] = ACTIONS(935),
    [anon_sym_Codeunit] = ACTIONS(935),
    [anon_sym_CodeUnit] = ACTIONS(935),
    [anon_sym_COdeunit] = ACTIONS(935),
    [anon_sym_codeUnit] = ACTIONS(935),
    [sym_report_keyword] = ACTIONS(929),
    [sym_query_keyword] = ACTIONS(929),
    [anon_sym_xmlport] = ACTIONS(938),
    [anon_sym_XMLPORT] = ACTIONS(938),
    [anon_sym_Xmlport] = ACTIONS(938),
    [anon_sym_XMLport] = ACTIONS(938),
    [anon_sym_XMLPort] = ACTIONS(938),
    [anon_sym_XmlPort] = ACTIONS(938),
    [anon_sym_enum] = ACTIONS(941),
    [anon_sym_ENUM] = ACTIONS(941),
    [anon_sym_Enum] = ACTIONS(941),
    [anon_sym_eNUM] = ACTIONS(941),
    [anon_sym_eNum] = ACTIONS(941),
    [anon_sym_ENum] = ACTIONS(941),
    [sym_local_keyword] = ACTIONS(774),
    [sym_internal_keyword] = ACTIONS(774),
    [sym_protected_keyword] = ACTIONS(774),
    [sym_key_keyword] = ACTIONS(780),
    [sym_dataset_keyword] = ACTIONS(780),
    [sym_quoted_identifier] = ACTIONS(944),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(944),
    [sym_verbatim_string] = ACTIONS(611),
    [sym_integer] = ACTIONS(920),
    [sym_continue_as_identifier] = ACTIONS(611),
    [sym_preproc_open] = ACTIONS(611),
  },
  [STATE(284)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3357),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(285)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3372),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(286)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2514),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(256),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(287)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(3387),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(275),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(117),
    [anon_sym_POUNDENDIF] = ACTIONS(117),
    [anon_sym_POUNDEndif] = ACTIONS(117),
    [anon_sym_POUNDendif2] = ACTIONS(117),
    [anon_sym_POUNDENDIF2] = ACTIONS(117),
    [anon_sym_POUNDEndif2] = ACTIONS(117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(117),
  },
  [STATE(288)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2495),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(289),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(289)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2508),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(349),
    [anon_sym_POUNDENDIF] = ACTIONS(349),
    [anon_sym_POUNDEndif] = ACTIONS(349),
    [anon_sym_POUNDendif2] = ACTIONS(349),
    [anon_sym_POUNDENDIF2] = ACTIONS(349),
    [anon_sym_POUNDEndif2] = ACTIONS(349),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(349),
  },
  [STATE(290)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_endif] = STATE(2886),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2723),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(291)] = {
    [sym_boolean] = STATE(2033),
    [sym_option_member] = STATE(1955),
    [sym_keyword_identifier] = STATE(2033),
    [sym_codeunit_keyword] = STATE(1978),
    [sym_xmlport_keyword] = STATE(1978),
    [sym_enum_keyword] = STATE(1978),
    [sym_keyword_as_identifier] = STATE(2033),
    [aux_sym_option_member_list_repeat2] = STATE(1661),
    [sym_identifier] = ACTIONS(851),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(947),
    [anon_sym_DASH] = ACTIONS(855),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [aux_sym_where_condition_token1] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(859),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_basic_type_token53] = ACTIONS(857),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(857),
    [aux_sym_separator_action_token1] = ACTIONS(857),
    [aux_sym_assembly_declaration_token1] = ACTIONS(857),
    [aux_sym_type_declaration_token1] = ACTIONS(857),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(602),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(681),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(602),
    [anon_sym_IF] = ACTIONS(602),
    [anon_sym_If] = ACTIONS(602),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_case] = ACTIONS(602),
    [anon_sym_CASE] = ACTIONS(602),
    [anon_sym_Case] = ACTIONS(602),
    [anon_sym_for] = ACTIONS(602),
    [anon_sym_FOR] = ACTIONS(602),
    [anon_sym_For] = ACTIONS(602),
    [anon_sym_foreach] = ACTIONS(602),
    [anon_sym_FOREACH] = ACTIONS(602),
    [anon_sym_Foreach] = ACTIONS(602),
    [anon_sym_while] = ACTIONS(602),
    [anon_sym_WHILE] = ACTIONS(602),
    [anon_sym_While] = ACTIONS(602),
    [anon_sym_repeat] = ACTIONS(602),
    [anon_sym_REPEAT] = ACTIONS(602),
    [anon_sym_Repeat] = ACTIONS(602),
    [anon_sym_exit] = ACTIONS(602),
    [anon_sym_EXIT] = ACTIONS(602),
    [anon_sym_Exit] = ACTIONS(602),
    [anon_sym_continue] = ACTIONS(602),
    [anon_sym_CONTINUE] = ACTIONS(602),
    [anon_sym_Continue] = ACTIONS(602),
    [anon_sym_break] = ACTIONS(602),
    [anon_sym_BREAK] = ACTIONS(602),
    [anon_sym_Break] = ACTIONS(602),
    [anon_sym_with] = ACTIONS(602),
    [anon_sym_WITH] = ACTIONS(602),
    [anon_sym_With] = ACTIONS(602),
    [sym_asserterror_keyword] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(857),
    [sym_page_keyword] = ACTIONS(681),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(681),
    [sym_query_keyword] = ACTIONS(681),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_local_keyword] = ACTIONS(851),
    [sym_internal_keyword] = ACTIONS(851),
    [sym_protected_keyword] = ACTIONS(851),
    [sym_key_keyword] = ACTIONS(857),
    [sym_dataset_keyword] = ACTIONS(857),
    [sym_quoted_identifier] = ACTIONS(861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(861),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(851),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
    [sym_end_keyword] = ACTIONS(600),
  },
  [STATE(292)] = {
    [sym_boolean] = STATE(2033),
    [sym_option_member] = STATE(2036),
    [sym_keyword_identifier] = STATE(2033),
    [sym_codeunit_keyword] = STATE(1978),
    [sym_xmlport_keyword] = STATE(1978),
    [sym_enum_keyword] = STATE(1978),
    [sym_keyword_as_identifier] = STATE(2033),
    [sym_identifier] = ACTIONS(949),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(952),
    [aux_sym_boolean_token1] = ACTIONS(955),
    [aux_sym_boolean_token2] = ACTIONS(955),
    [sym_decimal] = ACTIONS(613),
    [anon_sym_LPAREN] = ACTIONS(611),
    [aux_sym_where_condition_token1] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(958),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(958),
    [aux_sym_basic_type_token21] = ACTIONS(958),
    [aux_sym_basic_type_token22] = ACTIONS(961),
    [aux_sym_basic_type_token48] = ACTIONS(958),
    [aux_sym_basic_type_token53] = ACTIONS(857),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(857),
    [aux_sym_separator_action_token1] = ACTIONS(857),
    [aux_sym_assembly_declaration_token1] = ACTIONS(857),
    [aux_sym_type_declaration_token1] = ACTIONS(857),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(613),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [anon_sym_not] = ACTIONS(613),
    [anon_sym_NOT] = ACTIONS(613),
    [anon_sym_Not] = ACTIONS(613),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(613),
    [aux_sym_keyword_identifier_token1] = ACTIONS(958),
    [aux_sym_keyword_identifier_token2] = ACTIONS(958),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [sym_datetime_literal] = ACTIONS(611),
    [sym_date_literal] = ACTIONS(613),
    [sym_time_literal] = ACTIONS(613),
    [sym_biginteger_literal] = ACTIONS(611),
    [anon_sym_if] = ACTIONS(613),
    [anon_sym_IF] = ACTIONS(613),
    [anon_sym_If] = ACTIONS(613),
    [anon_sym_else] = ACTIONS(613),
    [anon_sym_ELSE] = ACTIONS(613),
    [anon_sym_Else] = ACTIONS(613),
    [anon_sym_case] = ACTIONS(613),
    [anon_sym_CASE] = ACTIONS(613),
    [anon_sym_Case] = ACTIONS(613),
    [anon_sym_for] = ACTIONS(613),
    [anon_sym_FOR] = ACTIONS(613),
    [anon_sym_For] = ACTIONS(613),
    [anon_sym_foreach] = ACTIONS(613),
    [anon_sym_FOREACH] = ACTIONS(613),
    [anon_sym_Foreach] = ACTIONS(613),
    [anon_sym_while] = ACTIONS(613),
    [anon_sym_WHILE] = ACTIONS(613),
    [anon_sym_While] = ACTIONS(613),
    [anon_sym_repeat] = ACTIONS(613),
    [anon_sym_REPEAT] = ACTIONS(613),
    [anon_sym_Repeat] = ACTIONS(613),
    [anon_sym_exit] = ACTIONS(613),
    [anon_sym_EXIT] = ACTIONS(613),
    [anon_sym_Exit] = ACTIONS(613),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_CONTINUE] = ACTIONS(613),
    [anon_sym_Continue] = ACTIONS(613),
    [anon_sym_break] = ACTIONS(613),
    [anon_sym_BREAK] = ACTIONS(613),
    [anon_sym_Break] = ACTIONS(613),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_WITH] = ACTIONS(613),
    [anon_sym_With] = ACTIONS(613),
    [sym_asserterror_keyword] = ACTIONS(611),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(857),
    [sym_page_keyword] = ACTIONS(958),
    [anon_sym_codeunit] = ACTIONS(964),
    [anon_sym_CODEUNIT] = ACTIONS(964),
    [anon_sym_Codeunit] = ACTIONS(964),
    [anon_sym_CodeUnit] = ACTIONS(964),
    [anon_sym_COdeunit] = ACTIONS(964),
    [anon_sym_codeUnit] = ACTIONS(964),
    [sym_report_keyword] = ACTIONS(958),
    [sym_query_keyword] = ACTIONS(958),
    [anon_sym_xmlport] = ACTIONS(967),
    [anon_sym_XMLPORT] = ACTIONS(967),
    [anon_sym_Xmlport] = ACTIONS(967),
    [anon_sym_XMLport] = ACTIONS(967),
    [anon_sym_XMLPort] = ACTIONS(967),
    [anon_sym_XmlPort] = ACTIONS(967),
    [anon_sym_enum] = ACTIONS(970),
    [anon_sym_ENUM] = ACTIONS(970),
    [anon_sym_Enum] = ACTIONS(970),
    [anon_sym_eNUM] = ACTIONS(970),
    [anon_sym_eNum] = ACTIONS(970),
    [anon_sym_ENum] = ACTIONS(970),
    [sym_local_keyword] = ACTIONS(851),
    [sym_internal_keyword] = ACTIONS(851),
    [sym_protected_keyword] = ACTIONS(851),
    [sym_key_keyword] = ACTIONS(857),
    [sym_dataset_keyword] = ACTIONS(857),
    [sym_quoted_identifier] = ACTIONS(973),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(973),
    [sym_verbatim_string] = ACTIONS(611),
    [sym_integer] = ACTIONS(949),
    [sym_continue_as_identifier] = ACTIONS(611),
    [sym_preproc_open] = ACTIONS(611),
    [sym_end_keyword] = ACTIONS(611),
  },
  [STATE(293)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4437),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(304),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(294)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4583),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(301),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(295)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4774),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(303),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(296)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4473),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(299),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(297)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(17413),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(808),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(980),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(298)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4564),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(299)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4478),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(300)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4560),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(298),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(301)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4585),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(302)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4606),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(303)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4508),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(304)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4487),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(305)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_until_keyword] = STATE(4605),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(302),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_until] = ACTIONS(976),
    [anon_sym_UNTIL] = ACTIONS(976),
    [anon_sym_Until] = ACTIONS(976),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(306)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(54),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(6194),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(984),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(986),
  },
  [STATE(307)] = {
    [sym_preproc_conditional_object] = STATE(1730),
    [sym_namespace_declaration] = STATE(1729),
    [sym_using_statement] = STATE(1730),
    [sym__object] = STATE(1730),
    [sym_preproc_split_declaration] = STATE(1730),
    [sym__object_header] = STATE(10925),
    [sym_table_declaration] = STATE(1730),
    [sym_page_declaration] = STATE(1730),
    [sym_report_declaration] = STATE(1730),
    [sym_query_declaration] = STATE(1730),
    [sym_xmlport_declaration] = STATE(1730),
    [sym_permissionset_declaration] = STATE(1730),
    [sym_codeunit_declaration] = STATE(1730),
    [sym_enum_declaration] = STATE(1730),
    [sym_tableextension_declaration] = STATE(1730),
    [sym_pageextension_declaration] = STATE(1730),
    [sym_reportextension_declaration] = STATE(1730),
    [sym_enumextension_declaration] = STATE(1730),
    [sym_permissionsetextension_declaration] = STATE(1730),
    [sym_controladdin_declaration] = STATE(1730),
    [sym_profile_declaration] = STATE(1730),
    [sym_entitlement_declaration] = STATE(1730),
    [sym_profileextension_declaration] = STATE(1730),
    [sym_interface_declaration] = STATE(1730),
    [sym_pagecustomization_declaration] = STATE(1730),
    [sym_dotnet_declaration] = STATE(1730),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elif] = STATE(1770),
    [sym_preproc_else] = STATE(1900),
    [sym_preproc_endif] = STATE(3731),
    [sym_tableextension_keyword] = STATE(17213),
    [sym_pageextension_keyword] = STATE(18121),
    [sym_codeunit_keyword] = STATE(18138),
    [sym_reportextension_keyword] = STATE(18073),
    [sym_xmlport_keyword] = STATE(16789),
    [sym_enum_keyword] = STATE(16746),
    [sym_enumextension_keyword] = STATE(16871),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17393),
    [sym_permissionsetextension_keyword] = STATE(17463),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1730),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(10782),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(988),
    [anon_sym_POUNDELIF] = ACTIONS(988),
    [anon_sym_POUNDElif] = ACTIONS(988),
    [anon_sym_POUNDelse] = ACTIONS(990),
    [anon_sym_POUNDELSE] = ACTIONS(990),
    [anon_sym_POUNDElse] = ACTIONS(990),
    [anon_sym_POUNDelse2] = ACTIONS(990),
    [anon_sym_POUNDELSE2] = ACTIONS(990),
    [anon_sym_POUNDElse2] = ACTIONS(990),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(994),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(996),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(998),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(1000),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(1002),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(308)] = {
    [sym_preproc_conditional_object] = STATE(1768),
    [sym_namespace_declaration] = STATE(1767),
    [sym_using_statement] = STATE(1768),
    [sym__object] = STATE(1768),
    [sym_preproc_split_declaration] = STATE(1768),
    [sym__object_header] = STATE(10845),
    [sym_table_declaration] = STATE(1768),
    [sym_page_declaration] = STATE(1768),
    [sym_report_declaration] = STATE(1768),
    [sym_query_declaration] = STATE(1768),
    [sym_xmlport_declaration] = STATE(1768),
    [sym_permissionset_declaration] = STATE(1768),
    [sym_codeunit_declaration] = STATE(1768),
    [sym_enum_declaration] = STATE(1768),
    [sym_tableextension_declaration] = STATE(1768),
    [sym_pageextension_declaration] = STATE(1768),
    [sym_reportextension_declaration] = STATE(1768),
    [sym_enumextension_declaration] = STATE(1768),
    [sym_permissionsetextension_declaration] = STATE(1768),
    [sym_controladdin_declaration] = STATE(1768),
    [sym_profile_declaration] = STATE(1768),
    [sym_entitlement_declaration] = STATE(1768),
    [sym_profileextension_declaration] = STATE(1768),
    [sym_interface_declaration] = STATE(1768),
    [sym_pagecustomization_declaration] = STATE(1768),
    [sym_dotnet_declaration] = STATE(1768),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elif] = STATE(1770),
    [sym_preproc_else] = STATE(1922),
    [sym_preproc_endif] = STATE(2857),
    [sym_tableextension_keyword] = STATE(17213),
    [sym_pageextension_keyword] = STATE(18121),
    [sym_codeunit_keyword] = STATE(18138),
    [sym_reportextension_keyword] = STATE(18073),
    [sym_xmlport_keyword] = STATE(16789),
    [sym_enum_keyword] = STATE(16746),
    [sym_enumextension_keyword] = STATE(16871),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17393),
    [sym_permissionsetextension_keyword] = STATE(17463),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1768),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(10764),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(988),
    [anon_sym_POUNDELIF] = ACTIONS(988),
    [anon_sym_POUNDElif] = ACTIONS(988),
    [anon_sym_POUNDelse] = ACTIONS(990),
    [anon_sym_POUNDELSE] = ACTIONS(990),
    [anon_sym_POUNDElse] = ACTIONS(990),
    [anon_sym_POUNDelse2] = ACTIONS(990),
    [anon_sym_POUNDELSE2] = ACTIONS(990),
    [anon_sym_POUNDElse2] = ACTIONS(990),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(994),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(996),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(998),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(1000),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(1002),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(309)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(91),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(5728),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(310),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1014),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1016),
  },
  [STATE(310)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(91),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(5581),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1018),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1020),
  },
  [STATE(311)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2374),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2361),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1022),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(1024),
  },
  [STATE(312)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6614),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6615),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6607),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(313)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6616),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6580),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6526),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(314)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6595),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6531),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6533),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(315)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6555),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6550),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6590),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(316)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6553),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6558),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6606),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(317)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4365),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4407),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4416),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(318)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4396),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4426),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4362),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(319)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4428),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4431),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4406),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(320)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4318),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4323),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4372),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(321)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4374),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4349),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4351),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(322)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4381),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4387),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4411),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(323)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4418),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4375),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4332),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(324)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4333),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4334),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4336),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(325)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4337),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4339),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4340),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(326)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4320),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4321),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4322),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(327)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4324),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4325),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4327),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(328)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4328),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4329),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4331),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(329)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4366),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4367),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym__if_statement_no_else] = STATE(4370),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4802),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(330)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(92),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(4240),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(331),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1026),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1028),
  },
  [STATE(331)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(92),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(4245),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1030),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1032),
  },
  [STATE(332)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(333)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6560),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6562),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6603),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(334)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6530),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6536),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6537),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(335)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6538),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6539),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6543),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(336)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6556),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6574),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6575),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(337)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6576),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6527),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6528),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(338)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(93),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(4004),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(339),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1034),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1036),
  },
  [STATE(339)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(93),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(4016),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1038),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1040),
  },
  [STATE(340)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6591),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6596),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6600),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(341)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(94),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(3403),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(342),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1042),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1044),
  },
  [STATE(342)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(94),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(3173),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1046),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1048),
  },
  [STATE(343)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(95),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(10501),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(344),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1050),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1052),
  },
  [STATE(344)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(95),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(10513),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1054),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1056),
  },
  [STATE(345)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6547),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6573),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6599),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(346)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6605),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6612),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6613),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(347)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2555),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(348),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(685),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(711),
  },
  [STATE(348)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(2559),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1058),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1060),
  },
  [STATE(349)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(97),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(3105),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(350),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1062),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1064),
  },
  [STATE(350)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(97),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(3109),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1066),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1068),
  },
  [STATE(351)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(98),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(9752),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(352),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1070),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1072),
  },
  [STATE(352)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(98),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(9756),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1074),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1076),
  },
  [STATE(353)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(99),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(8958),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(354),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1078),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1080),
  },
  [STATE(354)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(99),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(9141),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1082),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1084),
  },
  [STATE(355)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(100),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(11113),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(356),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1086),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1088),
  },
  [STATE(356)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(100),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(11049),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1090),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1092),
  },
  [STATE(357)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(101),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(14859),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(404),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1094),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1096),
  },
  [STATE(358)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(107),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(4245),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1030),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1032),
  },
  [STATE(359)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(102),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(11544),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(360),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1098),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1100),
  },
  [STATE(360)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(102),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(11558),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1102),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1104),
  },
  [STATE(361)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(104),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(9399),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(362),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1106),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1108),
  },
  [STATE(362)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(104),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(9407),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1110),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1112),
  },
  [STATE(363)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(105),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(11180),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(364),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1114),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1116),
  },
  [STATE(364)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(105),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(11159),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1118),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1120),
  },
  [STATE(365)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(106),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(7479),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(366),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1122),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1124),
  },
  [STATE(366)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(106),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(7483),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1126),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1128),
  },
  [STATE(367)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(108),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(8163),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(368),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1130),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1132),
  },
  [STATE(368)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(108),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(8167),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1134),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1136),
  },
  [STATE(369)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(109),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(7504),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(370),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1138),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1140),
  },
  [STATE(370)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(109),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(7508),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1142),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1144),
  },
  [STATE(371)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(3),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(5897),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(372),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1146),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1148),
  },
  [STATE(372)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(3),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(5921),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1150),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1152),
  },
  [STATE(373)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6569),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6540),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6541),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(374)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6577),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6578),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6579),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(375)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6581),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6582),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6583),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(376)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6586),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6588),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6589),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(377)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6601),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6602),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6604),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(378)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6611),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6532),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6542),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(379)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6563),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6598),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6552),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(380)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6594),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6592),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6521),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(381)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6524),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6525),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6529),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(382)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6545),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6554),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6557),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(383)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6564),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6566),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6567),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4608),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(384)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2374),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2361),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1154),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(1156),
  },
  [STATE(385)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6545),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6554),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6557),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(386)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6614),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6615),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6607),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(387)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6555),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6550),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6590),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(388)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6553),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6558),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6606),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(389)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6560),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6562),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6603),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(390)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6538),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6539),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6543),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(391)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6556),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6574),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6575),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(392)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6576),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6527),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6528),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(393)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6547),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6573),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6599),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(394)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6605),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6612),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6613),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(395)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6569),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6540),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6541),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(396)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6601),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6602),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6604),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(397)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2374),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2361),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1158),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(1160),
  },
  [STATE(398)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2374),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2361),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1162),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
    [sym_preproc_split_begin] = ACTIONS(1164),
  },
  [STATE(399)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6584),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6585),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym__if_statement_no_else] = STATE(6587),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4805),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(400)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(54),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(6267),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(306),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1166),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1168),
  },
  [STATE(401)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(103),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(6194),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(984),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(986),
  },
  [STATE(402)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(103),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(6267),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(401),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1166),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1168),
  },
  [STATE(403)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(107),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(4240),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(358),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1026),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1028),
  },
  [STATE(404)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(101),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_split_code_block_end] = STATE(14866),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1170),
    [anon_sym_POUNDif] = ACTIONS(687),
    [anon_sym_POUNDIF] = ACTIONS(687),
    [anon_sym_POUNDIf] = ACTIONS(687),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(687),
    [sym_end_keyword] = ACTIONS(1172),
  },
  [STATE(405)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3008),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3009),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(406)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2592),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2593),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2594),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(407)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2602),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2603),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(408)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2607),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2608),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(409)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2612),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2613),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(410)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2614),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2615),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(411)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2616),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2617),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2618),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(412)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2619),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2620),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2621),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(413)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2627),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2628),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(414)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2629),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2630),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(415)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2420),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2421),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(416)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2422),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2423),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(417)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2424),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2425),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(418)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2426),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2427),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(419)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2444),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2445),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(420)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2446),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2447),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(421)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2448),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2449),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(422)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2450),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2451),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(423)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1174),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1176),
  },
  [STATE(424)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1178),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1180),
  },
  [STATE(425)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3164),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3166),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(426)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3172),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3389),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3281),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(427)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3309),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3312),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3340),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(428)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(442),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1186),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1188),
  },
  [STATE(429)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3250),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3311),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(430)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1190),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1192),
  },
  [STATE(431)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1194),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1196),
  },
  [STATE(432)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(589),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1198),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1200),
  },
  [STATE(433)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(473),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1202),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1204),
  },
  [STATE(434)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(436),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1206),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1208),
  },
  [STATE(435)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6099),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6100),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(436)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1210),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1212),
  },
  [STATE(437)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(443),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1214),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1216),
  },
  [STATE(438)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(444),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1218),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1220),
  },
  [STATE(439)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(446),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1222),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1224),
  },
  [STATE(440)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(48),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(452),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1226),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1228),
  },
  [STATE(441)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1230),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1232),
  },
  [STATE(442)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1234),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1236),
  },
  [STATE(443)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1238),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1240),
  },
  [STATE(444)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1242),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1244),
  },
  [STATE(445)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(454),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1246),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1248),
  },
  [STATE(446)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1250),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1252),
  },
  [STATE(447)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(455),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1254),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1256),
  },
  [STATE(448)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(456),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1258),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1260),
  },
  [STATE(449)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(458),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1262),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1264),
  },
  [STATE(450)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(459),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1266),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1268),
  },
  [STATE(451)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(461),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1270),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1272),
  },
  [STATE(452)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(49),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1274),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1276),
  },
  [STATE(453)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(50),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(464),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1278),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1280),
  },
  [STATE(454)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1282),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1284),
  },
  [STATE(455)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1286),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1288),
  },
  [STATE(456)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1290),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1292),
  },
  [STATE(457)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(466),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1294),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1296),
  },
  [STATE(458)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1298),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1300),
  },
  [STATE(459)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1302),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1304),
  },
  [STATE(460)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(467),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1306),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1308),
  },
  [STATE(461)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1310),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1312),
  },
  [STATE(462)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(468),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1314),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1316),
  },
  [STATE(463)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(469),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1318),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1320),
  },
  [STATE(464)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(52),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1322),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1324),
  },
  [STATE(465)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6488),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6489),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(466)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1326),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1328),
  },
  [STATE(467)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1330),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1332),
  },
  [STATE(468)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1334),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1336),
  },
  [STATE(469)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1338),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1340),
  },
  [STATE(470)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(471),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1342),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1344),
  },
  [STATE(471)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1346),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1348),
  },
  [STATE(472)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(520),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1350),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1352),
  },
  [STATE(473)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1354),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1356),
  },
  [STATE(474)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1358),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1360),
  },
  [STATE(475)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(590),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1362),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1364),
  },
  [STATE(476)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(595),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1366),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1368),
  },
  [STATE(477)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3169),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3170),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(478)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15229),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15230),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(479)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15231),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15232),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(480)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15234),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15235),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(481)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3280),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3306),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3307),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(482)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3308),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3310),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3314),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(483)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(485),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1406),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1408),
  },
  [STATE(484)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(4),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(608),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1410),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1412),
  },
  [STATE(485)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1414),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1416),
  },
  [STATE(486)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(492),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1418),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1420),
  },
  [STATE(487)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(493),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1422),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1424),
  },
  [STATE(488)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(495),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1426),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1428),
  },
  [STATE(489)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(69),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(501),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1430),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1432),
  },
  [STATE(490)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(557),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1434),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1436),
  },
  [STATE(491)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3171),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3147),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(492)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1438),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1440),
  },
  [STATE(493)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1442),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1444),
  },
  [STATE(494)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(503),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1446),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1448),
  },
  [STATE(495)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1450),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1452),
  },
  [STATE(496)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(504),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1454),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1456),
  },
  [STATE(497)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(505),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1458),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1460),
  },
  [STATE(498)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(507),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1462),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1464),
  },
  [STATE(499)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(508),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1466),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1468),
  },
  [STATE(500)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(510),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1470),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1472),
  },
  [STATE(501)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(70),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1474),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1476),
  },
  [STATE(502)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(71),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(513),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1478),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1480),
  },
  [STATE(503)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1482),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1484),
  },
  [STATE(504)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1486),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1488),
  },
  [STATE(505)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1490),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1492),
  },
  [STATE(506)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(514),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1494),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1496),
  },
  [STATE(507)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1498),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1500),
  },
  [STATE(508)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1502),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1504),
  },
  [STATE(509)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(515),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1506),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1508),
  },
  [STATE(510)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1510),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1512),
  },
  [STATE(511)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(516),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1514),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1516),
  },
  [STATE(512)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(517),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1518),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1520),
  },
  [STATE(513)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(73),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1522),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1524),
  },
  [STATE(514)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1526),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1528),
  },
  [STATE(515)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1530),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1532),
  },
  [STATE(516)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1534),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1536),
  },
  [STATE(517)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1538),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1540),
  },
  [STATE(518)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(519),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1542),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1544),
  },
  [STATE(519)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1546),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1548),
  },
  [STATE(520)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1550),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1552),
  },
  [STATE(521)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(559),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1554),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1556),
  },
  [STATE(522)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(523),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1558),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1560),
  },
  [STATE(523)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1562),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1564),
  },
  [STATE(524)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(529),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1566),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1568),
  },
  [STATE(525)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(530),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1570),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1572),
  },
  [STATE(526)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(532),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1574),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1576),
  },
  [STATE(527)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3278),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3288),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(528)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3302),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3303),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(529)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1578),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1580),
  },
  [STATE(530)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1582),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1584),
  },
  [STATE(531)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(538),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1586),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1588),
  },
  [STATE(532)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1590),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1592),
  },
  [STATE(533)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(539),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1594),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1596),
  },
  [STATE(534)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(540),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1598),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1600),
  },
  [STATE(535)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(542),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1602),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1604),
  },
  [STATE(536)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(543),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1606),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1608),
  },
  [STATE(537)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(545),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1610),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1612),
  },
  [STATE(538)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1614),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1616),
  },
  [STATE(539)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1618),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1620),
  },
  [STATE(540)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1622),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1624),
  },
  [STATE(541)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(548),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1626),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1628),
  },
  [STATE(542)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1630),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1632),
  },
  [STATE(543)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1634),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1636),
  },
  [STATE(544)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(549),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1638),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1640),
  },
  [STATE(545)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1642),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1644),
  },
  [STATE(546)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(550),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1646),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1648),
  },
  [STATE(547)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(551),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1650),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1652),
  },
  [STATE(548)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1654),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1656),
  },
  [STATE(549)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1658),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1660),
  },
  [STATE(550)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1662),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1664),
  },
  [STATE(551)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1666),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1668),
  },
  [STATE(552)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(553),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1670),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1672),
  },
  [STATE(553)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1674),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1676),
  },
  [STATE(554)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(560),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1678),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1680),
  },
  [STATE(555)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(562),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1682),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1684),
  },
  [STATE(556)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(26),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(568),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1686),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1688),
  },
  [STATE(557)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1690),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1692),
  },
  [STATE(558)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(474),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1694),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1696),
  },
  [STATE(559)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1698),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1700),
  },
  [STATE(560)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1702),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1704),
  },
  [STATE(561)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(571),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1706),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1708),
  },
  [STATE(562)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1710),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1712),
  },
  [STATE(563)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(572),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1714),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1716),
  },
  [STATE(564)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(573),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1718),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1720),
  },
  [STATE(565)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(575),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1722),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1724),
  },
  [STATE(566)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(576),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1726),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1728),
  },
  [STATE(567)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(578),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1730),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1732),
  },
  [STATE(568)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(27),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1734),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1736),
  },
  [STATE(569)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(28),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(581),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1738),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1740),
  },
  [STATE(570)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3244),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3226),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3227),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(571)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1742),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1744),
  },
  [STATE(572)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1746),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1748),
  },
  [STATE(573)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1750),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1752),
  },
  [STATE(574)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(592),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1754),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1756),
  },
  [STATE(575)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1758),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1760),
  },
  [STATE(576)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1762),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1764),
  },
  [STATE(577)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(594),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1766),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1768),
  },
  [STATE(578)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1770),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1772),
  },
  [STATE(579)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(597),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1774),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1776),
  },
  [STATE(580)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(603),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1778),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1780),
  },
  [STATE(581)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(30),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1782),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1784),
  },
  [STATE(582)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3228),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3239),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3240),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(583)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3220),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3223),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3225),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(584)] = {
    [aux_sym_option_member_list_repeat2] = STATE(584),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_EQ] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1786),
    [anon_sym_DASH] = ACTIONS(836),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [sym_decimal] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(838),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(838),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [anon_sym_not] = ACTIONS(836),
    [anon_sym_NOT] = ACTIONS(836),
    [anon_sym_Not] = ACTIONS(836),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(838),
    [aux_sym__expression_token1] = ACTIONS(838),
    [aux_sym__expression_token2] = ACTIONS(836),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_div] = ACTIONS(836),
    [anon_sym_DIV] = ACTIONS(836),
    [anon_sym_Div] = ACTIONS(836),
    [anon_sym_mod] = ACTIONS(836),
    [anon_sym_MOD] = ACTIONS(836),
    [anon_sym_Mod] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_LT_GT] = ACTIONS(838),
    [anon_sym_and] = ACTIONS(836),
    [anon_sym_AND] = ACTIONS(836),
    [anon_sym_And] = ACTIONS(836),
    [anon_sym_or] = ACTIONS(836),
    [anon_sym_OR] = ACTIONS(836),
    [anon_sym_Or] = ACTIONS(836),
    [anon_sym_xor] = ACTIONS(836),
    [anon_sym_XOR] = ACTIONS(836),
    [anon_sym_Xor] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(838),
    [sym_datetime_literal] = ACTIONS(838),
    [sym_date_literal] = ACTIONS(836),
    [sym_time_literal] = ACTIONS(836),
    [sym_biginteger_literal] = ACTIONS(838),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_IF] = ACTIONS(836),
    [anon_sym_If] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_ELSE] = ACTIONS(836),
    [anon_sym_Else] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_CASE] = ACTIONS(836),
    [anon_sym_Case] = ACTIONS(836),
    [anon_sym_for] = ACTIONS(836),
    [anon_sym_FOR] = ACTIONS(836),
    [anon_sym_For] = ACTIONS(836),
    [anon_sym_foreach] = ACTIONS(836),
    [anon_sym_FOREACH] = ACTIONS(836),
    [anon_sym_Foreach] = ACTIONS(836),
    [anon_sym_while] = ACTIONS(836),
    [anon_sym_WHILE] = ACTIONS(836),
    [anon_sym_While] = ACTIONS(836),
    [anon_sym_repeat] = ACTIONS(836),
    [anon_sym_REPEAT] = ACTIONS(836),
    [anon_sym_Repeat] = ACTIONS(836),
    [anon_sym_until] = ACTIONS(836),
    [anon_sym_UNTIL] = ACTIONS(836),
    [anon_sym_Until] = ACTIONS(836),
    [anon_sym_exit] = ACTIONS(836),
    [anon_sym_EXIT] = ACTIONS(836),
    [anon_sym_Exit] = ACTIONS(836),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_CONTINUE] = ACTIONS(836),
    [anon_sym_Continue] = ACTIONS(836),
    [anon_sym_break] = ACTIONS(836),
    [anon_sym_BREAK] = ACTIONS(836),
    [anon_sym_Break] = ACTIONS(836),
    [anon_sym_with] = ACTIONS(836),
    [anon_sym_WITH] = ACTIONS(836),
    [anon_sym_With] = ACTIONS(836),
    [sym_asserterror_keyword] = ACTIONS(838),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_IN] = ACTIONS(836),
    [anon_sym_In] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_verbatim_string] = ACTIONS(838),
    [sym_integer] = ACTIONS(836),
    [sym_continue_as_identifier] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
  },
  [STATE(585)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3390),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3224),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(586)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(431),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1789),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1791),
  },
  [STATE(587)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15292),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15293),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(588)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15294),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15295),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(589)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1793),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1795),
  },
  [STATE(590)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1797),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1799),
  },
  [STATE(591)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4111),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4112),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(592)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1801),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1803),
  },
  [STATE(593)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(627),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1805),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1807),
  },
  [STATE(594)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1809),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1811),
  },
  [STATE(595)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1813),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1815),
  },
  [STATE(596)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(634),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1817),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1819),
  },
  [STATE(597)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1821),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1823),
  },
  [STATE(598)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(640),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1825),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1827),
  },
  [STATE(599)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(423),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1829),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1831),
  },
  [STATE(600)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(424),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1833),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1835),
  },
  [STATE(601)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(430),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1837),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1839),
  },
  [STATE(602)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3259),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3270),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3279),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(603)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1841),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1843),
  },
  [STATE(604)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(697),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1845),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1847),
  },
  [STATE(605)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15076),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15078),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(606)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3326),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3327),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3329),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(607)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3162),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3163),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(608)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(5),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1849),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1851),
  },
  [STATE(609)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3209),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3221),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(610)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3255),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3256),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(611)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3257),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3258),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(612)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3269),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3272),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(613)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3273),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3275),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(614)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3253),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3261),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(615)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(6),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(701),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1853),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1855),
  },
  [STATE(616)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3155),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3156),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(617)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3260),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3262),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(618)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15109),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15114),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(619)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3321),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3322),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(620)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3323),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3324),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(621)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3328),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3332),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(622)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3333),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3337),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(623)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15115),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15116),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(624)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3217),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3218),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3219),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(625)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15074),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15075),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(626)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3211),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3222),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(627)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1857),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1859),
  },
  [STATE(628)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2367),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2360),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(629)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2512),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2513),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(630)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2868),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2869),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(631)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2520),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2521),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(632)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2524),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2525),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(633)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2370),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2358),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(634)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1861),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1863),
  },
  [STATE(635)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2356),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2371),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(636)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2534),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2535),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2536),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(637)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2537),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2538),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2539),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(638)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2898),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2899),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2900),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(639)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2901),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2902),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2903),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(640)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1865),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1867),
  },
  [STATE(641)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2551),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2552),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(642)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2375),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2357),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(643)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2553),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2560),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2578),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(644)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2579),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2580),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2581),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(645)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2589),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2590),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2591),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(646)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2592),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2593),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2594),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(647)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2602),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2603),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(648)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2607),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2608),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(649)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2612),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2613),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(650)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2614),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2615),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(651)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2616),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2617),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2618),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(652)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2619),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2620),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2621),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(653)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2627),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2628),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(654)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2629),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2630),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(655)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2420),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2421),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(656)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2422),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2423),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(657)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2424),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2425),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(658)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2426),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2427),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(659)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2444),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2445),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(660)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2446),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2447),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(661)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2448),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2449),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(662)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2450),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2451),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(663)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(441),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1869),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1871),
  },
  [STATE(664)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2776),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2777),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(665)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3133),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3134),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(666)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2374),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2361),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(667)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2878),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2879),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(668)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2881),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2882),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(669)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2787),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2788),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(670)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2789),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2790),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(671)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2889),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2890),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2891),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(672)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2892),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2893),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2894),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(673)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2543),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2544),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2545),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(674)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(1805),
    [sym_code_block] = STATE(2546),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2547),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(1805),
    [sym_if_statement] = STATE(2548),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(1805),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1805),
    [sym_multiplicative_expression] = STATE(1805),
    [sym_additive_expression] = STATE(1805),
    [sym_comparison_expression] = STATE(1805),
    [sym_logical_expression] = STATE(1805),
    [sym_ternary_expression] = STATE(1805),
    [sym_unary_expression] = STATE(1805),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1805),
    [sym_list_literal] = STATE(1805),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1805),
    [sym__literal_value] = STATE(1805),
    [sym_if_keyword] = STATE(4692),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4846),
    [sym_foreach_keyword] = STATE(16489),
    [sym_while_keyword] = STATE(4648),
    [sym_repeat_keyword] = STATE(296),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4649),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(85),
    [sym_date_literal] = ACTIONS(63),
    [sym_time_literal] = ACTIONS(63),
    [sym_biginteger_literal] = ACTIONS(85),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(107),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(85),
    [sym_verbatim_string] = ACTIONS(85),
    [sym_integer] = ACTIONS(63),
    [sym_continue_as_identifier] = ACTIONS(85),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(675)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2906),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2907),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(676)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2791),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2792),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(677)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2908),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2909),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2910),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(678)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2911),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2912),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2913),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(679)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2921),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2922),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2923),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(680)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2924),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2925),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2926),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(681)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2934),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2935),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(682)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2936),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2937),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(683)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2940),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2941),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(684)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2942),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2943),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(685)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2944),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2945),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2946),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(686)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2947),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2948),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2949),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(687)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2955),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2956),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(688)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(2957),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2958),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(689)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3002),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3003),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(690)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3004),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3005),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(691)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3006),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3007),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(692)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3008),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3009),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(693)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3025),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3026),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(694)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3027),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3028),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(695)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3029),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3030),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(696)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_code_block] = STATE(3031),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3144),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(697)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1873),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1875),
  },
  [STATE(698)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3263),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3265),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(699)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15120),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15121),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(700)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15136),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15137),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(701)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_preproc_if] = STATE(8),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3491),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(273),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1877),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_end_keyword] = ACTIONS(1879),
  },
  [STATE(702)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4146),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4147),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(703)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2512),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2513),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(704)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(6000),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(6001),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(705)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2520),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2521),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(706)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15398),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15399),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(707)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15400),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15401),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(708)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2524),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2525),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(709)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4148),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4149),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(710)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4150),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4151),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(711)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15404),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15405),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(712)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15406),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15407),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(713)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2534),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2535),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2536),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(714)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(5964),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(5965),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(715)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2537),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2538),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2539),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(716)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15032),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15033),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(717)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15034),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15035),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(718)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15036),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15037),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(719)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15038),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15039),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(720)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3133),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3134),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(721)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2898),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2899),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2900),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(722)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15099),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15100),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(723)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15101),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15102),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(724)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15104),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15105),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(725)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15106),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15107),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(726)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4236),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4237),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(727)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15153),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15154),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(728)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15155),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15156),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(729)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15157),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15158),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(730)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15159),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15160),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(731)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2878),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2879),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(732)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15192),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15193),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(733)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15194),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15195),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(734)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15196),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15197),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(735)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15198),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15199),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(736)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2901),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2902),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2903),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(737)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2881),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2882),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(738)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(5967),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(5968),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(739)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(5969),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(5970),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(740)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2889),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2890),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2891),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(741)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2892),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2893),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2894),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(742)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2543),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2544),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2545),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(743)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2546),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2547),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2548),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(744)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2906),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2907),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(745)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(5971),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(5972),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(746)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2908),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2909),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2910),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(747)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2911),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2912),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2913),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(748)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2921),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2922),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2923),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(749)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2924),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2925),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2926),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(750)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2934),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2935),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(751)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2936),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2937),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(752)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2940),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2941),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(753)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2942),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2943),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(754)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2944),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2945),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2946),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(755)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2947),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2948),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2949),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(756)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2955),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2956),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(757)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(2957),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(2958),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(758)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3002),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3003),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(759)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3004),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3005),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(760)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3006),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3007),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(761)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2551),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2552),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(762)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(4152),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(4153),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2452),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(763)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3025),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3026),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(764)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3027),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3028),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(765)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3029),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3030),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(766)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(3540),
    [sym_code_block] = STATE(3031),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3144),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(3540),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(3540),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3540),
    [sym_multiplicative_expression] = STATE(3540),
    [sym_additive_expression] = STATE(3540),
    [sym_comparison_expression] = STATE(3540),
    [sym_logical_expression] = STATE(3540),
    [sym_ternary_expression] = STATE(3540),
    [sym_unary_expression] = STATE(3540),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3540),
    [sym_list_literal] = STATE(3540),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3540),
    [sym__literal_value] = STATE(3540),
    [sym_if_keyword] = STATE(4723),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4864),
    [sym_foreach_keyword] = STATE(16506),
    [sym_while_keyword] = STATE(4724),
    [sym_repeat_keyword] = STATE(294),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4725),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(449),
    [sym_date_literal] = ACTIONS(433),
    [sym_time_literal] = ACTIONS(433),
    [sym_biginteger_literal] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(457),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(449),
    [sym_verbatim_string] = ACTIONS(449),
    [sym_integer] = ACTIONS(433),
    [sym_continue_as_identifier] = ACTIONS(449),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(767)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15003),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15005),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(768)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15013),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15015),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(769)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(14868),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(14952),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(770)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15020),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15144),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(771)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15146),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15148),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(772)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(14847),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(14853),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(773)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(14855),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(14877),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(774)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15283),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15284),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15285),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(775)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15286),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15287),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15288),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(776)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15403),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15408),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15409),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(777)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15416),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15433),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15434),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(778)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15436),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15438),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(779)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(14823),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(14828),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(780)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15117),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15118),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15123),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(781)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15124),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15125),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15126),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(782)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2553),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2560),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2578),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(783)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15238),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15239),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15243),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(784)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15244),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15245),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15250),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(785)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15269),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15270),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(786)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15271),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15272),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(787)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2579),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2580),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2581),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(788)] = {
    [sym_empty_statement] = STATE(2452),
    [sym_boolean] = STATE(2344),
    [sym_code_block] = STATE(2589),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_split_if_statement] = STATE(2452),
    [sym_preproc_guarded_statement] = STATE(2452),
    [sym_preproc_split_if_else_statement] = STATE(2452),
    [sym_preproc_split_if_then_begin] = STATE(2452),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2452),
    [sym_preproc_split_if_begin_else] = STATE(2452),
    [sym_preproc_split_call_statement] = STATE(2452),
    [sym_preproc_conditional_statement] = STATE(2452),
    [sym__statement] = STATE(2590),
    [sym__expression_statement] = STATE(2492),
    [sym_assignment_statement] = STATE(2452),
    [sym_assignment_expression] = STATE(2344),
    [sym_if_statement] = STATE(2591),
    [sym_case_statement] = STATE(2452),
    [sym_for_statement] = STATE(2452),
    [sym_foreach_statement] = STATE(2452),
    [sym_while_statement] = STATE(2452),
    [sym_repeat_statement] = STATE(2452),
    [sym_with_statement] = STATE(2452),
    [sym_exit_statement] = STATE(2452),
    [sym_continue_statement] = STATE(2452),
    [sym_break_statement] = STATE(2452),
    [sym_asserterror_statement] = STATE(2452),
    [sym__expression] = STATE(2344),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2344),
    [sym_multiplicative_expression] = STATE(2344),
    [sym_additive_expression] = STATE(2344),
    [sym_comparison_expression] = STATE(2344),
    [sym_logical_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_list_literal] = STATE(2344),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2344),
    [sym__literal_value] = STATE(2344),
    [sym_if_keyword] = STATE(4739),
    [sym_case_keyword] = STATE(4800),
    [sym_for_keyword] = STATE(4873),
    [sym_foreach_keyword] = STATE(16510),
    [sym_while_keyword] = STATE(4740),
    [sym_repeat_keyword] = STATE(305),
    [sym_exit_keyword] = STATE(2365),
    [sym_continue_keyword] = STATE(2463),
    [sym_break_keyword] = STATE(2470),
    [sym_with_keyword] = STATE(4741),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(381),
    [sym_date_literal] = ACTIONS(365),
    [sym_time_literal] = ACTIONS(365),
    [sym_biginteger_literal] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(99),
    [anon_sym_EXIT] = ACTIONS(99),
    [anon_sym_Exit] = ACTIONS(99),
    [anon_sym_continue] = ACTIONS(101),
    [anon_sym_CONTINUE] = ACTIONS(101),
    [anon_sym_Continue] = ACTIONS(101),
    [anon_sym_break] = ACTIONS(103),
    [anon_sym_BREAK] = ACTIONS(103),
    [anon_sym_Break] = ACTIONS(103),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(383),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(381),
    [sym_verbatim_string] = ACTIONS(381),
    [sym_integer] = ACTIONS(365),
    [sym_continue_as_identifier] = ACTIONS(381),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(789)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15275),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15276),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(790)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15277),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15278),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(791)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15297),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15305),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15306),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(792)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15307),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15308),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15309),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(793)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15319),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15320),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(794)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15321),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15322),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(795)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15067),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15068),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(796)] = {
    [sym_empty_statement] = STATE(15083),
    [sym_boolean] = STATE(8541),
    [sym_code_block] = STATE(15069),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_split_if_statement] = STATE(15083),
    [sym_preproc_guarded_statement] = STATE(15083),
    [sym_preproc_split_if_else_statement] = STATE(15083),
    [sym_preproc_split_if_then_begin] = STATE(15083),
    [sym_preproc_split_if_begin_asymmetric] = STATE(15083),
    [sym_preproc_split_if_begin_else] = STATE(15083),
    [sym_preproc_split_call_statement] = STATE(15083),
    [sym_preproc_conditional_statement] = STATE(15083),
    [sym__statement] = STATE(15070),
    [sym__expression_statement] = STATE(15084),
    [sym_assignment_statement] = STATE(15083),
    [sym_assignment_expression] = STATE(8541),
    [sym_if_statement] = STATE(15083),
    [sym_case_statement] = STATE(15083),
    [sym_for_statement] = STATE(15083),
    [sym_foreach_statement] = STATE(15083),
    [sym_while_statement] = STATE(15083),
    [sym_repeat_statement] = STATE(15083),
    [sym_with_statement] = STATE(15083),
    [sym_exit_statement] = STATE(15083),
    [sym_continue_statement] = STATE(15083),
    [sym_break_statement] = STATE(15083),
    [sym_asserterror_statement] = STATE(15083),
    [sym__expression] = STATE(8541),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8541),
    [sym_multiplicative_expression] = STATE(8541),
    [sym_additive_expression] = STATE(8541),
    [sym_comparison_expression] = STATE(8541),
    [sym_logical_expression] = STATE(8541),
    [sym_ternary_expression] = STATE(8541),
    [sym_unary_expression] = STATE(8541),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8541),
    [sym_list_literal] = STATE(8541),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8541),
    [sym__literal_value] = STATE(8541),
    [sym_if_keyword] = STATE(4779),
    [sym_case_keyword] = STATE(4806),
    [sym_for_keyword] = STATE(4874),
    [sym_foreach_keyword] = STATE(16514),
    [sym_while_keyword] = STATE(4780),
    [sym_repeat_keyword] = STATE(293),
    [sym_exit_keyword] = STATE(14856),
    [sym_continue_keyword] = STATE(15087),
    [sym_break_keyword] = STATE(15088),
    [sym_with_keyword] = STATE(4781),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(1372),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(1378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(1390),
    [sym_date_literal] = ACTIONS(1378),
    [sym_time_literal] = ACTIONS(1378),
    [sym_biginteger_literal] = ACTIONS(1390),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(1392),
    [anon_sym_EXIT] = ACTIONS(1392),
    [anon_sym_Exit] = ACTIONS(1392),
    [anon_sym_continue] = ACTIONS(1394),
    [anon_sym_CONTINUE] = ACTIONS(1394),
    [anon_sym_Continue] = ACTIONS(1394),
    [anon_sym_break] = ACTIONS(1396),
    [anon_sym_BREAK] = ACTIONS(1396),
    [anon_sym_Break] = ACTIONS(1396),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(1398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(1390),
    [sym_verbatim_string] = ACTIONS(1390),
    [sym_integer] = ACTIONS(1378),
    [sym_continue_as_identifier] = ACTIONS(1390),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(797)] = {
    [sym_empty_statement] = STATE(3292),
    [sym_boolean] = STATE(1967),
    [sym_code_block] = STATE(3177),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_split_if_statement] = STATE(3292),
    [sym_preproc_guarded_statement] = STATE(3292),
    [sym_preproc_split_if_else_statement] = STATE(3292),
    [sym_preproc_split_if_then_begin] = STATE(3292),
    [sym_preproc_split_if_begin_asymmetric] = STATE(3292),
    [sym_preproc_split_if_begin_else] = STATE(3292),
    [sym_preproc_split_call_statement] = STATE(3292),
    [sym_preproc_conditional_statement] = STATE(3292),
    [sym__statement] = STATE(3190),
    [sym__expression_statement] = STATE(3383),
    [sym_assignment_statement] = STATE(3292),
    [sym_assignment_expression] = STATE(1967),
    [sym_if_statement] = STATE(3292),
    [sym_case_statement] = STATE(3292),
    [sym_for_statement] = STATE(3292),
    [sym_foreach_statement] = STATE(3292),
    [sym_while_statement] = STATE(3292),
    [sym_repeat_statement] = STATE(3292),
    [sym_with_statement] = STATE(3292),
    [sym_exit_statement] = STATE(3292),
    [sym_continue_statement] = STATE(3292),
    [sym_break_statement] = STATE(3292),
    [sym_asserterror_statement] = STATE(3292),
    [sym__expression] = STATE(1967),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1967),
    [sym_multiplicative_expression] = STATE(1967),
    [sym_additive_expression] = STATE(1967),
    [sym_comparison_expression] = STATE(1967),
    [sym_logical_expression] = STATE(1967),
    [sym_ternary_expression] = STATE(1967),
    [sym_unary_expression] = STATE(1967),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1967),
    [sym_list_literal] = STATE(1967),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1967),
    [sym__literal_value] = STATE(1967),
    [sym_if_keyword] = STATE(4622),
    [sym_case_keyword] = STATE(4625),
    [sym_for_keyword] = STATE(4627),
    [sym_foreach_keyword] = STATE(16444),
    [sym_while_keyword] = STATE(4628),
    [sym_repeat_keyword] = STATE(295),
    [sym_exit_keyword] = STATE(3153),
    [sym_continue_keyword] = STATE(3212),
    [sym_break_keyword] = STATE(3216),
    [sym_with_keyword] = STATE(4637),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(693),
    [sym_date_literal] = ACTIONS(677),
    [sym_time_literal] = ACTIONS(677),
    [sym_biginteger_literal] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(695),
    [anon_sym_EXIT] = ACTIONS(695),
    [anon_sym_Exit] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_CONTINUE] = ACTIONS(697),
    [anon_sym_Continue] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_BREAK] = ACTIONS(699),
    [anon_sym_Break] = ACTIONS(699),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(701),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(693),
    [sym_verbatim_string] = ACTIONS(693),
    [sym_integer] = ACTIONS(677),
    [sym_continue_as_identifier] = ACTIONS(693),
    [sym_preproc_open] = ACTIONS(73),
    [sym_begin_keyword] = ACTIONS(1184),
  },
  [STATE(798)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1881),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(799)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1883),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(800)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(824),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1885),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(801)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1887),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(802)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1889),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(803)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1891),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(804)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(832),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(843),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(805)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1893),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(806)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(830),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1895),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(807)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1897),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(808)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1899),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(809)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(841),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1901),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(810)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1903),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(811)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(846),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1905),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(812)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1907),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(813)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(847),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1909),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(814)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1911),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(815)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1913),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(816)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1915),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(817)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(835),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1917),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(818)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1919),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(819)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(894),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1921),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(820)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1923),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(821)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1925),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(822)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(836),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1927),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(823)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1929),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(824)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1931),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(825)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(837),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1933),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(826)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(838),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1935),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(827)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1937),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(828)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1939),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(829)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1941),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(830)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1943),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(831)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1020),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1945),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(832)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(812),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(833)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(940),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(822),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(834)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1026),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1947),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(835)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1949),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(836)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1951),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(837)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1953),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(838)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1955),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(839)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(925),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1957),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(840)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1959),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(841)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1961),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(842)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(930),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1963),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(843)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1120),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1965),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(844)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(849),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(798),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(845)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1122),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1967),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(846)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1969),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(847)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1971),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(848)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1563),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1973),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(849)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(830),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(850)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(851),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(818),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(851)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(826),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(852)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(854),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1975),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(853)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(858),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1977),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(854)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1979),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(855)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(861),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1981),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(856)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(864),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1983),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(857)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(870),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1985),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(858)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1987),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(859)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(872),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1989),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(860)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(873),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1991),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(861)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1993),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(862)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1995),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(863)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(876),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1997),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(864)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(1999),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(865)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(879),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2001),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(866)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(880),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2003),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(867)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(884),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2005),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(868)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(887),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2007),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(869)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(890),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2009),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(870)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2011),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(871)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(892),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2013),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(872)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2015),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(873)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2017),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(874)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(895),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2019),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(875)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2021),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(876)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2023),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(877)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(896),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2025),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(878)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(897),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2027),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(879)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2029),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(880)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2031),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(881)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(899),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2033),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(882)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(900),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2035),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(883)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(901),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2037),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(884)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2039),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(885)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(903),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2041),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(886)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(904),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2043),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(887)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2045),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(888)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(907),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2047),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(889)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(908),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2049),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(890)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2051),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(891)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(910),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2053),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(892)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2055),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(893)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1564),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2057),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(894)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2059),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(895)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2061),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(896)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2063),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(897)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2065),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(898)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(913),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2067),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(899)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2069),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(900)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2071),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(901)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2073),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(902)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(914),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2075),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(903)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2077),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(904)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2079),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(905)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(915),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2081),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(906)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(916),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2083),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(907)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2085),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(908)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2087),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(909)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(918),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2089),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(910)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2091),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(911)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1650),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2093),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(912)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1651),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2095),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(913)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2097),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(914)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2099),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(915)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2101),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(916)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2103),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(917)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(921),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2105),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(918)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2107),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(919)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(922),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2109),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(920)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1656),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2111),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(921)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2113),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(922)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2115),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(923)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(927),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(924)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(928),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2119),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(925)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2121),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(926)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(933),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2123),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(927)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2125),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(928)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2127),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(929)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(936),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2129),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(930)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2131),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(931)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1031),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2133),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(932)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1033),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2135),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(933)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2137),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(934)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(937),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2139),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(935)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(938),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2141),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(936)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2143),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(937)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2145),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(938)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2147),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(939)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(943),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2149),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(940)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(834),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(941)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(801),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2151),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(942)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1059),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2153),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(943)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2155),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(944)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(945),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(820),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(945)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(824),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(946)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(947),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(828),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(947)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(832),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(948)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(950),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2157),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(949)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(954),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2159),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(950)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2161),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(951)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(957),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2163),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(952)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(960),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2165),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(953)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(966),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2167),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(954)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2169),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(955)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(798),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2171),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(956)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(968),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2173),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(957)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2175),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(958)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(970),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2177),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(959)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(971),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2179),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(960)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2181),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(961)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(974),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2183),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(962)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(975),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2185),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(963)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(979),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2187),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(964)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(982),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2189),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(965)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(985),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2191),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(966)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2193),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(967)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(987),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2195),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(968)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2197),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(969)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(988),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2199),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(970)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2201),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(971)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2203),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(972)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(989),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2205),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(973)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(990),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2207),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(974)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2209),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(975)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2211),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(976)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(992),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2213),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(977)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(993),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2215),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(978)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(994),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2217),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(979)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2219),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(980)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(996),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2221),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(981)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(997),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2223),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(982)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2225),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(983)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1000),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2227),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(984)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1001),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2229),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(985)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2231),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(986)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1003),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2233),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(987)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2235),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(988)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2237),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(989)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2239),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(990)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2241),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(991)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1004),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2243),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(992)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2245),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(993)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2247),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(994)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2249),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(995)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1005),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2251),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(996)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2253),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(997)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2255),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(998)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1006),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2257),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(999)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1007),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2259),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1000)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2261),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1001)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2263),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1002)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1009),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2265),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1003)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2267),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1004)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2269),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1005)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2271),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1006)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2273),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1007)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2275),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1008)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1011),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2277),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1009)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2279),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1010)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1012),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2281),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1011)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2283),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1012)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2285),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1013)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1017),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2287),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1014)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1018),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2289),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1015)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(805),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2291),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1016)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1023),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2293),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1017)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2295),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1018)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2297),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1019)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1027),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2299),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1020)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2301),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1021)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(807),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2303),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1022)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(799),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2305),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1023)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2307),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1024)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1028),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2309),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1025)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1029),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2311),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1026)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2313),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1027)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2315),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1028)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2317),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1029)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2319),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1030)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1032),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2321),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1031)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2323),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1032)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2325),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1033)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2327),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1034)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1116),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2329),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1035)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1036),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2331),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1036)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2333),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1037)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1038),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2335),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1038)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1039)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1041),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2339),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1040)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1045),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2341),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1041)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2343),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1042)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1048),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2345),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1043)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1051),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2347),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1044)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1057),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2349),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1045)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2351),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1046)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1060),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2353),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1047)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1061),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2355),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1048)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2357),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1049)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1063),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2359),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1050)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1064),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2361),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1051)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2363),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1052)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1067),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2365),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1053)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1068),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2367),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1054)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1072),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2369),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1055)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1075),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2371),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1056)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1078),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2373),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1057)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2375),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1058)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1080),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2377),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1059)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2379),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1060)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2381),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1061)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2383),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1062)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1083),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2385),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1063)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2387),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1064)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2389),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1065)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1084),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2391),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1066)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1085),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2393),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1067)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2395),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1068)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2397),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1069)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1087),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2399),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1070)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1088),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2401),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1071)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1089),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2403),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1072)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2405),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1073)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1091),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2407),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1074)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1092),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2409),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1075)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2411),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1076)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1095),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2413),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1077)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1096),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2415),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1078)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2417),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1079)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1098),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2419),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1080)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2421),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1081)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1565),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2423),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1082)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1566),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2425),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1083)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1084)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2429),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1085)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2431),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1086)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1099),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2433),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1087)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2435),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1088)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2437),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1089)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2439),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1090)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1100),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1091)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2443),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1092)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2445),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1093)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1101),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2447),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1094)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1102),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2449),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1095)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2451),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1096)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2453),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1097)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1104),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2455),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1098)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2457),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1099)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2459),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1100)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2461),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1101)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2463),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1102)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2465),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1103)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1106),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2467),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1104)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2469),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1105)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1107),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2471),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1106)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2473),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1107)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2475),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1108)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1112),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2477),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1109)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1113),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2479),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1110)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(810),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2481),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1111)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1117),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2483),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1112)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2485),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1113)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2487),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1114)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1121),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2489),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1115)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(812),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2491),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1116)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2493),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1117)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2495),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1118)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1123),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2497),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1119)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1124),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2499),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1120)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2501),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1121)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2503),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1122)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2505),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1123)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2507),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1124)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2509),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1125)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1127),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2511),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1126)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(814),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2513),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1127)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2515),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1128)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1129),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2517),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1129)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2519),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1130)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1131),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2521),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1131)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2523),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1132)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1134),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2525),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1133)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1138),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2527),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1134)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2529),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1135)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1141),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2531),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1136)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1144),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2533),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1137)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1150),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2535),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1138)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2537),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1139)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1152),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2539),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1140)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1153),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2541),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1141)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2543),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1142)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1155),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2545),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1143)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1156),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2547),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1144)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2549),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1145)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1159),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2551),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1146)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1160),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2553),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1147)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1164),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2555),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1148)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1167),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2557),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1149)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2559),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1150)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2561),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1151)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1172),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2563),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1152)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2565),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1153)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2567),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1154)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1173),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2569),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1155)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2571),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1156)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2573),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1157)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1174),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2575),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1158)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1175),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2577),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1159)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2579),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1160)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2581),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1161)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1177),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2583),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1162)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1178),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2585),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1163)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2587),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1164)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2589),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1165)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1181),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2591),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1166)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1182),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2593),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1167)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2595),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1168)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1185),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2597),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1169)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1186),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2599),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1170)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2601),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1171)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1188),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2603),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1172)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2605),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1173)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2607),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1174)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2609),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1175)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2611),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1176)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1189),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2613),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1177)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2615),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1178)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2617),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1179)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2619),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1180)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1190),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2621),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1181)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2623),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1182)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2625),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1183)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1191),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2627),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1184)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1192),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2629),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1185)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2631),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1186)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2633),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1187)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1194),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2635),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1188)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2637),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1189)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2639),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1190)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2641),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1191)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2643),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1192)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2645),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1193)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1195),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2647),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1194)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1195)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2651),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1196)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1197),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(808),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1197)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(810),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1198)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1199),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(814),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1199)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(816),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1200)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1202),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2653),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1201)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1206),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2655),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1202)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2657),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1203)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1209),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2659),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1204)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1212),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2661),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1205)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1218),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2663),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1206)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2665),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1207)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1220),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2667),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1208)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1221),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2669),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1209)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2671),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1210)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1223),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2673),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1211)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1224),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2675),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1212)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2677),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1213)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1227),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2679),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1214)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1228),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2681),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1215)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1232),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2683),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1216)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1235),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2685),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1217)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1238),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2687),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1218)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2689),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1219)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1240),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2691),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1220)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2693),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1221)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2695),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1222)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1241),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2697),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1223)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2699),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1224)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2701),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1225)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1242),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2703),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1226)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1243),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2705),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1227)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2707),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1228)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2709),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1229)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1245),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2711),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1230)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1246),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2713),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1231)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1247),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2715),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1232)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2717),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1233)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1249),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2719),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1234)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1250),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2721),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1235)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2723),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1236)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1252),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2725),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1237)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1253),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2727),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1238)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2729),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1239)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1255),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2731),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1240)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2733),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1241)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2735),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1242)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2737),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1243)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2739),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1244)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1256),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2741),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1245)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2743),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1246)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2745),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1247)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2747),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1248)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1257),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2749),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1249)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2751),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1250)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2753),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1251)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1258),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2755),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1252)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2757),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1253)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2759),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1254)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1261),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2761),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1255)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2763),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1256)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2765),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1257)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2767),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1258)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2769),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1259)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2771),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1260)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1262),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2773),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1261)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2775),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1262)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2777),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1263)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1264),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(845),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1264)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(847),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1265)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1266),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(849),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1266)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(788),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1267)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1269),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2779),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1268)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1273),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2781),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1269)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2783),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1270)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1276),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2785),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1271)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1279),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2787),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1272)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1285),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2789),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1273)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2791),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1274)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1287),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2793),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1275)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1288),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2795),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1276)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2797),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1277)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1290),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2799),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1278)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1291),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2801),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1279)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2803),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1280)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1294),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2805),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1281)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1295),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2807),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1282)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1299),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2809),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1283)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1302),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2811),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1284)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1305),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2813),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1285)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2815),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1286)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1307),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2817),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1287)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2819),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1288)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2821),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1289)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1308),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2823),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1290)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2825),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1291)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2827),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1292)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1309),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2829),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1293)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1310),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2831),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1294)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2833),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1295)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2835),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1296)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1312),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2837),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1297)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1313),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2839),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1298)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1314),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2841),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1299)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2843),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1300)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1316),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2845),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1301)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1317),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2847),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1302)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2849),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1303)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1320),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2851),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1304)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1321),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2853),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1305)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2855),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1306)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1323),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2857),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1307)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2859),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1308)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2861),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1309)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2863),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1310)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2865),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1311)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1324),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2867),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1312)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2869),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1313)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2871),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1314)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2873),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1315)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1325),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2875),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1316)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2877),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1317)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2879),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1318)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1326),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2881),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1319)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1327),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2883),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1320)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2885),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1321)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2887),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1322)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1329),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2889),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1323)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2891),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1324)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2893),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1325)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2895),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1326)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2897),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1327)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2899),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1328)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1330),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2901),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1329)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2903),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1330)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2905),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1331)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1332),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(790),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1332)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(792),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1333)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1334),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(794),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1334)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(796),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1335)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1337),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2907),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1336)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1341),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2909),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1337)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2911),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1338)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1344),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2913),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1339)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1347),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2915),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1340)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1353),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2917),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1341)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2919),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1342)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1355),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2921),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1343)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1356),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2923),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1344)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2925),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1345)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1358),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2927),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1346)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1359),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2929),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1347)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2931),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1348)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1362),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2933),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1349)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1363),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2935),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1350)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1367),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2937),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1351)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1370),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2939),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1352)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1373),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2941),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1353)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2943),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1354)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1375),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2945),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1355)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2947),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1356)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2949),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1357)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1376),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2951),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1358)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2953),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1359)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2955),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1360)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1377),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2957),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1361)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1378),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2959),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1362)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2961),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1363)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2963),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1364)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1380),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2965),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1365)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1381),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2967),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1366)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1382),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2969),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1367)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2971),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1368)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1384),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2973),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1369)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1385),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2975),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1370)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2977),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1371)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1388),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2979),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1372)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1389),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2981),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1373)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2983),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1374)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1391),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2985),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1375)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2987),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1376)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2989),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1377)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2991),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1378)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2993),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1379)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1392),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2995),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1380)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2997),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1381)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(2999),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1382)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3001),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1383)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1393),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3003),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1384)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3005),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1385)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3007),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1386)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1394),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3009),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1387)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1395),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3011),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1388)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3013),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1389)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3015),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1390)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1397),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3017),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1391)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3019),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1392)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3021),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1393)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3023),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1394)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3025),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1395)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3027),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1396)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1398),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3029),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1397)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3031),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1398)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3033),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1399)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1400),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(786),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1400)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(800),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1401)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1402),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(802),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1402)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(804),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1403)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1405),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3035),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1404)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1409),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3037),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1405)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3039),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1406)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1412),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3041),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1407)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1415),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3043),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1408)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1421),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3045),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1409)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3047),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1410)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1423),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3049),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1411)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1424),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3051),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1412)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3053),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1413)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1426),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3055),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1414)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1427),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3057),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1415)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3059),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1416)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1430),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3061),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1417)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1431),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3063),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1418)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1435),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3065),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1419)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1438),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3067),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1420)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1441),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3069),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1421)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3071),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1422)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1443),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3073),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1423)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3075),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1424)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3077),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1425)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1444),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3079),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1426)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3081),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1427)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3083),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1428)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1445),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3085),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1429)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1446),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3087),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1430)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3089),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1431)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3091),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1432)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1448),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3093),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1433)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1449),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3095),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1434)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1450),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3097),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1435)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3099),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1436)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1452),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3101),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1437)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1453),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3103),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1438)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3105),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1439)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1456),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3107),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1440)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1457),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3109),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1441)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3111),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1442)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1459),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3113),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1443)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3115),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1444)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3117),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1445)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3119),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1446)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3121),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1447)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1460),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3123),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1448)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3125),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1449)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3127),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1450)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3129),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1451)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1461),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3131),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1452)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3133),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1453)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3135),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1454)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1462),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3137),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1455)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1463),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3139),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1456)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3141),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1457)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3143),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1458)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1465),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3145),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1459)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3147),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1460)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3149),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1461)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3151),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1462)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3153),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1463)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3155),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1464)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1466),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3157),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1465)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3159),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1466)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3161),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1467)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1469),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3163),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1468)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1471),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3165),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1469)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3167),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1470)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1473),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3169),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1471)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3171),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1472)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1474),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3173),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1473)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3175),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1474)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3177),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1475)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1477),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3179),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1476)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1479),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3181),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1477)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3183),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1478)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1481),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3185),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1479)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3187),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1480)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1482),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3189),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1481)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3191),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1482)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3193),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1483)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1485),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3195),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1484)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1487),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3197),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1485)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3199),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1486)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1489),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3201),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1487)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3203),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1488)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1490),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3205),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1489)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3207),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1490)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3209),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1491)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1493),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3211),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1492)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1495),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3213),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1493)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3215),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1494)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1497),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3217),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1495)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3219),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1496)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1498),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3221),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1497)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3223),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1498)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3225),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1499)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1501),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3227),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1500)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1503),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3229),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1501)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3231),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1502)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1505),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3233),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1503)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3235),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1504)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1506),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3237),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1505)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3239),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1506)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3241),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1507)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1509),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3243),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1508)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1511),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3245),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1509)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3247),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1510)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1513),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3249),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1511)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3251),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1512)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1514),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3253),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1513)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3255),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1514)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3257),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1515)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1517),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3259),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1516)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1519),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3261),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1517)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3263),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1518)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1521),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3265),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1519)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3267),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1520)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1522),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3269),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1521)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3271),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1522)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3273),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1523)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1525),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3275),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1524)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1527),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3277),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1525)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3279),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1526)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1529),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3281),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1527)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3283),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1528)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1530),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3285),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1529)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3287),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1530)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3289),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1531)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1533),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3291),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1532)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1535),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3293),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1533)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3295),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1534)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1537),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3297),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1535)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3299),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1536)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1538),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3301),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1537)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3303),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1538)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3305),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1539)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1541),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3307),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1540)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1543),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3309),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1541)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3311),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1542)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1545),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3313),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1543)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3315),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1544)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1546),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3317),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1545)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3319),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1546)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3321),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1547)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1549),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3323),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1548)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1551),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3325),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1549)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3327),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1550)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1553),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3329),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1551)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3331),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1552)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1554),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3333),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1553)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3335),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1554)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3337),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1555)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1557),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3339),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1556)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1559),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3341),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1557)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3343),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1558)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1561),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3345),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1559)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3347),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1560)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1562),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3349),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1561)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3351),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1562)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3353),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1563)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3355),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1564)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3357),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1565)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3359),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1566)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3361),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1567)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1654),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3363),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1568)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(815),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3365),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1569)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(816),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3367),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1570)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1572),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3369),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1571)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1573),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3371),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1572)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3373),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1573)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3375),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1574)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1576),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3377),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1575)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1577),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3379),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1576)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3381),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1577)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3383),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1578)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1580),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3385),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1579)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1581),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3387),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1580)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3389),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1581)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3391),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1582)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1584),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3393),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1583)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1585),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3395),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1584)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3397),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1585)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3399),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1586)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1588),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3401),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1587)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1589),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3403),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1588)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3405),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1589)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3407),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1590)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1592),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3409),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1591)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1593),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3411),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1592)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3413),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1593)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3415),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1594)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1596),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3417),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1595)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1597),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3419),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1596)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3421),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1597)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3423),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1598)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1600),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3425),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1599)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1601),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3427),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1600)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3429),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1601)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3431),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1602)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1604),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3433),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1603)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1605),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3435),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1604)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3437),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1605)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3439),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1606)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1608),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3441),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1607)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1609),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3443),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1608)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3445),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1609)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3447),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1610)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1612),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3449),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1611)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1613),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3451),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1612)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3453),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1613)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3455),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1614)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1616),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3457),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1615)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1617),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3459),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1616)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3461),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1617)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3463),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1618)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1620),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3465),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1619)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1621),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3467),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1620)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3469),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1621)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3471),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1622)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1624),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3473),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1623)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1625),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3475),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1624)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3477),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1625)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3479),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1626)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1628),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3481),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1627)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1629),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3483),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1628)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3485),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1629)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3487),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1630)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1632),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3489),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1631)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1633),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3491),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1632)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3493),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1633)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3495),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1634)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1636),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3497),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1635)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1637),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3499),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1636)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3501),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1637)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3503),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1638)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1640),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3505),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1639)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1641),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3507),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1640)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3509),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1641)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3511),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1642)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1644),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3513),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1643)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1645),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3515),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1644)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3517),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1645)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3519),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1646)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1648),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3521),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1647)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1649),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3523),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1648)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3525),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1649)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3527),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1650)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3529),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1651)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3531),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1652)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(818),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3533),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1653)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(820),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3535),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1654)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3537),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1655)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(821),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3539),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1656)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3541),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1657)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(823),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3543),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1658)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1259),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3545),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1659)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(80),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1660)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(21),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1661)] = {
    [aux_sym_option_member_list_repeat2] = STATE(1661),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_EQ] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(3547),
    [anon_sym_DASH] = ACTIONS(836),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [sym_decimal] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(838),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(838),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [anon_sym_not] = ACTIONS(836),
    [anon_sym_NOT] = ACTIONS(836),
    [anon_sym_Not] = ACTIONS(836),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(838),
    [aux_sym__expression_token1] = ACTIONS(838),
    [aux_sym__expression_token2] = ACTIONS(836),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_div] = ACTIONS(836),
    [anon_sym_DIV] = ACTIONS(836),
    [anon_sym_Div] = ACTIONS(836),
    [anon_sym_mod] = ACTIONS(836),
    [anon_sym_MOD] = ACTIONS(836),
    [anon_sym_Mod] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_LT_GT] = ACTIONS(838),
    [anon_sym_and] = ACTIONS(836),
    [anon_sym_AND] = ACTIONS(836),
    [anon_sym_And] = ACTIONS(836),
    [anon_sym_or] = ACTIONS(836),
    [anon_sym_OR] = ACTIONS(836),
    [anon_sym_Or] = ACTIONS(836),
    [anon_sym_xor] = ACTIONS(836),
    [anon_sym_XOR] = ACTIONS(836),
    [anon_sym_Xor] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(838),
    [sym_datetime_literal] = ACTIONS(838),
    [sym_date_literal] = ACTIONS(836),
    [sym_time_literal] = ACTIONS(836),
    [sym_biginteger_literal] = ACTIONS(838),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_IF] = ACTIONS(836),
    [anon_sym_If] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_ELSE] = ACTIONS(836),
    [anon_sym_Else] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_CASE] = ACTIONS(836),
    [anon_sym_Case] = ACTIONS(836),
    [anon_sym_for] = ACTIONS(836),
    [anon_sym_FOR] = ACTIONS(836),
    [anon_sym_For] = ACTIONS(836),
    [anon_sym_foreach] = ACTIONS(836),
    [anon_sym_FOREACH] = ACTIONS(836),
    [anon_sym_Foreach] = ACTIONS(836),
    [anon_sym_while] = ACTIONS(836),
    [anon_sym_WHILE] = ACTIONS(836),
    [anon_sym_While] = ACTIONS(836),
    [anon_sym_repeat] = ACTIONS(836),
    [anon_sym_REPEAT] = ACTIONS(836),
    [anon_sym_Repeat] = ACTIONS(836),
    [anon_sym_exit] = ACTIONS(836),
    [anon_sym_EXIT] = ACTIONS(836),
    [anon_sym_Exit] = ACTIONS(836),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_CONTINUE] = ACTIONS(836),
    [anon_sym_Continue] = ACTIONS(836),
    [anon_sym_break] = ACTIONS(836),
    [anon_sym_BREAK] = ACTIONS(836),
    [anon_sym_Break] = ACTIONS(836),
    [anon_sym_with] = ACTIONS(836),
    [anon_sym_WITH] = ACTIONS(836),
    [anon_sym_With] = ACTIONS(836),
    [sym_asserterror_keyword] = ACTIONS(838),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_IN] = ACTIONS(836),
    [anon_sym_In] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_verbatim_string] = ACTIONS(838),
    [sym_integer] = ACTIONS(836),
    [sym_continue_as_identifier] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
    [sym_end_keyword] = ACTIONS(838),
  },
  [STATE(1662)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(11),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1663)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(12),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1724),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1664)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(13),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1725),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1665)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(14),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1737),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1666)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(9),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1667)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4466),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1668)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4726),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1669),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1669)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4785),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1670)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4786),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1732),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1671)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(29),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1672),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1672)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(31),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1673)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(32),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1674),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1674)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1675)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(34),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1678),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1676)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(35),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1679),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1677)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(36),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1681),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1678)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1679)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(38),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1680)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(39),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1684),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1681)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(40),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1682)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(41),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1685),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1683)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1686),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1684)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(43),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1685)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(44),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1686)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(45),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1687)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(46),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1688),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1688)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(47),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1689)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(51),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1690),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1690)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(53),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1691)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(2),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1692),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1692)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(55),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1693)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(56),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1696),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1694)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(110),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1697),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1695)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1699),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1696)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1697)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1698)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1702),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1699)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1700)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1703),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1701)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(63),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1704),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1702)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(64),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1703)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(65),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1704)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(66),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1705)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(67),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1706),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1706)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(68),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1707)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(72),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1708),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1708)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(74),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1709)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(75),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1710),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1710)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(76),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1711)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(77),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1659),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1712)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(78),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1769),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1713)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(79),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1716),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1714)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elif] = STATE(1770),
    [sym_preproc_else] = STATE(1923),
    [sym_preproc_endif] = STATE(2763),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(10831),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(988),
    [anon_sym_POUNDELIF] = ACTIONS(988),
    [anon_sym_POUNDElif] = ACTIONS(988),
    [anon_sym_POUNDelse] = ACTIONS(990),
    [anon_sym_POUNDELSE] = ACTIONS(990),
    [anon_sym_POUNDElse] = ACTIONS(990),
    [anon_sym_POUNDelse2] = ACTIONS(990),
    [anon_sym_POUNDELSE2] = ACTIONS(990),
    [anon_sym_POUNDElse2] = ACTIONS(990),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1715)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(82),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1719),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1716)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(83),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1717)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(84),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1720),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1718)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(85),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1721),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1719)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(86),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1720)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(87),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1721)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(88),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1722)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(89),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1723),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1723)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(90),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1724)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(15),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1725)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(16),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1726)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(22),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1727)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(17),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1660),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1728)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(10),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1662),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1729)] = {
    [sym_preproc_conditional_object] = STATE(1736),
    [sym_using_statement] = STATE(1736),
    [sym__object] = STATE(1736),
    [sym_preproc_split_declaration] = STATE(1736),
    [sym_table_declaration] = STATE(1736),
    [sym_page_declaration] = STATE(1736),
    [sym_report_declaration] = STATE(1736),
    [sym_query_declaration] = STATE(1736),
    [sym_xmlport_declaration] = STATE(1736),
    [sym_permissionset_declaration] = STATE(1736),
    [sym_codeunit_declaration] = STATE(1736),
    [sym_enum_declaration] = STATE(1736),
    [sym_tableextension_declaration] = STATE(1736),
    [sym_pageextension_declaration] = STATE(1736),
    [sym_reportextension_declaration] = STATE(1736),
    [sym_enumextension_declaration] = STATE(1736),
    [sym_permissionsetextension_declaration] = STATE(1736),
    [sym_controladdin_declaration] = STATE(1736),
    [sym_profile_declaration] = STATE(1736),
    [sym_entitlement_declaration] = STATE(1736),
    [sym_profileextension_declaration] = STATE(1736),
    [sym_interface_declaration] = STATE(1736),
    [sym_pagecustomization_declaration] = STATE(1736),
    [sym_dotnet_declaration] = STATE(1736),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elif] = STATE(1770),
    [sym_preproc_else] = STATE(1905),
    [sym_preproc_endif] = STATE(3684),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1736),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(10702),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(988),
    [anon_sym_POUNDELIF] = ACTIONS(988),
    [anon_sym_POUNDElif] = ACTIONS(988),
    [anon_sym_POUNDelse] = ACTIONS(990),
    [anon_sym_POUNDELSE] = ACTIONS(990),
    [anon_sym_POUNDElse] = ACTIONS(990),
    [anon_sym_POUNDelse2] = ACTIONS(990),
    [anon_sym_POUNDELSE2] = ACTIONS(990),
    [anon_sym_POUNDElse2] = ACTIONS(990),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1730)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elif] = STATE(1770),
    [sym_preproc_else] = STATE(1905),
    [sym_preproc_endif] = STATE(3684),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(10702),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(988),
    [anon_sym_POUNDELIF] = ACTIONS(988),
    [anon_sym_POUNDElif] = ACTIONS(988),
    [anon_sym_POUNDelse] = ACTIONS(990),
    [anon_sym_POUNDELSE] = ACTIONS(990),
    [anon_sym_POUNDElse] = ACTIONS(990),
    [anon_sym_POUNDelse2] = ACTIONS(990),
    [anon_sym_POUNDELSE2] = ACTIONS(990),
    [anon_sym_POUNDElse2] = ACTIONS(990),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1731)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4794),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1734),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1732)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4844),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1733)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(7),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1666),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1734)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4876),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1735)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4660),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1667),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1736)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elif] = STATE(1770),
    [sym_preproc_else] = STATE(1901),
    [sym_preproc_endif] = STATE(3687),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(10674),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(988),
    [anon_sym_POUNDELIF] = ACTIONS(988),
    [anon_sym_POUNDElif] = ACTIONS(988),
    [anon_sym_POUNDelse] = ACTIONS(990),
    [anon_sym_POUNDELSE] = ACTIONS(990),
    [anon_sym_POUNDElse] = ACTIONS(990),
    [anon_sym_POUNDelse2] = ACTIONS(990),
    [anon_sym_POUNDELSE2] = ACTIONS(990),
    [anon_sym_POUNDElse2] = ACTIONS(990),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1737)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(18),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1738)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(19),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1726),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1739)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(20),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1764),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1740)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4847),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1741),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1741)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4848),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1742)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4849),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1744),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1743)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4850),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1745),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1744)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4851),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1745)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4852),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1746)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4853),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1747),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1747)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4854),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1748)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4856),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1749),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1749)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4857),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1750)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4858),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1752),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1751)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4859),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1753),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1752)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4860),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1753)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4861),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1754)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4862),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1755),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1755)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4863),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1756)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4865),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1757),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1757)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4866),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1758)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4867),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1760),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1759)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4868),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1761),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1760)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4869),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1761)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4870),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1762)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4871),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1763),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1763)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4872),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1764)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(23),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1765)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(24),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(1766),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1766)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(25),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1767)] = {
    [sym_preproc_conditional_object] = STATE(1714),
    [sym_using_statement] = STATE(1714),
    [sym__object] = STATE(1714),
    [sym_preproc_split_declaration] = STATE(1714),
    [sym_table_declaration] = STATE(1714),
    [sym_page_declaration] = STATE(1714),
    [sym_report_declaration] = STATE(1714),
    [sym_query_declaration] = STATE(1714),
    [sym_xmlport_declaration] = STATE(1714),
    [sym_permissionset_declaration] = STATE(1714),
    [sym_codeunit_declaration] = STATE(1714),
    [sym_enum_declaration] = STATE(1714),
    [sym_tableextension_declaration] = STATE(1714),
    [sym_pageextension_declaration] = STATE(1714),
    [sym_reportextension_declaration] = STATE(1714),
    [sym_enumextension_declaration] = STATE(1714),
    [sym_permissionsetextension_declaration] = STATE(1714),
    [sym_controladdin_declaration] = STATE(1714),
    [sym_profile_declaration] = STATE(1714),
    [sym_entitlement_declaration] = STATE(1714),
    [sym_profileextension_declaration] = STATE(1714),
    [sym_interface_declaration] = STATE(1714),
    [sym_pagecustomization_declaration] = STATE(1714),
    [sym_dotnet_declaration] = STATE(1714),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elif] = STATE(1770),
    [sym_preproc_else] = STATE(1899),
    [sym_preproc_endif] = STATE(2861),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1714),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(10779),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(988),
    [anon_sym_POUNDELIF] = ACTIONS(988),
    [anon_sym_POUNDElif] = ACTIONS(988),
    [anon_sym_POUNDelse] = ACTIONS(990),
    [anon_sym_POUNDELSE] = ACTIONS(990),
    [anon_sym_POUNDElse] = ACTIONS(990),
    [anon_sym_POUNDelse2] = ACTIONS(990),
    [anon_sym_POUNDELSE2] = ACTIONS(990),
    [anon_sym_POUNDElse2] = ACTIONS(990),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1768)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elif] = STATE(1770),
    [sym_preproc_else] = STATE(1899),
    [sym_preproc_endif] = STATE(2861),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [aux_sym_preproc_conditional_object_repeat1] = STATE(10779),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(988),
    [anon_sym_POUNDELIF] = ACTIONS(988),
    [anon_sym_POUNDElif] = ACTIONS(988),
    [anon_sym_POUNDelse] = ACTIONS(990),
    [anon_sym_POUNDELSE] = ACTIONS(990),
    [anon_sym_POUNDElse] = ACTIONS(990),
    [anon_sym_POUNDelse2] = ACTIONS(990),
    [anon_sym_POUNDELSE2] = ACTIONS(990),
    [anon_sym_POUNDElse2] = ACTIONS(990),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1769)] = {
    [sym_empty_statement] = STATE(2877),
    [sym_boolean] = STATE(1876),
    [sym_preproc_if] = STATE(81),
    [sym_preproc_split_if_statement] = STATE(2877),
    [sym_preproc_guarded_statement] = STATE(2877),
    [sym_preproc_split_if_else_statement] = STATE(2877),
    [sym_preproc_split_if_then_begin] = STATE(2877),
    [sym_preproc_split_if_begin_asymmetric] = STATE(2877),
    [sym_preproc_split_if_begin_else] = STATE(2877),
    [sym_preproc_split_call_statement] = STATE(2877),
    [sym_preproc_conditional_statement] = STATE(2877),
    [sym__statement] = STATE(3421),
    [sym__expression_statement] = STATE(3098),
    [sym_assignment_statement] = STATE(2877),
    [sym_assignment_expression] = STATE(1876),
    [sym_if_statement] = STATE(2877),
    [sym_case_statement] = STATE(2877),
    [sym_for_statement] = STATE(2877),
    [sym_foreach_statement] = STATE(2877),
    [sym_while_statement] = STATE(2877),
    [sym_repeat_statement] = STATE(2877),
    [sym_with_statement] = STATE(2877),
    [sym_exit_statement] = STATE(2877),
    [sym_continue_statement] = STATE(2877),
    [sym_break_statement] = STATE(2877),
    [sym_asserterror_statement] = STATE(2877),
    [sym__expression] = STATE(1876),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1876),
    [sym_multiplicative_expression] = STATE(1876),
    [sym_additive_expression] = STATE(1876),
    [sym_comparison_expression] = STATE(1876),
    [sym_logical_expression] = STATE(1876),
    [sym_ternary_expression] = STATE(1876),
    [sym_unary_expression] = STATE(1876),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1876),
    [sym_list_literal] = STATE(1876),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1876),
    [sym__literal_value] = STATE(1876),
    [sym_if_keyword] = STATE(4647),
    [sym_case_keyword] = STATE(4804),
    [sym_for_keyword] = STATE(4855),
    [sym_foreach_keyword] = STATE(16500),
    [sym_while_keyword] = STATE(4693),
    [sym_repeat_keyword] = STATE(300),
    [sym_exit_keyword] = STATE(2771),
    [sym_continue_keyword] = STATE(3075),
    [sym_break_keyword] = STATE(3077),
    [sym_with_keyword] = STATE(4694),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [aux_sym_preproc_split_procedure_body_repeat1] = STATE(179),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(657),
    [sym_date_literal] = ACTIONS(645),
    [sym_time_literal] = ACTIONS(645),
    [sym_biginteger_literal] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [anon_sym_case] = ACTIONS(89),
    [anon_sym_CASE] = ACTIONS(89),
    [anon_sym_Case] = ACTIONS(89),
    [anon_sym_for] = ACTIONS(91),
    [anon_sym_FOR] = ACTIONS(91),
    [anon_sym_For] = ACTIONS(91),
    [anon_sym_foreach] = ACTIONS(93),
    [anon_sym_FOREACH] = ACTIONS(93),
    [anon_sym_Foreach] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(95),
    [anon_sym_WHILE] = ACTIONS(95),
    [anon_sym_While] = ACTIONS(95),
    [anon_sym_repeat] = ACTIONS(97),
    [anon_sym_REPEAT] = ACTIONS(97),
    [anon_sym_Repeat] = ACTIONS(97),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_EXIT] = ACTIONS(451),
    [anon_sym_Exit] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(453),
    [anon_sym_CONTINUE] = ACTIONS(453),
    [anon_sym_Continue] = ACTIONS(453),
    [anon_sym_break] = ACTIONS(455),
    [anon_sym_BREAK] = ACTIONS(455),
    [anon_sym_Break] = ACTIONS(455),
    [anon_sym_with] = ACTIONS(105),
    [anon_sym_WITH] = ACTIONS(105),
    [anon_sym_With] = ACTIONS(105),
    [sym_asserterror_keyword] = ACTIONS(659),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(657),
    [sym_verbatim_string] = ACTIONS(657),
    [sym_integer] = ACTIONS(645),
    [sym_continue_as_identifier] = ACTIONS(657),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(1770)] = {
    [sym_preproc_conditional_object] = STATE(1829),
    [sym_namespace_declaration] = STATE(1828),
    [sym_using_statement] = STATE(1829),
    [sym__object] = STATE(1829),
    [sym_preproc_split_declaration] = STATE(1829),
    [sym_table_declaration] = STATE(1829),
    [sym_page_declaration] = STATE(1829),
    [sym_report_declaration] = STATE(1829),
    [sym_query_declaration] = STATE(1829),
    [sym_xmlport_declaration] = STATE(1829),
    [sym_permissionset_declaration] = STATE(1829),
    [sym_codeunit_declaration] = STATE(1829),
    [sym_enum_declaration] = STATE(1829),
    [sym_tableextension_declaration] = STATE(1829),
    [sym_pageextension_declaration] = STATE(1829),
    [sym_reportextension_declaration] = STATE(1829),
    [sym_enumextension_declaration] = STATE(1829),
    [sym_permissionsetextension_declaration] = STATE(1829),
    [sym_controladdin_declaration] = STATE(1829),
    [sym_profile_declaration] = STATE(1829),
    [sym_entitlement_declaration] = STATE(1829),
    [sym_profileextension_declaration] = STATE(1829),
    [sym_interface_declaration] = STATE(1829),
    [sym_pagecustomization_declaration] = STATE(1829),
    [sym_dotnet_declaration] = STATE(1829),
    [sym_preproc_if] = STATE(308),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1829),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(3560),
    [anon_sym_POUNDELIF] = ACTIONS(3560),
    [anon_sym_POUNDElif] = ACTIONS(3560),
    [anon_sym_POUNDelse] = ACTIONS(3560),
    [anon_sym_POUNDELSE] = ACTIONS(3560),
    [anon_sym_POUNDElse] = ACTIONS(3560),
    [anon_sym_POUNDelse2] = ACTIONS(3560),
    [anon_sym_POUNDELSE2] = ACTIONS(3560),
    [anon_sym_POUNDElse2] = ACTIONS(3560),
    [anon_sym_POUNDendif] = ACTIONS(3560),
    [anon_sym_POUNDENDIF] = ACTIONS(3560),
    [anon_sym_POUNDEndif] = ACTIONS(3560),
    [anon_sym_POUNDendif2] = ACTIONS(3560),
    [anon_sym_POUNDENDIF2] = ACTIONS(3560),
    [anon_sym_POUNDEndif2] = ACTIONS(3560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(3560),
  },
  [STATE(1771)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_COMMA] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [aux_sym_boolean_token1] = ACTIONS(3562),
    [aux_sym_boolean_token2] = ACTIONS(3562),
    [sym_decimal] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_record_type_token1] = ACTIONS(3562),
    [aux_sym_basic_type_token21] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token48] = ACTIONS(3562),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_not] = ACTIONS(3562),
    [anon_sym_NOT] = ACTIONS(3562),
    [anon_sym_Not] = ACTIONS(3562),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3562),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [sym_datetime_literal] = ACTIONS(3564),
    [sym_date_literal] = ACTIONS(3562),
    [sym_time_literal] = ACTIONS(3562),
    [sym_biginteger_literal] = ACTIONS(3564),
    [anon_sym_if] = ACTIONS(3562),
    [anon_sym_IF] = ACTIONS(3562),
    [anon_sym_If] = ACTIONS(3562),
    [anon_sym_else] = ACTIONS(3562),
    [anon_sym_ELSE] = ACTIONS(3562),
    [anon_sym_Else] = ACTIONS(3562),
    [anon_sym_case] = ACTIONS(3562),
    [anon_sym_CASE] = ACTIONS(3562),
    [anon_sym_Case] = ACTIONS(3562),
    [anon_sym_for] = ACTIONS(3562),
    [anon_sym_FOR] = ACTIONS(3562),
    [anon_sym_For] = ACTIONS(3562),
    [anon_sym_foreach] = ACTIONS(3562),
    [anon_sym_FOREACH] = ACTIONS(3562),
    [anon_sym_Foreach] = ACTIONS(3562),
    [anon_sym_while] = ACTIONS(3562),
    [anon_sym_WHILE] = ACTIONS(3562),
    [anon_sym_While] = ACTIONS(3562),
    [anon_sym_repeat] = ACTIONS(3562),
    [anon_sym_REPEAT] = ACTIONS(3562),
    [anon_sym_Repeat] = ACTIONS(3562),
    [anon_sym_exit] = ACTIONS(3562),
    [anon_sym_EXIT] = ACTIONS(3562),
    [anon_sym_Exit] = ACTIONS(3562),
    [anon_sym_continue] = ACTIONS(3562),
    [anon_sym_CONTINUE] = ACTIONS(3562),
    [anon_sym_Continue] = ACTIONS(3562),
    [anon_sym_break] = ACTIONS(3562),
    [anon_sym_BREAK] = ACTIONS(3562),
    [anon_sym_Break] = ACTIONS(3562),
    [anon_sym_with] = ACTIONS(3562),
    [anon_sym_WITH] = ACTIONS(3562),
    [anon_sym_With] = ACTIONS(3562),
    [sym_asserterror_keyword] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_page_keyword] = ACTIONS(3562),
    [anon_sym_codeunit] = ACTIONS(3562),
    [anon_sym_CODEUNIT] = ACTIONS(3562),
    [anon_sym_Codeunit] = ACTIONS(3562),
    [anon_sym_CodeUnit] = ACTIONS(3562),
    [anon_sym_COdeunit] = ACTIONS(3562),
    [anon_sym_codeUnit] = ACTIONS(3562),
    [sym_report_keyword] = ACTIONS(3562),
    [sym_query_keyword] = ACTIONS(3562),
    [anon_sym_xmlport] = ACTIONS(3562),
    [anon_sym_XMLPORT] = ACTIONS(3562),
    [anon_sym_Xmlport] = ACTIONS(3562),
    [anon_sym_XMLport] = ACTIONS(3562),
    [anon_sym_XMLPort] = ACTIONS(3562),
    [anon_sym_XmlPort] = ACTIONS(3562),
    [anon_sym_enum] = ACTIONS(3562),
    [anon_sym_ENUM] = ACTIONS(3562),
    [anon_sym_Enum] = ACTIONS(3562),
    [anon_sym_eNUM] = ACTIONS(3562),
    [anon_sym_eNum] = ACTIONS(3562),
    [anon_sym_ENum] = ACTIONS(3562),
    [sym_temporary_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3564),
    [sym_verbatim_string] = ACTIONS(3564),
    [sym_integer] = ACTIONS(3562),
    [sym_continue_as_identifier] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
  },
  [STATE(1772)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(1773)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(1774)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3576),
    [anon_sym_SEMI] = ACTIONS(3578),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3576),
    [aux_sym_boolean_token2] = ACTIONS(3576),
    [sym_decimal] = ACTIONS(3576),
    [anon_sym_LPAREN] = ACTIONS(3578),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3576),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3576),
    [aux_sym_basic_type_token21] = ACTIONS(3576),
    [aux_sym_basic_type_token22] = ACTIONS(3576),
    [aux_sym_basic_type_token48] = ACTIONS(3576),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3576),
    [anon_sym_POUNDif] = ACTIONS(3578),
    [anon_sym_POUNDIF] = ACTIONS(3578),
    [anon_sym_POUNDIf] = ACTIONS(3578),
    [anon_sym_not] = ACTIONS(3576),
    [anon_sym_NOT] = ACTIONS(3576),
    [anon_sym_Not] = ACTIONS(3576),
    [anon_sym_POUNDelif] = ACTIONS(3578),
    [anon_sym_POUNDELIF] = ACTIONS(3578),
    [anon_sym_POUNDElif] = ACTIONS(3578),
    [anon_sym_POUNDelse] = ACTIONS(3578),
    [anon_sym_POUNDELSE] = ACTIONS(3578),
    [anon_sym_POUNDElse] = ACTIONS(3578),
    [anon_sym_POUNDelse2] = ACTIONS(3578),
    [anon_sym_POUNDELSE2] = ACTIONS(3578),
    [anon_sym_POUNDElse2] = ACTIONS(3578),
    [anon_sym_POUNDendif] = ACTIONS(3578),
    [anon_sym_POUNDENDIF] = ACTIONS(3578),
    [anon_sym_POUNDEndif] = ACTIONS(3578),
    [anon_sym_POUNDendif2] = ACTIONS(3578),
    [anon_sym_POUNDENDIF2] = ACTIONS(3578),
    [anon_sym_POUNDEndif2] = ACTIONS(3578),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3586),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3576),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3576),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3616),
    [anon_sym_OR] = ACTIONS(3618),
    [anon_sym_Or] = ACTIONS(3620),
    [anon_sym_xor] = ACTIONS(3622),
    [anon_sym_XOR] = ACTIONS(3624),
    [anon_sym_Xor] = ACTIONS(3626),
    [anon_sym_QMARK] = ACTIONS(3628),
    [sym_datetime_literal] = ACTIONS(3578),
    [sym_date_literal] = ACTIONS(3576),
    [sym_time_literal] = ACTIONS(3576),
    [sym_biginteger_literal] = ACTIONS(3578),
    [anon_sym_if] = ACTIONS(3576),
    [anon_sym_IF] = ACTIONS(3576),
    [anon_sym_If] = ACTIONS(3576),
    [anon_sym_else] = ACTIONS(3576),
    [anon_sym_ELSE] = ACTIONS(3576),
    [anon_sym_Else] = ACTIONS(3576),
    [anon_sym_case] = ACTIONS(3576),
    [anon_sym_CASE] = ACTIONS(3576),
    [anon_sym_Case] = ACTIONS(3576),
    [anon_sym_for] = ACTIONS(3576),
    [anon_sym_FOR] = ACTIONS(3576),
    [anon_sym_For] = ACTIONS(3576),
    [anon_sym_foreach] = ACTIONS(3576),
    [anon_sym_FOREACH] = ACTIONS(3576),
    [anon_sym_Foreach] = ACTIONS(3576),
    [anon_sym_while] = ACTIONS(3576),
    [anon_sym_WHILE] = ACTIONS(3576),
    [anon_sym_While] = ACTIONS(3576),
    [anon_sym_repeat] = ACTIONS(3576),
    [anon_sym_REPEAT] = ACTIONS(3576),
    [anon_sym_Repeat] = ACTIONS(3576),
    [anon_sym_exit] = ACTIONS(3576),
    [anon_sym_EXIT] = ACTIONS(3576),
    [anon_sym_Exit] = ACTIONS(3576),
    [anon_sym_continue] = ACTIONS(3576),
    [anon_sym_CONTINUE] = ACTIONS(3576),
    [anon_sym_Continue] = ACTIONS(3576),
    [anon_sym_break] = ACTIONS(3576),
    [anon_sym_BREAK] = ACTIONS(3576),
    [anon_sym_Break] = ACTIONS(3576),
    [anon_sym_with] = ACTIONS(3576),
    [anon_sym_WITH] = ACTIONS(3576),
    [anon_sym_With] = ACTIONS(3576),
    [sym_asserterror_keyword] = ACTIONS(3578),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3576),
    [anon_sym_codeunit] = ACTIONS(3576),
    [anon_sym_CODEUNIT] = ACTIONS(3576),
    [anon_sym_Codeunit] = ACTIONS(3576),
    [anon_sym_CodeUnit] = ACTIONS(3576),
    [anon_sym_COdeunit] = ACTIONS(3576),
    [anon_sym_codeUnit] = ACTIONS(3576),
    [sym_report_keyword] = ACTIONS(3576),
    [sym_query_keyword] = ACTIONS(3576),
    [anon_sym_xmlport] = ACTIONS(3576),
    [anon_sym_XMLPORT] = ACTIONS(3576),
    [anon_sym_Xmlport] = ACTIONS(3576),
    [anon_sym_XMLport] = ACTIONS(3576),
    [anon_sym_XMLPort] = ACTIONS(3576),
    [anon_sym_XmlPort] = ACTIONS(3576),
    [anon_sym_enum] = ACTIONS(3576),
    [anon_sym_ENUM] = ACTIONS(3576),
    [anon_sym_Enum] = ACTIONS(3576),
    [anon_sym_eNUM] = ACTIONS(3576),
    [anon_sym_eNum] = ACTIONS(3576),
    [anon_sym_ENum] = ACTIONS(3576),
    [sym_quoted_identifier] = ACTIONS(3578),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3578),
    [sym_verbatim_string] = ACTIONS(3578),
    [sym_integer] = ACTIONS(3576),
    [sym_continue_as_identifier] = ACTIONS(3578),
    [sym_preproc_open] = ACTIONS(3578),
    [sym_preproc_close] = ACTIONS(3578),
  },
  [STATE(1775)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1775),
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(3636),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelif] = ACTIONS(3634),
    [anon_sym_POUNDELIF] = ACTIONS(3634),
    [anon_sym_POUNDElif] = ACTIONS(3634),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [anon_sym_POUNDendif] = ACTIONS(3634),
    [anon_sym_POUNDENDIF] = ACTIONS(3634),
    [anon_sym_POUNDEndif] = ACTIONS(3634),
    [anon_sym_POUNDendif2] = ACTIONS(3634),
    [anon_sym_POUNDENDIF2] = ACTIONS(3634),
    [anon_sym_POUNDEndif2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_if] = ACTIONS(3632),
    [anon_sym_IF] = ACTIONS(3632),
    [anon_sym_If] = ACTIONS(3632),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_case] = ACTIONS(3632),
    [anon_sym_CASE] = ACTIONS(3632),
    [anon_sym_Case] = ACTIONS(3632),
    [anon_sym_for] = ACTIONS(3632),
    [anon_sym_FOR] = ACTIONS(3632),
    [anon_sym_For] = ACTIONS(3632),
    [anon_sym_foreach] = ACTIONS(3632),
    [anon_sym_FOREACH] = ACTIONS(3632),
    [anon_sym_Foreach] = ACTIONS(3632),
    [anon_sym_while] = ACTIONS(3632),
    [anon_sym_WHILE] = ACTIONS(3632),
    [anon_sym_While] = ACTIONS(3632),
    [anon_sym_repeat] = ACTIONS(3632),
    [anon_sym_REPEAT] = ACTIONS(3632),
    [anon_sym_Repeat] = ACTIONS(3632),
    [anon_sym_exit] = ACTIONS(3632),
    [anon_sym_EXIT] = ACTIONS(3632),
    [anon_sym_Exit] = ACTIONS(3632),
    [anon_sym_continue] = ACTIONS(3632),
    [anon_sym_CONTINUE] = ACTIONS(3632),
    [anon_sym_Continue] = ACTIONS(3632),
    [anon_sym_break] = ACTIONS(3632),
    [anon_sym_BREAK] = ACTIONS(3632),
    [anon_sym_Break] = ACTIONS(3632),
    [anon_sym_with] = ACTIONS(3632),
    [anon_sym_WITH] = ACTIONS(3632),
    [anon_sym_With] = ACTIONS(3632),
    [sym_asserterror_keyword] = ACTIONS(3634),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
    [sym_preproc_close] = ACTIONS(3634),
  },
  [STATE(1776)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3639),
    [anon_sym_SEMI] = ACTIONS(3641),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3641),
    [anon_sym_DASH] = ACTIONS(3639),
    [aux_sym_boolean_token1] = ACTIONS(3639),
    [aux_sym_boolean_token2] = ACTIONS(3639),
    [sym_decimal] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3641),
    [anon_sym_DOT_DOT] = ACTIONS(3641),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3639),
    [anon_sym_STAR] = ACTIONS(3639),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3639),
    [aux_sym_basic_type_token21] = ACTIONS(3639),
    [aux_sym_basic_type_token22] = ACTIONS(3639),
    [aux_sym_basic_type_token48] = ACTIONS(3639),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3639),
    [anon_sym_POUNDif] = ACTIONS(3641),
    [anon_sym_POUNDIF] = ACTIONS(3641),
    [anon_sym_POUNDIf] = ACTIONS(3641),
    [anon_sym_not] = ACTIONS(3639),
    [anon_sym_NOT] = ACTIONS(3639),
    [anon_sym_Not] = ACTIONS(3639),
    [anon_sym_POUNDelif] = ACTIONS(3641),
    [anon_sym_POUNDELIF] = ACTIONS(3641),
    [anon_sym_POUNDElif] = ACTIONS(3641),
    [anon_sym_POUNDelse] = ACTIONS(3641),
    [anon_sym_POUNDELSE] = ACTIONS(3641),
    [anon_sym_POUNDElse] = ACTIONS(3641),
    [anon_sym_POUNDelse2] = ACTIONS(3641),
    [anon_sym_POUNDELSE2] = ACTIONS(3641),
    [anon_sym_POUNDElse2] = ACTIONS(3641),
    [anon_sym_POUNDendif] = ACTIONS(3641),
    [anon_sym_POUNDENDIF] = ACTIONS(3641),
    [anon_sym_POUNDEndif] = ACTIONS(3641),
    [anon_sym_POUNDendif2] = ACTIONS(3641),
    [anon_sym_POUNDENDIF2] = ACTIONS(3641),
    [anon_sym_POUNDEndif2] = ACTIONS(3641),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3641),
    [aux_sym__expression_token1] = ACTIONS(3641),
    [aux_sym__expression_token2] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3639),
    [anon_sym_SLASH] = ACTIONS(3639),
    [anon_sym_div] = ACTIONS(3639),
    [anon_sym_DIV] = ACTIONS(3639),
    [anon_sym_Div] = ACTIONS(3639),
    [anon_sym_mod] = ACTIONS(3639),
    [anon_sym_MOD] = ACTIONS(3639),
    [anon_sym_Mod] = ACTIONS(3639),
    [anon_sym_PLUS] = ACTIONS(3639),
    [anon_sym_GT_EQ] = ACTIONS(3641),
    [anon_sym_LT_EQ] = ACTIONS(3641),
    [anon_sym_GT] = ACTIONS(3639),
    [anon_sym_LT] = ACTIONS(3639),
    [anon_sym_LT_GT] = ACTIONS(3641),
    [anon_sym_and] = ACTIONS(3639),
    [anon_sym_AND] = ACTIONS(3639),
    [anon_sym_And] = ACTIONS(3639),
    [anon_sym_or] = ACTIONS(3639),
    [anon_sym_OR] = ACTIONS(3639),
    [anon_sym_Or] = ACTIONS(3639),
    [anon_sym_xor] = ACTIONS(3639),
    [anon_sym_XOR] = ACTIONS(3639),
    [anon_sym_Xor] = ACTIONS(3639),
    [anon_sym_QMARK] = ACTIONS(3641),
    [sym_datetime_literal] = ACTIONS(3641),
    [sym_date_literal] = ACTIONS(3639),
    [sym_time_literal] = ACTIONS(3639),
    [sym_biginteger_literal] = ACTIONS(3641),
    [anon_sym_if] = ACTIONS(3639),
    [anon_sym_IF] = ACTIONS(3639),
    [anon_sym_If] = ACTIONS(3639),
    [anon_sym_else] = ACTIONS(3639),
    [anon_sym_ELSE] = ACTIONS(3639),
    [anon_sym_Else] = ACTIONS(3639),
    [anon_sym_case] = ACTIONS(3639),
    [anon_sym_CASE] = ACTIONS(3639),
    [anon_sym_Case] = ACTIONS(3639),
    [anon_sym_for] = ACTIONS(3639),
    [anon_sym_FOR] = ACTIONS(3639),
    [anon_sym_For] = ACTIONS(3639),
    [anon_sym_foreach] = ACTIONS(3639),
    [anon_sym_FOREACH] = ACTIONS(3639),
    [anon_sym_Foreach] = ACTIONS(3639),
    [anon_sym_while] = ACTIONS(3639),
    [anon_sym_WHILE] = ACTIONS(3639),
    [anon_sym_While] = ACTIONS(3639),
    [anon_sym_repeat] = ACTIONS(3639),
    [anon_sym_REPEAT] = ACTIONS(3639),
    [anon_sym_Repeat] = ACTIONS(3639),
    [anon_sym_exit] = ACTIONS(3639),
    [anon_sym_EXIT] = ACTIONS(3639),
    [anon_sym_Exit] = ACTIONS(3639),
    [anon_sym_continue] = ACTIONS(3639),
    [anon_sym_CONTINUE] = ACTIONS(3639),
    [anon_sym_Continue] = ACTIONS(3639),
    [anon_sym_break] = ACTIONS(3639),
    [anon_sym_BREAK] = ACTIONS(3639),
    [anon_sym_Break] = ACTIONS(3639),
    [anon_sym_with] = ACTIONS(3639),
    [anon_sym_WITH] = ACTIONS(3639),
    [anon_sym_With] = ACTIONS(3639),
    [sym_asserterror_keyword] = ACTIONS(3641),
    [anon_sym_in] = ACTIONS(3639),
    [anon_sym_IN] = ACTIONS(3639),
    [anon_sym_In] = ACTIONS(3639),
    [sym_page_keyword] = ACTIONS(3639),
    [anon_sym_codeunit] = ACTIONS(3639),
    [anon_sym_CODEUNIT] = ACTIONS(3639),
    [anon_sym_Codeunit] = ACTIONS(3639),
    [anon_sym_CodeUnit] = ACTIONS(3639),
    [anon_sym_COdeunit] = ACTIONS(3639),
    [anon_sym_codeUnit] = ACTIONS(3639),
    [sym_report_keyword] = ACTIONS(3639),
    [sym_query_keyword] = ACTIONS(3639),
    [anon_sym_xmlport] = ACTIONS(3639),
    [anon_sym_XMLPORT] = ACTIONS(3639),
    [anon_sym_Xmlport] = ACTIONS(3639),
    [anon_sym_XMLport] = ACTIONS(3639),
    [anon_sym_XMLPort] = ACTIONS(3639),
    [anon_sym_XmlPort] = ACTIONS(3639),
    [anon_sym_enum] = ACTIONS(3639),
    [anon_sym_ENUM] = ACTIONS(3639),
    [anon_sym_Enum] = ACTIONS(3639),
    [anon_sym_eNUM] = ACTIONS(3639),
    [anon_sym_eNum] = ACTIONS(3639),
    [anon_sym_ENum] = ACTIONS(3639),
    [sym_quoted_identifier] = ACTIONS(3641),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3641),
    [sym_verbatim_string] = ACTIONS(3641),
    [sym_integer] = ACTIONS(3639),
    [sym_continue_as_identifier] = ACTIONS(3641),
    [sym_preproc_open] = ACTIONS(3641),
    [sym_preproc_close] = ACTIONS(3641),
  },
  [STATE(1777)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1778)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3647),
    [anon_sym_SEMI] = ACTIONS(3649),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3649),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3647),
    [aux_sym_boolean_token2] = ACTIONS(3647),
    [sym_decimal] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3649),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3647),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3647),
    [aux_sym_basic_type_token21] = ACTIONS(3647),
    [aux_sym_basic_type_token22] = ACTIONS(3647),
    [aux_sym_basic_type_token48] = ACTIONS(3647),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3647),
    [anon_sym_POUNDif] = ACTIONS(3649),
    [anon_sym_POUNDIF] = ACTIONS(3649),
    [anon_sym_POUNDIf] = ACTIONS(3649),
    [anon_sym_not] = ACTIONS(3647),
    [anon_sym_NOT] = ACTIONS(3647),
    [anon_sym_Not] = ACTIONS(3647),
    [anon_sym_POUNDelif] = ACTIONS(3649),
    [anon_sym_POUNDELIF] = ACTIONS(3649),
    [anon_sym_POUNDElif] = ACTIONS(3649),
    [anon_sym_POUNDelse] = ACTIONS(3649),
    [anon_sym_POUNDELSE] = ACTIONS(3649),
    [anon_sym_POUNDElse] = ACTIONS(3649),
    [anon_sym_POUNDelse2] = ACTIONS(3649),
    [anon_sym_POUNDELSE2] = ACTIONS(3649),
    [anon_sym_POUNDElse2] = ACTIONS(3649),
    [anon_sym_POUNDendif] = ACTIONS(3649),
    [anon_sym_POUNDENDIF] = ACTIONS(3649),
    [anon_sym_POUNDEndif] = ACTIONS(3649),
    [anon_sym_POUNDendif2] = ACTIONS(3649),
    [anon_sym_POUNDENDIF2] = ACTIONS(3649),
    [anon_sym_POUNDEndif2] = ACTIONS(3649),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3649),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3647),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3647),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3649),
    [anon_sym_LT_EQ] = ACTIONS(3649),
    [anon_sym_GT] = ACTIONS(3647),
    [anon_sym_LT] = ACTIONS(3647),
    [anon_sym_LT_GT] = ACTIONS(3649),
    [anon_sym_and] = ACTIONS(3647),
    [anon_sym_AND] = ACTIONS(3647),
    [anon_sym_And] = ACTIONS(3647),
    [anon_sym_or] = ACTIONS(3647),
    [anon_sym_OR] = ACTIONS(3647),
    [anon_sym_Or] = ACTIONS(3647),
    [anon_sym_xor] = ACTIONS(3647),
    [anon_sym_XOR] = ACTIONS(3647),
    [anon_sym_Xor] = ACTIONS(3647),
    [anon_sym_QMARK] = ACTIONS(3649),
    [sym_datetime_literal] = ACTIONS(3649),
    [sym_date_literal] = ACTIONS(3647),
    [sym_time_literal] = ACTIONS(3647),
    [sym_biginteger_literal] = ACTIONS(3649),
    [anon_sym_if] = ACTIONS(3647),
    [anon_sym_IF] = ACTIONS(3647),
    [anon_sym_If] = ACTIONS(3647),
    [anon_sym_else] = ACTIONS(3647),
    [anon_sym_ELSE] = ACTIONS(3647),
    [anon_sym_Else] = ACTIONS(3647),
    [anon_sym_case] = ACTIONS(3647),
    [anon_sym_CASE] = ACTIONS(3647),
    [anon_sym_Case] = ACTIONS(3647),
    [anon_sym_for] = ACTIONS(3647),
    [anon_sym_FOR] = ACTIONS(3647),
    [anon_sym_For] = ACTIONS(3647),
    [anon_sym_foreach] = ACTIONS(3647),
    [anon_sym_FOREACH] = ACTIONS(3647),
    [anon_sym_Foreach] = ACTIONS(3647),
    [anon_sym_while] = ACTIONS(3647),
    [anon_sym_WHILE] = ACTIONS(3647),
    [anon_sym_While] = ACTIONS(3647),
    [anon_sym_repeat] = ACTIONS(3647),
    [anon_sym_REPEAT] = ACTIONS(3647),
    [anon_sym_Repeat] = ACTIONS(3647),
    [anon_sym_exit] = ACTIONS(3647),
    [anon_sym_EXIT] = ACTIONS(3647),
    [anon_sym_Exit] = ACTIONS(3647),
    [anon_sym_continue] = ACTIONS(3647),
    [anon_sym_CONTINUE] = ACTIONS(3647),
    [anon_sym_Continue] = ACTIONS(3647),
    [anon_sym_break] = ACTIONS(3647),
    [anon_sym_BREAK] = ACTIONS(3647),
    [anon_sym_Break] = ACTIONS(3647),
    [anon_sym_with] = ACTIONS(3647),
    [anon_sym_WITH] = ACTIONS(3647),
    [anon_sym_With] = ACTIONS(3647),
    [sym_asserterror_keyword] = ACTIONS(3649),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3647),
    [anon_sym_codeunit] = ACTIONS(3647),
    [anon_sym_CODEUNIT] = ACTIONS(3647),
    [anon_sym_Codeunit] = ACTIONS(3647),
    [anon_sym_CodeUnit] = ACTIONS(3647),
    [anon_sym_COdeunit] = ACTIONS(3647),
    [anon_sym_codeUnit] = ACTIONS(3647),
    [sym_report_keyword] = ACTIONS(3647),
    [sym_query_keyword] = ACTIONS(3647),
    [anon_sym_xmlport] = ACTIONS(3647),
    [anon_sym_XMLPORT] = ACTIONS(3647),
    [anon_sym_Xmlport] = ACTIONS(3647),
    [anon_sym_XMLport] = ACTIONS(3647),
    [anon_sym_XMLPort] = ACTIONS(3647),
    [anon_sym_XmlPort] = ACTIONS(3647),
    [anon_sym_enum] = ACTIONS(3647),
    [anon_sym_ENUM] = ACTIONS(3647),
    [anon_sym_Enum] = ACTIONS(3647),
    [anon_sym_eNUM] = ACTIONS(3647),
    [anon_sym_eNum] = ACTIONS(3647),
    [anon_sym_ENum] = ACTIONS(3647),
    [sym_quoted_identifier] = ACTIONS(3649),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3649),
    [sym_verbatim_string] = ACTIONS(3649),
    [sym_integer] = ACTIONS(3647),
    [sym_continue_as_identifier] = ACTIONS(3649),
    [sym_preproc_open] = ACTIONS(3649),
    [sym_preproc_close] = ACTIONS(3649),
  },
  [STATE(1779)] = {
    [sym_identifier] = ACTIONS(3651),
    [anon_sym_SEMI] = ACTIONS(3653),
    [anon_sym_DOT] = ACTIONS(3651),
    [anon_sym_EQ] = ACTIONS(3653),
    [anon_sym_COMMA] = ACTIONS(3653),
    [anon_sym_DASH] = ACTIONS(3651),
    [aux_sym_boolean_token1] = ACTIONS(3651),
    [aux_sym_boolean_token2] = ACTIONS(3651),
    [sym_decimal] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3653),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3651),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_LBRACK] = ACTIONS(3653),
    [aux_sym_record_type_token1] = ACTIONS(3651),
    [aux_sym_basic_type_token21] = ACTIONS(3651),
    [aux_sym_basic_type_token22] = ACTIONS(3651),
    [aux_sym_basic_type_token48] = ACTIONS(3651),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3651),
    [anon_sym_COLON_COLON] = ACTIONS(3653),
    [anon_sym_POUNDif] = ACTIONS(3653),
    [anon_sym_POUNDIF] = ACTIONS(3653),
    [anon_sym_POUNDIf] = ACTIONS(3653),
    [anon_sym_not] = ACTIONS(3651),
    [anon_sym_NOT] = ACTIONS(3651),
    [anon_sym_Not] = ACTIONS(3651),
    [anon_sym_POUNDelif] = ACTIONS(3653),
    [anon_sym_POUNDELIF] = ACTIONS(3653),
    [anon_sym_POUNDElif] = ACTIONS(3653),
    [anon_sym_POUNDelse] = ACTIONS(3653),
    [anon_sym_POUNDELSE] = ACTIONS(3653),
    [anon_sym_POUNDElse] = ACTIONS(3653),
    [anon_sym_POUNDelse2] = ACTIONS(3653),
    [anon_sym_POUNDELSE2] = ACTIONS(3653),
    [anon_sym_POUNDElse2] = ACTIONS(3653),
    [anon_sym_POUNDendif] = ACTIONS(3653),
    [anon_sym_POUNDENDIF] = ACTIONS(3653),
    [anon_sym_POUNDEndif] = ACTIONS(3653),
    [anon_sym_POUNDendif2] = ACTIONS(3653),
    [anon_sym_POUNDENDIF2] = ACTIONS(3653),
    [anon_sym_POUNDEndif2] = ACTIONS(3653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3653),
    [aux_sym__expression_token1] = ACTIONS(3653),
    [aux_sym__expression_token2] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3651),
    [anon_sym_SLASH] = ACTIONS(3651),
    [anon_sym_div] = ACTIONS(3651),
    [anon_sym_DIV] = ACTIONS(3651),
    [anon_sym_Div] = ACTIONS(3651),
    [anon_sym_mod] = ACTIONS(3651),
    [anon_sym_MOD] = ACTIONS(3651),
    [anon_sym_Mod] = ACTIONS(3651),
    [anon_sym_PLUS] = ACTIONS(3651),
    [anon_sym_GT_EQ] = ACTIONS(3653),
    [anon_sym_LT_EQ] = ACTIONS(3653),
    [anon_sym_GT] = ACTIONS(3651),
    [anon_sym_LT] = ACTIONS(3651),
    [anon_sym_LT_GT] = ACTIONS(3653),
    [anon_sym_and] = ACTIONS(3651),
    [anon_sym_AND] = ACTIONS(3651),
    [anon_sym_And] = ACTIONS(3651),
    [anon_sym_or] = ACTIONS(3651),
    [anon_sym_OR] = ACTIONS(3651),
    [anon_sym_Or] = ACTIONS(3651),
    [anon_sym_xor] = ACTIONS(3651),
    [anon_sym_XOR] = ACTIONS(3651),
    [anon_sym_Xor] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [sym_datetime_literal] = ACTIONS(3653),
    [sym_date_literal] = ACTIONS(3651),
    [sym_time_literal] = ACTIONS(3651),
    [sym_biginteger_literal] = ACTIONS(3653),
    [anon_sym_if] = ACTIONS(3651),
    [anon_sym_IF] = ACTIONS(3651),
    [anon_sym_If] = ACTIONS(3651),
    [anon_sym_else] = ACTIONS(3651),
    [anon_sym_ELSE] = ACTIONS(3651),
    [anon_sym_Else] = ACTIONS(3651),
    [anon_sym_case] = ACTIONS(3651),
    [anon_sym_CASE] = ACTIONS(3651),
    [anon_sym_Case] = ACTIONS(3651),
    [anon_sym_for] = ACTIONS(3651),
    [anon_sym_FOR] = ACTIONS(3651),
    [anon_sym_For] = ACTIONS(3651),
    [anon_sym_foreach] = ACTIONS(3651),
    [anon_sym_FOREACH] = ACTIONS(3651),
    [anon_sym_Foreach] = ACTIONS(3651),
    [anon_sym_while] = ACTIONS(3651),
    [anon_sym_WHILE] = ACTIONS(3651),
    [anon_sym_While] = ACTIONS(3651),
    [anon_sym_repeat] = ACTIONS(3651),
    [anon_sym_REPEAT] = ACTIONS(3651),
    [anon_sym_Repeat] = ACTIONS(3651),
    [anon_sym_exit] = ACTIONS(3651),
    [anon_sym_EXIT] = ACTIONS(3651),
    [anon_sym_Exit] = ACTIONS(3651),
    [anon_sym_continue] = ACTIONS(3651),
    [anon_sym_CONTINUE] = ACTIONS(3651),
    [anon_sym_Continue] = ACTIONS(3651),
    [anon_sym_break] = ACTIONS(3651),
    [anon_sym_BREAK] = ACTIONS(3651),
    [anon_sym_Break] = ACTIONS(3651),
    [anon_sym_with] = ACTIONS(3651),
    [anon_sym_WITH] = ACTIONS(3651),
    [anon_sym_With] = ACTIONS(3651),
    [sym_asserterror_keyword] = ACTIONS(3653),
    [anon_sym_in] = ACTIONS(3651),
    [anon_sym_IN] = ACTIONS(3651),
    [anon_sym_In] = ACTIONS(3651),
    [sym_page_keyword] = ACTIONS(3651),
    [anon_sym_codeunit] = ACTIONS(3651),
    [anon_sym_CODEUNIT] = ACTIONS(3651),
    [anon_sym_Codeunit] = ACTIONS(3651),
    [anon_sym_CodeUnit] = ACTIONS(3651),
    [anon_sym_COdeunit] = ACTIONS(3651),
    [anon_sym_codeUnit] = ACTIONS(3651),
    [sym_report_keyword] = ACTIONS(3651),
    [sym_query_keyword] = ACTIONS(3651),
    [anon_sym_xmlport] = ACTIONS(3651),
    [anon_sym_XMLPORT] = ACTIONS(3651),
    [anon_sym_Xmlport] = ACTIONS(3651),
    [anon_sym_XMLport] = ACTIONS(3651),
    [anon_sym_XMLPort] = ACTIONS(3651),
    [anon_sym_XmlPort] = ACTIONS(3651),
    [anon_sym_enum] = ACTIONS(3651),
    [anon_sym_ENUM] = ACTIONS(3651),
    [anon_sym_Enum] = ACTIONS(3651),
    [anon_sym_eNUM] = ACTIONS(3651),
    [anon_sym_eNum] = ACTIONS(3651),
    [anon_sym_ENum] = ACTIONS(3651),
    [sym_quoted_identifier] = ACTIONS(3653),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3653),
    [sym_verbatim_string] = ACTIONS(3653),
    [sym_integer] = ACTIONS(3651),
    [sym_continue_as_identifier] = ACTIONS(3653),
    [sym_preproc_open] = ACTIONS(3653),
    [sym_preproc_close] = ACTIONS(3653),
  },
  [STATE(1780)] = {
    [sym_identifier] = ACTIONS(3655),
    [anon_sym_SEMI] = ACTIONS(3657),
    [anon_sym_DOT] = ACTIONS(3655),
    [anon_sym_EQ] = ACTIONS(3657),
    [anon_sym_COMMA] = ACTIONS(3657),
    [anon_sym_DASH] = ACTIONS(3655),
    [aux_sym_boolean_token1] = ACTIONS(3655),
    [aux_sym_boolean_token2] = ACTIONS(3655),
    [sym_decimal] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3657),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3655),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [aux_sym_record_type_token1] = ACTIONS(3655),
    [aux_sym_basic_type_token21] = ACTIONS(3655),
    [aux_sym_basic_type_token22] = ACTIONS(3655),
    [aux_sym_basic_type_token48] = ACTIONS(3655),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3655),
    [anon_sym_COLON_COLON] = ACTIONS(3657),
    [anon_sym_POUNDif] = ACTIONS(3657),
    [anon_sym_POUNDIF] = ACTIONS(3657),
    [anon_sym_POUNDIf] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3655),
    [anon_sym_NOT] = ACTIONS(3655),
    [anon_sym_Not] = ACTIONS(3655),
    [anon_sym_POUNDelif] = ACTIONS(3657),
    [anon_sym_POUNDELIF] = ACTIONS(3657),
    [anon_sym_POUNDElif] = ACTIONS(3657),
    [anon_sym_POUNDelse] = ACTIONS(3657),
    [anon_sym_POUNDELSE] = ACTIONS(3657),
    [anon_sym_POUNDElse] = ACTIONS(3657),
    [anon_sym_POUNDelse2] = ACTIONS(3657),
    [anon_sym_POUNDELSE2] = ACTIONS(3657),
    [anon_sym_POUNDElse2] = ACTIONS(3657),
    [anon_sym_POUNDendif] = ACTIONS(3657),
    [anon_sym_POUNDENDIF] = ACTIONS(3657),
    [anon_sym_POUNDEndif] = ACTIONS(3657),
    [anon_sym_POUNDendif2] = ACTIONS(3657),
    [anon_sym_POUNDENDIF2] = ACTIONS(3657),
    [anon_sym_POUNDEndif2] = ACTIONS(3657),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3657),
    [aux_sym__expression_token1] = ACTIONS(3657),
    [aux_sym__expression_token2] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3655),
    [anon_sym_SLASH] = ACTIONS(3655),
    [anon_sym_div] = ACTIONS(3655),
    [anon_sym_DIV] = ACTIONS(3655),
    [anon_sym_Div] = ACTIONS(3655),
    [anon_sym_mod] = ACTIONS(3655),
    [anon_sym_MOD] = ACTIONS(3655),
    [anon_sym_Mod] = ACTIONS(3655),
    [anon_sym_PLUS] = ACTIONS(3655),
    [anon_sym_GT_EQ] = ACTIONS(3657),
    [anon_sym_LT_EQ] = ACTIONS(3657),
    [anon_sym_GT] = ACTIONS(3655),
    [anon_sym_LT] = ACTIONS(3655),
    [anon_sym_LT_GT] = ACTIONS(3657),
    [anon_sym_and] = ACTIONS(3655),
    [anon_sym_AND] = ACTIONS(3655),
    [anon_sym_And] = ACTIONS(3655),
    [anon_sym_or] = ACTIONS(3655),
    [anon_sym_OR] = ACTIONS(3655),
    [anon_sym_Or] = ACTIONS(3655),
    [anon_sym_xor] = ACTIONS(3655),
    [anon_sym_XOR] = ACTIONS(3655),
    [anon_sym_Xor] = ACTIONS(3655),
    [anon_sym_QMARK] = ACTIONS(3657),
    [sym_datetime_literal] = ACTIONS(3657),
    [sym_date_literal] = ACTIONS(3655),
    [sym_time_literal] = ACTIONS(3655),
    [sym_biginteger_literal] = ACTIONS(3657),
    [anon_sym_if] = ACTIONS(3655),
    [anon_sym_IF] = ACTIONS(3655),
    [anon_sym_If] = ACTIONS(3655),
    [anon_sym_else] = ACTIONS(3655),
    [anon_sym_ELSE] = ACTIONS(3655),
    [anon_sym_Else] = ACTIONS(3655),
    [anon_sym_case] = ACTIONS(3655),
    [anon_sym_CASE] = ACTIONS(3655),
    [anon_sym_Case] = ACTIONS(3655),
    [anon_sym_for] = ACTIONS(3655),
    [anon_sym_FOR] = ACTIONS(3655),
    [anon_sym_For] = ACTIONS(3655),
    [anon_sym_foreach] = ACTIONS(3655),
    [anon_sym_FOREACH] = ACTIONS(3655),
    [anon_sym_Foreach] = ACTIONS(3655),
    [anon_sym_while] = ACTIONS(3655),
    [anon_sym_WHILE] = ACTIONS(3655),
    [anon_sym_While] = ACTIONS(3655),
    [anon_sym_repeat] = ACTIONS(3655),
    [anon_sym_REPEAT] = ACTIONS(3655),
    [anon_sym_Repeat] = ACTIONS(3655),
    [anon_sym_exit] = ACTIONS(3655),
    [anon_sym_EXIT] = ACTIONS(3655),
    [anon_sym_Exit] = ACTIONS(3655),
    [anon_sym_continue] = ACTIONS(3655),
    [anon_sym_CONTINUE] = ACTIONS(3655),
    [anon_sym_Continue] = ACTIONS(3655),
    [anon_sym_break] = ACTIONS(3655),
    [anon_sym_BREAK] = ACTIONS(3655),
    [anon_sym_Break] = ACTIONS(3655),
    [anon_sym_with] = ACTIONS(3655),
    [anon_sym_WITH] = ACTIONS(3655),
    [anon_sym_With] = ACTIONS(3655),
    [sym_asserterror_keyword] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3655),
    [anon_sym_IN] = ACTIONS(3655),
    [anon_sym_In] = ACTIONS(3655),
    [sym_page_keyword] = ACTIONS(3655),
    [anon_sym_codeunit] = ACTIONS(3655),
    [anon_sym_CODEUNIT] = ACTIONS(3655),
    [anon_sym_Codeunit] = ACTIONS(3655),
    [anon_sym_CodeUnit] = ACTIONS(3655),
    [anon_sym_COdeunit] = ACTIONS(3655),
    [anon_sym_codeUnit] = ACTIONS(3655),
    [sym_report_keyword] = ACTIONS(3655),
    [sym_query_keyword] = ACTIONS(3655),
    [anon_sym_xmlport] = ACTIONS(3655),
    [anon_sym_XMLPORT] = ACTIONS(3655),
    [anon_sym_Xmlport] = ACTIONS(3655),
    [anon_sym_XMLport] = ACTIONS(3655),
    [anon_sym_XMLPort] = ACTIONS(3655),
    [anon_sym_XmlPort] = ACTIONS(3655),
    [anon_sym_enum] = ACTIONS(3655),
    [anon_sym_ENUM] = ACTIONS(3655),
    [anon_sym_Enum] = ACTIONS(3655),
    [anon_sym_eNUM] = ACTIONS(3655),
    [anon_sym_eNum] = ACTIONS(3655),
    [anon_sym_ENum] = ACTIONS(3655),
    [sym_quoted_identifier] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3657),
    [sym_verbatim_string] = ACTIONS(3657),
    [sym_integer] = ACTIONS(3655),
    [sym_continue_as_identifier] = ACTIONS(3657),
    [sym_preproc_open] = ACTIONS(3657),
    [sym_preproc_close] = ACTIONS(3657),
  },
  [STATE(1781)] = {
    [sym_identifier] = ACTIONS(3659),
    [anon_sym_SEMI] = ACTIONS(3661),
    [anon_sym_DOT] = ACTIONS(3659),
    [anon_sym_EQ] = ACTIONS(3661),
    [anon_sym_COMMA] = ACTIONS(3661),
    [anon_sym_DASH] = ACTIONS(3659),
    [aux_sym_boolean_token1] = ACTIONS(3659),
    [aux_sym_boolean_token2] = ACTIONS(3659),
    [sym_decimal] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3661),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3661),
    [aux_sym_record_type_token1] = ACTIONS(3659),
    [aux_sym_basic_type_token21] = ACTIONS(3659),
    [aux_sym_basic_type_token22] = ACTIONS(3659),
    [aux_sym_basic_type_token48] = ACTIONS(3659),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3659),
    [anon_sym_COLON_COLON] = ACTIONS(3661),
    [anon_sym_POUNDif] = ACTIONS(3661),
    [anon_sym_POUNDIF] = ACTIONS(3661),
    [anon_sym_POUNDIf] = ACTIONS(3661),
    [anon_sym_not] = ACTIONS(3659),
    [anon_sym_NOT] = ACTIONS(3659),
    [anon_sym_Not] = ACTIONS(3659),
    [anon_sym_POUNDelif] = ACTIONS(3661),
    [anon_sym_POUNDELIF] = ACTIONS(3661),
    [anon_sym_POUNDElif] = ACTIONS(3661),
    [anon_sym_POUNDelse] = ACTIONS(3661),
    [anon_sym_POUNDELSE] = ACTIONS(3661),
    [anon_sym_POUNDElse] = ACTIONS(3661),
    [anon_sym_POUNDelse2] = ACTIONS(3661),
    [anon_sym_POUNDELSE2] = ACTIONS(3661),
    [anon_sym_POUNDElse2] = ACTIONS(3661),
    [anon_sym_POUNDendif] = ACTIONS(3661),
    [anon_sym_POUNDENDIF] = ACTIONS(3661),
    [anon_sym_POUNDEndif] = ACTIONS(3661),
    [anon_sym_POUNDendif2] = ACTIONS(3661),
    [anon_sym_POUNDENDIF2] = ACTIONS(3661),
    [anon_sym_POUNDEndif2] = ACTIONS(3661),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3661),
    [aux_sym__expression_token1] = ACTIONS(3661),
    [aux_sym__expression_token2] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3659),
    [anon_sym_SLASH] = ACTIONS(3659),
    [anon_sym_div] = ACTIONS(3659),
    [anon_sym_DIV] = ACTIONS(3659),
    [anon_sym_Div] = ACTIONS(3659),
    [anon_sym_mod] = ACTIONS(3659),
    [anon_sym_MOD] = ACTIONS(3659),
    [anon_sym_Mod] = ACTIONS(3659),
    [anon_sym_PLUS] = ACTIONS(3659),
    [anon_sym_GT_EQ] = ACTIONS(3661),
    [anon_sym_LT_EQ] = ACTIONS(3661),
    [anon_sym_GT] = ACTIONS(3659),
    [anon_sym_LT] = ACTIONS(3659),
    [anon_sym_LT_GT] = ACTIONS(3661),
    [anon_sym_and] = ACTIONS(3659),
    [anon_sym_AND] = ACTIONS(3659),
    [anon_sym_And] = ACTIONS(3659),
    [anon_sym_or] = ACTIONS(3659),
    [anon_sym_OR] = ACTIONS(3659),
    [anon_sym_Or] = ACTIONS(3659),
    [anon_sym_xor] = ACTIONS(3659),
    [anon_sym_XOR] = ACTIONS(3659),
    [anon_sym_Xor] = ACTIONS(3659),
    [anon_sym_QMARK] = ACTIONS(3661),
    [sym_datetime_literal] = ACTIONS(3661),
    [sym_date_literal] = ACTIONS(3659),
    [sym_time_literal] = ACTIONS(3659),
    [sym_biginteger_literal] = ACTIONS(3661),
    [anon_sym_if] = ACTIONS(3659),
    [anon_sym_IF] = ACTIONS(3659),
    [anon_sym_If] = ACTIONS(3659),
    [anon_sym_else] = ACTIONS(3659),
    [anon_sym_ELSE] = ACTIONS(3659),
    [anon_sym_Else] = ACTIONS(3659),
    [anon_sym_case] = ACTIONS(3659),
    [anon_sym_CASE] = ACTIONS(3659),
    [anon_sym_Case] = ACTIONS(3659),
    [anon_sym_for] = ACTIONS(3659),
    [anon_sym_FOR] = ACTIONS(3659),
    [anon_sym_For] = ACTIONS(3659),
    [anon_sym_foreach] = ACTIONS(3659),
    [anon_sym_FOREACH] = ACTIONS(3659),
    [anon_sym_Foreach] = ACTIONS(3659),
    [anon_sym_while] = ACTIONS(3659),
    [anon_sym_WHILE] = ACTIONS(3659),
    [anon_sym_While] = ACTIONS(3659),
    [anon_sym_repeat] = ACTIONS(3659),
    [anon_sym_REPEAT] = ACTIONS(3659),
    [anon_sym_Repeat] = ACTIONS(3659),
    [anon_sym_exit] = ACTIONS(3659),
    [anon_sym_EXIT] = ACTIONS(3659),
    [anon_sym_Exit] = ACTIONS(3659),
    [anon_sym_continue] = ACTIONS(3659),
    [anon_sym_CONTINUE] = ACTIONS(3659),
    [anon_sym_Continue] = ACTIONS(3659),
    [anon_sym_break] = ACTIONS(3659),
    [anon_sym_BREAK] = ACTIONS(3659),
    [anon_sym_Break] = ACTIONS(3659),
    [anon_sym_with] = ACTIONS(3659),
    [anon_sym_WITH] = ACTIONS(3659),
    [anon_sym_With] = ACTIONS(3659),
    [sym_asserterror_keyword] = ACTIONS(3661),
    [anon_sym_in] = ACTIONS(3659),
    [anon_sym_IN] = ACTIONS(3659),
    [anon_sym_In] = ACTIONS(3659),
    [sym_page_keyword] = ACTIONS(3659),
    [anon_sym_codeunit] = ACTIONS(3659),
    [anon_sym_CODEUNIT] = ACTIONS(3659),
    [anon_sym_Codeunit] = ACTIONS(3659),
    [anon_sym_CodeUnit] = ACTIONS(3659),
    [anon_sym_COdeunit] = ACTIONS(3659),
    [anon_sym_codeUnit] = ACTIONS(3659),
    [sym_report_keyword] = ACTIONS(3659),
    [sym_query_keyword] = ACTIONS(3659),
    [anon_sym_xmlport] = ACTIONS(3659),
    [anon_sym_XMLPORT] = ACTIONS(3659),
    [anon_sym_Xmlport] = ACTIONS(3659),
    [anon_sym_XMLport] = ACTIONS(3659),
    [anon_sym_XMLPort] = ACTIONS(3659),
    [anon_sym_XmlPort] = ACTIONS(3659),
    [anon_sym_enum] = ACTIONS(3659),
    [anon_sym_ENUM] = ACTIONS(3659),
    [anon_sym_Enum] = ACTIONS(3659),
    [anon_sym_eNUM] = ACTIONS(3659),
    [anon_sym_eNum] = ACTIONS(3659),
    [anon_sym_ENum] = ACTIONS(3659),
    [sym_quoted_identifier] = ACTIONS(3661),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3661),
    [sym_verbatim_string] = ACTIONS(3661),
    [sym_integer] = ACTIONS(3659),
    [sym_continue_as_identifier] = ACTIONS(3661),
    [sym_preproc_open] = ACTIONS(3661),
    [sym_preproc_close] = ACTIONS(3661),
  },
  [STATE(1782)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(1783)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1775),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_SEMI] = ACTIONS(3669),
    [anon_sym_DOT] = ACTIONS(3667),
    [anon_sym_EQ] = ACTIONS(3669),
    [anon_sym_COMMA] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3667),
    [aux_sym_boolean_token1] = ACTIONS(3667),
    [aux_sym_boolean_token2] = ACTIONS(3667),
    [sym_decimal] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3669),
    [anon_sym_DOT_DOT] = ACTIONS(3669),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3667),
    [anon_sym_STAR] = ACTIONS(3667),
    [anon_sym_LBRACK] = ACTIONS(3669),
    [aux_sym_record_type_token1] = ACTIONS(3667),
    [aux_sym_basic_type_token21] = ACTIONS(3667),
    [aux_sym_basic_type_token22] = ACTIONS(3667),
    [aux_sym_basic_type_token48] = ACTIONS(3667),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3667),
    [anon_sym_POUNDif] = ACTIONS(3669),
    [anon_sym_POUNDIF] = ACTIONS(3669),
    [anon_sym_POUNDIf] = ACTIONS(3669),
    [anon_sym_not] = ACTIONS(3667),
    [anon_sym_NOT] = ACTIONS(3667),
    [anon_sym_Not] = ACTIONS(3667),
    [anon_sym_POUNDelif] = ACTIONS(3669),
    [anon_sym_POUNDELIF] = ACTIONS(3669),
    [anon_sym_POUNDElif] = ACTIONS(3669),
    [anon_sym_POUNDelse] = ACTIONS(3669),
    [anon_sym_POUNDELSE] = ACTIONS(3669),
    [anon_sym_POUNDElse] = ACTIONS(3669),
    [anon_sym_POUNDelse2] = ACTIONS(3669),
    [anon_sym_POUNDELSE2] = ACTIONS(3669),
    [anon_sym_POUNDElse2] = ACTIONS(3669),
    [anon_sym_POUNDendif] = ACTIONS(3669),
    [anon_sym_POUNDENDIF] = ACTIONS(3669),
    [anon_sym_POUNDEndif] = ACTIONS(3669),
    [anon_sym_POUNDendif2] = ACTIONS(3669),
    [anon_sym_POUNDENDIF2] = ACTIONS(3669),
    [anon_sym_POUNDEndif2] = ACTIONS(3669),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3669),
    [aux_sym__expression_token1] = ACTIONS(3669),
    [aux_sym__expression_token2] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3667),
    [anon_sym_SLASH] = ACTIONS(3667),
    [anon_sym_div] = ACTIONS(3667),
    [anon_sym_DIV] = ACTIONS(3667),
    [anon_sym_Div] = ACTIONS(3667),
    [anon_sym_mod] = ACTIONS(3667),
    [anon_sym_MOD] = ACTIONS(3667),
    [anon_sym_Mod] = ACTIONS(3667),
    [anon_sym_PLUS] = ACTIONS(3667),
    [anon_sym_GT_EQ] = ACTIONS(3669),
    [anon_sym_LT_EQ] = ACTIONS(3669),
    [anon_sym_GT] = ACTIONS(3667),
    [anon_sym_LT] = ACTIONS(3667),
    [anon_sym_LT_GT] = ACTIONS(3669),
    [anon_sym_and] = ACTIONS(3667),
    [anon_sym_AND] = ACTIONS(3667),
    [anon_sym_And] = ACTIONS(3667),
    [anon_sym_or] = ACTIONS(3667),
    [anon_sym_OR] = ACTIONS(3667),
    [anon_sym_Or] = ACTIONS(3667),
    [anon_sym_xor] = ACTIONS(3667),
    [anon_sym_XOR] = ACTIONS(3667),
    [anon_sym_Xor] = ACTIONS(3667),
    [anon_sym_QMARK] = ACTIONS(3669),
    [sym_datetime_literal] = ACTIONS(3669),
    [sym_date_literal] = ACTIONS(3667),
    [sym_time_literal] = ACTIONS(3667),
    [sym_biginteger_literal] = ACTIONS(3669),
    [anon_sym_if] = ACTIONS(3667),
    [anon_sym_IF] = ACTIONS(3667),
    [anon_sym_If] = ACTIONS(3667),
    [anon_sym_else] = ACTIONS(3667),
    [anon_sym_ELSE] = ACTIONS(3667),
    [anon_sym_Else] = ACTIONS(3667),
    [anon_sym_case] = ACTIONS(3667),
    [anon_sym_CASE] = ACTIONS(3667),
    [anon_sym_Case] = ACTIONS(3667),
    [anon_sym_for] = ACTIONS(3667),
    [anon_sym_FOR] = ACTIONS(3667),
    [anon_sym_For] = ACTIONS(3667),
    [anon_sym_foreach] = ACTIONS(3667),
    [anon_sym_FOREACH] = ACTIONS(3667),
    [anon_sym_Foreach] = ACTIONS(3667),
    [anon_sym_while] = ACTIONS(3667),
    [anon_sym_WHILE] = ACTIONS(3667),
    [anon_sym_While] = ACTIONS(3667),
    [anon_sym_repeat] = ACTIONS(3667),
    [anon_sym_REPEAT] = ACTIONS(3667),
    [anon_sym_Repeat] = ACTIONS(3667),
    [anon_sym_exit] = ACTIONS(3667),
    [anon_sym_EXIT] = ACTIONS(3667),
    [anon_sym_Exit] = ACTIONS(3667),
    [anon_sym_continue] = ACTIONS(3667),
    [anon_sym_CONTINUE] = ACTIONS(3667),
    [anon_sym_Continue] = ACTIONS(3667),
    [anon_sym_break] = ACTIONS(3667),
    [anon_sym_BREAK] = ACTIONS(3667),
    [anon_sym_Break] = ACTIONS(3667),
    [anon_sym_with] = ACTIONS(3667),
    [anon_sym_WITH] = ACTIONS(3667),
    [anon_sym_With] = ACTIONS(3667),
    [sym_asserterror_keyword] = ACTIONS(3669),
    [anon_sym_in] = ACTIONS(3667),
    [anon_sym_IN] = ACTIONS(3667),
    [anon_sym_In] = ACTIONS(3667),
    [sym_page_keyword] = ACTIONS(3667),
    [anon_sym_codeunit] = ACTIONS(3667),
    [anon_sym_CODEUNIT] = ACTIONS(3667),
    [anon_sym_Codeunit] = ACTIONS(3667),
    [anon_sym_CodeUnit] = ACTIONS(3667),
    [anon_sym_COdeunit] = ACTIONS(3667),
    [anon_sym_codeUnit] = ACTIONS(3667),
    [sym_report_keyword] = ACTIONS(3667),
    [sym_query_keyword] = ACTIONS(3667),
    [anon_sym_xmlport] = ACTIONS(3667),
    [anon_sym_XMLPORT] = ACTIONS(3667),
    [anon_sym_Xmlport] = ACTIONS(3667),
    [anon_sym_XMLport] = ACTIONS(3667),
    [anon_sym_XMLPort] = ACTIONS(3667),
    [anon_sym_XmlPort] = ACTIONS(3667),
    [anon_sym_enum] = ACTIONS(3667),
    [anon_sym_ENUM] = ACTIONS(3667),
    [anon_sym_Enum] = ACTIONS(3667),
    [anon_sym_eNUM] = ACTIONS(3667),
    [anon_sym_eNum] = ACTIONS(3667),
    [anon_sym_ENum] = ACTIONS(3667),
    [sym_quoted_identifier] = ACTIONS(3669),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3669),
    [sym_verbatim_string] = ACTIONS(3669),
    [sym_integer] = ACTIONS(3667),
    [sym_continue_as_identifier] = ACTIONS(3669),
    [sym_preproc_open] = ACTIONS(3669),
    [sym_preproc_close] = ACTIONS(3669),
  },
  [STATE(1784)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1796),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(602),
    [aux_sym_boolean_token1] = ACTIONS(602),
    [aux_sym_boolean_token2] = ACTIONS(602),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(602),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(602),
    [aux_sym_basic_type_token21] = ACTIONS(602),
    [aux_sym_basic_type_token22] = ACTIONS(602),
    [aux_sym_basic_type_token48] = ACTIONS(602),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(602),
    [aux_sym_keyword_identifier_token1] = ACTIONS(602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(602),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(602),
    [anon_sym_IF] = ACTIONS(602),
    [anon_sym_If] = ACTIONS(602),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_case] = ACTIONS(602),
    [anon_sym_CASE] = ACTIONS(602),
    [anon_sym_Case] = ACTIONS(602),
    [anon_sym_for] = ACTIONS(602),
    [anon_sym_FOR] = ACTIONS(602),
    [anon_sym_For] = ACTIONS(602),
    [anon_sym_foreach] = ACTIONS(602),
    [anon_sym_FOREACH] = ACTIONS(602),
    [anon_sym_Foreach] = ACTIONS(602),
    [anon_sym_while] = ACTIONS(602),
    [anon_sym_WHILE] = ACTIONS(602),
    [anon_sym_While] = ACTIONS(602),
    [anon_sym_repeat] = ACTIONS(602),
    [anon_sym_REPEAT] = ACTIONS(602),
    [anon_sym_Repeat] = ACTIONS(602),
    [anon_sym_exit] = ACTIONS(602),
    [anon_sym_EXIT] = ACTIONS(602),
    [anon_sym_Exit] = ACTIONS(602),
    [anon_sym_continue] = ACTIONS(602),
    [anon_sym_CONTINUE] = ACTIONS(602),
    [anon_sym_Continue] = ACTIONS(602),
    [anon_sym_break] = ACTIONS(602),
    [anon_sym_BREAK] = ACTIONS(602),
    [anon_sym_Break] = ACTIONS(602),
    [anon_sym_with] = ACTIONS(602),
    [anon_sym_WITH] = ACTIONS(602),
    [anon_sym_With] = ACTIONS(602),
    [sym_asserterror_keyword] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_page_keyword] = ACTIONS(602),
    [anon_sym_codeunit] = ACTIONS(602),
    [anon_sym_CODEUNIT] = ACTIONS(602),
    [anon_sym_Codeunit] = ACTIONS(602),
    [anon_sym_CodeUnit] = ACTIONS(602),
    [anon_sym_COdeunit] = ACTIONS(602),
    [anon_sym_codeUnit] = ACTIONS(602),
    [sym_report_keyword] = ACTIONS(602),
    [sym_query_keyword] = ACTIONS(602),
    [anon_sym_xmlport] = ACTIONS(602),
    [anon_sym_XMLPORT] = ACTIONS(602),
    [anon_sym_Xmlport] = ACTIONS(602),
    [anon_sym_XMLport] = ACTIONS(602),
    [anon_sym_XMLPort] = ACTIONS(602),
    [anon_sym_XmlPort] = ACTIONS(602),
    [anon_sym_enum] = ACTIONS(602),
    [anon_sym_ENUM] = ACTIONS(602),
    [anon_sym_Enum] = ACTIONS(602),
    [anon_sym_eNUM] = ACTIONS(602),
    [anon_sym_eNum] = ACTIONS(602),
    [anon_sym_ENum] = ACTIONS(602),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(600),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(602),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
  },
  [STATE(1785)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3673),
    [anon_sym_SEMI] = ACTIONS(3675),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3673),
    [aux_sym_boolean_token2] = ACTIONS(3673),
    [sym_decimal] = ACTIONS(3673),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3673),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3673),
    [aux_sym_basic_type_token21] = ACTIONS(3673),
    [aux_sym_basic_type_token22] = ACTIONS(3673),
    [aux_sym_basic_type_token48] = ACTIONS(3673),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3673),
    [anon_sym_POUNDif] = ACTIONS(3675),
    [anon_sym_POUNDIF] = ACTIONS(3675),
    [anon_sym_POUNDIf] = ACTIONS(3675),
    [anon_sym_not] = ACTIONS(3673),
    [anon_sym_NOT] = ACTIONS(3673),
    [anon_sym_Not] = ACTIONS(3673),
    [anon_sym_POUNDelif] = ACTIONS(3675),
    [anon_sym_POUNDELIF] = ACTIONS(3675),
    [anon_sym_POUNDElif] = ACTIONS(3675),
    [anon_sym_POUNDelse] = ACTIONS(3675),
    [anon_sym_POUNDELSE] = ACTIONS(3675),
    [anon_sym_POUNDElse] = ACTIONS(3675),
    [anon_sym_POUNDelse2] = ACTIONS(3675),
    [anon_sym_POUNDELSE2] = ACTIONS(3675),
    [anon_sym_POUNDElse2] = ACTIONS(3675),
    [anon_sym_POUNDendif] = ACTIONS(3675),
    [anon_sym_POUNDENDIF] = ACTIONS(3675),
    [anon_sym_POUNDEndif] = ACTIONS(3675),
    [anon_sym_POUNDendif2] = ACTIONS(3675),
    [anon_sym_POUNDENDIF2] = ACTIONS(3675),
    [anon_sym_POUNDEndif2] = ACTIONS(3675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3675),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3673),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3616),
    [anon_sym_OR] = ACTIONS(3618),
    [anon_sym_Or] = ACTIONS(3620),
    [anon_sym_xor] = ACTIONS(3622),
    [anon_sym_XOR] = ACTIONS(3624),
    [anon_sym_Xor] = ACTIONS(3626),
    [anon_sym_QMARK] = ACTIONS(3628),
    [sym_datetime_literal] = ACTIONS(3675),
    [sym_date_literal] = ACTIONS(3673),
    [sym_time_literal] = ACTIONS(3673),
    [sym_biginteger_literal] = ACTIONS(3675),
    [anon_sym_if] = ACTIONS(3673),
    [anon_sym_IF] = ACTIONS(3673),
    [anon_sym_If] = ACTIONS(3673),
    [anon_sym_else] = ACTIONS(3673),
    [anon_sym_ELSE] = ACTIONS(3673),
    [anon_sym_Else] = ACTIONS(3673),
    [anon_sym_case] = ACTIONS(3673),
    [anon_sym_CASE] = ACTIONS(3673),
    [anon_sym_Case] = ACTIONS(3673),
    [anon_sym_for] = ACTIONS(3673),
    [anon_sym_FOR] = ACTIONS(3673),
    [anon_sym_For] = ACTIONS(3673),
    [anon_sym_foreach] = ACTIONS(3673),
    [anon_sym_FOREACH] = ACTIONS(3673),
    [anon_sym_Foreach] = ACTIONS(3673),
    [anon_sym_while] = ACTIONS(3673),
    [anon_sym_WHILE] = ACTIONS(3673),
    [anon_sym_While] = ACTIONS(3673),
    [anon_sym_repeat] = ACTIONS(3673),
    [anon_sym_REPEAT] = ACTIONS(3673),
    [anon_sym_Repeat] = ACTIONS(3673),
    [anon_sym_exit] = ACTIONS(3673),
    [anon_sym_EXIT] = ACTIONS(3673),
    [anon_sym_Exit] = ACTIONS(3673),
    [anon_sym_continue] = ACTIONS(3673),
    [anon_sym_CONTINUE] = ACTIONS(3673),
    [anon_sym_Continue] = ACTIONS(3673),
    [anon_sym_break] = ACTIONS(3673),
    [anon_sym_BREAK] = ACTIONS(3673),
    [anon_sym_Break] = ACTIONS(3673),
    [anon_sym_with] = ACTIONS(3673),
    [anon_sym_WITH] = ACTIONS(3673),
    [anon_sym_With] = ACTIONS(3673),
    [sym_asserterror_keyword] = ACTIONS(3675),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3673),
    [anon_sym_codeunit] = ACTIONS(3673),
    [anon_sym_CODEUNIT] = ACTIONS(3673),
    [anon_sym_Codeunit] = ACTIONS(3673),
    [anon_sym_CodeUnit] = ACTIONS(3673),
    [anon_sym_COdeunit] = ACTIONS(3673),
    [anon_sym_codeUnit] = ACTIONS(3673),
    [sym_report_keyword] = ACTIONS(3673),
    [sym_query_keyword] = ACTIONS(3673),
    [anon_sym_xmlport] = ACTIONS(3673),
    [anon_sym_XMLPORT] = ACTIONS(3673),
    [anon_sym_Xmlport] = ACTIONS(3673),
    [anon_sym_XMLport] = ACTIONS(3673),
    [anon_sym_XMLPort] = ACTIONS(3673),
    [anon_sym_XmlPort] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_ENUM] = ACTIONS(3673),
    [anon_sym_Enum] = ACTIONS(3673),
    [anon_sym_eNUM] = ACTIONS(3673),
    [anon_sym_eNum] = ACTIONS(3673),
    [anon_sym_ENum] = ACTIONS(3673),
    [sym_quoted_identifier] = ACTIONS(3675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3675),
    [sym_verbatim_string] = ACTIONS(3675),
    [sym_integer] = ACTIONS(3673),
    [sym_continue_as_identifier] = ACTIONS(3675),
    [sym_preproc_open] = ACTIONS(3675),
    [sym_preproc_close] = ACTIONS(3675),
  },
  [STATE(1786)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelif] = ACTIONS(3679),
    [anon_sym_POUNDELIF] = ACTIONS(3679),
    [anon_sym_POUNDElif] = ACTIONS(3679),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [anon_sym_POUNDendif] = ACTIONS(3679),
    [anon_sym_POUNDENDIF] = ACTIONS(3679),
    [anon_sym_POUNDEndif] = ACTIONS(3679),
    [anon_sym_POUNDendif2] = ACTIONS(3679),
    [anon_sym_POUNDENDIF2] = ACTIONS(3679),
    [anon_sym_POUNDEndif2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_if] = ACTIONS(3677),
    [anon_sym_IF] = ACTIONS(3677),
    [anon_sym_If] = ACTIONS(3677),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_case] = ACTIONS(3677),
    [anon_sym_CASE] = ACTIONS(3677),
    [anon_sym_Case] = ACTIONS(3677),
    [anon_sym_for] = ACTIONS(3677),
    [anon_sym_FOR] = ACTIONS(3677),
    [anon_sym_For] = ACTIONS(3677),
    [anon_sym_foreach] = ACTIONS(3677),
    [anon_sym_FOREACH] = ACTIONS(3677),
    [anon_sym_Foreach] = ACTIONS(3677),
    [anon_sym_while] = ACTIONS(3677),
    [anon_sym_WHILE] = ACTIONS(3677),
    [anon_sym_While] = ACTIONS(3677),
    [anon_sym_repeat] = ACTIONS(3677),
    [anon_sym_REPEAT] = ACTIONS(3677),
    [anon_sym_Repeat] = ACTIONS(3677),
    [anon_sym_exit] = ACTIONS(3677),
    [anon_sym_EXIT] = ACTIONS(3677),
    [anon_sym_Exit] = ACTIONS(3677),
    [anon_sym_continue] = ACTIONS(3677),
    [anon_sym_CONTINUE] = ACTIONS(3677),
    [anon_sym_Continue] = ACTIONS(3677),
    [anon_sym_break] = ACTIONS(3677),
    [anon_sym_BREAK] = ACTIONS(3677),
    [anon_sym_Break] = ACTIONS(3677),
    [anon_sym_with] = ACTIONS(3677),
    [anon_sym_WITH] = ACTIONS(3677),
    [anon_sym_With] = ACTIONS(3677),
    [sym_asserterror_keyword] = ACTIONS(3679),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
    [sym_preproc_close] = ACTIONS(3679),
  },
  [STATE(1787)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(1788)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(1789)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1790)] = {
    [sym_argument_list] = STATE(1833),
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(3685),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(3687),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelif] = ACTIONS(3683),
    [anon_sym_POUNDELIF] = ACTIONS(3683),
    [anon_sym_POUNDElif] = ACTIONS(3683),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [anon_sym_POUNDendif] = ACTIONS(3683),
    [anon_sym_POUNDENDIF] = ACTIONS(3683),
    [anon_sym_POUNDEndif] = ACTIONS(3683),
    [anon_sym_POUNDendif2] = ACTIONS(3683),
    [anon_sym_POUNDENDIF2] = ACTIONS(3683),
    [anon_sym_POUNDEndif2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_IF] = ACTIONS(3681),
    [anon_sym_If] = ACTIONS(3681),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_case] = ACTIONS(3681),
    [anon_sym_CASE] = ACTIONS(3681),
    [anon_sym_Case] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_FOR] = ACTIONS(3681),
    [anon_sym_For] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_FOREACH] = ACTIONS(3681),
    [anon_sym_Foreach] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_WHILE] = ACTIONS(3681),
    [anon_sym_While] = ACTIONS(3681),
    [anon_sym_repeat] = ACTIONS(3681),
    [anon_sym_REPEAT] = ACTIONS(3681),
    [anon_sym_Repeat] = ACTIONS(3681),
    [anon_sym_exit] = ACTIONS(3681),
    [anon_sym_EXIT] = ACTIONS(3681),
    [anon_sym_Exit] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_CONTINUE] = ACTIONS(3681),
    [anon_sym_Continue] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_BREAK] = ACTIONS(3681),
    [anon_sym_Break] = ACTIONS(3681),
    [anon_sym_with] = ACTIONS(3681),
    [anon_sym_WITH] = ACTIONS(3681),
    [anon_sym_With] = ACTIONS(3681),
    [sym_asserterror_keyword] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
    [sym_preproc_close] = ACTIONS(3683),
  },
  [STATE(1791)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(1792)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1793)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(1794)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(1795)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelif] = ACTIONS(3679),
    [anon_sym_POUNDELIF] = ACTIONS(3679),
    [anon_sym_POUNDElif] = ACTIONS(3679),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [anon_sym_POUNDendif] = ACTIONS(3679),
    [anon_sym_POUNDENDIF] = ACTIONS(3679),
    [anon_sym_POUNDEndif] = ACTIONS(3679),
    [anon_sym_POUNDendif2] = ACTIONS(3679),
    [anon_sym_POUNDENDIF2] = ACTIONS(3679),
    [anon_sym_POUNDEndif2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_if] = ACTIONS(3677),
    [anon_sym_IF] = ACTIONS(3677),
    [anon_sym_If] = ACTIONS(3677),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_case] = ACTIONS(3677),
    [anon_sym_CASE] = ACTIONS(3677),
    [anon_sym_Case] = ACTIONS(3677),
    [anon_sym_for] = ACTIONS(3677),
    [anon_sym_FOR] = ACTIONS(3677),
    [anon_sym_For] = ACTIONS(3677),
    [anon_sym_foreach] = ACTIONS(3677),
    [anon_sym_FOREACH] = ACTIONS(3677),
    [anon_sym_Foreach] = ACTIONS(3677),
    [anon_sym_while] = ACTIONS(3677),
    [anon_sym_WHILE] = ACTIONS(3677),
    [anon_sym_While] = ACTIONS(3677),
    [anon_sym_repeat] = ACTIONS(3677),
    [anon_sym_REPEAT] = ACTIONS(3677),
    [anon_sym_Repeat] = ACTIONS(3677),
    [anon_sym_exit] = ACTIONS(3677),
    [anon_sym_EXIT] = ACTIONS(3677),
    [anon_sym_Exit] = ACTIONS(3677),
    [anon_sym_continue] = ACTIONS(3677),
    [anon_sym_CONTINUE] = ACTIONS(3677),
    [anon_sym_Continue] = ACTIONS(3677),
    [anon_sym_break] = ACTIONS(3677),
    [anon_sym_BREAK] = ACTIONS(3677),
    [anon_sym_Break] = ACTIONS(3677),
    [anon_sym_with] = ACTIONS(3677),
    [anon_sym_WITH] = ACTIONS(3677),
    [anon_sym_With] = ACTIONS(3677),
    [sym_asserterror_keyword] = ACTIONS(3679),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
    [sym_preproc_close] = ACTIONS(3679),
  },
  [STATE(1796)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1775),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelif] = ACTIONS(3691),
    [anon_sym_POUNDELIF] = ACTIONS(3691),
    [anon_sym_POUNDElif] = ACTIONS(3691),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [anon_sym_POUNDendif] = ACTIONS(3691),
    [anon_sym_POUNDENDIF] = ACTIONS(3691),
    [anon_sym_POUNDEndif] = ACTIONS(3691),
    [anon_sym_POUNDendif2] = ACTIONS(3691),
    [anon_sym_POUNDENDIF2] = ACTIONS(3691),
    [anon_sym_POUNDEndif2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_if] = ACTIONS(3689),
    [anon_sym_IF] = ACTIONS(3689),
    [anon_sym_If] = ACTIONS(3689),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_case] = ACTIONS(3689),
    [anon_sym_CASE] = ACTIONS(3689),
    [anon_sym_Case] = ACTIONS(3689),
    [anon_sym_for] = ACTIONS(3689),
    [anon_sym_FOR] = ACTIONS(3689),
    [anon_sym_For] = ACTIONS(3689),
    [anon_sym_foreach] = ACTIONS(3689),
    [anon_sym_FOREACH] = ACTIONS(3689),
    [anon_sym_Foreach] = ACTIONS(3689),
    [anon_sym_while] = ACTIONS(3689),
    [anon_sym_WHILE] = ACTIONS(3689),
    [anon_sym_While] = ACTIONS(3689),
    [anon_sym_repeat] = ACTIONS(3689),
    [anon_sym_REPEAT] = ACTIONS(3689),
    [anon_sym_Repeat] = ACTIONS(3689),
    [anon_sym_exit] = ACTIONS(3689),
    [anon_sym_EXIT] = ACTIONS(3689),
    [anon_sym_Exit] = ACTIONS(3689),
    [anon_sym_continue] = ACTIONS(3689),
    [anon_sym_CONTINUE] = ACTIONS(3689),
    [anon_sym_Continue] = ACTIONS(3689),
    [anon_sym_break] = ACTIONS(3689),
    [anon_sym_BREAK] = ACTIONS(3689),
    [anon_sym_Break] = ACTIONS(3689),
    [anon_sym_with] = ACTIONS(3689),
    [anon_sym_WITH] = ACTIONS(3689),
    [anon_sym_With] = ACTIONS(3689),
    [sym_asserterror_keyword] = ACTIONS(3691),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
    [sym_preproc_close] = ACTIONS(3691),
  },
  [STATE(1797)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1783),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelif] = ACTIONS(3691),
    [anon_sym_POUNDELIF] = ACTIONS(3691),
    [anon_sym_POUNDElif] = ACTIONS(3691),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [anon_sym_POUNDendif] = ACTIONS(3691),
    [anon_sym_POUNDENDIF] = ACTIONS(3691),
    [anon_sym_POUNDEndif] = ACTIONS(3691),
    [anon_sym_POUNDendif2] = ACTIONS(3691),
    [anon_sym_POUNDENDIF2] = ACTIONS(3691),
    [anon_sym_POUNDEndif2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_if] = ACTIONS(3689),
    [anon_sym_IF] = ACTIONS(3689),
    [anon_sym_If] = ACTIONS(3689),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_case] = ACTIONS(3689),
    [anon_sym_CASE] = ACTIONS(3689),
    [anon_sym_Case] = ACTIONS(3689),
    [anon_sym_for] = ACTIONS(3689),
    [anon_sym_FOR] = ACTIONS(3689),
    [anon_sym_For] = ACTIONS(3689),
    [anon_sym_foreach] = ACTIONS(3689),
    [anon_sym_FOREACH] = ACTIONS(3689),
    [anon_sym_Foreach] = ACTIONS(3689),
    [anon_sym_while] = ACTIONS(3689),
    [anon_sym_WHILE] = ACTIONS(3689),
    [anon_sym_While] = ACTIONS(3689),
    [anon_sym_repeat] = ACTIONS(3689),
    [anon_sym_REPEAT] = ACTIONS(3689),
    [anon_sym_Repeat] = ACTIONS(3689),
    [anon_sym_exit] = ACTIONS(3689),
    [anon_sym_EXIT] = ACTIONS(3689),
    [anon_sym_Exit] = ACTIONS(3689),
    [anon_sym_continue] = ACTIONS(3689),
    [anon_sym_CONTINUE] = ACTIONS(3689),
    [anon_sym_Continue] = ACTIONS(3689),
    [anon_sym_break] = ACTIONS(3689),
    [anon_sym_BREAK] = ACTIONS(3689),
    [anon_sym_Break] = ACTIONS(3689),
    [anon_sym_with] = ACTIONS(3689),
    [anon_sym_WITH] = ACTIONS(3689),
    [anon_sym_With] = ACTIONS(3689),
    [sym_asserterror_keyword] = ACTIONS(3691),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
    [sym_preproc_close] = ACTIONS(3691),
  },
  [STATE(1798)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1799)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1800),
    [sym_identifier] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(3697),
    [anon_sym_EQ] = ACTIONS(3695),
    [anon_sym_DASH] = ACTIONS(3693),
    [aux_sym_boolean_token1] = ACTIONS(3693),
    [aux_sym_boolean_token2] = ACTIONS(3693),
    [sym_decimal] = ACTIONS(3693),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_DOT_DOT] = ACTIONS(3695),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [aux_sym_record_type_token1] = ACTIONS(3693),
    [aux_sym_basic_type_token21] = ACTIONS(3693),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_basic_type_token48] = ACTIONS(3693),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_not] = ACTIONS(3693),
    [anon_sym_NOT] = ACTIONS(3693),
    [anon_sym_Not] = ACTIONS(3693),
    [anon_sym_POUNDelif] = ACTIONS(3695),
    [anon_sym_POUNDELIF] = ACTIONS(3695),
    [anon_sym_POUNDElif] = ACTIONS(3695),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [anon_sym_POUNDendif] = ACTIONS(3695),
    [anon_sym_POUNDENDIF] = ACTIONS(3695),
    [anon_sym_POUNDEndif] = ACTIONS(3695),
    [anon_sym_POUNDendif2] = ACTIONS(3695),
    [anon_sym_POUNDENDIF2] = ACTIONS(3695),
    [anon_sym_POUNDEndif2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3695),
    [aux_sym__expression_token1] = ACTIONS(3695),
    [aux_sym__expression_token2] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3693),
    [anon_sym_SLASH] = ACTIONS(3693),
    [anon_sym_div] = ACTIONS(3693),
    [anon_sym_DIV] = ACTIONS(3693),
    [anon_sym_Div] = ACTIONS(3693),
    [anon_sym_mod] = ACTIONS(3693),
    [anon_sym_MOD] = ACTIONS(3693),
    [anon_sym_Mod] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(3693),
    [anon_sym_GT_EQ] = ACTIONS(3695),
    [anon_sym_LT_EQ] = ACTIONS(3695),
    [anon_sym_GT] = ACTIONS(3693),
    [anon_sym_LT] = ACTIONS(3693),
    [anon_sym_LT_GT] = ACTIONS(3695),
    [anon_sym_and] = ACTIONS(3693),
    [anon_sym_AND] = ACTIONS(3693),
    [anon_sym_And] = ACTIONS(3693),
    [anon_sym_or] = ACTIONS(3693),
    [anon_sym_OR] = ACTIONS(3693),
    [anon_sym_Or] = ACTIONS(3693),
    [anon_sym_xor] = ACTIONS(3693),
    [anon_sym_XOR] = ACTIONS(3693),
    [anon_sym_Xor] = ACTIONS(3693),
    [anon_sym_QMARK] = ACTIONS(3695),
    [sym_datetime_literal] = ACTIONS(3695),
    [sym_date_literal] = ACTIONS(3693),
    [sym_time_literal] = ACTIONS(3693),
    [sym_biginteger_literal] = ACTIONS(3695),
    [anon_sym_if] = ACTIONS(3693),
    [anon_sym_IF] = ACTIONS(3693),
    [anon_sym_If] = ACTIONS(3693),
    [anon_sym_else] = ACTIONS(3693),
    [anon_sym_ELSE] = ACTIONS(3693),
    [anon_sym_Else] = ACTIONS(3693),
    [anon_sym_case] = ACTIONS(3693),
    [anon_sym_CASE] = ACTIONS(3693),
    [anon_sym_Case] = ACTIONS(3693),
    [anon_sym_for] = ACTIONS(3693),
    [anon_sym_FOR] = ACTIONS(3693),
    [anon_sym_For] = ACTIONS(3693),
    [anon_sym_foreach] = ACTIONS(3693),
    [anon_sym_FOREACH] = ACTIONS(3693),
    [anon_sym_Foreach] = ACTIONS(3693),
    [anon_sym_while] = ACTIONS(3693),
    [anon_sym_WHILE] = ACTIONS(3693),
    [anon_sym_While] = ACTIONS(3693),
    [anon_sym_repeat] = ACTIONS(3693),
    [anon_sym_REPEAT] = ACTIONS(3693),
    [anon_sym_Repeat] = ACTIONS(3693),
    [anon_sym_exit] = ACTIONS(3693),
    [anon_sym_EXIT] = ACTIONS(3693),
    [anon_sym_Exit] = ACTIONS(3693),
    [anon_sym_continue] = ACTIONS(3693),
    [anon_sym_CONTINUE] = ACTIONS(3693),
    [anon_sym_Continue] = ACTIONS(3693),
    [anon_sym_break] = ACTIONS(3693),
    [anon_sym_BREAK] = ACTIONS(3693),
    [anon_sym_Break] = ACTIONS(3693),
    [anon_sym_with] = ACTIONS(3693),
    [anon_sym_WITH] = ACTIONS(3693),
    [anon_sym_With] = ACTIONS(3693),
    [sym_asserterror_keyword] = ACTIONS(3695),
    [anon_sym_in] = ACTIONS(3693),
    [anon_sym_IN] = ACTIONS(3693),
    [anon_sym_In] = ACTIONS(3693),
    [sym_page_keyword] = ACTIONS(3693),
    [anon_sym_codeunit] = ACTIONS(3693),
    [anon_sym_CODEUNIT] = ACTIONS(3693),
    [anon_sym_Codeunit] = ACTIONS(3693),
    [anon_sym_CodeUnit] = ACTIONS(3693),
    [anon_sym_COdeunit] = ACTIONS(3693),
    [anon_sym_codeUnit] = ACTIONS(3693),
    [sym_report_keyword] = ACTIONS(3693),
    [sym_query_keyword] = ACTIONS(3693),
    [anon_sym_xmlport] = ACTIONS(3693),
    [anon_sym_XMLPORT] = ACTIONS(3693),
    [anon_sym_Xmlport] = ACTIONS(3693),
    [anon_sym_XMLport] = ACTIONS(3693),
    [anon_sym_XMLPort] = ACTIONS(3693),
    [anon_sym_XmlPort] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_ENUM] = ACTIONS(3693),
    [anon_sym_Enum] = ACTIONS(3693),
    [anon_sym_eNUM] = ACTIONS(3693),
    [anon_sym_eNum] = ACTIONS(3693),
    [anon_sym_ENum] = ACTIONS(3693),
    [sym_temporary_keyword] = ACTIONS(3693),
    [sym_quoted_identifier] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3695),
    [sym_verbatim_string] = ACTIONS(3695),
    [sym_integer] = ACTIONS(3693),
    [sym_continue_as_identifier] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
    [sym_preproc_close] = ACTIONS(3695),
  },
  [STATE(1800)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1801),
    [sym_identifier] = ACTIONS(3699),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(3697),
    [anon_sym_EQ] = ACTIONS(3701),
    [anon_sym_DASH] = ACTIONS(3699),
    [aux_sym_boolean_token1] = ACTIONS(3699),
    [aux_sym_boolean_token2] = ACTIONS(3699),
    [sym_decimal] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_DOT_DOT] = ACTIONS(3701),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3699),
    [anon_sym_STAR] = ACTIONS(3699),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [aux_sym_record_type_token1] = ACTIONS(3699),
    [aux_sym_basic_type_token21] = ACTIONS(3699),
    [aux_sym_basic_type_token22] = ACTIONS(3699),
    [aux_sym_basic_type_token48] = ACTIONS(3699),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3699),
    [anon_sym_POUNDif] = ACTIONS(3701),
    [anon_sym_POUNDIF] = ACTIONS(3701),
    [anon_sym_POUNDIf] = ACTIONS(3701),
    [anon_sym_not] = ACTIONS(3699),
    [anon_sym_NOT] = ACTIONS(3699),
    [anon_sym_Not] = ACTIONS(3699),
    [anon_sym_POUNDelif] = ACTIONS(3701),
    [anon_sym_POUNDELIF] = ACTIONS(3701),
    [anon_sym_POUNDElif] = ACTIONS(3701),
    [anon_sym_POUNDelse] = ACTIONS(3701),
    [anon_sym_POUNDELSE] = ACTIONS(3701),
    [anon_sym_POUNDElse] = ACTIONS(3701),
    [anon_sym_POUNDelse2] = ACTIONS(3701),
    [anon_sym_POUNDELSE2] = ACTIONS(3701),
    [anon_sym_POUNDElse2] = ACTIONS(3701),
    [anon_sym_POUNDendif] = ACTIONS(3701),
    [anon_sym_POUNDENDIF] = ACTIONS(3701),
    [anon_sym_POUNDEndif] = ACTIONS(3701),
    [anon_sym_POUNDendif2] = ACTIONS(3701),
    [anon_sym_POUNDENDIF2] = ACTIONS(3701),
    [anon_sym_POUNDEndif2] = ACTIONS(3701),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3701),
    [aux_sym__expression_token1] = ACTIONS(3701),
    [aux_sym__expression_token2] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3699),
    [anon_sym_SLASH] = ACTIONS(3699),
    [anon_sym_div] = ACTIONS(3699),
    [anon_sym_DIV] = ACTIONS(3699),
    [anon_sym_Div] = ACTIONS(3699),
    [anon_sym_mod] = ACTIONS(3699),
    [anon_sym_MOD] = ACTIONS(3699),
    [anon_sym_Mod] = ACTIONS(3699),
    [anon_sym_PLUS] = ACTIONS(3699),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT] = ACTIONS(3699),
    [anon_sym_LT] = ACTIONS(3699),
    [anon_sym_LT_GT] = ACTIONS(3701),
    [anon_sym_and] = ACTIONS(3699),
    [anon_sym_AND] = ACTIONS(3699),
    [anon_sym_And] = ACTIONS(3699),
    [anon_sym_or] = ACTIONS(3699),
    [anon_sym_OR] = ACTIONS(3699),
    [anon_sym_Or] = ACTIONS(3699),
    [anon_sym_xor] = ACTIONS(3699),
    [anon_sym_XOR] = ACTIONS(3699),
    [anon_sym_Xor] = ACTIONS(3699),
    [anon_sym_QMARK] = ACTIONS(3701),
    [sym_datetime_literal] = ACTIONS(3701),
    [sym_date_literal] = ACTIONS(3699),
    [sym_time_literal] = ACTIONS(3699),
    [sym_biginteger_literal] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3699),
    [anon_sym_IF] = ACTIONS(3699),
    [anon_sym_If] = ACTIONS(3699),
    [anon_sym_else] = ACTIONS(3699),
    [anon_sym_ELSE] = ACTIONS(3699),
    [anon_sym_Else] = ACTIONS(3699),
    [anon_sym_case] = ACTIONS(3699),
    [anon_sym_CASE] = ACTIONS(3699),
    [anon_sym_Case] = ACTIONS(3699),
    [anon_sym_for] = ACTIONS(3699),
    [anon_sym_FOR] = ACTIONS(3699),
    [anon_sym_For] = ACTIONS(3699),
    [anon_sym_foreach] = ACTIONS(3699),
    [anon_sym_FOREACH] = ACTIONS(3699),
    [anon_sym_Foreach] = ACTIONS(3699),
    [anon_sym_while] = ACTIONS(3699),
    [anon_sym_WHILE] = ACTIONS(3699),
    [anon_sym_While] = ACTIONS(3699),
    [anon_sym_repeat] = ACTIONS(3699),
    [anon_sym_REPEAT] = ACTIONS(3699),
    [anon_sym_Repeat] = ACTIONS(3699),
    [anon_sym_exit] = ACTIONS(3699),
    [anon_sym_EXIT] = ACTIONS(3699),
    [anon_sym_Exit] = ACTIONS(3699),
    [anon_sym_continue] = ACTIONS(3699),
    [anon_sym_CONTINUE] = ACTIONS(3699),
    [anon_sym_Continue] = ACTIONS(3699),
    [anon_sym_break] = ACTIONS(3699),
    [anon_sym_BREAK] = ACTIONS(3699),
    [anon_sym_Break] = ACTIONS(3699),
    [anon_sym_with] = ACTIONS(3699),
    [anon_sym_WITH] = ACTIONS(3699),
    [anon_sym_With] = ACTIONS(3699),
    [sym_asserterror_keyword] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3699),
    [anon_sym_IN] = ACTIONS(3699),
    [anon_sym_In] = ACTIONS(3699),
    [sym_page_keyword] = ACTIONS(3699),
    [anon_sym_codeunit] = ACTIONS(3699),
    [anon_sym_CODEUNIT] = ACTIONS(3699),
    [anon_sym_Codeunit] = ACTIONS(3699),
    [anon_sym_CodeUnit] = ACTIONS(3699),
    [anon_sym_COdeunit] = ACTIONS(3699),
    [anon_sym_codeUnit] = ACTIONS(3699),
    [sym_report_keyword] = ACTIONS(3699),
    [sym_query_keyword] = ACTIONS(3699),
    [anon_sym_xmlport] = ACTIONS(3699),
    [anon_sym_XMLPORT] = ACTIONS(3699),
    [anon_sym_Xmlport] = ACTIONS(3699),
    [anon_sym_XMLport] = ACTIONS(3699),
    [anon_sym_XMLPort] = ACTIONS(3699),
    [anon_sym_XmlPort] = ACTIONS(3699),
    [anon_sym_enum] = ACTIONS(3699),
    [anon_sym_ENUM] = ACTIONS(3699),
    [anon_sym_Enum] = ACTIONS(3699),
    [anon_sym_eNUM] = ACTIONS(3699),
    [anon_sym_eNum] = ACTIONS(3699),
    [anon_sym_ENum] = ACTIONS(3699),
    [sym_temporary_keyword] = ACTIONS(3699),
    [sym_quoted_identifier] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3701),
    [sym_verbatim_string] = ACTIONS(3701),
    [sym_integer] = ACTIONS(3699),
    [sym_continue_as_identifier] = ACTIONS(3701),
    [sym_preproc_open] = ACTIONS(3701),
    [sym_preproc_close] = ACTIONS(3701),
  },
  [STATE(1801)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1801),
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(3707),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelif] = ACTIONS(3705),
    [anon_sym_POUNDELIF] = ACTIONS(3705),
    [anon_sym_POUNDElif] = ACTIONS(3705),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [anon_sym_POUNDendif] = ACTIONS(3705),
    [anon_sym_POUNDENDIF] = ACTIONS(3705),
    [anon_sym_POUNDEndif] = ACTIONS(3705),
    [anon_sym_POUNDendif2] = ACTIONS(3705),
    [anon_sym_POUNDENDIF2] = ACTIONS(3705),
    [anon_sym_POUNDEndif2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_if] = ACTIONS(3703),
    [anon_sym_IF] = ACTIONS(3703),
    [anon_sym_If] = ACTIONS(3703),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_case] = ACTIONS(3703),
    [anon_sym_CASE] = ACTIONS(3703),
    [anon_sym_Case] = ACTIONS(3703),
    [anon_sym_for] = ACTIONS(3703),
    [anon_sym_FOR] = ACTIONS(3703),
    [anon_sym_For] = ACTIONS(3703),
    [anon_sym_foreach] = ACTIONS(3703),
    [anon_sym_FOREACH] = ACTIONS(3703),
    [anon_sym_Foreach] = ACTIONS(3703),
    [anon_sym_while] = ACTIONS(3703),
    [anon_sym_WHILE] = ACTIONS(3703),
    [anon_sym_While] = ACTIONS(3703),
    [anon_sym_repeat] = ACTIONS(3703),
    [anon_sym_REPEAT] = ACTIONS(3703),
    [anon_sym_Repeat] = ACTIONS(3703),
    [anon_sym_exit] = ACTIONS(3703),
    [anon_sym_EXIT] = ACTIONS(3703),
    [anon_sym_Exit] = ACTIONS(3703),
    [anon_sym_continue] = ACTIONS(3703),
    [anon_sym_CONTINUE] = ACTIONS(3703),
    [anon_sym_Continue] = ACTIONS(3703),
    [anon_sym_break] = ACTIONS(3703),
    [anon_sym_BREAK] = ACTIONS(3703),
    [anon_sym_Break] = ACTIONS(3703),
    [anon_sym_with] = ACTIONS(3703),
    [anon_sym_WITH] = ACTIONS(3703),
    [anon_sym_With] = ACTIONS(3703),
    [sym_asserterror_keyword] = ACTIONS(3705),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
    [sym_preproc_close] = ACTIONS(3705),
  },
  [STATE(1802)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1803)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1804)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1805)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3710),
    [anon_sym_SEMI] = ACTIONS(3712),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3710),
    [aux_sym_boolean_token2] = ACTIONS(3710),
    [sym_decimal] = ACTIONS(3710),
    [anon_sym_LPAREN] = ACTIONS(3712),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3710),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3710),
    [aux_sym_basic_type_token21] = ACTIONS(3710),
    [aux_sym_basic_type_token22] = ACTIONS(3710),
    [aux_sym_basic_type_token48] = ACTIONS(3710),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3710),
    [anon_sym_POUNDif] = ACTIONS(3712),
    [anon_sym_POUNDIF] = ACTIONS(3712),
    [anon_sym_POUNDIf] = ACTIONS(3712),
    [anon_sym_not] = ACTIONS(3710),
    [anon_sym_NOT] = ACTIONS(3710),
    [anon_sym_Not] = ACTIONS(3710),
    [anon_sym_POUNDelif] = ACTIONS(3712),
    [anon_sym_POUNDELIF] = ACTIONS(3712),
    [anon_sym_POUNDElif] = ACTIONS(3712),
    [anon_sym_POUNDelse] = ACTIONS(3712),
    [anon_sym_POUNDELSE] = ACTIONS(3712),
    [anon_sym_POUNDElse] = ACTIONS(3712),
    [anon_sym_POUNDelse2] = ACTIONS(3712),
    [anon_sym_POUNDELSE2] = ACTIONS(3712),
    [anon_sym_POUNDElse2] = ACTIONS(3712),
    [anon_sym_POUNDendif] = ACTIONS(3712),
    [anon_sym_POUNDENDIF] = ACTIONS(3712),
    [anon_sym_POUNDEndif] = ACTIONS(3712),
    [anon_sym_POUNDendif2] = ACTIONS(3712),
    [anon_sym_POUNDENDIF2] = ACTIONS(3712),
    [anon_sym_POUNDEndif2] = ACTIONS(3712),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3714),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3710),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3710),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3616),
    [anon_sym_OR] = ACTIONS(3618),
    [anon_sym_Or] = ACTIONS(3620),
    [anon_sym_xor] = ACTIONS(3622),
    [anon_sym_XOR] = ACTIONS(3624),
    [anon_sym_Xor] = ACTIONS(3626),
    [anon_sym_QMARK] = ACTIONS(3628),
    [sym_datetime_literal] = ACTIONS(3712),
    [sym_date_literal] = ACTIONS(3710),
    [sym_time_literal] = ACTIONS(3710),
    [sym_biginteger_literal] = ACTIONS(3712),
    [anon_sym_if] = ACTIONS(3710),
    [anon_sym_IF] = ACTIONS(3710),
    [anon_sym_If] = ACTIONS(3710),
    [anon_sym_else] = ACTIONS(3710),
    [anon_sym_ELSE] = ACTIONS(3710),
    [anon_sym_Else] = ACTIONS(3710),
    [anon_sym_case] = ACTIONS(3710),
    [anon_sym_CASE] = ACTIONS(3710),
    [anon_sym_Case] = ACTIONS(3710),
    [anon_sym_for] = ACTIONS(3710),
    [anon_sym_FOR] = ACTIONS(3710),
    [anon_sym_For] = ACTIONS(3710),
    [anon_sym_foreach] = ACTIONS(3710),
    [anon_sym_FOREACH] = ACTIONS(3710),
    [anon_sym_Foreach] = ACTIONS(3710),
    [anon_sym_while] = ACTIONS(3710),
    [anon_sym_WHILE] = ACTIONS(3710),
    [anon_sym_While] = ACTIONS(3710),
    [anon_sym_repeat] = ACTIONS(3710),
    [anon_sym_REPEAT] = ACTIONS(3710),
    [anon_sym_Repeat] = ACTIONS(3710),
    [anon_sym_exit] = ACTIONS(3710),
    [anon_sym_EXIT] = ACTIONS(3710),
    [anon_sym_Exit] = ACTIONS(3710),
    [anon_sym_continue] = ACTIONS(3710),
    [anon_sym_CONTINUE] = ACTIONS(3710),
    [anon_sym_Continue] = ACTIONS(3710),
    [anon_sym_break] = ACTIONS(3710),
    [anon_sym_BREAK] = ACTIONS(3710),
    [anon_sym_Break] = ACTIONS(3710),
    [anon_sym_with] = ACTIONS(3710),
    [anon_sym_WITH] = ACTIONS(3710),
    [anon_sym_With] = ACTIONS(3710),
    [sym_asserterror_keyword] = ACTIONS(3712),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3710),
    [anon_sym_codeunit] = ACTIONS(3710),
    [anon_sym_CODEUNIT] = ACTIONS(3710),
    [anon_sym_Codeunit] = ACTIONS(3710),
    [anon_sym_CodeUnit] = ACTIONS(3710),
    [anon_sym_COdeunit] = ACTIONS(3710),
    [anon_sym_codeUnit] = ACTIONS(3710),
    [sym_report_keyword] = ACTIONS(3710),
    [sym_query_keyword] = ACTIONS(3710),
    [anon_sym_xmlport] = ACTIONS(3710),
    [anon_sym_XMLPORT] = ACTIONS(3710),
    [anon_sym_Xmlport] = ACTIONS(3710),
    [anon_sym_XMLport] = ACTIONS(3710),
    [anon_sym_XMLPort] = ACTIONS(3710),
    [anon_sym_XmlPort] = ACTIONS(3710),
    [anon_sym_enum] = ACTIONS(3710),
    [anon_sym_ENUM] = ACTIONS(3710),
    [anon_sym_Enum] = ACTIONS(3710),
    [anon_sym_eNUM] = ACTIONS(3710),
    [anon_sym_eNum] = ACTIONS(3710),
    [anon_sym_ENum] = ACTIONS(3710),
    [sym_quoted_identifier] = ACTIONS(3712),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3712),
    [sym_verbatim_string] = ACTIONS(3712),
    [sym_integer] = ACTIONS(3710),
    [sym_continue_as_identifier] = ACTIONS(3712),
    [sym_preproc_open] = ACTIONS(3712),
    [sym_preproc_close] = ACTIONS(3712),
  },
  [STATE(1806)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3716),
    [anon_sym_SEMI] = ACTIONS(3718),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3716),
    [aux_sym_boolean_token1] = ACTIONS(3716),
    [aux_sym_boolean_token2] = ACTIONS(3716),
    [sym_decimal] = ACTIONS(3716),
    [anon_sym_LPAREN] = ACTIONS(3718),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3716),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3718),
    [aux_sym_record_type_token1] = ACTIONS(3716),
    [aux_sym_basic_type_token21] = ACTIONS(3716),
    [aux_sym_basic_type_token22] = ACTIONS(3716),
    [aux_sym_basic_type_token48] = ACTIONS(3716),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3716),
    [anon_sym_POUNDif] = ACTIONS(3718),
    [anon_sym_POUNDIF] = ACTIONS(3718),
    [anon_sym_POUNDIf] = ACTIONS(3718),
    [anon_sym_not] = ACTIONS(3716),
    [anon_sym_NOT] = ACTIONS(3716),
    [anon_sym_Not] = ACTIONS(3716),
    [anon_sym_POUNDelif] = ACTIONS(3718),
    [anon_sym_POUNDELIF] = ACTIONS(3718),
    [anon_sym_POUNDElif] = ACTIONS(3718),
    [anon_sym_POUNDelse] = ACTIONS(3718),
    [anon_sym_POUNDELSE] = ACTIONS(3718),
    [anon_sym_POUNDElse] = ACTIONS(3718),
    [anon_sym_POUNDelse2] = ACTIONS(3718),
    [anon_sym_POUNDELSE2] = ACTIONS(3718),
    [anon_sym_POUNDElse2] = ACTIONS(3718),
    [anon_sym_POUNDendif] = ACTIONS(3718),
    [anon_sym_POUNDENDIF] = ACTIONS(3718),
    [anon_sym_POUNDEndif] = ACTIONS(3718),
    [anon_sym_POUNDendif2] = ACTIONS(3718),
    [anon_sym_POUNDENDIF2] = ACTIONS(3718),
    [anon_sym_POUNDEndif2] = ACTIONS(3718),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3586),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3716),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3716),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3716),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3616),
    [anon_sym_OR] = ACTIONS(3618),
    [anon_sym_Or] = ACTIONS(3620),
    [anon_sym_xor] = ACTIONS(3622),
    [anon_sym_XOR] = ACTIONS(3624),
    [anon_sym_Xor] = ACTIONS(3626),
    [anon_sym_QMARK] = ACTIONS(3628),
    [sym_datetime_literal] = ACTIONS(3718),
    [sym_date_literal] = ACTIONS(3716),
    [sym_time_literal] = ACTIONS(3716),
    [sym_biginteger_literal] = ACTIONS(3718),
    [anon_sym_if] = ACTIONS(3716),
    [anon_sym_IF] = ACTIONS(3716),
    [anon_sym_If] = ACTIONS(3716),
    [anon_sym_else] = ACTIONS(3716),
    [anon_sym_ELSE] = ACTIONS(3716),
    [anon_sym_Else] = ACTIONS(3716),
    [anon_sym_case] = ACTIONS(3716),
    [anon_sym_CASE] = ACTIONS(3716),
    [anon_sym_Case] = ACTIONS(3716),
    [anon_sym_for] = ACTIONS(3716),
    [anon_sym_FOR] = ACTIONS(3716),
    [anon_sym_For] = ACTIONS(3716),
    [anon_sym_foreach] = ACTIONS(3716),
    [anon_sym_FOREACH] = ACTIONS(3716),
    [anon_sym_Foreach] = ACTIONS(3716),
    [anon_sym_while] = ACTIONS(3716),
    [anon_sym_WHILE] = ACTIONS(3716),
    [anon_sym_While] = ACTIONS(3716),
    [anon_sym_repeat] = ACTIONS(3716),
    [anon_sym_REPEAT] = ACTIONS(3716),
    [anon_sym_Repeat] = ACTIONS(3716),
    [anon_sym_exit] = ACTIONS(3716),
    [anon_sym_EXIT] = ACTIONS(3716),
    [anon_sym_Exit] = ACTIONS(3716),
    [anon_sym_continue] = ACTIONS(3716),
    [anon_sym_CONTINUE] = ACTIONS(3716),
    [anon_sym_Continue] = ACTIONS(3716),
    [anon_sym_break] = ACTIONS(3716),
    [anon_sym_BREAK] = ACTIONS(3716),
    [anon_sym_Break] = ACTIONS(3716),
    [anon_sym_with] = ACTIONS(3716),
    [anon_sym_WITH] = ACTIONS(3716),
    [anon_sym_With] = ACTIONS(3716),
    [sym_asserterror_keyword] = ACTIONS(3718),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3716),
    [anon_sym_codeunit] = ACTIONS(3716),
    [anon_sym_CODEUNIT] = ACTIONS(3716),
    [anon_sym_Codeunit] = ACTIONS(3716),
    [anon_sym_CodeUnit] = ACTIONS(3716),
    [anon_sym_COdeunit] = ACTIONS(3716),
    [anon_sym_codeUnit] = ACTIONS(3716),
    [sym_report_keyword] = ACTIONS(3716),
    [sym_query_keyword] = ACTIONS(3716),
    [anon_sym_xmlport] = ACTIONS(3716),
    [anon_sym_XMLPORT] = ACTIONS(3716),
    [anon_sym_Xmlport] = ACTIONS(3716),
    [anon_sym_XMLport] = ACTIONS(3716),
    [anon_sym_XMLPort] = ACTIONS(3716),
    [anon_sym_XmlPort] = ACTIONS(3716),
    [anon_sym_enum] = ACTIONS(3716),
    [anon_sym_ENUM] = ACTIONS(3716),
    [anon_sym_Enum] = ACTIONS(3716),
    [anon_sym_eNUM] = ACTIONS(3716),
    [anon_sym_eNum] = ACTIONS(3716),
    [anon_sym_ENum] = ACTIONS(3716),
    [sym_quoted_identifier] = ACTIONS(3718),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3718),
    [sym_verbatim_string] = ACTIONS(3718),
    [sym_integer] = ACTIONS(3716),
    [sym_continue_as_identifier] = ACTIONS(3718),
    [sym_preproc_open] = ACTIONS(3718),
    [sym_preproc_close] = ACTIONS(3718),
  },
  [STATE(1807)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1808)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3720),
    [anon_sym_SEMI] = ACTIONS(3723),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3720),
    [aux_sym_boolean_token2] = ACTIONS(3720),
    [sym_decimal] = ACTIONS(3720),
    [anon_sym_LPAREN] = ACTIONS(3723),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3720),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3720),
    [aux_sym_basic_type_token21] = ACTIONS(3720),
    [aux_sym_basic_type_token22] = ACTIONS(3720),
    [aux_sym_basic_type_token48] = ACTIONS(3720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3720),
    [anon_sym_POUNDif] = ACTIONS(3723),
    [anon_sym_POUNDIF] = ACTIONS(3723),
    [anon_sym_POUNDIf] = ACTIONS(3723),
    [anon_sym_not] = ACTIONS(3720),
    [anon_sym_NOT] = ACTIONS(3720),
    [anon_sym_Not] = ACTIONS(3720),
    [anon_sym_POUNDelif] = ACTIONS(3723),
    [anon_sym_POUNDELIF] = ACTIONS(3723),
    [anon_sym_POUNDElif] = ACTIONS(3723),
    [anon_sym_POUNDelse] = ACTIONS(3723),
    [anon_sym_POUNDELSE] = ACTIONS(3723),
    [anon_sym_POUNDElse] = ACTIONS(3723),
    [anon_sym_POUNDelse2] = ACTIONS(3723),
    [anon_sym_POUNDELSE2] = ACTIONS(3723),
    [anon_sym_POUNDElse2] = ACTIONS(3723),
    [anon_sym_POUNDendif] = ACTIONS(3723),
    [anon_sym_POUNDENDIF] = ACTIONS(3723),
    [anon_sym_POUNDEndif] = ACTIONS(3723),
    [anon_sym_POUNDendif2] = ACTIONS(3723),
    [anon_sym_POUNDENDIF2] = ACTIONS(3723),
    [anon_sym_POUNDEndif2] = ACTIONS(3723),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3586),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3720),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3616),
    [anon_sym_OR] = ACTIONS(3618),
    [anon_sym_Or] = ACTIONS(3620),
    [anon_sym_xor] = ACTIONS(3622),
    [anon_sym_XOR] = ACTIONS(3624),
    [anon_sym_Xor] = ACTIONS(3626),
    [anon_sym_QMARK] = ACTIONS(3628),
    [sym_datetime_literal] = ACTIONS(3723),
    [sym_date_literal] = ACTIONS(3720),
    [sym_time_literal] = ACTIONS(3720),
    [sym_biginteger_literal] = ACTIONS(3723),
    [anon_sym_if] = ACTIONS(3720),
    [anon_sym_IF] = ACTIONS(3720),
    [anon_sym_If] = ACTIONS(3720),
    [anon_sym_else] = ACTIONS(3720),
    [anon_sym_ELSE] = ACTIONS(3720),
    [anon_sym_Else] = ACTIONS(3720),
    [anon_sym_case] = ACTIONS(3720),
    [anon_sym_CASE] = ACTIONS(3720),
    [anon_sym_Case] = ACTIONS(3720),
    [anon_sym_for] = ACTIONS(3720),
    [anon_sym_FOR] = ACTIONS(3720),
    [anon_sym_For] = ACTIONS(3720),
    [anon_sym_foreach] = ACTIONS(3720),
    [anon_sym_FOREACH] = ACTIONS(3720),
    [anon_sym_Foreach] = ACTIONS(3720),
    [anon_sym_while] = ACTIONS(3720),
    [anon_sym_WHILE] = ACTIONS(3720),
    [anon_sym_While] = ACTIONS(3720),
    [anon_sym_repeat] = ACTIONS(3720),
    [anon_sym_REPEAT] = ACTIONS(3720),
    [anon_sym_Repeat] = ACTIONS(3720),
    [anon_sym_exit] = ACTIONS(3720),
    [anon_sym_EXIT] = ACTIONS(3720),
    [anon_sym_Exit] = ACTIONS(3720),
    [anon_sym_continue] = ACTIONS(3720),
    [anon_sym_CONTINUE] = ACTIONS(3720),
    [anon_sym_Continue] = ACTIONS(3720),
    [anon_sym_break] = ACTIONS(3720),
    [anon_sym_BREAK] = ACTIONS(3720),
    [anon_sym_Break] = ACTIONS(3720),
    [anon_sym_with] = ACTIONS(3720),
    [anon_sym_WITH] = ACTIONS(3720),
    [anon_sym_With] = ACTIONS(3720),
    [sym_asserterror_keyword] = ACTIONS(3723),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3720),
    [anon_sym_codeunit] = ACTIONS(3720),
    [anon_sym_CODEUNIT] = ACTIONS(3720),
    [anon_sym_Codeunit] = ACTIONS(3720),
    [anon_sym_CodeUnit] = ACTIONS(3720),
    [anon_sym_COdeunit] = ACTIONS(3720),
    [anon_sym_codeUnit] = ACTIONS(3720),
    [sym_report_keyword] = ACTIONS(3720),
    [sym_query_keyword] = ACTIONS(3720),
    [anon_sym_xmlport] = ACTIONS(3720),
    [anon_sym_XMLPORT] = ACTIONS(3720),
    [anon_sym_Xmlport] = ACTIONS(3720),
    [anon_sym_XMLport] = ACTIONS(3720),
    [anon_sym_XMLPort] = ACTIONS(3720),
    [anon_sym_XmlPort] = ACTIONS(3720),
    [anon_sym_enum] = ACTIONS(3720),
    [anon_sym_ENUM] = ACTIONS(3720),
    [anon_sym_Enum] = ACTIONS(3720),
    [anon_sym_eNUM] = ACTIONS(3720),
    [anon_sym_eNum] = ACTIONS(3720),
    [anon_sym_ENum] = ACTIONS(3720),
    [sym_quoted_identifier] = ACTIONS(3723),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3723),
    [sym_verbatim_string] = ACTIONS(3723),
    [sym_integer] = ACTIONS(3720),
    [sym_continue_as_identifier] = ACTIONS(3723),
    [sym_preproc_open] = ACTIONS(3723),
    [sym_preproc_close] = ACTIONS(3723),
  },
  [STATE(1809)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3726),
    [anon_sym_SEMI] = ACTIONS(3728),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3728),
    [anon_sym_DASH] = ACTIONS(3726),
    [aux_sym_boolean_token1] = ACTIONS(3726),
    [aux_sym_boolean_token2] = ACTIONS(3726),
    [sym_decimal] = ACTIONS(3726),
    [anon_sym_LPAREN] = ACTIONS(3728),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3726),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3726),
    [aux_sym_basic_type_token21] = ACTIONS(3726),
    [aux_sym_basic_type_token22] = ACTIONS(3726),
    [aux_sym_basic_type_token48] = ACTIONS(3726),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3726),
    [anon_sym_POUNDif] = ACTIONS(3728),
    [anon_sym_POUNDIF] = ACTIONS(3728),
    [anon_sym_POUNDIf] = ACTIONS(3728),
    [anon_sym_not] = ACTIONS(3726),
    [anon_sym_NOT] = ACTIONS(3726),
    [anon_sym_Not] = ACTIONS(3726),
    [anon_sym_POUNDelif] = ACTIONS(3728),
    [anon_sym_POUNDELIF] = ACTIONS(3728),
    [anon_sym_POUNDElif] = ACTIONS(3728),
    [anon_sym_POUNDelse] = ACTIONS(3728),
    [anon_sym_POUNDELSE] = ACTIONS(3728),
    [anon_sym_POUNDElse] = ACTIONS(3728),
    [anon_sym_POUNDelse2] = ACTIONS(3728),
    [anon_sym_POUNDELSE2] = ACTIONS(3728),
    [anon_sym_POUNDElse2] = ACTIONS(3728),
    [anon_sym_POUNDendif] = ACTIONS(3728),
    [anon_sym_POUNDENDIF] = ACTIONS(3728),
    [anon_sym_POUNDEndif] = ACTIONS(3728),
    [anon_sym_POUNDendif2] = ACTIONS(3728),
    [anon_sym_POUNDENDIF2] = ACTIONS(3728),
    [anon_sym_POUNDEndif2] = ACTIONS(3728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3728),
    [aux_sym__expression_token1] = ACTIONS(3728),
    [aux_sym__expression_token2] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3726),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3726),
    [anon_sym_GT_EQ] = ACTIONS(3728),
    [anon_sym_LT_EQ] = ACTIONS(3728),
    [anon_sym_GT] = ACTIONS(3726),
    [anon_sym_LT] = ACTIONS(3726),
    [anon_sym_LT_GT] = ACTIONS(3728),
    [anon_sym_and] = ACTIONS(3726),
    [anon_sym_AND] = ACTIONS(3726),
    [anon_sym_And] = ACTIONS(3726),
    [anon_sym_or] = ACTIONS(3726),
    [anon_sym_OR] = ACTIONS(3726),
    [anon_sym_Or] = ACTIONS(3726),
    [anon_sym_xor] = ACTIONS(3726),
    [anon_sym_XOR] = ACTIONS(3726),
    [anon_sym_Xor] = ACTIONS(3726),
    [anon_sym_QMARK] = ACTIONS(3728),
    [sym_datetime_literal] = ACTIONS(3728),
    [sym_date_literal] = ACTIONS(3726),
    [sym_time_literal] = ACTIONS(3726),
    [sym_biginteger_literal] = ACTIONS(3728),
    [anon_sym_if] = ACTIONS(3726),
    [anon_sym_IF] = ACTIONS(3726),
    [anon_sym_If] = ACTIONS(3726),
    [anon_sym_else] = ACTIONS(3726),
    [anon_sym_ELSE] = ACTIONS(3726),
    [anon_sym_Else] = ACTIONS(3726),
    [anon_sym_case] = ACTIONS(3726),
    [anon_sym_CASE] = ACTIONS(3726),
    [anon_sym_Case] = ACTIONS(3726),
    [anon_sym_for] = ACTIONS(3726),
    [anon_sym_FOR] = ACTIONS(3726),
    [anon_sym_For] = ACTIONS(3726),
    [anon_sym_foreach] = ACTIONS(3726),
    [anon_sym_FOREACH] = ACTIONS(3726),
    [anon_sym_Foreach] = ACTIONS(3726),
    [anon_sym_while] = ACTIONS(3726),
    [anon_sym_WHILE] = ACTIONS(3726),
    [anon_sym_While] = ACTIONS(3726),
    [anon_sym_repeat] = ACTIONS(3726),
    [anon_sym_REPEAT] = ACTIONS(3726),
    [anon_sym_Repeat] = ACTIONS(3726),
    [anon_sym_exit] = ACTIONS(3726),
    [anon_sym_EXIT] = ACTIONS(3726),
    [anon_sym_Exit] = ACTIONS(3726),
    [anon_sym_continue] = ACTIONS(3726),
    [anon_sym_CONTINUE] = ACTIONS(3726),
    [anon_sym_Continue] = ACTIONS(3726),
    [anon_sym_break] = ACTIONS(3726),
    [anon_sym_BREAK] = ACTIONS(3726),
    [anon_sym_Break] = ACTIONS(3726),
    [anon_sym_with] = ACTIONS(3726),
    [anon_sym_WITH] = ACTIONS(3726),
    [anon_sym_With] = ACTIONS(3726),
    [sym_asserterror_keyword] = ACTIONS(3728),
    [anon_sym_in] = ACTIONS(3726),
    [anon_sym_IN] = ACTIONS(3726),
    [anon_sym_In] = ACTIONS(3726),
    [sym_page_keyword] = ACTIONS(3726),
    [anon_sym_codeunit] = ACTIONS(3726),
    [anon_sym_CODEUNIT] = ACTIONS(3726),
    [anon_sym_Codeunit] = ACTIONS(3726),
    [anon_sym_CodeUnit] = ACTIONS(3726),
    [anon_sym_COdeunit] = ACTIONS(3726),
    [anon_sym_codeUnit] = ACTIONS(3726),
    [sym_report_keyword] = ACTIONS(3726),
    [sym_query_keyword] = ACTIONS(3726),
    [anon_sym_xmlport] = ACTIONS(3726),
    [anon_sym_XMLPORT] = ACTIONS(3726),
    [anon_sym_Xmlport] = ACTIONS(3726),
    [anon_sym_XMLport] = ACTIONS(3726),
    [anon_sym_XMLPort] = ACTIONS(3726),
    [anon_sym_XmlPort] = ACTIONS(3726),
    [anon_sym_enum] = ACTIONS(3726),
    [anon_sym_ENUM] = ACTIONS(3726),
    [anon_sym_Enum] = ACTIONS(3726),
    [anon_sym_eNUM] = ACTIONS(3726),
    [anon_sym_eNum] = ACTIONS(3726),
    [anon_sym_ENum] = ACTIONS(3726),
    [sym_quoted_identifier] = ACTIONS(3728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3728),
    [sym_verbatim_string] = ACTIONS(3728),
    [sym_integer] = ACTIONS(3726),
    [sym_continue_as_identifier] = ACTIONS(3728),
    [sym_preproc_open] = ACTIONS(3728),
    [sym_preproc_close] = ACTIONS(3728),
  },
  [STATE(1810)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3730),
    [anon_sym_SEMI] = ACTIONS(3732),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3730),
    [aux_sym_boolean_token2] = ACTIONS(3730),
    [sym_decimal] = ACTIONS(3730),
    [anon_sym_LPAREN] = ACTIONS(3732),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3730),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3730),
    [aux_sym_basic_type_token21] = ACTIONS(3730),
    [aux_sym_basic_type_token22] = ACTIONS(3730),
    [aux_sym_basic_type_token48] = ACTIONS(3730),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3730),
    [anon_sym_POUNDif] = ACTIONS(3732),
    [anon_sym_POUNDIF] = ACTIONS(3732),
    [anon_sym_POUNDIf] = ACTIONS(3732),
    [anon_sym_not] = ACTIONS(3730),
    [anon_sym_NOT] = ACTIONS(3730),
    [anon_sym_Not] = ACTIONS(3730),
    [anon_sym_POUNDelif] = ACTIONS(3732),
    [anon_sym_POUNDELIF] = ACTIONS(3732),
    [anon_sym_POUNDElif] = ACTIONS(3732),
    [anon_sym_POUNDelse] = ACTIONS(3732),
    [anon_sym_POUNDELSE] = ACTIONS(3732),
    [anon_sym_POUNDElse] = ACTIONS(3732),
    [anon_sym_POUNDelse2] = ACTIONS(3732),
    [anon_sym_POUNDELSE2] = ACTIONS(3732),
    [anon_sym_POUNDElse2] = ACTIONS(3732),
    [anon_sym_POUNDendif] = ACTIONS(3732),
    [anon_sym_POUNDENDIF] = ACTIONS(3732),
    [anon_sym_POUNDEndif] = ACTIONS(3732),
    [anon_sym_POUNDendif2] = ACTIONS(3732),
    [anon_sym_POUNDENDIF2] = ACTIONS(3732),
    [anon_sym_POUNDEndif2] = ACTIONS(3732),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3586),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3730),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3730),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3616),
    [anon_sym_OR] = ACTIONS(3618),
    [anon_sym_Or] = ACTIONS(3620),
    [anon_sym_xor] = ACTIONS(3622),
    [anon_sym_XOR] = ACTIONS(3624),
    [anon_sym_Xor] = ACTIONS(3626),
    [anon_sym_QMARK] = ACTIONS(3628),
    [sym_datetime_literal] = ACTIONS(3732),
    [sym_date_literal] = ACTIONS(3730),
    [sym_time_literal] = ACTIONS(3730),
    [sym_biginteger_literal] = ACTIONS(3732),
    [anon_sym_if] = ACTIONS(3730),
    [anon_sym_IF] = ACTIONS(3730),
    [anon_sym_If] = ACTIONS(3730),
    [anon_sym_else] = ACTIONS(3730),
    [anon_sym_ELSE] = ACTIONS(3730),
    [anon_sym_Else] = ACTIONS(3730),
    [anon_sym_case] = ACTIONS(3730),
    [anon_sym_CASE] = ACTIONS(3730),
    [anon_sym_Case] = ACTIONS(3730),
    [anon_sym_for] = ACTIONS(3730),
    [anon_sym_FOR] = ACTIONS(3730),
    [anon_sym_For] = ACTIONS(3730),
    [anon_sym_foreach] = ACTIONS(3730),
    [anon_sym_FOREACH] = ACTIONS(3730),
    [anon_sym_Foreach] = ACTIONS(3730),
    [anon_sym_while] = ACTIONS(3730),
    [anon_sym_WHILE] = ACTIONS(3730),
    [anon_sym_While] = ACTIONS(3730),
    [anon_sym_repeat] = ACTIONS(3730),
    [anon_sym_REPEAT] = ACTIONS(3730),
    [anon_sym_Repeat] = ACTIONS(3730),
    [anon_sym_exit] = ACTIONS(3730),
    [anon_sym_EXIT] = ACTIONS(3730),
    [anon_sym_Exit] = ACTIONS(3730),
    [anon_sym_continue] = ACTIONS(3730),
    [anon_sym_CONTINUE] = ACTIONS(3730),
    [anon_sym_Continue] = ACTIONS(3730),
    [anon_sym_break] = ACTIONS(3730),
    [anon_sym_BREAK] = ACTIONS(3730),
    [anon_sym_Break] = ACTIONS(3730),
    [anon_sym_with] = ACTIONS(3730),
    [anon_sym_WITH] = ACTIONS(3730),
    [anon_sym_With] = ACTIONS(3730),
    [sym_asserterror_keyword] = ACTIONS(3732),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3730),
    [anon_sym_codeunit] = ACTIONS(3730),
    [anon_sym_CODEUNIT] = ACTIONS(3730),
    [anon_sym_Codeunit] = ACTIONS(3730),
    [anon_sym_CodeUnit] = ACTIONS(3730),
    [anon_sym_COdeunit] = ACTIONS(3730),
    [anon_sym_codeUnit] = ACTIONS(3730),
    [sym_report_keyword] = ACTIONS(3730),
    [sym_query_keyword] = ACTIONS(3730),
    [anon_sym_xmlport] = ACTIONS(3730),
    [anon_sym_XMLPORT] = ACTIONS(3730),
    [anon_sym_Xmlport] = ACTIONS(3730),
    [anon_sym_XMLport] = ACTIONS(3730),
    [anon_sym_XMLPort] = ACTIONS(3730),
    [anon_sym_XmlPort] = ACTIONS(3730),
    [anon_sym_enum] = ACTIONS(3730),
    [anon_sym_ENUM] = ACTIONS(3730),
    [anon_sym_Enum] = ACTIONS(3730),
    [anon_sym_eNUM] = ACTIONS(3730),
    [anon_sym_eNum] = ACTIONS(3730),
    [anon_sym_ENum] = ACTIONS(3730),
    [sym_quoted_identifier] = ACTIONS(3732),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3732),
    [sym_verbatim_string] = ACTIONS(3732),
    [sym_integer] = ACTIONS(3730),
    [sym_continue_as_identifier] = ACTIONS(3732),
    [sym_preproc_open] = ACTIONS(3732),
    [sym_preproc_close] = ACTIONS(3732),
  },
  [STATE(1811)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(1812)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3734),
    [anon_sym_SEMI] = ACTIONS(3736),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3582),
    [aux_sym_boolean_token1] = ACTIONS(3734),
    [aux_sym_boolean_token2] = ACTIONS(3734),
    [sym_decimal] = ACTIONS(3734),
    [anon_sym_LPAREN] = ACTIONS(3736),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3734),
    [anon_sym_STAR] = ACTIONS(3584),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3734),
    [aux_sym_basic_type_token21] = ACTIONS(3734),
    [aux_sym_basic_type_token22] = ACTIONS(3734),
    [aux_sym_basic_type_token48] = ACTIONS(3734),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3734),
    [anon_sym_POUNDif] = ACTIONS(3736),
    [anon_sym_POUNDIF] = ACTIONS(3736),
    [anon_sym_POUNDIf] = ACTIONS(3736),
    [anon_sym_not] = ACTIONS(3734),
    [anon_sym_NOT] = ACTIONS(3734),
    [anon_sym_Not] = ACTIONS(3734),
    [anon_sym_POUNDelif] = ACTIONS(3736),
    [anon_sym_POUNDELIF] = ACTIONS(3736),
    [anon_sym_POUNDElif] = ACTIONS(3736),
    [anon_sym_POUNDelse] = ACTIONS(3736),
    [anon_sym_POUNDELSE] = ACTIONS(3736),
    [anon_sym_POUNDElse] = ACTIONS(3736),
    [anon_sym_POUNDelse2] = ACTIONS(3736),
    [anon_sym_POUNDELSE2] = ACTIONS(3736),
    [anon_sym_POUNDElse2] = ACTIONS(3736),
    [anon_sym_POUNDendif] = ACTIONS(3736),
    [anon_sym_POUNDENDIF] = ACTIONS(3736),
    [anon_sym_POUNDEndif] = ACTIONS(3736),
    [anon_sym_POUNDendif2] = ACTIONS(3736),
    [anon_sym_POUNDENDIF2] = ACTIONS(3736),
    [anon_sym_POUNDEndif2] = ACTIONS(3736),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3586),
    [aux_sym__expression_token1] = ACTIONS(3588),
    [aux_sym__expression_token2] = ACTIONS(3590),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3734),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3734),
    [anon_sym_SLASH] = ACTIONS(3592),
    [anon_sym_div] = ACTIONS(3594),
    [anon_sym_DIV] = ACTIONS(3596),
    [anon_sym_Div] = ACTIONS(3598),
    [anon_sym_mod] = ACTIONS(3600),
    [anon_sym_MOD] = ACTIONS(3602),
    [anon_sym_Mod] = ACTIONS(3604),
    [anon_sym_PLUS] = ACTIONS(3606),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3610),
    [anon_sym_AND] = ACTIONS(3612),
    [anon_sym_And] = ACTIONS(3614),
    [anon_sym_or] = ACTIONS(3616),
    [anon_sym_OR] = ACTIONS(3618),
    [anon_sym_Or] = ACTIONS(3620),
    [anon_sym_xor] = ACTIONS(3622),
    [anon_sym_XOR] = ACTIONS(3624),
    [anon_sym_Xor] = ACTIONS(3626),
    [anon_sym_QMARK] = ACTIONS(3628),
    [sym_datetime_literal] = ACTIONS(3736),
    [sym_date_literal] = ACTIONS(3734),
    [sym_time_literal] = ACTIONS(3734),
    [sym_biginteger_literal] = ACTIONS(3736),
    [anon_sym_if] = ACTIONS(3734),
    [anon_sym_IF] = ACTIONS(3734),
    [anon_sym_If] = ACTIONS(3734),
    [anon_sym_else] = ACTIONS(3734),
    [anon_sym_ELSE] = ACTIONS(3734),
    [anon_sym_Else] = ACTIONS(3734),
    [anon_sym_case] = ACTIONS(3734),
    [anon_sym_CASE] = ACTIONS(3734),
    [anon_sym_Case] = ACTIONS(3734),
    [anon_sym_for] = ACTIONS(3734),
    [anon_sym_FOR] = ACTIONS(3734),
    [anon_sym_For] = ACTIONS(3734),
    [anon_sym_foreach] = ACTIONS(3734),
    [anon_sym_FOREACH] = ACTIONS(3734),
    [anon_sym_Foreach] = ACTIONS(3734),
    [anon_sym_while] = ACTIONS(3734),
    [anon_sym_WHILE] = ACTIONS(3734),
    [anon_sym_While] = ACTIONS(3734),
    [anon_sym_repeat] = ACTIONS(3734),
    [anon_sym_REPEAT] = ACTIONS(3734),
    [anon_sym_Repeat] = ACTIONS(3734),
    [anon_sym_exit] = ACTIONS(3734),
    [anon_sym_EXIT] = ACTIONS(3734),
    [anon_sym_Exit] = ACTIONS(3734),
    [anon_sym_continue] = ACTIONS(3734),
    [anon_sym_CONTINUE] = ACTIONS(3734),
    [anon_sym_Continue] = ACTIONS(3734),
    [anon_sym_break] = ACTIONS(3734),
    [anon_sym_BREAK] = ACTIONS(3734),
    [anon_sym_Break] = ACTIONS(3734),
    [anon_sym_with] = ACTIONS(3734),
    [anon_sym_WITH] = ACTIONS(3734),
    [anon_sym_With] = ACTIONS(3734),
    [sym_asserterror_keyword] = ACTIONS(3736),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3734),
    [anon_sym_codeunit] = ACTIONS(3734),
    [anon_sym_CODEUNIT] = ACTIONS(3734),
    [anon_sym_Codeunit] = ACTIONS(3734),
    [anon_sym_CodeUnit] = ACTIONS(3734),
    [anon_sym_COdeunit] = ACTIONS(3734),
    [anon_sym_codeUnit] = ACTIONS(3734),
    [sym_report_keyword] = ACTIONS(3734),
    [sym_query_keyword] = ACTIONS(3734),
    [anon_sym_xmlport] = ACTIONS(3734),
    [anon_sym_XMLPORT] = ACTIONS(3734),
    [anon_sym_Xmlport] = ACTIONS(3734),
    [anon_sym_XMLport] = ACTIONS(3734),
    [anon_sym_XMLPort] = ACTIONS(3734),
    [anon_sym_XmlPort] = ACTIONS(3734),
    [anon_sym_enum] = ACTIONS(3734),
    [anon_sym_ENUM] = ACTIONS(3734),
    [anon_sym_Enum] = ACTIONS(3734),
    [anon_sym_eNUM] = ACTIONS(3734),
    [anon_sym_eNum] = ACTIONS(3734),
    [anon_sym_ENum] = ACTIONS(3734),
    [sym_quoted_identifier] = ACTIONS(3736),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3736),
    [sym_verbatim_string] = ACTIONS(3736),
    [sym_integer] = ACTIONS(3734),
    [sym_continue_as_identifier] = ACTIONS(3736),
    [sym_preproc_open] = ACTIONS(3736),
    [sym_preproc_close] = ACTIONS(3736),
  },
  [STATE(1813)] = {
    [sym_comparison_operator] = STATE(4771),
    [sym_in_keyword] = STATE(16443),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(3570),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(3572),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(3574),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(1814)] = {
    [sym_identifier] = ACTIONS(3738),
    [anon_sym_SEMI] = ACTIONS(3740),
    [anon_sym_DOT] = ACTIONS(3738),
    [anon_sym_EQ] = ACTIONS(3740),
    [anon_sym_COMMA] = ACTIONS(3740),
    [anon_sym_DASH] = ACTIONS(3738),
    [aux_sym_boolean_token1] = ACTIONS(3738),
    [aux_sym_boolean_token2] = ACTIONS(3738),
    [sym_decimal] = ACTIONS(3738),
    [anon_sym_LPAREN] = ACTIONS(3740),
    [anon_sym_DOT_DOT] = ACTIONS(3740),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3738),
    [anon_sym_STAR] = ACTIONS(3738),
    [anon_sym_LBRACK] = ACTIONS(3740),
    [aux_sym_record_type_token1] = ACTIONS(3738),
    [aux_sym_basic_type_token21] = ACTIONS(3738),
    [aux_sym_basic_type_token22] = ACTIONS(3738),
    [aux_sym_basic_type_token48] = ACTIONS(3738),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3738),
    [anon_sym_POUNDif] = ACTIONS(3740),
    [anon_sym_POUNDIF] = ACTIONS(3740),
    [anon_sym_POUNDIf] = ACTIONS(3740),
    [anon_sym_not] = ACTIONS(3738),
    [anon_sym_NOT] = ACTIONS(3738),
    [anon_sym_Not] = ACTIONS(3738),
    [anon_sym_POUNDelif] = ACTIONS(3740),
    [anon_sym_POUNDELIF] = ACTIONS(3740),
    [anon_sym_POUNDElif] = ACTIONS(3740),
    [anon_sym_POUNDelse] = ACTIONS(3740),
    [anon_sym_POUNDELSE] = ACTIONS(3740),
    [anon_sym_POUNDElse] = ACTIONS(3740),
    [anon_sym_POUNDelse2] = ACTIONS(3740),
    [anon_sym_POUNDELSE2] = ACTIONS(3740),
    [anon_sym_POUNDElse2] = ACTIONS(3740),
    [anon_sym_POUNDendif] = ACTIONS(3740),
    [anon_sym_POUNDENDIF] = ACTIONS(3740),
    [anon_sym_POUNDEndif] = ACTIONS(3740),
    [anon_sym_POUNDendif2] = ACTIONS(3740),
    [anon_sym_POUNDENDIF2] = ACTIONS(3740),
    [anon_sym_POUNDEndif2] = ACTIONS(3740),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3740),
    [aux_sym__expression_token1] = ACTIONS(3740),
    [aux_sym__expression_token2] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3738),
    [anon_sym_SLASH] = ACTIONS(3738),
    [anon_sym_div] = ACTIONS(3738),
    [anon_sym_DIV] = ACTIONS(3738),
    [anon_sym_Div] = ACTIONS(3738),
    [anon_sym_mod] = ACTIONS(3738),
    [anon_sym_MOD] = ACTIONS(3738),
    [anon_sym_Mod] = ACTIONS(3738),
    [anon_sym_PLUS] = ACTIONS(3738),
    [anon_sym_GT_EQ] = ACTIONS(3740),
    [anon_sym_LT_EQ] = ACTIONS(3740),
    [anon_sym_GT] = ACTIONS(3738),
    [anon_sym_LT] = ACTIONS(3738),
    [anon_sym_LT_GT] = ACTIONS(3740),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3738),
    [anon_sym_And] = ACTIONS(3738),
    [anon_sym_or] = ACTIONS(3738),
    [anon_sym_OR] = ACTIONS(3738),
    [anon_sym_Or] = ACTIONS(3738),
    [anon_sym_xor] = ACTIONS(3738),
    [anon_sym_XOR] = ACTIONS(3738),
    [anon_sym_Xor] = ACTIONS(3738),
    [anon_sym_QMARK] = ACTIONS(3740),
    [sym_datetime_literal] = ACTIONS(3740),
    [sym_date_literal] = ACTIONS(3738),
    [sym_time_literal] = ACTIONS(3738),
    [sym_biginteger_literal] = ACTIONS(3740),
    [anon_sym_if] = ACTIONS(3738),
    [anon_sym_IF] = ACTIONS(3738),
    [anon_sym_If] = ACTIONS(3738),
    [anon_sym_else] = ACTIONS(3738),
    [anon_sym_ELSE] = ACTIONS(3738),
    [anon_sym_Else] = ACTIONS(3738),
    [anon_sym_case] = ACTIONS(3738),
    [anon_sym_CASE] = ACTIONS(3738),
    [anon_sym_Case] = ACTIONS(3738),
    [anon_sym_for] = ACTIONS(3738),
    [anon_sym_FOR] = ACTIONS(3738),
    [anon_sym_For] = ACTIONS(3738),
    [anon_sym_foreach] = ACTIONS(3738),
    [anon_sym_FOREACH] = ACTIONS(3738),
    [anon_sym_Foreach] = ACTIONS(3738),
    [anon_sym_while] = ACTIONS(3738),
    [anon_sym_WHILE] = ACTIONS(3738),
    [anon_sym_While] = ACTIONS(3738),
    [anon_sym_repeat] = ACTIONS(3738),
    [anon_sym_REPEAT] = ACTIONS(3738),
    [anon_sym_Repeat] = ACTIONS(3738),
    [anon_sym_exit] = ACTIONS(3738),
    [anon_sym_EXIT] = ACTIONS(3738),
    [anon_sym_Exit] = ACTIONS(3738),
    [anon_sym_continue] = ACTIONS(3738),
    [anon_sym_CONTINUE] = ACTIONS(3738),
    [anon_sym_Continue] = ACTIONS(3738),
    [anon_sym_break] = ACTIONS(3738),
    [anon_sym_BREAK] = ACTIONS(3738),
    [anon_sym_Break] = ACTIONS(3738),
    [anon_sym_with] = ACTIONS(3738),
    [anon_sym_WITH] = ACTIONS(3738),
    [anon_sym_With] = ACTIONS(3738),
    [sym_asserterror_keyword] = ACTIONS(3740),
    [anon_sym_in] = ACTIONS(3738),
    [anon_sym_IN] = ACTIONS(3738),
    [anon_sym_In] = ACTIONS(3738),
    [sym_page_keyword] = ACTIONS(3738),
    [anon_sym_codeunit] = ACTIONS(3738),
    [anon_sym_CODEUNIT] = ACTIONS(3738),
    [anon_sym_Codeunit] = ACTIONS(3738),
    [anon_sym_CodeUnit] = ACTIONS(3738),
    [anon_sym_COdeunit] = ACTIONS(3738),
    [anon_sym_codeUnit] = ACTIONS(3738),
    [sym_report_keyword] = ACTIONS(3738),
    [sym_query_keyword] = ACTIONS(3738),
    [anon_sym_xmlport] = ACTIONS(3738),
    [anon_sym_XMLPORT] = ACTIONS(3738),
    [anon_sym_Xmlport] = ACTIONS(3738),
    [anon_sym_XMLport] = ACTIONS(3738),
    [anon_sym_XMLPort] = ACTIONS(3738),
    [anon_sym_XmlPort] = ACTIONS(3738),
    [anon_sym_enum] = ACTIONS(3738),
    [anon_sym_ENUM] = ACTIONS(3738),
    [anon_sym_Enum] = ACTIONS(3738),
    [anon_sym_eNUM] = ACTIONS(3738),
    [anon_sym_eNum] = ACTIONS(3738),
    [anon_sym_ENum] = ACTIONS(3738),
    [sym_quoted_identifier] = ACTIONS(3740),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3740),
    [sym_verbatim_string] = ACTIONS(3740),
    [sym_integer] = ACTIONS(3738),
    [sym_continue_as_identifier] = ACTIONS(3740),
    [sym_preproc_open] = ACTIONS(3740),
    [sym_preproc_close] = ACTIONS(3740),
  },
  [STATE(1815)] = {
    [sym_identifier] = ACTIONS(3742),
    [anon_sym_SEMI] = ACTIONS(3744),
    [anon_sym_DOT] = ACTIONS(3742),
    [anon_sym_EQ] = ACTIONS(3744),
    [anon_sym_COMMA] = ACTIONS(3744),
    [anon_sym_DASH] = ACTIONS(3742),
    [aux_sym_boolean_token1] = ACTIONS(3742),
    [aux_sym_boolean_token2] = ACTIONS(3742),
    [sym_decimal] = ACTIONS(3742),
    [anon_sym_LPAREN] = ACTIONS(3744),
    [anon_sym_DOT_DOT] = ACTIONS(3744),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3742),
    [anon_sym_STAR] = ACTIONS(3742),
    [anon_sym_LBRACK] = ACTIONS(3744),
    [aux_sym_record_type_token1] = ACTIONS(3742),
    [aux_sym_basic_type_token21] = ACTIONS(3742),
    [aux_sym_basic_type_token22] = ACTIONS(3742),
    [aux_sym_basic_type_token48] = ACTIONS(3742),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3742),
    [anon_sym_POUNDif] = ACTIONS(3744),
    [anon_sym_POUNDIF] = ACTIONS(3744),
    [anon_sym_POUNDIf] = ACTIONS(3744),
    [anon_sym_not] = ACTIONS(3742),
    [anon_sym_NOT] = ACTIONS(3742),
    [anon_sym_Not] = ACTIONS(3742),
    [anon_sym_POUNDelif] = ACTIONS(3744),
    [anon_sym_POUNDELIF] = ACTIONS(3744),
    [anon_sym_POUNDElif] = ACTIONS(3744),
    [anon_sym_POUNDelse] = ACTIONS(3744),
    [anon_sym_POUNDELSE] = ACTIONS(3744),
    [anon_sym_POUNDElse] = ACTIONS(3744),
    [anon_sym_POUNDelse2] = ACTIONS(3744),
    [anon_sym_POUNDELSE2] = ACTIONS(3744),
    [anon_sym_POUNDElse2] = ACTIONS(3744),
    [anon_sym_POUNDendif] = ACTIONS(3744),
    [anon_sym_POUNDENDIF] = ACTIONS(3744),
    [anon_sym_POUNDEndif] = ACTIONS(3744),
    [anon_sym_POUNDendif2] = ACTIONS(3744),
    [anon_sym_POUNDENDIF2] = ACTIONS(3744),
    [anon_sym_POUNDEndif2] = ACTIONS(3744),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3744),
    [aux_sym__expression_token1] = ACTIONS(3744),
    [aux_sym__expression_token2] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3742),
    [anon_sym_SLASH] = ACTIONS(3742),
    [anon_sym_div] = ACTIONS(3742),
    [anon_sym_DIV] = ACTIONS(3742),
    [anon_sym_Div] = ACTIONS(3742),
    [anon_sym_mod] = ACTIONS(3742),
    [anon_sym_MOD] = ACTIONS(3742),
    [anon_sym_Mod] = ACTIONS(3742),
    [anon_sym_PLUS] = ACTIONS(3742),
    [anon_sym_GT_EQ] = ACTIONS(3744),
    [anon_sym_LT_EQ] = ACTIONS(3744),
    [anon_sym_GT] = ACTIONS(3742),
    [anon_sym_LT] = ACTIONS(3742),
    [anon_sym_LT_GT] = ACTIONS(3744),
    [anon_sym_and] = ACTIONS(3742),
    [anon_sym_AND] = ACTIONS(3742),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3742),
    [anon_sym_OR] = ACTIONS(3742),
    [anon_sym_Or] = ACTIONS(3742),
    [anon_sym_xor] = ACTIONS(3742),
    [anon_sym_XOR] = ACTIONS(3742),
    [anon_sym_Xor] = ACTIONS(3742),
    [anon_sym_QMARK] = ACTIONS(3744),
    [sym_datetime_literal] = ACTIONS(3744),
    [sym_date_literal] = ACTIONS(3742),
    [sym_time_literal] = ACTIONS(3742),
    [sym_biginteger_literal] = ACTIONS(3744),
    [anon_sym_if] = ACTIONS(3742),
    [anon_sym_IF] = ACTIONS(3742),
    [anon_sym_If] = ACTIONS(3742),
    [anon_sym_else] = ACTIONS(3742),
    [anon_sym_ELSE] = ACTIONS(3742),
    [anon_sym_Else] = ACTIONS(3742),
    [anon_sym_case] = ACTIONS(3742),
    [anon_sym_CASE] = ACTIONS(3742),
    [anon_sym_Case] = ACTIONS(3742),
    [anon_sym_for] = ACTIONS(3742),
    [anon_sym_FOR] = ACTIONS(3742),
    [anon_sym_For] = ACTIONS(3742),
    [anon_sym_foreach] = ACTIONS(3742),
    [anon_sym_FOREACH] = ACTIONS(3742),
    [anon_sym_Foreach] = ACTIONS(3742),
    [anon_sym_while] = ACTIONS(3742),
    [anon_sym_WHILE] = ACTIONS(3742),
    [anon_sym_While] = ACTIONS(3742),
    [anon_sym_repeat] = ACTIONS(3742),
    [anon_sym_REPEAT] = ACTIONS(3742),
    [anon_sym_Repeat] = ACTIONS(3742),
    [anon_sym_exit] = ACTIONS(3742),
    [anon_sym_EXIT] = ACTIONS(3742),
    [anon_sym_Exit] = ACTIONS(3742),
    [anon_sym_continue] = ACTIONS(3742),
    [anon_sym_CONTINUE] = ACTIONS(3742),
    [anon_sym_Continue] = ACTIONS(3742),
    [anon_sym_break] = ACTIONS(3742),
    [anon_sym_BREAK] = ACTIONS(3742),
    [anon_sym_Break] = ACTIONS(3742),
    [anon_sym_with] = ACTIONS(3742),
    [anon_sym_WITH] = ACTIONS(3742),
    [anon_sym_With] = ACTIONS(3742),
    [sym_asserterror_keyword] = ACTIONS(3744),
    [anon_sym_in] = ACTIONS(3742),
    [anon_sym_IN] = ACTIONS(3742),
    [anon_sym_In] = ACTIONS(3742),
    [sym_page_keyword] = ACTIONS(3742),
    [anon_sym_codeunit] = ACTIONS(3742),
    [anon_sym_CODEUNIT] = ACTIONS(3742),
    [anon_sym_Codeunit] = ACTIONS(3742),
    [anon_sym_CodeUnit] = ACTIONS(3742),
    [anon_sym_COdeunit] = ACTIONS(3742),
    [anon_sym_codeUnit] = ACTIONS(3742),
    [sym_report_keyword] = ACTIONS(3742),
    [sym_query_keyword] = ACTIONS(3742),
    [anon_sym_xmlport] = ACTIONS(3742),
    [anon_sym_XMLPORT] = ACTIONS(3742),
    [anon_sym_Xmlport] = ACTIONS(3742),
    [anon_sym_XMLport] = ACTIONS(3742),
    [anon_sym_XMLPort] = ACTIONS(3742),
    [anon_sym_XmlPort] = ACTIONS(3742),
    [anon_sym_enum] = ACTIONS(3742),
    [anon_sym_ENUM] = ACTIONS(3742),
    [anon_sym_Enum] = ACTIONS(3742),
    [anon_sym_eNUM] = ACTIONS(3742),
    [anon_sym_eNum] = ACTIONS(3742),
    [anon_sym_ENum] = ACTIONS(3742),
    [sym_quoted_identifier] = ACTIONS(3744),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3744),
    [sym_verbatim_string] = ACTIONS(3744),
    [sym_integer] = ACTIONS(3742),
    [sym_continue_as_identifier] = ACTIONS(3744),
    [sym_preproc_open] = ACTIONS(3744),
    [sym_preproc_close] = ACTIONS(3744),
  },
  [STATE(1816)] = {
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_SEMI] = ACTIONS(3748),
    [anon_sym_DOT] = ACTIONS(3746),
    [anon_sym_EQ] = ACTIONS(3748),
    [anon_sym_DASH] = ACTIONS(3746),
    [aux_sym_boolean_token1] = ACTIONS(3746),
    [aux_sym_boolean_token2] = ACTIONS(3746),
    [sym_decimal] = ACTIONS(3746),
    [anon_sym_LPAREN] = ACTIONS(3748),
    [anon_sym_DOT_DOT] = ACTIONS(3748),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3746),
    [anon_sym_STAR] = ACTIONS(3746),
    [anon_sym_LBRACK] = ACTIONS(3748),
    [aux_sym_record_type_token1] = ACTIONS(3746),
    [aux_sym_basic_type_token21] = ACTIONS(3746),
    [aux_sym_basic_type_token22] = ACTIONS(3746),
    [aux_sym_basic_type_token48] = ACTIONS(3746),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3746),
    [anon_sym_POUNDif] = ACTIONS(3748),
    [anon_sym_POUNDIF] = ACTIONS(3748),
    [anon_sym_POUNDIf] = ACTIONS(3748),
    [anon_sym_not] = ACTIONS(3746),
    [anon_sym_NOT] = ACTIONS(3746),
    [anon_sym_Not] = ACTIONS(3746),
    [anon_sym_POUNDelif] = ACTIONS(3748),
    [anon_sym_POUNDELIF] = ACTIONS(3748),
    [anon_sym_POUNDElif] = ACTIONS(3748),
    [anon_sym_POUNDelse] = ACTIONS(3748),
    [anon_sym_POUNDELSE] = ACTIONS(3748),
    [anon_sym_POUNDElse] = ACTIONS(3748),
    [anon_sym_POUNDelse2] = ACTIONS(3748),
    [anon_sym_POUNDELSE2] = ACTIONS(3748),
    [anon_sym_POUNDElse2] = ACTIONS(3748),
    [anon_sym_POUNDendif] = ACTIONS(3748),
    [anon_sym_POUNDENDIF] = ACTIONS(3748),
    [anon_sym_POUNDEndif] = ACTIONS(3748),
    [anon_sym_POUNDendif2] = ACTIONS(3748),
    [anon_sym_POUNDENDIF2] = ACTIONS(3748),
    [anon_sym_POUNDEndif2] = ACTIONS(3748),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3748),
    [aux_sym__expression_token1] = ACTIONS(3748),
    [aux_sym__expression_token2] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3746),
    [anon_sym_SLASH] = ACTIONS(3746),
    [anon_sym_div] = ACTIONS(3746),
    [anon_sym_DIV] = ACTIONS(3746),
    [anon_sym_Div] = ACTIONS(3746),
    [anon_sym_mod] = ACTIONS(3746),
    [anon_sym_MOD] = ACTIONS(3746),
    [anon_sym_Mod] = ACTIONS(3746),
    [anon_sym_PLUS] = ACTIONS(3746),
    [anon_sym_GT_EQ] = ACTIONS(3748),
    [anon_sym_LT_EQ] = ACTIONS(3748),
    [anon_sym_GT] = ACTIONS(3746),
    [anon_sym_LT] = ACTIONS(3746),
    [anon_sym_LT_GT] = ACTIONS(3748),
    [anon_sym_and] = ACTIONS(3746),
    [anon_sym_AND] = ACTIONS(3746),
    [anon_sym_And] = ACTIONS(3746),
    [anon_sym_or] = ACTIONS(3746),
    [anon_sym_OR] = ACTIONS(3746),
    [anon_sym_Or] = ACTIONS(3746),
    [anon_sym_xor] = ACTIONS(3746),
    [anon_sym_XOR] = ACTIONS(3746),
    [anon_sym_Xor] = ACTIONS(3746),
    [anon_sym_QMARK] = ACTIONS(3748),
    [sym_datetime_literal] = ACTIONS(3748),
    [sym_date_literal] = ACTIONS(3746),
    [sym_time_literal] = ACTIONS(3746),
    [sym_biginteger_literal] = ACTIONS(3748),
    [anon_sym_if] = ACTIONS(3746),
    [anon_sym_IF] = ACTIONS(3746),
    [anon_sym_If] = ACTIONS(3746),
    [anon_sym_else] = ACTIONS(3746),
    [anon_sym_ELSE] = ACTIONS(3746),
    [anon_sym_Else] = ACTIONS(3746),
    [anon_sym_case] = ACTIONS(3746),
    [anon_sym_CASE] = ACTIONS(3746),
    [anon_sym_Case] = ACTIONS(3746),
    [anon_sym_for] = ACTIONS(3746),
    [anon_sym_FOR] = ACTIONS(3746),
    [anon_sym_For] = ACTIONS(3746),
    [anon_sym_foreach] = ACTIONS(3746),
    [anon_sym_FOREACH] = ACTIONS(3746),
    [anon_sym_Foreach] = ACTIONS(3746),
    [anon_sym_while] = ACTIONS(3746),
    [anon_sym_WHILE] = ACTIONS(3746),
    [anon_sym_While] = ACTIONS(3746),
    [anon_sym_repeat] = ACTIONS(3746),
    [anon_sym_REPEAT] = ACTIONS(3746),
    [anon_sym_Repeat] = ACTIONS(3746),
    [anon_sym_exit] = ACTIONS(3746),
    [anon_sym_EXIT] = ACTIONS(3746),
    [anon_sym_Exit] = ACTIONS(3746),
    [anon_sym_continue] = ACTIONS(3746),
    [anon_sym_CONTINUE] = ACTIONS(3746),
    [anon_sym_Continue] = ACTIONS(3746),
    [anon_sym_break] = ACTIONS(3746),
    [anon_sym_BREAK] = ACTIONS(3746),
    [anon_sym_Break] = ACTIONS(3746),
    [anon_sym_with] = ACTIONS(3746),
    [anon_sym_WITH] = ACTIONS(3746),
    [anon_sym_With] = ACTIONS(3746),
    [sym_asserterror_keyword] = ACTIONS(3748),
    [anon_sym_in] = ACTIONS(3746),
    [anon_sym_IN] = ACTIONS(3746),
    [anon_sym_In] = ACTIONS(3746),
    [sym_page_keyword] = ACTIONS(3746),
    [anon_sym_codeunit] = ACTIONS(3746),
    [anon_sym_CODEUNIT] = ACTIONS(3746),
    [anon_sym_Codeunit] = ACTIONS(3746),
    [anon_sym_CodeUnit] = ACTIONS(3746),
    [anon_sym_COdeunit] = ACTIONS(3746),
    [anon_sym_codeUnit] = ACTIONS(3746),
    [sym_report_keyword] = ACTIONS(3746),
    [sym_query_keyword] = ACTIONS(3746),
    [anon_sym_xmlport] = ACTIONS(3746),
    [anon_sym_XMLPORT] = ACTIONS(3746),
    [anon_sym_Xmlport] = ACTIONS(3746),
    [anon_sym_XMLport] = ACTIONS(3746),
    [anon_sym_XMLPort] = ACTIONS(3746),
    [anon_sym_XmlPort] = ACTIONS(3746),
    [anon_sym_enum] = ACTIONS(3746),
    [anon_sym_ENUM] = ACTIONS(3746),
    [anon_sym_Enum] = ACTIONS(3746),
    [anon_sym_eNUM] = ACTIONS(3746),
    [anon_sym_eNum] = ACTIONS(3746),
    [anon_sym_ENum] = ACTIONS(3746),
    [sym_temporary_keyword] = ACTIONS(3750),
    [sym_quoted_identifier] = ACTIONS(3748),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3748),
    [sym_verbatim_string] = ACTIONS(3748),
    [sym_integer] = ACTIONS(3746),
    [sym_continue_as_identifier] = ACTIONS(3748),
    [sym_preproc_open] = ACTIONS(3748),
    [sym_preproc_close] = ACTIONS(3748),
  },
  [STATE(1817)] = {
    [sym_identifier] = ACTIONS(3752),
    [anon_sym_SEMI] = ACTIONS(3754),
    [anon_sym_DOT] = ACTIONS(3752),
    [anon_sym_EQ] = ACTIONS(3754),
    [anon_sym_COMMA] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3752),
    [aux_sym_boolean_token1] = ACTIONS(3752),
    [aux_sym_boolean_token2] = ACTIONS(3752),
    [sym_decimal] = ACTIONS(3752),
    [anon_sym_LPAREN] = ACTIONS(3754),
    [anon_sym_DOT_DOT] = ACTIONS(3754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3752),
    [anon_sym_STAR] = ACTIONS(3752),
    [anon_sym_LBRACK] = ACTIONS(3754),
    [aux_sym_record_type_token1] = ACTIONS(3752),
    [aux_sym_basic_type_token21] = ACTIONS(3752),
    [aux_sym_basic_type_token22] = ACTIONS(3752),
    [aux_sym_basic_type_token48] = ACTIONS(3752),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3752),
    [anon_sym_POUNDif] = ACTIONS(3754),
    [anon_sym_POUNDIF] = ACTIONS(3754),
    [anon_sym_POUNDIf] = ACTIONS(3754),
    [anon_sym_not] = ACTIONS(3752),
    [anon_sym_NOT] = ACTIONS(3752),
    [anon_sym_Not] = ACTIONS(3752),
    [anon_sym_POUNDelif] = ACTIONS(3754),
    [anon_sym_POUNDELIF] = ACTIONS(3754),
    [anon_sym_POUNDElif] = ACTIONS(3754),
    [anon_sym_POUNDelse] = ACTIONS(3754),
    [anon_sym_POUNDELSE] = ACTIONS(3754),
    [anon_sym_POUNDElse] = ACTIONS(3754),
    [anon_sym_POUNDelse2] = ACTIONS(3754),
    [anon_sym_POUNDELSE2] = ACTIONS(3754),
    [anon_sym_POUNDElse2] = ACTIONS(3754),
    [anon_sym_POUNDendif] = ACTIONS(3754),
    [anon_sym_POUNDENDIF] = ACTIONS(3754),
    [anon_sym_POUNDEndif] = ACTIONS(3754),
    [anon_sym_POUNDendif2] = ACTIONS(3754),
    [anon_sym_POUNDENDIF2] = ACTIONS(3754),
    [anon_sym_POUNDEndif2] = ACTIONS(3754),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3754),
    [aux_sym__expression_token1] = ACTIONS(3754),
    [aux_sym__expression_token2] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3752),
    [anon_sym_SLASH] = ACTIONS(3752),
    [anon_sym_div] = ACTIONS(3752),
    [anon_sym_DIV] = ACTIONS(3752),
    [anon_sym_Div] = ACTIONS(3752),
    [anon_sym_mod] = ACTIONS(3752),
    [anon_sym_MOD] = ACTIONS(3752),
    [anon_sym_Mod] = ACTIONS(3752),
    [anon_sym_PLUS] = ACTIONS(3752),
    [anon_sym_GT_EQ] = ACTIONS(3754),
    [anon_sym_LT_EQ] = ACTIONS(3754),
    [anon_sym_GT] = ACTIONS(3752),
    [anon_sym_LT] = ACTIONS(3752),
    [anon_sym_LT_GT] = ACTIONS(3754),
    [anon_sym_and] = ACTIONS(3752),
    [anon_sym_AND] = ACTIONS(3752),
    [anon_sym_And] = ACTIONS(3752),
    [anon_sym_or] = ACTIONS(3752),
    [anon_sym_OR] = ACTIONS(3752),
    [anon_sym_Or] = ACTIONS(3752),
    [anon_sym_xor] = ACTIONS(3752),
    [anon_sym_XOR] = ACTIONS(3752),
    [anon_sym_Xor] = ACTIONS(3752),
    [anon_sym_QMARK] = ACTIONS(3754),
    [sym_datetime_literal] = ACTIONS(3754),
    [sym_date_literal] = ACTIONS(3752),
    [sym_time_literal] = ACTIONS(3752),
    [sym_biginteger_literal] = ACTIONS(3754),
    [anon_sym_if] = ACTIONS(3752),
    [anon_sym_IF] = ACTIONS(3752),
    [anon_sym_If] = ACTIONS(3752),
    [anon_sym_else] = ACTIONS(3752),
    [anon_sym_ELSE] = ACTIONS(3752),
    [anon_sym_Else] = ACTIONS(3752),
    [anon_sym_case] = ACTIONS(3752),
    [anon_sym_CASE] = ACTIONS(3752),
    [anon_sym_Case] = ACTIONS(3752),
    [anon_sym_for] = ACTIONS(3752),
    [anon_sym_FOR] = ACTIONS(3752),
    [anon_sym_For] = ACTIONS(3752),
    [anon_sym_foreach] = ACTIONS(3752),
    [anon_sym_FOREACH] = ACTIONS(3752),
    [anon_sym_Foreach] = ACTIONS(3752),
    [anon_sym_while] = ACTIONS(3752),
    [anon_sym_WHILE] = ACTIONS(3752),
    [anon_sym_While] = ACTIONS(3752),
    [anon_sym_repeat] = ACTIONS(3752),
    [anon_sym_REPEAT] = ACTIONS(3752),
    [anon_sym_Repeat] = ACTIONS(3752),
    [anon_sym_exit] = ACTIONS(3752),
    [anon_sym_EXIT] = ACTIONS(3752),
    [anon_sym_Exit] = ACTIONS(3752),
    [anon_sym_continue] = ACTIONS(3752),
    [anon_sym_CONTINUE] = ACTIONS(3752),
    [anon_sym_Continue] = ACTIONS(3752),
    [anon_sym_break] = ACTIONS(3752),
    [anon_sym_BREAK] = ACTIONS(3752),
    [anon_sym_Break] = ACTIONS(3752),
    [anon_sym_with] = ACTIONS(3752),
    [anon_sym_WITH] = ACTIONS(3752),
    [anon_sym_With] = ACTIONS(3752),
    [sym_asserterror_keyword] = ACTIONS(3754),
    [anon_sym_in] = ACTIONS(3752),
    [anon_sym_IN] = ACTIONS(3752),
    [anon_sym_In] = ACTIONS(3752),
    [sym_page_keyword] = ACTIONS(3752),
    [anon_sym_codeunit] = ACTIONS(3752),
    [anon_sym_CODEUNIT] = ACTIONS(3752),
    [anon_sym_Codeunit] = ACTIONS(3752),
    [anon_sym_CodeUnit] = ACTIONS(3752),
    [anon_sym_COdeunit] = ACTIONS(3752),
    [anon_sym_codeUnit] = ACTIONS(3752),
    [sym_report_keyword] = ACTIONS(3752),
    [sym_query_keyword] = ACTIONS(3752),
    [anon_sym_xmlport] = ACTIONS(3752),
    [anon_sym_XMLPORT] = ACTIONS(3752),
    [anon_sym_Xmlport] = ACTIONS(3752),
    [anon_sym_XMLport] = ACTIONS(3752),
    [anon_sym_XMLPort] = ACTIONS(3752),
    [anon_sym_XmlPort] = ACTIONS(3752),
    [anon_sym_enum] = ACTIONS(3752),
    [anon_sym_ENUM] = ACTIONS(3752),
    [anon_sym_Enum] = ACTIONS(3752),
    [anon_sym_eNUM] = ACTIONS(3752),
    [anon_sym_eNum] = ACTIONS(3752),
    [anon_sym_ENum] = ACTIONS(3752),
    [sym_quoted_identifier] = ACTIONS(3754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3754),
    [sym_verbatim_string] = ACTIONS(3754),
    [sym_integer] = ACTIONS(3752),
    [sym_continue_as_identifier] = ACTIONS(3754),
    [sym_preproc_open] = ACTIONS(3754),
    [sym_preproc_close] = ACTIONS(3754),
  },
  [STATE(1818)] = {
    [sym_identifier] = ACTIONS(3756),
    [anon_sym_SEMI] = ACTIONS(3758),
    [anon_sym_DOT] = ACTIONS(3756),
    [anon_sym_EQ] = ACTIONS(3758),
    [anon_sym_DASH] = ACTIONS(3756),
    [aux_sym_boolean_token1] = ACTIONS(3756),
    [aux_sym_boolean_token2] = ACTIONS(3756),
    [sym_decimal] = ACTIONS(3756),
    [anon_sym_LPAREN] = ACTIONS(3758),
    [anon_sym_DOT_DOT] = ACTIONS(3758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3756),
    [anon_sym_LBRACK] = ACTIONS(3758),
    [aux_sym_record_type_token1] = ACTIONS(3756),
    [aux_sym_basic_type_token21] = ACTIONS(3756),
    [aux_sym_basic_type_token22] = ACTIONS(3756),
    [aux_sym_basic_type_token48] = ACTIONS(3756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3756),
    [anon_sym_COLON_COLON] = ACTIONS(3758),
    [anon_sym_POUNDif] = ACTIONS(3758),
    [anon_sym_POUNDIF] = ACTIONS(3758),
    [anon_sym_POUNDIf] = ACTIONS(3758),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_NOT] = ACTIONS(3756),
    [anon_sym_Not] = ACTIONS(3756),
    [anon_sym_POUNDelif] = ACTIONS(3758),
    [anon_sym_POUNDELIF] = ACTIONS(3758),
    [anon_sym_POUNDElif] = ACTIONS(3758),
    [anon_sym_POUNDelse] = ACTIONS(3758),
    [anon_sym_POUNDELSE] = ACTIONS(3758),
    [anon_sym_POUNDElse] = ACTIONS(3758),
    [anon_sym_POUNDelse2] = ACTIONS(3758),
    [anon_sym_POUNDELSE2] = ACTIONS(3758),
    [anon_sym_POUNDElse2] = ACTIONS(3758),
    [anon_sym_POUNDendif] = ACTIONS(3758),
    [anon_sym_POUNDENDIF] = ACTIONS(3758),
    [anon_sym_POUNDEndif] = ACTIONS(3758),
    [anon_sym_POUNDendif2] = ACTIONS(3758),
    [anon_sym_POUNDENDIF2] = ACTIONS(3758),
    [anon_sym_POUNDEndif2] = ACTIONS(3758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3758),
    [aux_sym__expression_token1] = ACTIONS(3758),
    [aux_sym__expression_token2] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3756),
    [anon_sym_SLASH] = ACTIONS(3756),
    [anon_sym_div] = ACTIONS(3756),
    [anon_sym_DIV] = ACTIONS(3756),
    [anon_sym_Div] = ACTIONS(3756),
    [anon_sym_mod] = ACTIONS(3756),
    [anon_sym_MOD] = ACTIONS(3756),
    [anon_sym_Mod] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_GT_EQ] = ACTIONS(3758),
    [anon_sym_LT_EQ] = ACTIONS(3758),
    [anon_sym_GT] = ACTIONS(3756),
    [anon_sym_LT] = ACTIONS(3756),
    [anon_sym_LT_GT] = ACTIONS(3758),
    [anon_sym_and] = ACTIONS(3756),
    [anon_sym_AND] = ACTIONS(3756),
    [anon_sym_And] = ACTIONS(3756),
    [anon_sym_or] = ACTIONS(3756),
    [anon_sym_OR] = ACTIONS(3756),
    [anon_sym_Or] = ACTIONS(3756),
    [anon_sym_xor] = ACTIONS(3756),
    [anon_sym_XOR] = ACTIONS(3756),
    [anon_sym_Xor] = ACTIONS(3756),
    [anon_sym_QMARK] = ACTIONS(3758),
    [sym_datetime_literal] = ACTIONS(3758),
    [sym_date_literal] = ACTIONS(3756),
    [sym_time_literal] = ACTIONS(3756),
    [sym_biginteger_literal] = ACTIONS(3758),
    [anon_sym_if] = ACTIONS(3756),
    [anon_sym_IF] = ACTIONS(3756),
    [anon_sym_If] = ACTIONS(3756),
    [anon_sym_else] = ACTIONS(3756),
    [anon_sym_ELSE] = ACTIONS(3756),
    [anon_sym_Else] = ACTIONS(3756),
    [anon_sym_case] = ACTIONS(3756),
    [anon_sym_CASE] = ACTIONS(3756),
    [anon_sym_Case] = ACTIONS(3756),
    [anon_sym_for] = ACTIONS(3756),
    [anon_sym_FOR] = ACTIONS(3756),
    [anon_sym_For] = ACTIONS(3756),
    [anon_sym_foreach] = ACTIONS(3756),
    [anon_sym_FOREACH] = ACTIONS(3756),
    [anon_sym_Foreach] = ACTIONS(3756),
    [anon_sym_while] = ACTIONS(3756),
    [anon_sym_WHILE] = ACTIONS(3756),
    [anon_sym_While] = ACTIONS(3756),
    [anon_sym_repeat] = ACTIONS(3756),
    [anon_sym_REPEAT] = ACTIONS(3756),
    [anon_sym_Repeat] = ACTIONS(3756),
    [anon_sym_exit] = ACTIONS(3756),
    [anon_sym_EXIT] = ACTIONS(3756),
    [anon_sym_Exit] = ACTIONS(3756),
    [anon_sym_continue] = ACTIONS(3756),
    [anon_sym_CONTINUE] = ACTIONS(3756),
    [anon_sym_Continue] = ACTIONS(3756),
    [anon_sym_break] = ACTIONS(3756),
    [anon_sym_BREAK] = ACTIONS(3756),
    [anon_sym_Break] = ACTIONS(3756),
    [anon_sym_with] = ACTIONS(3756),
    [anon_sym_WITH] = ACTIONS(3756),
    [anon_sym_With] = ACTIONS(3756),
    [sym_asserterror_keyword] = ACTIONS(3758),
    [anon_sym_in] = ACTIONS(3756),
    [anon_sym_IN] = ACTIONS(3756),
    [anon_sym_In] = ACTIONS(3756),
    [sym_page_keyword] = ACTIONS(3756),
    [anon_sym_codeunit] = ACTIONS(3756),
    [anon_sym_CODEUNIT] = ACTIONS(3756),
    [anon_sym_Codeunit] = ACTIONS(3756),
    [anon_sym_CodeUnit] = ACTIONS(3756),
    [anon_sym_COdeunit] = ACTIONS(3756),
    [anon_sym_codeUnit] = ACTIONS(3756),
    [sym_report_keyword] = ACTIONS(3756),
    [sym_query_keyword] = ACTIONS(3756),
    [anon_sym_xmlport] = ACTIONS(3756),
    [anon_sym_XMLPORT] = ACTIONS(3756),
    [anon_sym_Xmlport] = ACTIONS(3756),
    [anon_sym_XMLport] = ACTIONS(3756),
    [anon_sym_XMLPort] = ACTIONS(3756),
    [anon_sym_XmlPort] = ACTIONS(3756),
    [anon_sym_enum] = ACTIONS(3756),
    [anon_sym_ENUM] = ACTIONS(3756),
    [anon_sym_Enum] = ACTIONS(3756),
    [anon_sym_eNUM] = ACTIONS(3756),
    [anon_sym_eNum] = ACTIONS(3756),
    [anon_sym_ENum] = ACTIONS(3756),
    [sym_quoted_identifier] = ACTIONS(3758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3758),
    [sym_verbatim_string] = ACTIONS(3758),
    [sym_integer] = ACTIONS(3756),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_open] = ACTIONS(3758),
    [sym_preproc_close] = ACTIONS(3758),
  },
  [STATE(1819)] = {
    [sym_identifier] = ACTIONS(3760),
    [anon_sym_SEMI] = ACTIONS(3762),
    [anon_sym_DOT] = ACTIONS(3760),
    [anon_sym_EQ] = ACTIONS(3762),
    [anon_sym_DASH] = ACTIONS(3760),
    [aux_sym_boolean_token1] = ACTIONS(3760),
    [aux_sym_boolean_token2] = ACTIONS(3760),
    [sym_decimal] = ACTIONS(3760),
    [anon_sym_LPAREN] = ACTIONS(3762),
    [anon_sym_DOT_DOT] = ACTIONS(3762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3760),
    [anon_sym_STAR] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3762),
    [aux_sym_record_type_token1] = ACTIONS(3760),
    [aux_sym_basic_type_token21] = ACTIONS(3760),
    [aux_sym_basic_type_token22] = ACTIONS(3760),
    [aux_sym_basic_type_token48] = ACTIONS(3760),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3760),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(3762),
    [anon_sym_POUNDIF] = ACTIONS(3762),
    [anon_sym_POUNDIf] = ACTIONS(3762),
    [anon_sym_not] = ACTIONS(3760),
    [anon_sym_NOT] = ACTIONS(3760),
    [anon_sym_Not] = ACTIONS(3760),
    [anon_sym_POUNDelif] = ACTIONS(3762),
    [anon_sym_POUNDELIF] = ACTIONS(3762),
    [anon_sym_POUNDElif] = ACTIONS(3762),
    [anon_sym_POUNDelse] = ACTIONS(3762),
    [anon_sym_POUNDELSE] = ACTIONS(3762),
    [anon_sym_POUNDElse] = ACTIONS(3762),
    [anon_sym_POUNDelse2] = ACTIONS(3762),
    [anon_sym_POUNDELSE2] = ACTIONS(3762),
    [anon_sym_POUNDElse2] = ACTIONS(3762),
    [anon_sym_POUNDendif] = ACTIONS(3762),
    [anon_sym_POUNDENDIF] = ACTIONS(3762),
    [anon_sym_POUNDEndif] = ACTIONS(3762),
    [anon_sym_POUNDendif2] = ACTIONS(3762),
    [anon_sym_POUNDENDIF2] = ACTIONS(3762),
    [anon_sym_POUNDEndif2] = ACTIONS(3762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3762),
    [aux_sym__expression_token1] = ACTIONS(3762),
    [aux_sym__expression_token2] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3760),
    [anon_sym_SLASH] = ACTIONS(3760),
    [anon_sym_div] = ACTIONS(3760),
    [anon_sym_DIV] = ACTIONS(3760),
    [anon_sym_Div] = ACTIONS(3760),
    [anon_sym_mod] = ACTIONS(3760),
    [anon_sym_MOD] = ACTIONS(3760),
    [anon_sym_Mod] = ACTIONS(3760),
    [anon_sym_PLUS] = ACTIONS(3760),
    [anon_sym_GT_EQ] = ACTIONS(3762),
    [anon_sym_LT_EQ] = ACTIONS(3762),
    [anon_sym_GT] = ACTIONS(3760),
    [anon_sym_LT] = ACTIONS(3760),
    [anon_sym_LT_GT] = ACTIONS(3762),
    [anon_sym_and] = ACTIONS(3760),
    [anon_sym_AND] = ACTIONS(3760),
    [anon_sym_And] = ACTIONS(3760),
    [anon_sym_or] = ACTIONS(3760),
    [anon_sym_OR] = ACTIONS(3760),
    [anon_sym_Or] = ACTIONS(3760),
    [anon_sym_xor] = ACTIONS(3760),
    [anon_sym_XOR] = ACTIONS(3760),
    [anon_sym_Xor] = ACTIONS(3760),
    [anon_sym_QMARK] = ACTIONS(3762),
    [sym_datetime_literal] = ACTIONS(3762),
    [sym_date_literal] = ACTIONS(3760),
    [sym_time_literal] = ACTIONS(3760),
    [sym_biginteger_literal] = ACTIONS(3762),
    [anon_sym_if] = ACTIONS(3760),
    [anon_sym_IF] = ACTIONS(3760),
    [anon_sym_If] = ACTIONS(3760),
    [anon_sym_else] = ACTIONS(3760),
    [anon_sym_ELSE] = ACTIONS(3760),
    [anon_sym_Else] = ACTIONS(3760),
    [anon_sym_case] = ACTIONS(3760),
    [anon_sym_CASE] = ACTIONS(3760),
    [anon_sym_Case] = ACTIONS(3760),
    [anon_sym_for] = ACTIONS(3760),
    [anon_sym_FOR] = ACTIONS(3760),
    [anon_sym_For] = ACTIONS(3760),
    [anon_sym_foreach] = ACTIONS(3760),
    [anon_sym_FOREACH] = ACTIONS(3760),
    [anon_sym_Foreach] = ACTIONS(3760),
    [anon_sym_while] = ACTIONS(3760),
    [anon_sym_WHILE] = ACTIONS(3760),
    [anon_sym_While] = ACTIONS(3760),
    [anon_sym_repeat] = ACTIONS(3760),
    [anon_sym_REPEAT] = ACTIONS(3760),
    [anon_sym_Repeat] = ACTIONS(3760),
    [anon_sym_exit] = ACTIONS(3760),
    [anon_sym_EXIT] = ACTIONS(3760),
    [anon_sym_Exit] = ACTIONS(3760),
    [anon_sym_continue] = ACTIONS(3760),
    [anon_sym_CONTINUE] = ACTIONS(3760),
    [anon_sym_Continue] = ACTIONS(3760),
    [anon_sym_break] = ACTIONS(3760),
    [anon_sym_BREAK] = ACTIONS(3760),
    [anon_sym_Break] = ACTIONS(3760),
    [anon_sym_with] = ACTIONS(3760),
    [anon_sym_WITH] = ACTIONS(3760),
    [anon_sym_With] = ACTIONS(3760),
    [sym_asserterror_keyword] = ACTIONS(3762),
    [anon_sym_in] = ACTIONS(3760),
    [anon_sym_IN] = ACTIONS(3760),
    [anon_sym_In] = ACTIONS(3760),
    [sym_page_keyword] = ACTIONS(3760),
    [anon_sym_codeunit] = ACTIONS(3760),
    [anon_sym_CODEUNIT] = ACTIONS(3760),
    [anon_sym_Codeunit] = ACTIONS(3760),
    [anon_sym_CodeUnit] = ACTIONS(3760),
    [anon_sym_COdeunit] = ACTIONS(3760),
    [anon_sym_codeUnit] = ACTIONS(3760),
    [sym_report_keyword] = ACTIONS(3760),
    [sym_query_keyword] = ACTIONS(3760),
    [anon_sym_xmlport] = ACTIONS(3760),
    [anon_sym_XMLPORT] = ACTIONS(3760),
    [anon_sym_Xmlport] = ACTIONS(3760),
    [anon_sym_XMLport] = ACTIONS(3760),
    [anon_sym_XMLPort] = ACTIONS(3760),
    [anon_sym_XmlPort] = ACTIONS(3760),
    [anon_sym_enum] = ACTIONS(3760),
    [anon_sym_ENUM] = ACTIONS(3760),
    [anon_sym_Enum] = ACTIONS(3760),
    [anon_sym_eNUM] = ACTIONS(3760),
    [anon_sym_eNum] = ACTIONS(3760),
    [anon_sym_ENum] = ACTIONS(3760),
    [sym_quoted_identifier] = ACTIONS(3762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3762),
    [sym_verbatim_string] = ACTIONS(3762),
    [sym_integer] = ACTIONS(3760),
    [sym_continue_as_identifier] = ACTIONS(3762),
    [sym_preproc_open] = ACTIONS(3762),
    [sym_preproc_close] = ACTIONS(3762),
  },
  [STATE(1820)] = {
    [sym_identifier] = ACTIONS(3764),
    [anon_sym_SEMI] = ACTIONS(3766),
    [anon_sym_DOT] = ACTIONS(3764),
    [anon_sym_EQ] = ACTIONS(3766),
    [anon_sym_DASH] = ACTIONS(3764),
    [aux_sym_boolean_token1] = ACTIONS(3764),
    [aux_sym_boolean_token2] = ACTIONS(3764),
    [sym_decimal] = ACTIONS(3764),
    [anon_sym_LPAREN] = ACTIONS(3766),
    [anon_sym_DOT_DOT] = ACTIONS(3766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3764),
    [anon_sym_STAR] = ACTIONS(3764),
    [anon_sym_LBRACK] = ACTIONS(3766),
    [aux_sym_record_type_token1] = ACTIONS(3764),
    [aux_sym_basic_type_token21] = ACTIONS(3764),
    [aux_sym_basic_type_token22] = ACTIONS(3764),
    [aux_sym_basic_type_token48] = ACTIONS(3764),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3764),
    [anon_sym_COLON_COLON] = ACTIONS(3766),
    [anon_sym_POUNDif] = ACTIONS(3766),
    [anon_sym_POUNDIF] = ACTIONS(3766),
    [anon_sym_POUNDIf] = ACTIONS(3766),
    [anon_sym_not] = ACTIONS(3764),
    [anon_sym_NOT] = ACTIONS(3764),
    [anon_sym_Not] = ACTIONS(3764),
    [anon_sym_POUNDelif] = ACTIONS(3766),
    [anon_sym_POUNDELIF] = ACTIONS(3766),
    [anon_sym_POUNDElif] = ACTIONS(3766),
    [anon_sym_POUNDelse] = ACTIONS(3766),
    [anon_sym_POUNDELSE] = ACTIONS(3766),
    [anon_sym_POUNDElse] = ACTIONS(3766),
    [anon_sym_POUNDelse2] = ACTIONS(3766),
    [anon_sym_POUNDELSE2] = ACTIONS(3766),
    [anon_sym_POUNDElse2] = ACTIONS(3766),
    [anon_sym_POUNDendif] = ACTIONS(3766),
    [anon_sym_POUNDENDIF] = ACTIONS(3766),
    [anon_sym_POUNDEndif] = ACTIONS(3766),
    [anon_sym_POUNDendif2] = ACTIONS(3766),
    [anon_sym_POUNDENDIF2] = ACTIONS(3766),
    [anon_sym_POUNDEndif2] = ACTIONS(3766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3766),
    [aux_sym__expression_token1] = ACTIONS(3766),
    [aux_sym__expression_token2] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3764),
    [anon_sym_SLASH] = ACTIONS(3764),
    [anon_sym_div] = ACTIONS(3764),
    [anon_sym_DIV] = ACTIONS(3764),
    [anon_sym_Div] = ACTIONS(3764),
    [anon_sym_mod] = ACTIONS(3764),
    [anon_sym_MOD] = ACTIONS(3764),
    [anon_sym_Mod] = ACTIONS(3764),
    [anon_sym_PLUS] = ACTIONS(3764),
    [anon_sym_GT_EQ] = ACTIONS(3766),
    [anon_sym_LT_EQ] = ACTIONS(3766),
    [anon_sym_GT] = ACTIONS(3764),
    [anon_sym_LT] = ACTIONS(3764),
    [anon_sym_LT_GT] = ACTIONS(3766),
    [anon_sym_and] = ACTIONS(3764),
    [anon_sym_AND] = ACTIONS(3764),
    [anon_sym_And] = ACTIONS(3764),
    [anon_sym_or] = ACTIONS(3764),
    [anon_sym_OR] = ACTIONS(3764),
    [anon_sym_Or] = ACTIONS(3764),
    [anon_sym_xor] = ACTIONS(3764),
    [anon_sym_XOR] = ACTIONS(3764),
    [anon_sym_Xor] = ACTIONS(3764),
    [anon_sym_QMARK] = ACTIONS(3766),
    [sym_datetime_literal] = ACTIONS(3766),
    [sym_date_literal] = ACTIONS(3764),
    [sym_time_literal] = ACTIONS(3764),
    [sym_biginteger_literal] = ACTIONS(3766),
    [anon_sym_if] = ACTIONS(3764),
    [anon_sym_IF] = ACTIONS(3764),
    [anon_sym_If] = ACTIONS(3764),
    [anon_sym_else] = ACTIONS(3764),
    [anon_sym_ELSE] = ACTIONS(3764),
    [anon_sym_Else] = ACTIONS(3764),
    [anon_sym_case] = ACTIONS(3764),
    [anon_sym_CASE] = ACTIONS(3764),
    [anon_sym_Case] = ACTIONS(3764),
    [anon_sym_for] = ACTIONS(3764),
    [anon_sym_FOR] = ACTIONS(3764),
    [anon_sym_For] = ACTIONS(3764),
    [anon_sym_foreach] = ACTIONS(3764),
    [anon_sym_FOREACH] = ACTIONS(3764),
    [anon_sym_Foreach] = ACTIONS(3764),
    [anon_sym_while] = ACTIONS(3764),
    [anon_sym_WHILE] = ACTIONS(3764),
    [anon_sym_While] = ACTIONS(3764),
    [anon_sym_repeat] = ACTIONS(3764),
    [anon_sym_REPEAT] = ACTIONS(3764),
    [anon_sym_Repeat] = ACTIONS(3764),
    [anon_sym_exit] = ACTIONS(3764),
    [anon_sym_EXIT] = ACTIONS(3764),
    [anon_sym_Exit] = ACTIONS(3764),
    [anon_sym_continue] = ACTIONS(3764),
    [anon_sym_CONTINUE] = ACTIONS(3764),
    [anon_sym_Continue] = ACTIONS(3764),
    [anon_sym_break] = ACTIONS(3764),
    [anon_sym_BREAK] = ACTIONS(3764),
    [anon_sym_Break] = ACTIONS(3764),
    [anon_sym_with] = ACTIONS(3764),
    [anon_sym_WITH] = ACTIONS(3764),
    [anon_sym_With] = ACTIONS(3764),
    [sym_asserterror_keyword] = ACTIONS(3766),
    [anon_sym_in] = ACTIONS(3764),
    [anon_sym_IN] = ACTIONS(3764),
    [anon_sym_In] = ACTIONS(3764),
    [sym_page_keyword] = ACTIONS(3764),
    [anon_sym_codeunit] = ACTIONS(3764),
    [anon_sym_CODEUNIT] = ACTIONS(3764),
    [anon_sym_Codeunit] = ACTIONS(3764),
    [anon_sym_CodeUnit] = ACTIONS(3764),
    [anon_sym_COdeunit] = ACTIONS(3764),
    [anon_sym_codeUnit] = ACTIONS(3764),
    [sym_report_keyword] = ACTIONS(3764),
    [sym_query_keyword] = ACTIONS(3764),
    [anon_sym_xmlport] = ACTIONS(3764),
    [anon_sym_XMLPORT] = ACTIONS(3764),
    [anon_sym_Xmlport] = ACTIONS(3764),
    [anon_sym_XMLport] = ACTIONS(3764),
    [anon_sym_XMLPort] = ACTIONS(3764),
    [anon_sym_XmlPort] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3764),
    [anon_sym_ENUM] = ACTIONS(3764),
    [anon_sym_Enum] = ACTIONS(3764),
    [anon_sym_eNUM] = ACTIONS(3764),
    [anon_sym_eNum] = ACTIONS(3764),
    [anon_sym_ENum] = ACTIONS(3764),
    [sym_quoted_identifier] = ACTIONS(3766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3766),
    [sym_verbatim_string] = ACTIONS(3766),
    [sym_integer] = ACTIONS(3764),
    [sym_continue_as_identifier] = ACTIONS(3766),
    [sym_preproc_open] = ACTIONS(3766),
    [sym_preproc_close] = ACTIONS(3766),
  },
  [STATE(1821)] = {
    [sym_identifier] = ACTIONS(3768),
    [anon_sym_SEMI] = ACTIONS(3770),
    [anon_sym_DOT] = ACTIONS(3768),
    [anon_sym_EQ] = ACTIONS(3770),
    [anon_sym_DASH] = ACTIONS(3768),
    [aux_sym_boolean_token1] = ACTIONS(3768),
    [aux_sym_boolean_token2] = ACTIONS(3768),
    [sym_decimal] = ACTIONS(3768),
    [anon_sym_LPAREN] = ACTIONS(3770),
    [anon_sym_DOT_DOT] = ACTIONS(3770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3768),
    [anon_sym_STAR] = ACTIONS(3768),
    [anon_sym_LBRACK] = ACTIONS(3770),
    [aux_sym_record_type_token1] = ACTIONS(3768),
    [aux_sym_basic_type_token21] = ACTIONS(3768),
    [aux_sym_basic_type_token22] = ACTIONS(3768),
    [aux_sym_basic_type_token48] = ACTIONS(3768),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3768),
    [anon_sym_COLON_COLON] = ACTIONS(3770),
    [anon_sym_POUNDif] = ACTIONS(3770),
    [anon_sym_POUNDIF] = ACTIONS(3770),
    [anon_sym_POUNDIf] = ACTIONS(3770),
    [anon_sym_not] = ACTIONS(3768),
    [anon_sym_NOT] = ACTIONS(3768),
    [anon_sym_Not] = ACTIONS(3768),
    [anon_sym_POUNDelif] = ACTIONS(3770),
    [anon_sym_POUNDELIF] = ACTIONS(3770),
    [anon_sym_POUNDElif] = ACTIONS(3770),
    [anon_sym_POUNDelse] = ACTIONS(3770),
    [anon_sym_POUNDELSE] = ACTIONS(3770),
    [anon_sym_POUNDElse] = ACTIONS(3770),
    [anon_sym_POUNDelse2] = ACTIONS(3770),
    [anon_sym_POUNDELSE2] = ACTIONS(3770),
    [anon_sym_POUNDElse2] = ACTIONS(3770),
    [anon_sym_POUNDendif] = ACTIONS(3770),
    [anon_sym_POUNDENDIF] = ACTIONS(3770),
    [anon_sym_POUNDEndif] = ACTIONS(3770),
    [anon_sym_POUNDendif2] = ACTIONS(3770),
    [anon_sym_POUNDENDIF2] = ACTIONS(3770),
    [anon_sym_POUNDEndif2] = ACTIONS(3770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3770),
    [aux_sym__expression_token1] = ACTIONS(3770),
    [aux_sym__expression_token2] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3768),
    [anon_sym_SLASH] = ACTIONS(3768),
    [anon_sym_div] = ACTIONS(3768),
    [anon_sym_DIV] = ACTIONS(3768),
    [anon_sym_Div] = ACTIONS(3768),
    [anon_sym_mod] = ACTIONS(3768),
    [anon_sym_MOD] = ACTIONS(3768),
    [anon_sym_Mod] = ACTIONS(3768),
    [anon_sym_PLUS] = ACTIONS(3768),
    [anon_sym_GT_EQ] = ACTIONS(3770),
    [anon_sym_LT_EQ] = ACTIONS(3770),
    [anon_sym_GT] = ACTIONS(3768),
    [anon_sym_LT] = ACTIONS(3768),
    [anon_sym_LT_GT] = ACTIONS(3770),
    [anon_sym_and] = ACTIONS(3768),
    [anon_sym_AND] = ACTIONS(3768),
    [anon_sym_And] = ACTIONS(3768),
    [anon_sym_or] = ACTIONS(3768),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3768),
    [anon_sym_xor] = ACTIONS(3768),
    [anon_sym_XOR] = ACTIONS(3768),
    [anon_sym_Xor] = ACTIONS(3768),
    [anon_sym_QMARK] = ACTIONS(3770),
    [sym_datetime_literal] = ACTIONS(3770),
    [sym_date_literal] = ACTIONS(3768),
    [sym_time_literal] = ACTIONS(3768),
    [sym_biginteger_literal] = ACTIONS(3770),
    [anon_sym_if] = ACTIONS(3768),
    [anon_sym_IF] = ACTIONS(3768),
    [anon_sym_If] = ACTIONS(3768),
    [anon_sym_else] = ACTIONS(3768),
    [anon_sym_ELSE] = ACTIONS(3768),
    [anon_sym_Else] = ACTIONS(3768),
    [anon_sym_case] = ACTIONS(3768),
    [anon_sym_CASE] = ACTIONS(3768),
    [anon_sym_Case] = ACTIONS(3768),
    [anon_sym_for] = ACTIONS(3768),
    [anon_sym_FOR] = ACTIONS(3768),
    [anon_sym_For] = ACTIONS(3768),
    [anon_sym_foreach] = ACTIONS(3768),
    [anon_sym_FOREACH] = ACTIONS(3768),
    [anon_sym_Foreach] = ACTIONS(3768),
    [anon_sym_while] = ACTIONS(3768),
    [anon_sym_WHILE] = ACTIONS(3768),
    [anon_sym_While] = ACTIONS(3768),
    [anon_sym_repeat] = ACTIONS(3768),
    [anon_sym_REPEAT] = ACTIONS(3768),
    [anon_sym_Repeat] = ACTIONS(3768),
    [anon_sym_exit] = ACTIONS(3768),
    [anon_sym_EXIT] = ACTIONS(3768),
    [anon_sym_Exit] = ACTIONS(3768),
    [anon_sym_continue] = ACTIONS(3768),
    [anon_sym_CONTINUE] = ACTIONS(3768),
    [anon_sym_Continue] = ACTIONS(3768),
    [anon_sym_break] = ACTIONS(3768),
    [anon_sym_BREAK] = ACTIONS(3768),
    [anon_sym_Break] = ACTIONS(3768),
    [anon_sym_with] = ACTIONS(3768),
    [anon_sym_WITH] = ACTIONS(3768),
    [anon_sym_With] = ACTIONS(3768),
    [sym_asserterror_keyword] = ACTIONS(3770),
    [anon_sym_in] = ACTIONS(3768),
    [anon_sym_IN] = ACTIONS(3768),
    [anon_sym_In] = ACTIONS(3768),
    [sym_page_keyword] = ACTIONS(3768),
    [anon_sym_codeunit] = ACTIONS(3768),
    [anon_sym_CODEUNIT] = ACTIONS(3768),
    [anon_sym_Codeunit] = ACTIONS(3768),
    [anon_sym_CodeUnit] = ACTIONS(3768),
    [anon_sym_COdeunit] = ACTIONS(3768),
    [anon_sym_codeUnit] = ACTIONS(3768),
    [sym_report_keyword] = ACTIONS(3768),
    [sym_query_keyword] = ACTIONS(3768),
    [anon_sym_xmlport] = ACTIONS(3768),
    [anon_sym_XMLPORT] = ACTIONS(3768),
    [anon_sym_Xmlport] = ACTIONS(3768),
    [anon_sym_XMLport] = ACTIONS(3768),
    [anon_sym_XMLPort] = ACTIONS(3768),
    [anon_sym_XmlPort] = ACTIONS(3768),
    [anon_sym_enum] = ACTIONS(3768),
    [anon_sym_ENUM] = ACTIONS(3768),
    [anon_sym_Enum] = ACTIONS(3768),
    [anon_sym_eNUM] = ACTIONS(3768),
    [anon_sym_eNum] = ACTIONS(3768),
    [anon_sym_ENum] = ACTIONS(3768),
    [sym_quoted_identifier] = ACTIONS(3770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3770),
    [sym_verbatim_string] = ACTIONS(3770),
    [sym_integer] = ACTIONS(3768),
    [sym_continue_as_identifier] = ACTIONS(3770),
    [sym_preproc_open] = ACTIONS(3770),
    [sym_preproc_close] = ACTIONS(3770),
  },
  [STATE(1822)] = {
    [sym_identifier] = ACTIONS(3772),
    [anon_sym_SEMI] = ACTIONS(3774),
    [anon_sym_DOT] = ACTIONS(3772),
    [anon_sym_EQ] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [aux_sym_boolean_token1] = ACTIONS(3772),
    [aux_sym_boolean_token2] = ACTIONS(3772),
    [sym_decimal] = ACTIONS(3772),
    [anon_sym_LPAREN] = ACTIONS(3774),
    [anon_sym_DOT_DOT] = ACTIONS(3774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(3772),
    [anon_sym_LBRACK] = ACTIONS(3774),
    [aux_sym_record_type_token1] = ACTIONS(3772),
    [aux_sym_basic_type_token21] = ACTIONS(3772),
    [aux_sym_basic_type_token22] = ACTIONS(3772),
    [aux_sym_basic_type_token48] = ACTIONS(3772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3772),
    [anon_sym_COLON_COLON] = ACTIONS(3774),
    [anon_sym_POUNDif] = ACTIONS(3774),
    [anon_sym_POUNDIF] = ACTIONS(3774),
    [anon_sym_POUNDIf] = ACTIONS(3774),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_NOT] = ACTIONS(3772),
    [anon_sym_Not] = ACTIONS(3772),
    [anon_sym_POUNDelif] = ACTIONS(3774),
    [anon_sym_POUNDELIF] = ACTIONS(3774),
    [anon_sym_POUNDElif] = ACTIONS(3774),
    [anon_sym_POUNDelse] = ACTIONS(3774),
    [anon_sym_POUNDELSE] = ACTIONS(3774),
    [anon_sym_POUNDElse] = ACTIONS(3774),
    [anon_sym_POUNDelse2] = ACTIONS(3774),
    [anon_sym_POUNDELSE2] = ACTIONS(3774),
    [anon_sym_POUNDElse2] = ACTIONS(3774),
    [anon_sym_POUNDendif] = ACTIONS(3774),
    [anon_sym_POUNDENDIF] = ACTIONS(3774),
    [anon_sym_POUNDEndif] = ACTIONS(3774),
    [anon_sym_POUNDendif2] = ACTIONS(3774),
    [anon_sym_POUNDENDIF2] = ACTIONS(3774),
    [anon_sym_POUNDEndif2] = ACTIONS(3774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3774),
    [aux_sym__expression_token1] = ACTIONS(3774),
    [aux_sym__expression_token2] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3772),
    [anon_sym_SLASH] = ACTIONS(3772),
    [anon_sym_div] = ACTIONS(3772),
    [anon_sym_DIV] = ACTIONS(3772),
    [anon_sym_Div] = ACTIONS(3772),
    [anon_sym_mod] = ACTIONS(3772),
    [anon_sym_MOD] = ACTIONS(3772),
    [anon_sym_Mod] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_GT_EQ] = ACTIONS(3774),
    [anon_sym_LT_EQ] = ACTIONS(3774),
    [anon_sym_GT] = ACTIONS(3772),
    [anon_sym_LT] = ACTIONS(3772),
    [anon_sym_LT_GT] = ACTIONS(3774),
    [anon_sym_and] = ACTIONS(3772),
    [anon_sym_AND] = ACTIONS(3772),
    [anon_sym_And] = ACTIONS(3772),
    [anon_sym_or] = ACTIONS(3772),
    [anon_sym_OR] = ACTIONS(3772),
    [anon_sym_Or] = ACTIONS(3772),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3772),
    [anon_sym_Xor] = ACTIONS(3772),
    [anon_sym_QMARK] = ACTIONS(3774),
    [sym_datetime_literal] = ACTIONS(3774),
    [sym_date_literal] = ACTIONS(3772),
    [sym_time_literal] = ACTIONS(3772),
    [sym_biginteger_literal] = ACTIONS(3774),
    [anon_sym_if] = ACTIONS(3772),
    [anon_sym_IF] = ACTIONS(3772),
    [anon_sym_If] = ACTIONS(3772),
    [anon_sym_else] = ACTIONS(3772),
    [anon_sym_ELSE] = ACTIONS(3772),
    [anon_sym_Else] = ACTIONS(3772),
    [anon_sym_case] = ACTIONS(3772),
    [anon_sym_CASE] = ACTIONS(3772),
    [anon_sym_Case] = ACTIONS(3772),
    [anon_sym_for] = ACTIONS(3772),
    [anon_sym_FOR] = ACTIONS(3772),
    [anon_sym_For] = ACTIONS(3772),
    [anon_sym_foreach] = ACTIONS(3772),
    [anon_sym_FOREACH] = ACTIONS(3772),
    [anon_sym_Foreach] = ACTIONS(3772),
    [anon_sym_while] = ACTIONS(3772),
    [anon_sym_WHILE] = ACTIONS(3772),
    [anon_sym_While] = ACTIONS(3772),
    [anon_sym_repeat] = ACTIONS(3772),
    [anon_sym_REPEAT] = ACTIONS(3772),
    [anon_sym_Repeat] = ACTIONS(3772),
    [anon_sym_exit] = ACTIONS(3772),
    [anon_sym_EXIT] = ACTIONS(3772),
    [anon_sym_Exit] = ACTIONS(3772),
    [anon_sym_continue] = ACTIONS(3772),
    [anon_sym_CONTINUE] = ACTIONS(3772),
    [anon_sym_Continue] = ACTIONS(3772),
    [anon_sym_break] = ACTIONS(3772),
    [anon_sym_BREAK] = ACTIONS(3772),
    [anon_sym_Break] = ACTIONS(3772),
    [anon_sym_with] = ACTIONS(3772),
    [anon_sym_WITH] = ACTIONS(3772),
    [anon_sym_With] = ACTIONS(3772),
    [sym_asserterror_keyword] = ACTIONS(3774),
    [anon_sym_in] = ACTIONS(3772),
    [anon_sym_IN] = ACTIONS(3772),
    [anon_sym_In] = ACTIONS(3772),
    [sym_page_keyword] = ACTIONS(3772),
    [anon_sym_codeunit] = ACTIONS(3772),
    [anon_sym_CODEUNIT] = ACTIONS(3772),
    [anon_sym_Codeunit] = ACTIONS(3772),
    [anon_sym_CodeUnit] = ACTIONS(3772),
    [anon_sym_COdeunit] = ACTIONS(3772),
    [anon_sym_codeUnit] = ACTIONS(3772),
    [sym_report_keyword] = ACTIONS(3772),
    [sym_query_keyword] = ACTIONS(3772),
    [anon_sym_xmlport] = ACTIONS(3772),
    [anon_sym_XMLPORT] = ACTIONS(3772),
    [anon_sym_Xmlport] = ACTIONS(3772),
    [anon_sym_XMLport] = ACTIONS(3772),
    [anon_sym_XMLPort] = ACTIONS(3772),
    [anon_sym_XmlPort] = ACTIONS(3772),
    [anon_sym_enum] = ACTIONS(3772),
    [anon_sym_ENUM] = ACTIONS(3772),
    [anon_sym_Enum] = ACTIONS(3772),
    [anon_sym_eNUM] = ACTIONS(3772),
    [anon_sym_eNum] = ACTIONS(3772),
    [anon_sym_ENum] = ACTIONS(3772),
    [sym_quoted_identifier] = ACTIONS(3774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3774),
    [sym_verbatim_string] = ACTIONS(3774),
    [sym_integer] = ACTIONS(3772),
    [sym_continue_as_identifier] = ACTIONS(3774),
    [sym_preproc_open] = ACTIONS(3774),
    [sym_preproc_close] = ACTIONS(3774),
  },
  [STATE(1823)] = {
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(3634),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelif] = ACTIONS(3634),
    [anon_sym_POUNDELIF] = ACTIONS(3634),
    [anon_sym_POUNDElif] = ACTIONS(3634),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [anon_sym_POUNDendif] = ACTIONS(3634),
    [anon_sym_POUNDENDIF] = ACTIONS(3634),
    [anon_sym_POUNDEndif] = ACTIONS(3634),
    [anon_sym_POUNDendif2] = ACTIONS(3634),
    [anon_sym_POUNDENDIF2] = ACTIONS(3634),
    [anon_sym_POUNDEndif2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_if] = ACTIONS(3632),
    [anon_sym_IF] = ACTIONS(3632),
    [anon_sym_If] = ACTIONS(3632),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_case] = ACTIONS(3632),
    [anon_sym_CASE] = ACTIONS(3632),
    [anon_sym_Case] = ACTIONS(3632),
    [anon_sym_for] = ACTIONS(3632),
    [anon_sym_FOR] = ACTIONS(3632),
    [anon_sym_For] = ACTIONS(3632),
    [anon_sym_foreach] = ACTIONS(3632),
    [anon_sym_FOREACH] = ACTIONS(3632),
    [anon_sym_Foreach] = ACTIONS(3632),
    [anon_sym_while] = ACTIONS(3632),
    [anon_sym_WHILE] = ACTIONS(3632),
    [anon_sym_While] = ACTIONS(3632),
    [anon_sym_repeat] = ACTIONS(3632),
    [anon_sym_REPEAT] = ACTIONS(3632),
    [anon_sym_Repeat] = ACTIONS(3632),
    [anon_sym_exit] = ACTIONS(3632),
    [anon_sym_EXIT] = ACTIONS(3632),
    [anon_sym_Exit] = ACTIONS(3632),
    [anon_sym_continue] = ACTIONS(3632),
    [anon_sym_CONTINUE] = ACTIONS(3632),
    [anon_sym_Continue] = ACTIONS(3632),
    [anon_sym_break] = ACTIONS(3632),
    [anon_sym_BREAK] = ACTIONS(3632),
    [anon_sym_Break] = ACTIONS(3632),
    [anon_sym_with] = ACTIONS(3632),
    [anon_sym_WITH] = ACTIONS(3632),
    [anon_sym_With] = ACTIONS(3632),
    [sym_asserterror_keyword] = ACTIONS(3634),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
    [sym_preproc_close] = ACTIONS(3634),
  },
  [STATE(1824)] = {
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(3703),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelif] = ACTIONS(3705),
    [anon_sym_POUNDELIF] = ACTIONS(3705),
    [anon_sym_POUNDElif] = ACTIONS(3705),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [anon_sym_POUNDendif] = ACTIONS(3705),
    [anon_sym_POUNDENDIF] = ACTIONS(3705),
    [anon_sym_POUNDEndif] = ACTIONS(3705),
    [anon_sym_POUNDendif2] = ACTIONS(3705),
    [anon_sym_POUNDENDIF2] = ACTIONS(3705),
    [anon_sym_POUNDEndif2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_if] = ACTIONS(3703),
    [anon_sym_IF] = ACTIONS(3703),
    [anon_sym_If] = ACTIONS(3703),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_case] = ACTIONS(3703),
    [anon_sym_CASE] = ACTIONS(3703),
    [anon_sym_Case] = ACTIONS(3703),
    [anon_sym_for] = ACTIONS(3703),
    [anon_sym_FOR] = ACTIONS(3703),
    [anon_sym_For] = ACTIONS(3703),
    [anon_sym_foreach] = ACTIONS(3703),
    [anon_sym_FOREACH] = ACTIONS(3703),
    [anon_sym_Foreach] = ACTIONS(3703),
    [anon_sym_while] = ACTIONS(3703),
    [anon_sym_WHILE] = ACTIONS(3703),
    [anon_sym_While] = ACTIONS(3703),
    [anon_sym_repeat] = ACTIONS(3703),
    [anon_sym_REPEAT] = ACTIONS(3703),
    [anon_sym_Repeat] = ACTIONS(3703),
    [anon_sym_exit] = ACTIONS(3703),
    [anon_sym_EXIT] = ACTIONS(3703),
    [anon_sym_Exit] = ACTIONS(3703),
    [anon_sym_continue] = ACTIONS(3703),
    [anon_sym_CONTINUE] = ACTIONS(3703),
    [anon_sym_Continue] = ACTIONS(3703),
    [anon_sym_break] = ACTIONS(3703),
    [anon_sym_BREAK] = ACTIONS(3703),
    [anon_sym_Break] = ACTIONS(3703),
    [anon_sym_with] = ACTIONS(3703),
    [anon_sym_WITH] = ACTIONS(3703),
    [anon_sym_With] = ACTIONS(3703),
    [sym_asserterror_keyword] = ACTIONS(3705),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
    [sym_preproc_close] = ACTIONS(3705),
  },
  [STATE(1825)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(1826)] = {
    [sym_identifier] = ACTIONS(3776),
    [anon_sym_SEMI] = ACTIONS(3778),
    [anon_sym_DOT] = ACTIONS(3776),
    [anon_sym_EQ] = ACTIONS(3778),
    [anon_sym_DASH] = ACTIONS(3776),
    [aux_sym_boolean_token1] = ACTIONS(3776),
    [aux_sym_boolean_token2] = ACTIONS(3776),
    [sym_decimal] = ACTIONS(3776),
    [anon_sym_LPAREN] = ACTIONS(3778),
    [anon_sym_DOT_DOT] = ACTIONS(3778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3776),
    [anon_sym_STAR] = ACTIONS(3776),
    [anon_sym_LBRACK] = ACTIONS(3778),
    [aux_sym_record_type_token1] = ACTIONS(3776),
    [aux_sym_basic_type_token21] = ACTIONS(3776),
    [aux_sym_basic_type_token22] = ACTIONS(3776),
    [aux_sym_basic_type_token48] = ACTIONS(3776),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_POUNDif] = ACTIONS(3778),
    [anon_sym_POUNDIF] = ACTIONS(3778),
    [anon_sym_POUNDIf] = ACTIONS(3778),
    [anon_sym_not] = ACTIONS(3776),
    [anon_sym_NOT] = ACTIONS(3776),
    [anon_sym_Not] = ACTIONS(3776),
    [anon_sym_POUNDelif] = ACTIONS(3778),
    [anon_sym_POUNDELIF] = ACTIONS(3778),
    [anon_sym_POUNDElif] = ACTIONS(3778),
    [anon_sym_POUNDelse] = ACTIONS(3778),
    [anon_sym_POUNDELSE] = ACTIONS(3778),
    [anon_sym_POUNDElse] = ACTIONS(3778),
    [anon_sym_POUNDelse2] = ACTIONS(3778),
    [anon_sym_POUNDELSE2] = ACTIONS(3778),
    [anon_sym_POUNDElse2] = ACTIONS(3778),
    [anon_sym_POUNDendif] = ACTIONS(3778),
    [anon_sym_POUNDENDIF] = ACTIONS(3778),
    [anon_sym_POUNDEndif] = ACTIONS(3778),
    [anon_sym_POUNDendif2] = ACTIONS(3778),
    [anon_sym_POUNDENDIF2] = ACTIONS(3778),
    [anon_sym_POUNDEndif2] = ACTIONS(3778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3778),
    [aux_sym__expression_token1] = ACTIONS(3778),
    [aux_sym__expression_token2] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3776),
    [anon_sym_SLASH] = ACTIONS(3776),
    [anon_sym_div] = ACTIONS(3776),
    [anon_sym_DIV] = ACTIONS(3776),
    [anon_sym_Div] = ACTIONS(3776),
    [anon_sym_mod] = ACTIONS(3776),
    [anon_sym_MOD] = ACTIONS(3776),
    [anon_sym_Mod] = ACTIONS(3776),
    [anon_sym_PLUS] = ACTIONS(3776),
    [anon_sym_GT_EQ] = ACTIONS(3778),
    [anon_sym_LT_EQ] = ACTIONS(3778),
    [anon_sym_GT] = ACTIONS(3776),
    [anon_sym_LT] = ACTIONS(3776),
    [anon_sym_LT_GT] = ACTIONS(3778),
    [anon_sym_and] = ACTIONS(3776),
    [anon_sym_AND] = ACTIONS(3776),
    [anon_sym_And] = ACTIONS(3776),
    [anon_sym_or] = ACTIONS(3776),
    [anon_sym_OR] = ACTIONS(3776),
    [anon_sym_Or] = ACTIONS(3776),
    [anon_sym_xor] = ACTIONS(3776),
    [anon_sym_XOR] = ACTIONS(3776),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(3778),
    [sym_date_literal] = ACTIONS(3776),
    [sym_time_literal] = ACTIONS(3776),
    [sym_biginteger_literal] = ACTIONS(3778),
    [anon_sym_if] = ACTIONS(3776),
    [anon_sym_IF] = ACTIONS(3776),
    [anon_sym_If] = ACTIONS(3776),
    [anon_sym_else] = ACTIONS(3776),
    [anon_sym_ELSE] = ACTIONS(3776),
    [anon_sym_Else] = ACTIONS(3776),
    [anon_sym_case] = ACTIONS(3776),
    [anon_sym_CASE] = ACTIONS(3776),
    [anon_sym_Case] = ACTIONS(3776),
    [anon_sym_for] = ACTIONS(3776),
    [anon_sym_FOR] = ACTIONS(3776),
    [anon_sym_For] = ACTIONS(3776),
    [anon_sym_foreach] = ACTIONS(3776),
    [anon_sym_FOREACH] = ACTIONS(3776),
    [anon_sym_Foreach] = ACTIONS(3776),
    [anon_sym_while] = ACTIONS(3776),
    [anon_sym_WHILE] = ACTIONS(3776),
    [anon_sym_While] = ACTIONS(3776),
    [anon_sym_repeat] = ACTIONS(3776),
    [anon_sym_REPEAT] = ACTIONS(3776),
    [anon_sym_Repeat] = ACTIONS(3776),
    [anon_sym_exit] = ACTIONS(3776),
    [anon_sym_EXIT] = ACTIONS(3776),
    [anon_sym_Exit] = ACTIONS(3776),
    [anon_sym_continue] = ACTIONS(3776),
    [anon_sym_CONTINUE] = ACTIONS(3776),
    [anon_sym_Continue] = ACTIONS(3776),
    [anon_sym_break] = ACTIONS(3776),
    [anon_sym_BREAK] = ACTIONS(3776),
    [anon_sym_Break] = ACTIONS(3776),
    [anon_sym_with] = ACTIONS(3776),
    [anon_sym_WITH] = ACTIONS(3776),
    [anon_sym_With] = ACTIONS(3776),
    [sym_asserterror_keyword] = ACTIONS(3778),
    [anon_sym_in] = ACTIONS(3776),
    [anon_sym_IN] = ACTIONS(3776),
    [anon_sym_In] = ACTIONS(3776),
    [sym_page_keyword] = ACTIONS(3776),
    [anon_sym_codeunit] = ACTIONS(3776),
    [anon_sym_CODEUNIT] = ACTIONS(3776),
    [anon_sym_Codeunit] = ACTIONS(3776),
    [anon_sym_CodeUnit] = ACTIONS(3776),
    [anon_sym_COdeunit] = ACTIONS(3776),
    [anon_sym_codeUnit] = ACTIONS(3776),
    [sym_report_keyword] = ACTIONS(3776),
    [sym_query_keyword] = ACTIONS(3776),
    [anon_sym_xmlport] = ACTIONS(3776),
    [anon_sym_XMLPORT] = ACTIONS(3776),
    [anon_sym_Xmlport] = ACTIONS(3776),
    [anon_sym_XMLport] = ACTIONS(3776),
    [anon_sym_XMLPort] = ACTIONS(3776),
    [anon_sym_XmlPort] = ACTIONS(3776),
    [anon_sym_enum] = ACTIONS(3776),
    [anon_sym_ENUM] = ACTIONS(3776),
    [anon_sym_Enum] = ACTIONS(3776),
    [anon_sym_eNUM] = ACTIONS(3776),
    [anon_sym_eNum] = ACTIONS(3776),
    [anon_sym_ENum] = ACTIONS(3776),
    [sym_quoted_identifier] = ACTIONS(3778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3778),
    [sym_verbatim_string] = ACTIONS(3778),
    [sym_integer] = ACTIONS(3776),
    [sym_continue_as_identifier] = ACTIONS(3778),
    [sym_preproc_open] = ACTIONS(3778),
    [sym_preproc_close] = ACTIONS(3778),
  },
  [STATE(1827)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(3780),
    [anon_sym_POUNDELIF] = ACTIONS(3780),
    [anon_sym_POUNDElif] = ACTIONS(3780),
    [anon_sym_POUNDelse] = ACTIONS(3780),
    [anon_sym_POUNDELSE] = ACTIONS(3780),
    [anon_sym_POUNDElse] = ACTIONS(3780),
    [anon_sym_POUNDelse2] = ACTIONS(3780),
    [anon_sym_POUNDELSE2] = ACTIONS(3780),
    [anon_sym_POUNDElse2] = ACTIONS(3780),
    [anon_sym_POUNDendif] = ACTIONS(3780),
    [anon_sym_POUNDENDIF] = ACTIONS(3780),
    [anon_sym_POUNDEndif] = ACTIONS(3780),
    [anon_sym_POUNDendif2] = ACTIONS(3780),
    [anon_sym_POUNDENDIF2] = ACTIONS(3780),
    [anon_sym_POUNDEndif2] = ACTIONS(3780),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(3780),
  },
  [STATE(1828)] = {
    [sym_preproc_conditional_object] = STATE(1827),
    [sym_using_statement] = STATE(1827),
    [sym__object] = STATE(1827),
    [sym_preproc_split_declaration] = STATE(1827),
    [sym_table_declaration] = STATE(1827),
    [sym_page_declaration] = STATE(1827),
    [sym_report_declaration] = STATE(1827),
    [sym_query_declaration] = STATE(1827),
    [sym_xmlport_declaration] = STATE(1827),
    [sym_permissionset_declaration] = STATE(1827),
    [sym_codeunit_declaration] = STATE(1827),
    [sym_enum_declaration] = STATE(1827),
    [sym_tableextension_declaration] = STATE(1827),
    [sym_pageextension_declaration] = STATE(1827),
    [sym_reportextension_declaration] = STATE(1827),
    [sym_enumextension_declaration] = STATE(1827),
    [sym_permissionsetextension_declaration] = STATE(1827),
    [sym_controladdin_declaration] = STATE(1827),
    [sym_profile_declaration] = STATE(1827),
    [sym_entitlement_declaration] = STATE(1827),
    [sym_profileextension_declaration] = STATE(1827),
    [sym_interface_declaration] = STATE(1827),
    [sym_pagecustomization_declaration] = STATE(1827),
    [sym_dotnet_declaration] = STATE(1827),
    [sym_preproc_if] = STATE(308),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1827),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(3782),
    [anon_sym_POUNDELIF] = ACTIONS(3782),
    [anon_sym_POUNDElif] = ACTIONS(3782),
    [anon_sym_POUNDelse] = ACTIONS(3782),
    [anon_sym_POUNDELSE] = ACTIONS(3782),
    [anon_sym_POUNDElse] = ACTIONS(3782),
    [anon_sym_POUNDelse2] = ACTIONS(3782),
    [anon_sym_POUNDELSE2] = ACTIONS(3782),
    [anon_sym_POUNDElse2] = ACTIONS(3782),
    [anon_sym_POUNDendif] = ACTIONS(3782),
    [anon_sym_POUNDENDIF] = ACTIONS(3782),
    [anon_sym_POUNDEndif] = ACTIONS(3782),
    [anon_sym_POUNDendif2] = ACTIONS(3782),
    [anon_sym_POUNDENDIF2] = ACTIONS(3782),
    [anon_sym_POUNDEndif2] = ACTIONS(3782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(3782),
  },
  [STATE(1829)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDelif] = ACTIONS(3782),
    [anon_sym_POUNDELIF] = ACTIONS(3782),
    [anon_sym_POUNDElif] = ACTIONS(3782),
    [anon_sym_POUNDelse] = ACTIONS(3782),
    [anon_sym_POUNDELSE] = ACTIONS(3782),
    [anon_sym_POUNDElse] = ACTIONS(3782),
    [anon_sym_POUNDelse2] = ACTIONS(3782),
    [anon_sym_POUNDELSE2] = ACTIONS(3782),
    [anon_sym_POUNDElse2] = ACTIONS(3782),
    [anon_sym_POUNDendif] = ACTIONS(3782),
    [anon_sym_POUNDENDIF] = ACTIONS(3782),
    [anon_sym_POUNDEndif] = ACTIONS(3782),
    [anon_sym_POUNDendif2] = ACTIONS(3782),
    [anon_sym_POUNDENDIF2] = ACTIONS(3782),
    [anon_sym_POUNDEndif2] = ACTIONS(3782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(3782),
  },
  [STATE(1830)] = {
    [sym_identifier] = ACTIONS(3784),
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [aux_sym_boolean_token1] = ACTIONS(3784),
    [aux_sym_boolean_token2] = ACTIONS(3784),
    [sym_decimal] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3784),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_record_type_token1] = ACTIONS(3784),
    [aux_sym_basic_type_token21] = ACTIONS(3784),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_basic_type_token48] = ACTIONS(3784),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_not] = ACTIONS(3784),
    [anon_sym_NOT] = ACTIONS(3784),
    [anon_sym_Not] = ACTIONS(3784),
    [anon_sym_POUNDelif] = ACTIONS(3786),
    [anon_sym_POUNDELIF] = ACTIONS(3786),
    [anon_sym_POUNDElif] = ACTIONS(3786),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [anon_sym_POUNDendif] = ACTIONS(3786),
    [anon_sym_POUNDENDIF] = ACTIONS(3786),
    [anon_sym_POUNDEndif] = ACTIONS(3786),
    [anon_sym_POUNDendif2] = ACTIONS(3786),
    [anon_sym_POUNDENDIF2] = ACTIONS(3786),
    [anon_sym_POUNDEndif2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3784),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3784),
    [anon_sym_DIV] = ACTIONS(3784),
    [anon_sym_Div] = ACTIONS(3784),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3784),
    [anon_sym_AND] = ACTIONS(3784),
    [anon_sym_And] = ACTIONS(3784),
    [anon_sym_or] = ACTIONS(3784),
    [anon_sym_OR] = ACTIONS(3784),
    [anon_sym_Or] = ACTIONS(3784),
    [anon_sym_xor] = ACTIONS(3784),
    [anon_sym_XOR] = ACTIONS(3784),
    [anon_sym_Xor] = ACTIONS(3784),
    [anon_sym_QMARK] = ACTIONS(3786),
    [sym_datetime_literal] = ACTIONS(3786),
    [sym_date_literal] = ACTIONS(3784),
    [sym_time_literal] = ACTIONS(3784),
    [sym_biginteger_literal] = ACTIONS(3786),
    [anon_sym_if] = ACTIONS(3784),
    [anon_sym_IF] = ACTIONS(3784),
    [anon_sym_If] = ACTIONS(3784),
    [anon_sym_else] = ACTIONS(3784),
    [anon_sym_ELSE] = ACTIONS(3784),
    [anon_sym_Else] = ACTIONS(3784),
    [anon_sym_case] = ACTIONS(3784),
    [anon_sym_CASE] = ACTIONS(3784),
    [anon_sym_Case] = ACTIONS(3784),
    [anon_sym_for] = ACTIONS(3784),
    [anon_sym_FOR] = ACTIONS(3784),
    [anon_sym_For] = ACTIONS(3784),
    [anon_sym_foreach] = ACTIONS(3784),
    [anon_sym_FOREACH] = ACTIONS(3784),
    [anon_sym_Foreach] = ACTIONS(3784),
    [anon_sym_while] = ACTIONS(3784),
    [anon_sym_WHILE] = ACTIONS(3784),
    [anon_sym_While] = ACTIONS(3784),
    [anon_sym_repeat] = ACTIONS(3784),
    [anon_sym_REPEAT] = ACTIONS(3784),
    [anon_sym_Repeat] = ACTIONS(3784),
    [anon_sym_exit] = ACTIONS(3784),
    [anon_sym_EXIT] = ACTIONS(3784),
    [anon_sym_Exit] = ACTIONS(3784),
    [anon_sym_continue] = ACTIONS(3784),
    [anon_sym_CONTINUE] = ACTIONS(3784),
    [anon_sym_Continue] = ACTIONS(3784),
    [anon_sym_break] = ACTIONS(3784),
    [anon_sym_BREAK] = ACTIONS(3784),
    [anon_sym_Break] = ACTIONS(3784),
    [anon_sym_with] = ACTIONS(3784),
    [anon_sym_WITH] = ACTIONS(3784),
    [anon_sym_With] = ACTIONS(3784),
    [sym_asserterror_keyword] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_page_keyword] = ACTIONS(3784),
    [anon_sym_codeunit] = ACTIONS(3784),
    [anon_sym_CODEUNIT] = ACTIONS(3784),
    [anon_sym_Codeunit] = ACTIONS(3784),
    [anon_sym_CodeUnit] = ACTIONS(3784),
    [anon_sym_COdeunit] = ACTIONS(3784),
    [anon_sym_codeUnit] = ACTIONS(3784),
    [sym_report_keyword] = ACTIONS(3784),
    [sym_query_keyword] = ACTIONS(3784),
    [anon_sym_xmlport] = ACTIONS(3784),
    [anon_sym_XMLPORT] = ACTIONS(3784),
    [anon_sym_Xmlport] = ACTIONS(3784),
    [anon_sym_XMLport] = ACTIONS(3784),
    [anon_sym_XMLPort] = ACTIONS(3784),
    [anon_sym_XmlPort] = ACTIONS(3784),
    [anon_sym_enum] = ACTIONS(3784),
    [anon_sym_ENUM] = ACTIONS(3784),
    [anon_sym_Enum] = ACTIONS(3784),
    [anon_sym_eNUM] = ACTIONS(3784),
    [anon_sym_eNum] = ACTIONS(3784),
    [anon_sym_ENum] = ACTIONS(3784),
    [sym_quoted_identifier] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3786),
    [sym_verbatim_string] = ACTIONS(3786),
    [sym_integer] = ACTIONS(3784),
    [sym_continue_as_identifier] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
    [sym_preproc_close] = ACTIONS(3786),
  },
  [STATE(1831)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(3788),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(1832)] = {
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(3687),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelif] = ACTIONS(3683),
    [anon_sym_POUNDELIF] = ACTIONS(3683),
    [anon_sym_POUNDElif] = ACTIONS(3683),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [anon_sym_POUNDendif] = ACTIONS(3683),
    [anon_sym_POUNDENDIF] = ACTIONS(3683),
    [anon_sym_POUNDEndif] = ACTIONS(3683),
    [anon_sym_POUNDendif2] = ACTIONS(3683),
    [anon_sym_POUNDENDIF2] = ACTIONS(3683),
    [anon_sym_POUNDEndif2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_IF] = ACTIONS(3681),
    [anon_sym_If] = ACTIONS(3681),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_case] = ACTIONS(3681),
    [anon_sym_CASE] = ACTIONS(3681),
    [anon_sym_Case] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_FOR] = ACTIONS(3681),
    [anon_sym_For] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_FOREACH] = ACTIONS(3681),
    [anon_sym_Foreach] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_WHILE] = ACTIONS(3681),
    [anon_sym_While] = ACTIONS(3681),
    [anon_sym_repeat] = ACTIONS(3681),
    [anon_sym_REPEAT] = ACTIONS(3681),
    [anon_sym_Repeat] = ACTIONS(3681),
    [anon_sym_exit] = ACTIONS(3681),
    [anon_sym_EXIT] = ACTIONS(3681),
    [anon_sym_Exit] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_CONTINUE] = ACTIONS(3681),
    [anon_sym_Continue] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_BREAK] = ACTIONS(3681),
    [anon_sym_Break] = ACTIONS(3681),
    [anon_sym_with] = ACTIONS(3681),
    [anon_sym_WITH] = ACTIONS(3681),
    [anon_sym_With] = ACTIONS(3681),
    [sym_asserterror_keyword] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
    [sym_preproc_close] = ACTIONS(3683),
  },
  [STATE(1833)] = {
    [sym_identifier] = ACTIONS(3790),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_DOT] = ACTIONS(3790),
    [anon_sym_EQ] = ACTIONS(3792),
    [anon_sym_DASH] = ACTIONS(3790),
    [aux_sym_boolean_token1] = ACTIONS(3790),
    [aux_sym_boolean_token2] = ACTIONS(3790),
    [sym_decimal] = ACTIONS(3790),
    [anon_sym_LPAREN] = ACTIONS(3792),
    [anon_sym_DOT_DOT] = ACTIONS(3792),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3790),
    [anon_sym_STAR] = ACTIONS(3790),
    [anon_sym_LBRACK] = ACTIONS(3792),
    [aux_sym_record_type_token1] = ACTIONS(3790),
    [aux_sym_basic_type_token21] = ACTIONS(3790),
    [aux_sym_basic_type_token22] = ACTIONS(3790),
    [aux_sym_basic_type_token48] = ACTIONS(3790),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3790),
    [anon_sym_COLON_COLON] = ACTIONS(3792),
    [anon_sym_POUNDif] = ACTIONS(3792),
    [anon_sym_POUNDIF] = ACTIONS(3792),
    [anon_sym_POUNDIf] = ACTIONS(3792),
    [anon_sym_not] = ACTIONS(3790),
    [anon_sym_NOT] = ACTIONS(3790),
    [anon_sym_Not] = ACTIONS(3790),
    [anon_sym_POUNDelif] = ACTIONS(3792),
    [anon_sym_POUNDELIF] = ACTIONS(3792),
    [anon_sym_POUNDElif] = ACTIONS(3792),
    [anon_sym_POUNDelse] = ACTIONS(3792),
    [anon_sym_POUNDELSE] = ACTIONS(3792),
    [anon_sym_POUNDElse] = ACTIONS(3792),
    [anon_sym_POUNDelse2] = ACTIONS(3792),
    [anon_sym_POUNDELSE2] = ACTIONS(3792),
    [anon_sym_POUNDElse2] = ACTIONS(3792),
    [anon_sym_POUNDendif] = ACTIONS(3792),
    [anon_sym_POUNDENDIF] = ACTIONS(3792),
    [anon_sym_POUNDEndif] = ACTIONS(3792),
    [anon_sym_POUNDendif2] = ACTIONS(3792),
    [anon_sym_POUNDENDIF2] = ACTIONS(3792),
    [anon_sym_POUNDEndif2] = ACTIONS(3792),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3792),
    [aux_sym__expression_token1] = ACTIONS(3792),
    [aux_sym__expression_token2] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3790),
    [anon_sym_SLASH] = ACTIONS(3790),
    [anon_sym_div] = ACTIONS(3790),
    [anon_sym_DIV] = ACTIONS(3790),
    [anon_sym_Div] = ACTIONS(3790),
    [anon_sym_mod] = ACTIONS(3790),
    [anon_sym_MOD] = ACTIONS(3790),
    [anon_sym_Mod] = ACTIONS(3790),
    [anon_sym_PLUS] = ACTIONS(3790),
    [anon_sym_GT_EQ] = ACTIONS(3792),
    [anon_sym_LT_EQ] = ACTIONS(3792),
    [anon_sym_GT] = ACTIONS(3790),
    [anon_sym_LT] = ACTIONS(3790),
    [anon_sym_LT_GT] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3790),
    [anon_sym_AND] = ACTIONS(3790),
    [anon_sym_And] = ACTIONS(3790),
    [anon_sym_or] = ACTIONS(3790),
    [anon_sym_OR] = ACTIONS(3790),
    [anon_sym_Or] = ACTIONS(3790),
    [anon_sym_xor] = ACTIONS(3790),
    [anon_sym_XOR] = ACTIONS(3790),
    [anon_sym_Xor] = ACTIONS(3790),
    [anon_sym_QMARK] = ACTIONS(3792),
    [sym_datetime_literal] = ACTIONS(3792),
    [sym_date_literal] = ACTIONS(3790),
    [sym_time_literal] = ACTIONS(3790),
    [sym_biginteger_literal] = ACTIONS(3792),
    [anon_sym_if] = ACTIONS(3790),
    [anon_sym_IF] = ACTIONS(3790),
    [anon_sym_If] = ACTIONS(3790),
    [anon_sym_else] = ACTIONS(3790),
    [anon_sym_ELSE] = ACTIONS(3790),
    [anon_sym_Else] = ACTIONS(3790),
    [anon_sym_case] = ACTIONS(3790),
    [anon_sym_CASE] = ACTIONS(3790),
    [anon_sym_Case] = ACTIONS(3790),
    [anon_sym_for] = ACTIONS(3790),
    [anon_sym_FOR] = ACTIONS(3790),
    [anon_sym_For] = ACTIONS(3790),
    [anon_sym_foreach] = ACTIONS(3790),
    [anon_sym_FOREACH] = ACTIONS(3790),
    [anon_sym_Foreach] = ACTIONS(3790),
    [anon_sym_while] = ACTIONS(3790),
    [anon_sym_WHILE] = ACTIONS(3790),
    [anon_sym_While] = ACTIONS(3790),
    [anon_sym_repeat] = ACTIONS(3790),
    [anon_sym_REPEAT] = ACTIONS(3790),
    [anon_sym_Repeat] = ACTIONS(3790),
    [anon_sym_exit] = ACTIONS(3790),
    [anon_sym_EXIT] = ACTIONS(3790),
    [anon_sym_Exit] = ACTIONS(3790),
    [anon_sym_continue] = ACTIONS(3790),
    [anon_sym_CONTINUE] = ACTIONS(3790),
    [anon_sym_Continue] = ACTIONS(3790),
    [anon_sym_break] = ACTIONS(3790),
    [anon_sym_BREAK] = ACTIONS(3790),
    [anon_sym_Break] = ACTIONS(3790),
    [anon_sym_with] = ACTIONS(3790),
    [anon_sym_WITH] = ACTIONS(3790),
    [anon_sym_With] = ACTIONS(3790),
    [sym_asserterror_keyword] = ACTIONS(3792),
    [anon_sym_in] = ACTIONS(3790),
    [anon_sym_IN] = ACTIONS(3790),
    [anon_sym_In] = ACTIONS(3790),
    [sym_page_keyword] = ACTIONS(3790),
    [anon_sym_codeunit] = ACTIONS(3790),
    [anon_sym_CODEUNIT] = ACTIONS(3790),
    [anon_sym_Codeunit] = ACTIONS(3790),
    [anon_sym_CodeUnit] = ACTIONS(3790),
    [anon_sym_COdeunit] = ACTIONS(3790),
    [anon_sym_codeUnit] = ACTIONS(3790),
    [sym_report_keyword] = ACTIONS(3790),
    [sym_query_keyword] = ACTIONS(3790),
    [anon_sym_xmlport] = ACTIONS(3790),
    [anon_sym_XMLPORT] = ACTIONS(3790),
    [anon_sym_Xmlport] = ACTIONS(3790),
    [anon_sym_XMLport] = ACTIONS(3790),
    [anon_sym_XMLPort] = ACTIONS(3790),
    [anon_sym_XmlPort] = ACTIONS(3790),
    [anon_sym_enum] = ACTIONS(3790),
    [anon_sym_ENUM] = ACTIONS(3790),
    [anon_sym_Enum] = ACTIONS(3790),
    [anon_sym_eNUM] = ACTIONS(3790),
    [anon_sym_eNum] = ACTIONS(3790),
    [anon_sym_ENum] = ACTIONS(3790),
    [sym_quoted_identifier] = ACTIONS(3792),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3792),
    [sym_verbatim_string] = ACTIONS(3792),
    [sym_integer] = ACTIONS(3790),
    [sym_continue_as_identifier] = ACTIONS(3792),
    [sym_preproc_open] = ACTIONS(3792),
    [sym_preproc_close] = ACTIONS(3792),
  },
  [STATE(1834)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(3794),
    [anon_sym_POUNDIF] = ACTIONS(3794),
    [anon_sym_POUNDIf] = ACTIONS(3794),
    [anon_sym_POUNDelif] = ACTIONS(3797),
    [anon_sym_POUNDELIF] = ACTIONS(3797),
    [anon_sym_POUNDElif] = ACTIONS(3797),
    [anon_sym_POUNDelse] = ACTIONS(3797),
    [anon_sym_POUNDELSE] = ACTIONS(3797),
    [anon_sym_POUNDElse] = ACTIONS(3797),
    [anon_sym_POUNDelse2] = ACTIONS(3797),
    [anon_sym_POUNDELSE2] = ACTIONS(3797),
    [anon_sym_POUNDElse2] = ACTIONS(3797),
    [anon_sym_POUNDendif] = ACTIONS(3797),
    [anon_sym_POUNDENDIF] = ACTIONS(3797),
    [anon_sym_POUNDEndif] = ACTIONS(3797),
    [anon_sym_POUNDendif2] = ACTIONS(3797),
    [anon_sym_POUNDENDIF2] = ACTIONS(3797),
    [anon_sym_POUNDEndif2] = ACTIONS(3797),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3799),
    [anon_sym_tableextension] = ACTIONS(3802),
    [anon_sym_TABLEEXTENSION] = ACTIONS(3802),
    [anon_sym_Tableextension] = ACTIONS(3802),
    [anon_sym_TableExtension] = ACTIONS(3802),
    [anon_sym_tableExtension] = ACTIONS(3802),
    [sym_page_keyword] = ACTIONS(3805),
    [anon_sym_pageextension] = ACTIONS(3808),
    [anon_sym_PAGEEXTENSION] = ACTIONS(3808),
    [anon_sym_Pageextension] = ACTIONS(3808),
    [anon_sym_PageExtension] = ACTIONS(3808),
    [anon_sym_pageExtension] = ACTIONS(3808),
    [anon_sym_codeunit] = ACTIONS(3811),
    [anon_sym_CODEUNIT] = ACTIONS(3811),
    [anon_sym_Codeunit] = ACTIONS(3811),
    [anon_sym_CodeUnit] = ACTIONS(3811),
    [anon_sym_COdeunit] = ACTIONS(3811),
    [anon_sym_codeUnit] = ACTIONS(3811),
    [sym_report_keyword] = ACTIONS(3814),
    [anon_sym_reportextension] = ACTIONS(3817),
    [anon_sym_REPORTEXTENSION] = ACTIONS(3817),
    [anon_sym_Reportextension] = ACTIONS(3817),
    [anon_sym_ReportExtension] = ACTIONS(3817),
    [anon_sym_reportExtension] = ACTIONS(3817),
    [sym_query_keyword] = ACTIONS(3820),
    [anon_sym_xmlport] = ACTIONS(3823),
    [anon_sym_XMLPORT] = ACTIONS(3823),
    [anon_sym_Xmlport] = ACTIONS(3823),
    [anon_sym_XMLport] = ACTIONS(3823),
    [anon_sym_XMLPort] = ACTIONS(3823),
    [anon_sym_XmlPort] = ACTIONS(3823),
    [anon_sym_enum] = ACTIONS(3826),
    [anon_sym_ENUM] = ACTIONS(3826),
    [anon_sym_Enum] = ACTIONS(3826),
    [anon_sym_eNUM] = ACTIONS(3829),
    [anon_sym_eNum] = ACTIONS(3829),
    [anon_sym_ENum] = ACTIONS(3829),
    [anon_sym_enumextension] = ACTIONS(3832),
    [anon_sym_ENUMEXTENSION] = ACTIONS(3832),
    [anon_sym_Enumextension] = ACTIONS(3832),
    [anon_sym_EnumExtension] = ACTIONS(3832),
    [anon_sym_enumExtension] = ACTIONS(3832),
    [sym_interface_keyword] = ACTIONS(3835),
    [anon_sym_controladdin] = ACTIONS(3838),
    [anon_sym_CONTROLADDIN] = ACTIONS(3838),
    [anon_sym_Controladdin] = ACTIONS(3838),
    [anon_sym_ControlAddIn] = ACTIONS(3838),
    [anon_sym_ControlAddin] = ACTIONS(3838),
    [anon_sym_controlAddIn] = ACTIONS(3838),
    [anon_sym_controlAddin] = ACTIONS(3838),
    [anon_sym_dotnet] = ACTIONS(3841),
    [anon_sym_DOTNET] = ACTIONS(3841),
    [anon_sym_Dotnet] = ACTIONS(3841),
    [anon_sym_DotNet] = ACTIONS(3841),
    [anon_sym_dotNet] = ACTIONS(3841),
    [sym_profile_keyword] = ACTIONS(3844),
    [anon_sym_profileextension] = ACTIONS(3847),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(3847),
    [anon_sym_Profileextension] = ACTIONS(3847),
    [anon_sym_ProfileExtension] = ACTIONS(3847),
    [anon_sym_profileExtension] = ACTIONS(3847),
    [anon_sym_permissionset] = ACTIONS(3850),
    [anon_sym_PERMISSIONSET] = ACTIONS(3850),
    [anon_sym_Permissionset] = ACTIONS(3850),
    [anon_sym_PermissionSet] = ACTIONS(3850),
    [anon_sym_permissionSet] = ACTIONS(3850),
    [anon_sym_permissionsetextension] = ACTIONS(3853),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(3853),
    [anon_sym_Permissionsetextension] = ACTIONS(3853),
    [anon_sym_PermissionSetExtension] = ACTIONS(3853),
    [anon_sym_permissionSetExtension] = ACTIONS(3853),
    [sym_entitlement_keyword] = ACTIONS(3856),
    [anon_sym_pagecustomization] = ACTIONS(3859),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(3859),
    [anon_sym_Pagecustomization] = ACTIONS(3859),
    [anon_sym_PageCustomization] = ACTIONS(3859),
    [anon_sym_pageCustomization] = ACTIONS(3859),
    [sym_using_keyword] = ACTIONS(3862),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(3794),
    [sym_preproc_close] = ACTIONS(3797),
  },
  [STATE(1835)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(1836)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(1837)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(1838)] = {
    [sym_identifier] = ACTIONS(3877),
    [anon_sym_SEMI] = ACTIONS(3879),
    [anon_sym_DOT] = ACTIONS(3877),
    [anon_sym_EQ] = ACTIONS(3879),
    [anon_sym_DASH] = ACTIONS(3877),
    [aux_sym_boolean_token1] = ACTIONS(3877),
    [aux_sym_boolean_token2] = ACTIONS(3877),
    [sym_decimal] = ACTIONS(3877),
    [anon_sym_LPAREN] = ACTIONS(3879),
    [anon_sym_DOT_DOT] = ACTIONS(3879),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3877),
    [anon_sym_STAR] = ACTIONS(3877),
    [anon_sym_LBRACK] = ACTIONS(3879),
    [aux_sym_record_type_token1] = ACTIONS(3877),
    [aux_sym_basic_type_token21] = ACTIONS(3877),
    [aux_sym_basic_type_token22] = ACTIONS(3877),
    [aux_sym_basic_type_token48] = ACTIONS(3877),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3877),
    [anon_sym_POUNDif] = ACTIONS(3879),
    [anon_sym_POUNDIF] = ACTIONS(3879),
    [anon_sym_POUNDIf] = ACTIONS(3879),
    [anon_sym_not] = ACTIONS(3877),
    [anon_sym_NOT] = ACTIONS(3877),
    [anon_sym_Not] = ACTIONS(3877),
    [anon_sym_POUNDelif] = ACTIONS(3879),
    [anon_sym_POUNDELIF] = ACTIONS(3879),
    [anon_sym_POUNDElif] = ACTIONS(3879),
    [anon_sym_POUNDelse] = ACTIONS(3879),
    [anon_sym_POUNDELSE] = ACTIONS(3879),
    [anon_sym_POUNDElse] = ACTIONS(3879),
    [anon_sym_POUNDelse2] = ACTIONS(3879),
    [anon_sym_POUNDELSE2] = ACTIONS(3879),
    [anon_sym_POUNDElse2] = ACTIONS(3879),
    [anon_sym_POUNDendif] = ACTIONS(3879),
    [anon_sym_POUNDENDIF] = ACTIONS(3879),
    [anon_sym_POUNDEndif] = ACTIONS(3879),
    [anon_sym_POUNDendif2] = ACTIONS(3879),
    [anon_sym_POUNDENDIF2] = ACTIONS(3879),
    [anon_sym_POUNDEndif2] = ACTIONS(3879),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3879),
    [aux_sym__expression_token1] = ACTIONS(3879),
    [aux_sym__expression_token2] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3877),
    [anon_sym_SLASH] = ACTIONS(3877),
    [anon_sym_div] = ACTIONS(3877),
    [anon_sym_DIV] = ACTIONS(3877),
    [anon_sym_Div] = ACTIONS(3877),
    [anon_sym_mod] = ACTIONS(3877),
    [anon_sym_MOD] = ACTIONS(3877),
    [anon_sym_Mod] = ACTIONS(3877),
    [anon_sym_PLUS] = ACTIONS(3877),
    [anon_sym_GT_EQ] = ACTIONS(3879),
    [anon_sym_LT_EQ] = ACTIONS(3879),
    [anon_sym_GT] = ACTIONS(3877),
    [anon_sym_LT] = ACTIONS(3877),
    [anon_sym_LT_GT] = ACTIONS(3879),
    [anon_sym_and] = ACTIONS(3877),
    [anon_sym_AND] = ACTIONS(3877),
    [anon_sym_And] = ACTIONS(3877),
    [anon_sym_or] = ACTIONS(3877),
    [anon_sym_OR] = ACTIONS(3877),
    [anon_sym_Or] = ACTIONS(3877),
    [anon_sym_xor] = ACTIONS(3877),
    [anon_sym_XOR] = ACTIONS(3877),
    [anon_sym_Xor] = ACTIONS(3877),
    [anon_sym_QMARK] = ACTIONS(3879),
    [sym_datetime_literal] = ACTIONS(3879),
    [sym_date_literal] = ACTIONS(3877),
    [sym_time_literal] = ACTIONS(3877),
    [sym_biginteger_literal] = ACTIONS(3879),
    [anon_sym_if] = ACTIONS(3877),
    [anon_sym_IF] = ACTIONS(3877),
    [anon_sym_If] = ACTIONS(3877),
    [anon_sym_else] = ACTIONS(3877),
    [anon_sym_ELSE] = ACTIONS(3877),
    [anon_sym_Else] = ACTIONS(3877),
    [anon_sym_case] = ACTIONS(3877),
    [anon_sym_CASE] = ACTIONS(3877),
    [anon_sym_Case] = ACTIONS(3877),
    [anon_sym_for] = ACTIONS(3877),
    [anon_sym_FOR] = ACTIONS(3877),
    [anon_sym_For] = ACTIONS(3877),
    [anon_sym_foreach] = ACTIONS(3877),
    [anon_sym_FOREACH] = ACTIONS(3877),
    [anon_sym_Foreach] = ACTIONS(3877),
    [anon_sym_while] = ACTIONS(3877),
    [anon_sym_WHILE] = ACTIONS(3877),
    [anon_sym_While] = ACTIONS(3877),
    [anon_sym_repeat] = ACTIONS(3877),
    [anon_sym_REPEAT] = ACTIONS(3877),
    [anon_sym_Repeat] = ACTIONS(3877),
    [anon_sym_exit] = ACTIONS(3877),
    [anon_sym_EXIT] = ACTIONS(3877),
    [anon_sym_Exit] = ACTIONS(3877),
    [anon_sym_continue] = ACTIONS(3877),
    [anon_sym_CONTINUE] = ACTIONS(3877),
    [anon_sym_Continue] = ACTIONS(3877),
    [anon_sym_break] = ACTIONS(3877),
    [anon_sym_BREAK] = ACTIONS(3877),
    [anon_sym_Break] = ACTIONS(3877),
    [anon_sym_with] = ACTIONS(3877),
    [anon_sym_WITH] = ACTIONS(3877),
    [anon_sym_With] = ACTIONS(3877),
    [sym_asserterror_keyword] = ACTIONS(3879),
    [anon_sym_in] = ACTIONS(3877),
    [anon_sym_IN] = ACTIONS(3877),
    [anon_sym_In] = ACTIONS(3877),
    [sym_page_keyword] = ACTIONS(3877),
    [anon_sym_codeunit] = ACTIONS(3877),
    [anon_sym_CODEUNIT] = ACTIONS(3877),
    [anon_sym_Codeunit] = ACTIONS(3877),
    [anon_sym_CodeUnit] = ACTIONS(3877),
    [anon_sym_COdeunit] = ACTIONS(3877),
    [anon_sym_codeUnit] = ACTIONS(3877),
    [sym_report_keyword] = ACTIONS(3877),
    [sym_query_keyword] = ACTIONS(3877),
    [anon_sym_xmlport] = ACTIONS(3877),
    [anon_sym_XMLPORT] = ACTIONS(3877),
    [anon_sym_Xmlport] = ACTIONS(3877),
    [anon_sym_XMLport] = ACTIONS(3877),
    [anon_sym_XMLPort] = ACTIONS(3877),
    [anon_sym_XmlPort] = ACTIONS(3877),
    [anon_sym_enum] = ACTIONS(3877),
    [anon_sym_ENUM] = ACTIONS(3877),
    [anon_sym_Enum] = ACTIONS(3877),
    [anon_sym_eNUM] = ACTIONS(3877),
    [anon_sym_eNum] = ACTIONS(3877),
    [anon_sym_ENum] = ACTIONS(3877),
    [sym_quoted_identifier] = ACTIONS(3879),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3879),
    [sym_verbatim_string] = ACTIONS(3879),
    [sym_integer] = ACTIONS(3877),
    [sym_continue_as_identifier] = ACTIONS(3879),
    [sym_preproc_open] = ACTIONS(3879),
    [sym_preproc_close] = ACTIONS(3879),
  },
  [STATE(1839)] = {
    [sym_identifier] = ACTIONS(3881),
    [anon_sym_SEMI] = ACTIONS(3883),
    [anon_sym_DOT] = ACTIONS(3881),
    [anon_sym_EQ] = ACTIONS(3883),
    [anon_sym_DASH] = ACTIONS(3881),
    [aux_sym_boolean_token1] = ACTIONS(3881),
    [aux_sym_boolean_token2] = ACTIONS(3881),
    [sym_decimal] = ACTIONS(3881),
    [anon_sym_LPAREN] = ACTIONS(3883),
    [anon_sym_DOT_DOT] = ACTIONS(3883),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3881),
    [anon_sym_STAR] = ACTIONS(3881),
    [anon_sym_LBRACK] = ACTIONS(3883),
    [aux_sym_record_type_token1] = ACTIONS(3881),
    [aux_sym_basic_type_token21] = ACTIONS(3881),
    [aux_sym_basic_type_token22] = ACTIONS(3881),
    [aux_sym_basic_type_token48] = ACTIONS(3881),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3881),
    [anon_sym_POUNDif] = ACTIONS(3883),
    [anon_sym_POUNDIF] = ACTIONS(3883),
    [anon_sym_POUNDIf] = ACTIONS(3883),
    [anon_sym_not] = ACTIONS(3881),
    [anon_sym_NOT] = ACTIONS(3881),
    [anon_sym_Not] = ACTIONS(3881),
    [anon_sym_POUNDelif] = ACTIONS(3883),
    [anon_sym_POUNDELIF] = ACTIONS(3883),
    [anon_sym_POUNDElif] = ACTIONS(3883),
    [anon_sym_POUNDelse] = ACTIONS(3883),
    [anon_sym_POUNDELSE] = ACTIONS(3883),
    [anon_sym_POUNDElse] = ACTIONS(3883),
    [anon_sym_POUNDelse2] = ACTIONS(3883),
    [anon_sym_POUNDELSE2] = ACTIONS(3883),
    [anon_sym_POUNDElse2] = ACTIONS(3883),
    [anon_sym_POUNDendif] = ACTIONS(3883),
    [anon_sym_POUNDENDIF] = ACTIONS(3883),
    [anon_sym_POUNDEndif] = ACTIONS(3883),
    [anon_sym_POUNDendif2] = ACTIONS(3883),
    [anon_sym_POUNDENDIF2] = ACTIONS(3883),
    [anon_sym_POUNDEndif2] = ACTIONS(3883),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3883),
    [aux_sym__expression_token1] = ACTIONS(3883),
    [aux_sym__expression_token2] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3881),
    [anon_sym_SLASH] = ACTIONS(3881),
    [anon_sym_div] = ACTIONS(3881),
    [anon_sym_DIV] = ACTIONS(3881),
    [anon_sym_Div] = ACTIONS(3881),
    [anon_sym_mod] = ACTIONS(3881),
    [anon_sym_MOD] = ACTIONS(3881),
    [anon_sym_Mod] = ACTIONS(3881),
    [anon_sym_PLUS] = ACTIONS(3881),
    [anon_sym_GT_EQ] = ACTIONS(3883),
    [anon_sym_LT_EQ] = ACTIONS(3883),
    [anon_sym_GT] = ACTIONS(3881),
    [anon_sym_LT] = ACTIONS(3881),
    [anon_sym_LT_GT] = ACTIONS(3883),
    [anon_sym_and] = ACTIONS(3881),
    [anon_sym_AND] = ACTIONS(3881),
    [anon_sym_And] = ACTIONS(3881),
    [anon_sym_or] = ACTIONS(3881),
    [anon_sym_OR] = ACTIONS(3881),
    [anon_sym_Or] = ACTIONS(3881),
    [anon_sym_xor] = ACTIONS(3881),
    [anon_sym_XOR] = ACTIONS(3881),
    [anon_sym_Xor] = ACTIONS(3881),
    [anon_sym_QMARK] = ACTIONS(3883),
    [sym_datetime_literal] = ACTIONS(3883),
    [sym_date_literal] = ACTIONS(3881),
    [sym_time_literal] = ACTIONS(3881),
    [sym_biginteger_literal] = ACTIONS(3883),
    [anon_sym_if] = ACTIONS(3881),
    [anon_sym_IF] = ACTIONS(3881),
    [anon_sym_If] = ACTIONS(3881),
    [anon_sym_else] = ACTIONS(3881),
    [anon_sym_ELSE] = ACTIONS(3881),
    [anon_sym_Else] = ACTIONS(3881),
    [anon_sym_case] = ACTIONS(3881),
    [anon_sym_CASE] = ACTIONS(3881),
    [anon_sym_Case] = ACTIONS(3881),
    [anon_sym_for] = ACTIONS(3881),
    [anon_sym_FOR] = ACTIONS(3881),
    [anon_sym_For] = ACTIONS(3881),
    [anon_sym_foreach] = ACTIONS(3881),
    [anon_sym_FOREACH] = ACTIONS(3881),
    [anon_sym_Foreach] = ACTIONS(3881),
    [anon_sym_while] = ACTIONS(3881),
    [anon_sym_WHILE] = ACTIONS(3881),
    [anon_sym_While] = ACTIONS(3881),
    [anon_sym_repeat] = ACTIONS(3881),
    [anon_sym_REPEAT] = ACTIONS(3881),
    [anon_sym_Repeat] = ACTIONS(3881),
    [anon_sym_exit] = ACTIONS(3881),
    [anon_sym_EXIT] = ACTIONS(3881),
    [anon_sym_Exit] = ACTIONS(3881),
    [anon_sym_continue] = ACTIONS(3881),
    [anon_sym_CONTINUE] = ACTIONS(3881),
    [anon_sym_Continue] = ACTIONS(3881),
    [anon_sym_break] = ACTIONS(3881),
    [anon_sym_BREAK] = ACTIONS(3881),
    [anon_sym_Break] = ACTIONS(3881),
    [anon_sym_with] = ACTIONS(3881),
    [anon_sym_WITH] = ACTIONS(3881),
    [anon_sym_With] = ACTIONS(3881),
    [sym_asserterror_keyword] = ACTIONS(3883),
    [anon_sym_in] = ACTIONS(3881),
    [anon_sym_IN] = ACTIONS(3881),
    [anon_sym_In] = ACTIONS(3881),
    [sym_page_keyword] = ACTIONS(3881),
    [anon_sym_codeunit] = ACTIONS(3881),
    [anon_sym_CODEUNIT] = ACTIONS(3881),
    [anon_sym_Codeunit] = ACTIONS(3881),
    [anon_sym_CodeUnit] = ACTIONS(3881),
    [anon_sym_COdeunit] = ACTIONS(3881),
    [anon_sym_codeUnit] = ACTIONS(3881),
    [sym_report_keyword] = ACTIONS(3881),
    [sym_query_keyword] = ACTIONS(3881),
    [anon_sym_xmlport] = ACTIONS(3881),
    [anon_sym_XMLPORT] = ACTIONS(3881),
    [anon_sym_Xmlport] = ACTIONS(3881),
    [anon_sym_XMLport] = ACTIONS(3881),
    [anon_sym_XMLPort] = ACTIONS(3881),
    [anon_sym_XmlPort] = ACTIONS(3881),
    [anon_sym_enum] = ACTIONS(3881),
    [anon_sym_ENUM] = ACTIONS(3881),
    [anon_sym_Enum] = ACTIONS(3881),
    [anon_sym_eNUM] = ACTIONS(3881),
    [anon_sym_eNum] = ACTIONS(3881),
    [anon_sym_ENum] = ACTIONS(3881),
    [sym_quoted_identifier] = ACTIONS(3883),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3883),
    [sym_verbatim_string] = ACTIONS(3883),
    [sym_integer] = ACTIONS(3881),
    [sym_continue_as_identifier] = ACTIONS(3883),
    [sym_preproc_open] = ACTIONS(3883),
    [sym_preproc_close] = ACTIONS(3883),
  },
  [STATE(1840)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(1841)] = {
    [sym_identifier] = ACTIONS(3885),
    [anon_sym_SEMI] = ACTIONS(3887),
    [anon_sym_DOT] = ACTIONS(3885),
    [anon_sym_EQ] = ACTIONS(3887),
    [anon_sym_DASH] = ACTIONS(3885),
    [aux_sym_boolean_token1] = ACTIONS(3885),
    [aux_sym_boolean_token2] = ACTIONS(3885),
    [sym_decimal] = ACTIONS(3885),
    [anon_sym_LPAREN] = ACTIONS(3887),
    [anon_sym_DOT_DOT] = ACTIONS(3887),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3885),
    [anon_sym_STAR] = ACTIONS(3885),
    [anon_sym_LBRACK] = ACTIONS(3887),
    [aux_sym_record_type_token1] = ACTIONS(3885),
    [aux_sym_basic_type_token21] = ACTIONS(3885),
    [aux_sym_basic_type_token22] = ACTIONS(3885),
    [aux_sym_basic_type_token48] = ACTIONS(3885),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3885),
    [anon_sym_POUNDif] = ACTIONS(3887),
    [anon_sym_POUNDIF] = ACTIONS(3887),
    [anon_sym_POUNDIf] = ACTIONS(3887),
    [anon_sym_not] = ACTIONS(3885),
    [anon_sym_NOT] = ACTIONS(3885),
    [anon_sym_Not] = ACTIONS(3885),
    [anon_sym_POUNDelif] = ACTIONS(3887),
    [anon_sym_POUNDELIF] = ACTIONS(3887),
    [anon_sym_POUNDElif] = ACTIONS(3887),
    [anon_sym_POUNDelse] = ACTIONS(3887),
    [anon_sym_POUNDELSE] = ACTIONS(3887),
    [anon_sym_POUNDElse] = ACTIONS(3887),
    [anon_sym_POUNDelse2] = ACTIONS(3887),
    [anon_sym_POUNDELSE2] = ACTIONS(3887),
    [anon_sym_POUNDElse2] = ACTIONS(3887),
    [anon_sym_POUNDendif] = ACTIONS(3887),
    [anon_sym_POUNDENDIF] = ACTIONS(3887),
    [anon_sym_POUNDEndif] = ACTIONS(3887),
    [anon_sym_POUNDendif2] = ACTIONS(3887),
    [anon_sym_POUNDENDIF2] = ACTIONS(3887),
    [anon_sym_POUNDEndif2] = ACTIONS(3887),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3887),
    [aux_sym__expression_token1] = ACTIONS(3887),
    [aux_sym__expression_token2] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3885),
    [anon_sym_SLASH] = ACTIONS(3885),
    [anon_sym_div] = ACTIONS(3885),
    [anon_sym_DIV] = ACTIONS(3885),
    [anon_sym_Div] = ACTIONS(3885),
    [anon_sym_mod] = ACTIONS(3885),
    [anon_sym_MOD] = ACTIONS(3885),
    [anon_sym_Mod] = ACTIONS(3885),
    [anon_sym_PLUS] = ACTIONS(3885),
    [anon_sym_GT_EQ] = ACTIONS(3887),
    [anon_sym_LT_EQ] = ACTIONS(3887),
    [anon_sym_GT] = ACTIONS(3885),
    [anon_sym_LT] = ACTIONS(3885),
    [anon_sym_LT_GT] = ACTIONS(3887),
    [anon_sym_and] = ACTIONS(3885),
    [anon_sym_AND] = ACTIONS(3885),
    [anon_sym_And] = ACTIONS(3885),
    [anon_sym_or] = ACTIONS(3885),
    [anon_sym_OR] = ACTIONS(3885),
    [anon_sym_Or] = ACTIONS(3885),
    [anon_sym_xor] = ACTIONS(3885),
    [anon_sym_XOR] = ACTIONS(3885),
    [anon_sym_Xor] = ACTIONS(3885),
    [anon_sym_QMARK] = ACTIONS(3887),
    [sym_datetime_literal] = ACTIONS(3887),
    [sym_date_literal] = ACTIONS(3885),
    [sym_time_literal] = ACTIONS(3885),
    [sym_biginteger_literal] = ACTIONS(3887),
    [anon_sym_if] = ACTIONS(3885),
    [anon_sym_IF] = ACTIONS(3885),
    [anon_sym_If] = ACTIONS(3885),
    [anon_sym_else] = ACTIONS(3885),
    [anon_sym_ELSE] = ACTIONS(3885),
    [anon_sym_Else] = ACTIONS(3885),
    [anon_sym_case] = ACTIONS(3885),
    [anon_sym_CASE] = ACTIONS(3885),
    [anon_sym_Case] = ACTIONS(3885),
    [anon_sym_for] = ACTIONS(3885),
    [anon_sym_FOR] = ACTIONS(3885),
    [anon_sym_For] = ACTIONS(3885),
    [anon_sym_foreach] = ACTIONS(3885),
    [anon_sym_FOREACH] = ACTIONS(3885),
    [anon_sym_Foreach] = ACTIONS(3885),
    [anon_sym_while] = ACTIONS(3885),
    [anon_sym_WHILE] = ACTIONS(3885),
    [anon_sym_While] = ACTIONS(3885),
    [anon_sym_repeat] = ACTIONS(3885),
    [anon_sym_REPEAT] = ACTIONS(3885),
    [anon_sym_Repeat] = ACTIONS(3885),
    [anon_sym_exit] = ACTIONS(3885),
    [anon_sym_EXIT] = ACTIONS(3885),
    [anon_sym_Exit] = ACTIONS(3885),
    [anon_sym_continue] = ACTIONS(3885),
    [anon_sym_CONTINUE] = ACTIONS(3885),
    [anon_sym_Continue] = ACTIONS(3885),
    [anon_sym_break] = ACTIONS(3885),
    [anon_sym_BREAK] = ACTIONS(3885),
    [anon_sym_Break] = ACTIONS(3885),
    [anon_sym_with] = ACTIONS(3885),
    [anon_sym_WITH] = ACTIONS(3885),
    [anon_sym_With] = ACTIONS(3885),
    [sym_asserterror_keyword] = ACTIONS(3887),
    [anon_sym_in] = ACTIONS(3885),
    [anon_sym_IN] = ACTIONS(3885),
    [anon_sym_In] = ACTIONS(3885),
    [sym_page_keyword] = ACTIONS(3885),
    [anon_sym_codeunit] = ACTIONS(3885),
    [anon_sym_CODEUNIT] = ACTIONS(3885),
    [anon_sym_Codeunit] = ACTIONS(3885),
    [anon_sym_CodeUnit] = ACTIONS(3885),
    [anon_sym_COdeunit] = ACTIONS(3885),
    [anon_sym_codeUnit] = ACTIONS(3885),
    [sym_report_keyword] = ACTIONS(3885),
    [sym_query_keyword] = ACTIONS(3885),
    [anon_sym_xmlport] = ACTIONS(3885),
    [anon_sym_XMLPORT] = ACTIONS(3885),
    [anon_sym_Xmlport] = ACTIONS(3885),
    [anon_sym_XMLport] = ACTIONS(3885),
    [anon_sym_XMLPort] = ACTIONS(3885),
    [anon_sym_XmlPort] = ACTIONS(3885),
    [anon_sym_enum] = ACTIONS(3885),
    [anon_sym_ENUM] = ACTIONS(3885),
    [anon_sym_Enum] = ACTIONS(3885),
    [anon_sym_eNUM] = ACTIONS(3885),
    [anon_sym_eNum] = ACTIONS(3885),
    [anon_sym_ENum] = ACTIONS(3885),
    [sym_quoted_identifier] = ACTIONS(3887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3887),
    [sym_verbatim_string] = ACTIONS(3887),
    [sym_integer] = ACTIONS(3885),
    [sym_continue_as_identifier] = ACTIONS(3887),
    [sym_preproc_open] = ACTIONS(3887),
    [sym_preproc_close] = ACTIONS(3887),
  },
  [STATE(1842)] = {
    [sym_identifier] = ACTIONS(3889),
    [anon_sym_SEMI] = ACTIONS(3891),
    [anon_sym_DOT] = ACTIONS(3889),
    [anon_sym_EQ] = ACTIONS(3891),
    [anon_sym_DASH] = ACTIONS(3889),
    [aux_sym_boolean_token1] = ACTIONS(3889),
    [aux_sym_boolean_token2] = ACTIONS(3889),
    [sym_decimal] = ACTIONS(3889),
    [anon_sym_LPAREN] = ACTIONS(3891),
    [anon_sym_DOT_DOT] = ACTIONS(3891),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3889),
    [anon_sym_STAR] = ACTIONS(3889),
    [anon_sym_LBRACK] = ACTIONS(3891),
    [aux_sym_record_type_token1] = ACTIONS(3889),
    [aux_sym_basic_type_token21] = ACTIONS(3889),
    [aux_sym_basic_type_token22] = ACTIONS(3889),
    [aux_sym_basic_type_token48] = ACTIONS(3889),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3889),
    [anon_sym_POUNDif] = ACTIONS(3891),
    [anon_sym_POUNDIF] = ACTIONS(3891),
    [anon_sym_POUNDIf] = ACTIONS(3891),
    [anon_sym_not] = ACTIONS(3889),
    [anon_sym_NOT] = ACTIONS(3889),
    [anon_sym_Not] = ACTIONS(3889),
    [anon_sym_POUNDelif] = ACTIONS(3891),
    [anon_sym_POUNDELIF] = ACTIONS(3891),
    [anon_sym_POUNDElif] = ACTIONS(3891),
    [anon_sym_POUNDelse] = ACTIONS(3891),
    [anon_sym_POUNDELSE] = ACTIONS(3891),
    [anon_sym_POUNDElse] = ACTIONS(3891),
    [anon_sym_POUNDelse2] = ACTIONS(3891),
    [anon_sym_POUNDELSE2] = ACTIONS(3891),
    [anon_sym_POUNDElse2] = ACTIONS(3891),
    [anon_sym_POUNDendif] = ACTIONS(3891),
    [anon_sym_POUNDENDIF] = ACTIONS(3891),
    [anon_sym_POUNDEndif] = ACTIONS(3891),
    [anon_sym_POUNDendif2] = ACTIONS(3891),
    [anon_sym_POUNDENDIF2] = ACTIONS(3891),
    [anon_sym_POUNDEndif2] = ACTIONS(3891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3891),
    [aux_sym__expression_token1] = ACTIONS(3891),
    [aux_sym__expression_token2] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3889),
    [anon_sym_SLASH] = ACTIONS(3889),
    [anon_sym_div] = ACTIONS(3889),
    [anon_sym_DIV] = ACTIONS(3889),
    [anon_sym_Div] = ACTIONS(3889),
    [anon_sym_mod] = ACTIONS(3889),
    [anon_sym_MOD] = ACTIONS(3889),
    [anon_sym_Mod] = ACTIONS(3889),
    [anon_sym_PLUS] = ACTIONS(3889),
    [anon_sym_GT_EQ] = ACTIONS(3891),
    [anon_sym_LT_EQ] = ACTIONS(3891),
    [anon_sym_GT] = ACTIONS(3889),
    [anon_sym_LT] = ACTIONS(3889),
    [anon_sym_LT_GT] = ACTIONS(3891),
    [anon_sym_and] = ACTIONS(3889),
    [anon_sym_AND] = ACTIONS(3889),
    [anon_sym_And] = ACTIONS(3889),
    [anon_sym_or] = ACTIONS(3889),
    [anon_sym_OR] = ACTIONS(3889),
    [anon_sym_Or] = ACTIONS(3889),
    [anon_sym_xor] = ACTIONS(3889),
    [anon_sym_XOR] = ACTIONS(3889),
    [anon_sym_Xor] = ACTIONS(3889),
    [anon_sym_QMARK] = ACTIONS(3891),
    [sym_datetime_literal] = ACTIONS(3891),
    [sym_date_literal] = ACTIONS(3889),
    [sym_time_literal] = ACTIONS(3889),
    [sym_biginteger_literal] = ACTIONS(3891),
    [anon_sym_if] = ACTIONS(3889),
    [anon_sym_IF] = ACTIONS(3889),
    [anon_sym_If] = ACTIONS(3889),
    [anon_sym_else] = ACTIONS(3889),
    [anon_sym_ELSE] = ACTIONS(3889),
    [anon_sym_Else] = ACTIONS(3889),
    [anon_sym_case] = ACTIONS(3889),
    [anon_sym_CASE] = ACTIONS(3889),
    [anon_sym_Case] = ACTIONS(3889),
    [anon_sym_for] = ACTIONS(3889),
    [anon_sym_FOR] = ACTIONS(3889),
    [anon_sym_For] = ACTIONS(3889),
    [anon_sym_foreach] = ACTIONS(3889),
    [anon_sym_FOREACH] = ACTIONS(3889),
    [anon_sym_Foreach] = ACTIONS(3889),
    [anon_sym_while] = ACTIONS(3889),
    [anon_sym_WHILE] = ACTIONS(3889),
    [anon_sym_While] = ACTIONS(3889),
    [anon_sym_repeat] = ACTIONS(3889),
    [anon_sym_REPEAT] = ACTIONS(3889),
    [anon_sym_Repeat] = ACTIONS(3889),
    [anon_sym_exit] = ACTIONS(3889),
    [anon_sym_EXIT] = ACTIONS(3889),
    [anon_sym_Exit] = ACTIONS(3889),
    [anon_sym_continue] = ACTIONS(3889),
    [anon_sym_CONTINUE] = ACTIONS(3889),
    [anon_sym_Continue] = ACTIONS(3889),
    [anon_sym_break] = ACTIONS(3889),
    [anon_sym_BREAK] = ACTIONS(3889),
    [anon_sym_Break] = ACTIONS(3889),
    [anon_sym_with] = ACTIONS(3889),
    [anon_sym_WITH] = ACTIONS(3889),
    [anon_sym_With] = ACTIONS(3889),
    [sym_asserterror_keyword] = ACTIONS(3891),
    [anon_sym_in] = ACTIONS(3889),
    [anon_sym_IN] = ACTIONS(3889),
    [anon_sym_In] = ACTIONS(3889),
    [sym_page_keyword] = ACTIONS(3889),
    [anon_sym_codeunit] = ACTIONS(3889),
    [anon_sym_CODEUNIT] = ACTIONS(3889),
    [anon_sym_Codeunit] = ACTIONS(3889),
    [anon_sym_CodeUnit] = ACTIONS(3889),
    [anon_sym_COdeunit] = ACTIONS(3889),
    [anon_sym_codeUnit] = ACTIONS(3889),
    [sym_report_keyword] = ACTIONS(3889),
    [sym_query_keyword] = ACTIONS(3889),
    [anon_sym_xmlport] = ACTIONS(3889),
    [anon_sym_XMLPORT] = ACTIONS(3889),
    [anon_sym_Xmlport] = ACTIONS(3889),
    [anon_sym_XMLport] = ACTIONS(3889),
    [anon_sym_XMLPort] = ACTIONS(3889),
    [anon_sym_XmlPort] = ACTIONS(3889),
    [anon_sym_enum] = ACTIONS(3889),
    [anon_sym_ENUM] = ACTIONS(3889),
    [anon_sym_Enum] = ACTIONS(3889),
    [anon_sym_eNUM] = ACTIONS(3889),
    [anon_sym_eNum] = ACTIONS(3889),
    [anon_sym_ENum] = ACTIONS(3889),
    [sym_quoted_identifier] = ACTIONS(3891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3891),
    [sym_verbatim_string] = ACTIONS(3891),
    [sym_integer] = ACTIONS(3889),
    [sym_continue_as_identifier] = ACTIONS(3891),
    [sym_preproc_open] = ACTIONS(3891),
    [sym_preproc_close] = ACTIONS(3891),
  },
  [STATE(1843)] = {
    [sym_identifier] = ACTIONS(3893),
    [anon_sym_SEMI] = ACTIONS(3895),
    [anon_sym_DOT] = ACTIONS(3893),
    [anon_sym_EQ] = ACTIONS(3895),
    [anon_sym_DASH] = ACTIONS(3893),
    [aux_sym_boolean_token1] = ACTIONS(3893),
    [aux_sym_boolean_token2] = ACTIONS(3893),
    [sym_decimal] = ACTIONS(3893),
    [anon_sym_LPAREN] = ACTIONS(3895),
    [anon_sym_DOT_DOT] = ACTIONS(3895),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3893),
    [anon_sym_STAR] = ACTIONS(3893),
    [anon_sym_LBRACK] = ACTIONS(3895),
    [aux_sym_record_type_token1] = ACTIONS(3893),
    [aux_sym_basic_type_token21] = ACTIONS(3893),
    [aux_sym_basic_type_token22] = ACTIONS(3893),
    [aux_sym_basic_type_token48] = ACTIONS(3893),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3893),
    [anon_sym_POUNDif] = ACTIONS(3895),
    [anon_sym_POUNDIF] = ACTIONS(3895),
    [anon_sym_POUNDIf] = ACTIONS(3895),
    [anon_sym_not] = ACTIONS(3893),
    [anon_sym_NOT] = ACTIONS(3893),
    [anon_sym_Not] = ACTIONS(3893),
    [anon_sym_POUNDelif] = ACTIONS(3895),
    [anon_sym_POUNDELIF] = ACTIONS(3895),
    [anon_sym_POUNDElif] = ACTIONS(3895),
    [anon_sym_POUNDelse] = ACTIONS(3895),
    [anon_sym_POUNDELSE] = ACTIONS(3895),
    [anon_sym_POUNDElse] = ACTIONS(3895),
    [anon_sym_POUNDelse2] = ACTIONS(3895),
    [anon_sym_POUNDELSE2] = ACTIONS(3895),
    [anon_sym_POUNDElse2] = ACTIONS(3895),
    [anon_sym_POUNDendif] = ACTIONS(3895),
    [anon_sym_POUNDENDIF] = ACTIONS(3895),
    [anon_sym_POUNDEndif] = ACTIONS(3895),
    [anon_sym_POUNDendif2] = ACTIONS(3895),
    [anon_sym_POUNDENDIF2] = ACTIONS(3895),
    [anon_sym_POUNDEndif2] = ACTIONS(3895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3895),
    [aux_sym__expression_token1] = ACTIONS(3895),
    [aux_sym__expression_token2] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3893),
    [anon_sym_SLASH] = ACTIONS(3893),
    [anon_sym_div] = ACTIONS(3893),
    [anon_sym_DIV] = ACTIONS(3893),
    [anon_sym_Div] = ACTIONS(3893),
    [anon_sym_mod] = ACTIONS(3893),
    [anon_sym_MOD] = ACTIONS(3893),
    [anon_sym_Mod] = ACTIONS(3893),
    [anon_sym_PLUS] = ACTIONS(3893),
    [anon_sym_GT_EQ] = ACTIONS(3895),
    [anon_sym_LT_EQ] = ACTIONS(3895),
    [anon_sym_GT] = ACTIONS(3893),
    [anon_sym_LT] = ACTIONS(3893),
    [anon_sym_LT_GT] = ACTIONS(3895),
    [anon_sym_and] = ACTIONS(3893),
    [anon_sym_AND] = ACTIONS(3893),
    [anon_sym_And] = ACTIONS(3893),
    [anon_sym_or] = ACTIONS(3893),
    [anon_sym_OR] = ACTIONS(3893),
    [anon_sym_Or] = ACTIONS(3893),
    [anon_sym_xor] = ACTIONS(3893),
    [anon_sym_XOR] = ACTIONS(3893),
    [anon_sym_Xor] = ACTIONS(3893),
    [anon_sym_QMARK] = ACTIONS(3895),
    [sym_datetime_literal] = ACTIONS(3895),
    [sym_date_literal] = ACTIONS(3893),
    [sym_time_literal] = ACTIONS(3893),
    [sym_biginteger_literal] = ACTIONS(3895),
    [anon_sym_if] = ACTIONS(3893),
    [anon_sym_IF] = ACTIONS(3893),
    [anon_sym_If] = ACTIONS(3893),
    [anon_sym_else] = ACTIONS(3893),
    [anon_sym_ELSE] = ACTIONS(3893),
    [anon_sym_Else] = ACTIONS(3893),
    [anon_sym_case] = ACTIONS(3893),
    [anon_sym_CASE] = ACTIONS(3893),
    [anon_sym_Case] = ACTIONS(3893),
    [anon_sym_for] = ACTIONS(3893),
    [anon_sym_FOR] = ACTIONS(3893),
    [anon_sym_For] = ACTIONS(3893),
    [anon_sym_foreach] = ACTIONS(3893),
    [anon_sym_FOREACH] = ACTIONS(3893),
    [anon_sym_Foreach] = ACTIONS(3893),
    [anon_sym_while] = ACTIONS(3893),
    [anon_sym_WHILE] = ACTIONS(3893),
    [anon_sym_While] = ACTIONS(3893),
    [anon_sym_repeat] = ACTIONS(3893),
    [anon_sym_REPEAT] = ACTIONS(3893),
    [anon_sym_Repeat] = ACTIONS(3893),
    [anon_sym_exit] = ACTIONS(3893),
    [anon_sym_EXIT] = ACTIONS(3893),
    [anon_sym_Exit] = ACTIONS(3893),
    [anon_sym_continue] = ACTIONS(3893),
    [anon_sym_CONTINUE] = ACTIONS(3893),
    [anon_sym_Continue] = ACTIONS(3893),
    [anon_sym_break] = ACTIONS(3893),
    [anon_sym_BREAK] = ACTIONS(3893),
    [anon_sym_Break] = ACTIONS(3893),
    [anon_sym_with] = ACTIONS(3893),
    [anon_sym_WITH] = ACTIONS(3893),
    [anon_sym_With] = ACTIONS(3893),
    [sym_asserterror_keyword] = ACTIONS(3895),
    [anon_sym_in] = ACTIONS(3893),
    [anon_sym_IN] = ACTIONS(3893),
    [anon_sym_In] = ACTIONS(3893),
    [sym_page_keyword] = ACTIONS(3893),
    [anon_sym_codeunit] = ACTIONS(3893),
    [anon_sym_CODEUNIT] = ACTIONS(3893),
    [anon_sym_Codeunit] = ACTIONS(3893),
    [anon_sym_CodeUnit] = ACTIONS(3893),
    [anon_sym_COdeunit] = ACTIONS(3893),
    [anon_sym_codeUnit] = ACTIONS(3893),
    [sym_report_keyword] = ACTIONS(3893),
    [sym_query_keyword] = ACTIONS(3893),
    [anon_sym_xmlport] = ACTIONS(3893),
    [anon_sym_XMLPORT] = ACTIONS(3893),
    [anon_sym_Xmlport] = ACTIONS(3893),
    [anon_sym_XMLport] = ACTIONS(3893),
    [anon_sym_XMLPort] = ACTIONS(3893),
    [anon_sym_XmlPort] = ACTIONS(3893),
    [anon_sym_enum] = ACTIONS(3893),
    [anon_sym_ENUM] = ACTIONS(3893),
    [anon_sym_Enum] = ACTIONS(3893),
    [anon_sym_eNUM] = ACTIONS(3893),
    [anon_sym_eNum] = ACTIONS(3893),
    [anon_sym_ENum] = ACTIONS(3893),
    [sym_quoted_identifier] = ACTIONS(3895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3895),
    [sym_verbatim_string] = ACTIONS(3895),
    [sym_integer] = ACTIONS(3893),
    [sym_continue_as_identifier] = ACTIONS(3895),
    [sym_preproc_open] = ACTIONS(3895),
    [sym_preproc_close] = ACTIONS(3895),
  },
  [STATE(1844)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(1845)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(1846)] = {
    [sym_identifier] = ACTIONS(3897),
    [anon_sym_SEMI] = ACTIONS(3899),
    [anon_sym_DOT] = ACTIONS(3897),
    [anon_sym_EQ] = ACTIONS(3899),
    [anon_sym_DASH] = ACTIONS(3897),
    [aux_sym_boolean_token1] = ACTIONS(3897),
    [aux_sym_boolean_token2] = ACTIONS(3897),
    [sym_decimal] = ACTIONS(3897),
    [anon_sym_LPAREN] = ACTIONS(3899),
    [anon_sym_DOT_DOT] = ACTIONS(3899),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3897),
    [anon_sym_STAR] = ACTIONS(3897),
    [anon_sym_LBRACK] = ACTIONS(3899),
    [aux_sym_record_type_token1] = ACTIONS(3897),
    [aux_sym_basic_type_token21] = ACTIONS(3897),
    [aux_sym_basic_type_token22] = ACTIONS(3897),
    [aux_sym_basic_type_token48] = ACTIONS(3897),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3897),
    [anon_sym_POUNDif] = ACTIONS(3899),
    [anon_sym_POUNDIF] = ACTIONS(3899),
    [anon_sym_POUNDIf] = ACTIONS(3899),
    [anon_sym_not] = ACTIONS(3897),
    [anon_sym_NOT] = ACTIONS(3897),
    [anon_sym_Not] = ACTIONS(3897),
    [anon_sym_POUNDelif] = ACTIONS(3899),
    [anon_sym_POUNDELIF] = ACTIONS(3899),
    [anon_sym_POUNDElif] = ACTIONS(3899),
    [anon_sym_POUNDelse] = ACTIONS(3899),
    [anon_sym_POUNDELSE] = ACTIONS(3899),
    [anon_sym_POUNDElse] = ACTIONS(3899),
    [anon_sym_POUNDelse2] = ACTIONS(3899),
    [anon_sym_POUNDELSE2] = ACTIONS(3899),
    [anon_sym_POUNDElse2] = ACTIONS(3899),
    [anon_sym_POUNDendif] = ACTIONS(3899),
    [anon_sym_POUNDENDIF] = ACTIONS(3899),
    [anon_sym_POUNDEndif] = ACTIONS(3899),
    [anon_sym_POUNDendif2] = ACTIONS(3899),
    [anon_sym_POUNDENDIF2] = ACTIONS(3899),
    [anon_sym_POUNDEndif2] = ACTIONS(3899),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3899),
    [aux_sym__expression_token1] = ACTIONS(3899),
    [aux_sym__expression_token2] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3897),
    [anon_sym_SLASH] = ACTIONS(3897),
    [anon_sym_div] = ACTIONS(3897),
    [anon_sym_DIV] = ACTIONS(3897),
    [anon_sym_Div] = ACTIONS(3897),
    [anon_sym_mod] = ACTIONS(3897),
    [anon_sym_MOD] = ACTIONS(3897),
    [anon_sym_Mod] = ACTIONS(3897),
    [anon_sym_PLUS] = ACTIONS(3897),
    [anon_sym_GT_EQ] = ACTIONS(3899),
    [anon_sym_LT_EQ] = ACTIONS(3899),
    [anon_sym_GT] = ACTIONS(3897),
    [anon_sym_LT] = ACTIONS(3897),
    [anon_sym_LT_GT] = ACTIONS(3899),
    [anon_sym_and] = ACTIONS(3897),
    [anon_sym_AND] = ACTIONS(3897),
    [anon_sym_And] = ACTIONS(3897),
    [anon_sym_or] = ACTIONS(3897),
    [anon_sym_OR] = ACTIONS(3897),
    [anon_sym_Or] = ACTIONS(3897),
    [anon_sym_xor] = ACTIONS(3897),
    [anon_sym_XOR] = ACTIONS(3897),
    [anon_sym_Xor] = ACTIONS(3897),
    [anon_sym_QMARK] = ACTIONS(3899),
    [sym_datetime_literal] = ACTIONS(3899),
    [sym_date_literal] = ACTIONS(3897),
    [sym_time_literal] = ACTIONS(3897),
    [sym_biginteger_literal] = ACTIONS(3899),
    [anon_sym_if] = ACTIONS(3897),
    [anon_sym_IF] = ACTIONS(3897),
    [anon_sym_If] = ACTIONS(3897),
    [anon_sym_else] = ACTIONS(3897),
    [anon_sym_ELSE] = ACTIONS(3897),
    [anon_sym_Else] = ACTIONS(3897),
    [anon_sym_case] = ACTIONS(3897),
    [anon_sym_CASE] = ACTIONS(3897),
    [anon_sym_Case] = ACTIONS(3897),
    [anon_sym_for] = ACTIONS(3897),
    [anon_sym_FOR] = ACTIONS(3897),
    [anon_sym_For] = ACTIONS(3897),
    [anon_sym_foreach] = ACTIONS(3897),
    [anon_sym_FOREACH] = ACTIONS(3897),
    [anon_sym_Foreach] = ACTIONS(3897),
    [anon_sym_while] = ACTIONS(3897),
    [anon_sym_WHILE] = ACTIONS(3897),
    [anon_sym_While] = ACTIONS(3897),
    [anon_sym_repeat] = ACTIONS(3897),
    [anon_sym_REPEAT] = ACTIONS(3897),
    [anon_sym_Repeat] = ACTIONS(3897),
    [anon_sym_exit] = ACTIONS(3897),
    [anon_sym_EXIT] = ACTIONS(3897),
    [anon_sym_Exit] = ACTIONS(3897),
    [anon_sym_continue] = ACTIONS(3897),
    [anon_sym_CONTINUE] = ACTIONS(3897),
    [anon_sym_Continue] = ACTIONS(3897),
    [anon_sym_break] = ACTIONS(3897),
    [anon_sym_BREAK] = ACTIONS(3897),
    [anon_sym_Break] = ACTIONS(3897),
    [anon_sym_with] = ACTIONS(3897),
    [anon_sym_WITH] = ACTIONS(3897),
    [anon_sym_With] = ACTIONS(3897),
    [sym_asserterror_keyword] = ACTIONS(3899),
    [anon_sym_in] = ACTIONS(3897),
    [anon_sym_IN] = ACTIONS(3897),
    [anon_sym_In] = ACTIONS(3897),
    [sym_page_keyword] = ACTIONS(3897),
    [anon_sym_codeunit] = ACTIONS(3897),
    [anon_sym_CODEUNIT] = ACTIONS(3897),
    [anon_sym_Codeunit] = ACTIONS(3897),
    [anon_sym_CodeUnit] = ACTIONS(3897),
    [anon_sym_COdeunit] = ACTIONS(3897),
    [anon_sym_codeUnit] = ACTIONS(3897),
    [sym_report_keyword] = ACTIONS(3897),
    [sym_query_keyword] = ACTIONS(3897),
    [anon_sym_xmlport] = ACTIONS(3897),
    [anon_sym_XMLPORT] = ACTIONS(3897),
    [anon_sym_Xmlport] = ACTIONS(3897),
    [anon_sym_XMLport] = ACTIONS(3897),
    [anon_sym_XMLPort] = ACTIONS(3897),
    [anon_sym_XmlPort] = ACTIONS(3897),
    [anon_sym_enum] = ACTIONS(3897),
    [anon_sym_ENUM] = ACTIONS(3897),
    [anon_sym_Enum] = ACTIONS(3897),
    [anon_sym_eNUM] = ACTIONS(3897),
    [anon_sym_eNum] = ACTIONS(3897),
    [anon_sym_ENum] = ACTIONS(3897),
    [sym_quoted_identifier] = ACTIONS(3899),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3899),
    [sym_verbatim_string] = ACTIONS(3899),
    [sym_integer] = ACTIONS(3897),
    [sym_continue_as_identifier] = ACTIONS(3899),
    [sym_preproc_open] = ACTIONS(3899),
    [sym_preproc_close] = ACTIONS(3899),
  },
  [STATE(1847)] = {
    [sym_identifier] = ACTIONS(3901),
    [anon_sym_SEMI] = ACTIONS(3903),
    [anon_sym_DOT] = ACTIONS(3901),
    [anon_sym_EQ] = ACTIONS(3903),
    [anon_sym_DASH] = ACTIONS(3901),
    [aux_sym_boolean_token1] = ACTIONS(3901),
    [aux_sym_boolean_token2] = ACTIONS(3901),
    [sym_decimal] = ACTIONS(3901),
    [anon_sym_LPAREN] = ACTIONS(3903),
    [anon_sym_DOT_DOT] = ACTIONS(3903),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3901),
    [anon_sym_STAR] = ACTIONS(3901),
    [anon_sym_LBRACK] = ACTIONS(3903),
    [aux_sym_record_type_token1] = ACTIONS(3901),
    [aux_sym_basic_type_token21] = ACTIONS(3901),
    [aux_sym_basic_type_token22] = ACTIONS(3901),
    [aux_sym_basic_type_token48] = ACTIONS(3901),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3901),
    [anon_sym_POUNDif] = ACTIONS(3903),
    [anon_sym_POUNDIF] = ACTIONS(3903),
    [anon_sym_POUNDIf] = ACTIONS(3903),
    [anon_sym_not] = ACTIONS(3901),
    [anon_sym_NOT] = ACTIONS(3901),
    [anon_sym_Not] = ACTIONS(3901),
    [anon_sym_POUNDelif] = ACTIONS(3903),
    [anon_sym_POUNDELIF] = ACTIONS(3903),
    [anon_sym_POUNDElif] = ACTIONS(3903),
    [anon_sym_POUNDelse] = ACTIONS(3903),
    [anon_sym_POUNDELSE] = ACTIONS(3903),
    [anon_sym_POUNDElse] = ACTIONS(3903),
    [anon_sym_POUNDelse2] = ACTIONS(3903),
    [anon_sym_POUNDELSE2] = ACTIONS(3903),
    [anon_sym_POUNDElse2] = ACTIONS(3903),
    [anon_sym_POUNDendif] = ACTIONS(3903),
    [anon_sym_POUNDENDIF] = ACTIONS(3903),
    [anon_sym_POUNDEndif] = ACTIONS(3903),
    [anon_sym_POUNDendif2] = ACTIONS(3903),
    [anon_sym_POUNDENDIF2] = ACTIONS(3903),
    [anon_sym_POUNDEndif2] = ACTIONS(3903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3903),
    [aux_sym__expression_token1] = ACTIONS(3903),
    [aux_sym__expression_token2] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3901),
    [anon_sym_SLASH] = ACTIONS(3901),
    [anon_sym_div] = ACTIONS(3901),
    [anon_sym_DIV] = ACTIONS(3901),
    [anon_sym_Div] = ACTIONS(3901),
    [anon_sym_mod] = ACTIONS(3901),
    [anon_sym_MOD] = ACTIONS(3901),
    [anon_sym_Mod] = ACTIONS(3901),
    [anon_sym_PLUS] = ACTIONS(3901),
    [anon_sym_GT_EQ] = ACTIONS(3903),
    [anon_sym_LT_EQ] = ACTIONS(3903),
    [anon_sym_GT] = ACTIONS(3901),
    [anon_sym_LT] = ACTIONS(3901),
    [anon_sym_LT_GT] = ACTIONS(3903),
    [anon_sym_and] = ACTIONS(3901),
    [anon_sym_AND] = ACTIONS(3901),
    [anon_sym_And] = ACTIONS(3901),
    [anon_sym_or] = ACTIONS(3901),
    [anon_sym_OR] = ACTIONS(3901),
    [anon_sym_Or] = ACTIONS(3901),
    [anon_sym_xor] = ACTIONS(3901),
    [anon_sym_XOR] = ACTIONS(3901),
    [anon_sym_Xor] = ACTIONS(3901),
    [anon_sym_QMARK] = ACTIONS(3903),
    [sym_datetime_literal] = ACTIONS(3903),
    [sym_date_literal] = ACTIONS(3901),
    [sym_time_literal] = ACTIONS(3901),
    [sym_biginteger_literal] = ACTIONS(3903),
    [anon_sym_if] = ACTIONS(3901),
    [anon_sym_IF] = ACTIONS(3901),
    [anon_sym_If] = ACTIONS(3901),
    [anon_sym_else] = ACTIONS(3901),
    [anon_sym_ELSE] = ACTIONS(3901),
    [anon_sym_Else] = ACTIONS(3901),
    [anon_sym_case] = ACTIONS(3901),
    [anon_sym_CASE] = ACTIONS(3901),
    [anon_sym_Case] = ACTIONS(3901),
    [anon_sym_for] = ACTIONS(3901),
    [anon_sym_FOR] = ACTIONS(3901),
    [anon_sym_For] = ACTIONS(3901),
    [anon_sym_foreach] = ACTIONS(3901),
    [anon_sym_FOREACH] = ACTIONS(3901),
    [anon_sym_Foreach] = ACTIONS(3901),
    [anon_sym_while] = ACTIONS(3901),
    [anon_sym_WHILE] = ACTIONS(3901),
    [anon_sym_While] = ACTIONS(3901),
    [anon_sym_repeat] = ACTIONS(3901),
    [anon_sym_REPEAT] = ACTIONS(3901),
    [anon_sym_Repeat] = ACTIONS(3901),
    [anon_sym_exit] = ACTIONS(3901),
    [anon_sym_EXIT] = ACTIONS(3901),
    [anon_sym_Exit] = ACTIONS(3901),
    [anon_sym_continue] = ACTIONS(3901),
    [anon_sym_CONTINUE] = ACTIONS(3901),
    [anon_sym_Continue] = ACTIONS(3901),
    [anon_sym_break] = ACTIONS(3901),
    [anon_sym_BREAK] = ACTIONS(3901),
    [anon_sym_Break] = ACTIONS(3901),
    [anon_sym_with] = ACTIONS(3901),
    [anon_sym_WITH] = ACTIONS(3901),
    [anon_sym_With] = ACTIONS(3901),
    [sym_asserterror_keyword] = ACTIONS(3903),
    [anon_sym_in] = ACTIONS(3901),
    [anon_sym_IN] = ACTIONS(3901),
    [anon_sym_In] = ACTIONS(3901),
    [sym_page_keyword] = ACTIONS(3901),
    [anon_sym_codeunit] = ACTIONS(3901),
    [anon_sym_CODEUNIT] = ACTIONS(3901),
    [anon_sym_Codeunit] = ACTIONS(3901),
    [anon_sym_CodeUnit] = ACTIONS(3901),
    [anon_sym_COdeunit] = ACTIONS(3901),
    [anon_sym_codeUnit] = ACTIONS(3901),
    [sym_report_keyword] = ACTIONS(3901),
    [sym_query_keyword] = ACTIONS(3901),
    [anon_sym_xmlport] = ACTIONS(3901),
    [anon_sym_XMLPORT] = ACTIONS(3901),
    [anon_sym_Xmlport] = ACTIONS(3901),
    [anon_sym_XMLport] = ACTIONS(3901),
    [anon_sym_XMLPort] = ACTIONS(3901),
    [anon_sym_XmlPort] = ACTIONS(3901),
    [anon_sym_enum] = ACTIONS(3901),
    [anon_sym_ENUM] = ACTIONS(3901),
    [anon_sym_Enum] = ACTIONS(3901),
    [anon_sym_eNUM] = ACTIONS(3901),
    [anon_sym_eNum] = ACTIONS(3901),
    [anon_sym_ENum] = ACTIONS(3901),
    [sym_quoted_identifier] = ACTIONS(3903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3903),
    [sym_verbatim_string] = ACTIONS(3903),
    [sym_integer] = ACTIONS(3901),
    [sym_continue_as_identifier] = ACTIONS(3903),
    [sym_preproc_open] = ACTIONS(3903),
    [sym_preproc_close] = ACTIONS(3903),
  },
  [STATE(1848)] = {
    [sym_identifier] = ACTIONS(3905),
    [anon_sym_SEMI] = ACTIONS(3907),
    [anon_sym_DOT] = ACTIONS(3905),
    [anon_sym_EQ] = ACTIONS(3907),
    [anon_sym_DASH] = ACTIONS(3905),
    [aux_sym_boolean_token1] = ACTIONS(3905),
    [aux_sym_boolean_token2] = ACTIONS(3905),
    [sym_decimal] = ACTIONS(3905),
    [anon_sym_LPAREN] = ACTIONS(3907),
    [anon_sym_DOT_DOT] = ACTIONS(3907),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3905),
    [anon_sym_STAR] = ACTIONS(3905),
    [anon_sym_LBRACK] = ACTIONS(3907),
    [aux_sym_record_type_token1] = ACTIONS(3905),
    [aux_sym_basic_type_token21] = ACTIONS(3905),
    [aux_sym_basic_type_token22] = ACTIONS(3905),
    [aux_sym_basic_type_token48] = ACTIONS(3905),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3905),
    [anon_sym_POUNDif] = ACTIONS(3907),
    [anon_sym_POUNDIF] = ACTIONS(3907),
    [anon_sym_POUNDIf] = ACTIONS(3907),
    [anon_sym_not] = ACTIONS(3905),
    [anon_sym_NOT] = ACTIONS(3905),
    [anon_sym_Not] = ACTIONS(3905),
    [anon_sym_POUNDelif] = ACTIONS(3907),
    [anon_sym_POUNDELIF] = ACTIONS(3907),
    [anon_sym_POUNDElif] = ACTIONS(3907),
    [anon_sym_POUNDelse] = ACTIONS(3907),
    [anon_sym_POUNDELSE] = ACTIONS(3907),
    [anon_sym_POUNDElse] = ACTIONS(3907),
    [anon_sym_POUNDelse2] = ACTIONS(3907),
    [anon_sym_POUNDELSE2] = ACTIONS(3907),
    [anon_sym_POUNDElse2] = ACTIONS(3907),
    [anon_sym_POUNDendif] = ACTIONS(3907),
    [anon_sym_POUNDENDIF] = ACTIONS(3907),
    [anon_sym_POUNDEndif] = ACTIONS(3907),
    [anon_sym_POUNDendif2] = ACTIONS(3907),
    [anon_sym_POUNDENDIF2] = ACTIONS(3907),
    [anon_sym_POUNDEndif2] = ACTIONS(3907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3907),
    [aux_sym__expression_token1] = ACTIONS(3907),
    [aux_sym__expression_token2] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3905),
    [anon_sym_SLASH] = ACTIONS(3905),
    [anon_sym_div] = ACTIONS(3905),
    [anon_sym_DIV] = ACTIONS(3905),
    [anon_sym_Div] = ACTIONS(3905),
    [anon_sym_mod] = ACTIONS(3905),
    [anon_sym_MOD] = ACTIONS(3905),
    [anon_sym_Mod] = ACTIONS(3905),
    [anon_sym_PLUS] = ACTIONS(3905),
    [anon_sym_GT_EQ] = ACTIONS(3907),
    [anon_sym_LT_EQ] = ACTIONS(3907),
    [anon_sym_GT] = ACTIONS(3905),
    [anon_sym_LT] = ACTIONS(3905),
    [anon_sym_LT_GT] = ACTIONS(3907),
    [anon_sym_and] = ACTIONS(3905),
    [anon_sym_AND] = ACTIONS(3905),
    [anon_sym_And] = ACTIONS(3905),
    [anon_sym_or] = ACTIONS(3905),
    [anon_sym_OR] = ACTIONS(3905),
    [anon_sym_Or] = ACTIONS(3905),
    [anon_sym_xor] = ACTIONS(3905),
    [anon_sym_XOR] = ACTIONS(3905),
    [anon_sym_Xor] = ACTIONS(3905),
    [anon_sym_QMARK] = ACTIONS(3907),
    [sym_datetime_literal] = ACTIONS(3907),
    [sym_date_literal] = ACTIONS(3905),
    [sym_time_literal] = ACTIONS(3905),
    [sym_biginteger_literal] = ACTIONS(3907),
    [anon_sym_if] = ACTIONS(3905),
    [anon_sym_IF] = ACTIONS(3905),
    [anon_sym_If] = ACTIONS(3905),
    [anon_sym_else] = ACTIONS(3905),
    [anon_sym_ELSE] = ACTIONS(3905),
    [anon_sym_Else] = ACTIONS(3905),
    [anon_sym_case] = ACTIONS(3905),
    [anon_sym_CASE] = ACTIONS(3905),
    [anon_sym_Case] = ACTIONS(3905),
    [anon_sym_for] = ACTIONS(3905),
    [anon_sym_FOR] = ACTIONS(3905),
    [anon_sym_For] = ACTIONS(3905),
    [anon_sym_foreach] = ACTIONS(3905),
    [anon_sym_FOREACH] = ACTIONS(3905),
    [anon_sym_Foreach] = ACTIONS(3905),
    [anon_sym_while] = ACTIONS(3905),
    [anon_sym_WHILE] = ACTIONS(3905),
    [anon_sym_While] = ACTIONS(3905),
    [anon_sym_repeat] = ACTIONS(3905),
    [anon_sym_REPEAT] = ACTIONS(3905),
    [anon_sym_Repeat] = ACTIONS(3905),
    [anon_sym_exit] = ACTIONS(3905),
    [anon_sym_EXIT] = ACTIONS(3905),
    [anon_sym_Exit] = ACTIONS(3905),
    [anon_sym_continue] = ACTIONS(3905),
    [anon_sym_CONTINUE] = ACTIONS(3905),
    [anon_sym_Continue] = ACTIONS(3905),
    [anon_sym_break] = ACTIONS(3905),
    [anon_sym_BREAK] = ACTIONS(3905),
    [anon_sym_Break] = ACTIONS(3905),
    [anon_sym_with] = ACTIONS(3905),
    [anon_sym_WITH] = ACTIONS(3905),
    [anon_sym_With] = ACTIONS(3905),
    [sym_asserterror_keyword] = ACTIONS(3907),
    [anon_sym_in] = ACTIONS(3905),
    [anon_sym_IN] = ACTIONS(3905),
    [anon_sym_In] = ACTIONS(3905),
    [sym_page_keyword] = ACTIONS(3905),
    [anon_sym_codeunit] = ACTIONS(3905),
    [anon_sym_CODEUNIT] = ACTIONS(3905),
    [anon_sym_Codeunit] = ACTIONS(3905),
    [anon_sym_CodeUnit] = ACTIONS(3905),
    [anon_sym_COdeunit] = ACTIONS(3905),
    [anon_sym_codeUnit] = ACTIONS(3905),
    [sym_report_keyword] = ACTIONS(3905),
    [sym_query_keyword] = ACTIONS(3905),
    [anon_sym_xmlport] = ACTIONS(3905),
    [anon_sym_XMLPORT] = ACTIONS(3905),
    [anon_sym_Xmlport] = ACTIONS(3905),
    [anon_sym_XMLport] = ACTIONS(3905),
    [anon_sym_XMLPort] = ACTIONS(3905),
    [anon_sym_XmlPort] = ACTIONS(3905),
    [anon_sym_enum] = ACTIONS(3905),
    [anon_sym_ENUM] = ACTIONS(3905),
    [anon_sym_Enum] = ACTIONS(3905),
    [anon_sym_eNUM] = ACTIONS(3905),
    [anon_sym_eNum] = ACTIONS(3905),
    [anon_sym_ENum] = ACTIONS(3905),
    [sym_quoted_identifier] = ACTIONS(3907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3907),
    [sym_verbatim_string] = ACTIONS(3907),
    [sym_integer] = ACTIONS(3905),
    [sym_continue_as_identifier] = ACTIONS(3907),
    [sym_preproc_open] = ACTIONS(3907),
    [sym_preproc_close] = ACTIONS(3907),
  },
  [STATE(1849)] = {
    [sym_identifier] = ACTIONS(3909),
    [anon_sym_SEMI] = ACTIONS(3911),
    [anon_sym_DOT] = ACTIONS(3909),
    [anon_sym_EQ] = ACTIONS(3911),
    [anon_sym_DASH] = ACTIONS(3909),
    [aux_sym_boolean_token1] = ACTIONS(3909),
    [aux_sym_boolean_token2] = ACTIONS(3909),
    [sym_decimal] = ACTIONS(3909),
    [anon_sym_LPAREN] = ACTIONS(3911),
    [anon_sym_DOT_DOT] = ACTIONS(3911),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3909),
    [anon_sym_STAR] = ACTIONS(3909),
    [anon_sym_LBRACK] = ACTIONS(3911),
    [aux_sym_record_type_token1] = ACTIONS(3909),
    [aux_sym_basic_type_token21] = ACTIONS(3909),
    [aux_sym_basic_type_token22] = ACTIONS(3909),
    [aux_sym_basic_type_token48] = ACTIONS(3909),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3909),
    [anon_sym_POUNDif] = ACTIONS(3911),
    [anon_sym_POUNDIF] = ACTIONS(3911),
    [anon_sym_POUNDIf] = ACTIONS(3911),
    [anon_sym_not] = ACTIONS(3909),
    [anon_sym_NOT] = ACTIONS(3909),
    [anon_sym_Not] = ACTIONS(3909),
    [anon_sym_POUNDelif] = ACTIONS(3911),
    [anon_sym_POUNDELIF] = ACTIONS(3911),
    [anon_sym_POUNDElif] = ACTIONS(3911),
    [anon_sym_POUNDelse] = ACTIONS(3911),
    [anon_sym_POUNDELSE] = ACTIONS(3911),
    [anon_sym_POUNDElse] = ACTIONS(3911),
    [anon_sym_POUNDelse2] = ACTIONS(3911),
    [anon_sym_POUNDELSE2] = ACTIONS(3911),
    [anon_sym_POUNDElse2] = ACTIONS(3911),
    [anon_sym_POUNDendif] = ACTIONS(3911),
    [anon_sym_POUNDENDIF] = ACTIONS(3911),
    [anon_sym_POUNDEndif] = ACTIONS(3911),
    [anon_sym_POUNDendif2] = ACTIONS(3911),
    [anon_sym_POUNDENDIF2] = ACTIONS(3911),
    [anon_sym_POUNDEndif2] = ACTIONS(3911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3911),
    [aux_sym__expression_token1] = ACTIONS(3911),
    [aux_sym__expression_token2] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3909),
    [anon_sym_SLASH] = ACTIONS(3909),
    [anon_sym_div] = ACTIONS(3909),
    [anon_sym_DIV] = ACTIONS(3909),
    [anon_sym_Div] = ACTIONS(3909),
    [anon_sym_mod] = ACTIONS(3909),
    [anon_sym_MOD] = ACTIONS(3909),
    [anon_sym_Mod] = ACTIONS(3909),
    [anon_sym_PLUS] = ACTIONS(3909),
    [anon_sym_GT_EQ] = ACTIONS(3911),
    [anon_sym_LT_EQ] = ACTIONS(3911),
    [anon_sym_GT] = ACTIONS(3909),
    [anon_sym_LT] = ACTIONS(3909),
    [anon_sym_LT_GT] = ACTIONS(3911),
    [anon_sym_and] = ACTIONS(3909),
    [anon_sym_AND] = ACTIONS(3909),
    [anon_sym_And] = ACTIONS(3909),
    [anon_sym_or] = ACTIONS(3909),
    [anon_sym_OR] = ACTIONS(3909),
    [anon_sym_Or] = ACTIONS(3909),
    [anon_sym_xor] = ACTIONS(3909),
    [anon_sym_XOR] = ACTIONS(3909),
    [anon_sym_Xor] = ACTIONS(3909),
    [anon_sym_QMARK] = ACTIONS(3911),
    [sym_datetime_literal] = ACTIONS(3911),
    [sym_date_literal] = ACTIONS(3909),
    [sym_time_literal] = ACTIONS(3909),
    [sym_biginteger_literal] = ACTIONS(3911),
    [anon_sym_if] = ACTIONS(3909),
    [anon_sym_IF] = ACTIONS(3909),
    [anon_sym_If] = ACTIONS(3909),
    [anon_sym_else] = ACTIONS(3909),
    [anon_sym_ELSE] = ACTIONS(3909),
    [anon_sym_Else] = ACTIONS(3909),
    [anon_sym_case] = ACTIONS(3909),
    [anon_sym_CASE] = ACTIONS(3909),
    [anon_sym_Case] = ACTIONS(3909),
    [anon_sym_for] = ACTIONS(3909),
    [anon_sym_FOR] = ACTIONS(3909),
    [anon_sym_For] = ACTIONS(3909),
    [anon_sym_foreach] = ACTIONS(3909),
    [anon_sym_FOREACH] = ACTIONS(3909),
    [anon_sym_Foreach] = ACTIONS(3909),
    [anon_sym_while] = ACTIONS(3909),
    [anon_sym_WHILE] = ACTIONS(3909),
    [anon_sym_While] = ACTIONS(3909),
    [anon_sym_repeat] = ACTIONS(3909),
    [anon_sym_REPEAT] = ACTIONS(3909),
    [anon_sym_Repeat] = ACTIONS(3909),
    [anon_sym_exit] = ACTIONS(3909),
    [anon_sym_EXIT] = ACTIONS(3909),
    [anon_sym_Exit] = ACTIONS(3909),
    [anon_sym_continue] = ACTIONS(3909),
    [anon_sym_CONTINUE] = ACTIONS(3909),
    [anon_sym_Continue] = ACTIONS(3909),
    [anon_sym_break] = ACTIONS(3909),
    [anon_sym_BREAK] = ACTIONS(3909),
    [anon_sym_Break] = ACTIONS(3909),
    [anon_sym_with] = ACTIONS(3909),
    [anon_sym_WITH] = ACTIONS(3909),
    [anon_sym_With] = ACTIONS(3909),
    [sym_asserterror_keyword] = ACTIONS(3911),
    [anon_sym_in] = ACTIONS(3909),
    [anon_sym_IN] = ACTIONS(3909),
    [anon_sym_In] = ACTIONS(3909),
    [sym_page_keyword] = ACTIONS(3909),
    [anon_sym_codeunit] = ACTIONS(3909),
    [anon_sym_CODEUNIT] = ACTIONS(3909),
    [anon_sym_Codeunit] = ACTIONS(3909),
    [anon_sym_CodeUnit] = ACTIONS(3909),
    [anon_sym_COdeunit] = ACTIONS(3909),
    [anon_sym_codeUnit] = ACTIONS(3909),
    [sym_report_keyword] = ACTIONS(3909),
    [sym_query_keyword] = ACTIONS(3909),
    [anon_sym_xmlport] = ACTIONS(3909),
    [anon_sym_XMLPORT] = ACTIONS(3909),
    [anon_sym_Xmlport] = ACTIONS(3909),
    [anon_sym_XMLport] = ACTIONS(3909),
    [anon_sym_XMLPort] = ACTIONS(3909),
    [anon_sym_XmlPort] = ACTIONS(3909),
    [anon_sym_enum] = ACTIONS(3909),
    [anon_sym_ENUM] = ACTIONS(3909),
    [anon_sym_Enum] = ACTIONS(3909),
    [anon_sym_eNUM] = ACTIONS(3909),
    [anon_sym_eNum] = ACTIONS(3909),
    [anon_sym_ENum] = ACTIONS(3909),
    [sym_quoted_identifier] = ACTIONS(3911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3911),
    [sym_verbatim_string] = ACTIONS(3911),
    [sym_integer] = ACTIONS(3909),
    [sym_continue_as_identifier] = ACTIONS(3911),
    [sym_preproc_open] = ACTIONS(3911),
    [sym_preproc_close] = ACTIONS(3911),
  },
  [STATE(1850)] = {
    [sym_identifier] = ACTIONS(3913),
    [anon_sym_SEMI] = ACTIONS(3915),
    [anon_sym_DOT] = ACTIONS(3913),
    [anon_sym_EQ] = ACTIONS(3915),
    [anon_sym_DASH] = ACTIONS(3913),
    [aux_sym_boolean_token1] = ACTIONS(3913),
    [aux_sym_boolean_token2] = ACTIONS(3913),
    [sym_decimal] = ACTIONS(3913),
    [anon_sym_LPAREN] = ACTIONS(3915),
    [anon_sym_DOT_DOT] = ACTIONS(3915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3913),
    [anon_sym_STAR] = ACTIONS(3913),
    [anon_sym_LBRACK] = ACTIONS(3915),
    [aux_sym_record_type_token1] = ACTIONS(3913),
    [aux_sym_basic_type_token21] = ACTIONS(3913),
    [aux_sym_basic_type_token22] = ACTIONS(3913),
    [aux_sym_basic_type_token48] = ACTIONS(3913),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3913),
    [anon_sym_POUNDif] = ACTIONS(3915),
    [anon_sym_POUNDIF] = ACTIONS(3915),
    [anon_sym_POUNDIf] = ACTIONS(3915),
    [anon_sym_not] = ACTIONS(3913),
    [anon_sym_NOT] = ACTIONS(3913),
    [anon_sym_Not] = ACTIONS(3913),
    [anon_sym_POUNDelif] = ACTIONS(3915),
    [anon_sym_POUNDELIF] = ACTIONS(3915),
    [anon_sym_POUNDElif] = ACTIONS(3915),
    [anon_sym_POUNDelse] = ACTIONS(3915),
    [anon_sym_POUNDELSE] = ACTIONS(3915),
    [anon_sym_POUNDElse] = ACTIONS(3915),
    [anon_sym_POUNDelse2] = ACTIONS(3915),
    [anon_sym_POUNDELSE2] = ACTIONS(3915),
    [anon_sym_POUNDElse2] = ACTIONS(3915),
    [anon_sym_POUNDendif] = ACTIONS(3915),
    [anon_sym_POUNDENDIF] = ACTIONS(3915),
    [anon_sym_POUNDEndif] = ACTIONS(3915),
    [anon_sym_POUNDendif2] = ACTIONS(3915),
    [anon_sym_POUNDENDIF2] = ACTIONS(3915),
    [anon_sym_POUNDEndif2] = ACTIONS(3915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3915),
    [aux_sym__expression_token1] = ACTIONS(3915),
    [aux_sym__expression_token2] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3913),
    [anon_sym_SLASH] = ACTIONS(3913),
    [anon_sym_div] = ACTIONS(3913),
    [anon_sym_DIV] = ACTIONS(3913),
    [anon_sym_Div] = ACTIONS(3913),
    [anon_sym_mod] = ACTIONS(3913),
    [anon_sym_MOD] = ACTIONS(3913),
    [anon_sym_Mod] = ACTIONS(3913),
    [anon_sym_PLUS] = ACTIONS(3913),
    [anon_sym_GT_EQ] = ACTIONS(3915),
    [anon_sym_LT_EQ] = ACTIONS(3915),
    [anon_sym_GT] = ACTIONS(3913),
    [anon_sym_LT] = ACTIONS(3913),
    [anon_sym_LT_GT] = ACTIONS(3915),
    [anon_sym_and] = ACTIONS(3913),
    [anon_sym_AND] = ACTIONS(3913),
    [anon_sym_And] = ACTIONS(3913),
    [anon_sym_or] = ACTIONS(3913),
    [anon_sym_OR] = ACTIONS(3913),
    [anon_sym_Or] = ACTIONS(3913),
    [anon_sym_xor] = ACTIONS(3913),
    [anon_sym_XOR] = ACTIONS(3913),
    [anon_sym_Xor] = ACTIONS(3913),
    [anon_sym_QMARK] = ACTIONS(3915),
    [sym_datetime_literal] = ACTIONS(3915),
    [sym_date_literal] = ACTIONS(3913),
    [sym_time_literal] = ACTIONS(3913),
    [sym_biginteger_literal] = ACTIONS(3915),
    [anon_sym_if] = ACTIONS(3913),
    [anon_sym_IF] = ACTIONS(3913),
    [anon_sym_If] = ACTIONS(3913),
    [anon_sym_else] = ACTIONS(3913),
    [anon_sym_ELSE] = ACTIONS(3913),
    [anon_sym_Else] = ACTIONS(3913),
    [anon_sym_case] = ACTIONS(3913),
    [anon_sym_CASE] = ACTIONS(3913),
    [anon_sym_Case] = ACTIONS(3913),
    [anon_sym_for] = ACTIONS(3913),
    [anon_sym_FOR] = ACTIONS(3913),
    [anon_sym_For] = ACTIONS(3913),
    [anon_sym_foreach] = ACTIONS(3913),
    [anon_sym_FOREACH] = ACTIONS(3913),
    [anon_sym_Foreach] = ACTIONS(3913),
    [anon_sym_while] = ACTIONS(3913),
    [anon_sym_WHILE] = ACTIONS(3913),
    [anon_sym_While] = ACTIONS(3913),
    [anon_sym_repeat] = ACTIONS(3913),
    [anon_sym_REPEAT] = ACTIONS(3913),
    [anon_sym_Repeat] = ACTIONS(3913),
    [anon_sym_exit] = ACTIONS(3913),
    [anon_sym_EXIT] = ACTIONS(3913),
    [anon_sym_Exit] = ACTIONS(3913),
    [anon_sym_continue] = ACTIONS(3913),
    [anon_sym_CONTINUE] = ACTIONS(3913),
    [anon_sym_Continue] = ACTIONS(3913),
    [anon_sym_break] = ACTIONS(3913),
    [anon_sym_BREAK] = ACTIONS(3913),
    [anon_sym_Break] = ACTIONS(3913),
    [anon_sym_with] = ACTIONS(3913),
    [anon_sym_WITH] = ACTIONS(3913),
    [anon_sym_With] = ACTIONS(3913),
    [sym_asserterror_keyword] = ACTIONS(3915),
    [anon_sym_in] = ACTIONS(3913),
    [anon_sym_IN] = ACTIONS(3913),
    [anon_sym_In] = ACTIONS(3913),
    [sym_page_keyword] = ACTIONS(3913),
    [anon_sym_codeunit] = ACTIONS(3913),
    [anon_sym_CODEUNIT] = ACTIONS(3913),
    [anon_sym_Codeunit] = ACTIONS(3913),
    [anon_sym_CodeUnit] = ACTIONS(3913),
    [anon_sym_COdeunit] = ACTIONS(3913),
    [anon_sym_codeUnit] = ACTIONS(3913),
    [sym_report_keyword] = ACTIONS(3913),
    [sym_query_keyword] = ACTIONS(3913),
    [anon_sym_xmlport] = ACTIONS(3913),
    [anon_sym_XMLPORT] = ACTIONS(3913),
    [anon_sym_Xmlport] = ACTIONS(3913),
    [anon_sym_XMLport] = ACTIONS(3913),
    [anon_sym_XMLPort] = ACTIONS(3913),
    [anon_sym_XmlPort] = ACTIONS(3913),
    [anon_sym_enum] = ACTIONS(3913),
    [anon_sym_ENUM] = ACTIONS(3913),
    [anon_sym_Enum] = ACTIONS(3913),
    [anon_sym_eNUM] = ACTIONS(3913),
    [anon_sym_eNum] = ACTIONS(3913),
    [anon_sym_ENum] = ACTIONS(3913),
    [sym_quoted_identifier] = ACTIONS(3915),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3915),
    [sym_verbatim_string] = ACTIONS(3915),
    [sym_integer] = ACTIONS(3913),
    [sym_continue_as_identifier] = ACTIONS(3915),
    [sym_preproc_open] = ACTIONS(3915),
    [sym_preproc_close] = ACTIONS(3915),
  },
  [STATE(1851)] = {
    [sym_identifier] = ACTIONS(3917),
    [anon_sym_SEMI] = ACTIONS(3919),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_EQ] = ACTIONS(3919),
    [anon_sym_DASH] = ACTIONS(3917),
    [aux_sym_boolean_token1] = ACTIONS(3917),
    [aux_sym_boolean_token2] = ACTIONS(3917),
    [sym_decimal] = ACTIONS(3917),
    [anon_sym_LPAREN] = ACTIONS(3919),
    [anon_sym_DOT_DOT] = ACTIONS(3919),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3919),
    [aux_sym_record_type_token1] = ACTIONS(3917),
    [aux_sym_basic_type_token21] = ACTIONS(3917),
    [aux_sym_basic_type_token22] = ACTIONS(3917),
    [aux_sym_basic_type_token48] = ACTIONS(3917),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3917),
    [anon_sym_POUNDif] = ACTIONS(3919),
    [anon_sym_POUNDIF] = ACTIONS(3919),
    [anon_sym_POUNDIf] = ACTIONS(3919),
    [anon_sym_not] = ACTIONS(3917),
    [anon_sym_NOT] = ACTIONS(3917),
    [anon_sym_Not] = ACTIONS(3917),
    [anon_sym_POUNDelif] = ACTIONS(3919),
    [anon_sym_POUNDELIF] = ACTIONS(3919),
    [anon_sym_POUNDElif] = ACTIONS(3919),
    [anon_sym_POUNDelse] = ACTIONS(3919),
    [anon_sym_POUNDELSE] = ACTIONS(3919),
    [anon_sym_POUNDElse] = ACTIONS(3919),
    [anon_sym_POUNDelse2] = ACTIONS(3919),
    [anon_sym_POUNDELSE2] = ACTIONS(3919),
    [anon_sym_POUNDElse2] = ACTIONS(3919),
    [anon_sym_POUNDendif] = ACTIONS(3919),
    [anon_sym_POUNDENDIF] = ACTIONS(3919),
    [anon_sym_POUNDEndif] = ACTIONS(3919),
    [anon_sym_POUNDendif2] = ACTIONS(3919),
    [anon_sym_POUNDENDIF2] = ACTIONS(3919),
    [anon_sym_POUNDEndif2] = ACTIONS(3919),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3919),
    [aux_sym__expression_token1] = ACTIONS(3919),
    [aux_sym__expression_token2] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_div] = ACTIONS(3917),
    [anon_sym_DIV] = ACTIONS(3917),
    [anon_sym_Div] = ACTIONS(3917),
    [anon_sym_mod] = ACTIONS(3917),
    [anon_sym_MOD] = ACTIONS(3917),
    [anon_sym_Mod] = ACTIONS(3917),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3919),
    [anon_sym_LT_EQ] = ACTIONS(3919),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_LT_GT] = ACTIONS(3919),
    [anon_sym_and] = ACTIONS(3917),
    [anon_sym_AND] = ACTIONS(3917),
    [anon_sym_And] = ACTIONS(3917),
    [anon_sym_or] = ACTIONS(3917),
    [anon_sym_OR] = ACTIONS(3917),
    [anon_sym_Or] = ACTIONS(3917),
    [anon_sym_xor] = ACTIONS(3917),
    [anon_sym_XOR] = ACTIONS(3917),
    [anon_sym_Xor] = ACTIONS(3917),
    [anon_sym_QMARK] = ACTIONS(3919),
    [sym_datetime_literal] = ACTIONS(3919),
    [sym_date_literal] = ACTIONS(3917),
    [sym_time_literal] = ACTIONS(3917),
    [sym_biginteger_literal] = ACTIONS(3919),
    [anon_sym_if] = ACTIONS(3917),
    [anon_sym_IF] = ACTIONS(3917),
    [anon_sym_If] = ACTIONS(3917),
    [anon_sym_else] = ACTIONS(3917),
    [anon_sym_ELSE] = ACTIONS(3917),
    [anon_sym_Else] = ACTIONS(3917),
    [anon_sym_case] = ACTIONS(3917),
    [anon_sym_CASE] = ACTIONS(3917),
    [anon_sym_Case] = ACTIONS(3917),
    [anon_sym_for] = ACTIONS(3917),
    [anon_sym_FOR] = ACTIONS(3917),
    [anon_sym_For] = ACTIONS(3917),
    [anon_sym_foreach] = ACTIONS(3917),
    [anon_sym_FOREACH] = ACTIONS(3917),
    [anon_sym_Foreach] = ACTIONS(3917),
    [anon_sym_while] = ACTIONS(3917),
    [anon_sym_WHILE] = ACTIONS(3917),
    [anon_sym_While] = ACTIONS(3917),
    [anon_sym_repeat] = ACTIONS(3917),
    [anon_sym_REPEAT] = ACTIONS(3917),
    [anon_sym_Repeat] = ACTIONS(3917),
    [anon_sym_exit] = ACTIONS(3917),
    [anon_sym_EXIT] = ACTIONS(3917),
    [anon_sym_Exit] = ACTIONS(3917),
    [anon_sym_continue] = ACTIONS(3917),
    [anon_sym_CONTINUE] = ACTIONS(3917),
    [anon_sym_Continue] = ACTIONS(3917),
    [anon_sym_break] = ACTIONS(3917),
    [anon_sym_BREAK] = ACTIONS(3917),
    [anon_sym_Break] = ACTIONS(3917),
    [anon_sym_with] = ACTIONS(3917),
    [anon_sym_WITH] = ACTIONS(3917),
    [anon_sym_With] = ACTIONS(3917),
    [sym_asserterror_keyword] = ACTIONS(3919),
    [anon_sym_in] = ACTIONS(3917),
    [anon_sym_IN] = ACTIONS(3917),
    [anon_sym_In] = ACTIONS(3917),
    [sym_page_keyword] = ACTIONS(3917),
    [anon_sym_codeunit] = ACTIONS(3917),
    [anon_sym_CODEUNIT] = ACTIONS(3917),
    [anon_sym_Codeunit] = ACTIONS(3917),
    [anon_sym_CodeUnit] = ACTIONS(3917),
    [anon_sym_COdeunit] = ACTIONS(3917),
    [anon_sym_codeUnit] = ACTIONS(3917),
    [sym_report_keyword] = ACTIONS(3917),
    [sym_query_keyword] = ACTIONS(3917),
    [anon_sym_xmlport] = ACTIONS(3917),
    [anon_sym_XMLPORT] = ACTIONS(3917),
    [anon_sym_Xmlport] = ACTIONS(3917),
    [anon_sym_XMLport] = ACTIONS(3917),
    [anon_sym_XMLPort] = ACTIONS(3917),
    [anon_sym_XmlPort] = ACTIONS(3917),
    [anon_sym_enum] = ACTIONS(3917),
    [anon_sym_ENUM] = ACTIONS(3917),
    [anon_sym_Enum] = ACTIONS(3917),
    [anon_sym_eNUM] = ACTIONS(3917),
    [anon_sym_eNum] = ACTIONS(3917),
    [anon_sym_ENum] = ACTIONS(3917),
    [sym_quoted_identifier] = ACTIONS(3919),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3919),
    [sym_verbatim_string] = ACTIONS(3919),
    [sym_integer] = ACTIONS(3917),
    [sym_continue_as_identifier] = ACTIONS(3919),
    [sym_preproc_open] = ACTIONS(3919),
    [sym_preproc_close] = ACTIONS(3919),
  },
  [STATE(1852)] = {
    [sym_identifier] = ACTIONS(3921),
    [anon_sym_SEMI] = ACTIONS(3923),
    [anon_sym_DOT] = ACTIONS(3921),
    [anon_sym_EQ] = ACTIONS(3923),
    [anon_sym_DASH] = ACTIONS(3921),
    [aux_sym_boolean_token1] = ACTIONS(3921),
    [aux_sym_boolean_token2] = ACTIONS(3921),
    [sym_decimal] = ACTIONS(3921),
    [anon_sym_LPAREN] = ACTIONS(3923),
    [anon_sym_DOT_DOT] = ACTIONS(3923),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3921),
    [anon_sym_STAR] = ACTIONS(3921),
    [anon_sym_LBRACK] = ACTIONS(3923),
    [aux_sym_record_type_token1] = ACTIONS(3921),
    [aux_sym_basic_type_token21] = ACTIONS(3921),
    [aux_sym_basic_type_token22] = ACTIONS(3921),
    [aux_sym_basic_type_token48] = ACTIONS(3921),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3921),
    [anon_sym_POUNDif] = ACTIONS(3923),
    [anon_sym_POUNDIF] = ACTIONS(3923),
    [anon_sym_POUNDIf] = ACTIONS(3923),
    [anon_sym_not] = ACTIONS(3921),
    [anon_sym_NOT] = ACTIONS(3921),
    [anon_sym_Not] = ACTIONS(3921),
    [anon_sym_POUNDelif] = ACTIONS(3923),
    [anon_sym_POUNDELIF] = ACTIONS(3923),
    [anon_sym_POUNDElif] = ACTIONS(3923),
    [anon_sym_POUNDelse] = ACTIONS(3923),
    [anon_sym_POUNDELSE] = ACTIONS(3923),
    [anon_sym_POUNDElse] = ACTIONS(3923),
    [anon_sym_POUNDelse2] = ACTIONS(3923),
    [anon_sym_POUNDELSE2] = ACTIONS(3923),
    [anon_sym_POUNDElse2] = ACTIONS(3923),
    [anon_sym_POUNDendif] = ACTIONS(3923),
    [anon_sym_POUNDENDIF] = ACTIONS(3923),
    [anon_sym_POUNDEndif] = ACTIONS(3923),
    [anon_sym_POUNDendif2] = ACTIONS(3923),
    [anon_sym_POUNDENDIF2] = ACTIONS(3923),
    [anon_sym_POUNDEndif2] = ACTIONS(3923),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3923),
    [aux_sym__expression_token1] = ACTIONS(3923),
    [aux_sym__expression_token2] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3921),
    [anon_sym_SLASH] = ACTIONS(3921),
    [anon_sym_div] = ACTIONS(3921),
    [anon_sym_DIV] = ACTIONS(3921),
    [anon_sym_Div] = ACTIONS(3921),
    [anon_sym_mod] = ACTIONS(3921),
    [anon_sym_MOD] = ACTIONS(3921),
    [anon_sym_Mod] = ACTIONS(3921),
    [anon_sym_PLUS] = ACTIONS(3921),
    [anon_sym_GT_EQ] = ACTIONS(3923),
    [anon_sym_LT_EQ] = ACTIONS(3923),
    [anon_sym_GT] = ACTIONS(3921),
    [anon_sym_LT] = ACTIONS(3921),
    [anon_sym_LT_GT] = ACTIONS(3923),
    [anon_sym_and] = ACTIONS(3921),
    [anon_sym_AND] = ACTIONS(3921),
    [anon_sym_And] = ACTIONS(3921),
    [anon_sym_or] = ACTIONS(3921),
    [anon_sym_OR] = ACTIONS(3921),
    [anon_sym_Or] = ACTIONS(3921),
    [anon_sym_xor] = ACTIONS(3921),
    [anon_sym_XOR] = ACTIONS(3921),
    [anon_sym_Xor] = ACTIONS(3921),
    [anon_sym_QMARK] = ACTIONS(3923),
    [sym_datetime_literal] = ACTIONS(3923),
    [sym_date_literal] = ACTIONS(3921),
    [sym_time_literal] = ACTIONS(3921),
    [sym_biginteger_literal] = ACTIONS(3923),
    [anon_sym_if] = ACTIONS(3921),
    [anon_sym_IF] = ACTIONS(3921),
    [anon_sym_If] = ACTIONS(3921),
    [anon_sym_else] = ACTIONS(3921),
    [anon_sym_ELSE] = ACTIONS(3921),
    [anon_sym_Else] = ACTIONS(3921),
    [anon_sym_case] = ACTIONS(3921),
    [anon_sym_CASE] = ACTIONS(3921),
    [anon_sym_Case] = ACTIONS(3921),
    [anon_sym_for] = ACTIONS(3921),
    [anon_sym_FOR] = ACTIONS(3921),
    [anon_sym_For] = ACTIONS(3921),
    [anon_sym_foreach] = ACTIONS(3921),
    [anon_sym_FOREACH] = ACTIONS(3921),
    [anon_sym_Foreach] = ACTIONS(3921),
    [anon_sym_while] = ACTIONS(3921),
    [anon_sym_WHILE] = ACTIONS(3921),
    [anon_sym_While] = ACTIONS(3921),
    [anon_sym_repeat] = ACTIONS(3921),
    [anon_sym_REPEAT] = ACTIONS(3921),
    [anon_sym_Repeat] = ACTIONS(3921),
    [anon_sym_exit] = ACTIONS(3921),
    [anon_sym_EXIT] = ACTIONS(3921),
    [anon_sym_Exit] = ACTIONS(3921),
    [anon_sym_continue] = ACTIONS(3921),
    [anon_sym_CONTINUE] = ACTIONS(3921),
    [anon_sym_Continue] = ACTIONS(3921),
    [anon_sym_break] = ACTIONS(3921),
    [anon_sym_BREAK] = ACTIONS(3921),
    [anon_sym_Break] = ACTIONS(3921),
    [anon_sym_with] = ACTIONS(3921),
    [anon_sym_WITH] = ACTIONS(3921),
    [anon_sym_With] = ACTIONS(3921),
    [sym_asserterror_keyword] = ACTIONS(3923),
    [anon_sym_in] = ACTIONS(3921),
    [anon_sym_IN] = ACTIONS(3921),
    [anon_sym_In] = ACTIONS(3921),
    [sym_page_keyword] = ACTIONS(3921),
    [anon_sym_codeunit] = ACTIONS(3921),
    [anon_sym_CODEUNIT] = ACTIONS(3921),
    [anon_sym_Codeunit] = ACTIONS(3921),
    [anon_sym_CodeUnit] = ACTIONS(3921),
    [anon_sym_COdeunit] = ACTIONS(3921),
    [anon_sym_codeUnit] = ACTIONS(3921),
    [sym_report_keyword] = ACTIONS(3921),
    [sym_query_keyword] = ACTIONS(3921),
    [anon_sym_xmlport] = ACTIONS(3921),
    [anon_sym_XMLPORT] = ACTIONS(3921),
    [anon_sym_Xmlport] = ACTIONS(3921),
    [anon_sym_XMLport] = ACTIONS(3921),
    [anon_sym_XMLPort] = ACTIONS(3921),
    [anon_sym_XmlPort] = ACTIONS(3921),
    [anon_sym_enum] = ACTIONS(3921),
    [anon_sym_ENUM] = ACTIONS(3921),
    [anon_sym_Enum] = ACTIONS(3921),
    [anon_sym_eNUM] = ACTIONS(3921),
    [anon_sym_eNum] = ACTIONS(3921),
    [anon_sym_ENum] = ACTIONS(3921),
    [sym_quoted_identifier] = ACTIONS(3923),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3923),
    [sym_verbatim_string] = ACTIONS(3923),
    [sym_integer] = ACTIONS(3921),
    [sym_continue_as_identifier] = ACTIONS(3923),
    [sym_preproc_open] = ACTIONS(3923),
    [sym_preproc_close] = ACTIONS(3923),
  },
  [STATE(1853)] = {
    [sym_identifier] = ACTIONS(3925),
    [anon_sym_SEMI] = ACTIONS(3927),
    [anon_sym_DOT] = ACTIONS(3925),
    [anon_sym_EQ] = ACTIONS(3927),
    [anon_sym_DASH] = ACTIONS(3925),
    [aux_sym_boolean_token1] = ACTIONS(3925),
    [aux_sym_boolean_token2] = ACTIONS(3925),
    [sym_decimal] = ACTIONS(3925),
    [anon_sym_LPAREN] = ACTIONS(3927),
    [anon_sym_DOT_DOT] = ACTIONS(3927),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3925),
    [anon_sym_STAR] = ACTIONS(3925),
    [anon_sym_LBRACK] = ACTIONS(3929),
    [aux_sym_record_type_token1] = ACTIONS(3925),
    [aux_sym_basic_type_token21] = ACTIONS(3925),
    [aux_sym_basic_type_token22] = ACTIONS(3925),
    [aux_sym_basic_type_token48] = ACTIONS(3925),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3925),
    [anon_sym_POUNDif] = ACTIONS(3927),
    [anon_sym_POUNDIF] = ACTIONS(3927),
    [anon_sym_POUNDIf] = ACTIONS(3927),
    [anon_sym_not] = ACTIONS(3925),
    [anon_sym_NOT] = ACTIONS(3925),
    [anon_sym_Not] = ACTIONS(3925),
    [anon_sym_POUNDelif] = ACTIONS(3927),
    [anon_sym_POUNDELIF] = ACTIONS(3927),
    [anon_sym_POUNDElif] = ACTIONS(3927),
    [anon_sym_POUNDelse] = ACTIONS(3927),
    [anon_sym_POUNDELSE] = ACTIONS(3927),
    [anon_sym_POUNDElse] = ACTIONS(3927),
    [anon_sym_POUNDelse2] = ACTIONS(3927),
    [anon_sym_POUNDELSE2] = ACTIONS(3927),
    [anon_sym_POUNDElse2] = ACTIONS(3927),
    [anon_sym_POUNDendif] = ACTIONS(3927),
    [anon_sym_POUNDENDIF] = ACTIONS(3927),
    [anon_sym_POUNDEndif] = ACTIONS(3927),
    [anon_sym_POUNDendif2] = ACTIONS(3927),
    [anon_sym_POUNDENDIF2] = ACTIONS(3927),
    [anon_sym_POUNDEndif2] = ACTIONS(3927),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3927),
    [aux_sym__expression_token1] = ACTIONS(3927),
    [aux_sym__expression_token2] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3925),
    [anon_sym_SLASH] = ACTIONS(3925),
    [anon_sym_div] = ACTIONS(3925),
    [anon_sym_DIV] = ACTIONS(3925),
    [anon_sym_Div] = ACTIONS(3925),
    [anon_sym_mod] = ACTIONS(3925),
    [anon_sym_MOD] = ACTIONS(3925),
    [anon_sym_Mod] = ACTIONS(3925),
    [anon_sym_PLUS] = ACTIONS(3925),
    [anon_sym_GT_EQ] = ACTIONS(3927),
    [anon_sym_LT_EQ] = ACTIONS(3927),
    [anon_sym_GT] = ACTIONS(3925),
    [anon_sym_LT] = ACTIONS(3925),
    [anon_sym_LT_GT] = ACTIONS(3927),
    [anon_sym_and] = ACTIONS(3925),
    [anon_sym_AND] = ACTIONS(3925),
    [anon_sym_And] = ACTIONS(3925),
    [anon_sym_or] = ACTIONS(3925),
    [anon_sym_OR] = ACTIONS(3925),
    [anon_sym_Or] = ACTIONS(3925),
    [anon_sym_xor] = ACTIONS(3925),
    [anon_sym_XOR] = ACTIONS(3925),
    [anon_sym_Xor] = ACTIONS(3925),
    [anon_sym_QMARK] = ACTIONS(3927),
    [sym_datetime_literal] = ACTIONS(3927),
    [sym_date_literal] = ACTIONS(3925),
    [sym_time_literal] = ACTIONS(3925),
    [sym_biginteger_literal] = ACTIONS(3927),
    [anon_sym_if] = ACTIONS(3925),
    [anon_sym_IF] = ACTIONS(3925),
    [anon_sym_If] = ACTIONS(3925),
    [anon_sym_else] = ACTIONS(3925),
    [anon_sym_ELSE] = ACTIONS(3925),
    [anon_sym_Else] = ACTIONS(3925),
    [anon_sym_case] = ACTIONS(3925),
    [anon_sym_CASE] = ACTIONS(3925),
    [anon_sym_Case] = ACTIONS(3925),
    [anon_sym_for] = ACTIONS(3925),
    [anon_sym_FOR] = ACTIONS(3925),
    [anon_sym_For] = ACTIONS(3925),
    [anon_sym_foreach] = ACTIONS(3925),
    [anon_sym_FOREACH] = ACTIONS(3925),
    [anon_sym_Foreach] = ACTIONS(3925),
    [anon_sym_while] = ACTIONS(3925),
    [anon_sym_WHILE] = ACTIONS(3925),
    [anon_sym_While] = ACTIONS(3925),
    [anon_sym_repeat] = ACTIONS(3925),
    [anon_sym_REPEAT] = ACTIONS(3925),
    [anon_sym_Repeat] = ACTIONS(3925),
    [anon_sym_exit] = ACTIONS(3925),
    [anon_sym_EXIT] = ACTIONS(3925),
    [anon_sym_Exit] = ACTIONS(3925),
    [anon_sym_continue] = ACTIONS(3925),
    [anon_sym_CONTINUE] = ACTIONS(3925),
    [anon_sym_Continue] = ACTIONS(3925),
    [anon_sym_break] = ACTIONS(3925),
    [anon_sym_BREAK] = ACTIONS(3925),
    [anon_sym_Break] = ACTIONS(3925),
    [anon_sym_with] = ACTIONS(3925),
    [anon_sym_WITH] = ACTIONS(3925),
    [anon_sym_With] = ACTIONS(3925),
    [sym_asserterror_keyword] = ACTIONS(3927),
    [anon_sym_in] = ACTIONS(3925),
    [anon_sym_IN] = ACTIONS(3925),
    [anon_sym_In] = ACTIONS(3925),
    [sym_page_keyword] = ACTIONS(3925),
    [anon_sym_codeunit] = ACTIONS(3925),
    [anon_sym_CODEUNIT] = ACTIONS(3925),
    [anon_sym_Codeunit] = ACTIONS(3925),
    [anon_sym_CodeUnit] = ACTIONS(3925),
    [anon_sym_COdeunit] = ACTIONS(3925),
    [anon_sym_codeUnit] = ACTIONS(3925),
    [sym_report_keyword] = ACTIONS(3925),
    [sym_query_keyword] = ACTIONS(3925),
    [anon_sym_xmlport] = ACTIONS(3925),
    [anon_sym_XMLPORT] = ACTIONS(3925),
    [anon_sym_Xmlport] = ACTIONS(3925),
    [anon_sym_XMLport] = ACTIONS(3925),
    [anon_sym_XMLPort] = ACTIONS(3925),
    [anon_sym_XmlPort] = ACTIONS(3925),
    [anon_sym_enum] = ACTIONS(3925),
    [anon_sym_ENUM] = ACTIONS(3925),
    [anon_sym_Enum] = ACTIONS(3925),
    [anon_sym_eNUM] = ACTIONS(3925),
    [anon_sym_eNum] = ACTIONS(3925),
    [anon_sym_ENum] = ACTIONS(3925),
    [sym_quoted_identifier] = ACTIONS(3927),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3927),
    [sym_verbatim_string] = ACTIONS(3927),
    [sym_integer] = ACTIONS(3925),
    [sym_continue_as_identifier] = ACTIONS(3927),
    [sym_preproc_open] = ACTIONS(3927),
    [sym_preproc_close] = ACTIONS(3927),
  },
  [STATE(1854)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(1855)] = {
    [sym_identifier] = ACTIONS(3931),
    [anon_sym_SEMI] = ACTIONS(3933),
    [anon_sym_DOT] = ACTIONS(3931),
    [anon_sym_EQ] = ACTIONS(3933),
    [anon_sym_DASH] = ACTIONS(3931),
    [aux_sym_boolean_token1] = ACTIONS(3931),
    [aux_sym_boolean_token2] = ACTIONS(3931),
    [sym_decimal] = ACTIONS(3931),
    [anon_sym_LPAREN] = ACTIONS(3933),
    [anon_sym_DOT_DOT] = ACTIONS(3933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3931),
    [anon_sym_STAR] = ACTIONS(3931),
    [anon_sym_LBRACK] = ACTIONS(3935),
    [aux_sym_record_type_token1] = ACTIONS(3931),
    [aux_sym_basic_type_token21] = ACTIONS(3931),
    [aux_sym_basic_type_token22] = ACTIONS(3931),
    [aux_sym_basic_type_token48] = ACTIONS(3931),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3931),
    [anon_sym_POUNDif] = ACTIONS(3933),
    [anon_sym_POUNDIF] = ACTIONS(3933),
    [anon_sym_POUNDIf] = ACTIONS(3933),
    [anon_sym_not] = ACTIONS(3931),
    [anon_sym_NOT] = ACTIONS(3931),
    [anon_sym_Not] = ACTIONS(3931),
    [anon_sym_POUNDelif] = ACTIONS(3933),
    [anon_sym_POUNDELIF] = ACTIONS(3933),
    [anon_sym_POUNDElif] = ACTIONS(3933),
    [anon_sym_POUNDelse] = ACTIONS(3933),
    [anon_sym_POUNDELSE] = ACTIONS(3933),
    [anon_sym_POUNDElse] = ACTIONS(3933),
    [anon_sym_POUNDelse2] = ACTIONS(3933),
    [anon_sym_POUNDELSE2] = ACTIONS(3933),
    [anon_sym_POUNDElse2] = ACTIONS(3933),
    [anon_sym_POUNDendif] = ACTIONS(3933),
    [anon_sym_POUNDENDIF] = ACTIONS(3933),
    [anon_sym_POUNDEndif] = ACTIONS(3933),
    [anon_sym_POUNDendif2] = ACTIONS(3933),
    [anon_sym_POUNDENDIF2] = ACTIONS(3933),
    [anon_sym_POUNDEndif2] = ACTIONS(3933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3933),
    [aux_sym__expression_token1] = ACTIONS(3933),
    [aux_sym__expression_token2] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3931),
    [anon_sym_SLASH] = ACTIONS(3931),
    [anon_sym_div] = ACTIONS(3931),
    [anon_sym_DIV] = ACTIONS(3931),
    [anon_sym_Div] = ACTIONS(3931),
    [anon_sym_mod] = ACTIONS(3931),
    [anon_sym_MOD] = ACTIONS(3931),
    [anon_sym_Mod] = ACTIONS(3931),
    [anon_sym_PLUS] = ACTIONS(3931),
    [anon_sym_GT_EQ] = ACTIONS(3933),
    [anon_sym_LT_EQ] = ACTIONS(3933),
    [anon_sym_GT] = ACTIONS(3931),
    [anon_sym_LT] = ACTIONS(3931),
    [anon_sym_LT_GT] = ACTIONS(3933),
    [anon_sym_and] = ACTIONS(3931),
    [anon_sym_AND] = ACTIONS(3931),
    [anon_sym_And] = ACTIONS(3931),
    [anon_sym_or] = ACTIONS(3931),
    [anon_sym_OR] = ACTIONS(3931),
    [anon_sym_Or] = ACTIONS(3931),
    [anon_sym_xor] = ACTIONS(3931),
    [anon_sym_XOR] = ACTIONS(3931),
    [anon_sym_Xor] = ACTIONS(3931),
    [anon_sym_QMARK] = ACTIONS(3933),
    [sym_datetime_literal] = ACTIONS(3933),
    [sym_date_literal] = ACTIONS(3931),
    [sym_time_literal] = ACTIONS(3931),
    [sym_biginteger_literal] = ACTIONS(3933),
    [anon_sym_if] = ACTIONS(3931),
    [anon_sym_IF] = ACTIONS(3931),
    [anon_sym_If] = ACTIONS(3931),
    [anon_sym_else] = ACTIONS(3931),
    [anon_sym_ELSE] = ACTIONS(3931),
    [anon_sym_Else] = ACTIONS(3931),
    [anon_sym_case] = ACTIONS(3931),
    [anon_sym_CASE] = ACTIONS(3931),
    [anon_sym_Case] = ACTIONS(3931),
    [anon_sym_for] = ACTIONS(3931),
    [anon_sym_FOR] = ACTIONS(3931),
    [anon_sym_For] = ACTIONS(3931),
    [anon_sym_foreach] = ACTIONS(3931),
    [anon_sym_FOREACH] = ACTIONS(3931),
    [anon_sym_Foreach] = ACTIONS(3931),
    [anon_sym_while] = ACTIONS(3931),
    [anon_sym_WHILE] = ACTIONS(3931),
    [anon_sym_While] = ACTIONS(3931),
    [anon_sym_repeat] = ACTIONS(3931),
    [anon_sym_REPEAT] = ACTIONS(3931),
    [anon_sym_Repeat] = ACTIONS(3931),
    [anon_sym_exit] = ACTIONS(3931),
    [anon_sym_EXIT] = ACTIONS(3931),
    [anon_sym_Exit] = ACTIONS(3931),
    [anon_sym_continue] = ACTIONS(3931),
    [anon_sym_CONTINUE] = ACTIONS(3931),
    [anon_sym_Continue] = ACTIONS(3931),
    [anon_sym_break] = ACTIONS(3931),
    [anon_sym_BREAK] = ACTIONS(3931),
    [anon_sym_Break] = ACTIONS(3931),
    [anon_sym_with] = ACTIONS(3931),
    [anon_sym_WITH] = ACTIONS(3931),
    [anon_sym_With] = ACTIONS(3931),
    [sym_asserterror_keyword] = ACTIONS(3933),
    [anon_sym_in] = ACTIONS(3931),
    [anon_sym_IN] = ACTIONS(3931),
    [anon_sym_In] = ACTIONS(3931),
    [sym_page_keyword] = ACTIONS(3931),
    [anon_sym_codeunit] = ACTIONS(3931),
    [anon_sym_CODEUNIT] = ACTIONS(3931),
    [anon_sym_Codeunit] = ACTIONS(3931),
    [anon_sym_CodeUnit] = ACTIONS(3931),
    [anon_sym_COdeunit] = ACTIONS(3931),
    [anon_sym_codeUnit] = ACTIONS(3931),
    [sym_report_keyword] = ACTIONS(3931),
    [sym_query_keyword] = ACTIONS(3931),
    [anon_sym_xmlport] = ACTIONS(3931),
    [anon_sym_XMLPORT] = ACTIONS(3931),
    [anon_sym_Xmlport] = ACTIONS(3931),
    [anon_sym_XMLport] = ACTIONS(3931),
    [anon_sym_XMLPort] = ACTIONS(3931),
    [anon_sym_XmlPort] = ACTIONS(3931),
    [anon_sym_enum] = ACTIONS(3931),
    [anon_sym_ENUM] = ACTIONS(3931),
    [anon_sym_Enum] = ACTIONS(3931),
    [anon_sym_eNUM] = ACTIONS(3931),
    [anon_sym_eNum] = ACTIONS(3931),
    [anon_sym_ENum] = ACTIONS(3931),
    [sym_quoted_identifier] = ACTIONS(3933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3933),
    [sym_verbatim_string] = ACTIONS(3933),
    [sym_integer] = ACTIONS(3931),
    [sym_continue_as_identifier] = ACTIONS(3933),
    [sym_preproc_open] = ACTIONS(3933),
    [sym_preproc_close] = ACTIONS(3933),
  },
  [STATE(1856)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(1857)] = {
    [sym_identifier] = ACTIONS(3937),
    [anon_sym_SEMI] = ACTIONS(3939),
    [anon_sym_DOT] = ACTIONS(3937),
    [anon_sym_EQ] = ACTIONS(3939),
    [anon_sym_DASH] = ACTIONS(3937),
    [aux_sym_boolean_token1] = ACTIONS(3937),
    [aux_sym_boolean_token2] = ACTIONS(3937),
    [sym_decimal] = ACTIONS(3937),
    [anon_sym_LPAREN] = ACTIONS(3939),
    [anon_sym_DOT_DOT] = ACTIONS(3939),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3937),
    [anon_sym_STAR] = ACTIONS(3937),
    [anon_sym_LBRACK] = ACTIONS(3939),
    [aux_sym_record_type_token1] = ACTIONS(3937),
    [aux_sym_basic_type_token21] = ACTIONS(3937),
    [aux_sym_basic_type_token22] = ACTIONS(3937),
    [aux_sym_basic_type_token48] = ACTIONS(3937),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3937),
    [anon_sym_POUNDif] = ACTIONS(3939),
    [anon_sym_POUNDIF] = ACTIONS(3939),
    [anon_sym_POUNDIf] = ACTIONS(3939),
    [anon_sym_not] = ACTIONS(3937),
    [anon_sym_NOT] = ACTIONS(3937),
    [anon_sym_Not] = ACTIONS(3937),
    [anon_sym_POUNDelif] = ACTIONS(3939),
    [anon_sym_POUNDELIF] = ACTIONS(3939),
    [anon_sym_POUNDElif] = ACTIONS(3939),
    [anon_sym_POUNDelse] = ACTIONS(3939),
    [anon_sym_POUNDELSE] = ACTIONS(3939),
    [anon_sym_POUNDElse] = ACTIONS(3939),
    [anon_sym_POUNDelse2] = ACTIONS(3939),
    [anon_sym_POUNDELSE2] = ACTIONS(3939),
    [anon_sym_POUNDElse2] = ACTIONS(3939),
    [anon_sym_POUNDendif] = ACTIONS(3939),
    [anon_sym_POUNDENDIF] = ACTIONS(3939),
    [anon_sym_POUNDEndif] = ACTIONS(3939),
    [anon_sym_POUNDendif2] = ACTIONS(3939),
    [anon_sym_POUNDENDIF2] = ACTIONS(3939),
    [anon_sym_POUNDEndif2] = ACTIONS(3939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3939),
    [aux_sym__expression_token1] = ACTIONS(3939),
    [aux_sym__expression_token2] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3937),
    [anon_sym_SLASH] = ACTIONS(3937),
    [anon_sym_div] = ACTIONS(3937),
    [anon_sym_DIV] = ACTIONS(3937),
    [anon_sym_Div] = ACTIONS(3937),
    [anon_sym_mod] = ACTIONS(3937),
    [anon_sym_MOD] = ACTIONS(3937),
    [anon_sym_Mod] = ACTIONS(3937),
    [anon_sym_PLUS] = ACTIONS(3937),
    [anon_sym_GT_EQ] = ACTIONS(3939),
    [anon_sym_LT_EQ] = ACTIONS(3939),
    [anon_sym_GT] = ACTIONS(3937),
    [anon_sym_LT] = ACTIONS(3937),
    [anon_sym_LT_GT] = ACTIONS(3939),
    [anon_sym_and] = ACTIONS(3937),
    [anon_sym_AND] = ACTIONS(3937),
    [anon_sym_And] = ACTIONS(3937),
    [anon_sym_or] = ACTIONS(3937),
    [anon_sym_OR] = ACTIONS(3937),
    [anon_sym_Or] = ACTIONS(3937),
    [anon_sym_xor] = ACTIONS(3937),
    [anon_sym_XOR] = ACTIONS(3937),
    [anon_sym_Xor] = ACTIONS(3937),
    [anon_sym_QMARK] = ACTIONS(3939),
    [sym_datetime_literal] = ACTIONS(3939),
    [sym_date_literal] = ACTIONS(3937),
    [sym_time_literal] = ACTIONS(3937),
    [sym_biginteger_literal] = ACTIONS(3939),
    [anon_sym_if] = ACTIONS(3937),
    [anon_sym_IF] = ACTIONS(3937),
    [anon_sym_If] = ACTIONS(3937),
    [anon_sym_else] = ACTIONS(3937),
    [anon_sym_ELSE] = ACTIONS(3937),
    [anon_sym_Else] = ACTIONS(3937),
    [anon_sym_case] = ACTIONS(3937),
    [anon_sym_CASE] = ACTIONS(3937),
    [anon_sym_Case] = ACTIONS(3937),
    [anon_sym_for] = ACTIONS(3937),
    [anon_sym_FOR] = ACTIONS(3937),
    [anon_sym_For] = ACTIONS(3937),
    [anon_sym_foreach] = ACTIONS(3937),
    [anon_sym_FOREACH] = ACTIONS(3937),
    [anon_sym_Foreach] = ACTIONS(3937),
    [anon_sym_while] = ACTIONS(3937),
    [anon_sym_WHILE] = ACTIONS(3937),
    [anon_sym_While] = ACTIONS(3937),
    [anon_sym_repeat] = ACTIONS(3937),
    [anon_sym_REPEAT] = ACTIONS(3937),
    [anon_sym_Repeat] = ACTIONS(3937),
    [anon_sym_exit] = ACTIONS(3937),
    [anon_sym_EXIT] = ACTIONS(3937),
    [anon_sym_Exit] = ACTIONS(3937),
    [anon_sym_continue] = ACTIONS(3937),
    [anon_sym_CONTINUE] = ACTIONS(3937),
    [anon_sym_Continue] = ACTIONS(3937),
    [anon_sym_break] = ACTIONS(3937),
    [anon_sym_BREAK] = ACTIONS(3937),
    [anon_sym_Break] = ACTIONS(3937),
    [anon_sym_with] = ACTIONS(3937),
    [anon_sym_WITH] = ACTIONS(3937),
    [anon_sym_With] = ACTIONS(3937),
    [sym_asserterror_keyword] = ACTIONS(3939),
    [anon_sym_in] = ACTIONS(3937),
    [anon_sym_IN] = ACTIONS(3937),
    [anon_sym_In] = ACTIONS(3937),
    [sym_page_keyword] = ACTIONS(3937),
    [anon_sym_codeunit] = ACTIONS(3937),
    [anon_sym_CODEUNIT] = ACTIONS(3937),
    [anon_sym_Codeunit] = ACTIONS(3937),
    [anon_sym_CodeUnit] = ACTIONS(3937),
    [anon_sym_COdeunit] = ACTIONS(3937),
    [anon_sym_codeUnit] = ACTIONS(3937),
    [sym_report_keyword] = ACTIONS(3937),
    [sym_query_keyword] = ACTIONS(3937),
    [anon_sym_xmlport] = ACTIONS(3937),
    [anon_sym_XMLPORT] = ACTIONS(3937),
    [anon_sym_Xmlport] = ACTIONS(3937),
    [anon_sym_XMLport] = ACTIONS(3937),
    [anon_sym_XMLPort] = ACTIONS(3937),
    [anon_sym_XmlPort] = ACTIONS(3937),
    [anon_sym_enum] = ACTIONS(3937),
    [anon_sym_ENUM] = ACTIONS(3937),
    [anon_sym_Enum] = ACTIONS(3937),
    [anon_sym_eNUM] = ACTIONS(3937),
    [anon_sym_eNum] = ACTIONS(3937),
    [anon_sym_ENum] = ACTIONS(3937),
    [sym_quoted_identifier] = ACTIONS(3939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3939),
    [sym_verbatim_string] = ACTIONS(3939),
    [sym_integer] = ACTIONS(3937),
    [sym_continue_as_identifier] = ACTIONS(3939),
    [sym_preproc_open] = ACTIONS(3939),
    [sym_preproc_close] = ACTIONS(3939),
  },
  [STATE(1858)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(1859)] = {
    [sym_identifier] = ACTIONS(3941),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_DOT] = ACTIONS(3941),
    [anon_sym_EQ] = ACTIONS(3943),
    [anon_sym_DASH] = ACTIONS(3941),
    [aux_sym_boolean_token1] = ACTIONS(3941),
    [aux_sym_boolean_token2] = ACTIONS(3941),
    [sym_decimal] = ACTIONS(3941),
    [anon_sym_LPAREN] = ACTIONS(3943),
    [anon_sym_DOT_DOT] = ACTIONS(3943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3941),
    [anon_sym_STAR] = ACTIONS(3941),
    [anon_sym_LBRACK] = ACTIONS(3943),
    [aux_sym_record_type_token1] = ACTIONS(3941),
    [aux_sym_basic_type_token21] = ACTIONS(3941),
    [aux_sym_basic_type_token22] = ACTIONS(3941),
    [aux_sym_basic_type_token48] = ACTIONS(3941),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3941),
    [anon_sym_POUNDif] = ACTIONS(3943),
    [anon_sym_POUNDIF] = ACTIONS(3943),
    [anon_sym_POUNDIf] = ACTIONS(3943),
    [anon_sym_not] = ACTIONS(3941),
    [anon_sym_NOT] = ACTIONS(3941),
    [anon_sym_Not] = ACTIONS(3941),
    [anon_sym_POUNDelif] = ACTIONS(3943),
    [anon_sym_POUNDELIF] = ACTIONS(3943),
    [anon_sym_POUNDElif] = ACTIONS(3943),
    [anon_sym_POUNDelse] = ACTIONS(3943),
    [anon_sym_POUNDELSE] = ACTIONS(3943),
    [anon_sym_POUNDElse] = ACTIONS(3943),
    [anon_sym_POUNDelse2] = ACTIONS(3943),
    [anon_sym_POUNDELSE2] = ACTIONS(3943),
    [anon_sym_POUNDElse2] = ACTIONS(3943),
    [anon_sym_POUNDendif] = ACTIONS(3943),
    [anon_sym_POUNDENDIF] = ACTIONS(3943),
    [anon_sym_POUNDEndif] = ACTIONS(3943),
    [anon_sym_POUNDendif2] = ACTIONS(3943),
    [anon_sym_POUNDENDIF2] = ACTIONS(3943),
    [anon_sym_POUNDEndif2] = ACTIONS(3943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3943),
    [aux_sym__expression_token1] = ACTIONS(3943),
    [aux_sym__expression_token2] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3941),
    [anon_sym_SLASH] = ACTIONS(3941),
    [anon_sym_div] = ACTIONS(3941),
    [anon_sym_DIV] = ACTIONS(3941),
    [anon_sym_Div] = ACTIONS(3941),
    [anon_sym_mod] = ACTIONS(3941),
    [anon_sym_MOD] = ACTIONS(3941),
    [anon_sym_Mod] = ACTIONS(3941),
    [anon_sym_PLUS] = ACTIONS(3941),
    [anon_sym_GT_EQ] = ACTIONS(3943),
    [anon_sym_LT_EQ] = ACTIONS(3943),
    [anon_sym_GT] = ACTIONS(3941),
    [anon_sym_LT] = ACTIONS(3941),
    [anon_sym_LT_GT] = ACTIONS(3943),
    [anon_sym_and] = ACTIONS(3941),
    [anon_sym_AND] = ACTIONS(3941),
    [anon_sym_And] = ACTIONS(3941),
    [anon_sym_or] = ACTIONS(3941),
    [anon_sym_OR] = ACTIONS(3941),
    [anon_sym_Or] = ACTIONS(3941),
    [anon_sym_xor] = ACTIONS(3941),
    [anon_sym_XOR] = ACTIONS(3941),
    [anon_sym_Xor] = ACTIONS(3941),
    [anon_sym_QMARK] = ACTIONS(3943),
    [sym_datetime_literal] = ACTIONS(3943),
    [sym_date_literal] = ACTIONS(3941),
    [sym_time_literal] = ACTIONS(3941),
    [sym_biginteger_literal] = ACTIONS(3943),
    [anon_sym_if] = ACTIONS(3941),
    [anon_sym_IF] = ACTIONS(3941),
    [anon_sym_If] = ACTIONS(3941),
    [anon_sym_else] = ACTIONS(3941),
    [anon_sym_ELSE] = ACTIONS(3941),
    [anon_sym_Else] = ACTIONS(3941),
    [anon_sym_case] = ACTIONS(3941),
    [anon_sym_CASE] = ACTIONS(3941),
    [anon_sym_Case] = ACTIONS(3941),
    [anon_sym_for] = ACTIONS(3941),
    [anon_sym_FOR] = ACTIONS(3941),
    [anon_sym_For] = ACTIONS(3941),
    [anon_sym_foreach] = ACTIONS(3941),
    [anon_sym_FOREACH] = ACTIONS(3941),
    [anon_sym_Foreach] = ACTIONS(3941),
    [anon_sym_while] = ACTIONS(3941),
    [anon_sym_WHILE] = ACTIONS(3941),
    [anon_sym_While] = ACTIONS(3941),
    [anon_sym_repeat] = ACTIONS(3941),
    [anon_sym_REPEAT] = ACTIONS(3941),
    [anon_sym_Repeat] = ACTIONS(3941),
    [anon_sym_exit] = ACTIONS(3941),
    [anon_sym_EXIT] = ACTIONS(3941),
    [anon_sym_Exit] = ACTIONS(3941),
    [anon_sym_continue] = ACTIONS(3941),
    [anon_sym_CONTINUE] = ACTIONS(3941),
    [anon_sym_Continue] = ACTIONS(3941),
    [anon_sym_break] = ACTIONS(3941),
    [anon_sym_BREAK] = ACTIONS(3941),
    [anon_sym_Break] = ACTIONS(3941),
    [anon_sym_with] = ACTIONS(3941),
    [anon_sym_WITH] = ACTIONS(3941),
    [anon_sym_With] = ACTIONS(3941),
    [sym_asserterror_keyword] = ACTIONS(3943),
    [anon_sym_in] = ACTIONS(3941),
    [anon_sym_IN] = ACTIONS(3941),
    [anon_sym_In] = ACTIONS(3941),
    [sym_page_keyword] = ACTIONS(3941),
    [anon_sym_codeunit] = ACTIONS(3941),
    [anon_sym_CODEUNIT] = ACTIONS(3941),
    [anon_sym_Codeunit] = ACTIONS(3941),
    [anon_sym_CodeUnit] = ACTIONS(3941),
    [anon_sym_COdeunit] = ACTIONS(3941),
    [anon_sym_codeUnit] = ACTIONS(3941),
    [sym_report_keyword] = ACTIONS(3941),
    [sym_query_keyword] = ACTIONS(3941),
    [anon_sym_xmlport] = ACTIONS(3941),
    [anon_sym_XMLPORT] = ACTIONS(3941),
    [anon_sym_Xmlport] = ACTIONS(3941),
    [anon_sym_XMLport] = ACTIONS(3941),
    [anon_sym_XMLPort] = ACTIONS(3941),
    [anon_sym_XmlPort] = ACTIONS(3941),
    [anon_sym_enum] = ACTIONS(3941),
    [anon_sym_ENUM] = ACTIONS(3941),
    [anon_sym_Enum] = ACTIONS(3941),
    [anon_sym_eNUM] = ACTIONS(3941),
    [anon_sym_eNum] = ACTIONS(3941),
    [anon_sym_ENum] = ACTIONS(3941),
    [sym_quoted_identifier] = ACTIONS(3943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3943),
    [sym_verbatim_string] = ACTIONS(3943),
    [sym_integer] = ACTIONS(3941),
    [sym_continue_as_identifier] = ACTIONS(3943),
    [sym_preproc_open] = ACTIONS(3943),
    [sym_preproc_close] = ACTIONS(3943),
  },
  [STATE(1860)] = {
    [sym_identifier] = ACTIONS(3945),
    [anon_sym_SEMI] = ACTIONS(3947),
    [anon_sym_DOT] = ACTIONS(3945),
    [anon_sym_EQ] = ACTIONS(3947),
    [anon_sym_DASH] = ACTIONS(3945),
    [aux_sym_boolean_token1] = ACTIONS(3945),
    [aux_sym_boolean_token2] = ACTIONS(3945),
    [sym_decimal] = ACTIONS(3945),
    [anon_sym_LPAREN] = ACTIONS(3947),
    [anon_sym_DOT_DOT] = ACTIONS(3947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3945),
    [anon_sym_STAR] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(3947),
    [aux_sym_record_type_token1] = ACTIONS(3945),
    [aux_sym_basic_type_token21] = ACTIONS(3945),
    [aux_sym_basic_type_token22] = ACTIONS(3945),
    [aux_sym_basic_type_token48] = ACTIONS(3945),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3945),
    [anon_sym_POUNDif] = ACTIONS(3947),
    [anon_sym_POUNDIF] = ACTIONS(3947),
    [anon_sym_POUNDIf] = ACTIONS(3947),
    [anon_sym_not] = ACTIONS(3945),
    [anon_sym_NOT] = ACTIONS(3945),
    [anon_sym_Not] = ACTIONS(3945),
    [anon_sym_POUNDelif] = ACTIONS(3947),
    [anon_sym_POUNDELIF] = ACTIONS(3947),
    [anon_sym_POUNDElif] = ACTIONS(3947),
    [anon_sym_POUNDelse] = ACTIONS(3947),
    [anon_sym_POUNDELSE] = ACTIONS(3947),
    [anon_sym_POUNDElse] = ACTIONS(3947),
    [anon_sym_POUNDelse2] = ACTIONS(3947),
    [anon_sym_POUNDELSE2] = ACTIONS(3947),
    [anon_sym_POUNDElse2] = ACTIONS(3947),
    [anon_sym_POUNDendif] = ACTIONS(3947),
    [anon_sym_POUNDENDIF] = ACTIONS(3947),
    [anon_sym_POUNDEndif] = ACTIONS(3947),
    [anon_sym_POUNDendif2] = ACTIONS(3947),
    [anon_sym_POUNDENDIF2] = ACTIONS(3947),
    [anon_sym_POUNDEndif2] = ACTIONS(3947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3947),
    [aux_sym__expression_token1] = ACTIONS(3947),
    [aux_sym__expression_token2] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3945),
    [anon_sym_SLASH] = ACTIONS(3945),
    [anon_sym_div] = ACTIONS(3945),
    [anon_sym_DIV] = ACTIONS(3945),
    [anon_sym_Div] = ACTIONS(3945),
    [anon_sym_mod] = ACTIONS(3945),
    [anon_sym_MOD] = ACTIONS(3945),
    [anon_sym_Mod] = ACTIONS(3945),
    [anon_sym_PLUS] = ACTIONS(3945),
    [anon_sym_GT_EQ] = ACTIONS(3947),
    [anon_sym_LT_EQ] = ACTIONS(3947),
    [anon_sym_GT] = ACTIONS(3945),
    [anon_sym_LT] = ACTIONS(3945),
    [anon_sym_LT_GT] = ACTIONS(3947),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_AND] = ACTIONS(3945),
    [anon_sym_And] = ACTIONS(3945),
    [anon_sym_or] = ACTIONS(3945),
    [anon_sym_OR] = ACTIONS(3945),
    [anon_sym_Or] = ACTIONS(3945),
    [anon_sym_xor] = ACTIONS(3945),
    [anon_sym_XOR] = ACTIONS(3945),
    [anon_sym_Xor] = ACTIONS(3945),
    [anon_sym_QMARK] = ACTIONS(3947),
    [sym_datetime_literal] = ACTIONS(3947),
    [sym_date_literal] = ACTIONS(3945),
    [sym_time_literal] = ACTIONS(3945),
    [sym_biginteger_literal] = ACTIONS(3947),
    [anon_sym_if] = ACTIONS(3945),
    [anon_sym_IF] = ACTIONS(3945),
    [anon_sym_If] = ACTIONS(3945),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_ELSE] = ACTIONS(3945),
    [anon_sym_Else] = ACTIONS(3945),
    [anon_sym_case] = ACTIONS(3945),
    [anon_sym_CASE] = ACTIONS(3945),
    [anon_sym_Case] = ACTIONS(3945),
    [anon_sym_for] = ACTIONS(3945),
    [anon_sym_FOR] = ACTIONS(3945),
    [anon_sym_For] = ACTIONS(3945),
    [anon_sym_foreach] = ACTIONS(3945),
    [anon_sym_FOREACH] = ACTIONS(3945),
    [anon_sym_Foreach] = ACTIONS(3945),
    [anon_sym_while] = ACTIONS(3945),
    [anon_sym_WHILE] = ACTIONS(3945),
    [anon_sym_While] = ACTIONS(3945),
    [anon_sym_repeat] = ACTIONS(3945),
    [anon_sym_REPEAT] = ACTIONS(3945),
    [anon_sym_Repeat] = ACTIONS(3945),
    [anon_sym_exit] = ACTIONS(3945),
    [anon_sym_EXIT] = ACTIONS(3945),
    [anon_sym_Exit] = ACTIONS(3945),
    [anon_sym_continue] = ACTIONS(3945),
    [anon_sym_CONTINUE] = ACTIONS(3945),
    [anon_sym_Continue] = ACTIONS(3945),
    [anon_sym_break] = ACTIONS(3945),
    [anon_sym_BREAK] = ACTIONS(3945),
    [anon_sym_Break] = ACTIONS(3945),
    [anon_sym_with] = ACTIONS(3945),
    [anon_sym_WITH] = ACTIONS(3945),
    [anon_sym_With] = ACTIONS(3945),
    [sym_asserterror_keyword] = ACTIONS(3947),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_IN] = ACTIONS(3945),
    [anon_sym_In] = ACTIONS(3945),
    [sym_page_keyword] = ACTIONS(3945),
    [anon_sym_codeunit] = ACTIONS(3945),
    [anon_sym_CODEUNIT] = ACTIONS(3945),
    [anon_sym_Codeunit] = ACTIONS(3945),
    [anon_sym_CodeUnit] = ACTIONS(3945),
    [anon_sym_COdeunit] = ACTIONS(3945),
    [anon_sym_codeUnit] = ACTIONS(3945),
    [sym_report_keyword] = ACTIONS(3945),
    [sym_query_keyword] = ACTIONS(3945),
    [anon_sym_xmlport] = ACTIONS(3945),
    [anon_sym_XMLPORT] = ACTIONS(3945),
    [anon_sym_Xmlport] = ACTIONS(3945),
    [anon_sym_XMLport] = ACTIONS(3945),
    [anon_sym_XMLPort] = ACTIONS(3945),
    [anon_sym_XmlPort] = ACTIONS(3945),
    [anon_sym_enum] = ACTIONS(3945),
    [anon_sym_ENUM] = ACTIONS(3945),
    [anon_sym_Enum] = ACTIONS(3945),
    [anon_sym_eNUM] = ACTIONS(3945),
    [anon_sym_eNum] = ACTIONS(3945),
    [anon_sym_ENum] = ACTIONS(3945),
    [sym_quoted_identifier] = ACTIONS(3947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3947),
    [sym_verbatim_string] = ACTIONS(3947),
    [sym_integer] = ACTIONS(3945),
    [sym_continue_as_identifier] = ACTIONS(3947),
    [sym_preproc_open] = ACTIONS(3947),
    [sym_preproc_close] = ACTIONS(3947),
  },
  [STATE(1861)] = {
    [sym__property_value] = STATE(17209),
    [sym_decimal_range_value] = STATE(17209),
    [sym_signed_integer_list] = STATE(17209),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(17209),
    [sym_property_expression] = STATE(17209),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(17209),
    [sym_ml_value_list] = STATE(17209),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(17209),
    [sym_lookup_formula] = STATE(17209),
    [sym_aggregate_formula] = STATE(17209),
    [sym_where_clause] = STATE(17209),
    [sym_sorting_value] = STATE(17209),
    [sym_link_value_list] = STATE(17209),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(17209),
    [sym_preproc_conditional_table_relation] = STATE(9489),
    [sym_table_relation_expression] = STATE(14695),
    [sym_if_table_relation] = STATE(9490),
    [sym_simple_table_relation] = STATE(14951),
    [sym_tabledata_permission_list] = STATE(9491),
    [sym_preproc_conditional_permissions] = STATE(5939),
    [sym_tabledata_permission] = STATE(7115),
    [sym_order_by_list] = STATE(17209),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(17209),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(17209),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(14760),
    [sym_preproc_if] = STATE(2068),
    [sym_assignment_expression] = STATE(8821),
    [sym__expression] = STATE(8821),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8821),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8821),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8201),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8821),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8821),
    [sym_codeunit_keyword] = STATE(6847),
    [sym_xmlport_keyword] = STATE(6847),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(13389),
    [sym_keyword_as_identifier] = STATE(13000),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(5939),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3949),
    [anon_sym_SEMI] = ACTIONS(3951),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(3963),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(3967),
    [aux_sym_tabledata_permission_token1] = ACTIONS(3969),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3971),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(3975),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(3963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3963),
    [aux_sym_separator_action_token1] = ACTIONS(3963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3963),
    [aux_sym_type_declaration_token1] = ACTIONS(3963),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(3987),
    [sym_table_keyword] = ACTIONS(3989),
    [sym_page_keyword] = ACTIONS(3991),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3991),
    [sym_query_keyword] = ACTIONS(3991),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(3963),
    [sym_dataset_keyword] = ACTIONS(3963),
    [sym_quoted_identifier] = ACTIONS(3995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4001),
    [sym_continue_as_identifier] = ACTIONS(3987),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1862)] = {
    [sym__property_value] = STATE(16768),
    [sym_decimal_range_value] = STATE(16768),
    [sym_signed_integer_list] = STATE(16768),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(16768),
    [sym_property_expression] = STATE(16768),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(16768),
    [sym_ml_value_list] = STATE(16768),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(16768),
    [sym_lookup_formula] = STATE(16768),
    [sym_aggregate_formula] = STATE(16768),
    [sym_where_clause] = STATE(16768),
    [sym_sorting_value] = STATE(16768),
    [sym_link_value_list] = STATE(16768),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(16768),
    [sym_preproc_conditional_table_relation] = STATE(7589),
    [sym_table_relation_expression] = STATE(14747),
    [sym_if_table_relation] = STATE(7590),
    [sym_simple_table_relation] = STATE(14951),
    [sym_tabledata_permission_list] = STATE(7591),
    [sym_preproc_conditional_permissions] = STATE(4067),
    [sym_tabledata_permission] = STATE(4891),
    [sym_order_by_list] = STATE(16768),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(16768),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(16768),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(14760),
    [sym_preproc_if] = STATE(2047),
    [sym_assignment_expression] = STATE(8821),
    [sym__expression] = STATE(8821),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8821),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8821),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8201),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8821),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8821),
    [sym_codeunit_keyword] = STATE(6851),
    [sym_xmlport_keyword] = STATE(6851),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(13389),
    [sym_keyword_as_identifier] = STATE(13000),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4067),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3949),
    [anon_sym_SEMI] = ACTIONS(4003),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(3963),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4005),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4007),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4009),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(3975),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(3963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3963),
    [aux_sym_separator_action_token1] = ACTIONS(3963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3963),
    [aux_sym_type_declaration_token1] = ACTIONS(3963),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(3987),
    [sym_table_keyword] = ACTIONS(4011),
    [sym_page_keyword] = ACTIONS(4013),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4013),
    [sym_query_keyword] = ACTIONS(4013),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(3963),
    [sym_dataset_keyword] = ACTIONS(3963),
    [sym_quoted_identifier] = ACTIONS(3995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4001),
    [sym_continue_as_identifier] = ACTIONS(3987),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1863)] = {
    [sym__property_value] = STATE(17851),
    [sym_decimal_range_value] = STATE(17851),
    [sym_signed_integer_list] = STATE(17851),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(17851),
    [sym_property_expression] = STATE(17851),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(17851),
    [sym_ml_value_list] = STATE(17851),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(17851),
    [sym_lookup_formula] = STATE(17851),
    [sym_aggregate_formula] = STATE(17851),
    [sym_where_clause] = STATE(17851),
    [sym_sorting_value] = STATE(17851),
    [sym_link_value_list] = STATE(17851),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(17851),
    [sym_preproc_conditional_table_relation] = STATE(6887),
    [sym_table_relation_expression] = STATE(14743),
    [sym_if_table_relation] = STATE(6888),
    [sym_simple_table_relation] = STATE(14951),
    [sym_tabledata_permission_list] = STATE(6889),
    [sym_preproc_conditional_permissions] = STATE(3952),
    [sym_tabledata_permission] = STATE(4228),
    [sym_order_by_list] = STATE(17851),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(17851),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(17851),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(14760),
    [sym_preproc_if] = STATE(2054),
    [sym_assignment_expression] = STATE(8821),
    [sym__expression] = STATE(8821),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8821),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8821),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8201),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8821),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8821),
    [sym_codeunit_keyword] = STATE(6786),
    [sym_xmlport_keyword] = STATE(6786),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(13389),
    [sym_keyword_as_identifier] = STATE(13000),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(3952),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3949),
    [anon_sym_SEMI] = ACTIONS(4015),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(3963),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4017),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4019),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4021),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(3975),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(3963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3963),
    [aux_sym_separator_action_token1] = ACTIONS(3963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3963),
    [aux_sym_type_declaration_token1] = ACTIONS(3963),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(3987),
    [sym_table_keyword] = ACTIONS(4023),
    [sym_page_keyword] = ACTIONS(4025),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4025),
    [sym_query_keyword] = ACTIONS(4025),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(3963),
    [sym_dataset_keyword] = ACTIONS(3963),
    [sym_quoted_identifier] = ACTIONS(3995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4001),
    [sym_continue_as_identifier] = ACTIONS(3987),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1864)] = {
    [sym__property_value] = STATE(17154),
    [sym_decimal_range_value] = STATE(17154),
    [sym_signed_integer_list] = STATE(17154),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(17154),
    [sym_property_expression] = STATE(17154),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(17154),
    [sym_ml_value_list] = STATE(17154),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(17154),
    [sym_lookup_formula] = STATE(17154),
    [sym_aggregate_formula] = STATE(17154),
    [sym_where_clause] = STATE(17154),
    [sym_sorting_value] = STATE(17154),
    [sym_link_value_list] = STATE(17154),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(17154),
    [sym_preproc_conditional_table_relation] = STATE(5157),
    [sym_table_relation_expression] = STATE(14694),
    [sym_if_table_relation] = STATE(5158),
    [sym_simple_table_relation] = STATE(14951),
    [sym_tabledata_permission_list] = STATE(5159),
    [sym_preproc_conditional_permissions] = STATE(3584),
    [sym_tabledata_permission] = STATE(3688),
    [sym_order_by_list] = STATE(17154),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(17154),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(17154),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(14760),
    [sym_preproc_if] = STATE(2082),
    [sym_assignment_expression] = STATE(8821),
    [sym__expression] = STATE(8821),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8821),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8821),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8201),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8821),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8821),
    [sym_codeunit_keyword] = STATE(6849),
    [sym_xmlport_keyword] = STATE(6849),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(13389),
    [sym_keyword_as_identifier] = STATE(13000),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(3584),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3949),
    [anon_sym_SEMI] = ACTIONS(4027),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(3963),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4029),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4031),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4033),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(3975),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(3963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3963),
    [aux_sym_separator_action_token1] = ACTIONS(3963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3963),
    [aux_sym_type_declaration_token1] = ACTIONS(3963),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(3987),
    [sym_table_keyword] = ACTIONS(4035),
    [sym_page_keyword] = ACTIONS(4037),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4037),
    [sym_query_keyword] = ACTIONS(4037),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(3963),
    [sym_dataset_keyword] = ACTIONS(3963),
    [sym_quoted_identifier] = ACTIONS(3995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4001),
    [sym_continue_as_identifier] = ACTIONS(3987),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1865)] = {
    [sym__property_value] = STATE(18137),
    [sym_decimal_range_value] = STATE(18137),
    [sym_signed_integer_list] = STATE(18137),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(18137),
    [sym_property_expression] = STATE(18137),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(18137),
    [sym_ml_value_list] = STATE(18137),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(18137),
    [sym_lookup_formula] = STATE(18137),
    [sym_aggregate_formula] = STATE(18137),
    [sym_where_clause] = STATE(18137),
    [sym_sorting_value] = STATE(18137),
    [sym_link_value_list] = STATE(18137),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(18137),
    [sym_preproc_conditional_table_relation] = STATE(17344),
    [sym_table_relation_expression] = STATE(17348),
    [sym_if_table_relation] = STATE(17302),
    [sym_simple_table_relation] = STATE(17302),
    [sym_tabledata_permission_list] = STATE(18137),
    [sym_preproc_conditional_permissions] = STATE(10012),
    [sym_tabledata_permission] = STATE(10240),
    [sym_order_by_list] = STATE(18137),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(18137),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(18137),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(15111),
    [sym_preproc_if] = STATE(2072),
    [sym_assignment_expression] = STATE(8837),
    [sym__expression] = STATE(8837),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8837),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8837),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8382),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8837),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8837),
    [sym_codeunit_keyword] = STATE(6813),
    [sym_xmlport_keyword] = STATE(6813),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(14851),
    [sym_keyword_as_identifier] = STATE(14936),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(10012),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(4039),
    [anon_sym_SEMI] = ACTIONS(4041),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4045),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4047),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4049),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4051),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(4053),
    [sym_table_keyword] = ACTIONS(4055),
    [sym_page_keyword] = ACTIONS(4057),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4057),
    [sym_query_keyword] = ACTIONS(4057),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(4059),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4061),
    [sym_continue_as_identifier] = ACTIONS(4053),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1866)] = {
    [sym__property_value] = STATE(17154),
    [sym_decimal_range_value] = STATE(17154),
    [sym_signed_integer_list] = STATE(17154),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(17154),
    [sym_property_expression] = STATE(17154),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(17154),
    [sym_ml_value_list] = STATE(17154),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(17154),
    [sym_lookup_formula] = STATE(17154),
    [sym_aggregate_formula] = STATE(17154),
    [sym_where_clause] = STATE(17154),
    [sym_sorting_value] = STATE(17154),
    [sym_link_value_list] = STATE(17154),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(17154),
    [sym_preproc_conditional_table_relation] = STATE(5157),
    [sym_table_relation_expression] = STATE(14712),
    [sym_if_table_relation] = STATE(5158),
    [sym_simple_table_relation] = STATE(14951),
    [sym_tabledata_permission_list] = STATE(5159),
    [sym_preproc_conditional_permissions] = STATE(4308),
    [sym_tabledata_permission] = STATE(5160),
    [sym_order_by_list] = STATE(17154),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(17154),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(17154),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(14760),
    [sym_preproc_if] = STATE(2069),
    [sym_assignment_expression] = STATE(8821),
    [sym__expression] = STATE(8821),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8821),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8821),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8201),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8821),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8821),
    [sym_codeunit_keyword] = STATE(6767),
    [sym_xmlport_keyword] = STATE(6767),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(13389),
    [sym_keyword_as_identifier] = STATE(13000),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4308),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3949),
    [anon_sym_SEMI] = ACTIONS(4027),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(3963),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4063),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4065),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4067),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(3975),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(3963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3963),
    [aux_sym_separator_action_token1] = ACTIONS(3963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3963),
    [aux_sym_type_declaration_token1] = ACTIONS(3963),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(3987),
    [sym_table_keyword] = ACTIONS(4069),
    [sym_page_keyword] = ACTIONS(4071),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4071),
    [sym_query_keyword] = ACTIONS(4071),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(3963),
    [sym_dataset_keyword] = ACTIONS(3963),
    [sym_quoted_identifier] = ACTIONS(3995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4001),
    [sym_continue_as_identifier] = ACTIONS(3987),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1867)] = {
    [sym__property_value] = STATE(16582),
    [sym_decimal_range_value] = STATE(16582),
    [sym_signed_integer_list] = STATE(16582),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(16582),
    [sym_property_expression] = STATE(16582),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(16582),
    [sym_ml_value_list] = STATE(16582),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(16582),
    [sym_lookup_formula] = STATE(16582),
    [sym_aggregate_formula] = STATE(16582),
    [sym_where_clause] = STATE(16582),
    [sym_sorting_value] = STATE(16582),
    [sym_link_value_list] = STATE(16582),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(16582),
    [sym_preproc_conditional_table_relation] = STATE(17344),
    [sym_table_relation_expression] = STATE(17348),
    [sym_if_table_relation] = STATE(17302),
    [sym_simple_table_relation] = STATE(17302),
    [sym_tabledata_permission_list] = STATE(16582),
    [sym_preproc_conditional_permissions] = STATE(10012),
    [sym_tabledata_permission] = STATE(10240),
    [sym_order_by_list] = STATE(16582),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(16582),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(16582),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(15111),
    [sym_preproc_if] = STATE(2072),
    [sym_assignment_expression] = STATE(8837),
    [sym__expression] = STATE(8837),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8837),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8837),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8382),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8837),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8837),
    [sym_codeunit_keyword] = STATE(6813),
    [sym_xmlport_keyword] = STATE(6813),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(14851),
    [sym_keyword_as_identifier] = STATE(14936),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(10012),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(4039),
    [anon_sym_SEMI] = ACTIONS(4073),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4045),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4047),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4049),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4051),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(4053),
    [sym_table_keyword] = ACTIONS(4055),
    [sym_page_keyword] = ACTIONS(4057),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4057),
    [sym_query_keyword] = ACTIONS(4057),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(4059),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4061),
    [sym_continue_as_identifier] = ACTIONS(4053),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1868)] = {
    [sym_argument_list] = STATE(1833),
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(4075),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(3687),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelif] = ACTIONS(3683),
    [anon_sym_POUNDELIF] = ACTIONS(3683),
    [anon_sym_POUNDElif] = ACTIONS(3683),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [anon_sym_POUNDendif] = ACTIONS(3683),
    [anon_sym_POUNDENDIF] = ACTIONS(3683),
    [anon_sym_POUNDEndif] = ACTIONS(3683),
    [anon_sym_POUNDendif2] = ACTIONS(3683),
    [anon_sym_POUNDENDIF2] = ACTIONS(3683),
    [anon_sym_POUNDEndif2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_IF] = ACTIONS(3681),
    [anon_sym_If] = ACTIONS(3681),
    [anon_sym_case] = ACTIONS(3681),
    [anon_sym_CASE] = ACTIONS(3681),
    [anon_sym_Case] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_FOR] = ACTIONS(3681),
    [anon_sym_For] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_FOREACH] = ACTIONS(3681),
    [anon_sym_Foreach] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_WHILE] = ACTIONS(3681),
    [anon_sym_While] = ACTIONS(3681),
    [anon_sym_repeat] = ACTIONS(3681),
    [anon_sym_REPEAT] = ACTIONS(3681),
    [anon_sym_Repeat] = ACTIONS(3681),
    [anon_sym_exit] = ACTIONS(3681),
    [anon_sym_EXIT] = ACTIONS(3681),
    [anon_sym_Exit] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_CONTINUE] = ACTIONS(3681),
    [anon_sym_Continue] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_BREAK] = ACTIONS(3681),
    [anon_sym_Break] = ACTIONS(3681),
    [anon_sym_with] = ACTIONS(3681),
    [anon_sym_WITH] = ACTIONS(3681),
    [anon_sym_With] = ACTIONS(3681),
    [sym_asserterror_keyword] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
    [sym_preproc_close] = ACTIONS(3683),
  },
  [STATE(1869)] = {
    [sym__property_value] = STATE(17295),
    [sym_decimal_range_value] = STATE(17295),
    [sym_signed_integer_list] = STATE(17295),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(17295),
    [sym_property_expression] = STATE(17295),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(17295),
    [sym_ml_value_list] = STATE(17295),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(17295),
    [sym_lookup_formula] = STATE(17295),
    [sym_aggregate_formula] = STATE(17295),
    [sym_where_clause] = STATE(17295),
    [sym_sorting_value] = STATE(17295),
    [sym_link_value_list] = STATE(17295),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(17295),
    [sym_preproc_conditional_table_relation] = STATE(17344),
    [sym_table_relation_expression] = STATE(17348),
    [sym_if_table_relation] = STATE(17302),
    [sym_simple_table_relation] = STATE(17302),
    [sym_tabledata_permission_list] = STATE(17295),
    [sym_preproc_conditional_permissions] = STATE(10012),
    [sym_tabledata_permission] = STATE(10240),
    [sym_order_by_list] = STATE(17295),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(17295),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(17295),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(15111),
    [sym_preproc_if] = STATE(2072),
    [sym_assignment_expression] = STATE(8837),
    [sym__expression] = STATE(8837),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8837),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8837),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8382),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8837),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8837),
    [sym_codeunit_keyword] = STATE(6813),
    [sym_xmlport_keyword] = STATE(6813),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(14851),
    [sym_keyword_as_identifier] = STATE(14936),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(10012),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(4039),
    [anon_sym_SEMI] = ACTIONS(4077),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4045),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4047),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4049),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4051),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(4053),
    [sym_table_keyword] = ACTIONS(4055),
    [sym_page_keyword] = ACTIONS(4057),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4057),
    [sym_query_keyword] = ACTIONS(4057),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(4059),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4061),
    [sym_continue_as_identifier] = ACTIONS(4053),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1870)] = {
    [sym__property_value] = STATE(17268),
    [sym_decimal_range_value] = STATE(17268),
    [sym_signed_integer_list] = STATE(17268),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(17268),
    [sym_property_expression] = STATE(17268),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(17268),
    [sym_ml_value_list] = STATE(17268),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(17268),
    [sym_lookup_formula] = STATE(17268),
    [sym_aggregate_formula] = STATE(17268),
    [sym_where_clause] = STATE(17268),
    [sym_sorting_value] = STATE(17268),
    [sym_link_value_list] = STATE(17268),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(17268),
    [sym_preproc_conditional_table_relation] = STATE(6393),
    [sym_table_relation_expression] = STATE(14686),
    [sym_if_table_relation] = STATE(6471),
    [sym_simple_table_relation] = STATE(14951),
    [sym_tabledata_permission_list] = STATE(6474),
    [sym_preproc_conditional_permissions] = STATE(6493),
    [sym_tabledata_permission] = STATE(7230),
    [sym_order_by_list] = STATE(17268),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(17268),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(17268),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(14760),
    [sym_preproc_if] = STATE(2083),
    [sym_assignment_expression] = STATE(8821),
    [sym__expression] = STATE(8821),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8821),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8821),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8201),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8821),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8821),
    [sym_codeunit_keyword] = STATE(6879),
    [sym_xmlport_keyword] = STATE(6879),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(13389),
    [sym_keyword_as_identifier] = STATE(13000),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(6493),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3949),
    [anon_sym_SEMI] = ACTIONS(4079),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(3963),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4081),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4083),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4085),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(3975),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(3963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3963),
    [aux_sym_separator_action_token1] = ACTIONS(3963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3963),
    [aux_sym_type_declaration_token1] = ACTIONS(3963),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(3987),
    [sym_table_keyword] = ACTIONS(4087),
    [sym_page_keyword] = ACTIONS(4089),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4089),
    [sym_query_keyword] = ACTIONS(4089),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(3963),
    [sym_dataset_keyword] = ACTIONS(3963),
    [sym_quoted_identifier] = ACTIONS(3995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4001),
    [sym_continue_as_identifier] = ACTIONS(3987),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1871)] = {
    [sym__property_value] = STATE(17268),
    [sym_decimal_range_value] = STATE(17268),
    [sym_signed_integer_list] = STATE(17268),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(17268),
    [sym_property_expression] = STATE(17268),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(17268),
    [sym_ml_value_list] = STATE(17268),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(17268),
    [sym_lookup_formula] = STATE(17268),
    [sym_aggregate_formula] = STATE(17268),
    [sym_where_clause] = STATE(17268),
    [sym_sorting_value] = STATE(17268),
    [sym_link_value_list] = STATE(17268),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(17268),
    [sym_preproc_conditional_table_relation] = STATE(6393),
    [sym_table_relation_expression] = STATE(14692),
    [sym_if_table_relation] = STATE(6471),
    [sym_simple_table_relation] = STATE(14951),
    [sym_tabledata_permission_list] = STATE(6474),
    [sym_preproc_conditional_permissions] = STATE(4238),
    [sym_tabledata_permission] = STATE(4942),
    [sym_order_by_list] = STATE(17268),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(17268),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(17268),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(14760),
    [sym_preproc_if] = STATE(2066),
    [sym_assignment_expression] = STATE(8821),
    [sym__expression] = STATE(8821),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8821),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8821),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8201),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8821),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8821),
    [sym_codeunit_keyword] = STATE(6844),
    [sym_xmlport_keyword] = STATE(6844),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(13389),
    [sym_keyword_as_identifier] = STATE(13000),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4238),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3949),
    [anon_sym_SEMI] = ACTIONS(4079),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(3963),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4091),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4093),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4095),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(3975),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(3963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3963),
    [aux_sym_separator_action_token1] = ACTIONS(3963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3963),
    [aux_sym_type_declaration_token1] = ACTIONS(3963),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(3987),
    [sym_table_keyword] = ACTIONS(4097),
    [sym_page_keyword] = ACTIONS(4099),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4099),
    [sym_query_keyword] = ACTIONS(4099),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(3963),
    [sym_dataset_keyword] = ACTIONS(3963),
    [sym_quoted_identifier] = ACTIONS(3995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4001),
    [sym_continue_as_identifier] = ACTIONS(3987),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1872)] = {
    [sym__property_value] = STATE(17268),
    [sym_decimal_range_value] = STATE(17268),
    [sym_signed_integer_list] = STATE(17268),
    [sym__signed_integer] = STATE(16498),
    [sym_object_reference_value] = STATE(17268),
    [sym_property_expression] = STATE(17268),
    [sym_boolean] = STATE(8853),
    [sym_caption_value] = STATE(17268),
    [sym_ml_value_list] = STATE(17268),
    [sym_ml_value_pair] = STATE(16115),
    [sym__calc_formula_expression] = STATE(17268),
    [sym_lookup_formula] = STATE(17268),
    [sym_aggregate_formula] = STATE(17268),
    [sym_where_clause] = STATE(17268),
    [sym_sorting_value] = STATE(17268),
    [sym_link_value_list] = STATE(17268),
    [sym_preproc_conditional_link_values] = STATE(10279),
    [sym_link_value] = STATE(11149),
    [sym_table_relation_value] = STATE(17268),
    [sym_preproc_conditional_table_relation] = STATE(6393),
    [sym_table_relation_expression] = STATE(14692),
    [sym_if_table_relation] = STATE(6471),
    [sym_simple_table_relation] = STATE(14951),
    [sym_tabledata_permission_list] = STATE(6474),
    [sym_preproc_conditional_permissions] = STATE(5325),
    [sym_tabledata_permission] = STATE(5496),
    [sym_order_by_list] = STATE(17268),
    [sym_order_by_item] = STATE(16077),
    [sym_implementation_value_list] = STATE(17268),
    [sym_preproc_conditional_impl_values] = STATE(10280),
    [sym_implementation_value] = STATE(11204),
    [sym_option_member_list] = STATE(17268),
    [sym_option_member] = STATE(15000),
    [sym__namespaced_or_simple_ref] = STATE(14760),
    [sym_preproc_if] = STATE(2053),
    [sym_assignment_expression] = STATE(8821),
    [sym__expression] = STATE(8821),
    [sym_keyword_identifier] = STATE(8633),
    [sym_range_expression] = STATE(8821),
    [sym_multiplicative_expression] = STATE(9095),
    [sym_additive_expression] = STATE(9095),
    [sym_comparison_expression] = STATE(9095),
    [sym_logical_expression] = STATE(9095),
    [sym_ternary_expression] = STATE(8821),
    [sym_unary_expression] = STATE(9095),
    [sym_call_expression] = STATE(8850),
    [sym_member_expression] = STATE(8201),
    [sym_subscript_expression] = STATE(8684),
    [sym_parenthesized_expression] = STATE(9095),
    [sym_list_literal] = STATE(8821),
    [sym_qualified_enum_value] = STATE(8684),
    [sym_database_reference] = STATE(9095),
    [sym__literal_value] = STATE(8821),
    [sym_codeunit_keyword] = STATE(6839),
    [sym_xmlport_keyword] = STATE(6839),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(13389),
    [sym_keyword_as_identifier] = STATE(13000),
    [aux_sym_link_value_list_repeat1] = STATE(10279),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(5325),
    [aux_sym_implementation_value_list_repeat1] = STATE(10280),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3949),
    [anon_sym_SEMI] = ACTIONS(4079),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(3955),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(3957),
    [aux_sym_lookup_formula_token1] = ACTIONS(3959),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_clause_token1] = ACTIONS(3961),
    [aux_sym_where_condition_token1] = ACTIONS(3963),
    [aux_sym_sorting_value_token1] = ACTIONS(3965),
    [aux_sym_if_table_relation_token1] = ACTIONS(4091),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4101),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4103),
    [aux_sym_order_by_item_token1] = ACTIONS(3973),
    [aux_sym_order_by_item_token2] = ACTIONS(3973),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(3975),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(3963),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3963),
    [aux_sym_separator_action_token1] = ACTIONS(3963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3963),
    [aux_sym_type_declaration_token1] = ACTIONS(3963),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(3985),
    [sym_date_literal] = ACTIONS(3957),
    [sym_time_literal] = ACTIONS(3957),
    [sym_biginteger_literal] = ACTIONS(3987),
    [sym_table_keyword] = ACTIONS(4105),
    [sym_page_keyword] = ACTIONS(4107),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4107),
    [sym_query_keyword] = ACTIONS(4107),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(3963),
    [sym_dataset_keyword] = ACTIONS(3963),
    [sym_quoted_identifier] = ACTIONS(3995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3997),
    [sym_verbatim_string] = ACTIONS(3999),
    [sym_integer] = ACTIONS(4001),
    [sym_continue_as_identifier] = ACTIONS(3987),
    [sym_preproc_open] = ACTIONS(3977),
  },
  [STATE(1873)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_COMMA] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [aux_sym_boolean_token1] = ACTIONS(3562),
    [aux_sym_boolean_token2] = ACTIONS(3562),
    [sym_decimal] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_record_type_token1] = ACTIONS(3562),
    [aux_sym_basic_type_token21] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token48] = ACTIONS(3562),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_not] = ACTIONS(3562),
    [anon_sym_NOT] = ACTIONS(3562),
    [anon_sym_Not] = ACTIONS(3562),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3562),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [sym_datetime_literal] = ACTIONS(3564),
    [sym_date_literal] = ACTIONS(3562),
    [sym_time_literal] = ACTIONS(3562),
    [sym_biginteger_literal] = ACTIONS(3564),
    [anon_sym_if] = ACTIONS(3562),
    [anon_sym_IF] = ACTIONS(3562),
    [anon_sym_If] = ACTIONS(3562),
    [anon_sym_else] = ACTIONS(3562),
    [anon_sym_ELSE] = ACTIONS(3562),
    [anon_sym_Else] = ACTIONS(3562),
    [anon_sym_case] = ACTIONS(3562),
    [anon_sym_CASE] = ACTIONS(3562),
    [anon_sym_Case] = ACTIONS(3562),
    [anon_sym_for] = ACTIONS(3562),
    [anon_sym_FOR] = ACTIONS(3562),
    [anon_sym_For] = ACTIONS(3562),
    [anon_sym_foreach] = ACTIONS(3562),
    [anon_sym_FOREACH] = ACTIONS(3562),
    [anon_sym_Foreach] = ACTIONS(3562),
    [anon_sym_while] = ACTIONS(3562),
    [anon_sym_WHILE] = ACTIONS(3562),
    [anon_sym_While] = ACTIONS(3562),
    [anon_sym_repeat] = ACTIONS(3562),
    [anon_sym_REPEAT] = ACTIONS(3562),
    [anon_sym_Repeat] = ACTIONS(3562),
    [anon_sym_until] = ACTIONS(3562),
    [anon_sym_UNTIL] = ACTIONS(3562),
    [anon_sym_Until] = ACTIONS(3562),
    [anon_sym_exit] = ACTIONS(3562),
    [anon_sym_EXIT] = ACTIONS(3562),
    [anon_sym_Exit] = ACTIONS(3562),
    [anon_sym_continue] = ACTIONS(3562),
    [anon_sym_CONTINUE] = ACTIONS(3562),
    [anon_sym_Continue] = ACTIONS(3562),
    [anon_sym_break] = ACTIONS(3562),
    [anon_sym_BREAK] = ACTIONS(3562),
    [anon_sym_Break] = ACTIONS(3562),
    [anon_sym_with] = ACTIONS(3562),
    [anon_sym_WITH] = ACTIONS(3562),
    [anon_sym_With] = ACTIONS(3562),
    [sym_asserterror_keyword] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_page_keyword] = ACTIONS(3562),
    [anon_sym_codeunit] = ACTIONS(3562),
    [anon_sym_CODEUNIT] = ACTIONS(3562),
    [anon_sym_Codeunit] = ACTIONS(3562),
    [anon_sym_CodeUnit] = ACTIONS(3562),
    [anon_sym_COdeunit] = ACTIONS(3562),
    [anon_sym_codeUnit] = ACTIONS(3562),
    [sym_report_keyword] = ACTIONS(3562),
    [sym_query_keyword] = ACTIONS(3562),
    [anon_sym_xmlport] = ACTIONS(3562),
    [anon_sym_XMLPORT] = ACTIONS(3562),
    [anon_sym_Xmlport] = ACTIONS(3562),
    [anon_sym_XMLport] = ACTIONS(3562),
    [anon_sym_XMLPort] = ACTIONS(3562),
    [anon_sym_XmlPort] = ACTIONS(3562),
    [anon_sym_enum] = ACTIONS(3562),
    [anon_sym_ENUM] = ACTIONS(3562),
    [anon_sym_Enum] = ACTIONS(3562),
    [anon_sym_eNUM] = ACTIONS(3562),
    [anon_sym_eNum] = ACTIONS(3562),
    [anon_sym_ENum] = ACTIONS(3562),
    [sym_temporary_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3564),
    [sym_verbatim_string] = ACTIONS(3564),
    [sym_integer] = ACTIONS(3562),
    [sym_continue_as_identifier] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
  },
  [STATE(1874)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1875)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_until] = ACTIONS(3566),
    [anon_sym_UNTIL] = ACTIONS(3566),
    [anon_sym_Until] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(1876)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3710),
    [anon_sym_SEMI] = ACTIONS(3712),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3710),
    [aux_sym_boolean_token2] = ACTIONS(3710),
    [sym_decimal] = ACTIONS(3710),
    [anon_sym_LPAREN] = ACTIONS(3712),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3710),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3710),
    [aux_sym_basic_type_token21] = ACTIONS(3710),
    [aux_sym_basic_type_token22] = ACTIONS(3710),
    [aux_sym_basic_type_token48] = ACTIONS(3710),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3710),
    [anon_sym_POUNDif] = ACTIONS(3712),
    [anon_sym_POUNDIF] = ACTIONS(3712),
    [anon_sym_POUNDIf] = ACTIONS(3712),
    [anon_sym_not] = ACTIONS(3710),
    [anon_sym_NOT] = ACTIONS(3710),
    [anon_sym_Not] = ACTIONS(3710),
    [anon_sym_POUNDelse] = ACTIONS(3712),
    [anon_sym_POUNDELSE] = ACTIONS(3712),
    [anon_sym_POUNDElse] = ACTIONS(3712),
    [anon_sym_POUNDelse2] = ACTIONS(3712),
    [anon_sym_POUNDELSE2] = ACTIONS(3712),
    [anon_sym_POUNDElse2] = ACTIONS(3712),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4145),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3710),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3710),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(4147),
    [anon_sym_OR] = ACTIONS(4149),
    [anon_sym_Or] = ACTIONS(4151),
    [anon_sym_xor] = ACTIONS(4153),
    [anon_sym_XOR] = ACTIONS(4155),
    [anon_sym_Xor] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(3712),
    [sym_date_literal] = ACTIONS(3710),
    [sym_time_literal] = ACTIONS(3710),
    [sym_biginteger_literal] = ACTIONS(3712),
    [anon_sym_if] = ACTIONS(3710),
    [anon_sym_IF] = ACTIONS(3710),
    [anon_sym_If] = ACTIONS(3710),
    [anon_sym_else] = ACTIONS(3710),
    [anon_sym_ELSE] = ACTIONS(3710),
    [anon_sym_Else] = ACTIONS(3710),
    [anon_sym_case] = ACTIONS(3710),
    [anon_sym_CASE] = ACTIONS(3710),
    [anon_sym_Case] = ACTIONS(3710),
    [anon_sym_for] = ACTIONS(3710),
    [anon_sym_FOR] = ACTIONS(3710),
    [anon_sym_For] = ACTIONS(3710),
    [anon_sym_foreach] = ACTIONS(3710),
    [anon_sym_FOREACH] = ACTIONS(3710),
    [anon_sym_Foreach] = ACTIONS(3710),
    [anon_sym_while] = ACTIONS(3710),
    [anon_sym_WHILE] = ACTIONS(3710),
    [anon_sym_While] = ACTIONS(3710),
    [anon_sym_repeat] = ACTIONS(3710),
    [anon_sym_REPEAT] = ACTIONS(3710),
    [anon_sym_Repeat] = ACTIONS(3710),
    [anon_sym_until] = ACTIONS(3710),
    [anon_sym_UNTIL] = ACTIONS(3710),
    [anon_sym_Until] = ACTIONS(3710),
    [anon_sym_exit] = ACTIONS(3710),
    [anon_sym_EXIT] = ACTIONS(3710),
    [anon_sym_Exit] = ACTIONS(3710),
    [anon_sym_continue] = ACTIONS(3710),
    [anon_sym_CONTINUE] = ACTIONS(3710),
    [anon_sym_Continue] = ACTIONS(3710),
    [anon_sym_break] = ACTIONS(3710),
    [anon_sym_BREAK] = ACTIONS(3710),
    [anon_sym_Break] = ACTIONS(3710),
    [anon_sym_with] = ACTIONS(3710),
    [anon_sym_WITH] = ACTIONS(3710),
    [anon_sym_With] = ACTIONS(3710),
    [sym_asserterror_keyword] = ACTIONS(3712),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3710),
    [anon_sym_codeunit] = ACTIONS(3710),
    [anon_sym_CODEUNIT] = ACTIONS(3710),
    [anon_sym_Codeunit] = ACTIONS(3710),
    [anon_sym_CodeUnit] = ACTIONS(3710),
    [anon_sym_COdeunit] = ACTIONS(3710),
    [anon_sym_codeUnit] = ACTIONS(3710),
    [sym_report_keyword] = ACTIONS(3710),
    [sym_query_keyword] = ACTIONS(3710),
    [anon_sym_xmlport] = ACTIONS(3710),
    [anon_sym_XMLPORT] = ACTIONS(3710),
    [anon_sym_Xmlport] = ACTIONS(3710),
    [anon_sym_XMLport] = ACTIONS(3710),
    [anon_sym_XMLPort] = ACTIONS(3710),
    [anon_sym_XmlPort] = ACTIONS(3710),
    [anon_sym_enum] = ACTIONS(3710),
    [anon_sym_ENUM] = ACTIONS(3710),
    [anon_sym_Enum] = ACTIONS(3710),
    [anon_sym_eNUM] = ACTIONS(3710),
    [anon_sym_eNum] = ACTIONS(3710),
    [anon_sym_ENum] = ACTIONS(3710),
    [sym_quoted_identifier] = ACTIONS(3712),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3712),
    [sym_verbatim_string] = ACTIONS(3712),
    [sym_integer] = ACTIONS(3710),
    [sym_continue_as_identifier] = ACTIONS(3712),
    [sym_preproc_open] = ACTIONS(3712),
  },
  [STATE(1877)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1878)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1879)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3647),
    [anon_sym_SEMI] = ACTIONS(3649),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3649),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3647),
    [aux_sym_boolean_token2] = ACTIONS(3647),
    [sym_decimal] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3649),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3647),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3647),
    [aux_sym_basic_type_token21] = ACTIONS(3647),
    [aux_sym_basic_type_token22] = ACTIONS(3647),
    [aux_sym_basic_type_token48] = ACTIONS(3647),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3647),
    [anon_sym_POUNDif] = ACTIONS(3649),
    [anon_sym_POUNDIF] = ACTIONS(3649),
    [anon_sym_POUNDIf] = ACTIONS(3649),
    [anon_sym_not] = ACTIONS(3647),
    [anon_sym_NOT] = ACTIONS(3647),
    [anon_sym_Not] = ACTIONS(3647),
    [anon_sym_POUNDelse] = ACTIONS(3649),
    [anon_sym_POUNDELSE] = ACTIONS(3649),
    [anon_sym_POUNDElse] = ACTIONS(3649),
    [anon_sym_POUNDelse2] = ACTIONS(3649),
    [anon_sym_POUNDELSE2] = ACTIONS(3649),
    [anon_sym_POUNDElse2] = ACTIONS(3649),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3649),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3647),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3647),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3649),
    [anon_sym_LT_EQ] = ACTIONS(3649),
    [anon_sym_GT] = ACTIONS(3647),
    [anon_sym_LT] = ACTIONS(3647),
    [anon_sym_LT_GT] = ACTIONS(3649),
    [anon_sym_and] = ACTIONS(3647),
    [anon_sym_AND] = ACTIONS(3647),
    [anon_sym_And] = ACTIONS(3647),
    [anon_sym_or] = ACTIONS(3647),
    [anon_sym_OR] = ACTIONS(3647),
    [anon_sym_Or] = ACTIONS(3647),
    [anon_sym_xor] = ACTIONS(3647),
    [anon_sym_XOR] = ACTIONS(3647),
    [anon_sym_Xor] = ACTIONS(3647),
    [anon_sym_QMARK] = ACTIONS(3649),
    [sym_datetime_literal] = ACTIONS(3649),
    [sym_date_literal] = ACTIONS(3647),
    [sym_time_literal] = ACTIONS(3647),
    [sym_biginteger_literal] = ACTIONS(3649),
    [anon_sym_if] = ACTIONS(3647),
    [anon_sym_IF] = ACTIONS(3647),
    [anon_sym_If] = ACTIONS(3647),
    [anon_sym_else] = ACTIONS(3647),
    [anon_sym_ELSE] = ACTIONS(3647),
    [anon_sym_Else] = ACTIONS(3647),
    [anon_sym_case] = ACTIONS(3647),
    [anon_sym_CASE] = ACTIONS(3647),
    [anon_sym_Case] = ACTIONS(3647),
    [anon_sym_for] = ACTIONS(3647),
    [anon_sym_FOR] = ACTIONS(3647),
    [anon_sym_For] = ACTIONS(3647),
    [anon_sym_foreach] = ACTIONS(3647),
    [anon_sym_FOREACH] = ACTIONS(3647),
    [anon_sym_Foreach] = ACTIONS(3647),
    [anon_sym_while] = ACTIONS(3647),
    [anon_sym_WHILE] = ACTIONS(3647),
    [anon_sym_While] = ACTIONS(3647),
    [anon_sym_repeat] = ACTIONS(3647),
    [anon_sym_REPEAT] = ACTIONS(3647),
    [anon_sym_Repeat] = ACTIONS(3647),
    [anon_sym_until] = ACTIONS(3647),
    [anon_sym_UNTIL] = ACTIONS(3647),
    [anon_sym_Until] = ACTIONS(3647),
    [anon_sym_exit] = ACTIONS(3647),
    [anon_sym_EXIT] = ACTIONS(3647),
    [anon_sym_Exit] = ACTIONS(3647),
    [anon_sym_continue] = ACTIONS(3647),
    [anon_sym_CONTINUE] = ACTIONS(3647),
    [anon_sym_Continue] = ACTIONS(3647),
    [anon_sym_break] = ACTIONS(3647),
    [anon_sym_BREAK] = ACTIONS(3647),
    [anon_sym_Break] = ACTIONS(3647),
    [anon_sym_with] = ACTIONS(3647),
    [anon_sym_WITH] = ACTIONS(3647),
    [anon_sym_With] = ACTIONS(3647),
    [sym_asserterror_keyword] = ACTIONS(3649),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3647),
    [anon_sym_codeunit] = ACTIONS(3647),
    [anon_sym_CODEUNIT] = ACTIONS(3647),
    [anon_sym_Codeunit] = ACTIONS(3647),
    [anon_sym_CodeUnit] = ACTIONS(3647),
    [anon_sym_COdeunit] = ACTIONS(3647),
    [anon_sym_codeUnit] = ACTIONS(3647),
    [sym_report_keyword] = ACTIONS(3647),
    [sym_query_keyword] = ACTIONS(3647),
    [anon_sym_xmlport] = ACTIONS(3647),
    [anon_sym_XMLPORT] = ACTIONS(3647),
    [anon_sym_Xmlport] = ACTIONS(3647),
    [anon_sym_XMLport] = ACTIONS(3647),
    [anon_sym_XMLPort] = ACTIONS(3647),
    [anon_sym_XmlPort] = ACTIONS(3647),
    [anon_sym_enum] = ACTIONS(3647),
    [anon_sym_ENUM] = ACTIONS(3647),
    [anon_sym_Enum] = ACTIONS(3647),
    [anon_sym_eNUM] = ACTIONS(3647),
    [anon_sym_eNum] = ACTIONS(3647),
    [anon_sym_ENum] = ACTIONS(3647),
    [sym_quoted_identifier] = ACTIONS(3649),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3649),
    [sym_verbatim_string] = ACTIONS(3649),
    [sym_integer] = ACTIONS(3647),
    [sym_continue_as_identifier] = ACTIONS(3649),
    [sym_preproc_open] = ACTIONS(3649),
  },
  [STATE(1880)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1881)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3716),
    [anon_sym_SEMI] = ACTIONS(3718),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3716),
    [aux_sym_boolean_token1] = ACTIONS(3716),
    [aux_sym_boolean_token2] = ACTIONS(3716),
    [sym_decimal] = ACTIONS(3716),
    [anon_sym_LPAREN] = ACTIONS(3718),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3716),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(3718),
    [aux_sym_record_type_token1] = ACTIONS(3716),
    [aux_sym_basic_type_token21] = ACTIONS(3716),
    [aux_sym_basic_type_token22] = ACTIONS(3716),
    [aux_sym_basic_type_token48] = ACTIONS(3716),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3716),
    [anon_sym_POUNDif] = ACTIONS(3718),
    [anon_sym_POUNDIF] = ACTIONS(3718),
    [anon_sym_POUNDIf] = ACTIONS(3718),
    [anon_sym_not] = ACTIONS(3716),
    [anon_sym_NOT] = ACTIONS(3716),
    [anon_sym_Not] = ACTIONS(3716),
    [anon_sym_POUNDelse] = ACTIONS(3718),
    [anon_sym_POUNDELSE] = ACTIONS(3718),
    [anon_sym_POUNDElse] = ACTIONS(3718),
    [anon_sym_POUNDelse2] = ACTIONS(3718),
    [anon_sym_POUNDELSE2] = ACTIONS(3718),
    [anon_sym_POUNDElse2] = ACTIONS(3718),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4161),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3716),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3716),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(3716),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(4147),
    [anon_sym_OR] = ACTIONS(4149),
    [anon_sym_Or] = ACTIONS(4151),
    [anon_sym_xor] = ACTIONS(4153),
    [anon_sym_XOR] = ACTIONS(4155),
    [anon_sym_Xor] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(3718),
    [sym_date_literal] = ACTIONS(3716),
    [sym_time_literal] = ACTIONS(3716),
    [sym_biginteger_literal] = ACTIONS(3718),
    [anon_sym_if] = ACTIONS(3716),
    [anon_sym_IF] = ACTIONS(3716),
    [anon_sym_If] = ACTIONS(3716),
    [anon_sym_else] = ACTIONS(3716),
    [anon_sym_ELSE] = ACTIONS(3716),
    [anon_sym_Else] = ACTIONS(3716),
    [anon_sym_case] = ACTIONS(3716),
    [anon_sym_CASE] = ACTIONS(3716),
    [anon_sym_Case] = ACTIONS(3716),
    [anon_sym_for] = ACTIONS(3716),
    [anon_sym_FOR] = ACTIONS(3716),
    [anon_sym_For] = ACTIONS(3716),
    [anon_sym_foreach] = ACTIONS(3716),
    [anon_sym_FOREACH] = ACTIONS(3716),
    [anon_sym_Foreach] = ACTIONS(3716),
    [anon_sym_while] = ACTIONS(3716),
    [anon_sym_WHILE] = ACTIONS(3716),
    [anon_sym_While] = ACTIONS(3716),
    [anon_sym_repeat] = ACTIONS(3716),
    [anon_sym_REPEAT] = ACTIONS(3716),
    [anon_sym_Repeat] = ACTIONS(3716),
    [anon_sym_until] = ACTIONS(3716),
    [anon_sym_UNTIL] = ACTIONS(3716),
    [anon_sym_Until] = ACTIONS(3716),
    [anon_sym_exit] = ACTIONS(3716),
    [anon_sym_EXIT] = ACTIONS(3716),
    [anon_sym_Exit] = ACTIONS(3716),
    [anon_sym_continue] = ACTIONS(3716),
    [anon_sym_CONTINUE] = ACTIONS(3716),
    [anon_sym_Continue] = ACTIONS(3716),
    [anon_sym_break] = ACTIONS(3716),
    [anon_sym_BREAK] = ACTIONS(3716),
    [anon_sym_Break] = ACTIONS(3716),
    [anon_sym_with] = ACTIONS(3716),
    [anon_sym_WITH] = ACTIONS(3716),
    [anon_sym_With] = ACTIONS(3716),
    [sym_asserterror_keyword] = ACTIONS(3718),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3716),
    [anon_sym_codeunit] = ACTIONS(3716),
    [anon_sym_CODEUNIT] = ACTIONS(3716),
    [anon_sym_Codeunit] = ACTIONS(3716),
    [anon_sym_CodeUnit] = ACTIONS(3716),
    [anon_sym_COdeunit] = ACTIONS(3716),
    [anon_sym_codeUnit] = ACTIONS(3716),
    [sym_report_keyword] = ACTIONS(3716),
    [sym_query_keyword] = ACTIONS(3716),
    [anon_sym_xmlport] = ACTIONS(3716),
    [anon_sym_XMLPORT] = ACTIONS(3716),
    [anon_sym_Xmlport] = ACTIONS(3716),
    [anon_sym_XMLport] = ACTIONS(3716),
    [anon_sym_XMLPort] = ACTIONS(3716),
    [anon_sym_XmlPort] = ACTIONS(3716),
    [anon_sym_enum] = ACTIONS(3716),
    [anon_sym_ENUM] = ACTIONS(3716),
    [anon_sym_Enum] = ACTIONS(3716),
    [anon_sym_eNUM] = ACTIONS(3716),
    [anon_sym_eNum] = ACTIONS(3716),
    [anon_sym_ENum] = ACTIONS(3716),
    [sym_quoted_identifier] = ACTIONS(3718),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3718),
    [sym_verbatim_string] = ACTIONS(3718),
    [sym_integer] = ACTIONS(3716),
    [sym_continue_as_identifier] = ACTIONS(3718),
    [sym_preproc_open] = ACTIONS(3718),
  },
  [STATE(1882)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3720),
    [anon_sym_SEMI] = ACTIONS(3723),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3720),
    [aux_sym_boolean_token2] = ACTIONS(3720),
    [sym_decimal] = ACTIONS(3720),
    [anon_sym_LPAREN] = ACTIONS(3723),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3720),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3720),
    [aux_sym_basic_type_token21] = ACTIONS(3720),
    [aux_sym_basic_type_token22] = ACTIONS(3720),
    [aux_sym_basic_type_token48] = ACTIONS(3720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3720),
    [anon_sym_POUNDif] = ACTIONS(3723),
    [anon_sym_POUNDIF] = ACTIONS(3723),
    [anon_sym_POUNDIf] = ACTIONS(3723),
    [anon_sym_not] = ACTIONS(3720),
    [anon_sym_NOT] = ACTIONS(3720),
    [anon_sym_Not] = ACTIONS(3720),
    [anon_sym_POUNDelse] = ACTIONS(3723),
    [anon_sym_POUNDELSE] = ACTIONS(3723),
    [anon_sym_POUNDElse] = ACTIONS(3723),
    [anon_sym_POUNDelse2] = ACTIONS(3723),
    [anon_sym_POUNDELSE2] = ACTIONS(3723),
    [anon_sym_POUNDElse2] = ACTIONS(3723),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4161),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3720),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(4147),
    [anon_sym_OR] = ACTIONS(4149),
    [anon_sym_Or] = ACTIONS(4151),
    [anon_sym_xor] = ACTIONS(4153),
    [anon_sym_XOR] = ACTIONS(4155),
    [anon_sym_Xor] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(3723),
    [sym_date_literal] = ACTIONS(3720),
    [sym_time_literal] = ACTIONS(3720),
    [sym_biginteger_literal] = ACTIONS(3723),
    [anon_sym_if] = ACTIONS(3720),
    [anon_sym_IF] = ACTIONS(3720),
    [anon_sym_If] = ACTIONS(3720),
    [anon_sym_else] = ACTIONS(3720),
    [anon_sym_ELSE] = ACTIONS(3720),
    [anon_sym_Else] = ACTIONS(3720),
    [anon_sym_case] = ACTIONS(3720),
    [anon_sym_CASE] = ACTIONS(3720),
    [anon_sym_Case] = ACTIONS(3720),
    [anon_sym_for] = ACTIONS(3720),
    [anon_sym_FOR] = ACTIONS(3720),
    [anon_sym_For] = ACTIONS(3720),
    [anon_sym_foreach] = ACTIONS(3720),
    [anon_sym_FOREACH] = ACTIONS(3720),
    [anon_sym_Foreach] = ACTIONS(3720),
    [anon_sym_while] = ACTIONS(3720),
    [anon_sym_WHILE] = ACTIONS(3720),
    [anon_sym_While] = ACTIONS(3720),
    [anon_sym_repeat] = ACTIONS(3720),
    [anon_sym_REPEAT] = ACTIONS(3720),
    [anon_sym_Repeat] = ACTIONS(3720),
    [anon_sym_until] = ACTIONS(3720),
    [anon_sym_UNTIL] = ACTIONS(3720),
    [anon_sym_Until] = ACTIONS(3720),
    [anon_sym_exit] = ACTIONS(3720),
    [anon_sym_EXIT] = ACTIONS(3720),
    [anon_sym_Exit] = ACTIONS(3720),
    [anon_sym_continue] = ACTIONS(3720),
    [anon_sym_CONTINUE] = ACTIONS(3720),
    [anon_sym_Continue] = ACTIONS(3720),
    [anon_sym_break] = ACTIONS(3720),
    [anon_sym_BREAK] = ACTIONS(3720),
    [anon_sym_Break] = ACTIONS(3720),
    [anon_sym_with] = ACTIONS(3720),
    [anon_sym_WITH] = ACTIONS(3720),
    [anon_sym_With] = ACTIONS(3720),
    [sym_asserterror_keyword] = ACTIONS(3723),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3720),
    [anon_sym_codeunit] = ACTIONS(3720),
    [anon_sym_CODEUNIT] = ACTIONS(3720),
    [anon_sym_Codeunit] = ACTIONS(3720),
    [anon_sym_CodeUnit] = ACTIONS(3720),
    [anon_sym_COdeunit] = ACTIONS(3720),
    [anon_sym_codeUnit] = ACTIONS(3720),
    [sym_report_keyword] = ACTIONS(3720),
    [sym_query_keyword] = ACTIONS(3720),
    [anon_sym_xmlport] = ACTIONS(3720),
    [anon_sym_XMLPORT] = ACTIONS(3720),
    [anon_sym_Xmlport] = ACTIONS(3720),
    [anon_sym_XMLport] = ACTIONS(3720),
    [anon_sym_XMLPort] = ACTIONS(3720),
    [anon_sym_XmlPort] = ACTIONS(3720),
    [anon_sym_enum] = ACTIONS(3720),
    [anon_sym_ENUM] = ACTIONS(3720),
    [anon_sym_Enum] = ACTIONS(3720),
    [anon_sym_eNUM] = ACTIONS(3720),
    [anon_sym_eNum] = ACTIONS(3720),
    [anon_sym_ENum] = ACTIONS(3720),
    [sym_quoted_identifier] = ACTIONS(3723),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3723),
    [sym_verbatim_string] = ACTIONS(3723),
    [sym_integer] = ACTIONS(3720),
    [sym_continue_as_identifier] = ACTIONS(3723),
    [sym_preproc_open] = ACTIONS(3723),
  },
  [STATE(1883)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3730),
    [anon_sym_SEMI] = ACTIONS(3732),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3730),
    [aux_sym_boolean_token2] = ACTIONS(3730),
    [sym_decimal] = ACTIONS(3730),
    [anon_sym_LPAREN] = ACTIONS(3732),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3730),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3730),
    [aux_sym_basic_type_token21] = ACTIONS(3730),
    [aux_sym_basic_type_token22] = ACTIONS(3730),
    [aux_sym_basic_type_token48] = ACTIONS(3730),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3730),
    [anon_sym_POUNDif] = ACTIONS(3732),
    [anon_sym_POUNDIF] = ACTIONS(3732),
    [anon_sym_POUNDIf] = ACTIONS(3732),
    [anon_sym_not] = ACTIONS(3730),
    [anon_sym_NOT] = ACTIONS(3730),
    [anon_sym_Not] = ACTIONS(3730),
    [anon_sym_POUNDelse] = ACTIONS(3732),
    [anon_sym_POUNDELSE] = ACTIONS(3732),
    [anon_sym_POUNDElse] = ACTIONS(3732),
    [anon_sym_POUNDelse2] = ACTIONS(3732),
    [anon_sym_POUNDELSE2] = ACTIONS(3732),
    [anon_sym_POUNDElse2] = ACTIONS(3732),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4161),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3730),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3730),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(4147),
    [anon_sym_OR] = ACTIONS(4149),
    [anon_sym_Or] = ACTIONS(4151),
    [anon_sym_xor] = ACTIONS(4153),
    [anon_sym_XOR] = ACTIONS(4155),
    [anon_sym_Xor] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(3732),
    [sym_date_literal] = ACTIONS(3730),
    [sym_time_literal] = ACTIONS(3730),
    [sym_biginteger_literal] = ACTIONS(3732),
    [anon_sym_if] = ACTIONS(3730),
    [anon_sym_IF] = ACTIONS(3730),
    [anon_sym_If] = ACTIONS(3730),
    [anon_sym_else] = ACTIONS(3730),
    [anon_sym_ELSE] = ACTIONS(3730),
    [anon_sym_Else] = ACTIONS(3730),
    [anon_sym_case] = ACTIONS(3730),
    [anon_sym_CASE] = ACTIONS(3730),
    [anon_sym_Case] = ACTIONS(3730),
    [anon_sym_for] = ACTIONS(3730),
    [anon_sym_FOR] = ACTIONS(3730),
    [anon_sym_For] = ACTIONS(3730),
    [anon_sym_foreach] = ACTIONS(3730),
    [anon_sym_FOREACH] = ACTIONS(3730),
    [anon_sym_Foreach] = ACTIONS(3730),
    [anon_sym_while] = ACTIONS(3730),
    [anon_sym_WHILE] = ACTIONS(3730),
    [anon_sym_While] = ACTIONS(3730),
    [anon_sym_repeat] = ACTIONS(3730),
    [anon_sym_REPEAT] = ACTIONS(3730),
    [anon_sym_Repeat] = ACTIONS(3730),
    [anon_sym_until] = ACTIONS(3730),
    [anon_sym_UNTIL] = ACTIONS(3730),
    [anon_sym_Until] = ACTIONS(3730),
    [anon_sym_exit] = ACTIONS(3730),
    [anon_sym_EXIT] = ACTIONS(3730),
    [anon_sym_Exit] = ACTIONS(3730),
    [anon_sym_continue] = ACTIONS(3730),
    [anon_sym_CONTINUE] = ACTIONS(3730),
    [anon_sym_Continue] = ACTIONS(3730),
    [anon_sym_break] = ACTIONS(3730),
    [anon_sym_BREAK] = ACTIONS(3730),
    [anon_sym_Break] = ACTIONS(3730),
    [anon_sym_with] = ACTIONS(3730),
    [anon_sym_WITH] = ACTIONS(3730),
    [anon_sym_With] = ACTIONS(3730),
    [sym_asserterror_keyword] = ACTIONS(3732),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3730),
    [anon_sym_codeunit] = ACTIONS(3730),
    [anon_sym_CODEUNIT] = ACTIONS(3730),
    [anon_sym_Codeunit] = ACTIONS(3730),
    [anon_sym_CodeUnit] = ACTIONS(3730),
    [anon_sym_COdeunit] = ACTIONS(3730),
    [anon_sym_codeUnit] = ACTIONS(3730),
    [sym_report_keyword] = ACTIONS(3730),
    [sym_query_keyword] = ACTIONS(3730),
    [anon_sym_xmlport] = ACTIONS(3730),
    [anon_sym_XMLPORT] = ACTIONS(3730),
    [anon_sym_Xmlport] = ACTIONS(3730),
    [anon_sym_XMLport] = ACTIONS(3730),
    [anon_sym_XMLPort] = ACTIONS(3730),
    [anon_sym_XmlPort] = ACTIONS(3730),
    [anon_sym_enum] = ACTIONS(3730),
    [anon_sym_ENUM] = ACTIONS(3730),
    [anon_sym_Enum] = ACTIONS(3730),
    [anon_sym_eNUM] = ACTIONS(3730),
    [anon_sym_eNum] = ACTIONS(3730),
    [anon_sym_ENum] = ACTIONS(3730),
    [sym_quoted_identifier] = ACTIONS(3732),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3732),
    [sym_verbatim_string] = ACTIONS(3732),
    [sym_integer] = ACTIONS(3730),
    [sym_continue_as_identifier] = ACTIONS(3732),
    [sym_preproc_open] = ACTIONS(3732),
  },
  [STATE(1884)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3734),
    [anon_sym_SEMI] = ACTIONS(3736),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3734),
    [aux_sym_boolean_token2] = ACTIONS(3734),
    [sym_decimal] = ACTIONS(3734),
    [anon_sym_LPAREN] = ACTIONS(3736),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3734),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3734),
    [aux_sym_basic_type_token21] = ACTIONS(3734),
    [aux_sym_basic_type_token22] = ACTIONS(3734),
    [aux_sym_basic_type_token48] = ACTIONS(3734),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3734),
    [anon_sym_POUNDif] = ACTIONS(3736),
    [anon_sym_POUNDIF] = ACTIONS(3736),
    [anon_sym_POUNDIf] = ACTIONS(3736),
    [anon_sym_not] = ACTIONS(3734),
    [anon_sym_NOT] = ACTIONS(3734),
    [anon_sym_Not] = ACTIONS(3734),
    [anon_sym_POUNDelse] = ACTIONS(3736),
    [anon_sym_POUNDELSE] = ACTIONS(3736),
    [anon_sym_POUNDElse] = ACTIONS(3736),
    [anon_sym_POUNDelse2] = ACTIONS(3736),
    [anon_sym_POUNDELSE2] = ACTIONS(3736),
    [anon_sym_POUNDElse2] = ACTIONS(3736),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4161),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3734),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3734),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(4147),
    [anon_sym_OR] = ACTIONS(4149),
    [anon_sym_Or] = ACTIONS(4151),
    [anon_sym_xor] = ACTIONS(4153),
    [anon_sym_XOR] = ACTIONS(4155),
    [anon_sym_Xor] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(3736),
    [sym_date_literal] = ACTIONS(3734),
    [sym_time_literal] = ACTIONS(3734),
    [sym_biginteger_literal] = ACTIONS(3736),
    [anon_sym_if] = ACTIONS(3734),
    [anon_sym_IF] = ACTIONS(3734),
    [anon_sym_If] = ACTIONS(3734),
    [anon_sym_else] = ACTIONS(3734),
    [anon_sym_ELSE] = ACTIONS(3734),
    [anon_sym_Else] = ACTIONS(3734),
    [anon_sym_case] = ACTIONS(3734),
    [anon_sym_CASE] = ACTIONS(3734),
    [anon_sym_Case] = ACTIONS(3734),
    [anon_sym_for] = ACTIONS(3734),
    [anon_sym_FOR] = ACTIONS(3734),
    [anon_sym_For] = ACTIONS(3734),
    [anon_sym_foreach] = ACTIONS(3734),
    [anon_sym_FOREACH] = ACTIONS(3734),
    [anon_sym_Foreach] = ACTIONS(3734),
    [anon_sym_while] = ACTIONS(3734),
    [anon_sym_WHILE] = ACTIONS(3734),
    [anon_sym_While] = ACTIONS(3734),
    [anon_sym_repeat] = ACTIONS(3734),
    [anon_sym_REPEAT] = ACTIONS(3734),
    [anon_sym_Repeat] = ACTIONS(3734),
    [anon_sym_until] = ACTIONS(3734),
    [anon_sym_UNTIL] = ACTIONS(3734),
    [anon_sym_Until] = ACTIONS(3734),
    [anon_sym_exit] = ACTIONS(3734),
    [anon_sym_EXIT] = ACTIONS(3734),
    [anon_sym_Exit] = ACTIONS(3734),
    [anon_sym_continue] = ACTIONS(3734),
    [anon_sym_CONTINUE] = ACTIONS(3734),
    [anon_sym_Continue] = ACTIONS(3734),
    [anon_sym_break] = ACTIONS(3734),
    [anon_sym_BREAK] = ACTIONS(3734),
    [anon_sym_Break] = ACTIONS(3734),
    [anon_sym_with] = ACTIONS(3734),
    [anon_sym_WITH] = ACTIONS(3734),
    [anon_sym_With] = ACTIONS(3734),
    [sym_asserterror_keyword] = ACTIONS(3736),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3734),
    [anon_sym_codeunit] = ACTIONS(3734),
    [anon_sym_CODEUNIT] = ACTIONS(3734),
    [anon_sym_Codeunit] = ACTIONS(3734),
    [anon_sym_CodeUnit] = ACTIONS(3734),
    [anon_sym_COdeunit] = ACTIONS(3734),
    [anon_sym_codeUnit] = ACTIONS(3734),
    [sym_report_keyword] = ACTIONS(3734),
    [sym_query_keyword] = ACTIONS(3734),
    [anon_sym_xmlport] = ACTIONS(3734),
    [anon_sym_XMLPORT] = ACTIONS(3734),
    [anon_sym_Xmlport] = ACTIONS(3734),
    [anon_sym_XMLport] = ACTIONS(3734),
    [anon_sym_XMLPort] = ACTIONS(3734),
    [anon_sym_XmlPort] = ACTIONS(3734),
    [anon_sym_enum] = ACTIONS(3734),
    [anon_sym_ENUM] = ACTIONS(3734),
    [anon_sym_Enum] = ACTIONS(3734),
    [anon_sym_eNUM] = ACTIONS(3734),
    [anon_sym_eNum] = ACTIONS(3734),
    [anon_sym_ENum] = ACTIONS(3734),
    [sym_quoted_identifier] = ACTIONS(3736),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3736),
    [sym_verbatim_string] = ACTIONS(3736),
    [sym_integer] = ACTIONS(3734),
    [sym_continue_as_identifier] = ACTIONS(3736),
    [sym_preproc_open] = ACTIONS(3736),
  },
  [STATE(1885)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_until] = ACTIONS(3566),
    [anon_sym_UNTIL] = ACTIONS(3566),
    [anon_sym_Until] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(1886)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1889),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(4163),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_if] = ACTIONS(3689),
    [anon_sym_IF] = ACTIONS(3689),
    [anon_sym_If] = ACTIONS(3689),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_case] = ACTIONS(3689),
    [anon_sym_CASE] = ACTIONS(3689),
    [anon_sym_Case] = ACTIONS(3689),
    [anon_sym_for] = ACTIONS(3689),
    [anon_sym_FOR] = ACTIONS(3689),
    [anon_sym_For] = ACTIONS(3689),
    [anon_sym_foreach] = ACTIONS(3689),
    [anon_sym_FOREACH] = ACTIONS(3689),
    [anon_sym_Foreach] = ACTIONS(3689),
    [anon_sym_while] = ACTIONS(3689),
    [anon_sym_WHILE] = ACTIONS(3689),
    [anon_sym_While] = ACTIONS(3689),
    [anon_sym_repeat] = ACTIONS(3689),
    [anon_sym_REPEAT] = ACTIONS(3689),
    [anon_sym_Repeat] = ACTIONS(3689),
    [anon_sym_until] = ACTIONS(3689),
    [anon_sym_UNTIL] = ACTIONS(3689),
    [anon_sym_Until] = ACTIONS(3689),
    [anon_sym_exit] = ACTIONS(3689),
    [anon_sym_EXIT] = ACTIONS(3689),
    [anon_sym_Exit] = ACTIONS(3689),
    [anon_sym_continue] = ACTIONS(3689),
    [anon_sym_CONTINUE] = ACTIONS(3689),
    [anon_sym_Continue] = ACTIONS(3689),
    [anon_sym_break] = ACTIONS(3689),
    [anon_sym_BREAK] = ACTIONS(3689),
    [anon_sym_Break] = ACTIONS(3689),
    [anon_sym_with] = ACTIONS(3689),
    [anon_sym_WITH] = ACTIONS(3689),
    [anon_sym_With] = ACTIONS(3689),
    [sym_asserterror_keyword] = ACTIONS(3691),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
  },
  [STATE(1887)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1890),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(4163),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_if] = ACTIONS(3689),
    [anon_sym_IF] = ACTIONS(3689),
    [anon_sym_If] = ACTIONS(3689),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_case] = ACTIONS(3689),
    [anon_sym_CASE] = ACTIONS(3689),
    [anon_sym_Case] = ACTIONS(3689),
    [anon_sym_for] = ACTIONS(3689),
    [anon_sym_FOR] = ACTIONS(3689),
    [anon_sym_For] = ACTIONS(3689),
    [anon_sym_foreach] = ACTIONS(3689),
    [anon_sym_FOREACH] = ACTIONS(3689),
    [anon_sym_Foreach] = ACTIONS(3689),
    [anon_sym_while] = ACTIONS(3689),
    [anon_sym_WHILE] = ACTIONS(3689),
    [anon_sym_While] = ACTIONS(3689),
    [anon_sym_repeat] = ACTIONS(3689),
    [anon_sym_REPEAT] = ACTIONS(3689),
    [anon_sym_Repeat] = ACTIONS(3689),
    [anon_sym_until] = ACTIONS(3689),
    [anon_sym_UNTIL] = ACTIONS(3689),
    [anon_sym_Until] = ACTIONS(3689),
    [anon_sym_exit] = ACTIONS(3689),
    [anon_sym_EXIT] = ACTIONS(3689),
    [anon_sym_Exit] = ACTIONS(3689),
    [anon_sym_continue] = ACTIONS(3689),
    [anon_sym_CONTINUE] = ACTIONS(3689),
    [anon_sym_Continue] = ACTIONS(3689),
    [anon_sym_break] = ACTIONS(3689),
    [anon_sym_BREAK] = ACTIONS(3689),
    [anon_sym_Break] = ACTIONS(3689),
    [anon_sym_with] = ACTIONS(3689),
    [anon_sym_WITH] = ACTIONS(3689),
    [anon_sym_With] = ACTIONS(3689),
    [sym_asserterror_keyword] = ACTIONS(3691),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
  },
  [STATE(1888)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_if] = ACTIONS(3677),
    [anon_sym_IF] = ACTIONS(3677),
    [anon_sym_If] = ACTIONS(3677),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_case] = ACTIONS(3677),
    [anon_sym_CASE] = ACTIONS(3677),
    [anon_sym_Case] = ACTIONS(3677),
    [anon_sym_for] = ACTIONS(3677),
    [anon_sym_FOR] = ACTIONS(3677),
    [anon_sym_For] = ACTIONS(3677),
    [anon_sym_foreach] = ACTIONS(3677),
    [anon_sym_FOREACH] = ACTIONS(3677),
    [anon_sym_Foreach] = ACTIONS(3677),
    [anon_sym_while] = ACTIONS(3677),
    [anon_sym_WHILE] = ACTIONS(3677),
    [anon_sym_While] = ACTIONS(3677),
    [anon_sym_repeat] = ACTIONS(3677),
    [anon_sym_REPEAT] = ACTIONS(3677),
    [anon_sym_Repeat] = ACTIONS(3677),
    [anon_sym_until] = ACTIONS(3677),
    [anon_sym_UNTIL] = ACTIONS(3677),
    [anon_sym_Until] = ACTIONS(3677),
    [anon_sym_exit] = ACTIONS(3677),
    [anon_sym_EXIT] = ACTIONS(3677),
    [anon_sym_Exit] = ACTIONS(3677),
    [anon_sym_continue] = ACTIONS(3677),
    [anon_sym_CONTINUE] = ACTIONS(3677),
    [anon_sym_Continue] = ACTIONS(3677),
    [anon_sym_break] = ACTIONS(3677),
    [anon_sym_BREAK] = ACTIONS(3677),
    [anon_sym_Break] = ACTIONS(3677),
    [anon_sym_with] = ACTIONS(3677),
    [anon_sym_WITH] = ACTIONS(3677),
    [anon_sym_With] = ACTIONS(3677),
    [sym_asserterror_keyword] = ACTIONS(3679),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
  },
  [STATE(1889)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1889),
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(4165),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_if] = ACTIONS(3632),
    [anon_sym_IF] = ACTIONS(3632),
    [anon_sym_If] = ACTIONS(3632),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_case] = ACTIONS(3632),
    [anon_sym_CASE] = ACTIONS(3632),
    [anon_sym_Case] = ACTIONS(3632),
    [anon_sym_for] = ACTIONS(3632),
    [anon_sym_FOR] = ACTIONS(3632),
    [anon_sym_For] = ACTIONS(3632),
    [anon_sym_foreach] = ACTIONS(3632),
    [anon_sym_FOREACH] = ACTIONS(3632),
    [anon_sym_Foreach] = ACTIONS(3632),
    [anon_sym_while] = ACTIONS(3632),
    [anon_sym_WHILE] = ACTIONS(3632),
    [anon_sym_While] = ACTIONS(3632),
    [anon_sym_repeat] = ACTIONS(3632),
    [anon_sym_REPEAT] = ACTIONS(3632),
    [anon_sym_Repeat] = ACTIONS(3632),
    [anon_sym_until] = ACTIONS(3632),
    [anon_sym_UNTIL] = ACTIONS(3632),
    [anon_sym_Until] = ACTIONS(3632),
    [anon_sym_exit] = ACTIONS(3632),
    [anon_sym_EXIT] = ACTIONS(3632),
    [anon_sym_Exit] = ACTIONS(3632),
    [anon_sym_continue] = ACTIONS(3632),
    [anon_sym_CONTINUE] = ACTIONS(3632),
    [anon_sym_Continue] = ACTIONS(3632),
    [anon_sym_break] = ACTIONS(3632),
    [anon_sym_BREAK] = ACTIONS(3632),
    [anon_sym_Break] = ACTIONS(3632),
    [anon_sym_with] = ACTIONS(3632),
    [anon_sym_WITH] = ACTIONS(3632),
    [anon_sym_With] = ACTIONS(3632),
    [sym_asserterror_keyword] = ACTIONS(3634),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
  },
  [STATE(1890)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1889),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_SEMI] = ACTIONS(3669),
    [anon_sym_DOT] = ACTIONS(3667),
    [anon_sym_EQ] = ACTIONS(3669),
    [anon_sym_COMMA] = ACTIONS(4163),
    [anon_sym_DASH] = ACTIONS(3667),
    [aux_sym_boolean_token1] = ACTIONS(3667),
    [aux_sym_boolean_token2] = ACTIONS(3667),
    [sym_decimal] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3669),
    [anon_sym_DOT_DOT] = ACTIONS(3669),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3667),
    [anon_sym_STAR] = ACTIONS(3667),
    [anon_sym_LBRACK] = ACTIONS(3669),
    [aux_sym_record_type_token1] = ACTIONS(3667),
    [aux_sym_basic_type_token21] = ACTIONS(3667),
    [aux_sym_basic_type_token22] = ACTIONS(3667),
    [aux_sym_basic_type_token48] = ACTIONS(3667),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3667),
    [anon_sym_POUNDif] = ACTIONS(3669),
    [anon_sym_POUNDIF] = ACTIONS(3669),
    [anon_sym_POUNDIf] = ACTIONS(3669),
    [anon_sym_not] = ACTIONS(3667),
    [anon_sym_NOT] = ACTIONS(3667),
    [anon_sym_Not] = ACTIONS(3667),
    [anon_sym_POUNDelse] = ACTIONS(3669),
    [anon_sym_POUNDELSE] = ACTIONS(3669),
    [anon_sym_POUNDElse] = ACTIONS(3669),
    [anon_sym_POUNDelse2] = ACTIONS(3669),
    [anon_sym_POUNDELSE2] = ACTIONS(3669),
    [anon_sym_POUNDElse2] = ACTIONS(3669),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3669),
    [aux_sym__expression_token1] = ACTIONS(3669),
    [aux_sym__expression_token2] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3667),
    [anon_sym_SLASH] = ACTIONS(3667),
    [anon_sym_div] = ACTIONS(3667),
    [anon_sym_DIV] = ACTIONS(3667),
    [anon_sym_Div] = ACTIONS(3667),
    [anon_sym_mod] = ACTIONS(3667),
    [anon_sym_MOD] = ACTIONS(3667),
    [anon_sym_Mod] = ACTIONS(3667),
    [anon_sym_PLUS] = ACTIONS(3667),
    [anon_sym_GT_EQ] = ACTIONS(3669),
    [anon_sym_LT_EQ] = ACTIONS(3669),
    [anon_sym_GT] = ACTIONS(3667),
    [anon_sym_LT] = ACTIONS(3667),
    [anon_sym_LT_GT] = ACTIONS(3669),
    [anon_sym_and] = ACTIONS(3667),
    [anon_sym_AND] = ACTIONS(3667),
    [anon_sym_And] = ACTIONS(3667),
    [anon_sym_or] = ACTIONS(3667),
    [anon_sym_OR] = ACTIONS(3667),
    [anon_sym_Or] = ACTIONS(3667),
    [anon_sym_xor] = ACTIONS(3667),
    [anon_sym_XOR] = ACTIONS(3667),
    [anon_sym_Xor] = ACTIONS(3667),
    [anon_sym_QMARK] = ACTIONS(3669),
    [sym_datetime_literal] = ACTIONS(3669),
    [sym_date_literal] = ACTIONS(3667),
    [sym_time_literal] = ACTIONS(3667),
    [sym_biginteger_literal] = ACTIONS(3669),
    [anon_sym_if] = ACTIONS(3667),
    [anon_sym_IF] = ACTIONS(3667),
    [anon_sym_If] = ACTIONS(3667),
    [anon_sym_else] = ACTIONS(3667),
    [anon_sym_ELSE] = ACTIONS(3667),
    [anon_sym_Else] = ACTIONS(3667),
    [anon_sym_case] = ACTIONS(3667),
    [anon_sym_CASE] = ACTIONS(3667),
    [anon_sym_Case] = ACTIONS(3667),
    [anon_sym_for] = ACTIONS(3667),
    [anon_sym_FOR] = ACTIONS(3667),
    [anon_sym_For] = ACTIONS(3667),
    [anon_sym_foreach] = ACTIONS(3667),
    [anon_sym_FOREACH] = ACTIONS(3667),
    [anon_sym_Foreach] = ACTIONS(3667),
    [anon_sym_while] = ACTIONS(3667),
    [anon_sym_WHILE] = ACTIONS(3667),
    [anon_sym_While] = ACTIONS(3667),
    [anon_sym_repeat] = ACTIONS(3667),
    [anon_sym_REPEAT] = ACTIONS(3667),
    [anon_sym_Repeat] = ACTIONS(3667),
    [anon_sym_until] = ACTIONS(3667),
    [anon_sym_UNTIL] = ACTIONS(3667),
    [anon_sym_Until] = ACTIONS(3667),
    [anon_sym_exit] = ACTIONS(3667),
    [anon_sym_EXIT] = ACTIONS(3667),
    [anon_sym_Exit] = ACTIONS(3667),
    [anon_sym_continue] = ACTIONS(3667),
    [anon_sym_CONTINUE] = ACTIONS(3667),
    [anon_sym_Continue] = ACTIONS(3667),
    [anon_sym_break] = ACTIONS(3667),
    [anon_sym_BREAK] = ACTIONS(3667),
    [anon_sym_Break] = ACTIONS(3667),
    [anon_sym_with] = ACTIONS(3667),
    [anon_sym_WITH] = ACTIONS(3667),
    [anon_sym_With] = ACTIONS(3667),
    [sym_asserterror_keyword] = ACTIONS(3669),
    [anon_sym_in] = ACTIONS(3667),
    [anon_sym_IN] = ACTIONS(3667),
    [anon_sym_In] = ACTIONS(3667),
    [sym_page_keyword] = ACTIONS(3667),
    [anon_sym_codeunit] = ACTIONS(3667),
    [anon_sym_CODEUNIT] = ACTIONS(3667),
    [anon_sym_Codeunit] = ACTIONS(3667),
    [anon_sym_CodeUnit] = ACTIONS(3667),
    [anon_sym_COdeunit] = ACTIONS(3667),
    [anon_sym_codeUnit] = ACTIONS(3667),
    [sym_report_keyword] = ACTIONS(3667),
    [sym_query_keyword] = ACTIONS(3667),
    [anon_sym_xmlport] = ACTIONS(3667),
    [anon_sym_XMLPORT] = ACTIONS(3667),
    [anon_sym_Xmlport] = ACTIONS(3667),
    [anon_sym_XMLport] = ACTIONS(3667),
    [anon_sym_XMLPort] = ACTIONS(3667),
    [anon_sym_XmlPort] = ACTIONS(3667),
    [anon_sym_enum] = ACTIONS(3667),
    [anon_sym_ENUM] = ACTIONS(3667),
    [anon_sym_Enum] = ACTIONS(3667),
    [anon_sym_eNUM] = ACTIONS(3667),
    [anon_sym_eNum] = ACTIONS(3667),
    [anon_sym_ENum] = ACTIONS(3667),
    [sym_quoted_identifier] = ACTIONS(3669),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3669),
    [sym_verbatim_string] = ACTIONS(3669),
    [sym_integer] = ACTIONS(3667),
    [sym_continue_as_identifier] = ACTIONS(3669),
    [sym_preproc_open] = ACTIONS(3669),
  },
  [STATE(1891)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_until] = ACTIONS(3566),
    [anon_sym_UNTIL] = ACTIONS(3566),
    [anon_sym_Until] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(1892)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1895),
    [sym_identifier] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(4168),
    [anon_sym_EQ] = ACTIONS(3695),
    [anon_sym_DASH] = ACTIONS(3693),
    [aux_sym_boolean_token1] = ACTIONS(3693),
    [aux_sym_boolean_token2] = ACTIONS(3693),
    [sym_decimal] = ACTIONS(3693),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_DOT_DOT] = ACTIONS(3695),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [aux_sym_record_type_token1] = ACTIONS(3693),
    [aux_sym_basic_type_token21] = ACTIONS(3693),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_basic_type_token48] = ACTIONS(3693),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_not] = ACTIONS(3693),
    [anon_sym_NOT] = ACTIONS(3693),
    [anon_sym_Not] = ACTIONS(3693),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3695),
    [aux_sym__expression_token1] = ACTIONS(3695),
    [aux_sym__expression_token2] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3693),
    [anon_sym_SLASH] = ACTIONS(3693),
    [anon_sym_div] = ACTIONS(3693),
    [anon_sym_DIV] = ACTIONS(3693),
    [anon_sym_Div] = ACTIONS(3693),
    [anon_sym_mod] = ACTIONS(3693),
    [anon_sym_MOD] = ACTIONS(3693),
    [anon_sym_Mod] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(3693),
    [anon_sym_GT_EQ] = ACTIONS(3695),
    [anon_sym_LT_EQ] = ACTIONS(3695),
    [anon_sym_GT] = ACTIONS(3693),
    [anon_sym_LT] = ACTIONS(3693),
    [anon_sym_LT_GT] = ACTIONS(3695),
    [anon_sym_and] = ACTIONS(3693),
    [anon_sym_AND] = ACTIONS(3693),
    [anon_sym_And] = ACTIONS(3693),
    [anon_sym_or] = ACTIONS(3693),
    [anon_sym_OR] = ACTIONS(3693),
    [anon_sym_Or] = ACTIONS(3693),
    [anon_sym_xor] = ACTIONS(3693),
    [anon_sym_XOR] = ACTIONS(3693),
    [anon_sym_Xor] = ACTIONS(3693),
    [anon_sym_QMARK] = ACTIONS(3695),
    [sym_datetime_literal] = ACTIONS(3695),
    [sym_date_literal] = ACTIONS(3693),
    [sym_time_literal] = ACTIONS(3693),
    [sym_biginteger_literal] = ACTIONS(3695),
    [anon_sym_if] = ACTIONS(3693),
    [anon_sym_IF] = ACTIONS(3693),
    [anon_sym_If] = ACTIONS(3693),
    [anon_sym_else] = ACTIONS(3693),
    [anon_sym_ELSE] = ACTIONS(3693),
    [anon_sym_Else] = ACTIONS(3693),
    [anon_sym_case] = ACTIONS(3693),
    [anon_sym_CASE] = ACTIONS(3693),
    [anon_sym_Case] = ACTIONS(3693),
    [anon_sym_for] = ACTIONS(3693),
    [anon_sym_FOR] = ACTIONS(3693),
    [anon_sym_For] = ACTIONS(3693),
    [anon_sym_foreach] = ACTIONS(3693),
    [anon_sym_FOREACH] = ACTIONS(3693),
    [anon_sym_Foreach] = ACTIONS(3693),
    [anon_sym_while] = ACTIONS(3693),
    [anon_sym_WHILE] = ACTIONS(3693),
    [anon_sym_While] = ACTIONS(3693),
    [anon_sym_repeat] = ACTIONS(3693),
    [anon_sym_REPEAT] = ACTIONS(3693),
    [anon_sym_Repeat] = ACTIONS(3693),
    [anon_sym_until] = ACTIONS(3693),
    [anon_sym_UNTIL] = ACTIONS(3693),
    [anon_sym_Until] = ACTIONS(3693),
    [anon_sym_exit] = ACTIONS(3693),
    [anon_sym_EXIT] = ACTIONS(3693),
    [anon_sym_Exit] = ACTIONS(3693),
    [anon_sym_continue] = ACTIONS(3693),
    [anon_sym_CONTINUE] = ACTIONS(3693),
    [anon_sym_Continue] = ACTIONS(3693),
    [anon_sym_break] = ACTIONS(3693),
    [anon_sym_BREAK] = ACTIONS(3693),
    [anon_sym_Break] = ACTIONS(3693),
    [anon_sym_with] = ACTIONS(3693),
    [anon_sym_WITH] = ACTIONS(3693),
    [anon_sym_With] = ACTIONS(3693),
    [sym_asserterror_keyword] = ACTIONS(3695),
    [anon_sym_in] = ACTIONS(3693),
    [anon_sym_IN] = ACTIONS(3693),
    [anon_sym_In] = ACTIONS(3693),
    [sym_page_keyword] = ACTIONS(3693),
    [anon_sym_codeunit] = ACTIONS(3693),
    [anon_sym_CODEUNIT] = ACTIONS(3693),
    [anon_sym_Codeunit] = ACTIONS(3693),
    [anon_sym_CodeUnit] = ACTIONS(3693),
    [anon_sym_COdeunit] = ACTIONS(3693),
    [anon_sym_codeUnit] = ACTIONS(3693),
    [sym_report_keyword] = ACTIONS(3693),
    [sym_query_keyword] = ACTIONS(3693),
    [anon_sym_xmlport] = ACTIONS(3693),
    [anon_sym_XMLPORT] = ACTIONS(3693),
    [anon_sym_Xmlport] = ACTIONS(3693),
    [anon_sym_XMLport] = ACTIONS(3693),
    [anon_sym_XMLPort] = ACTIONS(3693),
    [anon_sym_XmlPort] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_ENUM] = ACTIONS(3693),
    [anon_sym_Enum] = ACTIONS(3693),
    [anon_sym_eNUM] = ACTIONS(3693),
    [anon_sym_eNum] = ACTIONS(3693),
    [anon_sym_ENum] = ACTIONS(3693),
    [sym_temporary_keyword] = ACTIONS(3693),
    [sym_quoted_identifier] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3695),
    [sym_verbatim_string] = ACTIONS(3695),
    [sym_integer] = ACTIONS(3693),
    [sym_continue_as_identifier] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
  },
  [STATE(1893)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1894)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_until] = ACTIONS(3566),
    [anon_sym_UNTIL] = ACTIONS(3566),
    [anon_sym_Until] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(1895)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1896),
    [sym_identifier] = ACTIONS(3699),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(4168),
    [anon_sym_EQ] = ACTIONS(3701),
    [anon_sym_DASH] = ACTIONS(3699),
    [aux_sym_boolean_token1] = ACTIONS(3699),
    [aux_sym_boolean_token2] = ACTIONS(3699),
    [sym_decimal] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_DOT_DOT] = ACTIONS(3701),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3699),
    [anon_sym_STAR] = ACTIONS(3699),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [aux_sym_record_type_token1] = ACTIONS(3699),
    [aux_sym_basic_type_token21] = ACTIONS(3699),
    [aux_sym_basic_type_token22] = ACTIONS(3699),
    [aux_sym_basic_type_token48] = ACTIONS(3699),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3699),
    [anon_sym_POUNDif] = ACTIONS(3701),
    [anon_sym_POUNDIF] = ACTIONS(3701),
    [anon_sym_POUNDIf] = ACTIONS(3701),
    [anon_sym_not] = ACTIONS(3699),
    [anon_sym_NOT] = ACTIONS(3699),
    [anon_sym_Not] = ACTIONS(3699),
    [anon_sym_POUNDelse] = ACTIONS(3701),
    [anon_sym_POUNDELSE] = ACTIONS(3701),
    [anon_sym_POUNDElse] = ACTIONS(3701),
    [anon_sym_POUNDelse2] = ACTIONS(3701),
    [anon_sym_POUNDELSE2] = ACTIONS(3701),
    [anon_sym_POUNDElse2] = ACTIONS(3701),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3701),
    [aux_sym__expression_token1] = ACTIONS(3701),
    [aux_sym__expression_token2] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3699),
    [anon_sym_SLASH] = ACTIONS(3699),
    [anon_sym_div] = ACTIONS(3699),
    [anon_sym_DIV] = ACTIONS(3699),
    [anon_sym_Div] = ACTIONS(3699),
    [anon_sym_mod] = ACTIONS(3699),
    [anon_sym_MOD] = ACTIONS(3699),
    [anon_sym_Mod] = ACTIONS(3699),
    [anon_sym_PLUS] = ACTIONS(3699),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT] = ACTIONS(3699),
    [anon_sym_LT] = ACTIONS(3699),
    [anon_sym_LT_GT] = ACTIONS(3701),
    [anon_sym_and] = ACTIONS(3699),
    [anon_sym_AND] = ACTIONS(3699),
    [anon_sym_And] = ACTIONS(3699),
    [anon_sym_or] = ACTIONS(3699),
    [anon_sym_OR] = ACTIONS(3699),
    [anon_sym_Or] = ACTIONS(3699),
    [anon_sym_xor] = ACTIONS(3699),
    [anon_sym_XOR] = ACTIONS(3699),
    [anon_sym_Xor] = ACTIONS(3699),
    [anon_sym_QMARK] = ACTIONS(3701),
    [sym_datetime_literal] = ACTIONS(3701),
    [sym_date_literal] = ACTIONS(3699),
    [sym_time_literal] = ACTIONS(3699),
    [sym_biginteger_literal] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3699),
    [anon_sym_IF] = ACTIONS(3699),
    [anon_sym_If] = ACTIONS(3699),
    [anon_sym_else] = ACTIONS(3699),
    [anon_sym_ELSE] = ACTIONS(3699),
    [anon_sym_Else] = ACTIONS(3699),
    [anon_sym_case] = ACTIONS(3699),
    [anon_sym_CASE] = ACTIONS(3699),
    [anon_sym_Case] = ACTIONS(3699),
    [anon_sym_for] = ACTIONS(3699),
    [anon_sym_FOR] = ACTIONS(3699),
    [anon_sym_For] = ACTIONS(3699),
    [anon_sym_foreach] = ACTIONS(3699),
    [anon_sym_FOREACH] = ACTIONS(3699),
    [anon_sym_Foreach] = ACTIONS(3699),
    [anon_sym_while] = ACTIONS(3699),
    [anon_sym_WHILE] = ACTIONS(3699),
    [anon_sym_While] = ACTIONS(3699),
    [anon_sym_repeat] = ACTIONS(3699),
    [anon_sym_REPEAT] = ACTIONS(3699),
    [anon_sym_Repeat] = ACTIONS(3699),
    [anon_sym_until] = ACTIONS(3699),
    [anon_sym_UNTIL] = ACTIONS(3699),
    [anon_sym_Until] = ACTIONS(3699),
    [anon_sym_exit] = ACTIONS(3699),
    [anon_sym_EXIT] = ACTIONS(3699),
    [anon_sym_Exit] = ACTIONS(3699),
    [anon_sym_continue] = ACTIONS(3699),
    [anon_sym_CONTINUE] = ACTIONS(3699),
    [anon_sym_Continue] = ACTIONS(3699),
    [anon_sym_break] = ACTIONS(3699),
    [anon_sym_BREAK] = ACTIONS(3699),
    [anon_sym_Break] = ACTIONS(3699),
    [anon_sym_with] = ACTIONS(3699),
    [anon_sym_WITH] = ACTIONS(3699),
    [anon_sym_With] = ACTIONS(3699),
    [sym_asserterror_keyword] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3699),
    [anon_sym_IN] = ACTIONS(3699),
    [anon_sym_In] = ACTIONS(3699),
    [sym_page_keyword] = ACTIONS(3699),
    [anon_sym_codeunit] = ACTIONS(3699),
    [anon_sym_CODEUNIT] = ACTIONS(3699),
    [anon_sym_Codeunit] = ACTIONS(3699),
    [anon_sym_CodeUnit] = ACTIONS(3699),
    [anon_sym_COdeunit] = ACTIONS(3699),
    [anon_sym_codeUnit] = ACTIONS(3699),
    [sym_report_keyword] = ACTIONS(3699),
    [sym_query_keyword] = ACTIONS(3699),
    [anon_sym_xmlport] = ACTIONS(3699),
    [anon_sym_XMLPORT] = ACTIONS(3699),
    [anon_sym_Xmlport] = ACTIONS(3699),
    [anon_sym_XMLport] = ACTIONS(3699),
    [anon_sym_XMLPort] = ACTIONS(3699),
    [anon_sym_XmlPort] = ACTIONS(3699),
    [anon_sym_enum] = ACTIONS(3699),
    [anon_sym_ENUM] = ACTIONS(3699),
    [anon_sym_Enum] = ACTIONS(3699),
    [anon_sym_eNUM] = ACTIONS(3699),
    [anon_sym_eNum] = ACTIONS(3699),
    [anon_sym_ENum] = ACTIONS(3699),
    [sym_temporary_keyword] = ACTIONS(3699),
    [sym_quoted_identifier] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3701),
    [sym_verbatim_string] = ACTIONS(3701),
    [sym_integer] = ACTIONS(3699),
    [sym_continue_as_identifier] = ACTIONS(3701),
    [sym_preproc_open] = ACTIONS(3701),
  },
  [STATE(1896)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1896),
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_if] = ACTIONS(3703),
    [anon_sym_IF] = ACTIONS(3703),
    [anon_sym_If] = ACTIONS(3703),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_case] = ACTIONS(3703),
    [anon_sym_CASE] = ACTIONS(3703),
    [anon_sym_Case] = ACTIONS(3703),
    [anon_sym_for] = ACTIONS(3703),
    [anon_sym_FOR] = ACTIONS(3703),
    [anon_sym_For] = ACTIONS(3703),
    [anon_sym_foreach] = ACTIONS(3703),
    [anon_sym_FOREACH] = ACTIONS(3703),
    [anon_sym_Foreach] = ACTIONS(3703),
    [anon_sym_while] = ACTIONS(3703),
    [anon_sym_WHILE] = ACTIONS(3703),
    [anon_sym_While] = ACTIONS(3703),
    [anon_sym_repeat] = ACTIONS(3703),
    [anon_sym_REPEAT] = ACTIONS(3703),
    [anon_sym_Repeat] = ACTIONS(3703),
    [anon_sym_until] = ACTIONS(3703),
    [anon_sym_UNTIL] = ACTIONS(3703),
    [anon_sym_Until] = ACTIONS(3703),
    [anon_sym_exit] = ACTIONS(3703),
    [anon_sym_EXIT] = ACTIONS(3703),
    [anon_sym_Exit] = ACTIONS(3703),
    [anon_sym_continue] = ACTIONS(3703),
    [anon_sym_CONTINUE] = ACTIONS(3703),
    [anon_sym_Continue] = ACTIONS(3703),
    [anon_sym_break] = ACTIONS(3703),
    [anon_sym_BREAK] = ACTIONS(3703),
    [anon_sym_Break] = ACTIONS(3703),
    [anon_sym_with] = ACTIONS(3703),
    [anon_sym_WITH] = ACTIONS(3703),
    [anon_sym_With] = ACTIONS(3703),
    [sym_asserterror_keyword] = ACTIONS(3705),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
  },
  [STATE(1897)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3673),
    [anon_sym_SEMI] = ACTIONS(3675),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3673),
    [aux_sym_boolean_token2] = ACTIONS(3673),
    [sym_decimal] = ACTIONS(3673),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3673),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3673),
    [aux_sym_basic_type_token21] = ACTIONS(3673),
    [aux_sym_basic_type_token22] = ACTIONS(3673),
    [aux_sym_basic_type_token48] = ACTIONS(3673),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3673),
    [anon_sym_POUNDif] = ACTIONS(3675),
    [anon_sym_POUNDIF] = ACTIONS(3675),
    [anon_sym_POUNDIf] = ACTIONS(3675),
    [anon_sym_not] = ACTIONS(3673),
    [anon_sym_NOT] = ACTIONS(3673),
    [anon_sym_Not] = ACTIONS(3673),
    [anon_sym_POUNDelse] = ACTIONS(3675),
    [anon_sym_POUNDELSE] = ACTIONS(3675),
    [anon_sym_POUNDElse] = ACTIONS(3675),
    [anon_sym_POUNDelse2] = ACTIONS(3675),
    [anon_sym_POUNDELSE2] = ACTIONS(3675),
    [anon_sym_POUNDElse2] = ACTIONS(3675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3675),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3673),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(4147),
    [anon_sym_OR] = ACTIONS(4149),
    [anon_sym_Or] = ACTIONS(4151),
    [anon_sym_xor] = ACTIONS(4153),
    [anon_sym_XOR] = ACTIONS(4155),
    [anon_sym_Xor] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(3675),
    [sym_date_literal] = ACTIONS(3673),
    [sym_time_literal] = ACTIONS(3673),
    [sym_biginteger_literal] = ACTIONS(3675),
    [anon_sym_if] = ACTIONS(3673),
    [anon_sym_IF] = ACTIONS(3673),
    [anon_sym_If] = ACTIONS(3673),
    [anon_sym_else] = ACTIONS(3673),
    [anon_sym_ELSE] = ACTIONS(3673),
    [anon_sym_Else] = ACTIONS(3673),
    [anon_sym_case] = ACTIONS(3673),
    [anon_sym_CASE] = ACTIONS(3673),
    [anon_sym_Case] = ACTIONS(3673),
    [anon_sym_for] = ACTIONS(3673),
    [anon_sym_FOR] = ACTIONS(3673),
    [anon_sym_For] = ACTIONS(3673),
    [anon_sym_foreach] = ACTIONS(3673),
    [anon_sym_FOREACH] = ACTIONS(3673),
    [anon_sym_Foreach] = ACTIONS(3673),
    [anon_sym_while] = ACTIONS(3673),
    [anon_sym_WHILE] = ACTIONS(3673),
    [anon_sym_While] = ACTIONS(3673),
    [anon_sym_repeat] = ACTIONS(3673),
    [anon_sym_REPEAT] = ACTIONS(3673),
    [anon_sym_Repeat] = ACTIONS(3673),
    [anon_sym_until] = ACTIONS(3673),
    [anon_sym_UNTIL] = ACTIONS(3673),
    [anon_sym_Until] = ACTIONS(3673),
    [anon_sym_exit] = ACTIONS(3673),
    [anon_sym_EXIT] = ACTIONS(3673),
    [anon_sym_Exit] = ACTIONS(3673),
    [anon_sym_continue] = ACTIONS(3673),
    [anon_sym_CONTINUE] = ACTIONS(3673),
    [anon_sym_Continue] = ACTIONS(3673),
    [anon_sym_break] = ACTIONS(3673),
    [anon_sym_BREAK] = ACTIONS(3673),
    [anon_sym_Break] = ACTIONS(3673),
    [anon_sym_with] = ACTIONS(3673),
    [anon_sym_WITH] = ACTIONS(3673),
    [anon_sym_With] = ACTIONS(3673),
    [sym_asserterror_keyword] = ACTIONS(3675),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3673),
    [anon_sym_codeunit] = ACTIONS(3673),
    [anon_sym_CODEUNIT] = ACTIONS(3673),
    [anon_sym_Codeunit] = ACTIONS(3673),
    [anon_sym_CodeUnit] = ACTIONS(3673),
    [anon_sym_COdeunit] = ACTIONS(3673),
    [anon_sym_codeUnit] = ACTIONS(3673),
    [sym_report_keyword] = ACTIONS(3673),
    [sym_query_keyword] = ACTIONS(3673),
    [anon_sym_xmlport] = ACTIONS(3673),
    [anon_sym_XMLPORT] = ACTIONS(3673),
    [anon_sym_Xmlport] = ACTIONS(3673),
    [anon_sym_XMLport] = ACTIONS(3673),
    [anon_sym_XMLPort] = ACTIONS(3673),
    [anon_sym_XmlPort] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_ENUM] = ACTIONS(3673),
    [anon_sym_Enum] = ACTIONS(3673),
    [anon_sym_eNUM] = ACTIONS(3673),
    [anon_sym_eNum] = ACTIONS(3673),
    [anon_sym_ENum] = ACTIONS(3673),
    [sym_quoted_identifier] = ACTIONS(3675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3675),
    [sym_verbatim_string] = ACTIONS(3675),
    [sym_integer] = ACTIONS(3673),
    [sym_continue_as_identifier] = ACTIONS(3675),
    [sym_preproc_open] = ACTIONS(3675),
  },
  [STATE(1898)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1899)] = {
    [sym_preproc_conditional_object] = STATE(1970),
    [sym_namespace_declaration] = STATE(2001),
    [sym_using_statement] = STATE(1970),
    [sym__object] = STATE(1970),
    [sym_preproc_split_declaration] = STATE(1970),
    [sym_table_declaration] = STATE(1970),
    [sym_page_declaration] = STATE(1970),
    [sym_report_declaration] = STATE(1970),
    [sym_query_declaration] = STATE(1970),
    [sym_xmlport_declaration] = STATE(1970),
    [sym_permissionset_declaration] = STATE(1970),
    [sym_codeunit_declaration] = STATE(1970),
    [sym_enum_declaration] = STATE(1970),
    [sym_tableextension_declaration] = STATE(1970),
    [sym_pageextension_declaration] = STATE(1970),
    [sym_reportextension_declaration] = STATE(1970),
    [sym_enumextension_declaration] = STATE(1970),
    [sym_permissionsetextension_declaration] = STATE(1970),
    [sym_controladdin_declaration] = STATE(1970),
    [sym_profile_declaration] = STATE(1970),
    [sym_entitlement_declaration] = STATE(1970),
    [sym_profileextension_declaration] = STATE(1970),
    [sym_interface_declaration] = STATE(1970),
    [sym_pagecustomization_declaration] = STATE(1970),
    [sym_dotnet_declaration] = STATE(1970),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2763),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1970),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1900)] = {
    [sym_preproc_conditional_object] = STATE(1951),
    [sym_namespace_declaration] = STATE(1972),
    [sym_using_statement] = STATE(1951),
    [sym__object] = STATE(1951),
    [sym_preproc_split_declaration] = STATE(1951),
    [sym_table_declaration] = STATE(1951),
    [sym_page_declaration] = STATE(1951),
    [sym_report_declaration] = STATE(1951),
    [sym_query_declaration] = STATE(1951),
    [sym_xmlport_declaration] = STATE(1951),
    [sym_permissionset_declaration] = STATE(1951),
    [sym_codeunit_declaration] = STATE(1951),
    [sym_enum_declaration] = STATE(1951),
    [sym_tableextension_declaration] = STATE(1951),
    [sym_pageextension_declaration] = STATE(1951),
    [sym_reportextension_declaration] = STATE(1951),
    [sym_enumextension_declaration] = STATE(1951),
    [sym_permissionsetextension_declaration] = STATE(1951),
    [sym_controladdin_declaration] = STATE(1951),
    [sym_profile_declaration] = STATE(1951),
    [sym_entitlement_declaration] = STATE(1951),
    [sym_profileextension_declaration] = STATE(1951),
    [sym_interface_declaration] = STATE(1951),
    [sym_pagecustomization_declaration] = STATE(1951),
    [sym_dotnet_declaration] = STATE(1951),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3684),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1951),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1901)] = {
    [sym_preproc_conditional_object] = STATE(1966),
    [sym_namespace_declaration] = STATE(1996),
    [sym_using_statement] = STATE(1966),
    [sym__object] = STATE(1966),
    [sym_preproc_split_declaration] = STATE(1966),
    [sym_table_declaration] = STATE(1966),
    [sym_page_declaration] = STATE(1966),
    [sym_report_declaration] = STATE(1966),
    [sym_query_declaration] = STATE(1966),
    [sym_xmlport_declaration] = STATE(1966),
    [sym_permissionset_declaration] = STATE(1966),
    [sym_codeunit_declaration] = STATE(1966),
    [sym_enum_declaration] = STATE(1966),
    [sym_tableextension_declaration] = STATE(1966),
    [sym_pageextension_declaration] = STATE(1966),
    [sym_reportextension_declaration] = STATE(1966),
    [sym_enumextension_declaration] = STATE(1966),
    [sym_permissionsetextension_declaration] = STATE(1966),
    [sym_controladdin_declaration] = STATE(1966),
    [sym_profile_declaration] = STATE(1966),
    [sym_entitlement_declaration] = STATE(1966),
    [sym_profileextension_declaration] = STATE(1966),
    [sym_interface_declaration] = STATE(1966),
    [sym_pagecustomization_declaration] = STATE(1966),
    [sym_dotnet_declaration] = STATE(1966),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3717),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1966),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1902)] = {
    [sym_preproc_conditional_object] = STATE(1985),
    [sym_namespace_declaration] = STATE(1986),
    [sym_using_statement] = STATE(1985),
    [sym__object] = STATE(1985),
    [sym_preproc_split_declaration] = STATE(1985),
    [sym_table_declaration] = STATE(1985),
    [sym_page_declaration] = STATE(1985),
    [sym_report_declaration] = STATE(1985),
    [sym_query_declaration] = STATE(1985),
    [sym_xmlport_declaration] = STATE(1985),
    [sym_permissionset_declaration] = STATE(1985),
    [sym_codeunit_declaration] = STATE(1985),
    [sym_enum_declaration] = STATE(1985),
    [sym_tableextension_declaration] = STATE(1985),
    [sym_pageextension_declaration] = STATE(1985),
    [sym_reportextension_declaration] = STATE(1985),
    [sym_enumextension_declaration] = STATE(1985),
    [sym_permissionsetextension_declaration] = STATE(1985),
    [sym_controladdin_declaration] = STATE(1985),
    [sym_profile_declaration] = STATE(1985),
    [sym_entitlement_declaration] = STATE(1985),
    [sym_profileextension_declaration] = STATE(1985),
    [sym_interface_declaration] = STATE(1985),
    [sym_pagecustomization_declaration] = STATE(1985),
    [sym_dotnet_declaration] = STATE(1985),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2802),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1985),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1903)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1886),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(4163),
    [anon_sym_DASH] = ACTIONS(602),
    [aux_sym_boolean_token1] = ACTIONS(602),
    [aux_sym_boolean_token2] = ACTIONS(602),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(602),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(602),
    [aux_sym_basic_type_token21] = ACTIONS(602),
    [aux_sym_basic_type_token22] = ACTIONS(602),
    [aux_sym_basic_type_token48] = ACTIONS(602),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(602),
    [aux_sym_keyword_identifier_token1] = ACTIONS(602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(602),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(602),
    [anon_sym_IF] = ACTIONS(602),
    [anon_sym_If] = ACTIONS(602),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_case] = ACTIONS(602),
    [anon_sym_CASE] = ACTIONS(602),
    [anon_sym_Case] = ACTIONS(602),
    [anon_sym_for] = ACTIONS(602),
    [anon_sym_FOR] = ACTIONS(602),
    [anon_sym_For] = ACTIONS(602),
    [anon_sym_foreach] = ACTIONS(602),
    [anon_sym_FOREACH] = ACTIONS(602),
    [anon_sym_Foreach] = ACTIONS(602),
    [anon_sym_while] = ACTIONS(602),
    [anon_sym_WHILE] = ACTIONS(602),
    [anon_sym_While] = ACTIONS(602),
    [anon_sym_repeat] = ACTIONS(602),
    [anon_sym_REPEAT] = ACTIONS(602),
    [anon_sym_Repeat] = ACTIONS(602),
    [anon_sym_until] = ACTIONS(602),
    [anon_sym_UNTIL] = ACTIONS(602),
    [anon_sym_Until] = ACTIONS(602),
    [anon_sym_exit] = ACTIONS(602),
    [anon_sym_EXIT] = ACTIONS(602),
    [anon_sym_Exit] = ACTIONS(602),
    [anon_sym_continue] = ACTIONS(602),
    [anon_sym_CONTINUE] = ACTIONS(602),
    [anon_sym_Continue] = ACTIONS(602),
    [anon_sym_break] = ACTIONS(602),
    [anon_sym_BREAK] = ACTIONS(602),
    [anon_sym_Break] = ACTIONS(602),
    [anon_sym_with] = ACTIONS(602),
    [anon_sym_WITH] = ACTIONS(602),
    [anon_sym_With] = ACTIONS(602),
    [sym_asserterror_keyword] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_page_keyword] = ACTIONS(602),
    [anon_sym_codeunit] = ACTIONS(602),
    [anon_sym_CODEUNIT] = ACTIONS(602),
    [anon_sym_Codeunit] = ACTIONS(602),
    [anon_sym_CodeUnit] = ACTIONS(602),
    [anon_sym_COdeunit] = ACTIONS(602),
    [anon_sym_codeUnit] = ACTIONS(602),
    [sym_report_keyword] = ACTIONS(602),
    [sym_query_keyword] = ACTIONS(602),
    [anon_sym_xmlport] = ACTIONS(602),
    [anon_sym_XMLPORT] = ACTIONS(602),
    [anon_sym_Xmlport] = ACTIONS(602),
    [anon_sym_XMLport] = ACTIONS(602),
    [anon_sym_XMLPort] = ACTIONS(602),
    [anon_sym_XmlPort] = ACTIONS(602),
    [anon_sym_enum] = ACTIONS(602),
    [anon_sym_ENUM] = ACTIONS(602),
    [anon_sym_Enum] = ACTIONS(602),
    [anon_sym_eNUM] = ACTIONS(602),
    [anon_sym_eNum] = ACTIONS(602),
    [anon_sym_ENum] = ACTIONS(602),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(600),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(602),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
  },
  [STATE(1904)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_until] = ACTIONS(3566),
    [anon_sym_UNTIL] = ACTIONS(3566),
    [anon_sym_Until] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(1905)] = {
    [sym_preproc_conditional_object] = STATE(1976),
    [sym_namespace_declaration] = STATE(1974),
    [sym_using_statement] = STATE(1976),
    [sym__object] = STATE(1976),
    [sym_preproc_split_declaration] = STATE(1976),
    [sym_table_declaration] = STATE(1976),
    [sym_page_declaration] = STATE(1976),
    [sym_report_declaration] = STATE(1976),
    [sym_query_declaration] = STATE(1976),
    [sym_xmlport_declaration] = STATE(1976),
    [sym_permissionset_declaration] = STATE(1976),
    [sym_codeunit_declaration] = STATE(1976),
    [sym_enum_declaration] = STATE(1976),
    [sym_tableextension_declaration] = STATE(1976),
    [sym_pageextension_declaration] = STATE(1976),
    [sym_reportextension_declaration] = STATE(1976),
    [sym_enumextension_declaration] = STATE(1976),
    [sym_permissionsetextension_declaration] = STATE(1976),
    [sym_controladdin_declaration] = STATE(1976),
    [sym_profile_declaration] = STATE(1976),
    [sym_entitlement_declaration] = STATE(1976),
    [sym_profileextension_declaration] = STATE(1976),
    [sym_interface_declaration] = STATE(1976),
    [sym_pagecustomization_declaration] = STATE(1976),
    [sym_dotnet_declaration] = STATE(1976),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3687),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1976),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1906)] = {
    [sym_identifier] = ACTIONS(3651),
    [anon_sym_SEMI] = ACTIONS(3653),
    [anon_sym_DOT] = ACTIONS(3651),
    [anon_sym_EQ] = ACTIONS(3653),
    [anon_sym_COMMA] = ACTIONS(3653),
    [anon_sym_DASH] = ACTIONS(3651),
    [aux_sym_boolean_token1] = ACTIONS(3651),
    [aux_sym_boolean_token2] = ACTIONS(3651),
    [sym_decimal] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3653),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3651),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_LBRACK] = ACTIONS(3653),
    [aux_sym_record_type_token1] = ACTIONS(3651),
    [aux_sym_basic_type_token21] = ACTIONS(3651),
    [aux_sym_basic_type_token22] = ACTIONS(3651),
    [aux_sym_basic_type_token48] = ACTIONS(3651),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3651),
    [anon_sym_COLON_COLON] = ACTIONS(3653),
    [anon_sym_POUNDif] = ACTIONS(3653),
    [anon_sym_POUNDIF] = ACTIONS(3653),
    [anon_sym_POUNDIf] = ACTIONS(3653),
    [anon_sym_not] = ACTIONS(3651),
    [anon_sym_NOT] = ACTIONS(3651),
    [anon_sym_Not] = ACTIONS(3651),
    [anon_sym_POUNDelse] = ACTIONS(3653),
    [anon_sym_POUNDELSE] = ACTIONS(3653),
    [anon_sym_POUNDElse] = ACTIONS(3653),
    [anon_sym_POUNDelse2] = ACTIONS(3653),
    [anon_sym_POUNDELSE2] = ACTIONS(3653),
    [anon_sym_POUNDElse2] = ACTIONS(3653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3653),
    [aux_sym__expression_token1] = ACTIONS(3653),
    [aux_sym__expression_token2] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3651),
    [anon_sym_SLASH] = ACTIONS(3651),
    [anon_sym_div] = ACTIONS(3651),
    [anon_sym_DIV] = ACTIONS(3651),
    [anon_sym_Div] = ACTIONS(3651),
    [anon_sym_mod] = ACTIONS(3651),
    [anon_sym_MOD] = ACTIONS(3651),
    [anon_sym_Mod] = ACTIONS(3651),
    [anon_sym_PLUS] = ACTIONS(3651),
    [anon_sym_GT_EQ] = ACTIONS(3653),
    [anon_sym_LT_EQ] = ACTIONS(3653),
    [anon_sym_GT] = ACTIONS(3651),
    [anon_sym_LT] = ACTIONS(3651),
    [anon_sym_LT_GT] = ACTIONS(3653),
    [anon_sym_and] = ACTIONS(3651),
    [anon_sym_AND] = ACTIONS(3651),
    [anon_sym_And] = ACTIONS(3651),
    [anon_sym_or] = ACTIONS(3651),
    [anon_sym_OR] = ACTIONS(3651),
    [anon_sym_Or] = ACTIONS(3651),
    [anon_sym_xor] = ACTIONS(3651),
    [anon_sym_XOR] = ACTIONS(3651),
    [anon_sym_Xor] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [sym_datetime_literal] = ACTIONS(3653),
    [sym_date_literal] = ACTIONS(3651),
    [sym_time_literal] = ACTIONS(3651),
    [sym_biginteger_literal] = ACTIONS(3653),
    [anon_sym_if] = ACTIONS(3651),
    [anon_sym_IF] = ACTIONS(3651),
    [anon_sym_If] = ACTIONS(3651),
    [anon_sym_else] = ACTIONS(3651),
    [anon_sym_ELSE] = ACTIONS(3651),
    [anon_sym_Else] = ACTIONS(3651),
    [anon_sym_case] = ACTIONS(3651),
    [anon_sym_CASE] = ACTIONS(3651),
    [anon_sym_Case] = ACTIONS(3651),
    [anon_sym_for] = ACTIONS(3651),
    [anon_sym_FOR] = ACTIONS(3651),
    [anon_sym_For] = ACTIONS(3651),
    [anon_sym_foreach] = ACTIONS(3651),
    [anon_sym_FOREACH] = ACTIONS(3651),
    [anon_sym_Foreach] = ACTIONS(3651),
    [anon_sym_while] = ACTIONS(3651),
    [anon_sym_WHILE] = ACTIONS(3651),
    [anon_sym_While] = ACTIONS(3651),
    [anon_sym_repeat] = ACTIONS(3651),
    [anon_sym_REPEAT] = ACTIONS(3651),
    [anon_sym_Repeat] = ACTIONS(3651),
    [anon_sym_until] = ACTIONS(3651),
    [anon_sym_UNTIL] = ACTIONS(3651),
    [anon_sym_Until] = ACTIONS(3651),
    [anon_sym_exit] = ACTIONS(3651),
    [anon_sym_EXIT] = ACTIONS(3651),
    [anon_sym_Exit] = ACTIONS(3651),
    [anon_sym_continue] = ACTIONS(3651),
    [anon_sym_CONTINUE] = ACTIONS(3651),
    [anon_sym_Continue] = ACTIONS(3651),
    [anon_sym_break] = ACTIONS(3651),
    [anon_sym_BREAK] = ACTIONS(3651),
    [anon_sym_Break] = ACTIONS(3651),
    [anon_sym_with] = ACTIONS(3651),
    [anon_sym_WITH] = ACTIONS(3651),
    [anon_sym_With] = ACTIONS(3651),
    [sym_asserterror_keyword] = ACTIONS(3653),
    [anon_sym_in] = ACTIONS(3651),
    [anon_sym_IN] = ACTIONS(3651),
    [anon_sym_In] = ACTIONS(3651),
    [sym_page_keyword] = ACTIONS(3651),
    [anon_sym_codeunit] = ACTIONS(3651),
    [anon_sym_CODEUNIT] = ACTIONS(3651),
    [anon_sym_Codeunit] = ACTIONS(3651),
    [anon_sym_CodeUnit] = ACTIONS(3651),
    [anon_sym_COdeunit] = ACTIONS(3651),
    [anon_sym_codeUnit] = ACTIONS(3651),
    [sym_report_keyword] = ACTIONS(3651),
    [sym_query_keyword] = ACTIONS(3651),
    [anon_sym_xmlport] = ACTIONS(3651),
    [anon_sym_XMLPORT] = ACTIONS(3651),
    [anon_sym_Xmlport] = ACTIONS(3651),
    [anon_sym_XMLport] = ACTIONS(3651),
    [anon_sym_XMLPort] = ACTIONS(3651),
    [anon_sym_XmlPort] = ACTIONS(3651),
    [anon_sym_enum] = ACTIONS(3651),
    [anon_sym_ENUM] = ACTIONS(3651),
    [anon_sym_Enum] = ACTIONS(3651),
    [anon_sym_eNUM] = ACTIONS(3651),
    [anon_sym_eNum] = ACTIONS(3651),
    [anon_sym_ENum] = ACTIONS(3651),
    [sym_quoted_identifier] = ACTIONS(3653),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3653),
    [sym_verbatim_string] = ACTIONS(3653),
    [sym_integer] = ACTIONS(3651),
    [sym_continue_as_identifier] = ACTIONS(3653),
    [sym_preproc_open] = ACTIONS(3653),
  },
  [STATE(1907)] = {
    [sym_identifier] = ACTIONS(3655),
    [anon_sym_SEMI] = ACTIONS(3657),
    [anon_sym_DOT] = ACTIONS(3655),
    [anon_sym_EQ] = ACTIONS(3657),
    [anon_sym_COMMA] = ACTIONS(3657),
    [anon_sym_DASH] = ACTIONS(3655),
    [aux_sym_boolean_token1] = ACTIONS(3655),
    [aux_sym_boolean_token2] = ACTIONS(3655),
    [sym_decimal] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3657),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3655),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [aux_sym_record_type_token1] = ACTIONS(3655),
    [aux_sym_basic_type_token21] = ACTIONS(3655),
    [aux_sym_basic_type_token22] = ACTIONS(3655),
    [aux_sym_basic_type_token48] = ACTIONS(3655),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3655),
    [anon_sym_COLON_COLON] = ACTIONS(3657),
    [anon_sym_POUNDif] = ACTIONS(3657),
    [anon_sym_POUNDIF] = ACTIONS(3657),
    [anon_sym_POUNDIf] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3655),
    [anon_sym_NOT] = ACTIONS(3655),
    [anon_sym_Not] = ACTIONS(3655),
    [anon_sym_POUNDelse] = ACTIONS(3657),
    [anon_sym_POUNDELSE] = ACTIONS(3657),
    [anon_sym_POUNDElse] = ACTIONS(3657),
    [anon_sym_POUNDelse2] = ACTIONS(3657),
    [anon_sym_POUNDELSE2] = ACTIONS(3657),
    [anon_sym_POUNDElse2] = ACTIONS(3657),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3657),
    [aux_sym__expression_token1] = ACTIONS(3657),
    [aux_sym__expression_token2] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3655),
    [anon_sym_SLASH] = ACTIONS(3655),
    [anon_sym_div] = ACTIONS(3655),
    [anon_sym_DIV] = ACTIONS(3655),
    [anon_sym_Div] = ACTIONS(3655),
    [anon_sym_mod] = ACTIONS(3655),
    [anon_sym_MOD] = ACTIONS(3655),
    [anon_sym_Mod] = ACTIONS(3655),
    [anon_sym_PLUS] = ACTIONS(3655),
    [anon_sym_GT_EQ] = ACTIONS(3657),
    [anon_sym_LT_EQ] = ACTIONS(3657),
    [anon_sym_GT] = ACTIONS(3655),
    [anon_sym_LT] = ACTIONS(3655),
    [anon_sym_LT_GT] = ACTIONS(3657),
    [anon_sym_and] = ACTIONS(3655),
    [anon_sym_AND] = ACTIONS(3655),
    [anon_sym_And] = ACTIONS(3655),
    [anon_sym_or] = ACTIONS(3655),
    [anon_sym_OR] = ACTIONS(3655),
    [anon_sym_Or] = ACTIONS(3655),
    [anon_sym_xor] = ACTIONS(3655),
    [anon_sym_XOR] = ACTIONS(3655),
    [anon_sym_Xor] = ACTIONS(3655),
    [anon_sym_QMARK] = ACTIONS(3657),
    [sym_datetime_literal] = ACTIONS(3657),
    [sym_date_literal] = ACTIONS(3655),
    [sym_time_literal] = ACTIONS(3655),
    [sym_biginteger_literal] = ACTIONS(3657),
    [anon_sym_if] = ACTIONS(3655),
    [anon_sym_IF] = ACTIONS(3655),
    [anon_sym_If] = ACTIONS(3655),
    [anon_sym_else] = ACTIONS(3655),
    [anon_sym_ELSE] = ACTIONS(3655),
    [anon_sym_Else] = ACTIONS(3655),
    [anon_sym_case] = ACTIONS(3655),
    [anon_sym_CASE] = ACTIONS(3655),
    [anon_sym_Case] = ACTIONS(3655),
    [anon_sym_for] = ACTIONS(3655),
    [anon_sym_FOR] = ACTIONS(3655),
    [anon_sym_For] = ACTIONS(3655),
    [anon_sym_foreach] = ACTIONS(3655),
    [anon_sym_FOREACH] = ACTIONS(3655),
    [anon_sym_Foreach] = ACTIONS(3655),
    [anon_sym_while] = ACTIONS(3655),
    [anon_sym_WHILE] = ACTIONS(3655),
    [anon_sym_While] = ACTIONS(3655),
    [anon_sym_repeat] = ACTIONS(3655),
    [anon_sym_REPEAT] = ACTIONS(3655),
    [anon_sym_Repeat] = ACTIONS(3655),
    [anon_sym_until] = ACTIONS(3655),
    [anon_sym_UNTIL] = ACTIONS(3655),
    [anon_sym_Until] = ACTIONS(3655),
    [anon_sym_exit] = ACTIONS(3655),
    [anon_sym_EXIT] = ACTIONS(3655),
    [anon_sym_Exit] = ACTIONS(3655),
    [anon_sym_continue] = ACTIONS(3655),
    [anon_sym_CONTINUE] = ACTIONS(3655),
    [anon_sym_Continue] = ACTIONS(3655),
    [anon_sym_break] = ACTIONS(3655),
    [anon_sym_BREAK] = ACTIONS(3655),
    [anon_sym_Break] = ACTIONS(3655),
    [anon_sym_with] = ACTIONS(3655),
    [anon_sym_WITH] = ACTIONS(3655),
    [anon_sym_With] = ACTIONS(3655),
    [sym_asserterror_keyword] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3655),
    [anon_sym_IN] = ACTIONS(3655),
    [anon_sym_In] = ACTIONS(3655),
    [sym_page_keyword] = ACTIONS(3655),
    [anon_sym_codeunit] = ACTIONS(3655),
    [anon_sym_CODEUNIT] = ACTIONS(3655),
    [anon_sym_Codeunit] = ACTIONS(3655),
    [anon_sym_CodeUnit] = ACTIONS(3655),
    [anon_sym_COdeunit] = ACTIONS(3655),
    [anon_sym_codeUnit] = ACTIONS(3655),
    [sym_report_keyword] = ACTIONS(3655),
    [sym_query_keyword] = ACTIONS(3655),
    [anon_sym_xmlport] = ACTIONS(3655),
    [anon_sym_XMLPORT] = ACTIONS(3655),
    [anon_sym_Xmlport] = ACTIONS(3655),
    [anon_sym_XMLport] = ACTIONS(3655),
    [anon_sym_XMLPort] = ACTIONS(3655),
    [anon_sym_XmlPort] = ACTIONS(3655),
    [anon_sym_enum] = ACTIONS(3655),
    [anon_sym_ENUM] = ACTIONS(3655),
    [anon_sym_Enum] = ACTIONS(3655),
    [anon_sym_eNUM] = ACTIONS(3655),
    [anon_sym_eNum] = ACTIONS(3655),
    [anon_sym_ENum] = ACTIONS(3655),
    [sym_quoted_identifier] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3657),
    [sym_verbatim_string] = ACTIONS(3657),
    [sym_integer] = ACTIONS(3655),
    [sym_continue_as_identifier] = ACTIONS(3657),
    [sym_preproc_open] = ACTIONS(3657),
  },
  [STATE(1908)] = {
    [sym_identifier] = ACTIONS(3659),
    [anon_sym_SEMI] = ACTIONS(3661),
    [anon_sym_DOT] = ACTIONS(3659),
    [anon_sym_EQ] = ACTIONS(3661),
    [anon_sym_COMMA] = ACTIONS(3661),
    [anon_sym_DASH] = ACTIONS(3659),
    [aux_sym_boolean_token1] = ACTIONS(3659),
    [aux_sym_boolean_token2] = ACTIONS(3659),
    [sym_decimal] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3661),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3661),
    [aux_sym_record_type_token1] = ACTIONS(3659),
    [aux_sym_basic_type_token21] = ACTIONS(3659),
    [aux_sym_basic_type_token22] = ACTIONS(3659),
    [aux_sym_basic_type_token48] = ACTIONS(3659),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3659),
    [anon_sym_COLON_COLON] = ACTIONS(3661),
    [anon_sym_POUNDif] = ACTIONS(3661),
    [anon_sym_POUNDIF] = ACTIONS(3661),
    [anon_sym_POUNDIf] = ACTIONS(3661),
    [anon_sym_not] = ACTIONS(3659),
    [anon_sym_NOT] = ACTIONS(3659),
    [anon_sym_Not] = ACTIONS(3659),
    [anon_sym_POUNDelse] = ACTIONS(3661),
    [anon_sym_POUNDELSE] = ACTIONS(3661),
    [anon_sym_POUNDElse] = ACTIONS(3661),
    [anon_sym_POUNDelse2] = ACTIONS(3661),
    [anon_sym_POUNDELSE2] = ACTIONS(3661),
    [anon_sym_POUNDElse2] = ACTIONS(3661),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3661),
    [aux_sym__expression_token1] = ACTIONS(3661),
    [aux_sym__expression_token2] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3659),
    [anon_sym_SLASH] = ACTIONS(3659),
    [anon_sym_div] = ACTIONS(3659),
    [anon_sym_DIV] = ACTIONS(3659),
    [anon_sym_Div] = ACTIONS(3659),
    [anon_sym_mod] = ACTIONS(3659),
    [anon_sym_MOD] = ACTIONS(3659),
    [anon_sym_Mod] = ACTIONS(3659),
    [anon_sym_PLUS] = ACTIONS(3659),
    [anon_sym_GT_EQ] = ACTIONS(3661),
    [anon_sym_LT_EQ] = ACTIONS(3661),
    [anon_sym_GT] = ACTIONS(3659),
    [anon_sym_LT] = ACTIONS(3659),
    [anon_sym_LT_GT] = ACTIONS(3661),
    [anon_sym_and] = ACTIONS(3659),
    [anon_sym_AND] = ACTIONS(3659),
    [anon_sym_And] = ACTIONS(3659),
    [anon_sym_or] = ACTIONS(3659),
    [anon_sym_OR] = ACTIONS(3659),
    [anon_sym_Or] = ACTIONS(3659),
    [anon_sym_xor] = ACTIONS(3659),
    [anon_sym_XOR] = ACTIONS(3659),
    [anon_sym_Xor] = ACTIONS(3659),
    [anon_sym_QMARK] = ACTIONS(3661),
    [sym_datetime_literal] = ACTIONS(3661),
    [sym_date_literal] = ACTIONS(3659),
    [sym_time_literal] = ACTIONS(3659),
    [sym_biginteger_literal] = ACTIONS(3661),
    [anon_sym_if] = ACTIONS(3659),
    [anon_sym_IF] = ACTIONS(3659),
    [anon_sym_If] = ACTIONS(3659),
    [anon_sym_else] = ACTIONS(3659),
    [anon_sym_ELSE] = ACTIONS(3659),
    [anon_sym_Else] = ACTIONS(3659),
    [anon_sym_case] = ACTIONS(3659),
    [anon_sym_CASE] = ACTIONS(3659),
    [anon_sym_Case] = ACTIONS(3659),
    [anon_sym_for] = ACTIONS(3659),
    [anon_sym_FOR] = ACTIONS(3659),
    [anon_sym_For] = ACTIONS(3659),
    [anon_sym_foreach] = ACTIONS(3659),
    [anon_sym_FOREACH] = ACTIONS(3659),
    [anon_sym_Foreach] = ACTIONS(3659),
    [anon_sym_while] = ACTIONS(3659),
    [anon_sym_WHILE] = ACTIONS(3659),
    [anon_sym_While] = ACTIONS(3659),
    [anon_sym_repeat] = ACTIONS(3659),
    [anon_sym_REPEAT] = ACTIONS(3659),
    [anon_sym_Repeat] = ACTIONS(3659),
    [anon_sym_until] = ACTIONS(3659),
    [anon_sym_UNTIL] = ACTIONS(3659),
    [anon_sym_Until] = ACTIONS(3659),
    [anon_sym_exit] = ACTIONS(3659),
    [anon_sym_EXIT] = ACTIONS(3659),
    [anon_sym_Exit] = ACTIONS(3659),
    [anon_sym_continue] = ACTIONS(3659),
    [anon_sym_CONTINUE] = ACTIONS(3659),
    [anon_sym_Continue] = ACTIONS(3659),
    [anon_sym_break] = ACTIONS(3659),
    [anon_sym_BREAK] = ACTIONS(3659),
    [anon_sym_Break] = ACTIONS(3659),
    [anon_sym_with] = ACTIONS(3659),
    [anon_sym_WITH] = ACTIONS(3659),
    [anon_sym_With] = ACTIONS(3659),
    [sym_asserterror_keyword] = ACTIONS(3661),
    [anon_sym_in] = ACTIONS(3659),
    [anon_sym_IN] = ACTIONS(3659),
    [anon_sym_In] = ACTIONS(3659),
    [sym_page_keyword] = ACTIONS(3659),
    [anon_sym_codeunit] = ACTIONS(3659),
    [anon_sym_CODEUNIT] = ACTIONS(3659),
    [anon_sym_Codeunit] = ACTIONS(3659),
    [anon_sym_CodeUnit] = ACTIONS(3659),
    [anon_sym_COdeunit] = ACTIONS(3659),
    [anon_sym_codeUnit] = ACTIONS(3659),
    [sym_report_keyword] = ACTIONS(3659),
    [sym_query_keyword] = ACTIONS(3659),
    [anon_sym_xmlport] = ACTIONS(3659),
    [anon_sym_XMLPORT] = ACTIONS(3659),
    [anon_sym_Xmlport] = ACTIONS(3659),
    [anon_sym_XMLport] = ACTIONS(3659),
    [anon_sym_XMLPort] = ACTIONS(3659),
    [anon_sym_XmlPort] = ACTIONS(3659),
    [anon_sym_enum] = ACTIONS(3659),
    [anon_sym_ENUM] = ACTIONS(3659),
    [anon_sym_Enum] = ACTIONS(3659),
    [anon_sym_eNUM] = ACTIONS(3659),
    [anon_sym_eNum] = ACTIONS(3659),
    [anon_sym_ENum] = ACTIONS(3659),
    [sym_quoted_identifier] = ACTIONS(3661),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3661),
    [sym_verbatim_string] = ACTIONS(3661),
    [sym_integer] = ACTIONS(3659),
    [sym_continue_as_identifier] = ACTIONS(3661),
    [sym_preproc_open] = ACTIONS(3661),
  },
  [STATE(1909)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_until] = ACTIONS(3663),
    [anon_sym_UNTIL] = ACTIONS(3663),
    [anon_sym_Until] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
  },
  [STATE(1910)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3726),
    [anon_sym_SEMI] = ACTIONS(3728),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3728),
    [anon_sym_DASH] = ACTIONS(3726),
    [aux_sym_boolean_token1] = ACTIONS(3726),
    [aux_sym_boolean_token2] = ACTIONS(3726),
    [sym_decimal] = ACTIONS(3726),
    [anon_sym_LPAREN] = ACTIONS(3728),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3726),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3726),
    [aux_sym_basic_type_token21] = ACTIONS(3726),
    [aux_sym_basic_type_token22] = ACTIONS(3726),
    [aux_sym_basic_type_token48] = ACTIONS(3726),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3726),
    [anon_sym_POUNDif] = ACTIONS(3728),
    [anon_sym_POUNDIF] = ACTIONS(3728),
    [anon_sym_POUNDIf] = ACTIONS(3728),
    [anon_sym_not] = ACTIONS(3726),
    [anon_sym_NOT] = ACTIONS(3726),
    [anon_sym_Not] = ACTIONS(3726),
    [anon_sym_POUNDelse] = ACTIONS(3728),
    [anon_sym_POUNDELSE] = ACTIONS(3728),
    [anon_sym_POUNDElse] = ACTIONS(3728),
    [anon_sym_POUNDelse2] = ACTIONS(3728),
    [anon_sym_POUNDELSE2] = ACTIONS(3728),
    [anon_sym_POUNDElse2] = ACTIONS(3728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3728),
    [aux_sym__expression_token1] = ACTIONS(3728),
    [aux_sym__expression_token2] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3726),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(3726),
    [anon_sym_GT_EQ] = ACTIONS(3728),
    [anon_sym_LT_EQ] = ACTIONS(3728),
    [anon_sym_GT] = ACTIONS(3726),
    [anon_sym_LT] = ACTIONS(3726),
    [anon_sym_LT_GT] = ACTIONS(3728),
    [anon_sym_and] = ACTIONS(3726),
    [anon_sym_AND] = ACTIONS(3726),
    [anon_sym_And] = ACTIONS(3726),
    [anon_sym_or] = ACTIONS(3726),
    [anon_sym_OR] = ACTIONS(3726),
    [anon_sym_Or] = ACTIONS(3726),
    [anon_sym_xor] = ACTIONS(3726),
    [anon_sym_XOR] = ACTIONS(3726),
    [anon_sym_Xor] = ACTIONS(3726),
    [anon_sym_QMARK] = ACTIONS(3728),
    [sym_datetime_literal] = ACTIONS(3728),
    [sym_date_literal] = ACTIONS(3726),
    [sym_time_literal] = ACTIONS(3726),
    [sym_biginteger_literal] = ACTIONS(3728),
    [anon_sym_if] = ACTIONS(3726),
    [anon_sym_IF] = ACTIONS(3726),
    [anon_sym_If] = ACTIONS(3726),
    [anon_sym_else] = ACTIONS(3726),
    [anon_sym_ELSE] = ACTIONS(3726),
    [anon_sym_Else] = ACTIONS(3726),
    [anon_sym_case] = ACTIONS(3726),
    [anon_sym_CASE] = ACTIONS(3726),
    [anon_sym_Case] = ACTIONS(3726),
    [anon_sym_for] = ACTIONS(3726),
    [anon_sym_FOR] = ACTIONS(3726),
    [anon_sym_For] = ACTIONS(3726),
    [anon_sym_foreach] = ACTIONS(3726),
    [anon_sym_FOREACH] = ACTIONS(3726),
    [anon_sym_Foreach] = ACTIONS(3726),
    [anon_sym_while] = ACTIONS(3726),
    [anon_sym_WHILE] = ACTIONS(3726),
    [anon_sym_While] = ACTIONS(3726),
    [anon_sym_repeat] = ACTIONS(3726),
    [anon_sym_REPEAT] = ACTIONS(3726),
    [anon_sym_Repeat] = ACTIONS(3726),
    [anon_sym_until] = ACTIONS(3726),
    [anon_sym_UNTIL] = ACTIONS(3726),
    [anon_sym_Until] = ACTIONS(3726),
    [anon_sym_exit] = ACTIONS(3726),
    [anon_sym_EXIT] = ACTIONS(3726),
    [anon_sym_Exit] = ACTIONS(3726),
    [anon_sym_continue] = ACTIONS(3726),
    [anon_sym_CONTINUE] = ACTIONS(3726),
    [anon_sym_Continue] = ACTIONS(3726),
    [anon_sym_break] = ACTIONS(3726),
    [anon_sym_BREAK] = ACTIONS(3726),
    [anon_sym_Break] = ACTIONS(3726),
    [anon_sym_with] = ACTIONS(3726),
    [anon_sym_WITH] = ACTIONS(3726),
    [anon_sym_With] = ACTIONS(3726),
    [sym_asserterror_keyword] = ACTIONS(3728),
    [anon_sym_in] = ACTIONS(3726),
    [anon_sym_IN] = ACTIONS(3726),
    [anon_sym_In] = ACTIONS(3726),
    [sym_page_keyword] = ACTIONS(3726),
    [anon_sym_codeunit] = ACTIONS(3726),
    [anon_sym_CODEUNIT] = ACTIONS(3726),
    [anon_sym_Codeunit] = ACTIONS(3726),
    [anon_sym_CodeUnit] = ACTIONS(3726),
    [anon_sym_COdeunit] = ACTIONS(3726),
    [anon_sym_codeUnit] = ACTIONS(3726),
    [sym_report_keyword] = ACTIONS(3726),
    [sym_query_keyword] = ACTIONS(3726),
    [anon_sym_xmlport] = ACTIONS(3726),
    [anon_sym_XMLPORT] = ACTIONS(3726),
    [anon_sym_Xmlport] = ACTIONS(3726),
    [anon_sym_XMLport] = ACTIONS(3726),
    [anon_sym_XMLPort] = ACTIONS(3726),
    [anon_sym_XmlPort] = ACTIONS(3726),
    [anon_sym_enum] = ACTIONS(3726),
    [anon_sym_ENUM] = ACTIONS(3726),
    [anon_sym_Enum] = ACTIONS(3726),
    [anon_sym_eNUM] = ACTIONS(3726),
    [anon_sym_eNum] = ACTIONS(3726),
    [anon_sym_ENum] = ACTIONS(3726),
    [sym_quoted_identifier] = ACTIONS(3728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3728),
    [sym_verbatim_string] = ACTIONS(3728),
    [sym_integer] = ACTIONS(3726),
    [sym_continue_as_identifier] = ACTIONS(3728),
    [sym_preproc_open] = ACTIONS(3728),
  },
  [STATE(1911)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_if] = ACTIONS(3677),
    [anon_sym_IF] = ACTIONS(3677),
    [anon_sym_If] = ACTIONS(3677),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_case] = ACTIONS(3677),
    [anon_sym_CASE] = ACTIONS(3677),
    [anon_sym_Case] = ACTIONS(3677),
    [anon_sym_for] = ACTIONS(3677),
    [anon_sym_FOR] = ACTIONS(3677),
    [anon_sym_For] = ACTIONS(3677),
    [anon_sym_foreach] = ACTIONS(3677),
    [anon_sym_FOREACH] = ACTIONS(3677),
    [anon_sym_Foreach] = ACTIONS(3677),
    [anon_sym_while] = ACTIONS(3677),
    [anon_sym_WHILE] = ACTIONS(3677),
    [anon_sym_While] = ACTIONS(3677),
    [anon_sym_repeat] = ACTIONS(3677),
    [anon_sym_REPEAT] = ACTIONS(3677),
    [anon_sym_Repeat] = ACTIONS(3677),
    [anon_sym_until] = ACTIONS(3677),
    [anon_sym_UNTIL] = ACTIONS(3677),
    [anon_sym_Until] = ACTIONS(3677),
    [anon_sym_exit] = ACTIONS(3677),
    [anon_sym_EXIT] = ACTIONS(3677),
    [anon_sym_Exit] = ACTIONS(3677),
    [anon_sym_continue] = ACTIONS(3677),
    [anon_sym_CONTINUE] = ACTIONS(3677),
    [anon_sym_Continue] = ACTIONS(3677),
    [anon_sym_break] = ACTIONS(3677),
    [anon_sym_BREAK] = ACTIONS(3677),
    [anon_sym_Break] = ACTIONS(3677),
    [anon_sym_with] = ACTIONS(3677),
    [anon_sym_WITH] = ACTIONS(3677),
    [anon_sym_With] = ACTIONS(3677),
    [sym_asserterror_keyword] = ACTIONS(3679),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
  },
  [STATE(1912)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3639),
    [anon_sym_SEMI] = ACTIONS(3641),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3641),
    [anon_sym_DASH] = ACTIONS(3639),
    [aux_sym_boolean_token1] = ACTIONS(3639),
    [aux_sym_boolean_token2] = ACTIONS(3639),
    [sym_decimal] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3641),
    [anon_sym_DOT_DOT] = ACTIONS(3641),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3639),
    [anon_sym_STAR] = ACTIONS(3639),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3639),
    [aux_sym_basic_type_token21] = ACTIONS(3639),
    [aux_sym_basic_type_token22] = ACTIONS(3639),
    [aux_sym_basic_type_token48] = ACTIONS(3639),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3639),
    [anon_sym_POUNDif] = ACTIONS(3641),
    [anon_sym_POUNDIF] = ACTIONS(3641),
    [anon_sym_POUNDIf] = ACTIONS(3641),
    [anon_sym_not] = ACTIONS(3639),
    [anon_sym_NOT] = ACTIONS(3639),
    [anon_sym_Not] = ACTIONS(3639),
    [anon_sym_POUNDelse] = ACTIONS(3641),
    [anon_sym_POUNDELSE] = ACTIONS(3641),
    [anon_sym_POUNDElse] = ACTIONS(3641),
    [anon_sym_POUNDelse2] = ACTIONS(3641),
    [anon_sym_POUNDELSE2] = ACTIONS(3641),
    [anon_sym_POUNDElse2] = ACTIONS(3641),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3641),
    [aux_sym__expression_token1] = ACTIONS(3641),
    [aux_sym__expression_token2] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3639),
    [anon_sym_SLASH] = ACTIONS(3639),
    [anon_sym_div] = ACTIONS(3639),
    [anon_sym_DIV] = ACTIONS(3639),
    [anon_sym_Div] = ACTIONS(3639),
    [anon_sym_mod] = ACTIONS(3639),
    [anon_sym_MOD] = ACTIONS(3639),
    [anon_sym_Mod] = ACTIONS(3639),
    [anon_sym_PLUS] = ACTIONS(3639),
    [anon_sym_GT_EQ] = ACTIONS(3641),
    [anon_sym_LT_EQ] = ACTIONS(3641),
    [anon_sym_GT] = ACTIONS(3639),
    [anon_sym_LT] = ACTIONS(3639),
    [anon_sym_LT_GT] = ACTIONS(3641),
    [anon_sym_and] = ACTIONS(3639),
    [anon_sym_AND] = ACTIONS(3639),
    [anon_sym_And] = ACTIONS(3639),
    [anon_sym_or] = ACTIONS(3639),
    [anon_sym_OR] = ACTIONS(3639),
    [anon_sym_Or] = ACTIONS(3639),
    [anon_sym_xor] = ACTIONS(3639),
    [anon_sym_XOR] = ACTIONS(3639),
    [anon_sym_Xor] = ACTIONS(3639),
    [anon_sym_QMARK] = ACTIONS(3641),
    [sym_datetime_literal] = ACTIONS(3641),
    [sym_date_literal] = ACTIONS(3639),
    [sym_time_literal] = ACTIONS(3639),
    [sym_biginteger_literal] = ACTIONS(3641),
    [anon_sym_if] = ACTIONS(3639),
    [anon_sym_IF] = ACTIONS(3639),
    [anon_sym_If] = ACTIONS(3639),
    [anon_sym_else] = ACTIONS(3639),
    [anon_sym_ELSE] = ACTIONS(3639),
    [anon_sym_Else] = ACTIONS(3639),
    [anon_sym_case] = ACTIONS(3639),
    [anon_sym_CASE] = ACTIONS(3639),
    [anon_sym_Case] = ACTIONS(3639),
    [anon_sym_for] = ACTIONS(3639),
    [anon_sym_FOR] = ACTIONS(3639),
    [anon_sym_For] = ACTIONS(3639),
    [anon_sym_foreach] = ACTIONS(3639),
    [anon_sym_FOREACH] = ACTIONS(3639),
    [anon_sym_Foreach] = ACTIONS(3639),
    [anon_sym_while] = ACTIONS(3639),
    [anon_sym_WHILE] = ACTIONS(3639),
    [anon_sym_While] = ACTIONS(3639),
    [anon_sym_repeat] = ACTIONS(3639),
    [anon_sym_REPEAT] = ACTIONS(3639),
    [anon_sym_Repeat] = ACTIONS(3639),
    [anon_sym_until] = ACTIONS(3639),
    [anon_sym_UNTIL] = ACTIONS(3639),
    [anon_sym_Until] = ACTIONS(3639),
    [anon_sym_exit] = ACTIONS(3639),
    [anon_sym_EXIT] = ACTIONS(3639),
    [anon_sym_Exit] = ACTIONS(3639),
    [anon_sym_continue] = ACTIONS(3639),
    [anon_sym_CONTINUE] = ACTIONS(3639),
    [anon_sym_Continue] = ACTIONS(3639),
    [anon_sym_break] = ACTIONS(3639),
    [anon_sym_BREAK] = ACTIONS(3639),
    [anon_sym_Break] = ACTIONS(3639),
    [anon_sym_with] = ACTIONS(3639),
    [anon_sym_WITH] = ACTIONS(3639),
    [anon_sym_With] = ACTIONS(3639),
    [sym_asserterror_keyword] = ACTIONS(3641),
    [anon_sym_in] = ACTIONS(3639),
    [anon_sym_IN] = ACTIONS(3639),
    [anon_sym_In] = ACTIONS(3639),
    [sym_page_keyword] = ACTIONS(3639),
    [anon_sym_codeunit] = ACTIONS(3639),
    [anon_sym_CODEUNIT] = ACTIONS(3639),
    [anon_sym_Codeunit] = ACTIONS(3639),
    [anon_sym_CodeUnit] = ACTIONS(3639),
    [anon_sym_COdeunit] = ACTIONS(3639),
    [anon_sym_codeUnit] = ACTIONS(3639),
    [sym_report_keyword] = ACTIONS(3639),
    [sym_query_keyword] = ACTIONS(3639),
    [anon_sym_xmlport] = ACTIONS(3639),
    [anon_sym_XMLPORT] = ACTIONS(3639),
    [anon_sym_Xmlport] = ACTIONS(3639),
    [anon_sym_XMLport] = ACTIONS(3639),
    [anon_sym_XMLPort] = ACTIONS(3639),
    [anon_sym_XmlPort] = ACTIONS(3639),
    [anon_sym_enum] = ACTIONS(3639),
    [anon_sym_ENUM] = ACTIONS(3639),
    [anon_sym_Enum] = ACTIONS(3639),
    [anon_sym_eNUM] = ACTIONS(3639),
    [anon_sym_eNum] = ACTIONS(3639),
    [anon_sym_ENum] = ACTIONS(3639),
    [sym_quoted_identifier] = ACTIONS(3641),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3641),
    [sym_verbatim_string] = ACTIONS(3641),
    [sym_integer] = ACTIONS(3639),
    [sym_continue_as_identifier] = ACTIONS(3641),
    [sym_preproc_open] = ACTIONS(3641),
  },
  [STATE(1913)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_until] = ACTIONS(3566),
    [anon_sym_UNTIL] = ACTIONS(3566),
    [anon_sym_Until] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(1914)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3576),
    [anon_sym_SEMI] = ACTIONS(3578),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3576),
    [aux_sym_boolean_token2] = ACTIONS(3576),
    [sym_decimal] = ACTIONS(3576),
    [anon_sym_LPAREN] = ACTIONS(3578),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3576),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3576),
    [aux_sym_basic_type_token21] = ACTIONS(3576),
    [aux_sym_basic_type_token22] = ACTIONS(3576),
    [aux_sym_basic_type_token48] = ACTIONS(3576),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3576),
    [anon_sym_POUNDif] = ACTIONS(3578),
    [anon_sym_POUNDIF] = ACTIONS(3578),
    [anon_sym_POUNDIf] = ACTIONS(3578),
    [anon_sym_not] = ACTIONS(3576),
    [anon_sym_NOT] = ACTIONS(3576),
    [anon_sym_Not] = ACTIONS(3576),
    [anon_sym_POUNDelse] = ACTIONS(3578),
    [anon_sym_POUNDELSE] = ACTIONS(3578),
    [anon_sym_POUNDElse] = ACTIONS(3578),
    [anon_sym_POUNDelse2] = ACTIONS(3578),
    [anon_sym_POUNDELSE2] = ACTIONS(3578),
    [anon_sym_POUNDElse2] = ACTIONS(3578),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4161),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3576),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3576),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(4147),
    [anon_sym_OR] = ACTIONS(4149),
    [anon_sym_Or] = ACTIONS(4151),
    [anon_sym_xor] = ACTIONS(4153),
    [anon_sym_XOR] = ACTIONS(4155),
    [anon_sym_Xor] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4159),
    [sym_datetime_literal] = ACTIONS(3578),
    [sym_date_literal] = ACTIONS(3576),
    [sym_time_literal] = ACTIONS(3576),
    [sym_biginteger_literal] = ACTIONS(3578),
    [anon_sym_if] = ACTIONS(3576),
    [anon_sym_IF] = ACTIONS(3576),
    [anon_sym_If] = ACTIONS(3576),
    [anon_sym_else] = ACTIONS(3576),
    [anon_sym_ELSE] = ACTIONS(3576),
    [anon_sym_Else] = ACTIONS(3576),
    [anon_sym_case] = ACTIONS(3576),
    [anon_sym_CASE] = ACTIONS(3576),
    [anon_sym_Case] = ACTIONS(3576),
    [anon_sym_for] = ACTIONS(3576),
    [anon_sym_FOR] = ACTIONS(3576),
    [anon_sym_For] = ACTIONS(3576),
    [anon_sym_foreach] = ACTIONS(3576),
    [anon_sym_FOREACH] = ACTIONS(3576),
    [anon_sym_Foreach] = ACTIONS(3576),
    [anon_sym_while] = ACTIONS(3576),
    [anon_sym_WHILE] = ACTIONS(3576),
    [anon_sym_While] = ACTIONS(3576),
    [anon_sym_repeat] = ACTIONS(3576),
    [anon_sym_REPEAT] = ACTIONS(3576),
    [anon_sym_Repeat] = ACTIONS(3576),
    [anon_sym_until] = ACTIONS(3576),
    [anon_sym_UNTIL] = ACTIONS(3576),
    [anon_sym_Until] = ACTIONS(3576),
    [anon_sym_exit] = ACTIONS(3576),
    [anon_sym_EXIT] = ACTIONS(3576),
    [anon_sym_Exit] = ACTIONS(3576),
    [anon_sym_continue] = ACTIONS(3576),
    [anon_sym_CONTINUE] = ACTIONS(3576),
    [anon_sym_Continue] = ACTIONS(3576),
    [anon_sym_break] = ACTIONS(3576),
    [anon_sym_BREAK] = ACTIONS(3576),
    [anon_sym_Break] = ACTIONS(3576),
    [anon_sym_with] = ACTIONS(3576),
    [anon_sym_WITH] = ACTIONS(3576),
    [anon_sym_With] = ACTIONS(3576),
    [sym_asserterror_keyword] = ACTIONS(3578),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3576),
    [anon_sym_codeunit] = ACTIONS(3576),
    [anon_sym_CODEUNIT] = ACTIONS(3576),
    [anon_sym_Codeunit] = ACTIONS(3576),
    [anon_sym_CodeUnit] = ACTIONS(3576),
    [anon_sym_COdeunit] = ACTIONS(3576),
    [anon_sym_codeUnit] = ACTIONS(3576),
    [sym_report_keyword] = ACTIONS(3576),
    [sym_query_keyword] = ACTIONS(3576),
    [anon_sym_xmlport] = ACTIONS(3576),
    [anon_sym_XMLPORT] = ACTIONS(3576),
    [anon_sym_Xmlport] = ACTIONS(3576),
    [anon_sym_XMLport] = ACTIONS(3576),
    [anon_sym_XMLPort] = ACTIONS(3576),
    [anon_sym_XmlPort] = ACTIONS(3576),
    [anon_sym_enum] = ACTIONS(3576),
    [anon_sym_ENUM] = ACTIONS(3576),
    [anon_sym_Enum] = ACTIONS(3576),
    [anon_sym_eNUM] = ACTIONS(3576),
    [anon_sym_eNum] = ACTIONS(3576),
    [anon_sym_ENum] = ACTIONS(3576),
    [sym_quoted_identifier] = ACTIONS(3578),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3578),
    [sym_verbatim_string] = ACTIONS(3578),
    [sym_integer] = ACTIONS(3576),
    [sym_continue_as_identifier] = ACTIONS(3578),
    [sym_preproc_open] = ACTIONS(3578),
  },
  [STATE(1915)] = {
    [sym_preproc_conditional_object] = STATE(2013),
    [sym_namespace_declaration] = STATE(2003),
    [sym_using_statement] = STATE(2013),
    [sym__object] = STATE(2013),
    [sym_preproc_split_declaration] = STATE(2013),
    [sym_table_declaration] = STATE(2013),
    [sym_page_declaration] = STATE(2013),
    [sym_report_declaration] = STATE(2013),
    [sym_query_declaration] = STATE(2013),
    [sym_xmlport_declaration] = STATE(2013),
    [sym_permissionset_declaration] = STATE(2013),
    [sym_codeunit_declaration] = STATE(2013),
    [sym_enum_declaration] = STATE(2013),
    [sym_tableextension_declaration] = STATE(2013),
    [sym_pageextension_declaration] = STATE(2013),
    [sym_reportextension_declaration] = STATE(2013),
    [sym_enumextension_declaration] = STATE(2013),
    [sym_permissionsetextension_declaration] = STATE(2013),
    [sym_controladdin_declaration] = STATE(2013),
    [sym_profile_declaration] = STATE(2013),
    [sym_entitlement_declaration] = STATE(2013),
    [sym_profileextension_declaration] = STATE(2013),
    [sym_interface_declaration] = STATE(2013),
    [sym_pagecustomization_declaration] = STATE(2013),
    [sym_dotnet_declaration] = STATE(2013),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3740),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(2013),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1916)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1917)] = {
    [sym_argument_list] = STATE(1927),
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(4173),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(4175),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_IF] = ACTIONS(3681),
    [anon_sym_If] = ACTIONS(3681),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_case] = ACTIONS(3681),
    [anon_sym_CASE] = ACTIONS(3681),
    [anon_sym_Case] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_FOR] = ACTIONS(3681),
    [anon_sym_For] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_FOREACH] = ACTIONS(3681),
    [anon_sym_Foreach] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_WHILE] = ACTIONS(3681),
    [anon_sym_While] = ACTIONS(3681),
    [anon_sym_repeat] = ACTIONS(3681),
    [anon_sym_REPEAT] = ACTIONS(3681),
    [anon_sym_Repeat] = ACTIONS(3681),
    [anon_sym_until] = ACTIONS(3681),
    [anon_sym_UNTIL] = ACTIONS(3681),
    [anon_sym_Until] = ACTIONS(3681),
    [anon_sym_exit] = ACTIONS(3681),
    [anon_sym_EXIT] = ACTIONS(3681),
    [anon_sym_Exit] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_CONTINUE] = ACTIONS(3681),
    [anon_sym_Continue] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_BREAK] = ACTIONS(3681),
    [anon_sym_Break] = ACTIONS(3681),
    [anon_sym_with] = ACTIONS(3681),
    [anon_sym_WITH] = ACTIONS(3681),
    [anon_sym_With] = ACTIONS(3681),
    [sym_asserterror_keyword] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
  },
  [STATE(1918)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1919)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4111),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4115),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4119),
    [aux_sym__expression_token2] = ACTIONS(4121),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4123),
    [anon_sym_div] = ACTIONS(4125),
    [anon_sym_DIV] = ACTIONS(4127),
    [anon_sym_Div] = ACTIONS(4129),
    [anon_sym_mod] = ACTIONS(4131),
    [anon_sym_MOD] = ACTIONS(4133),
    [anon_sym_Mod] = ACTIONS(4135),
    [anon_sym_PLUS] = ACTIONS(4137),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4139),
    [anon_sym_AND] = ACTIONS(4141),
    [anon_sym_And] = ACTIONS(4143),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_until] = ACTIONS(3643),
    [anon_sym_UNTIL] = ACTIONS(3643),
    [anon_sym_Until] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(1920)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_until] = ACTIONS(3566),
    [anon_sym_UNTIL] = ACTIONS(3566),
    [anon_sym_Until] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(1921)] = {
    [sym_comparison_operator] = STATE(4695),
    [sym_in_keyword] = STATE(16505),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4109),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4113),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4117),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_until] = ACTIONS(3566),
    [anon_sym_UNTIL] = ACTIONS(3566),
    [anon_sym_Until] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(1922)] = {
    [sym_preproc_conditional_object] = STATE(2027),
    [sym_namespace_declaration] = STATE(1943),
    [sym_using_statement] = STATE(2027),
    [sym__object] = STATE(2027),
    [sym_preproc_split_declaration] = STATE(2027),
    [sym_table_declaration] = STATE(2027),
    [sym_page_declaration] = STATE(2027),
    [sym_report_declaration] = STATE(2027),
    [sym_query_declaration] = STATE(2027),
    [sym_xmlport_declaration] = STATE(2027),
    [sym_permissionset_declaration] = STATE(2027),
    [sym_codeunit_declaration] = STATE(2027),
    [sym_enum_declaration] = STATE(2027),
    [sym_tableextension_declaration] = STATE(2027),
    [sym_pageextension_declaration] = STATE(2027),
    [sym_reportextension_declaration] = STATE(2027),
    [sym_enumextension_declaration] = STATE(2027),
    [sym_permissionsetextension_declaration] = STATE(2027),
    [sym_controladdin_declaration] = STATE(2027),
    [sym_profile_declaration] = STATE(2027),
    [sym_entitlement_declaration] = STATE(2027),
    [sym_profileextension_declaration] = STATE(2027),
    [sym_interface_declaration] = STATE(2027),
    [sym_pagecustomization_declaration] = STATE(2027),
    [sym_dotnet_declaration] = STATE(2027),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2861),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(2027),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1923)] = {
    [sym_preproc_conditional_object] = STATE(1973),
    [sym_namespace_declaration] = STATE(1975),
    [sym_using_statement] = STATE(1973),
    [sym__object] = STATE(1973),
    [sym_preproc_split_declaration] = STATE(1973),
    [sym_table_declaration] = STATE(1973),
    [sym_page_declaration] = STATE(1973),
    [sym_report_declaration] = STATE(1973),
    [sym_query_declaration] = STATE(1973),
    [sym_xmlport_declaration] = STATE(1973),
    [sym_permissionset_declaration] = STATE(1973),
    [sym_codeunit_declaration] = STATE(1973),
    [sym_enum_declaration] = STATE(1973),
    [sym_tableextension_declaration] = STATE(1973),
    [sym_pageextension_declaration] = STATE(1973),
    [sym_reportextension_declaration] = STATE(1973),
    [sym_enumextension_declaration] = STATE(1973),
    [sym_permissionsetextension_declaration] = STATE(1973),
    [sym_controladdin_declaration] = STATE(1973),
    [sym_profile_declaration] = STATE(1973),
    [sym_entitlement_declaration] = STATE(1973),
    [sym_profileextension_declaration] = STATE(1973),
    [sym_interface_declaration] = STATE(1973),
    [sym_pagecustomization_declaration] = STATE(1973),
    [sym_dotnet_declaration] = STATE(1973),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2775),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1973),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_namespace_keyword] = ACTIONS(1008),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1924)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(4177),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_until] = ACTIONS(3663),
    [anon_sym_UNTIL] = ACTIONS(3663),
    [anon_sym_Until] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
  },
  [STATE(1925)] = {
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(4175),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_IF] = ACTIONS(3681),
    [anon_sym_If] = ACTIONS(3681),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_case] = ACTIONS(3681),
    [anon_sym_CASE] = ACTIONS(3681),
    [anon_sym_Case] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_FOR] = ACTIONS(3681),
    [anon_sym_For] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_FOREACH] = ACTIONS(3681),
    [anon_sym_Foreach] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_WHILE] = ACTIONS(3681),
    [anon_sym_While] = ACTIONS(3681),
    [anon_sym_repeat] = ACTIONS(3681),
    [anon_sym_REPEAT] = ACTIONS(3681),
    [anon_sym_Repeat] = ACTIONS(3681),
    [anon_sym_until] = ACTIONS(3681),
    [anon_sym_UNTIL] = ACTIONS(3681),
    [anon_sym_Until] = ACTIONS(3681),
    [anon_sym_exit] = ACTIONS(3681),
    [anon_sym_EXIT] = ACTIONS(3681),
    [anon_sym_Exit] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_CONTINUE] = ACTIONS(3681),
    [anon_sym_Continue] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_BREAK] = ACTIONS(3681),
    [anon_sym_Break] = ACTIONS(3681),
    [anon_sym_with] = ACTIONS(3681),
    [anon_sym_WITH] = ACTIONS(3681),
    [anon_sym_With] = ACTIONS(3681),
    [sym_asserterror_keyword] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
  },
  [STATE(1926)] = {
    [sym_identifier] = ACTIONS(3742),
    [anon_sym_SEMI] = ACTIONS(3744),
    [anon_sym_DOT] = ACTIONS(3742),
    [anon_sym_EQ] = ACTIONS(3744),
    [anon_sym_COMMA] = ACTIONS(3744),
    [anon_sym_DASH] = ACTIONS(3742),
    [aux_sym_boolean_token1] = ACTIONS(3742),
    [aux_sym_boolean_token2] = ACTIONS(3742),
    [sym_decimal] = ACTIONS(3742),
    [anon_sym_LPAREN] = ACTIONS(3744),
    [anon_sym_DOT_DOT] = ACTIONS(3744),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3742),
    [anon_sym_STAR] = ACTIONS(3742),
    [anon_sym_LBRACK] = ACTIONS(3744),
    [aux_sym_record_type_token1] = ACTIONS(3742),
    [aux_sym_basic_type_token21] = ACTIONS(3742),
    [aux_sym_basic_type_token22] = ACTIONS(3742),
    [aux_sym_basic_type_token48] = ACTIONS(3742),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3742),
    [anon_sym_POUNDif] = ACTIONS(3744),
    [anon_sym_POUNDIF] = ACTIONS(3744),
    [anon_sym_POUNDIf] = ACTIONS(3744),
    [anon_sym_not] = ACTIONS(3742),
    [anon_sym_NOT] = ACTIONS(3742),
    [anon_sym_Not] = ACTIONS(3742),
    [anon_sym_POUNDelse] = ACTIONS(3744),
    [anon_sym_POUNDELSE] = ACTIONS(3744),
    [anon_sym_POUNDElse] = ACTIONS(3744),
    [anon_sym_POUNDelse2] = ACTIONS(3744),
    [anon_sym_POUNDELSE2] = ACTIONS(3744),
    [anon_sym_POUNDElse2] = ACTIONS(3744),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3744),
    [aux_sym__expression_token1] = ACTIONS(3744),
    [aux_sym__expression_token2] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3742),
    [anon_sym_SLASH] = ACTIONS(3742),
    [anon_sym_div] = ACTIONS(3742),
    [anon_sym_DIV] = ACTIONS(3742),
    [anon_sym_Div] = ACTIONS(3742),
    [anon_sym_mod] = ACTIONS(3742),
    [anon_sym_MOD] = ACTIONS(3742),
    [anon_sym_Mod] = ACTIONS(3742),
    [anon_sym_PLUS] = ACTIONS(3742),
    [anon_sym_GT_EQ] = ACTIONS(3744),
    [anon_sym_LT_EQ] = ACTIONS(3744),
    [anon_sym_GT] = ACTIONS(3742),
    [anon_sym_LT] = ACTIONS(3742),
    [anon_sym_LT_GT] = ACTIONS(3744),
    [anon_sym_and] = ACTIONS(3742),
    [anon_sym_AND] = ACTIONS(3742),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3742),
    [anon_sym_OR] = ACTIONS(3742),
    [anon_sym_Or] = ACTIONS(3742),
    [anon_sym_xor] = ACTIONS(3742),
    [anon_sym_XOR] = ACTIONS(3742),
    [anon_sym_Xor] = ACTIONS(3742),
    [anon_sym_QMARK] = ACTIONS(3744),
    [sym_datetime_literal] = ACTIONS(3744),
    [sym_date_literal] = ACTIONS(3742),
    [sym_time_literal] = ACTIONS(3742),
    [sym_biginteger_literal] = ACTIONS(3744),
    [anon_sym_if] = ACTIONS(3742),
    [anon_sym_IF] = ACTIONS(3742),
    [anon_sym_If] = ACTIONS(3742),
    [anon_sym_else] = ACTIONS(3742),
    [anon_sym_ELSE] = ACTIONS(3742),
    [anon_sym_Else] = ACTIONS(3742),
    [anon_sym_case] = ACTIONS(3742),
    [anon_sym_CASE] = ACTIONS(3742),
    [anon_sym_Case] = ACTIONS(3742),
    [anon_sym_for] = ACTIONS(3742),
    [anon_sym_FOR] = ACTIONS(3742),
    [anon_sym_For] = ACTIONS(3742),
    [anon_sym_foreach] = ACTIONS(3742),
    [anon_sym_FOREACH] = ACTIONS(3742),
    [anon_sym_Foreach] = ACTIONS(3742),
    [anon_sym_while] = ACTIONS(3742),
    [anon_sym_WHILE] = ACTIONS(3742),
    [anon_sym_While] = ACTIONS(3742),
    [anon_sym_repeat] = ACTIONS(3742),
    [anon_sym_REPEAT] = ACTIONS(3742),
    [anon_sym_Repeat] = ACTIONS(3742),
    [anon_sym_until] = ACTIONS(3742),
    [anon_sym_UNTIL] = ACTIONS(3742),
    [anon_sym_Until] = ACTIONS(3742),
    [anon_sym_exit] = ACTIONS(3742),
    [anon_sym_EXIT] = ACTIONS(3742),
    [anon_sym_Exit] = ACTIONS(3742),
    [anon_sym_continue] = ACTIONS(3742),
    [anon_sym_CONTINUE] = ACTIONS(3742),
    [anon_sym_Continue] = ACTIONS(3742),
    [anon_sym_break] = ACTIONS(3742),
    [anon_sym_BREAK] = ACTIONS(3742),
    [anon_sym_Break] = ACTIONS(3742),
    [anon_sym_with] = ACTIONS(3742),
    [anon_sym_WITH] = ACTIONS(3742),
    [anon_sym_With] = ACTIONS(3742),
    [sym_asserterror_keyword] = ACTIONS(3744),
    [anon_sym_in] = ACTIONS(3742),
    [anon_sym_IN] = ACTIONS(3742),
    [anon_sym_In] = ACTIONS(3742),
    [sym_page_keyword] = ACTIONS(3742),
    [anon_sym_codeunit] = ACTIONS(3742),
    [anon_sym_CODEUNIT] = ACTIONS(3742),
    [anon_sym_Codeunit] = ACTIONS(3742),
    [anon_sym_CodeUnit] = ACTIONS(3742),
    [anon_sym_COdeunit] = ACTIONS(3742),
    [anon_sym_codeUnit] = ACTIONS(3742),
    [sym_report_keyword] = ACTIONS(3742),
    [sym_query_keyword] = ACTIONS(3742),
    [anon_sym_xmlport] = ACTIONS(3742),
    [anon_sym_XMLPORT] = ACTIONS(3742),
    [anon_sym_Xmlport] = ACTIONS(3742),
    [anon_sym_XMLport] = ACTIONS(3742),
    [anon_sym_XMLPort] = ACTIONS(3742),
    [anon_sym_XmlPort] = ACTIONS(3742),
    [anon_sym_enum] = ACTIONS(3742),
    [anon_sym_ENUM] = ACTIONS(3742),
    [anon_sym_Enum] = ACTIONS(3742),
    [anon_sym_eNUM] = ACTIONS(3742),
    [anon_sym_eNum] = ACTIONS(3742),
    [anon_sym_ENum] = ACTIONS(3742),
    [sym_quoted_identifier] = ACTIONS(3744),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3744),
    [sym_verbatim_string] = ACTIONS(3744),
    [sym_integer] = ACTIONS(3742),
    [sym_continue_as_identifier] = ACTIONS(3744),
    [sym_preproc_open] = ACTIONS(3744),
  },
  [STATE(1927)] = {
    [sym_identifier] = ACTIONS(3790),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_DOT] = ACTIONS(3790),
    [anon_sym_EQ] = ACTIONS(3792),
    [anon_sym_DASH] = ACTIONS(3790),
    [aux_sym_boolean_token1] = ACTIONS(3790),
    [aux_sym_boolean_token2] = ACTIONS(3790),
    [sym_decimal] = ACTIONS(3790),
    [anon_sym_LPAREN] = ACTIONS(3792),
    [anon_sym_DOT_DOT] = ACTIONS(3792),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3790),
    [anon_sym_STAR] = ACTIONS(3790),
    [anon_sym_LBRACK] = ACTIONS(3792),
    [aux_sym_record_type_token1] = ACTIONS(3790),
    [aux_sym_basic_type_token21] = ACTIONS(3790),
    [aux_sym_basic_type_token22] = ACTIONS(3790),
    [aux_sym_basic_type_token48] = ACTIONS(3790),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3790),
    [anon_sym_COLON_COLON] = ACTIONS(3792),
    [anon_sym_POUNDif] = ACTIONS(3792),
    [anon_sym_POUNDIF] = ACTIONS(3792),
    [anon_sym_POUNDIf] = ACTIONS(3792),
    [anon_sym_not] = ACTIONS(3790),
    [anon_sym_NOT] = ACTIONS(3790),
    [anon_sym_Not] = ACTIONS(3790),
    [anon_sym_POUNDelse] = ACTIONS(3792),
    [anon_sym_POUNDELSE] = ACTIONS(3792),
    [anon_sym_POUNDElse] = ACTIONS(3792),
    [anon_sym_POUNDelse2] = ACTIONS(3792),
    [anon_sym_POUNDELSE2] = ACTIONS(3792),
    [anon_sym_POUNDElse2] = ACTIONS(3792),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3792),
    [aux_sym__expression_token1] = ACTIONS(3792),
    [aux_sym__expression_token2] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3790),
    [anon_sym_SLASH] = ACTIONS(3790),
    [anon_sym_div] = ACTIONS(3790),
    [anon_sym_DIV] = ACTIONS(3790),
    [anon_sym_Div] = ACTIONS(3790),
    [anon_sym_mod] = ACTIONS(3790),
    [anon_sym_MOD] = ACTIONS(3790),
    [anon_sym_Mod] = ACTIONS(3790),
    [anon_sym_PLUS] = ACTIONS(3790),
    [anon_sym_GT_EQ] = ACTIONS(3792),
    [anon_sym_LT_EQ] = ACTIONS(3792),
    [anon_sym_GT] = ACTIONS(3790),
    [anon_sym_LT] = ACTIONS(3790),
    [anon_sym_LT_GT] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3790),
    [anon_sym_AND] = ACTIONS(3790),
    [anon_sym_And] = ACTIONS(3790),
    [anon_sym_or] = ACTIONS(3790),
    [anon_sym_OR] = ACTIONS(3790),
    [anon_sym_Or] = ACTIONS(3790),
    [anon_sym_xor] = ACTIONS(3790),
    [anon_sym_XOR] = ACTIONS(3790),
    [anon_sym_Xor] = ACTIONS(3790),
    [anon_sym_QMARK] = ACTIONS(3792),
    [sym_datetime_literal] = ACTIONS(3792),
    [sym_date_literal] = ACTIONS(3790),
    [sym_time_literal] = ACTIONS(3790),
    [sym_biginteger_literal] = ACTIONS(3792),
    [anon_sym_if] = ACTIONS(3790),
    [anon_sym_IF] = ACTIONS(3790),
    [anon_sym_If] = ACTIONS(3790),
    [anon_sym_else] = ACTIONS(3790),
    [anon_sym_ELSE] = ACTIONS(3790),
    [anon_sym_Else] = ACTIONS(3790),
    [anon_sym_case] = ACTIONS(3790),
    [anon_sym_CASE] = ACTIONS(3790),
    [anon_sym_Case] = ACTIONS(3790),
    [anon_sym_for] = ACTIONS(3790),
    [anon_sym_FOR] = ACTIONS(3790),
    [anon_sym_For] = ACTIONS(3790),
    [anon_sym_foreach] = ACTIONS(3790),
    [anon_sym_FOREACH] = ACTIONS(3790),
    [anon_sym_Foreach] = ACTIONS(3790),
    [anon_sym_while] = ACTIONS(3790),
    [anon_sym_WHILE] = ACTIONS(3790),
    [anon_sym_While] = ACTIONS(3790),
    [anon_sym_repeat] = ACTIONS(3790),
    [anon_sym_REPEAT] = ACTIONS(3790),
    [anon_sym_Repeat] = ACTIONS(3790),
    [anon_sym_until] = ACTIONS(3790),
    [anon_sym_UNTIL] = ACTIONS(3790),
    [anon_sym_Until] = ACTIONS(3790),
    [anon_sym_exit] = ACTIONS(3790),
    [anon_sym_EXIT] = ACTIONS(3790),
    [anon_sym_Exit] = ACTIONS(3790),
    [anon_sym_continue] = ACTIONS(3790),
    [anon_sym_CONTINUE] = ACTIONS(3790),
    [anon_sym_Continue] = ACTIONS(3790),
    [anon_sym_break] = ACTIONS(3790),
    [anon_sym_BREAK] = ACTIONS(3790),
    [anon_sym_Break] = ACTIONS(3790),
    [anon_sym_with] = ACTIONS(3790),
    [anon_sym_WITH] = ACTIONS(3790),
    [anon_sym_With] = ACTIONS(3790),
    [sym_asserterror_keyword] = ACTIONS(3792),
    [anon_sym_in] = ACTIONS(3790),
    [anon_sym_IN] = ACTIONS(3790),
    [anon_sym_In] = ACTIONS(3790),
    [sym_page_keyword] = ACTIONS(3790),
    [anon_sym_codeunit] = ACTIONS(3790),
    [anon_sym_CODEUNIT] = ACTIONS(3790),
    [anon_sym_Codeunit] = ACTIONS(3790),
    [anon_sym_CodeUnit] = ACTIONS(3790),
    [anon_sym_COdeunit] = ACTIONS(3790),
    [anon_sym_codeUnit] = ACTIONS(3790),
    [sym_report_keyword] = ACTIONS(3790),
    [sym_query_keyword] = ACTIONS(3790),
    [anon_sym_xmlport] = ACTIONS(3790),
    [anon_sym_XMLPORT] = ACTIONS(3790),
    [anon_sym_Xmlport] = ACTIONS(3790),
    [anon_sym_XMLport] = ACTIONS(3790),
    [anon_sym_XMLPort] = ACTIONS(3790),
    [anon_sym_XmlPort] = ACTIONS(3790),
    [anon_sym_enum] = ACTIONS(3790),
    [anon_sym_ENUM] = ACTIONS(3790),
    [anon_sym_Enum] = ACTIONS(3790),
    [anon_sym_eNUM] = ACTIONS(3790),
    [anon_sym_eNum] = ACTIONS(3790),
    [anon_sym_ENum] = ACTIONS(3790),
    [sym_quoted_identifier] = ACTIONS(3792),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3792),
    [sym_verbatim_string] = ACTIONS(3792),
    [sym_integer] = ACTIONS(3790),
    [sym_continue_as_identifier] = ACTIONS(3792),
    [sym_preproc_open] = ACTIONS(3792),
  },
  [STATE(1928)] = {
    [sym_identifier] = ACTIONS(3760),
    [anon_sym_SEMI] = ACTIONS(3762),
    [anon_sym_DOT] = ACTIONS(3760),
    [anon_sym_EQ] = ACTIONS(3762),
    [anon_sym_DASH] = ACTIONS(3760),
    [aux_sym_boolean_token1] = ACTIONS(3760),
    [aux_sym_boolean_token2] = ACTIONS(3760),
    [sym_decimal] = ACTIONS(3760),
    [anon_sym_LPAREN] = ACTIONS(3762),
    [anon_sym_DOT_DOT] = ACTIONS(3762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3760),
    [anon_sym_STAR] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3762),
    [aux_sym_record_type_token1] = ACTIONS(3760),
    [aux_sym_basic_type_token21] = ACTIONS(3760),
    [aux_sym_basic_type_token22] = ACTIONS(3760),
    [aux_sym_basic_type_token48] = ACTIONS(3760),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3760),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(3762),
    [anon_sym_POUNDIF] = ACTIONS(3762),
    [anon_sym_POUNDIf] = ACTIONS(3762),
    [anon_sym_not] = ACTIONS(3760),
    [anon_sym_NOT] = ACTIONS(3760),
    [anon_sym_Not] = ACTIONS(3760),
    [anon_sym_POUNDelse] = ACTIONS(3762),
    [anon_sym_POUNDELSE] = ACTIONS(3762),
    [anon_sym_POUNDElse] = ACTIONS(3762),
    [anon_sym_POUNDelse2] = ACTIONS(3762),
    [anon_sym_POUNDELSE2] = ACTIONS(3762),
    [anon_sym_POUNDElse2] = ACTIONS(3762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3762),
    [aux_sym__expression_token1] = ACTIONS(3762),
    [aux_sym__expression_token2] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3760),
    [anon_sym_SLASH] = ACTIONS(3760),
    [anon_sym_div] = ACTIONS(3760),
    [anon_sym_DIV] = ACTIONS(3760),
    [anon_sym_Div] = ACTIONS(3760),
    [anon_sym_mod] = ACTIONS(3760),
    [anon_sym_MOD] = ACTIONS(3760),
    [anon_sym_Mod] = ACTIONS(3760),
    [anon_sym_PLUS] = ACTIONS(3760),
    [anon_sym_GT_EQ] = ACTIONS(3762),
    [anon_sym_LT_EQ] = ACTIONS(3762),
    [anon_sym_GT] = ACTIONS(3760),
    [anon_sym_LT] = ACTIONS(3760),
    [anon_sym_LT_GT] = ACTIONS(3762),
    [anon_sym_and] = ACTIONS(3760),
    [anon_sym_AND] = ACTIONS(3760),
    [anon_sym_And] = ACTIONS(3760),
    [anon_sym_or] = ACTIONS(3760),
    [anon_sym_OR] = ACTIONS(3760),
    [anon_sym_Or] = ACTIONS(3760),
    [anon_sym_xor] = ACTIONS(3760),
    [anon_sym_XOR] = ACTIONS(3760),
    [anon_sym_Xor] = ACTIONS(3760),
    [anon_sym_QMARK] = ACTIONS(3762),
    [sym_datetime_literal] = ACTIONS(3762),
    [sym_date_literal] = ACTIONS(3760),
    [sym_time_literal] = ACTIONS(3760),
    [sym_biginteger_literal] = ACTIONS(3762),
    [anon_sym_if] = ACTIONS(3760),
    [anon_sym_IF] = ACTIONS(3760),
    [anon_sym_If] = ACTIONS(3760),
    [anon_sym_else] = ACTIONS(3760),
    [anon_sym_ELSE] = ACTIONS(3760),
    [anon_sym_Else] = ACTIONS(3760),
    [anon_sym_case] = ACTIONS(3760),
    [anon_sym_CASE] = ACTIONS(3760),
    [anon_sym_Case] = ACTIONS(3760),
    [anon_sym_for] = ACTIONS(3760),
    [anon_sym_FOR] = ACTIONS(3760),
    [anon_sym_For] = ACTIONS(3760),
    [anon_sym_foreach] = ACTIONS(3760),
    [anon_sym_FOREACH] = ACTIONS(3760),
    [anon_sym_Foreach] = ACTIONS(3760),
    [anon_sym_while] = ACTIONS(3760),
    [anon_sym_WHILE] = ACTIONS(3760),
    [anon_sym_While] = ACTIONS(3760),
    [anon_sym_repeat] = ACTIONS(3760),
    [anon_sym_REPEAT] = ACTIONS(3760),
    [anon_sym_Repeat] = ACTIONS(3760),
    [anon_sym_until] = ACTIONS(3760),
    [anon_sym_UNTIL] = ACTIONS(3760),
    [anon_sym_Until] = ACTIONS(3760),
    [anon_sym_exit] = ACTIONS(3760),
    [anon_sym_EXIT] = ACTIONS(3760),
    [anon_sym_Exit] = ACTIONS(3760),
    [anon_sym_continue] = ACTIONS(3760),
    [anon_sym_CONTINUE] = ACTIONS(3760),
    [anon_sym_Continue] = ACTIONS(3760),
    [anon_sym_break] = ACTIONS(3760),
    [anon_sym_BREAK] = ACTIONS(3760),
    [anon_sym_Break] = ACTIONS(3760),
    [anon_sym_with] = ACTIONS(3760),
    [anon_sym_WITH] = ACTIONS(3760),
    [anon_sym_With] = ACTIONS(3760),
    [sym_asserterror_keyword] = ACTIONS(3762),
    [anon_sym_in] = ACTIONS(3760),
    [anon_sym_IN] = ACTIONS(3760),
    [anon_sym_In] = ACTIONS(3760),
    [sym_page_keyword] = ACTIONS(3760),
    [anon_sym_codeunit] = ACTIONS(3760),
    [anon_sym_CODEUNIT] = ACTIONS(3760),
    [anon_sym_Codeunit] = ACTIONS(3760),
    [anon_sym_CodeUnit] = ACTIONS(3760),
    [anon_sym_COdeunit] = ACTIONS(3760),
    [anon_sym_codeUnit] = ACTIONS(3760),
    [sym_report_keyword] = ACTIONS(3760),
    [sym_query_keyword] = ACTIONS(3760),
    [anon_sym_xmlport] = ACTIONS(3760),
    [anon_sym_XMLPORT] = ACTIONS(3760),
    [anon_sym_Xmlport] = ACTIONS(3760),
    [anon_sym_XMLport] = ACTIONS(3760),
    [anon_sym_XMLPort] = ACTIONS(3760),
    [anon_sym_XmlPort] = ACTIONS(3760),
    [anon_sym_enum] = ACTIONS(3760),
    [anon_sym_ENUM] = ACTIONS(3760),
    [anon_sym_Enum] = ACTIONS(3760),
    [anon_sym_eNUM] = ACTIONS(3760),
    [anon_sym_eNum] = ACTIONS(3760),
    [anon_sym_ENum] = ACTIONS(3760),
    [sym_quoted_identifier] = ACTIONS(3762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3762),
    [sym_verbatim_string] = ACTIONS(3762),
    [sym_integer] = ACTIONS(3760),
    [sym_continue_as_identifier] = ACTIONS(3762),
    [sym_preproc_open] = ACTIONS(3762),
  },
  [STATE(1929)] = {
    [sym_identifier] = ACTIONS(3776),
    [anon_sym_SEMI] = ACTIONS(3778),
    [anon_sym_DOT] = ACTIONS(3776),
    [anon_sym_EQ] = ACTIONS(3778),
    [anon_sym_DASH] = ACTIONS(3776),
    [aux_sym_boolean_token1] = ACTIONS(3776),
    [aux_sym_boolean_token2] = ACTIONS(3776),
    [sym_decimal] = ACTIONS(3776),
    [anon_sym_LPAREN] = ACTIONS(3778),
    [anon_sym_DOT_DOT] = ACTIONS(3778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3776),
    [anon_sym_STAR] = ACTIONS(3776),
    [anon_sym_LBRACK] = ACTIONS(3778),
    [aux_sym_record_type_token1] = ACTIONS(3776),
    [aux_sym_basic_type_token21] = ACTIONS(3776),
    [aux_sym_basic_type_token22] = ACTIONS(3776),
    [aux_sym_basic_type_token48] = ACTIONS(3776),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_POUNDif] = ACTIONS(3778),
    [anon_sym_POUNDIF] = ACTIONS(3778),
    [anon_sym_POUNDIf] = ACTIONS(3778),
    [anon_sym_not] = ACTIONS(3776),
    [anon_sym_NOT] = ACTIONS(3776),
    [anon_sym_Not] = ACTIONS(3776),
    [anon_sym_POUNDelse] = ACTIONS(3778),
    [anon_sym_POUNDELSE] = ACTIONS(3778),
    [anon_sym_POUNDElse] = ACTIONS(3778),
    [anon_sym_POUNDelse2] = ACTIONS(3778),
    [anon_sym_POUNDELSE2] = ACTIONS(3778),
    [anon_sym_POUNDElse2] = ACTIONS(3778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3778),
    [aux_sym__expression_token1] = ACTIONS(3778),
    [aux_sym__expression_token2] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3776),
    [anon_sym_SLASH] = ACTIONS(3776),
    [anon_sym_div] = ACTIONS(3776),
    [anon_sym_DIV] = ACTIONS(3776),
    [anon_sym_Div] = ACTIONS(3776),
    [anon_sym_mod] = ACTIONS(3776),
    [anon_sym_MOD] = ACTIONS(3776),
    [anon_sym_Mod] = ACTIONS(3776),
    [anon_sym_PLUS] = ACTIONS(3776),
    [anon_sym_GT_EQ] = ACTIONS(3778),
    [anon_sym_LT_EQ] = ACTIONS(3778),
    [anon_sym_GT] = ACTIONS(3776),
    [anon_sym_LT] = ACTIONS(3776),
    [anon_sym_LT_GT] = ACTIONS(3778),
    [anon_sym_and] = ACTIONS(3776),
    [anon_sym_AND] = ACTIONS(3776),
    [anon_sym_And] = ACTIONS(3776),
    [anon_sym_or] = ACTIONS(3776),
    [anon_sym_OR] = ACTIONS(3776),
    [anon_sym_Or] = ACTIONS(3776),
    [anon_sym_xor] = ACTIONS(3776),
    [anon_sym_XOR] = ACTIONS(3776),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(3778),
    [sym_date_literal] = ACTIONS(3776),
    [sym_time_literal] = ACTIONS(3776),
    [sym_biginteger_literal] = ACTIONS(3778),
    [anon_sym_if] = ACTIONS(3776),
    [anon_sym_IF] = ACTIONS(3776),
    [anon_sym_If] = ACTIONS(3776),
    [anon_sym_else] = ACTIONS(3776),
    [anon_sym_ELSE] = ACTIONS(3776),
    [anon_sym_Else] = ACTIONS(3776),
    [anon_sym_case] = ACTIONS(3776),
    [anon_sym_CASE] = ACTIONS(3776),
    [anon_sym_Case] = ACTIONS(3776),
    [anon_sym_for] = ACTIONS(3776),
    [anon_sym_FOR] = ACTIONS(3776),
    [anon_sym_For] = ACTIONS(3776),
    [anon_sym_foreach] = ACTIONS(3776),
    [anon_sym_FOREACH] = ACTIONS(3776),
    [anon_sym_Foreach] = ACTIONS(3776),
    [anon_sym_while] = ACTIONS(3776),
    [anon_sym_WHILE] = ACTIONS(3776),
    [anon_sym_While] = ACTIONS(3776),
    [anon_sym_repeat] = ACTIONS(3776),
    [anon_sym_REPEAT] = ACTIONS(3776),
    [anon_sym_Repeat] = ACTIONS(3776),
    [anon_sym_until] = ACTIONS(3776),
    [anon_sym_UNTIL] = ACTIONS(3776),
    [anon_sym_Until] = ACTIONS(3776),
    [anon_sym_exit] = ACTIONS(3776),
    [anon_sym_EXIT] = ACTIONS(3776),
    [anon_sym_Exit] = ACTIONS(3776),
    [anon_sym_continue] = ACTIONS(3776),
    [anon_sym_CONTINUE] = ACTIONS(3776),
    [anon_sym_Continue] = ACTIONS(3776),
    [anon_sym_break] = ACTIONS(3776),
    [anon_sym_BREAK] = ACTIONS(3776),
    [anon_sym_Break] = ACTIONS(3776),
    [anon_sym_with] = ACTIONS(3776),
    [anon_sym_WITH] = ACTIONS(3776),
    [anon_sym_With] = ACTIONS(3776),
    [sym_asserterror_keyword] = ACTIONS(3778),
    [anon_sym_in] = ACTIONS(3776),
    [anon_sym_IN] = ACTIONS(3776),
    [anon_sym_In] = ACTIONS(3776),
    [sym_page_keyword] = ACTIONS(3776),
    [anon_sym_codeunit] = ACTIONS(3776),
    [anon_sym_CODEUNIT] = ACTIONS(3776),
    [anon_sym_Codeunit] = ACTIONS(3776),
    [anon_sym_CodeUnit] = ACTIONS(3776),
    [anon_sym_COdeunit] = ACTIONS(3776),
    [anon_sym_codeUnit] = ACTIONS(3776),
    [sym_report_keyword] = ACTIONS(3776),
    [sym_query_keyword] = ACTIONS(3776),
    [anon_sym_xmlport] = ACTIONS(3776),
    [anon_sym_XMLPORT] = ACTIONS(3776),
    [anon_sym_Xmlport] = ACTIONS(3776),
    [anon_sym_XMLport] = ACTIONS(3776),
    [anon_sym_XMLPort] = ACTIONS(3776),
    [anon_sym_XmlPort] = ACTIONS(3776),
    [anon_sym_enum] = ACTIONS(3776),
    [anon_sym_ENUM] = ACTIONS(3776),
    [anon_sym_Enum] = ACTIONS(3776),
    [anon_sym_eNUM] = ACTIONS(3776),
    [anon_sym_eNum] = ACTIONS(3776),
    [anon_sym_ENum] = ACTIONS(3776),
    [sym_quoted_identifier] = ACTIONS(3778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3778),
    [sym_verbatim_string] = ACTIONS(3778),
    [sym_integer] = ACTIONS(3776),
    [sym_continue_as_identifier] = ACTIONS(3778),
    [sym_preproc_open] = ACTIONS(3778),
  },
  [STATE(1930)] = {
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(3703),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_if] = ACTIONS(3703),
    [anon_sym_IF] = ACTIONS(3703),
    [anon_sym_If] = ACTIONS(3703),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_case] = ACTIONS(3703),
    [anon_sym_CASE] = ACTIONS(3703),
    [anon_sym_Case] = ACTIONS(3703),
    [anon_sym_for] = ACTIONS(3703),
    [anon_sym_FOR] = ACTIONS(3703),
    [anon_sym_For] = ACTIONS(3703),
    [anon_sym_foreach] = ACTIONS(3703),
    [anon_sym_FOREACH] = ACTIONS(3703),
    [anon_sym_Foreach] = ACTIONS(3703),
    [anon_sym_while] = ACTIONS(3703),
    [anon_sym_WHILE] = ACTIONS(3703),
    [anon_sym_While] = ACTIONS(3703),
    [anon_sym_repeat] = ACTIONS(3703),
    [anon_sym_REPEAT] = ACTIONS(3703),
    [anon_sym_Repeat] = ACTIONS(3703),
    [anon_sym_until] = ACTIONS(3703),
    [anon_sym_UNTIL] = ACTIONS(3703),
    [anon_sym_Until] = ACTIONS(3703),
    [anon_sym_exit] = ACTIONS(3703),
    [anon_sym_EXIT] = ACTIONS(3703),
    [anon_sym_Exit] = ACTIONS(3703),
    [anon_sym_continue] = ACTIONS(3703),
    [anon_sym_CONTINUE] = ACTIONS(3703),
    [anon_sym_Continue] = ACTIONS(3703),
    [anon_sym_break] = ACTIONS(3703),
    [anon_sym_BREAK] = ACTIONS(3703),
    [anon_sym_Break] = ACTIONS(3703),
    [anon_sym_with] = ACTIONS(3703),
    [anon_sym_WITH] = ACTIONS(3703),
    [anon_sym_With] = ACTIONS(3703),
    [sym_asserterror_keyword] = ACTIONS(3705),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
  },
  [STATE(1931)] = {
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(3634),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_if] = ACTIONS(3632),
    [anon_sym_IF] = ACTIONS(3632),
    [anon_sym_If] = ACTIONS(3632),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_case] = ACTIONS(3632),
    [anon_sym_CASE] = ACTIONS(3632),
    [anon_sym_Case] = ACTIONS(3632),
    [anon_sym_for] = ACTIONS(3632),
    [anon_sym_FOR] = ACTIONS(3632),
    [anon_sym_For] = ACTIONS(3632),
    [anon_sym_foreach] = ACTIONS(3632),
    [anon_sym_FOREACH] = ACTIONS(3632),
    [anon_sym_Foreach] = ACTIONS(3632),
    [anon_sym_while] = ACTIONS(3632),
    [anon_sym_WHILE] = ACTIONS(3632),
    [anon_sym_While] = ACTIONS(3632),
    [anon_sym_repeat] = ACTIONS(3632),
    [anon_sym_REPEAT] = ACTIONS(3632),
    [anon_sym_Repeat] = ACTIONS(3632),
    [anon_sym_until] = ACTIONS(3632),
    [anon_sym_UNTIL] = ACTIONS(3632),
    [anon_sym_Until] = ACTIONS(3632),
    [anon_sym_exit] = ACTIONS(3632),
    [anon_sym_EXIT] = ACTIONS(3632),
    [anon_sym_Exit] = ACTIONS(3632),
    [anon_sym_continue] = ACTIONS(3632),
    [anon_sym_CONTINUE] = ACTIONS(3632),
    [anon_sym_Continue] = ACTIONS(3632),
    [anon_sym_break] = ACTIONS(3632),
    [anon_sym_BREAK] = ACTIONS(3632),
    [anon_sym_Break] = ACTIONS(3632),
    [anon_sym_with] = ACTIONS(3632),
    [anon_sym_WITH] = ACTIONS(3632),
    [anon_sym_With] = ACTIONS(3632),
    [sym_asserterror_keyword] = ACTIONS(3634),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
  },
  [STATE(1932)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_until] = ACTIONS(3663),
    [anon_sym_UNTIL] = ACTIONS(3663),
    [anon_sym_Until] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
  },
  [STATE(1933)] = {
    [sym_identifier] = ACTIONS(3752),
    [anon_sym_SEMI] = ACTIONS(3754),
    [anon_sym_DOT] = ACTIONS(3752),
    [anon_sym_EQ] = ACTIONS(3754),
    [anon_sym_COMMA] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3752),
    [aux_sym_boolean_token1] = ACTIONS(3752),
    [aux_sym_boolean_token2] = ACTIONS(3752),
    [sym_decimal] = ACTIONS(3752),
    [anon_sym_LPAREN] = ACTIONS(3754),
    [anon_sym_DOT_DOT] = ACTIONS(3754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3752),
    [anon_sym_STAR] = ACTIONS(3752),
    [anon_sym_LBRACK] = ACTIONS(3754),
    [aux_sym_record_type_token1] = ACTIONS(3752),
    [aux_sym_basic_type_token21] = ACTIONS(3752),
    [aux_sym_basic_type_token22] = ACTIONS(3752),
    [aux_sym_basic_type_token48] = ACTIONS(3752),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3752),
    [anon_sym_POUNDif] = ACTIONS(3754),
    [anon_sym_POUNDIF] = ACTIONS(3754),
    [anon_sym_POUNDIf] = ACTIONS(3754),
    [anon_sym_not] = ACTIONS(3752),
    [anon_sym_NOT] = ACTIONS(3752),
    [anon_sym_Not] = ACTIONS(3752),
    [anon_sym_POUNDelse] = ACTIONS(3754),
    [anon_sym_POUNDELSE] = ACTIONS(3754),
    [anon_sym_POUNDElse] = ACTIONS(3754),
    [anon_sym_POUNDelse2] = ACTIONS(3754),
    [anon_sym_POUNDELSE2] = ACTIONS(3754),
    [anon_sym_POUNDElse2] = ACTIONS(3754),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3754),
    [aux_sym__expression_token1] = ACTIONS(3754),
    [aux_sym__expression_token2] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3752),
    [anon_sym_SLASH] = ACTIONS(3752),
    [anon_sym_div] = ACTIONS(3752),
    [anon_sym_DIV] = ACTIONS(3752),
    [anon_sym_Div] = ACTIONS(3752),
    [anon_sym_mod] = ACTIONS(3752),
    [anon_sym_MOD] = ACTIONS(3752),
    [anon_sym_Mod] = ACTIONS(3752),
    [anon_sym_PLUS] = ACTIONS(3752),
    [anon_sym_GT_EQ] = ACTIONS(3754),
    [anon_sym_LT_EQ] = ACTIONS(3754),
    [anon_sym_GT] = ACTIONS(3752),
    [anon_sym_LT] = ACTIONS(3752),
    [anon_sym_LT_GT] = ACTIONS(3754),
    [anon_sym_and] = ACTIONS(3752),
    [anon_sym_AND] = ACTIONS(3752),
    [anon_sym_And] = ACTIONS(3752),
    [anon_sym_or] = ACTIONS(3752),
    [anon_sym_OR] = ACTIONS(3752),
    [anon_sym_Or] = ACTIONS(3752),
    [anon_sym_xor] = ACTIONS(3752),
    [anon_sym_XOR] = ACTIONS(3752),
    [anon_sym_Xor] = ACTIONS(3752),
    [anon_sym_QMARK] = ACTIONS(3754),
    [sym_datetime_literal] = ACTIONS(3754),
    [sym_date_literal] = ACTIONS(3752),
    [sym_time_literal] = ACTIONS(3752),
    [sym_biginteger_literal] = ACTIONS(3754),
    [anon_sym_if] = ACTIONS(3752),
    [anon_sym_IF] = ACTIONS(3752),
    [anon_sym_If] = ACTIONS(3752),
    [anon_sym_else] = ACTIONS(3752),
    [anon_sym_ELSE] = ACTIONS(3752),
    [anon_sym_Else] = ACTIONS(3752),
    [anon_sym_case] = ACTIONS(3752),
    [anon_sym_CASE] = ACTIONS(3752),
    [anon_sym_Case] = ACTIONS(3752),
    [anon_sym_for] = ACTIONS(3752),
    [anon_sym_FOR] = ACTIONS(3752),
    [anon_sym_For] = ACTIONS(3752),
    [anon_sym_foreach] = ACTIONS(3752),
    [anon_sym_FOREACH] = ACTIONS(3752),
    [anon_sym_Foreach] = ACTIONS(3752),
    [anon_sym_while] = ACTIONS(3752),
    [anon_sym_WHILE] = ACTIONS(3752),
    [anon_sym_While] = ACTIONS(3752),
    [anon_sym_repeat] = ACTIONS(3752),
    [anon_sym_REPEAT] = ACTIONS(3752),
    [anon_sym_Repeat] = ACTIONS(3752),
    [anon_sym_until] = ACTIONS(3752),
    [anon_sym_UNTIL] = ACTIONS(3752),
    [anon_sym_Until] = ACTIONS(3752),
    [anon_sym_exit] = ACTIONS(3752),
    [anon_sym_EXIT] = ACTIONS(3752),
    [anon_sym_Exit] = ACTIONS(3752),
    [anon_sym_continue] = ACTIONS(3752),
    [anon_sym_CONTINUE] = ACTIONS(3752),
    [anon_sym_Continue] = ACTIONS(3752),
    [anon_sym_break] = ACTIONS(3752),
    [anon_sym_BREAK] = ACTIONS(3752),
    [anon_sym_Break] = ACTIONS(3752),
    [anon_sym_with] = ACTIONS(3752),
    [anon_sym_WITH] = ACTIONS(3752),
    [anon_sym_With] = ACTIONS(3752),
    [sym_asserterror_keyword] = ACTIONS(3754),
    [anon_sym_in] = ACTIONS(3752),
    [anon_sym_IN] = ACTIONS(3752),
    [anon_sym_In] = ACTIONS(3752),
    [sym_page_keyword] = ACTIONS(3752),
    [anon_sym_codeunit] = ACTIONS(3752),
    [anon_sym_CODEUNIT] = ACTIONS(3752),
    [anon_sym_Codeunit] = ACTIONS(3752),
    [anon_sym_CodeUnit] = ACTIONS(3752),
    [anon_sym_COdeunit] = ACTIONS(3752),
    [anon_sym_codeUnit] = ACTIONS(3752),
    [sym_report_keyword] = ACTIONS(3752),
    [sym_query_keyword] = ACTIONS(3752),
    [anon_sym_xmlport] = ACTIONS(3752),
    [anon_sym_XMLPORT] = ACTIONS(3752),
    [anon_sym_Xmlport] = ACTIONS(3752),
    [anon_sym_XMLport] = ACTIONS(3752),
    [anon_sym_XMLPort] = ACTIONS(3752),
    [anon_sym_XmlPort] = ACTIONS(3752),
    [anon_sym_enum] = ACTIONS(3752),
    [anon_sym_ENUM] = ACTIONS(3752),
    [anon_sym_Enum] = ACTIONS(3752),
    [anon_sym_eNUM] = ACTIONS(3752),
    [anon_sym_eNum] = ACTIONS(3752),
    [anon_sym_ENum] = ACTIONS(3752),
    [sym_quoted_identifier] = ACTIONS(3754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3754),
    [sym_verbatim_string] = ACTIONS(3754),
    [sym_integer] = ACTIONS(3752),
    [sym_continue_as_identifier] = ACTIONS(3754),
    [sym_preproc_open] = ACTIONS(3754),
  },
  [STATE(1934)] = {
    [sym_identifier] = ACTIONS(3756),
    [anon_sym_SEMI] = ACTIONS(3758),
    [anon_sym_DOT] = ACTIONS(3756),
    [anon_sym_EQ] = ACTIONS(3758),
    [anon_sym_DASH] = ACTIONS(3756),
    [aux_sym_boolean_token1] = ACTIONS(3756),
    [aux_sym_boolean_token2] = ACTIONS(3756),
    [sym_decimal] = ACTIONS(3756),
    [anon_sym_LPAREN] = ACTIONS(3758),
    [anon_sym_DOT_DOT] = ACTIONS(3758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3756),
    [anon_sym_LBRACK] = ACTIONS(3758),
    [aux_sym_record_type_token1] = ACTIONS(3756),
    [aux_sym_basic_type_token21] = ACTIONS(3756),
    [aux_sym_basic_type_token22] = ACTIONS(3756),
    [aux_sym_basic_type_token48] = ACTIONS(3756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3756),
    [anon_sym_COLON_COLON] = ACTIONS(3758),
    [anon_sym_POUNDif] = ACTIONS(3758),
    [anon_sym_POUNDIF] = ACTIONS(3758),
    [anon_sym_POUNDIf] = ACTIONS(3758),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_NOT] = ACTIONS(3756),
    [anon_sym_Not] = ACTIONS(3756),
    [anon_sym_POUNDelse] = ACTIONS(3758),
    [anon_sym_POUNDELSE] = ACTIONS(3758),
    [anon_sym_POUNDElse] = ACTIONS(3758),
    [anon_sym_POUNDelse2] = ACTIONS(3758),
    [anon_sym_POUNDELSE2] = ACTIONS(3758),
    [anon_sym_POUNDElse2] = ACTIONS(3758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3758),
    [aux_sym__expression_token1] = ACTIONS(3758),
    [aux_sym__expression_token2] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3756),
    [anon_sym_SLASH] = ACTIONS(3756),
    [anon_sym_div] = ACTIONS(3756),
    [anon_sym_DIV] = ACTIONS(3756),
    [anon_sym_Div] = ACTIONS(3756),
    [anon_sym_mod] = ACTIONS(3756),
    [anon_sym_MOD] = ACTIONS(3756),
    [anon_sym_Mod] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_GT_EQ] = ACTIONS(3758),
    [anon_sym_LT_EQ] = ACTIONS(3758),
    [anon_sym_GT] = ACTIONS(3756),
    [anon_sym_LT] = ACTIONS(3756),
    [anon_sym_LT_GT] = ACTIONS(3758),
    [anon_sym_and] = ACTIONS(3756),
    [anon_sym_AND] = ACTIONS(3756),
    [anon_sym_And] = ACTIONS(3756),
    [anon_sym_or] = ACTIONS(3756),
    [anon_sym_OR] = ACTIONS(3756),
    [anon_sym_Or] = ACTIONS(3756),
    [anon_sym_xor] = ACTIONS(3756),
    [anon_sym_XOR] = ACTIONS(3756),
    [anon_sym_Xor] = ACTIONS(3756),
    [anon_sym_QMARK] = ACTIONS(3758),
    [sym_datetime_literal] = ACTIONS(3758),
    [sym_date_literal] = ACTIONS(3756),
    [sym_time_literal] = ACTIONS(3756),
    [sym_biginteger_literal] = ACTIONS(3758),
    [anon_sym_if] = ACTIONS(3756),
    [anon_sym_IF] = ACTIONS(3756),
    [anon_sym_If] = ACTIONS(3756),
    [anon_sym_else] = ACTIONS(3756),
    [anon_sym_ELSE] = ACTIONS(3756),
    [anon_sym_Else] = ACTIONS(3756),
    [anon_sym_case] = ACTIONS(3756),
    [anon_sym_CASE] = ACTIONS(3756),
    [anon_sym_Case] = ACTIONS(3756),
    [anon_sym_for] = ACTIONS(3756),
    [anon_sym_FOR] = ACTIONS(3756),
    [anon_sym_For] = ACTIONS(3756),
    [anon_sym_foreach] = ACTIONS(3756),
    [anon_sym_FOREACH] = ACTIONS(3756),
    [anon_sym_Foreach] = ACTIONS(3756),
    [anon_sym_while] = ACTIONS(3756),
    [anon_sym_WHILE] = ACTIONS(3756),
    [anon_sym_While] = ACTIONS(3756),
    [anon_sym_repeat] = ACTIONS(3756),
    [anon_sym_REPEAT] = ACTIONS(3756),
    [anon_sym_Repeat] = ACTIONS(3756),
    [anon_sym_until] = ACTIONS(3756),
    [anon_sym_UNTIL] = ACTIONS(3756),
    [anon_sym_Until] = ACTIONS(3756),
    [anon_sym_exit] = ACTIONS(3756),
    [anon_sym_EXIT] = ACTIONS(3756),
    [anon_sym_Exit] = ACTIONS(3756),
    [anon_sym_continue] = ACTIONS(3756),
    [anon_sym_CONTINUE] = ACTIONS(3756),
    [anon_sym_Continue] = ACTIONS(3756),
    [anon_sym_break] = ACTIONS(3756),
    [anon_sym_BREAK] = ACTIONS(3756),
    [anon_sym_Break] = ACTIONS(3756),
    [anon_sym_with] = ACTIONS(3756),
    [anon_sym_WITH] = ACTIONS(3756),
    [anon_sym_With] = ACTIONS(3756),
    [sym_asserterror_keyword] = ACTIONS(3758),
    [anon_sym_in] = ACTIONS(3756),
    [anon_sym_IN] = ACTIONS(3756),
    [anon_sym_In] = ACTIONS(3756),
    [sym_page_keyword] = ACTIONS(3756),
    [anon_sym_codeunit] = ACTIONS(3756),
    [anon_sym_CODEUNIT] = ACTIONS(3756),
    [anon_sym_Codeunit] = ACTIONS(3756),
    [anon_sym_CodeUnit] = ACTIONS(3756),
    [anon_sym_COdeunit] = ACTIONS(3756),
    [anon_sym_codeUnit] = ACTIONS(3756),
    [sym_report_keyword] = ACTIONS(3756),
    [sym_query_keyword] = ACTIONS(3756),
    [anon_sym_xmlport] = ACTIONS(3756),
    [anon_sym_XMLPORT] = ACTIONS(3756),
    [anon_sym_Xmlport] = ACTIONS(3756),
    [anon_sym_XMLport] = ACTIONS(3756),
    [anon_sym_XMLPort] = ACTIONS(3756),
    [anon_sym_XmlPort] = ACTIONS(3756),
    [anon_sym_enum] = ACTIONS(3756),
    [anon_sym_ENUM] = ACTIONS(3756),
    [anon_sym_Enum] = ACTIONS(3756),
    [anon_sym_eNUM] = ACTIONS(3756),
    [anon_sym_eNum] = ACTIONS(3756),
    [anon_sym_ENum] = ACTIONS(3756),
    [sym_quoted_identifier] = ACTIONS(3758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3758),
    [sym_verbatim_string] = ACTIONS(3758),
    [sym_integer] = ACTIONS(3756),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_open] = ACTIONS(3758),
  },
  [STATE(1935)] = {
    [sym_identifier] = ACTIONS(3764),
    [anon_sym_SEMI] = ACTIONS(3766),
    [anon_sym_DOT] = ACTIONS(3764),
    [anon_sym_EQ] = ACTIONS(3766),
    [anon_sym_DASH] = ACTIONS(3764),
    [aux_sym_boolean_token1] = ACTIONS(3764),
    [aux_sym_boolean_token2] = ACTIONS(3764),
    [sym_decimal] = ACTIONS(3764),
    [anon_sym_LPAREN] = ACTIONS(3766),
    [anon_sym_DOT_DOT] = ACTIONS(3766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3764),
    [anon_sym_STAR] = ACTIONS(3764),
    [anon_sym_LBRACK] = ACTIONS(3766),
    [aux_sym_record_type_token1] = ACTIONS(3764),
    [aux_sym_basic_type_token21] = ACTIONS(3764),
    [aux_sym_basic_type_token22] = ACTIONS(3764),
    [aux_sym_basic_type_token48] = ACTIONS(3764),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3764),
    [anon_sym_COLON_COLON] = ACTIONS(3766),
    [anon_sym_POUNDif] = ACTIONS(3766),
    [anon_sym_POUNDIF] = ACTIONS(3766),
    [anon_sym_POUNDIf] = ACTIONS(3766),
    [anon_sym_not] = ACTIONS(3764),
    [anon_sym_NOT] = ACTIONS(3764),
    [anon_sym_Not] = ACTIONS(3764),
    [anon_sym_POUNDelse] = ACTIONS(3766),
    [anon_sym_POUNDELSE] = ACTIONS(3766),
    [anon_sym_POUNDElse] = ACTIONS(3766),
    [anon_sym_POUNDelse2] = ACTIONS(3766),
    [anon_sym_POUNDELSE2] = ACTIONS(3766),
    [anon_sym_POUNDElse2] = ACTIONS(3766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3766),
    [aux_sym__expression_token1] = ACTIONS(3766),
    [aux_sym__expression_token2] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3764),
    [anon_sym_SLASH] = ACTIONS(3764),
    [anon_sym_div] = ACTIONS(3764),
    [anon_sym_DIV] = ACTIONS(3764),
    [anon_sym_Div] = ACTIONS(3764),
    [anon_sym_mod] = ACTIONS(3764),
    [anon_sym_MOD] = ACTIONS(3764),
    [anon_sym_Mod] = ACTIONS(3764),
    [anon_sym_PLUS] = ACTIONS(3764),
    [anon_sym_GT_EQ] = ACTIONS(3766),
    [anon_sym_LT_EQ] = ACTIONS(3766),
    [anon_sym_GT] = ACTIONS(3764),
    [anon_sym_LT] = ACTIONS(3764),
    [anon_sym_LT_GT] = ACTIONS(3766),
    [anon_sym_and] = ACTIONS(3764),
    [anon_sym_AND] = ACTIONS(3764),
    [anon_sym_And] = ACTIONS(3764),
    [anon_sym_or] = ACTIONS(3764),
    [anon_sym_OR] = ACTIONS(3764),
    [anon_sym_Or] = ACTIONS(3764),
    [anon_sym_xor] = ACTIONS(3764),
    [anon_sym_XOR] = ACTIONS(3764),
    [anon_sym_Xor] = ACTIONS(3764),
    [anon_sym_QMARK] = ACTIONS(3766),
    [sym_datetime_literal] = ACTIONS(3766),
    [sym_date_literal] = ACTIONS(3764),
    [sym_time_literal] = ACTIONS(3764),
    [sym_biginteger_literal] = ACTIONS(3766),
    [anon_sym_if] = ACTIONS(3764),
    [anon_sym_IF] = ACTIONS(3764),
    [anon_sym_If] = ACTIONS(3764),
    [anon_sym_else] = ACTIONS(3764),
    [anon_sym_ELSE] = ACTIONS(3764),
    [anon_sym_Else] = ACTIONS(3764),
    [anon_sym_case] = ACTIONS(3764),
    [anon_sym_CASE] = ACTIONS(3764),
    [anon_sym_Case] = ACTIONS(3764),
    [anon_sym_for] = ACTIONS(3764),
    [anon_sym_FOR] = ACTIONS(3764),
    [anon_sym_For] = ACTIONS(3764),
    [anon_sym_foreach] = ACTIONS(3764),
    [anon_sym_FOREACH] = ACTIONS(3764),
    [anon_sym_Foreach] = ACTIONS(3764),
    [anon_sym_while] = ACTIONS(3764),
    [anon_sym_WHILE] = ACTIONS(3764),
    [anon_sym_While] = ACTIONS(3764),
    [anon_sym_repeat] = ACTIONS(3764),
    [anon_sym_REPEAT] = ACTIONS(3764),
    [anon_sym_Repeat] = ACTIONS(3764),
    [anon_sym_until] = ACTIONS(3764),
    [anon_sym_UNTIL] = ACTIONS(3764),
    [anon_sym_Until] = ACTIONS(3764),
    [anon_sym_exit] = ACTIONS(3764),
    [anon_sym_EXIT] = ACTIONS(3764),
    [anon_sym_Exit] = ACTIONS(3764),
    [anon_sym_continue] = ACTIONS(3764),
    [anon_sym_CONTINUE] = ACTIONS(3764),
    [anon_sym_Continue] = ACTIONS(3764),
    [anon_sym_break] = ACTIONS(3764),
    [anon_sym_BREAK] = ACTIONS(3764),
    [anon_sym_Break] = ACTIONS(3764),
    [anon_sym_with] = ACTIONS(3764),
    [anon_sym_WITH] = ACTIONS(3764),
    [anon_sym_With] = ACTIONS(3764),
    [sym_asserterror_keyword] = ACTIONS(3766),
    [anon_sym_in] = ACTIONS(3764),
    [anon_sym_IN] = ACTIONS(3764),
    [anon_sym_In] = ACTIONS(3764),
    [sym_page_keyword] = ACTIONS(3764),
    [anon_sym_codeunit] = ACTIONS(3764),
    [anon_sym_CODEUNIT] = ACTIONS(3764),
    [anon_sym_Codeunit] = ACTIONS(3764),
    [anon_sym_CodeUnit] = ACTIONS(3764),
    [anon_sym_COdeunit] = ACTIONS(3764),
    [anon_sym_codeUnit] = ACTIONS(3764),
    [sym_report_keyword] = ACTIONS(3764),
    [sym_query_keyword] = ACTIONS(3764),
    [anon_sym_xmlport] = ACTIONS(3764),
    [anon_sym_XMLPORT] = ACTIONS(3764),
    [anon_sym_Xmlport] = ACTIONS(3764),
    [anon_sym_XMLport] = ACTIONS(3764),
    [anon_sym_XMLPort] = ACTIONS(3764),
    [anon_sym_XmlPort] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3764),
    [anon_sym_ENUM] = ACTIONS(3764),
    [anon_sym_Enum] = ACTIONS(3764),
    [anon_sym_eNUM] = ACTIONS(3764),
    [anon_sym_eNum] = ACTIONS(3764),
    [anon_sym_ENum] = ACTIONS(3764),
    [sym_quoted_identifier] = ACTIONS(3766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3766),
    [sym_verbatim_string] = ACTIONS(3766),
    [sym_integer] = ACTIONS(3764),
    [sym_continue_as_identifier] = ACTIONS(3766),
    [sym_preproc_open] = ACTIONS(3766),
  },
  [STATE(1936)] = {
    [sym_identifier] = ACTIONS(3768),
    [anon_sym_SEMI] = ACTIONS(3770),
    [anon_sym_DOT] = ACTIONS(3768),
    [anon_sym_EQ] = ACTIONS(3770),
    [anon_sym_DASH] = ACTIONS(3768),
    [aux_sym_boolean_token1] = ACTIONS(3768),
    [aux_sym_boolean_token2] = ACTIONS(3768),
    [sym_decimal] = ACTIONS(3768),
    [anon_sym_LPAREN] = ACTIONS(3770),
    [anon_sym_DOT_DOT] = ACTIONS(3770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3768),
    [anon_sym_STAR] = ACTIONS(3768),
    [anon_sym_LBRACK] = ACTIONS(3770),
    [aux_sym_record_type_token1] = ACTIONS(3768),
    [aux_sym_basic_type_token21] = ACTIONS(3768),
    [aux_sym_basic_type_token22] = ACTIONS(3768),
    [aux_sym_basic_type_token48] = ACTIONS(3768),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3768),
    [anon_sym_COLON_COLON] = ACTIONS(3770),
    [anon_sym_POUNDif] = ACTIONS(3770),
    [anon_sym_POUNDIF] = ACTIONS(3770),
    [anon_sym_POUNDIf] = ACTIONS(3770),
    [anon_sym_not] = ACTIONS(3768),
    [anon_sym_NOT] = ACTIONS(3768),
    [anon_sym_Not] = ACTIONS(3768),
    [anon_sym_POUNDelse] = ACTIONS(3770),
    [anon_sym_POUNDELSE] = ACTIONS(3770),
    [anon_sym_POUNDElse] = ACTIONS(3770),
    [anon_sym_POUNDelse2] = ACTIONS(3770),
    [anon_sym_POUNDELSE2] = ACTIONS(3770),
    [anon_sym_POUNDElse2] = ACTIONS(3770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3770),
    [aux_sym__expression_token1] = ACTIONS(3770),
    [aux_sym__expression_token2] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3768),
    [anon_sym_SLASH] = ACTIONS(3768),
    [anon_sym_div] = ACTIONS(3768),
    [anon_sym_DIV] = ACTIONS(3768),
    [anon_sym_Div] = ACTIONS(3768),
    [anon_sym_mod] = ACTIONS(3768),
    [anon_sym_MOD] = ACTIONS(3768),
    [anon_sym_Mod] = ACTIONS(3768),
    [anon_sym_PLUS] = ACTIONS(3768),
    [anon_sym_GT_EQ] = ACTIONS(3770),
    [anon_sym_LT_EQ] = ACTIONS(3770),
    [anon_sym_GT] = ACTIONS(3768),
    [anon_sym_LT] = ACTIONS(3768),
    [anon_sym_LT_GT] = ACTIONS(3770),
    [anon_sym_and] = ACTIONS(3768),
    [anon_sym_AND] = ACTIONS(3768),
    [anon_sym_And] = ACTIONS(3768),
    [anon_sym_or] = ACTIONS(3768),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3768),
    [anon_sym_xor] = ACTIONS(3768),
    [anon_sym_XOR] = ACTIONS(3768),
    [anon_sym_Xor] = ACTIONS(3768),
    [anon_sym_QMARK] = ACTIONS(3770),
    [sym_datetime_literal] = ACTIONS(3770),
    [sym_date_literal] = ACTIONS(3768),
    [sym_time_literal] = ACTIONS(3768),
    [sym_biginteger_literal] = ACTIONS(3770),
    [anon_sym_if] = ACTIONS(3768),
    [anon_sym_IF] = ACTIONS(3768),
    [anon_sym_If] = ACTIONS(3768),
    [anon_sym_else] = ACTIONS(3768),
    [anon_sym_ELSE] = ACTIONS(3768),
    [anon_sym_Else] = ACTIONS(3768),
    [anon_sym_case] = ACTIONS(3768),
    [anon_sym_CASE] = ACTIONS(3768),
    [anon_sym_Case] = ACTIONS(3768),
    [anon_sym_for] = ACTIONS(3768),
    [anon_sym_FOR] = ACTIONS(3768),
    [anon_sym_For] = ACTIONS(3768),
    [anon_sym_foreach] = ACTIONS(3768),
    [anon_sym_FOREACH] = ACTIONS(3768),
    [anon_sym_Foreach] = ACTIONS(3768),
    [anon_sym_while] = ACTIONS(3768),
    [anon_sym_WHILE] = ACTIONS(3768),
    [anon_sym_While] = ACTIONS(3768),
    [anon_sym_repeat] = ACTIONS(3768),
    [anon_sym_REPEAT] = ACTIONS(3768),
    [anon_sym_Repeat] = ACTIONS(3768),
    [anon_sym_until] = ACTIONS(3768),
    [anon_sym_UNTIL] = ACTIONS(3768),
    [anon_sym_Until] = ACTIONS(3768),
    [anon_sym_exit] = ACTIONS(3768),
    [anon_sym_EXIT] = ACTIONS(3768),
    [anon_sym_Exit] = ACTIONS(3768),
    [anon_sym_continue] = ACTIONS(3768),
    [anon_sym_CONTINUE] = ACTIONS(3768),
    [anon_sym_Continue] = ACTIONS(3768),
    [anon_sym_break] = ACTIONS(3768),
    [anon_sym_BREAK] = ACTIONS(3768),
    [anon_sym_Break] = ACTIONS(3768),
    [anon_sym_with] = ACTIONS(3768),
    [anon_sym_WITH] = ACTIONS(3768),
    [anon_sym_With] = ACTIONS(3768),
    [sym_asserterror_keyword] = ACTIONS(3770),
    [anon_sym_in] = ACTIONS(3768),
    [anon_sym_IN] = ACTIONS(3768),
    [anon_sym_In] = ACTIONS(3768),
    [sym_page_keyword] = ACTIONS(3768),
    [anon_sym_codeunit] = ACTIONS(3768),
    [anon_sym_CODEUNIT] = ACTIONS(3768),
    [anon_sym_Codeunit] = ACTIONS(3768),
    [anon_sym_CodeUnit] = ACTIONS(3768),
    [anon_sym_COdeunit] = ACTIONS(3768),
    [anon_sym_codeUnit] = ACTIONS(3768),
    [sym_report_keyword] = ACTIONS(3768),
    [sym_query_keyword] = ACTIONS(3768),
    [anon_sym_xmlport] = ACTIONS(3768),
    [anon_sym_XMLPORT] = ACTIONS(3768),
    [anon_sym_Xmlport] = ACTIONS(3768),
    [anon_sym_XMLport] = ACTIONS(3768),
    [anon_sym_XMLPort] = ACTIONS(3768),
    [anon_sym_XmlPort] = ACTIONS(3768),
    [anon_sym_enum] = ACTIONS(3768),
    [anon_sym_ENUM] = ACTIONS(3768),
    [anon_sym_Enum] = ACTIONS(3768),
    [anon_sym_eNUM] = ACTIONS(3768),
    [anon_sym_eNum] = ACTIONS(3768),
    [anon_sym_ENum] = ACTIONS(3768),
    [sym_quoted_identifier] = ACTIONS(3770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3770),
    [sym_verbatim_string] = ACTIONS(3770),
    [sym_integer] = ACTIONS(3768),
    [sym_continue_as_identifier] = ACTIONS(3770),
    [sym_preproc_open] = ACTIONS(3770),
  },
  [STATE(1937)] = {
    [sym_identifier] = ACTIONS(3772),
    [anon_sym_SEMI] = ACTIONS(3774),
    [anon_sym_DOT] = ACTIONS(3772),
    [anon_sym_EQ] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [aux_sym_boolean_token1] = ACTIONS(3772),
    [aux_sym_boolean_token2] = ACTIONS(3772),
    [sym_decimal] = ACTIONS(3772),
    [anon_sym_LPAREN] = ACTIONS(3774),
    [anon_sym_DOT_DOT] = ACTIONS(3774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(3772),
    [anon_sym_LBRACK] = ACTIONS(3774),
    [aux_sym_record_type_token1] = ACTIONS(3772),
    [aux_sym_basic_type_token21] = ACTIONS(3772),
    [aux_sym_basic_type_token22] = ACTIONS(3772),
    [aux_sym_basic_type_token48] = ACTIONS(3772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3772),
    [anon_sym_COLON_COLON] = ACTIONS(3774),
    [anon_sym_POUNDif] = ACTIONS(3774),
    [anon_sym_POUNDIF] = ACTIONS(3774),
    [anon_sym_POUNDIf] = ACTIONS(3774),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_NOT] = ACTIONS(3772),
    [anon_sym_Not] = ACTIONS(3772),
    [anon_sym_POUNDelse] = ACTIONS(3774),
    [anon_sym_POUNDELSE] = ACTIONS(3774),
    [anon_sym_POUNDElse] = ACTIONS(3774),
    [anon_sym_POUNDelse2] = ACTIONS(3774),
    [anon_sym_POUNDELSE2] = ACTIONS(3774),
    [anon_sym_POUNDElse2] = ACTIONS(3774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3774),
    [aux_sym__expression_token1] = ACTIONS(3774),
    [aux_sym__expression_token2] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3772),
    [anon_sym_SLASH] = ACTIONS(3772),
    [anon_sym_div] = ACTIONS(3772),
    [anon_sym_DIV] = ACTIONS(3772),
    [anon_sym_Div] = ACTIONS(3772),
    [anon_sym_mod] = ACTIONS(3772),
    [anon_sym_MOD] = ACTIONS(3772),
    [anon_sym_Mod] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_GT_EQ] = ACTIONS(3774),
    [anon_sym_LT_EQ] = ACTIONS(3774),
    [anon_sym_GT] = ACTIONS(3772),
    [anon_sym_LT] = ACTIONS(3772),
    [anon_sym_LT_GT] = ACTIONS(3774),
    [anon_sym_and] = ACTIONS(3772),
    [anon_sym_AND] = ACTIONS(3772),
    [anon_sym_And] = ACTIONS(3772),
    [anon_sym_or] = ACTIONS(3772),
    [anon_sym_OR] = ACTIONS(3772),
    [anon_sym_Or] = ACTIONS(3772),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3772),
    [anon_sym_Xor] = ACTIONS(3772),
    [anon_sym_QMARK] = ACTIONS(3774),
    [sym_datetime_literal] = ACTIONS(3774),
    [sym_date_literal] = ACTIONS(3772),
    [sym_time_literal] = ACTIONS(3772),
    [sym_biginteger_literal] = ACTIONS(3774),
    [anon_sym_if] = ACTIONS(3772),
    [anon_sym_IF] = ACTIONS(3772),
    [anon_sym_If] = ACTIONS(3772),
    [anon_sym_else] = ACTIONS(3772),
    [anon_sym_ELSE] = ACTIONS(3772),
    [anon_sym_Else] = ACTIONS(3772),
    [anon_sym_case] = ACTIONS(3772),
    [anon_sym_CASE] = ACTIONS(3772),
    [anon_sym_Case] = ACTIONS(3772),
    [anon_sym_for] = ACTIONS(3772),
    [anon_sym_FOR] = ACTIONS(3772),
    [anon_sym_For] = ACTIONS(3772),
    [anon_sym_foreach] = ACTIONS(3772),
    [anon_sym_FOREACH] = ACTIONS(3772),
    [anon_sym_Foreach] = ACTIONS(3772),
    [anon_sym_while] = ACTIONS(3772),
    [anon_sym_WHILE] = ACTIONS(3772),
    [anon_sym_While] = ACTIONS(3772),
    [anon_sym_repeat] = ACTIONS(3772),
    [anon_sym_REPEAT] = ACTIONS(3772),
    [anon_sym_Repeat] = ACTIONS(3772),
    [anon_sym_until] = ACTIONS(3772),
    [anon_sym_UNTIL] = ACTIONS(3772),
    [anon_sym_Until] = ACTIONS(3772),
    [anon_sym_exit] = ACTIONS(3772),
    [anon_sym_EXIT] = ACTIONS(3772),
    [anon_sym_Exit] = ACTIONS(3772),
    [anon_sym_continue] = ACTIONS(3772),
    [anon_sym_CONTINUE] = ACTIONS(3772),
    [anon_sym_Continue] = ACTIONS(3772),
    [anon_sym_break] = ACTIONS(3772),
    [anon_sym_BREAK] = ACTIONS(3772),
    [anon_sym_Break] = ACTIONS(3772),
    [anon_sym_with] = ACTIONS(3772),
    [anon_sym_WITH] = ACTIONS(3772),
    [anon_sym_With] = ACTIONS(3772),
    [sym_asserterror_keyword] = ACTIONS(3774),
    [anon_sym_in] = ACTIONS(3772),
    [anon_sym_IN] = ACTIONS(3772),
    [anon_sym_In] = ACTIONS(3772),
    [sym_page_keyword] = ACTIONS(3772),
    [anon_sym_codeunit] = ACTIONS(3772),
    [anon_sym_CODEUNIT] = ACTIONS(3772),
    [anon_sym_Codeunit] = ACTIONS(3772),
    [anon_sym_CodeUnit] = ACTIONS(3772),
    [anon_sym_COdeunit] = ACTIONS(3772),
    [anon_sym_codeUnit] = ACTIONS(3772),
    [sym_report_keyword] = ACTIONS(3772),
    [sym_query_keyword] = ACTIONS(3772),
    [anon_sym_xmlport] = ACTIONS(3772),
    [anon_sym_XMLPORT] = ACTIONS(3772),
    [anon_sym_Xmlport] = ACTIONS(3772),
    [anon_sym_XMLport] = ACTIONS(3772),
    [anon_sym_XMLPort] = ACTIONS(3772),
    [anon_sym_XmlPort] = ACTIONS(3772),
    [anon_sym_enum] = ACTIONS(3772),
    [anon_sym_ENUM] = ACTIONS(3772),
    [anon_sym_Enum] = ACTIONS(3772),
    [anon_sym_eNUM] = ACTIONS(3772),
    [anon_sym_eNum] = ACTIONS(3772),
    [anon_sym_ENum] = ACTIONS(3772),
    [sym_quoted_identifier] = ACTIONS(3774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3774),
    [sym_verbatim_string] = ACTIONS(3774),
    [sym_integer] = ACTIONS(3772),
    [sym_continue_as_identifier] = ACTIONS(3774),
    [sym_preproc_open] = ACTIONS(3774),
  },
  [STATE(1938)] = {
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_SEMI] = ACTIONS(3748),
    [anon_sym_DOT] = ACTIONS(3746),
    [anon_sym_EQ] = ACTIONS(3748),
    [anon_sym_DASH] = ACTIONS(3746),
    [aux_sym_boolean_token1] = ACTIONS(3746),
    [aux_sym_boolean_token2] = ACTIONS(3746),
    [sym_decimal] = ACTIONS(3746),
    [anon_sym_LPAREN] = ACTIONS(3748),
    [anon_sym_DOT_DOT] = ACTIONS(3748),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3746),
    [anon_sym_STAR] = ACTIONS(3746),
    [anon_sym_LBRACK] = ACTIONS(3748),
    [aux_sym_record_type_token1] = ACTIONS(3746),
    [aux_sym_basic_type_token21] = ACTIONS(3746),
    [aux_sym_basic_type_token22] = ACTIONS(3746),
    [aux_sym_basic_type_token48] = ACTIONS(3746),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3746),
    [anon_sym_POUNDif] = ACTIONS(3748),
    [anon_sym_POUNDIF] = ACTIONS(3748),
    [anon_sym_POUNDIf] = ACTIONS(3748),
    [anon_sym_not] = ACTIONS(3746),
    [anon_sym_NOT] = ACTIONS(3746),
    [anon_sym_Not] = ACTIONS(3746),
    [anon_sym_POUNDelse] = ACTIONS(3748),
    [anon_sym_POUNDELSE] = ACTIONS(3748),
    [anon_sym_POUNDElse] = ACTIONS(3748),
    [anon_sym_POUNDelse2] = ACTIONS(3748),
    [anon_sym_POUNDELSE2] = ACTIONS(3748),
    [anon_sym_POUNDElse2] = ACTIONS(3748),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3748),
    [aux_sym__expression_token1] = ACTIONS(3748),
    [aux_sym__expression_token2] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3746),
    [anon_sym_SLASH] = ACTIONS(3746),
    [anon_sym_div] = ACTIONS(3746),
    [anon_sym_DIV] = ACTIONS(3746),
    [anon_sym_Div] = ACTIONS(3746),
    [anon_sym_mod] = ACTIONS(3746),
    [anon_sym_MOD] = ACTIONS(3746),
    [anon_sym_Mod] = ACTIONS(3746),
    [anon_sym_PLUS] = ACTIONS(3746),
    [anon_sym_GT_EQ] = ACTIONS(3748),
    [anon_sym_LT_EQ] = ACTIONS(3748),
    [anon_sym_GT] = ACTIONS(3746),
    [anon_sym_LT] = ACTIONS(3746),
    [anon_sym_LT_GT] = ACTIONS(3748),
    [anon_sym_and] = ACTIONS(3746),
    [anon_sym_AND] = ACTIONS(3746),
    [anon_sym_And] = ACTIONS(3746),
    [anon_sym_or] = ACTIONS(3746),
    [anon_sym_OR] = ACTIONS(3746),
    [anon_sym_Or] = ACTIONS(3746),
    [anon_sym_xor] = ACTIONS(3746),
    [anon_sym_XOR] = ACTIONS(3746),
    [anon_sym_Xor] = ACTIONS(3746),
    [anon_sym_QMARK] = ACTIONS(3748),
    [sym_datetime_literal] = ACTIONS(3748),
    [sym_date_literal] = ACTIONS(3746),
    [sym_time_literal] = ACTIONS(3746),
    [sym_biginteger_literal] = ACTIONS(3748),
    [anon_sym_if] = ACTIONS(3746),
    [anon_sym_IF] = ACTIONS(3746),
    [anon_sym_If] = ACTIONS(3746),
    [anon_sym_else] = ACTIONS(3746),
    [anon_sym_ELSE] = ACTIONS(3746),
    [anon_sym_Else] = ACTIONS(3746),
    [anon_sym_case] = ACTIONS(3746),
    [anon_sym_CASE] = ACTIONS(3746),
    [anon_sym_Case] = ACTIONS(3746),
    [anon_sym_for] = ACTIONS(3746),
    [anon_sym_FOR] = ACTIONS(3746),
    [anon_sym_For] = ACTIONS(3746),
    [anon_sym_foreach] = ACTIONS(3746),
    [anon_sym_FOREACH] = ACTIONS(3746),
    [anon_sym_Foreach] = ACTIONS(3746),
    [anon_sym_while] = ACTIONS(3746),
    [anon_sym_WHILE] = ACTIONS(3746),
    [anon_sym_While] = ACTIONS(3746),
    [anon_sym_repeat] = ACTIONS(3746),
    [anon_sym_REPEAT] = ACTIONS(3746),
    [anon_sym_Repeat] = ACTIONS(3746),
    [anon_sym_until] = ACTIONS(3746),
    [anon_sym_UNTIL] = ACTIONS(3746),
    [anon_sym_Until] = ACTIONS(3746),
    [anon_sym_exit] = ACTIONS(3746),
    [anon_sym_EXIT] = ACTIONS(3746),
    [anon_sym_Exit] = ACTIONS(3746),
    [anon_sym_continue] = ACTIONS(3746),
    [anon_sym_CONTINUE] = ACTIONS(3746),
    [anon_sym_Continue] = ACTIONS(3746),
    [anon_sym_break] = ACTIONS(3746),
    [anon_sym_BREAK] = ACTIONS(3746),
    [anon_sym_Break] = ACTIONS(3746),
    [anon_sym_with] = ACTIONS(3746),
    [anon_sym_WITH] = ACTIONS(3746),
    [anon_sym_With] = ACTIONS(3746),
    [sym_asserterror_keyword] = ACTIONS(3748),
    [anon_sym_in] = ACTIONS(3746),
    [anon_sym_IN] = ACTIONS(3746),
    [anon_sym_In] = ACTIONS(3746),
    [sym_page_keyword] = ACTIONS(3746),
    [anon_sym_codeunit] = ACTIONS(3746),
    [anon_sym_CODEUNIT] = ACTIONS(3746),
    [anon_sym_Codeunit] = ACTIONS(3746),
    [anon_sym_CodeUnit] = ACTIONS(3746),
    [anon_sym_COdeunit] = ACTIONS(3746),
    [anon_sym_codeUnit] = ACTIONS(3746),
    [sym_report_keyword] = ACTIONS(3746),
    [sym_query_keyword] = ACTIONS(3746),
    [anon_sym_xmlport] = ACTIONS(3746),
    [anon_sym_XMLPORT] = ACTIONS(3746),
    [anon_sym_Xmlport] = ACTIONS(3746),
    [anon_sym_XMLport] = ACTIONS(3746),
    [anon_sym_XMLPort] = ACTIONS(3746),
    [anon_sym_XmlPort] = ACTIONS(3746),
    [anon_sym_enum] = ACTIONS(3746),
    [anon_sym_ENUM] = ACTIONS(3746),
    [anon_sym_Enum] = ACTIONS(3746),
    [anon_sym_eNUM] = ACTIONS(3746),
    [anon_sym_eNum] = ACTIONS(3746),
    [anon_sym_ENum] = ACTIONS(3746),
    [sym_temporary_keyword] = ACTIONS(4179),
    [sym_quoted_identifier] = ACTIONS(3748),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3748),
    [sym_verbatim_string] = ACTIONS(3748),
    [sym_integer] = ACTIONS(3746),
    [sym_continue_as_identifier] = ACTIONS(3748),
    [sym_preproc_open] = ACTIONS(3748),
  },
  [STATE(1939)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_COMMA] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [aux_sym_boolean_token1] = ACTIONS(3562),
    [aux_sym_boolean_token2] = ACTIONS(3562),
    [sym_decimal] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_record_type_token1] = ACTIONS(3562),
    [aux_sym_basic_type_token21] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token48] = ACTIONS(3562),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_not] = ACTIONS(3562),
    [anon_sym_NOT] = ACTIONS(3562),
    [anon_sym_Not] = ACTIONS(3562),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3562),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [sym_datetime_literal] = ACTIONS(3564),
    [sym_date_literal] = ACTIONS(3562),
    [sym_time_literal] = ACTIONS(3562),
    [sym_biginteger_literal] = ACTIONS(3564),
    [anon_sym_if] = ACTIONS(3562),
    [anon_sym_IF] = ACTIONS(3562),
    [anon_sym_If] = ACTIONS(3562),
    [anon_sym_else] = ACTIONS(3562),
    [anon_sym_ELSE] = ACTIONS(3562),
    [anon_sym_Else] = ACTIONS(3562),
    [anon_sym_case] = ACTIONS(3562),
    [anon_sym_CASE] = ACTIONS(3562),
    [anon_sym_Case] = ACTIONS(3562),
    [anon_sym_for] = ACTIONS(3562),
    [anon_sym_FOR] = ACTIONS(3562),
    [anon_sym_For] = ACTIONS(3562),
    [anon_sym_foreach] = ACTIONS(3562),
    [anon_sym_FOREACH] = ACTIONS(3562),
    [anon_sym_Foreach] = ACTIONS(3562),
    [anon_sym_while] = ACTIONS(3562),
    [anon_sym_WHILE] = ACTIONS(3562),
    [anon_sym_While] = ACTIONS(3562),
    [anon_sym_repeat] = ACTIONS(3562),
    [anon_sym_REPEAT] = ACTIONS(3562),
    [anon_sym_Repeat] = ACTIONS(3562),
    [anon_sym_exit] = ACTIONS(3562),
    [anon_sym_EXIT] = ACTIONS(3562),
    [anon_sym_Exit] = ACTIONS(3562),
    [anon_sym_continue] = ACTIONS(3562),
    [anon_sym_CONTINUE] = ACTIONS(3562),
    [anon_sym_Continue] = ACTIONS(3562),
    [anon_sym_break] = ACTIONS(3562),
    [anon_sym_BREAK] = ACTIONS(3562),
    [anon_sym_Break] = ACTIONS(3562),
    [anon_sym_with] = ACTIONS(3562),
    [anon_sym_WITH] = ACTIONS(3562),
    [anon_sym_With] = ACTIONS(3562),
    [sym_asserterror_keyword] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_page_keyword] = ACTIONS(3562),
    [anon_sym_codeunit] = ACTIONS(3562),
    [anon_sym_CODEUNIT] = ACTIONS(3562),
    [anon_sym_Codeunit] = ACTIONS(3562),
    [anon_sym_CodeUnit] = ACTIONS(3562),
    [anon_sym_COdeunit] = ACTIONS(3562),
    [anon_sym_codeUnit] = ACTIONS(3562),
    [sym_report_keyword] = ACTIONS(3562),
    [sym_query_keyword] = ACTIONS(3562),
    [anon_sym_xmlport] = ACTIONS(3562),
    [anon_sym_XMLPORT] = ACTIONS(3562),
    [anon_sym_Xmlport] = ACTIONS(3562),
    [anon_sym_XMLport] = ACTIONS(3562),
    [anon_sym_XMLPort] = ACTIONS(3562),
    [anon_sym_XmlPort] = ACTIONS(3562),
    [anon_sym_enum] = ACTIONS(3562),
    [anon_sym_ENUM] = ACTIONS(3562),
    [anon_sym_Enum] = ACTIONS(3562),
    [anon_sym_eNUM] = ACTIONS(3562),
    [anon_sym_eNum] = ACTIONS(3562),
    [anon_sym_ENum] = ACTIONS(3562),
    [sym_temporary_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3564),
    [sym_verbatim_string] = ACTIONS(3564),
    [sym_integer] = ACTIONS(3562),
    [sym_continue_as_identifier] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_end_keyword] = ACTIONS(3564),
  },
  [STATE(1940)] = {
    [sym_identifier] = ACTIONS(3738),
    [anon_sym_SEMI] = ACTIONS(3740),
    [anon_sym_DOT] = ACTIONS(3738),
    [anon_sym_EQ] = ACTIONS(3740),
    [anon_sym_COMMA] = ACTIONS(3740),
    [anon_sym_DASH] = ACTIONS(3738),
    [aux_sym_boolean_token1] = ACTIONS(3738),
    [aux_sym_boolean_token2] = ACTIONS(3738),
    [sym_decimal] = ACTIONS(3738),
    [anon_sym_LPAREN] = ACTIONS(3740),
    [anon_sym_DOT_DOT] = ACTIONS(3740),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3738),
    [anon_sym_STAR] = ACTIONS(3738),
    [anon_sym_LBRACK] = ACTIONS(3740),
    [aux_sym_record_type_token1] = ACTIONS(3738),
    [aux_sym_basic_type_token21] = ACTIONS(3738),
    [aux_sym_basic_type_token22] = ACTIONS(3738),
    [aux_sym_basic_type_token48] = ACTIONS(3738),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3738),
    [anon_sym_POUNDif] = ACTIONS(3740),
    [anon_sym_POUNDIF] = ACTIONS(3740),
    [anon_sym_POUNDIf] = ACTIONS(3740),
    [anon_sym_not] = ACTIONS(3738),
    [anon_sym_NOT] = ACTIONS(3738),
    [anon_sym_Not] = ACTIONS(3738),
    [anon_sym_POUNDelse] = ACTIONS(3740),
    [anon_sym_POUNDELSE] = ACTIONS(3740),
    [anon_sym_POUNDElse] = ACTIONS(3740),
    [anon_sym_POUNDelse2] = ACTIONS(3740),
    [anon_sym_POUNDELSE2] = ACTIONS(3740),
    [anon_sym_POUNDElse2] = ACTIONS(3740),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3740),
    [aux_sym__expression_token1] = ACTIONS(3740),
    [aux_sym__expression_token2] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3738),
    [anon_sym_SLASH] = ACTIONS(3738),
    [anon_sym_div] = ACTIONS(3738),
    [anon_sym_DIV] = ACTIONS(3738),
    [anon_sym_Div] = ACTIONS(3738),
    [anon_sym_mod] = ACTIONS(3738),
    [anon_sym_MOD] = ACTIONS(3738),
    [anon_sym_Mod] = ACTIONS(3738),
    [anon_sym_PLUS] = ACTIONS(3738),
    [anon_sym_GT_EQ] = ACTIONS(3740),
    [anon_sym_LT_EQ] = ACTIONS(3740),
    [anon_sym_GT] = ACTIONS(3738),
    [anon_sym_LT] = ACTIONS(3738),
    [anon_sym_LT_GT] = ACTIONS(3740),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3738),
    [anon_sym_And] = ACTIONS(3738),
    [anon_sym_or] = ACTIONS(3738),
    [anon_sym_OR] = ACTIONS(3738),
    [anon_sym_Or] = ACTIONS(3738),
    [anon_sym_xor] = ACTIONS(3738),
    [anon_sym_XOR] = ACTIONS(3738),
    [anon_sym_Xor] = ACTIONS(3738),
    [anon_sym_QMARK] = ACTIONS(3740),
    [sym_datetime_literal] = ACTIONS(3740),
    [sym_date_literal] = ACTIONS(3738),
    [sym_time_literal] = ACTIONS(3738),
    [sym_biginteger_literal] = ACTIONS(3740),
    [anon_sym_if] = ACTIONS(3738),
    [anon_sym_IF] = ACTIONS(3738),
    [anon_sym_If] = ACTIONS(3738),
    [anon_sym_else] = ACTIONS(3738),
    [anon_sym_ELSE] = ACTIONS(3738),
    [anon_sym_Else] = ACTIONS(3738),
    [anon_sym_case] = ACTIONS(3738),
    [anon_sym_CASE] = ACTIONS(3738),
    [anon_sym_Case] = ACTIONS(3738),
    [anon_sym_for] = ACTIONS(3738),
    [anon_sym_FOR] = ACTIONS(3738),
    [anon_sym_For] = ACTIONS(3738),
    [anon_sym_foreach] = ACTIONS(3738),
    [anon_sym_FOREACH] = ACTIONS(3738),
    [anon_sym_Foreach] = ACTIONS(3738),
    [anon_sym_while] = ACTIONS(3738),
    [anon_sym_WHILE] = ACTIONS(3738),
    [anon_sym_While] = ACTIONS(3738),
    [anon_sym_repeat] = ACTIONS(3738),
    [anon_sym_REPEAT] = ACTIONS(3738),
    [anon_sym_Repeat] = ACTIONS(3738),
    [anon_sym_until] = ACTIONS(3738),
    [anon_sym_UNTIL] = ACTIONS(3738),
    [anon_sym_Until] = ACTIONS(3738),
    [anon_sym_exit] = ACTIONS(3738),
    [anon_sym_EXIT] = ACTIONS(3738),
    [anon_sym_Exit] = ACTIONS(3738),
    [anon_sym_continue] = ACTIONS(3738),
    [anon_sym_CONTINUE] = ACTIONS(3738),
    [anon_sym_Continue] = ACTIONS(3738),
    [anon_sym_break] = ACTIONS(3738),
    [anon_sym_BREAK] = ACTIONS(3738),
    [anon_sym_Break] = ACTIONS(3738),
    [anon_sym_with] = ACTIONS(3738),
    [anon_sym_WITH] = ACTIONS(3738),
    [anon_sym_With] = ACTIONS(3738),
    [sym_asserterror_keyword] = ACTIONS(3740),
    [anon_sym_in] = ACTIONS(3738),
    [anon_sym_IN] = ACTIONS(3738),
    [anon_sym_In] = ACTIONS(3738),
    [sym_page_keyword] = ACTIONS(3738),
    [anon_sym_codeunit] = ACTIONS(3738),
    [anon_sym_CODEUNIT] = ACTIONS(3738),
    [anon_sym_Codeunit] = ACTIONS(3738),
    [anon_sym_CodeUnit] = ACTIONS(3738),
    [anon_sym_COdeunit] = ACTIONS(3738),
    [anon_sym_codeUnit] = ACTIONS(3738),
    [sym_report_keyword] = ACTIONS(3738),
    [sym_query_keyword] = ACTIONS(3738),
    [anon_sym_xmlport] = ACTIONS(3738),
    [anon_sym_XMLPORT] = ACTIONS(3738),
    [anon_sym_Xmlport] = ACTIONS(3738),
    [anon_sym_XMLport] = ACTIONS(3738),
    [anon_sym_XMLPort] = ACTIONS(3738),
    [anon_sym_XmlPort] = ACTIONS(3738),
    [anon_sym_enum] = ACTIONS(3738),
    [anon_sym_ENUM] = ACTIONS(3738),
    [anon_sym_Enum] = ACTIONS(3738),
    [anon_sym_eNUM] = ACTIONS(3738),
    [anon_sym_eNum] = ACTIONS(3738),
    [anon_sym_ENum] = ACTIONS(3738),
    [sym_quoted_identifier] = ACTIONS(3740),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3740),
    [sym_verbatim_string] = ACTIONS(3740),
    [sym_integer] = ACTIONS(3738),
    [sym_continue_as_identifier] = ACTIONS(3740),
    [sym_preproc_open] = ACTIONS(3740),
  },
  [STATE(1941)] = {
    [sym_identifier] = ACTIONS(3784),
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [aux_sym_boolean_token1] = ACTIONS(3784),
    [aux_sym_boolean_token2] = ACTIONS(3784),
    [sym_decimal] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3784),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_record_type_token1] = ACTIONS(3784),
    [aux_sym_basic_type_token21] = ACTIONS(3784),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_basic_type_token48] = ACTIONS(3784),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_not] = ACTIONS(3784),
    [anon_sym_NOT] = ACTIONS(3784),
    [anon_sym_Not] = ACTIONS(3784),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3784),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3784),
    [anon_sym_DIV] = ACTIONS(3784),
    [anon_sym_Div] = ACTIONS(3784),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3784),
    [anon_sym_AND] = ACTIONS(3784),
    [anon_sym_And] = ACTIONS(3784),
    [anon_sym_or] = ACTIONS(3784),
    [anon_sym_OR] = ACTIONS(3784),
    [anon_sym_Or] = ACTIONS(3784),
    [anon_sym_xor] = ACTIONS(3784),
    [anon_sym_XOR] = ACTIONS(3784),
    [anon_sym_Xor] = ACTIONS(3784),
    [anon_sym_QMARK] = ACTIONS(3786),
    [sym_datetime_literal] = ACTIONS(3786),
    [sym_date_literal] = ACTIONS(3784),
    [sym_time_literal] = ACTIONS(3784),
    [sym_biginteger_literal] = ACTIONS(3786),
    [anon_sym_if] = ACTIONS(3784),
    [anon_sym_IF] = ACTIONS(3784),
    [anon_sym_If] = ACTIONS(3784),
    [anon_sym_else] = ACTIONS(3784),
    [anon_sym_ELSE] = ACTIONS(3784),
    [anon_sym_Else] = ACTIONS(3784),
    [anon_sym_case] = ACTIONS(3784),
    [anon_sym_CASE] = ACTIONS(3784),
    [anon_sym_Case] = ACTIONS(3784),
    [anon_sym_for] = ACTIONS(3784),
    [anon_sym_FOR] = ACTIONS(3784),
    [anon_sym_For] = ACTIONS(3784),
    [anon_sym_foreach] = ACTIONS(3784),
    [anon_sym_FOREACH] = ACTIONS(3784),
    [anon_sym_Foreach] = ACTIONS(3784),
    [anon_sym_while] = ACTIONS(3784),
    [anon_sym_WHILE] = ACTIONS(3784),
    [anon_sym_While] = ACTIONS(3784),
    [anon_sym_repeat] = ACTIONS(3784),
    [anon_sym_REPEAT] = ACTIONS(3784),
    [anon_sym_Repeat] = ACTIONS(3784),
    [anon_sym_until] = ACTIONS(3784),
    [anon_sym_UNTIL] = ACTIONS(3784),
    [anon_sym_Until] = ACTIONS(3784),
    [anon_sym_exit] = ACTIONS(3784),
    [anon_sym_EXIT] = ACTIONS(3784),
    [anon_sym_Exit] = ACTIONS(3784),
    [anon_sym_continue] = ACTIONS(3784),
    [anon_sym_CONTINUE] = ACTIONS(3784),
    [anon_sym_Continue] = ACTIONS(3784),
    [anon_sym_break] = ACTIONS(3784),
    [anon_sym_BREAK] = ACTIONS(3784),
    [anon_sym_Break] = ACTIONS(3784),
    [anon_sym_with] = ACTIONS(3784),
    [anon_sym_WITH] = ACTIONS(3784),
    [anon_sym_With] = ACTIONS(3784),
    [sym_asserterror_keyword] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_page_keyword] = ACTIONS(3784),
    [anon_sym_codeunit] = ACTIONS(3784),
    [anon_sym_CODEUNIT] = ACTIONS(3784),
    [anon_sym_Codeunit] = ACTIONS(3784),
    [anon_sym_CodeUnit] = ACTIONS(3784),
    [anon_sym_COdeunit] = ACTIONS(3784),
    [anon_sym_codeUnit] = ACTIONS(3784),
    [sym_report_keyword] = ACTIONS(3784),
    [sym_query_keyword] = ACTIONS(3784),
    [anon_sym_xmlport] = ACTIONS(3784),
    [anon_sym_XMLPORT] = ACTIONS(3784),
    [anon_sym_Xmlport] = ACTIONS(3784),
    [anon_sym_XMLport] = ACTIONS(3784),
    [anon_sym_XMLPort] = ACTIONS(3784),
    [anon_sym_XmlPort] = ACTIONS(3784),
    [anon_sym_enum] = ACTIONS(3784),
    [anon_sym_ENUM] = ACTIONS(3784),
    [anon_sym_Enum] = ACTIONS(3784),
    [anon_sym_eNUM] = ACTIONS(3784),
    [anon_sym_eNum] = ACTIONS(3784),
    [anon_sym_ENum] = ACTIONS(3784),
    [sym_quoted_identifier] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3786),
    [sym_verbatim_string] = ACTIONS(3786),
    [sym_integer] = ACTIONS(3784),
    [sym_continue_as_identifier] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
  },
  [STATE(1942)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1994),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_DASH] = ACTIONS(602),
    [aux_sym_boolean_token1] = ACTIONS(602),
    [aux_sym_boolean_token2] = ACTIONS(602),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(602),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(602),
    [aux_sym_basic_type_token21] = ACTIONS(602),
    [aux_sym_basic_type_token22] = ACTIONS(602),
    [aux_sym_basic_type_token48] = ACTIONS(602),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(602),
    [aux_sym_keyword_identifier_token1] = ACTIONS(602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(602),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(602),
    [anon_sym_IF] = ACTIONS(602),
    [anon_sym_If] = ACTIONS(602),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_case] = ACTIONS(602),
    [anon_sym_CASE] = ACTIONS(602),
    [anon_sym_Case] = ACTIONS(602),
    [anon_sym_for] = ACTIONS(602),
    [anon_sym_FOR] = ACTIONS(602),
    [anon_sym_For] = ACTIONS(602),
    [anon_sym_foreach] = ACTIONS(602),
    [anon_sym_FOREACH] = ACTIONS(602),
    [anon_sym_Foreach] = ACTIONS(602),
    [anon_sym_while] = ACTIONS(602),
    [anon_sym_WHILE] = ACTIONS(602),
    [anon_sym_While] = ACTIONS(602),
    [anon_sym_repeat] = ACTIONS(602),
    [anon_sym_REPEAT] = ACTIONS(602),
    [anon_sym_Repeat] = ACTIONS(602),
    [anon_sym_exit] = ACTIONS(602),
    [anon_sym_EXIT] = ACTIONS(602),
    [anon_sym_Exit] = ACTIONS(602),
    [anon_sym_continue] = ACTIONS(602),
    [anon_sym_CONTINUE] = ACTIONS(602),
    [anon_sym_Continue] = ACTIONS(602),
    [anon_sym_break] = ACTIONS(602),
    [anon_sym_BREAK] = ACTIONS(602),
    [anon_sym_Break] = ACTIONS(602),
    [anon_sym_with] = ACTIONS(602),
    [anon_sym_WITH] = ACTIONS(602),
    [anon_sym_With] = ACTIONS(602),
    [sym_asserterror_keyword] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_page_keyword] = ACTIONS(602),
    [anon_sym_codeunit] = ACTIONS(602),
    [anon_sym_CODEUNIT] = ACTIONS(602),
    [anon_sym_Codeunit] = ACTIONS(602),
    [anon_sym_CodeUnit] = ACTIONS(602),
    [anon_sym_COdeunit] = ACTIONS(602),
    [anon_sym_codeUnit] = ACTIONS(602),
    [sym_report_keyword] = ACTIONS(602),
    [sym_query_keyword] = ACTIONS(602),
    [anon_sym_xmlport] = ACTIONS(602),
    [anon_sym_XMLPORT] = ACTIONS(602),
    [anon_sym_Xmlport] = ACTIONS(602),
    [anon_sym_XMLport] = ACTIONS(602),
    [anon_sym_XMLPort] = ACTIONS(602),
    [anon_sym_XmlPort] = ACTIONS(602),
    [anon_sym_enum] = ACTIONS(602),
    [anon_sym_ENUM] = ACTIONS(602),
    [anon_sym_Enum] = ACTIONS(602),
    [anon_sym_eNUM] = ACTIONS(602),
    [anon_sym_eNum] = ACTIONS(602),
    [anon_sym_ENum] = ACTIONS(602),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(600),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(602),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
    [sym_end_keyword] = ACTIONS(600),
  },
  [STATE(1943)] = {
    [sym_preproc_conditional_object] = STATE(1970),
    [sym_using_statement] = STATE(1970),
    [sym__object] = STATE(1970),
    [sym_preproc_split_declaration] = STATE(1970),
    [sym_table_declaration] = STATE(1970),
    [sym_page_declaration] = STATE(1970),
    [sym_report_declaration] = STATE(1970),
    [sym_query_declaration] = STATE(1970),
    [sym_xmlport_declaration] = STATE(1970),
    [sym_permissionset_declaration] = STATE(1970),
    [sym_codeunit_declaration] = STATE(1970),
    [sym_enum_declaration] = STATE(1970),
    [sym_tableextension_declaration] = STATE(1970),
    [sym_pageextension_declaration] = STATE(1970),
    [sym_reportextension_declaration] = STATE(1970),
    [sym_enumextension_declaration] = STATE(1970),
    [sym_permissionsetextension_declaration] = STATE(1970),
    [sym_controladdin_declaration] = STATE(1970),
    [sym_profile_declaration] = STATE(1970),
    [sym_entitlement_declaration] = STATE(1970),
    [sym_profileextension_declaration] = STATE(1970),
    [sym_interface_declaration] = STATE(1970),
    [sym_pagecustomization_declaration] = STATE(1970),
    [sym_dotnet_declaration] = STATE(1970),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2763),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1970),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1944)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1948),
    [sym_identifier] = ACTIONS(3699),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(4183),
    [anon_sym_EQ] = ACTIONS(3701),
    [anon_sym_DASH] = ACTIONS(3699),
    [aux_sym_boolean_token1] = ACTIONS(3699),
    [aux_sym_boolean_token2] = ACTIONS(3699),
    [sym_decimal] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_DOT_DOT] = ACTIONS(3701),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3699),
    [anon_sym_STAR] = ACTIONS(3699),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [aux_sym_record_type_token1] = ACTIONS(3699),
    [aux_sym_basic_type_token21] = ACTIONS(3699),
    [aux_sym_basic_type_token22] = ACTIONS(3699),
    [aux_sym_basic_type_token48] = ACTIONS(3699),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3699),
    [anon_sym_POUNDif] = ACTIONS(3701),
    [anon_sym_POUNDIF] = ACTIONS(3701),
    [anon_sym_POUNDIf] = ACTIONS(3701),
    [anon_sym_not] = ACTIONS(3699),
    [anon_sym_NOT] = ACTIONS(3699),
    [anon_sym_Not] = ACTIONS(3699),
    [anon_sym_POUNDelse] = ACTIONS(3701),
    [anon_sym_POUNDELSE] = ACTIONS(3701),
    [anon_sym_POUNDElse] = ACTIONS(3701),
    [anon_sym_POUNDelse2] = ACTIONS(3701),
    [anon_sym_POUNDELSE2] = ACTIONS(3701),
    [anon_sym_POUNDElse2] = ACTIONS(3701),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3701),
    [aux_sym__expression_token1] = ACTIONS(3701),
    [aux_sym__expression_token2] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3699),
    [anon_sym_SLASH] = ACTIONS(3699),
    [anon_sym_div] = ACTIONS(3699),
    [anon_sym_DIV] = ACTIONS(3699),
    [anon_sym_Div] = ACTIONS(3699),
    [anon_sym_mod] = ACTIONS(3699),
    [anon_sym_MOD] = ACTIONS(3699),
    [anon_sym_Mod] = ACTIONS(3699),
    [anon_sym_PLUS] = ACTIONS(3699),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT] = ACTIONS(3699),
    [anon_sym_LT] = ACTIONS(3699),
    [anon_sym_LT_GT] = ACTIONS(3701),
    [anon_sym_and] = ACTIONS(3699),
    [anon_sym_AND] = ACTIONS(3699),
    [anon_sym_And] = ACTIONS(3699),
    [anon_sym_or] = ACTIONS(3699),
    [anon_sym_OR] = ACTIONS(3699),
    [anon_sym_Or] = ACTIONS(3699),
    [anon_sym_xor] = ACTIONS(3699),
    [anon_sym_XOR] = ACTIONS(3699),
    [anon_sym_Xor] = ACTIONS(3699),
    [anon_sym_QMARK] = ACTIONS(3701),
    [sym_datetime_literal] = ACTIONS(3701),
    [sym_date_literal] = ACTIONS(3699),
    [sym_time_literal] = ACTIONS(3699),
    [sym_biginteger_literal] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3699),
    [anon_sym_IF] = ACTIONS(3699),
    [anon_sym_If] = ACTIONS(3699),
    [anon_sym_else] = ACTIONS(3699),
    [anon_sym_ELSE] = ACTIONS(3699),
    [anon_sym_Else] = ACTIONS(3699),
    [anon_sym_case] = ACTIONS(3699),
    [anon_sym_CASE] = ACTIONS(3699),
    [anon_sym_Case] = ACTIONS(3699),
    [anon_sym_for] = ACTIONS(3699),
    [anon_sym_FOR] = ACTIONS(3699),
    [anon_sym_For] = ACTIONS(3699),
    [anon_sym_foreach] = ACTIONS(3699),
    [anon_sym_FOREACH] = ACTIONS(3699),
    [anon_sym_Foreach] = ACTIONS(3699),
    [anon_sym_while] = ACTIONS(3699),
    [anon_sym_WHILE] = ACTIONS(3699),
    [anon_sym_While] = ACTIONS(3699),
    [anon_sym_repeat] = ACTIONS(3699),
    [anon_sym_REPEAT] = ACTIONS(3699),
    [anon_sym_Repeat] = ACTIONS(3699),
    [anon_sym_exit] = ACTIONS(3699),
    [anon_sym_EXIT] = ACTIONS(3699),
    [anon_sym_Exit] = ACTIONS(3699),
    [anon_sym_continue] = ACTIONS(3699),
    [anon_sym_CONTINUE] = ACTIONS(3699),
    [anon_sym_Continue] = ACTIONS(3699),
    [anon_sym_break] = ACTIONS(3699),
    [anon_sym_BREAK] = ACTIONS(3699),
    [anon_sym_Break] = ACTIONS(3699),
    [anon_sym_with] = ACTIONS(3699),
    [anon_sym_WITH] = ACTIONS(3699),
    [anon_sym_With] = ACTIONS(3699),
    [sym_asserterror_keyword] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3699),
    [anon_sym_IN] = ACTIONS(3699),
    [anon_sym_In] = ACTIONS(3699),
    [sym_page_keyword] = ACTIONS(3699),
    [anon_sym_codeunit] = ACTIONS(3699),
    [anon_sym_CODEUNIT] = ACTIONS(3699),
    [anon_sym_Codeunit] = ACTIONS(3699),
    [anon_sym_CodeUnit] = ACTIONS(3699),
    [anon_sym_COdeunit] = ACTIONS(3699),
    [anon_sym_codeUnit] = ACTIONS(3699),
    [sym_report_keyword] = ACTIONS(3699),
    [sym_query_keyword] = ACTIONS(3699),
    [anon_sym_xmlport] = ACTIONS(3699),
    [anon_sym_XMLPORT] = ACTIONS(3699),
    [anon_sym_Xmlport] = ACTIONS(3699),
    [anon_sym_XMLport] = ACTIONS(3699),
    [anon_sym_XMLPort] = ACTIONS(3699),
    [anon_sym_XmlPort] = ACTIONS(3699),
    [anon_sym_enum] = ACTIONS(3699),
    [anon_sym_ENUM] = ACTIONS(3699),
    [anon_sym_Enum] = ACTIONS(3699),
    [anon_sym_eNUM] = ACTIONS(3699),
    [anon_sym_eNum] = ACTIONS(3699),
    [anon_sym_ENum] = ACTIONS(3699),
    [sym_temporary_keyword] = ACTIONS(3699),
    [sym_quoted_identifier] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3701),
    [sym_verbatim_string] = ACTIONS(3701),
    [sym_integer] = ACTIONS(3699),
    [sym_continue_as_identifier] = ACTIONS(3701),
    [sym_preproc_open] = ACTIONS(3701),
    [sym_end_keyword] = ACTIONS(3701),
  },
  [STATE(1945)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_until] = ACTIONS(3869),
    [anon_sym_UNTIL] = ACTIONS(3869),
    [anon_sym_Until] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
  },
  [STATE(1946)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_until] = ACTIONS(3873),
    [anon_sym_UNTIL] = ACTIONS(3873),
    [anon_sym_Until] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
  },
  [STATE(1947)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_until] = ACTIONS(3869),
    [anon_sym_UNTIL] = ACTIONS(3869),
    [anon_sym_Until] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
  },
  [STATE(1948)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1948),
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(4185),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_if] = ACTIONS(3703),
    [anon_sym_IF] = ACTIONS(3703),
    [anon_sym_If] = ACTIONS(3703),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_case] = ACTIONS(3703),
    [anon_sym_CASE] = ACTIONS(3703),
    [anon_sym_Case] = ACTIONS(3703),
    [anon_sym_for] = ACTIONS(3703),
    [anon_sym_FOR] = ACTIONS(3703),
    [anon_sym_For] = ACTIONS(3703),
    [anon_sym_foreach] = ACTIONS(3703),
    [anon_sym_FOREACH] = ACTIONS(3703),
    [anon_sym_Foreach] = ACTIONS(3703),
    [anon_sym_while] = ACTIONS(3703),
    [anon_sym_WHILE] = ACTIONS(3703),
    [anon_sym_While] = ACTIONS(3703),
    [anon_sym_repeat] = ACTIONS(3703),
    [anon_sym_REPEAT] = ACTIONS(3703),
    [anon_sym_Repeat] = ACTIONS(3703),
    [anon_sym_exit] = ACTIONS(3703),
    [anon_sym_EXIT] = ACTIONS(3703),
    [anon_sym_Exit] = ACTIONS(3703),
    [anon_sym_continue] = ACTIONS(3703),
    [anon_sym_CONTINUE] = ACTIONS(3703),
    [anon_sym_Continue] = ACTIONS(3703),
    [anon_sym_break] = ACTIONS(3703),
    [anon_sym_BREAK] = ACTIONS(3703),
    [anon_sym_Break] = ACTIONS(3703),
    [anon_sym_with] = ACTIONS(3703),
    [anon_sym_WITH] = ACTIONS(3703),
    [anon_sym_With] = ACTIONS(3703),
    [sym_asserterror_keyword] = ACTIONS(3705),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
    [sym_end_keyword] = ACTIONS(3705),
  },
  [STATE(1949)] = {
    [sym__body_element] = STATE(5388),
    [sym_empty_statement] = STATE(5388),
    [sym_property] = STATE(5388),
    [sym_permissions_property] = STATE(5388),
    [sym_table_relation_property] = STATE(5388),
    [sym_fields_section] = STATE(5388),
    [sym_keys_section] = STATE(5388),
    [sym_fieldgroups_section] = STATE(5388),
    [sym_enum_value_declaration] = STATE(5388),
    [sym_labels_section] = STATE(5388),
    [sym_layout_section] = STATE(5388),
    [sym__layout_element] = STATE(5406),
    [sym_area_section] = STATE(5406),
    [sym_group_section] = STATE(5406),
    [sym_repeater_section] = STATE(5406),
    [sym_cuegroup_section] = STATE(5406),
    [sym_fixed_section] = STATE(5406),
    [sym_grid_section] = STATE(5406),
    [sym_page_field] = STATE(5406),
    [sym_part_section] = STATE(5406),
    [sym_systempart_section] = STATE(5406),
    [sym_usercontrol_section] = STATE(5406),
    [sym_preproc_split_field] = STATE(5406),
    [sym__field_header] = STATE(10877),
    [sym_label_section] = STATE(5406),
    [sym_addfirst_modification] = STATE(5406),
    [sym_addlast_modification] = STATE(5406),
    [sym_addafter_modification] = STATE(5406),
    [sym_addbefore_modification] = STATE(5406),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(5406),
    [sym_movelast_modification] = STATE(5406),
    [sym_moveafter_modification] = STATE(5406),
    [sym_movebefore_modification] = STATE(5406),
    [sym_actions_section] = STATE(5388),
    [sym_views_section] = STATE(5388),
    [sym_dataset_section] = STATE(5388),
    [sym_requestpage_section] = STATE(5388),
    [sym_rendering_section] = STATE(5388),
    [sym_elements_section] = STATE(5388),
    [sym_schema_section] = STATE(5388),
    [sym_assembly_declaration] = STATE(5388),
    [sym_event_declaration] = STATE(5388),
    [sym_procedure] = STATE(5388),
    [sym_preproc_split_procedure] = STATE(5388),
    [sym__procedure_preamble] = STATE(10866),
    [sym_preproc_split_procedure_preamble] = STATE(5388),
    [sym__procedure_header] = STATE(9968),
    [sym_procedure_modifier] = STATE(18047),
    [sym_trigger_declaration] = STATE(5388),
    [sym_var_section] = STATE(5388),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(5388),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_elif] = STATE(2097),
    [sym_preproc_else] = STATE(2248),
    [sym_preproc_endif] = STATE(8027),
    [sym_preproc_conditional_layout] = STATE(5406),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3843),
    [aux_sym_layout_section_repeat1] = STATE(4894),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10859),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10880),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2093),
    [aux_sym_preproc_conditional_layout_mixed_repeat2] = STATE(10735),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4190),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4226),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(1950)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2029),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_SEMI] = ACTIONS(3669),
    [anon_sym_DOT] = ACTIONS(3667),
    [anon_sym_EQ] = ACTIONS(3669),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_DASH] = ACTIONS(3667),
    [aux_sym_boolean_token1] = ACTIONS(3667),
    [aux_sym_boolean_token2] = ACTIONS(3667),
    [sym_decimal] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3669),
    [anon_sym_DOT_DOT] = ACTIONS(3669),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3667),
    [anon_sym_STAR] = ACTIONS(3667),
    [anon_sym_LBRACK] = ACTIONS(3669),
    [aux_sym_record_type_token1] = ACTIONS(3667),
    [aux_sym_basic_type_token21] = ACTIONS(3667),
    [aux_sym_basic_type_token22] = ACTIONS(3667),
    [aux_sym_basic_type_token48] = ACTIONS(3667),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3667),
    [anon_sym_POUNDif] = ACTIONS(3669),
    [anon_sym_POUNDIF] = ACTIONS(3669),
    [anon_sym_POUNDIf] = ACTIONS(3669),
    [anon_sym_not] = ACTIONS(3667),
    [anon_sym_NOT] = ACTIONS(3667),
    [anon_sym_Not] = ACTIONS(3667),
    [anon_sym_POUNDelse] = ACTIONS(3669),
    [anon_sym_POUNDELSE] = ACTIONS(3669),
    [anon_sym_POUNDElse] = ACTIONS(3669),
    [anon_sym_POUNDelse2] = ACTIONS(3669),
    [anon_sym_POUNDELSE2] = ACTIONS(3669),
    [anon_sym_POUNDElse2] = ACTIONS(3669),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3669),
    [aux_sym__expression_token1] = ACTIONS(3669),
    [aux_sym__expression_token2] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3667),
    [anon_sym_SLASH] = ACTIONS(3667),
    [anon_sym_div] = ACTIONS(3667),
    [anon_sym_DIV] = ACTIONS(3667),
    [anon_sym_Div] = ACTIONS(3667),
    [anon_sym_mod] = ACTIONS(3667),
    [anon_sym_MOD] = ACTIONS(3667),
    [anon_sym_Mod] = ACTIONS(3667),
    [anon_sym_PLUS] = ACTIONS(3667),
    [anon_sym_GT_EQ] = ACTIONS(3669),
    [anon_sym_LT_EQ] = ACTIONS(3669),
    [anon_sym_GT] = ACTIONS(3667),
    [anon_sym_LT] = ACTIONS(3667),
    [anon_sym_LT_GT] = ACTIONS(3669),
    [anon_sym_and] = ACTIONS(3667),
    [anon_sym_AND] = ACTIONS(3667),
    [anon_sym_And] = ACTIONS(3667),
    [anon_sym_or] = ACTIONS(3667),
    [anon_sym_OR] = ACTIONS(3667),
    [anon_sym_Or] = ACTIONS(3667),
    [anon_sym_xor] = ACTIONS(3667),
    [anon_sym_XOR] = ACTIONS(3667),
    [anon_sym_Xor] = ACTIONS(3667),
    [anon_sym_QMARK] = ACTIONS(3669),
    [sym_datetime_literal] = ACTIONS(3669),
    [sym_date_literal] = ACTIONS(3667),
    [sym_time_literal] = ACTIONS(3667),
    [sym_biginteger_literal] = ACTIONS(3669),
    [anon_sym_if] = ACTIONS(3667),
    [anon_sym_IF] = ACTIONS(3667),
    [anon_sym_If] = ACTIONS(3667),
    [anon_sym_else] = ACTIONS(3667),
    [anon_sym_ELSE] = ACTIONS(3667),
    [anon_sym_Else] = ACTIONS(3667),
    [anon_sym_case] = ACTIONS(3667),
    [anon_sym_CASE] = ACTIONS(3667),
    [anon_sym_Case] = ACTIONS(3667),
    [anon_sym_for] = ACTIONS(3667),
    [anon_sym_FOR] = ACTIONS(3667),
    [anon_sym_For] = ACTIONS(3667),
    [anon_sym_foreach] = ACTIONS(3667),
    [anon_sym_FOREACH] = ACTIONS(3667),
    [anon_sym_Foreach] = ACTIONS(3667),
    [anon_sym_while] = ACTIONS(3667),
    [anon_sym_WHILE] = ACTIONS(3667),
    [anon_sym_While] = ACTIONS(3667),
    [anon_sym_repeat] = ACTIONS(3667),
    [anon_sym_REPEAT] = ACTIONS(3667),
    [anon_sym_Repeat] = ACTIONS(3667),
    [anon_sym_exit] = ACTIONS(3667),
    [anon_sym_EXIT] = ACTIONS(3667),
    [anon_sym_Exit] = ACTIONS(3667),
    [anon_sym_continue] = ACTIONS(3667),
    [anon_sym_CONTINUE] = ACTIONS(3667),
    [anon_sym_Continue] = ACTIONS(3667),
    [anon_sym_break] = ACTIONS(3667),
    [anon_sym_BREAK] = ACTIONS(3667),
    [anon_sym_Break] = ACTIONS(3667),
    [anon_sym_with] = ACTIONS(3667),
    [anon_sym_WITH] = ACTIONS(3667),
    [anon_sym_With] = ACTIONS(3667),
    [sym_asserterror_keyword] = ACTIONS(3669),
    [anon_sym_in] = ACTIONS(3667),
    [anon_sym_IN] = ACTIONS(3667),
    [anon_sym_In] = ACTIONS(3667),
    [sym_page_keyword] = ACTIONS(3667),
    [anon_sym_codeunit] = ACTIONS(3667),
    [anon_sym_CODEUNIT] = ACTIONS(3667),
    [anon_sym_Codeunit] = ACTIONS(3667),
    [anon_sym_CodeUnit] = ACTIONS(3667),
    [anon_sym_COdeunit] = ACTIONS(3667),
    [anon_sym_codeUnit] = ACTIONS(3667),
    [sym_report_keyword] = ACTIONS(3667),
    [sym_query_keyword] = ACTIONS(3667),
    [anon_sym_xmlport] = ACTIONS(3667),
    [anon_sym_XMLPORT] = ACTIONS(3667),
    [anon_sym_Xmlport] = ACTIONS(3667),
    [anon_sym_XMLport] = ACTIONS(3667),
    [anon_sym_XMLPort] = ACTIONS(3667),
    [anon_sym_XmlPort] = ACTIONS(3667),
    [anon_sym_enum] = ACTIONS(3667),
    [anon_sym_ENUM] = ACTIONS(3667),
    [anon_sym_Enum] = ACTIONS(3667),
    [anon_sym_eNUM] = ACTIONS(3667),
    [anon_sym_eNum] = ACTIONS(3667),
    [anon_sym_ENum] = ACTIONS(3667),
    [sym_quoted_identifier] = ACTIONS(3669),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3669),
    [sym_verbatim_string] = ACTIONS(3669),
    [sym_integer] = ACTIONS(3667),
    [sym_continue_as_identifier] = ACTIONS(3669),
    [sym_preproc_open] = ACTIONS(3669),
    [sym_end_keyword] = ACTIONS(3669),
  },
  [STATE(1951)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3687),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1952)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_end_keyword] = ACTIONS(3568),
  },
  [STATE(1953)] = {
    [sym_identifier] = ACTIONS(3877),
    [anon_sym_SEMI] = ACTIONS(3879),
    [anon_sym_DOT] = ACTIONS(3877),
    [anon_sym_EQ] = ACTIONS(3879),
    [anon_sym_DASH] = ACTIONS(3877),
    [aux_sym_boolean_token1] = ACTIONS(3877),
    [aux_sym_boolean_token2] = ACTIONS(3877),
    [sym_decimal] = ACTIONS(3877),
    [anon_sym_LPAREN] = ACTIONS(3879),
    [anon_sym_DOT_DOT] = ACTIONS(3879),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3877),
    [anon_sym_STAR] = ACTIONS(3877),
    [anon_sym_LBRACK] = ACTIONS(3879),
    [aux_sym_record_type_token1] = ACTIONS(3877),
    [aux_sym_basic_type_token21] = ACTIONS(3877),
    [aux_sym_basic_type_token22] = ACTIONS(3877),
    [aux_sym_basic_type_token48] = ACTIONS(3877),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3877),
    [anon_sym_POUNDif] = ACTIONS(3879),
    [anon_sym_POUNDIF] = ACTIONS(3879),
    [anon_sym_POUNDIf] = ACTIONS(3879),
    [anon_sym_not] = ACTIONS(3877),
    [anon_sym_NOT] = ACTIONS(3877),
    [anon_sym_Not] = ACTIONS(3877),
    [anon_sym_POUNDelse] = ACTIONS(3879),
    [anon_sym_POUNDELSE] = ACTIONS(3879),
    [anon_sym_POUNDElse] = ACTIONS(3879),
    [anon_sym_POUNDelse2] = ACTIONS(3879),
    [anon_sym_POUNDELSE2] = ACTIONS(3879),
    [anon_sym_POUNDElse2] = ACTIONS(3879),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3879),
    [aux_sym__expression_token1] = ACTIONS(3879),
    [aux_sym__expression_token2] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3877),
    [anon_sym_SLASH] = ACTIONS(3877),
    [anon_sym_div] = ACTIONS(3877),
    [anon_sym_DIV] = ACTIONS(3877),
    [anon_sym_Div] = ACTIONS(3877),
    [anon_sym_mod] = ACTIONS(3877),
    [anon_sym_MOD] = ACTIONS(3877),
    [anon_sym_Mod] = ACTIONS(3877),
    [anon_sym_PLUS] = ACTIONS(3877),
    [anon_sym_GT_EQ] = ACTIONS(3879),
    [anon_sym_LT_EQ] = ACTIONS(3879),
    [anon_sym_GT] = ACTIONS(3877),
    [anon_sym_LT] = ACTIONS(3877),
    [anon_sym_LT_GT] = ACTIONS(3879),
    [anon_sym_and] = ACTIONS(3877),
    [anon_sym_AND] = ACTIONS(3877),
    [anon_sym_And] = ACTIONS(3877),
    [anon_sym_or] = ACTIONS(3877),
    [anon_sym_OR] = ACTIONS(3877),
    [anon_sym_Or] = ACTIONS(3877),
    [anon_sym_xor] = ACTIONS(3877),
    [anon_sym_XOR] = ACTIONS(3877),
    [anon_sym_Xor] = ACTIONS(3877),
    [anon_sym_QMARK] = ACTIONS(3879),
    [sym_datetime_literal] = ACTIONS(3879),
    [sym_date_literal] = ACTIONS(3877),
    [sym_time_literal] = ACTIONS(3877),
    [sym_biginteger_literal] = ACTIONS(3879),
    [anon_sym_if] = ACTIONS(3877),
    [anon_sym_IF] = ACTIONS(3877),
    [anon_sym_If] = ACTIONS(3877),
    [anon_sym_else] = ACTIONS(3877),
    [anon_sym_ELSE] = ACTIONS(3877),
    [anon_sym_Else] = ACTIONS(3877),
    [anon_sym_case] = ACTIONS(3877),
    [anon_sym_CASE] = ACTIONS(3877),
    [anon_sym_Case] = ACTIONS(3877),
    [anon_sym_for] = ACTIONS(3877),
    [anon_sym_FOR] = ACTIONS(3877),
    [anon_sym_For] = ACTIONS(3877),
    [anon_sym_foreach] = ACTIONS(3877),
    [anon_sym_FOREACH] = ACTIONS(3877),
    [anon_sym_Foreach] = ACTIONS(3877),
    [anon_sym_while] = ACTIONS(3877),
    [anon_sym_WHILE] = ACTIONS(3877),
    [anon_sym_While] = ACTIONS(3877),
    [anon_sym_repeat] = ACTIONS(3877),
    [anon_sym_REPEAT] = ACTIONS(3877),
    [anon_sym_Repeat] = ACTIONS(3877),
    [anon_sym_until] = ACTIONS(3877),
    [anon_sym_UNTIL] = ACTIONS(3877),
    [anon_sym_Until] = ACTIONS(3877),
    [anon_sym_exit] = ACTIONS(3877),
    [anon_sym_EXIT] = ACTIONS(3877),
    [anon_sym_Exit] = ACTIONS(3877),
    [anon_sym_continue] = ACTIONS(3877),
    [anon_sym_CONTINUE] = ACTIONS(3877),
    [anon_sym_Continue] = ACTIONS(3877),
    [anon_sym_break] = ACTIONS(3877),
    [anon_sym_BREAK] = ACTIONS(3877),
    [anon_sym_Break] = ACTIONS(3877),
    [anon_sym_with] = ACTIONS(3877),
    [anon_sym_WITH] = ACTIONS(3877),
    [anon_sym_With] = ACTIONS(3877),
    [sym_asserterror_keyword] = ACTIONS(3879),
    [anon_sym_in] = ACTIONS(3877),
    [anon_sym_IN] = ACTIONS(3877),
    [anon_sym_In] = ACTIONS(3877),
    [sym_page_keyword] = ACTIONS(3877),
    [anon_sym_codeunit] = ACTIONS(3877),
    [anon_sym_CODEUNIT] = ACTIONS(3877),
    [anon_sym_Codeunit] = ACTIONS(3877),
    [anon_sym_CodeUnit] = ACTIONS(3877),
    [anon_sym_COdeunit] = ACTIONS(3877),
    [anon_sym_codeUnit] = ACTIONS(3877),
    [sym_report_keyword] = ACTIONS(3877),
    [sym_query_keyword] = ACTIONS(3877),
    [anon_sym_xmlport] = ACTIONS(3877),
    [anon_sym_XMLPORT] = ACTIONS(3877),
    [anon_sym_Xmlport] = ACTIONS(3877),
    [anon_sym_XMLport] = ACTIONS(3877),
    [anon_sym_XMLPort] = ACTIONS(3877),
    [anon_sym_XmlPort] = ACTIONS(3877),
    [anon_sym_enum] = ACTIONS(3877),
    [anon_sym_ENUM] = ACTIONS(3877),
    [anon_sym_Enum] = ACTIONS(3877),
    [anon_sym_eNUM] = ACTIONS(3877),
    [anon_sym_eNum] = ACTIONS(3877),
    [anon_sym_ENum] = ACTIONS(3877),
    [sym_quoted_identifier] = ACTIONS(3879),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3879),
    [sym_verbatim_string] = ACTIONS(3879),
    [sym_integer] = ACTIONS(3877),
    [sym_continue_as_identifier] = ACTIONS(3879),
    [sym_preproc_open] = ACTIONS(3879),
  },
  [STATE(1954)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_end_keyword] = ACTIONS(3568),
  },
  [STATE(1955)] = {
    [aux_sym_option_member_list_repeat1] = STATE(1950),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_if] = ACTIONS(3689),
    [anon_sym_IF] = ACTIONS(3689),
    [anon_sym_If] = ACTIONS(3689),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_case] = ACTIONS(3689),
    [anon_sym_CASE] = ACTIONS(3689),
    [anon_sym_Case] = ACTIONS(3689),
    [anon_sym_for] = ACTIONS(3689),
    [anon_sym_FOR] = ACTIONS(3689),
    [anon_sym_For] = ACTIONS(3689),
    [anon_sym_foreach] = ACTIONS(3689),
    [anon_sym_FOREACH] = ACTIONS(3689),
    [anon_sym_Foreach] = ACTIONS(3689),
    [anon_sym_while] = ACTIONS(3689),
    [anon_sym_WHILE] = ACTIONS(3689),
    [anon_sym_While] = ACTIONS(3689),
    [anon_sym_repeat] = ACTIONS(3689),
    [anon_sym_REPEAT] = ACTIONS(3689),
    [anon_sym_Repeat] = ACTIONS(3689),
    [anon_sym_exit] = ACTIONS(3689),
    [anon_sym_EXIT] = ACTIONS(3689),
    [anon_sym_Exit] = ACTIONS(3689),
    [anon_sym_continue] = ACTIONS(3689),
    [anon_sym_CONTINUE] = ACTIONS(3689),
    [anon_sym_Continue] = ACTIONS(3689),
    [anon_sym_break] = ACTIONS(3689),
    [anon_sym_BREAK] = ACTIONS(3689),
    [anon_sym_Break] = ACTIONS(3689),
    [anon_sym_with] = ACTIONS(3689),
    [anon_sym_WITH] = ACTIONS(3689),
    [anon_sym_With] = ACTIONS(3689),
    [sym_asserterror_keyword] = ACTIONS(3691),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
    [sym_end_keyword] = ACTIONS(3691),
  },
  [STATE(1956)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_if] = ACTIONS(3677),
    [anon_sym_IF] = ACTIONS(3677),
    [anon_sym_If] = ACTIONS(3677),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_case] = ACTIONS(3677),
    [anon_sym_CASE] = ACTIONS(3677),
    [anon_sym_Case] = ACTIONS(3677),
    [anon_sym_for] = ACTIONS(3677),
    [anon_sym_FOR] = ACTIONS(3677),
    [anon_sym_For] = ACTIONS(3677),
    [anon_sym_foreach] = ACTIONS(3677),
    [anon_sym_FOREACH] = ACTIONS(3677),
    [anon_sym_Foreach] = ACTIONS(3677),
    [anon_sym_while] = ACTIONS(3677),
    [anon_sym_WHILE] = ACTIONS(3677),
    [anon_sym_While] = ACTIONS(3677),
    [anon_sym_repeat] = ACTIONS(3677),
    [anon_sym_REPEAT] = ACTIONS(3677),
    [anon_sym_Repeat] = ACTIONS(3677),
    [anon_sym_exit] = ACTIONS(3677),
    [anon_sym_EXIT] = ACTIONS(3677),
    [anon_sym_Exit] = ACTIONS(3677),
    [anon_sym_continue] = ACTIONS(3677),
    [anon_sym_CONTINUE] = ACTIONS(3677),
    [anon_sym_Continue] = ACTIONS(3677),
    [anon_sym_break] = ACTIONS(3677),
    [anon_sym_BREAK] = ACTIONS(3677),
    [anon_sym_Break] = ACTIONS(3677),
    [anon_sym_with] = ACTIONS(3677),
    [anon_sym_WITH] = ACTIONS(3677),
    [anon_sym_With] = ACTIONS(3677),
    [sym_asserterror_keyword] = ACTIONS(3679),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
    [sym_end_keyword] = ACTIONS(3679),
  },
  [STATE(1957)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_until] = ACTIONS(3869),
    [anon_sym_UNTIL] = ACTIONS(3869),
    [anon_sym_Until] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
  },
  [STATE(1958)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_until] = ACTIONS(3865),
    [anon_sym_UNTIL] = ACTIONS(3865),
    [anon_sym_Until] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
  },
  [STATE(1959)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3639),
    [anon_sym_SEMI] = ACTIONS(3641),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3641),
    [anon_sym_DASH] = ACTIONS(3639),
    [aux_sym_boolean_token1] = ACTIONS(3639),
    [aux_sym_boolean_token2] = ACTIONS(3639),
    [sym_decimal] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3641),
    [anon_sym_DOT_DOT] = ACTIONS(3641),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3639),
    [anon_sym_STAR] = ACTIONS(3639),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3639),
    [aux_sym_basic_type_token21] = ACTIONS(3639),
    [aux_sym_basic_type_token22] = ACTIONS(3639),
    [aux_sym_basic_type_token48] = ACTIONS(3639),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3639),
    [anon_sym_POUNDif] = ACTIONS(3641),
    [anon_sym_POUNDIF] = ACTIONS(3641),
    [anon_sym_POUNDIf] = ACTIONS(3641),
    [anon_sym_not] = ACTIONS(3639),
    [anon_sym_NOT] = ACTIONS(3639),
    [anon_sym_Not] = ACTIONS(3639),
    [anon_sym_POUNDelse] = ACTIONS(3641),
    [anon_sym_POUNDELSE] = ACTIONS(3641),
    [anon_sym_POUNDElse] = ACTIONS(3641),
    [anon_sym_POUNDelse2] = ACTIONS(3641),
    [anon_sym_POUNDELSE2] = ACTIONS(3641),
    [anon_sym_POUNDElse2] = ACTIONS(3641),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3641),
    [aux_sym__expression_token1] = ACTIONS(3641),
    [aux_sym__expression_token2] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3639),
    [anon_sym_SLASH] = ACTIONS(3639),
    [anon_sym_div] = ACTIONS(3639),
    [anon_sym_DIV] = ACTIONS(3639),
    [anon_sym_Div] = ACTIONS(3639),
    [anon_sym_mod] = ACTIONS(3639),
    [anon_sym_MOD] = ACTIONS(3639),
    [anon_sym_Mod] = ACTIONS(3639),
    [anon_sym_PLUS] = ACTIONS(3639),
    [anon_sym_GT_EQ] = ACTIONS(3641),
    [anon_sym_LT_EQ] = ACTIONS(3641),
    [anon_sym_GT] = ACTIONS(3639),
    [anon_sym_LT] = ACTIONS(3639),
    [anon_sym_LT_GT] = ACTIONS(3641),
    [anon_sym_and] = ACTIONS(3639),
    [anon_sym_AND] = ACTIONS(3639),
    [anon_sym_And] = ACTIONS(3639),
    [anon_sym_or] = ACTIONS(3639),
    [anon_sym_OR] = ACTIONS(3639),
    [anon_sym_Or] = ACTIONS(3639),
    [anon_sym_xor] = ACTIONS(3639),
    [anon_sym_XOR] = ACTIONS(3639),
    [anon_sym_Xor] = ACTIONS(3639),
    [anon_sym_QMARK] = ACTIONS(3641),
    [sym_datetime_literal] = ACTIONS(3641),
    [sym_date_literal] = ACTIONS(3639),
    [sym_time_literal] = ACTIONS(3639),
    [sym_biginteger_literal] = ACTIONS(3641),
    [anon_sym_if] = ACTIONS(3639),
    [anon_sym_IF] = ACTIONS(3639),
    [anon_sym_If] = ACTIONS(3639),
    [anon_sym_else] = ACTIONS(3639),
    [anon_sym_ELSE] = ACTIONS(3639),
    [anon_sym_Else] = ACTIONS(3639),
    [anon_sym_case] = ACTIONS(3639),
    [anon_sym_CASE] = ACTIONS(3639),
    [anon_sym_Case] = ACTIONS(3639),
    [anon_sym_for] = ACTIONS(3639),
    [anon_sym_FOR] = ACTIONS(3639),
    [anon_sym_For] = ACTIONS(3639),
    [anon_sym_foreach] = ACTIONS(3639),
    [anon_sym_FOREACH] = ACTIONS(3639),
    [anon_sym_Foreach] = ACTIONS(3639),
    [anon_sym_while] = ACTIONS(3639),
    [anon_sym_WHILE] = ACTIONS(3639),
    [anon_sym_While] = ACTIONS(3639),
    [anon_sym_repeat] = ACTIONS(3639),
    [anon_sym_REPEAT] = ACTIONS(3639),
    [anon_sym_Repeat] = ACTIONS(3639),
    [anon_sym_exit] = ACTIONS(3639),
    [anon_sym_EXIT] = ACTIONS(3639),
    [anon_sym_Exit] = ACTIONS(3639),
    [anon_sym_continue] = ACTIONS(3639),
    [anon_sym_CONTINUE] = ACTIONS(3639),
    [anon_sym_Continue] = ACTIONS(3639),
    [anon_sym_break] = ACTIONS(3639),
    [anon_sym_BREAK] = ACTIONS(3639),
    [anon_sym_Break] = ACTIONS(3639),
    [anon_sym_with] = ACTIONS(3639),
    [anon_sym_WITH] = ACTIONS(3639),
    [anon_sym_With] = ACTIONS(3639),
    [sym_asserterror_keyword] = ACTIONS(3641),
    [anon_sym_in] = ACTIONS(3639),
    [anon_sym_IN] = ACTIONS(3639),
    [anon_sym_In] = ACTIONS(3639),
    [sym_page_keyword] = ACTIONS(3639),
    [anon_sym_codeunit] = ACTIONS(3639),
    [anon_sym_CODEUNIT] = ACTIONS(3639),
    [anon_sym_Codeunit] = ACTIONS(3639),
    [anon_sym_CodeUnit] = ACTIONS(3639),
    [anon_sym_COdeunit] = ACTIONS(3639),
    [anon_sym_codeUnit] = ACTIONS(3639),
    [sym_report_keyword] = ACTIONS(3639),
    [sym_query_keyword] = ACTIONS(3639),
    [anon_sym_xmlport] = ACTIONS(3639),
    [anon_sym_XMLPORT] = ACTIONS(3639),
    [anon_sym_Xmlport] = ACTIONS(3639),
    [anon_sym_XMLport] = ACTIONS(3639),
    [anon_sym_XMLPort] = ACTIONS(3639),
    [anon_sym_XmlPort] = ACTIONS(3639),
    [anon_sym_enum] = ACTIONS(3639),
    [anon_sym_ENUM] = ACTIONS(3639),
    [anon_sym_Enum] = ACTIONS(3639),
    [anon_sym_eNUM] = ACTIONS(3639),
    [anon_sym_eNum] = ACTIONS(3639),
    [anon_sym_ENum] = ACTIONS(3639),
    [sym_quoted_identifier] = ACTIONS(3641),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3641),
    [sym_verbatim_string] = ACTIONS(3641),
    [sym_integer] = ACTIONS(3639),
    [sym_continue_as_identifier] = ACTIONS(3641),
    [sym_preproc_open] = ACTIONS(3641),
    [sym_end_keyword] = ACTIONS(3641),
  },
  [STATE(1960)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1961)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1962)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1963)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1964)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3647),
    [anon_sym_SEMI] = ACTIONS(3649),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3649),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3647),
    [aux_sym_boolean_token2] = ACTIONS(3647),
    [sym_decimal] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3649),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3647),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3647),
    [aux_sym_basic_type_token21] = ACTIONS(3647),
    [aux_sym_basic_type_token22] = ACTIONS(3647),
    [aux_sym_basic_type_token48] = ACTIONS(3647),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3647),
    [anon_sym_POUNDif] = ACTIONS(3649),
    [anon_sym_POUNDIF] = ACTIONS(3649),
    [anon_sym_POUNDIf] = ACTIONS(3649),
    [anon_sym_not] = ACTIONS(3647),
    [anon_sym_NOT] = ACTIONS(3647),
    [anon_sym_Not] = ACTIONS(3647),
    [anon_sym_POUNDelse] = ACTIONS(3649),
    [anon_sym_POUNDELSE] = ACTIONS(3649),
    [anon_sym_POUNDElse] = ACTIONS(3649),
    [anon_sym_POUNDelse2] = ACTIONS(3649),
    [anon_sym_POUNDELSE2] = ACTIONS(3649),
    [anon_sym_POUNDElse2] = ACTIONS(3649),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3649),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3647),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3647),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3649),
    [anon_sym_LT_EQ] = ACTIONS(3649),
    [anon_sym_GT] = ACTIONS(3647),
    [anon_sym_LT] = ACTIONS(3647),
    [anon_sym_LT_GT] = ACTIONS(3649),
    [anon_sym_and] = ACTIONS(3647),
    [anon_sym_AND] = ACTIONS(3647),
    [anon_sym_And] = ACTIONS(3647),
    [anon_sym_or] = ACTIONS(3647),
    [anon_sym_OR] = ACTIONS(3647),
    [anon_sym_Or] = ACTIONS(3647),
    [anon_sym_xor] = ACTIONS(3647),
    [anon_sym_XOR] = ACTIONS(3647),
    [anon_sym_Xor] = ACTIONS(3647),
    [anon_sym_QMARK] = ACTIONS(3649),
    [sym_datetime_literal] = ACTIONS(3649),
    [sym_date_literal] = ACTIONS(3647),
    [sym_time_literal] = ACTIONS(3647),
    [sym_biginteger_literal] = ACTIONS(3649),
    [anon_sym_if] = ACTIONS(3647),
    [anon_sym_IF] = ACTIONS(3647),
    [anon_sym_If] = ACTIONS(3647),
    [anon_sym_else] = ACTIONS(3647),
    [anon_sym_ELSE] = ACTIONS(3647),
    [anon_sym_Else] = ACTIONS(3647),
    [anon_sym_case] = ACTIONS(3647),
    [anon_sym_CASE] = ACTIONS(3647),
    [anon_sym_Case] = ACTIONS(3647),
    [anon_sym_for] = ACTIONS(3647),
    [anon_sym_FOR] = ACTIONS(3647),
    [anon_sym_For] = ACTIONS(3647),
    [anon_sym_foreach] = ACTIONS(3647),
    [anon_sym_FOREACH] = ACTIONS(3647),
    [anon_sym_Foreach] = ACTIONS(3647),
    [anon_sym_while] = ACTIONS(3647),
    [anon_sym_WHILE] = ACTIONS(3647),
    [anon_sym_While] = ACTIONS(3647),
    [anon_sym_repeat] = ACTIONS(3647),
    [anon_sym_REPEAT] = ACTIONS(3647),
    [anon_sym_Repeat] = ACTIONS(3647),
    [anon_sym_exit] = ACTIONS(3647),
    [anon_sym_EXIT] = ACTIONS(3647),
    [anon_sym_Exit] = ACTIONS(3647),
    [anon_sym_continue] = ACTIONS(3647),
    [anon_sym_CONTINUE] = ACTIONS(3647),
    [anon_sym_Continue] = ACTIONS(3647),
    [anon_sym_break] = ACTIONS(3647),
    [anon_sym_BREAK] = ACTIONS(3647),
    [anon_sym_Break] = ACTIONS(3647),
    [anon_sym_with] = ACTIONS(3647),
    [anon_sym_WITH] = ACTIONS(3647),
    [anon_sym_With] = ACTIONS(3647),
    [sym_asserterror_keyword] = ACTIONS(3649),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3647),
    [anon_sym_codeunit] = ACTIONS(3647),
    [anon_sym_CODEUNIT] = ACTIONS(3647),
    [anon_sym_Codeunit] = ACTIONS(3647),
    [anon_sym_CodeUnit] = ACTIONS(3647),
    [anon_sym_COdeunit] = ACTIONS(3647),
    [anon_sym_codeUnit] = ACTIONS(3647),
    [sym_report_keyword] = ACTIONS(3647),
    [sym_query_keyword] = ACTIONS(3647),
    [anon_sym_xmlport] = ACTIONS(3647),
    [anon_sym_XMLPORT] = ACTIONS(3647),
    [anon_sym_Xmlport] = ACTIONS(3647),
    [anon_sym_XMLport] = ACTIONS(3647),
    [anon_sym_XMLPort] = ACTIONS(3647),
    [anon_sym_XmlPort] = ACTIONS(3647),
    [anon_sym_enum] = ACTIONS(3647),
    [anon_sym_ENUM] = ACTIONS(3647),
    [anon_sym_Enum] = ACTIONS(3647),
    [anon_sym_eNUM] = ACTIONS(3647),
    [anon_sym_eNum] = ACTIONS(3647),
    [anon_sym_ENum] = ACTIONS(3647),
    [sym_quoted_identifier] = ACTIONS(3649),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3649),
    [sym_verbatim_string] = ACTIONS(3649),
    [sym_integer] = ACTIONS(3647),
    [sym_continue_as_identifier] = ACTIONS(3649),
    [sym_preproc_open] = ACTIONS(3649),
    [sym_end_keyword] = ACTIONS(3649),
  },
  [STATE(1965)] = {
    [sym_boolean] = STATE(1806),
    [sym_code_block] = STATE(2488),
    [sym_assignment_expression] = STATE(1806),
    [sym__expression] = STATE(1806),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1806),
    [sym_multiplicative_expression] = STATE(1806),
    [sym_additive_expression] = STATE(1806),
    [sym_comparison_expression] = STATE(1806),
    [sym_logical_expression] = STATE(1806),
    [sym_ternary_expression] = STATE(1806),
    [sym_unary_expression] = STATE(1806),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1806),
    [sym_list_literal] = STATE(1806),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1806),
    [sym__literal_value] = STATE(1806),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(4320),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4322),
    [anon_sym_POUNDif] = ACTIONS(4318),
    [anon_sym_POUNDIF] = ACTIONS(4318),
    [anon_sym_POUNDIf] = ACTIONS(4318),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [anon_sym_POUNDelif] = ACTIONS(4318),
    [anon_sym_POUNDELIF] = ACTIONS(4318),
    [anon_sym_POUNDElif] = ACTIONS(4318),
    [anon_sym_POUNDelse] = ACTIONS(4318),
    [anon_sym_POUNDELSE] = ACTIONS(4318),
    [anon_sym_POUNDElse] = ACTIONS(4318),
    [anon_sym_POUNDelse2] = ACTIONS(4318),
    [anon_sym_POUNDELSE2] = ACTIONS(4318),
    [anon_sym_POUNDElse2] = ACTIONS(4318),
    [anon_sym_POUNDendif] = ACTIONS(4318),
    [anon_sym_POUNDENDIF] = ACTIONS(4318),
    [anon_sym_POUNDEndif] = ACTIONS(4318),
    [anon_sym_POUNDendif2] = ACTIONS(4318),
    [anon_sym_POUNDENDIF2] = ACTIONS(4318),
    [anon_sym_POUNDEndif2] = ACTIONS(4318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(4324),
    [sym_date_literal] = ACTIONS(4320),
    [sym_time_literal] = ACTIONS(4320),
    [sym_biginteger_literal] = ACTIONS(4324),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_IF] = ACTIONS(4322),
    [anon_sym_If] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_ELSE] = ACTIONS(4322),
    [anon_sym_Else] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_CASE] = ACTIONS(4322),
    [anon_sym_Case] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_FOR] = ACTIONS(4322),
    [anon_sym_For] = ACTIONS(4322),
    [anon_sym_foreach] = ACTIONS(4322),
    [anon_sym_FOREACH] = ACTIONS(4322),
    [anon_sym_Foreach] = ACTIONS(4322),
    [anon_sym_while] = ACTIONS(4322),
    [anon_sym_WHILE] = ACTIONS(4322),
    [anon_sym_While] = ACTIONS(4322),
    [anon_sym_repeat] = ACTIONS(4322),
    [anon_sym_REPEAT] = ACTIONS(4322),
    [anon_sym_Repeat] = ACTIONS(4322),
    [anon_sym_exit] = ACTIONS(4322),
    [anon_sym_EXIT] = ACTIONS(4322),
    [anon_sym_Exit] = ACTIONS(4322),
    [anon_sym_continue] = ACTIONS(4322),
    [anon_sym_CONTINUE] = ACTIONS(4322),
    [anon_sym_Continue] = ACTIONS(4322),
    [anon_sym_break] = ACTIONS(4322),
    [anon_sym_BREAK] = ACTIONS(4322),
    [anon_sym_Break] = ACTIONS(4322),
    [anon_sym_with] = ACTIONS(4322),
    [anon_sym_WITH] = ACTIONS(4322),
    [anon_sym_With] = ACTIONS(4322),
    [sym_asserterror_keyword] = ACTIONS(4318),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4324),
    [sym_verbatim_string] = ACTIONS(4324),
    [sym_integer] = ACTIONS(4320),
    [sym_continue_as_identifier] = ACTIONS(4324),
    [sym_preproc_open] = ACTIONS(4318),
    [sym_preproc_close] = ACTIONS(4318),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(1966)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3740),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1967)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3710),
    [anon_sym_SEMI] = ACTIONS(3712),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3710),
    [aux_sym_boolean_token2] = ACTIONS(3710),
    [sym_decimal] = ACTIONS(3710),
    [anon_sym_LPAREN] = ACTIONS(3712),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3710),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3710),
    [aux_sym_basic_type_token21] = ACTIONS(3710),
    [aux_sym_basic_type_token22] = ACTIONS(3710),
    [aux_sym_basic_type_token48] = ACTIONS(3710),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3710),
    [anon_sym_POUNDif] = ACTIONS(3712),
    [anon_sym_POUNDIF] = ACTIONS(3712),
    [anon_sym_POUNDIf] = ACTIONS(3712),
    [anon_sym_not] = ACTIONS(3710),
    [anon_sym_NOT] = ACTIONS(3710),
    [anon_sym_Not] = ACTIONS(3710),
    [anon_sym_POUNDelse] = ACTIONS(3712),
    [anon_sym_POUNDELSE] = ACTIONS(3712),
    [anon_sym_POUNDElse] = ACTIONS(3712),
    [anon_sym_POUNDelse2] = ACTIONS(3712),
    [anon_sym_POUNDELSE2] = ACTIONS(3712),
    [anon_sym_POUNDElse2] = ACTIONS(3712),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4326),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3710),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3710),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_OR] = ACTIONS(4330),
    [anon_sym_Or] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_XOR] = ACTIONS(4336),
    [anon_sym_Xor] = ACTIONS(4338),
    [anon_sym_QMARK] = ACTIONS(4340),
    [sym_datetime_literal] = ACTIONS(3712),
    [sym_date_literal] = ACTIONS(3710),
    [sym_time_literal] = ACTIONS(3710),
    [sym_biginteger_literal] = ACTIONS(3712),
    [anon_sym_if] = ACTIONS(3710),
    [anon_sym_IF] = ACTIONS(3710),
    [anon_sym_If] = ACTIONS(3710),
    [anon_sym_else] = ACTIONS(3710),
    [anon_sym_ELSE] = ACTIONS(3710),
    [anon_sym_Else] = ACTIONS(3710),
    [anon_sym_case] = ACTIONS(3710),
    [anon_sym_CASE] = ACTIONS(3710),
    [anon_sym_Case] = ACTIONS(3710),
    [anon_sym_for] = ACTIONS(3710),
    [anon_sym_FOR] = ACTIONS(3710),
    [anon_sym_For] = ACTIONS(3710),
    [anon_sym_foreach] = ACTIONS(3710),
    [anon_sym_FOREACH] = ACTIONS(3710),
    [anon_sym_Foreach] = ACTIONS(3710),
    [anon_sym_while] = ACTIONS(3710),
    [anon_sym_WHILE] = ACTIONS(3710),
    [anon_sym_While] = ACTIONS(3710),
    [anon_sym_repeat] = ACTIONS(3710),
    [anon_sym_REPEAT] = ACTIONS(3710),
    [anon_sym_Repeat] = ACTIONS(3710),
    [anon_sym_exit] = ACTIONS(3710),
    [anon_sym_EXIT] = ACTIONS(3710),
    [anon_sym_Exit] = ACTIONS(3710),
    [anon_sym_continue] = ACTIONS(3710),
    [anon_sym_CONTINUE] = ACTIONS(3710),
    [anon_sym_Continue] = ACTIONS(3710),
    [anon_sym_break] = ACTIONS(3710),
    [anon_sym_BREAK] = ACTIONS(3710),
    [anon_sym_Break] = ACTIONS(3710),
    [anon_sym_with] = ACTIONS(3710),
    [anon_sym_WITH] = ACTIONS(3710),
    [anon_sym_With] = ACTIONS(3710),
    [sym_asserterror_keyword] = ACTIONS(3712),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3710),
    [anon_sym_codeunit] = ACTIONS(3710),
    [anon_sym_CODEUNIT] = ACTIONS(3710),
    [anon_sym_Codeunit] = ACTIONS(3710),
    [anon_sym_CodeUnit] = ACTIONS(3710),
    [anon_sym_COdeunit] = ACTIONS(3710),
    [anon_sym_codeUnit] = ACTIONS(3710),
    [sym_report_keyword] = ACTIONS(3710),
    [sym_query_keyword] = ACTIONS(3710),
    [anon_sym_xmlport] = ACTIONS(3710),
    [anon_sym_XMLPORT] = ACTIONS(3710),
    [anon_sym_Xmlport] = ACTIONS(3710),
    [anon_sym_XMLport] = ACTIONS(3710),
    [anon_sym_XMLPort] = ACTIONS(3710),
    [anon_sym_XmlPort] = ACTIONS(3710),
    [anon_sym_enum] = ACTIONS(3710),
    [anon_sym_ENUM] = ACTIONS(3710),
    [anon_sym_Enum] = ACTIONS(3710),
    [anon_sym_eNUM] = ACTIONS(3710),
    [anon_sym_eNum] = ACTIONS(3710),
    [anon_sym_ENum] = ACTIONS(3710),
    [sym_quoted_identifier] = ACTIONS(3712),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3712),
    [sym_verbatim_string] = ACTIONS(3712),
    [sym_integer] = ACTIONS(3710),
    [sym_continue_as_identifier] = ACTIONS(3712),
    [sym_preproc_open] = ACTIONS(3712),
    [sym_end_keyword] = ACTIONS(3712),
  },
  [STATE(1968)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3673),
    [anon_sym_SEMI] = ACTIONS(3675),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3673),
    [aux_sym_boolean_token2] = ACTIONS(3673),
    [sym_decimal] = ACTIONS(3673),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3673),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3673),
    [aux_sym_basic_type_token21] = ACTIONS(3673),
    [aux_sym_basic_type_token22] = ACTIONS(3673),
    [aux_sym_basic_type_token48] = ACTIONS(3673),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3673),
    [anon_sym_POUNDif] = ACTIONS(3675),
    [anon_sym_POUNDIF] = ACTIONS(3675),
    [anon_sym_POUNDIf] = ACTIONS(3675),
    [anon_sym_not] = ACTIONS(3673),
    [anon_sym_NOT] = ACTIONS(3673),
    [anon_sym_Not] = ACTIONS(3673),
    [anon_sym_POUNDelse] = ACTIONS(3675),
    [anon_sym_POUNDELSE] = ACTIONS(3675),
    [anon_sym_POUNDElse] = ACTIONS(3675),
    [anon_sym_POUNDelse2] = ACTIONS(3675),
    [anon_sym_POUNDELSE2] = ACTIONS(3675),
    [anon_sym_POUNDElse2] = ACTIONS(3675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3675),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3673),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_OR] = ACTIONS(4330),
    [anon_sym_Or] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_XOR] = ACTIONS(4336),
    [anon_sym_Xor] = ACTIONS(4338),
    [anon_sym_QMARK] = ACTIONS(4340),
    [sym_datetime_literal] = ACTIONS(3675),
    [sym_date_literal] = ACTIONS(3673),
    [sym_time_literal] = ACTIONS(3673),
    [sym_biginteger_literal] = ACTIONS(3675),
    [anon_sym_if] = ACTIONS(3673),
    [anon_sym_IF] = ACTIONS(3673),
    [anon_sym_If] = ACTIONS(3673),
    [anon_sym_else] = ACTIONS(3673),
    [anon_sym_ELSE] = ACTIONS(3673),
    [anon_sym_Else] = ACTIONS(3673),
    [anon_sym_case] = ACTIONS(3673),
    [anon_sym_CASE] = ACTIONS(3673),
    [anon_sym_Case] = ACTIONS(3673),
    [anon_sym_for] = ACTIONS(3673),
    [anon_sym_FOR] = ACTIONS(3673),
    [anon_sym_For] = ACTIONS(3673),
    [anon_sym_foreach] = ACTIONS(3673),
    [anon_sym_FOREACH] = ACTIONS(3673),
    [anon_sym_Foreach] = ACTIONS(3673),
    [anon_sym_while] = ACTIONS(3673),
    [anon_sym_WHILE] = ACTIONS(3673),
    [anon_sym_While] = ACTIONS(3673),
    [anon_sym_repeat] = ACTIONS(3673),
    [anon_sym_REPEAT] = ACTIONS(3673),
    [anon_sym_Repeat] = ACTIONS(3673),
    [anon_sym_exit] = ACTIONS(3673),
    [anon_sym_EXIT] = ACTIONS(3673),
    [anon_sym_Exit] = ACTIONS(3673),
    [anon_sym_continue] = ACTIONS(3673),
    [anon_sym_CONTINUE] = ACTIONS(3673),
    [anon_sym_Continue] = ACTIONS(3673),
    [anon_sym_break] = ACTIONS(3673),
    [anon_sym_BREAK] = ACTIONS(3673),
    [anon_sym_Break] = ACTIONS(3673),
    [anon_sym_with] = ACTIONS(3673),
    [anon_sym_WITH] = ACTIONS(3673),
    [anon_sym_With] = ACTIONS(3673),
    [sym_asserterror_keyword] = ACTIONS(3675),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3673),
    [anon_sym_codeunit] = ACTIONS(3673),
    [anon_sym_CODEUNIT] = ACTIONS(3673),
    [anon_sym_Codeunit] = ACTIONS(3673),
    [anon_sym_CodeUnit] = ACTIONS(3673),
    [anon_sym_COdeunit] = ACTIONS(3673),
    [anon_sym_codeUnit] = ACTIONS(3673),
    [sym_report_keyword] = ACTIONS(3673),
    [sym_query_keyword] = ACTIONS(3673),
    [anon_sym_xmlport] = ACTIONS(3673),
    [anon_sym_XMLPORT] = ACTIONS(3673),
    [anon_sym_Xmlport] = ACTIONS(3673),
    [anon_sym_XMLport] = ACTIONS(3673),
    [anon_sym_XMLPort] = ACTIONS(3673),
    [anon_sym_XmlPort] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_ENUM] = ACTIONS(3673),
    [anon_sym_Enum] = ACTIONS(3673),
    [anon_sym_eNUM] = ACTIONS(3673),
    [anon_sym_eNum] = ACTIONS(3673),
    [anon_sym_ENum] = ACTIONS(3673),
    [sym_quoted_identifier] = ACTIONS(3675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3675),
    [sym_verbatim_string] = ACTIONS(3675),
    [sym_integer] = ACTIONS(3673),
    [sym_continue_as_identifier] = ACTIONS(3675),
    [sym_preproc_open] = ACTIONS(3675),
    [sym_end_keyword] = ACTIONS(3675),
  },
  [STATE(1969)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_if] = ACTIONS(3677),
    [anon_sym_IF] = ACTIONS(3677),
    [anon_sym_If] = ACTIONS(3677),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_case] = ACTIONS(3677),
    [anon_sym_CASE] = ACTIONS(3677),
    [anon_sym_Case] = ACTIONS(3677),
    [anon_sym_for] = ACTIONS(3677),
    [anon_sym_FOR] = ACTIONS(3677),
    [anon_sym_For] = ACTIONS(3677),
    [anon_sym_foreach] = ACTIONS(3677),
    [anon_sym_FOREACH] = ACTIONS(3677),
    [anon_sym_Foreach] = ACTIONS(3677),
    [anon_sym_while] = ACTIONS(3677),
    [anon_sym_WHILE] = ACTIONS(3677),
    [anon_sym_While] = ACTIONS(3677),
    [anon_sym_repeat] = ACTIONS(3677),
    [anon_sym_REPEAT] = ACTIONS(3677),
    [anon_sym_Repeat] = ACTIONS(3677),
    [anon_sym_exit] = ACTIONS(3677),
    [anon_sym_EXIT] = ACTIONS(3677),
    [anon_sym_Exit] = ACTIONS(3677),
    [anon_sym_continue] = ACTIONS(3677),
    [anon_sym_CONTINUE] = ACTIONS(3677),
    [anon_sym_Continue] = ACTIONS(3677),
    [anon_sym_break] = ACTIONS(3677),
    [anon_sym_BREAK] = ACTIONS(3677),
    [anon_sym_Break] = ACTIONS(3677),
    [anon_sym_with] = ACTIONS(3677),
    [anon_sym_WITH] = ACTIONS(3677),
    [anon_sym_With] = ACTIONS(3677),
    [sym_asserterror_keyword] = ACTIONS(3679),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
    [sym_end_keyword] = ACTIONS(3679),
  },
  [STATE(1970)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2775),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1971)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_end_keyword] = ACTIONS(3568),
  },
  [STATE(1972)] = {
    [sym_preproc_conditional_object] = STATE(1976),
    [sym_using_statement] = STATE(1976),
    [sym__object] = STATE(1976),
    [sym_preproc_split_declaration] = STATE(1976),
    [sym_table_declaration] = STATE(1976),
    [sym_page_declaration] = STATE(1976),
    [sym_report_declaration] = STATE(1976),
    [sym_query_declaration] = STATE(1976),
    [sym_xmlport_declaration] = STATE(1976),
    [sym_permissionset_declaration] = STATE(1976),
    [sym_codeunit_declaration] = STATE(1976),
    [sym_enum_declaration] = STATE(1976),
    [sym_tableextension_declaration] = STATE(1976),
    [sym_pageextension_declaration] = STATE(1976),
    [sym_reportextension_declaration] = STATE(1976),
    [sym_enumextension_declaration] = STATE(1976),
    [sym_permissionsetextension_declaration] = STATE(1976),
    [sym_controladdin_declaration] = STATE(1976),
    [sym_profile_declaration] = STATE(1976),
    [sym_entitlement_declaration] = STATE(1976),
    [sym_profileextension_declaration] = STATE(1976),
    [sym_interface_declaration] = STATE(1976),
    [sym_pagecustomization_declaration] = STATE(1976),
    [sym_dotnet_declaration] = STATE(1976),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3687),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1976),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1973)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2802),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1974)] = {
    [sym_preproc_conditional_object] = STATE(1966),
    [sym_using_statement] = STATE(1966),
    [sym__object] = STATE(1966),
    [sym_preproc_split_declaration] = STATE(1966),
    [sym_table_declaration] = STATE(1966),
    [sym_page_declaration] = STATE(1966),
    [sym_report_declaration] = STATE(1966),
    [sym_query_declaration] = STATE(1966),
    [sym_xmlport_declaration] = STATE(1966),
    [sym_permissionset_declaration] = STATE(1966),
    [sym_codeunit_declaration] = STATE(1966),
    [sym_enum_declaration] = STATE(1966),
    [sym_tableextension_declaration] = STATE(1966),
    [sym_pageextension_declaration] = STATE(1966),
    [sym_reportextension_declaration] = STATE(1966),
    [sym_enumextension_declaration] = STATE(1966),
    [sym_permissionsetextension_declaration] = STATE(1966),
    [sym_controladdin_declaration] = STATE(1966),
    [sym_profile_declaration] = STATE(1966),
    [sym_entitlement_declaration] = STATE(1966),
    [sym_profileextension_declaration] = STATE(1966),
    [sym_interface_declaration] = STATE(1966),
    [sym_pagecustomization_declaration] = STATE(1966),
    [sym_dotnet_declaration] = STATE(1966),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3717),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1966),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1975)] = {
    [sym_preproc_conditional_object] = STATE(1985),
    [sym_using_statement] = STATE(1985),
    [sym__object] = STATE(1985),
    [sym_preproc_split_declaration] = STATE(1985),
    [sym_table_declaration] = STATE(1985),
    [sym_page_declaration] = STATE(1985),
    [sym_report_declaration] = STATE(1985),
    [sym_query_declaration] = STATE(1985),
    [sym_xmlport_declaration] = STATE(1985),
    [sym_permissionset_declaration] = STATE(1985),
    [sym_codeunit_declaration] = STATE(1985),
    [sym_enum_declaration] = STATE(1985),
    [sym_tableextension_declaration] = STATE(1985),
    [sym_pageextension_declaration] = STATE(1985),
    [sym_reportextension_declaration] = STATE(1985),
    [sym_enumextension_declaration] = STATE(1985),
    [sym_permissionsetextension_declaration] = STATE(1985),
    [sym_controladdin_declaration] = STATE(1985),
    [sym_profile_declaration] = STATE(1985),
    [sym_entitlement_declaration] = STATE(1985),
    [sym_profileextension_declaration] = STATE(1985),
    [sym_interface_declaration] = STATE(1985),
    [sym_pagecustomization_declaration] = STATE(1985),
    [sym_dotnet_declaration] = STATE(1985),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2802),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1985),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1976)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3717),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1977)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3576),
    [anon_sym_SEMI] = ACTIONS(3578),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3576),
    [aux_sym_boolean_token2] = ACTIONS(3576),
    [sym_decimal] = ACTIONS(3576),
    [anon_sym_LPAREN] = ACTIONS(3578),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3576),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3576),
    [aux_sym_basic_type_token21] = ACTIONS(3576),
    [aux_sym_basic_type_token22] = ACTIONS(3576),
    [aux_sym_basic_type_token48] = ACTIONS(3576),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3576),
    [anon_sym_POUNDif] = ACTIONS(3578),
    [anon_sym_POUNDIF] = ACTIONS(3578),
    [anon_sym_POUNDIf] = ACTIONS(3578),
    [anon_sym_not] = ACTIONS(3576),
    [anon_sym_NOT] = ACTIONS(3576),
    [anon_sym_Not] = ACTIONS(3576),
    [anon_sym_POUNDelse] = ACTIONS(3578),
    [anon_sym_POUNDELSE] = ACTIONS(3578),
    [anon_sym_POUNDElse] = ACTIONS(3578),
    [anon_sym_POUNDelse2] = ACTIONS(3578),
    [anon_sym_POUNDELSE2] = ACTIONS(3578),
    [anon_sym_POUNDElse2] = ACTIONS(3578),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4342),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3576),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3576),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_OR] = ACTIONS(4330),
    [anon_sym_Or] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_XOR] = ACTIONS(4336),
    [anon_sym_Xor] = ACTIONS(4338),
    [anon_sym_QMARK] = ACTIONS(4340),
    [sym_datetime_literal] = ACTIONS(3578),
    [sym_date_literal] = ACTIONS(3576),
    [sym_time_literal] = ACTIONS(3576),
    [sym_biginteger_literal] = ACTIONS(3578),
    [anon_sym_if] = ACTIONS(3576),
    [anon_sym_IF] = ACTIONS(3576),
    [anon_sym_If] = ACTIONS(3576),
    [anon_sym_else] = ACTIONS(3576),
    [anon_sym_ELSE] = ACTIONS(3576),
    [anon_sym_Else] = ACTIONS(3576),
    [anon_sym_case] = ACTIONS(3576),
    [anon_sym_CASE] = ACTIONS(3576),
    [anon_sym_Case] = ACTIONS(3576),
    [anon_sym_for] = ACTIONS(3576),
    [anon_sym_FOR] = ACTIONS(3576),
    [anon_sym_For] = ACTIONS(3576),
    [anon_sym_foreach] = ACTIONS(3576),
    [anon_sym_FOREACH] = ACTIONS(3576),
    [anon_sym_Foreach] = ACTIONS(3576),
    [anon_sym_while] = ACTIONS(3576),
    [anon_sym_WHILE] = ACTIONS(3576),
    [anon_sym_While] = ACTIONS(3576),
    [anon_sym_repeat] = ACTIONS(3576),
    [anon_sym_REPEAT] = ACTIONS(3576),
    [anon_sym_Repeat] = ACTIONS(3576),
    [anon_sym_exit] = ACTIONS(3576),
    [anon_sym_EXIT] = ACTIONS(3576),
    [anon_sym_Exit] = ACTIONS(3576),
    [anon_sym_continue] = ACTIONS(3576),
    [anon_sym_CONTINUE] = ACTIONS(3576),
    [anon_sym_Continue] = ACTIONS(3576),
    [anon_sym_break] = ACTIONS(3576),
    [anon_sym_BREAK] = ACTIONS(3576),
    [anon_sym_Break] = ACTIONS(3576),
    [anon_sym_with] = ACTIONS(3576),
    [anon_sym_WITH] = ACTIONS(3576),
    [anon_sym_With] = ACTIONS(3576),
    [sym_asserterror_keyword] = ACTIONS(3578),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3576),
    [anon_sym_codeunit] = ACTIONS(3576),
    [anon_sym_CODEUNIT] = ACTIONS(3576),
    [anon_sym_Codeunit] = ACTIONS(3576),
    [anon_sym_CodeUnit] = ACTIONS(3576),
    [anon_sym_COdeunit] = ACTIONS(3576),
    [anon_sym_codeUnit] = ACTIONS(3576),
    [sym_report_keyword] = ACTIONS(3576),
    [sym_query_keyword] = ACTIONS(3576),
    [anon_sym_xmlport] = ACTIONS(3576),
    [anon_sym_XMLPORT] = ACTIONS(3576),
    [anon_sym_Xmlport] = ACTIONS(3576),
    [anon_sym_XMLport] = ACTIONS(3576),
    [anon_sym_XMLPort] = ACTIONS(3576),
    [anon_sym_XmlPort] = ACTIONS(3576),
    [anon_sym_enum] = ACTIONS(3576),
    [anon_sym_ENUM] = ACTIONS(3576),
    [anon_sym_Enum] = ACTIONS(3576),
    [anon_sym_eNUM] = ACTIONS(3576),
    [anon_sym_eNum] = ACTIONS(3576),
    [anon_sym_ENum] = ACTIONS(3576),
    [sym_quoted_identifier] = ACTIONS(3578),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3578),
    [sym_verbatim_string] = ACTIONS(3578),
    [sym_integer] = ACTIONS(3576),
    [sym_continue_as_identifier] = ACTIONS(3578),
    [sym_preproc_open] = ACTIONS(3578),
    [sym_end_keyword] = ACTIONS(3578),
  },
  [STATE(1978)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_end_keyword] = ACTIONS(3665),
  },
  [STATE(1979)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3716),
    [anon_sym_SEMI] = ACTIONS(3718),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3716),
    [aux_sym_boolean_token1] = ACTIONS(3716),
    [aux_sym_boolean_token2] = ACTIONS(3716),
    [sym_decimal] = ACTIONS(3716),
    [anon_sym_LPAREN] = ACTIONS(3718),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3716),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(3718),
    [aux_sym_record_type_token1] = ACTIONS(3716),
    [aux_sym_basic_type_token21] = ACTIONS(3716),
    [aux_sym_basic_type_token22] = ACTIONS(3716),
    [aux_sym_basic_type_token48] = ACTIONS(3716),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3716),
    [anon_sym_POUNDif] = ACTIONS(3718),
    [anon_sym_POUNDIF] = ACTIONS(3718),
    [anon_sym_POUNDIf] = ACTIONS(3718),
    [anon_sym_not] = ACTIONS(3716),
    [anon_sym_NOT] = ACTIONS(3716),
    [anon_sym_Not] = ACTIONS(3716),
    [anon_sym_POUNDelse] = ACTIONS(3718),
    [anon_sym_POUNDELSE] = ACTIONS(3718),
    [anon_sym_POUNDElse] = ACTIONS(3718),
    [anon_sym_POUNDelse2] = ACTIONS(3718),
    [anon_sym_POUNDELSE2] = ACTIONS(3718),
    [anon_sym_POUNDElse2] = ACTIONS(3718),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4342),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3716),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3716),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(3716),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_OR] = ACTIONS(4330),
    [anon_sym_Or] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_XOR] = ACTIONS(4336),
    [anon_sym_Xor] = ACTIONS(4338),
    [anon_sym_QMARK] = ACTIONS(4340),
    [sym_datetime_literal] = ACTIONS(3718),
    [sym_date_literal] = ACTIONS(3716),
    [sym_time_literal] = ACTIONS(3716),
    [sym_biginteger_literal] = ACTIONS(3718),
    [anon_sym_if] = ACTIONS(3716),
    [anon_sym_IF] = ACTIONS(3716),
    [anon_sym_If] = ACTIONS(3716),
    [anon_sym_else] = ACTIONS(3716),
    [anon_sym_ELSE] = ACTIONS(3716),
    [anon_sym_Else] = ACTIONS(3716),
    [anon_sym_case] = ACTIONS(3716),
    [anon_sym_CASE] = ACTIONS(3716),
    [anon_sym_Case] = ACTIONS(3716),
    [anon_sym_for] = ACTIONS(3716),
    [anon_sym_FOR] = ACTIONS(3716),
    [anon_sym_For] = ACTIONS(3716),
    [anon_sym_foreach] = ACTIONS(3716),
    [anon_sym_FOREACH] = ACTIONS(3716),
    [anon_sym_Foreach] = ACTIONS(3716),
    [anon_sym_while] = ACTIONS(3716),
    [anon_sym_WHILE] = ACTIONS(3716),
    [anon_sym_While] = ACTIONS(3716),
    [anon_sym_repeat] = ACTIONS(3716),
    [anon_sym_REPEAT] = ACTIONS(3716),
    [anon_sym_Repeat] = ACTIONS(3716),
    [anon_sym_exit] = ACTIONS(3716),
    [anon_sym_EXIT] = ACTIONS(3716),
    [anon_sym_Exit] = ACTIONS(3716),
    [anon_sym_continue] = ACTIONS(3716),
    [anon_sym_CONTINUE] = ACTIONS(3716),
    [anon_sym_Continue] = ACTIONS(3716),
    [anon_sym_break] = ACTIONS(3716),
    [anon_sym_BREAK] = ACTIONS(3716),
    [anon_sym_Break] = ACTIONS(3716),
    [anon_sym_with] = ACTIONS(3716),
    [anon_sym_WITH] = ACTIONS(3716),
    [anon_sym_With] = ACTIONS(3716),
    [sym_asserterror_keyword] = ACTIONS(3718),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3716),
    [anon_sym_codeunit] = ACTIONS(3716),
    [anon_sym_CODEUNIT] = ACTIONS(3716),
    [anon_sym_Codeunit] = ACTIONS(3716),
    [anon_sym_CodeUnit] = ACTIONS(3716),
    [anon_sym_COdeunit] = ACTIONS(3716),
    [anon_sym_codeUnit] = ACTIONS(3716),
    [sym_report_keyword] = ACTIONS(3716),
    [sym_query_keyword] = ACTIONS(3716),
    [anon_sym_xmlport] = ACTIONS(3716),
    [anon_sym_XMLPORT] = ACTIONS(3716),
    [anon_sym_Xmlport] = ACTIONS(3716),
    [anon_sym_XMLport] = ACTIONS(3716),
    [anon_sym_XMLPort] = ACTIONS(3716),
    [anon_sym_XmlPort] = ACTIONS(3716),
    [anon_sym_enum] = ACTIONS(3716),
    [anon_sym_ENUM] = ACTIONS(3716),
    [anon_sym_Enum] = ACTIONS(3716),
    [anon_sym_eNUM] = ACTIONS(3716),
    [anon_sym_eNum] = ACTIONS(3716),
    [anon_sym_ENum] = ACTIONS(3716),
    [sym_quoted_identifier] = ACTIONS(3718),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3718),
    [sym_verbatim_string] = ACTIONS(3718),
    [sym_integer] = ACTIONS(3716),
    [sym_continue_as_identifier] = ACTIONS(3718),
    [sym_preproc_open] = ACTIONS(3718),
    [sym_end_keyword] = ACTIONS(3718),
  },
  [STATE(1980)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3720),
    [anon_sym_SEMI] = ACTIONS(3723),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3720),
    [aux_sym_boolean_token2] = ACTIONS(3720),
    [sym_decimal] = ACTIONS(3720),
    [anon_sym_LPAREN] = ACTIONS(3723),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3720),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3720),
    [aux_sym_basic_type_token21] = ACTIONS(3720),
    [aux_sym_basic_type_token22] = ACTIONS(3720),
    [aux_sym_basic_type_token48] = ACTIONS(3720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3720),
    [anon_sym_POUNDif] = ACTIONS(3723),
    [anon_sym_POUNDIF] = ACTIONS(3723),
    [anon_sym_POUNDIf] = ACTIONS(3723),
    [anon_sym_not] = ACTIONS(3720),
    [anon_sym_NOT] = ACTIONS(3720),
    [anon_sym_Not] = ACTIONS(3720),
    [anon_sym_POUNDelse] = ACTIONS(3723),
    [anon_sym_POUNDELSE] = ACTIONS(3723),
    [anon_sym_POUNDElse] = ACTIONS(3723),
    [anon_sym_POUNDelse2] = ACTIONS(3723),
    [anon_sym_POUNDELSE2] = ACTIONS(3723),
    [anon_sym_POUNDElse2] = ACTIONS(3723),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4342),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3720),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_OR] = ACTIONS(4330),
    [anon_sym_Or] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_XOR] = ACTIONS(4336),
    [anon_sym_Xor] = ACTIONS(4338),
    [anon_sym_QMARK] = ACTIONS(4340),
    [sym_datetime_literal] = ACTIONS(3723),
    [sym_date_literal] = ACTIONS(3720),
    [sym_time_literal] = ACTIONS(3720),
    [sym_biginteger_literal] = ACTIONS(3723),
    [anon_sym_if] = ACTIONS(3720),
    [anon_sym_IF] = ACTIONS(3720),
    [anon_sym_If] = ACTIONS(3720),
    [anon_sym_else] = ACTIONS(3720),
    [anon_sym_ELSE] = ACTIONS(3720),
    [anon_sym_Else] = ACTIONS(3720),
    [anon_sym_case] = ACTIONS(3720),
    [anon_sym_CASE] = ACTIONS(3720),
    [anon_sym_Case] = ACTIONS(3720),
    [anon_sym_for] = ACTIONS(3720),
    [anon_sym_FOR] = ACTIONS(3720),
    [anon_sym_For] = ACTIONS(3720),
    [anon_sym_foreach] = ACTIONS(3720),
    [anon_sym_FOREACH] = ACTIONS(3720),
    [anon_sym_Foreach] = ACTIONS(3720),
    [anon_sym_while] = ACTIONS(3720),
    [anon_sym_WHILE] = ACTIONS(3720),
    [anon_sym_While] = ACTIONS(3720),
    [anon_sym_repeat] = ACTIONS(3720),
    [anon_sym_REPEAT] = ACTIONS(3720),
    [anon_sym_Repeat] = ACTIONS(3720),
    [anon_sym_exit] = ACTIONS(3720),
    [anon_sym_EXIT] = ACTIONS(3720),
    [anon_sym_Exit] = ACTIONS(3720),
    [anon_sym_continue] = ACTIONS(3720),
    [anon_sym_CONTINUE] = ACTIONS(3720),
    [anon_sym_Continue] = ACTIONS(3720),
    [anon_sym_break] = ACTIONS(3720),
    [anon_sym_BREAK] = ACTIONS(3720),
    [anon_sym_Break] = ACTIONS(3720),
    [anon_sym_with] = ACTIONS(3720),
    [anon_sym_WITH] = ACTIONS(3720),
    [anon_sym_With] = ACTIONS(3720),
    [sym_asserterror_keyword] = ACTIONS(3723),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3720),
    [anon_sym_codeunit] = ACTIONS(3720),
    [anon_sym_CODEUNIT] = ACTIONS(3720),
    [anon_sym_Codeunit] = ACTIONS(3720),
    [anon_sym_CodeUnit] = ACTIONS(3720),
    [anon_sym_COdeunit] = ACTIONS(3720),
    [anon_sym_codeUnit] = ACTIONS(3720),
    [sym_report_keyword] = ACTIONS(3720),
    [sym_query_keyword] = ACTIONS(3720),
    [anon_sym_xmlport] = ACTIONS(3720),
    [anon_sym_XMLPORT] = ACTIONS(3720),
    [anon_sym_Xmlport] = ACTIONS(3720),
    [anon_sym_XMLport] = ACTIONS(3720),
    [anon_sym_XMLPort] = ACTIONS(3720),
    [anon_sym_XmlPort] = ACTIONS(3720),
    [anon_sym_enum] = ACTIONS(3720),
    [anon_sym_ENUM] = ACTIONS(3720),
    [anon_sym_Enum] = ACTIONS(3720),
    [anon_sym_eNUM] = ACTIONS(3720),
    [anon_sym_eNum] = ACTIONS(3720),
    [anon_sym_ENum] = ACTIONS(3720),
    [sym_quoted_identifier] = ACTIONS(3723),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3723),
    [sym_verbatim_string] = ACTIONS(3723),
    [sym_integer] = ACTIONS(3720),
    [sym_continue_as_identifier] = ACTIONS(3723),
    [sym_preproc_open] = ACTIONS(3723),
    [sym_end_keyword] = ACTIONS(3723),
  },
  [STATE(1981)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_until] = ACTIONS(3865),
    [anon_sym_UNTIL] = ACTIONS(3865),
    [anon_sym_Until] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
  },
  [STATE(1982)] = {
    [sym_identifier] = ACTIONS(3921),
    [anon_sym_SEMI] = ACTIONS(3923),
    [anon_sym_DOT] = ACTIONS(3921),
    [anon_sym_EQ] = ACTIONS(3923),
    [anon_sym_DASH] = ACTIONS(3921),
    [aux_sym_boolean_token1] = ACTIONS(3921),
    [aux_sym_boolean_token2] = ACTIONS(3921),
    [sym_decimal] = ACTIONS(3921),
    [anon_sym_LPAREN] = ACTIONS(3923),
    [anon_sym_DOT_DOT] = ACTIONS(3923),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3921),
    [anon_sym_STAR] = ACTIONS(3921),
    [anon_sym_LBRACK] = ACTIONS(3923),
    [aux_sym_record_type_token1] = ACTIONS(3921),
    [aux_sym_basic_type_token21] = ACTIONS(3921),
    [aux_sym_basic_type_token22] = ACTIONS(3921),
    [aux_sym_basic_type_token48] = ACTIONS(3921),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3921),
    [anon_sym_POUNDif] = ACTIONS(3923),
    [anon_sym_POUNDIF] = ACTIONS(3923),
    [anon_sym_POUNDIf] = ACTIONS(3923),
    [anon_sym_not] = ACTIONS(3921),
    [anon_sym_NOT] = ACTIONS(3921),
    [anon_sym_Not] = ACTIONS(3921),
    [anon_sym_POUNDelse] = ACTIONS(3923),
    [anon_sym_POUNDELSE] = ACTIONS(3923),
    [anon_sym_POUNDElse] = ACTIONS(3923),
    [anon_sym_POUNDelse2] = ACTIONS(3923),
    [anon_sym_POUNDELSE2] = ACTIONS(3923),
    [anon_sym_POUNDElse2] = ACTIONS(3923),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3923),
    [aux_sym__expression_token1] = ACTIONS(3923),
    [aux_sym__expression_token2] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3921),
    [anon_sym_SLASH] = ACTIONS(3921),
    [anon_sym_div] = ACTIONS(3921),
    [anon_sym_DIV] = ACTIONS(3921),
    [anon_sym_Div] = ACTIONS(3921),
    [anon_sym_mod] = ACTIONS(3921),
    [anon_sym_MOD] = ACTIONS(3921),
    [anon_sym_Mod] = ACTIONS(3921),
    [anon_sym_PLUS] = ACTIONS(3921),
    [anon_sym_GT_EQ] = ACTIONS(3923),
    [anon_sym_LT_EQ] = ACTIONS(3923),
    [anon_sym_GT] = ACTIONS(3921),
    [anon_sym_LT] = ACTIONS(3921),
    [anon_sym_LT_GT] = ACTIONS(3923),
    [anon_sym_and] = ACTIONS(3921),
    [anon_sym_AND] = ACTIONS(3921),
    [anon_sym_And] = ACTIONS(3921),
    [anon_sym_or] = ACTIONS(3921),
    [anon_sym_OR] = ACTIONS(3921),
    [anon_sym_Or] = ACTIONS(3921),
    [anon_sym_xor] = ACTIONS(3921),
    [anon_sym_XOR] = ACTIONS(3921),
    [anon_sym_Xor] = ACTIONS(3921),
    [anon_sym_QMARK] = ACTIONS(3923),
    [sym_datetime_literal] = ACTIONS(3923),
    [sym_date_literal] = ACTIONS(3921),
    [sym_time_literal] = ACTIONS(3921),
    [sym_biginteger_literal] = ACTIONS(3923),
    [anon_sym_if] = ACTIONS(3921),
    [anon_sym_IF] = ACTIONS(3921),
    [anon_sym_If] = ACTIONS(3921),
    [anon_sym_else] = ACTIONS(3921),
    [anon_sym_ELSE] = ACTIONS(3921),
    [anon_sym_Else] = ACTIONS(3921),
    [anon_sym_case] = ACTIONS(3921),
    [anon_sym_CASE] = ACTIONS(3921),
    [anon_sym_Case] = ACTIONS(3921),
    [anon_sym_for] = ACTIONS(3921),
    [anon_sym_FOR] = ACTIONS(3921),
    [anon_sym_For] = ACTIONS(3921),
    [anon_sym_foreach] = ACTIONS(3921),
    [anon_sym_FOREACH] = ACTIONS(3921),
    [anon_sym_Foreach] = ACTIONS(3921),
    [anon_sym_while] = ACTIONS(3921),
    [anon_sym_WHILE] = ACTIONS(3921),
    [anon_sym_While] = ACTIONS(3921),
    [anon_sym_repeat] = ACTIONS(3921),
    [anon_sym_REPEAT] = ACTIONS(3921),
    [anon_sym_Repeat] = ACTIONS(3921),
    [anon_sym_until] = ACTIONS(3921),
    [anon_sym_UNTIL] = ACTIONS(3921),
    [anon_sym_Until] = ACTIONS(3921),
    [anon_sym_exit] = ACTIONS(3921),
    [anon_sym_EXIT] = ACTIONS(3921),
    [anon_sym_Exit] = ACTIONS(3921),
    [anon_sym_continue] = ACTIONS(3921),
    [anon_sym_CONTINUE] = ACTIONS(3921),
    [anon_sym_Continue] = ACTIONS(3921),
    [anon_sym_break] = ACTIONS(3921),
    [anon_sym_BREAK] = ACTIONS(3921),
    [anon_sym_Break] = ACTIONS(3921),
    [anon_sym_with] = ACTIONS(3921),
    [anon_sym_WITH] = ACTIONS(3921),
    [anon_sym_With] = ACTIONS(3921),
    [sym_asserterror_keyword] = ACTIONS(3923),
    [anon_sym_in] = ACTIONS(3921),
    [anon_sym_IN] = ACTIONS(3921),
    [anon_sym_In] = ACTIONS(3921),
    [sym_page_keyword] = ACTIONS(3921),
    [anon_sym_codeunit] = ACTIONS(3921),
    [anon_sym_CODEUNIT] = ACTIONS(3921),
    [anon_sym_Codeunit] = ACTIONS(3921),
    [anon_sym_CodeUnit] = ACTIONS(3921),
    [anon_sym_COdeunit] = ACTIONS(3921),
    [anon_sym_codeUnit] = ACTIONS(3921),
    [sym_report_keyword] = ACTIONS(3921),
    [sym_query_keyword] = ACTIONS(3921),
    [anon_sym_xmlport] = ACTIONS(3921),
    [anon_sym_XMLPORT] = ACTIONS(3921),
    [anon_sym_Xmlport] = ACTIONS(3921),
    [anon_sym_XMLport] = ACTIONS(3921),
    [anon_sym_XMLPort] = ACTIONS(3921),
    [anon_sym_XmlPort] = ACTIONS(3921),
    [anon_sym_enum] = ACTIONS(3921),
    [anon_sym_ENUM] = ACTIONS(3921),
    [anon_sym_Enum] = ACTIONS(3921),
    [anon_sym_eNUM] = ACTIONS(3921),
    [anon_sym_eNum] = ACTIONS(3921),
    [anon_sym_ENum] = ACTIONS(3921),
    [sym_quoted_identifier] = ACTIONS(3923),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3923),
    [sym_verbatim_string] = ACTIONS(3923),
    [sym_integer] = ACTIONS(3921),
    [sym_continue_as_identifier] = ACTIONS(3923),
    [sym_preproc_open] = ACTIONS(3923),
  },
  [STATE(1983)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1984)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1985)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2816),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1986)] = {
    [sym_preproc_conditional_object] = STATE(1993),
    [sym_using_statement] = STATE(1993),
    [sym__object] = STATE(1993),
    [sym_preproc_split_declaration] = STATE(1993),
    [sym_table_declaration] = STATE(1993),
    [sym_page_declaration] = STATE(1993),
    [sym_report_declaration] = STATE(1993),
    [sym_query_declaration] = STATE(1993),
    [sym_xmlport_declaration] = STATE(1993),
    [sym_permissionset_declaration] = STATE(1993),
    [sym_codeunit_declaration] = STATE(1993),
    [sym_enum_declaration] = STATE(1993),
    [sym_tableextension_declaration] = STATE(1993),
    [sym_pageextension_declaration] = STATE(1993),
    [sym_reportextension_declaration] = STATE(1993),
    [sym_enumextension_declaration] = STATE(1993),
    [sym_permissionsetextension_declaration] = STATE(1993),
    [sym_controladdin_declaration] = STATE(1993),
    [sym_profile_declaration] = STATE(1993),
    [sym_entitlement_declaration] = STATE(1993),
    [sym_profileextension_declaration] = STATE(1993),
    [sym_interface_declaration] = STATE(1993),
    [sym_pagecustomization_declaration] = STATE(1993),
    [sym_dotnet_declaration] = STATE(1993),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2816),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1993),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1987)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1988)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1989)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3726),
    [anon_sym_SEMI] = ACTIONS(3728),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3728),
    [anon_sym_DASH] = ACTIONS(3726),
    [aux_sym_boolean_token1] = ACTIONS(3726),
    [aux_sym_boolean_token2] = ACTIONS(3726),
    [sym_decimal] = ACTIONS(3726),
    [anon_sym_LPAREN] = ACTIONS(3728),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3726),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3726),
    [aux_sym_basic_type_token21] = ACTIONS(3726),
    [aux_sym_basic_type_token22] = ACTIONS(3726),
    [aux_sym_basic_type_token48] = ACTIONS(3726),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3726),
    [anon_sym_POUNDif] = ACTIONS(3728),
    [anon_sym_POUNDIF] = ACTIONS(3728),
    [anon_sym_POUNDIf] = ACTIONS(3728),
    [anon_sym_not] = ACTIONS(3726),
    [anon_sym_NOT] = ACTIONS(3726),
    [anon_sym_Not] = ACTIONS(3726),
    [anon_sym_POUNDelse] = ACTIONS(3728),
    [anon_sym_POUNDELSE] = ACTIONS(3728),
    [anon_sym_POUNDElse] = ACTIONS(3728),
    [anon_sym_POUNDelse2] = ACTIONS(3728),
    [anon_sym_POUNDELSE2] = ACTIONS(3728),
    [anon_sym_POUNDElse2] = ACTIONS(3728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3728),
    [aux_sym__expression_token1] = ACTIONS(3728),
    [aux_sym__expression_token2] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3726),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(3726),
    [anon_sym_GT_EQ] = ACTIONS(3728),
    [anon_sym_LT_EQ] = ACTIONS(3728),
    [anon_sym_GT] = ACTIONS(3726),
    [anon_sym_LT] = ACTIONS(3726),
    [anon_sym_LT_GT] = ACTIONS(3728),
    [anon_sym_and] = ACTIONS(3726),
    [anon_sym_AND] = ACTIONS(3726),
    [anon_sym_And] = ACTIONS(3726),
    [anon_sym_or] = ACTIONS(3726),
    [anon_sym_OR] = ACTIONS(3726),
    [anon_sym_Or] = ACTIONS(3726),
    [anon_sym_xor] = ACTIONS(3726),
    [anon_sym_XOR] = ACTIONS(3726),
    [anon_sym_Xor] = ACTIONS(3726),
    [anon_sym_QMARK] = ACTIONS(3728),
    [sym_datetime_literal] = ACTIONS(3728),
    [sym_date_literal] = ACTIONS(3726),
    [sym_time_literal] = ACTIONS(3726),
    [sym_biginteger_literal] = ACTIONS(3728),
    [anon_sym_if] = ACTIONS(3726),
    [anon_sym_IF] = ACTIONS(3726),
    [anon_sym_If] = ACTIONS(3726),
    [anon_sym_else] = ACTIONS(3726),
    [anon_sym_ELSE] = ACTIONS(3726),
    [anon_sym_Else] = ACTIONS(3726),
    [anon_sym_case] = ACTIONS(3726),
    [anon_sym_CASE] = ACTIONS(3726),
    [anon_sym_Case] = ACTIONS(3726),
    [anon_sym_for] = ACTIONS(3726),
    [anon_sym_FOR] = ACTIONS(3726),
    [anon_sym_For] = ACTIONS(3726),
    [anon_sym_foreach] = ACTIONS(3726),
    [anon_sym_FOREACH] = ACTIONS(3726),
    [anon_sym_Foreach] = ACTIONS(3726),
    [anon_sym_while] = ACTIONS(3726),
    [anon_sym_WHILE] = ACTIONS(3726),
    [anon_sym_While] = ACTIONS(3726),
    [anon_sym_repeat] = ACTIONS(3726),
    [anon_sym_REPEAT] = ACTIONS(3726),
    [anon_sym_Repeat] = ACTIONS(3726),
    [anon_sym_exit] = ACTIONS(3726),
    [anon_sym_EXIT] = ACTIONS(3726),
    [anon_sym_Exit] = ACTIONS(3726),
    [anon_sym_continue] = ACTIONS(3726),
    [anon_sym_CONTINUE] = ACTIONS(3726),
    [anon_sym_Continue] = ACTIONS(3726),
    [anon_sym_break] = ACTIONS(3726),
    [anon_sym_BREAK] = ACTIONS(3726),
    [anon_sym_Break] = ACTIONS(3726),
    [anon_sym_with] = ACTIONS(3726),
    [anon_sym_WITH] = ACTIONS(3726),
    [anon_sym_With] = ACTIONS(3726),
    [sym_asserterror_keyword] = ACTIONS(3728),
    [anon_sym_in] = ACTIONS(3726),
    [anon_sym_IN] = ACTIONS(3726),
    [anon_sym_In] = ACTIONS(3726),
    [sym_page_keyword] = ACTIONS(3726),
    [anon_sym_codeunit] = ACTIONS(3726),
    [anon_sym_CODEUNIT] = ACTIONS(3726),
    [anon_sym_Codeunit] = ACTIONS(3726),
    [anon_sym_CodeUnit] = ACTIONS(3726),
    [anon_sym_COdeunit] = ACTIONS(3726),
    [anon_sym_codeUnit] = ACTIONS(3726),
    [sym_report_keyword] = ACTIONS(3726),
    [sym_query_keyword] = ACTIONS(3726),
    [anon_sym_xmlport] = ACTIONS(3726),
    [anon_sym_XMLPORT] = ACTIONS(3726),
    [anon_sym_Xmlport] = ACTIONS(3726),
    [anon_sym_XMLport] = ACTIONS(3726),
    [anon_sym_XMLPort] = ACTIONS(3726),
    [anon_sym_XmlPort] = ACTIONS(3726),
    [anon_sym_enum] = ACTIONS(3726),
    [anon_sym_ENUM] = ACTIONS(3726),
    [anon_sym_Enum] = ACTIONS(3726),
    [anon_sym_eNUM] = ACTIONS(3726),
    [anon_sym_eNum] = ACTIONS(3726),
    [anon_sym_ENum] = ACTIONS(3726),
    [sym_quoted_identifier] = ACTIONS(3728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3728),
    [sym_verbatim_string] = ACTIONS(3728),
    [sym_integer] = ACTIONS(3726),
    [sym_continue_as_identifier] = ACTIONS(3728),
    [sym_preproc_open] = ACTIONS(3728),
    [sym_end_keyword] = ACTIONS(3728),
  },
  [STATE(1990)] = {
    [sym_argument_list] = STATE(2045),
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(4344),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(4346),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_IF] = ACTIONS(3681),
    [anon_sym_If] = ACTIONS(3681),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_case] = ACTIONS(3681),
    [anon_sym_CASE] = ACTIONS(3681),
    [anon_sym_Case] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_FOR] = ACTIONS(3681),
    [anon_sym_For] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_FOREACH] = ACTIONS(3681),
    [anon_sym_Foreach] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_WHILE] = ACTIONS(3681),
    [anon_sym_While] = ACTIONS(3681),
    [anon_sym_repeat] = ACTIONS(3681),
    [anon_sym_REPEAT] = ACTIONS(3681),
    [anon_sym_Repeat] = ACTIONS(3681),
    [anon_sym_exit] = ACTIONS(3681),
    [anon_sym_EXIT] = ACTIONS(3681),
    [anon_sym_Exit] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_CONTINUE] = ACTIONS(3681),
    [anon_sym_Continue] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_BREAK] = ACTIONS(3681),
    [anon_sym_Break] = ACTIONS(3681),
    [anon_sym_with] = ACTIONS(3681),
    [anon_sym_WITH] = ACTIONS(3681),
    [anon_sym_With] = ACTIONS(3681),
    [sym_asserterror_keyword] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
    [sym_end_keyword] = ACTIONS(3683),
  },
  [STATE(1991)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3643),
    [anon_sym_IF] = ACTIONS(3643),
    [anon_sym_If] = ACTIONS(3643),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_case] = ACTIONS(3643),
    [anon_sym_CASE] = ACTIONS(3643),
    [anon_sym_Case] = ACTIONS(3643),
    [anon_sym_for] = ACTIONS(3643),
    [anon_sym_FOR] = ACTIONS(3643),
    [anon_sym_For] = ACTIONS(3643),
    [anon_sym_foreach] = ACTIONS(3643),
    [anon_sym_FOREACH] = ACTIONS(3643),
    [anon_sym_Foreach] = ACTIONS(3643),
    [anon_sym_while] = ACTIONS(3643),
    [anon_sym_WHILE] = ACTIONS(3643),
    [anon_sym_While] = ACTIONS(3643),
    [anon_sym_repeat] = ACTIONS(3643),
    [anon_sym_REPEAT] = ACTIONS(3643),
    [anon_sym_Repeat] = ACTIONS(3643),
    [anon_sym_exit] = ACTIONS(3643),
    [anon_sym_EXIT] = ACTIONS(3643),
    [anon_sym_Exit] = ACTIONS(3643),
    [anon_sym_continue] = ACTIONS(3643),
    [anon_sym_CONTINUE] = ACTIONS(3643),
    [anon_sym_Continue] = ACTIONS(3643),
    [anon_sym_break] = ACTIONS(3643),
    [anon_sym_BREAK] = ACTIONS(3643),
    [anon_sym_Break] = ACTIONS(3643),
    [anon_sym_with] = ACTIONS(3643),
    [anon_sym_WITH] = ACTIONS(3643),
    [anon_sym_With] = ACTIONS(3643),
    [sym_asserterror_keyword] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_end_keyword] = ACTIONS(3645),
  },
  [STATE(1992)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(1944),
    [sym_identifier] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(4183),
    [anon_sym_EQ] = ACTIONS(3695),
    [anon_sym_DASH] = ACTIONS(3693),
    [aux_sym_boolean_token1] = ACTIONS(3693),
    [aux_sym_boolean_token2] = ACTIONS(3693),
    [sym_decimal] = ACTIONS(3693),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_DOT_DOT] = ACTIONS(3695),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [aux_sym_record_type_token1] = ACTIONS(3693),
    [aux_sym_basic_type_token21] = ACTIONS(3693),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_basic_type_token48] = ACTIONS(3693),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_not] = ACTIONS(3693),
    [anon_sym_NOT] = ACTIONS(3693),
    [anon_sym_Not] = ACTIONS(3693),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3695),
    [aux_sym__expression_token1] = ACTIONS(3695),
    [aux_sym__expression_token2] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3693),
    [anon_sym_SLASH] = ACTIONS(3693),
    [anon_sym_div] = ACTIONS(3693),
    [anon_sym_DIV] = ACTIONS(3693),
    [anon_sym_Div] = ACTIONS(3693),
    [anon_sym_mod] = ACTIONS(3693),
    [anon_sym_MOD] = ACTIONS(3693),
    [anon_sym_Mod] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(3693),
    [anon_sym_GT_EQ] = ACTIONS(3695),
    [anon_sym_LT_EQ] = ACTIONS(3695),
    [anon_sym_GT] = ACTIONS(3693),
    [anon_sym_LT] = ACTIONS(3693),
    [anon_sym_LT_GT] = ACTIONS(3695),
    [anon_sym_and] = ACTIONS(3693),
    [anon_sym_AND] = ACTIONS(3693),
    [anon_sym_And] = ACTIONS(3693),
    [anon_sym_or] = ACTIONS(3693),
    [anon_sym_OR] = ACTIONS(3693),
    [anon_sym_Or] = ACTIONS(3693),
    [anon_sym_xor] = ACTIONS(3693),
    [anon_sym_XOR] = ACTIONS(3693),
    [anon_sym_Xor] = ACTIONS(3693),
    [anon_sym_QMARK] = ACTIONS(3695),
    [sym_datetime_literal] = ACTIONS(3695),
    [sym_date_literal] = ACTIONS(3693),
    [sym_time_literal] = ACTIONS(3693),
    [sym_biginteger_literal] = ACTIONS(3695),
    [anon_sym_if] = ACTIONS(3693),
    [anon_sym_IF] = ACTIONS(3693),
    [anon_sym_If] = ACTIONS(3693),
    [anon_sym_else] = ACTIONS(3693),
    [anon_sym_ELSE] = ACTIONS(3693),
    [anon_sym_Else] = ACTIONS(3693),
    [anon_sym_case] = ACTIONS(3693),
    [anon_sym_CASE] = ACTIONS(3693),
    [anon_sym_Case] = ACTIONS(3693),
    [anon_sym_for] = ACTIONS(3693),
    [anon_sym_FOR] = ACTIONS(3693),
    [anon_sym_For] = ACTIONS(3693),
    [anon_sym_foreach] = ACTIONS(3693),
    [anon_sym_FOREACH] = ACTIONS(3693),
    [anon_sym_Foreach] = ACTIONS(3693),
    [anon_sym_while] = ACTIONS(3693),
    [anon_sym_WHILE] = ACTIONS(3693),
    [anon_sym_While] = ACTIONS(3693),
    [anon_sym_repeat] = ACTIONS(3693),
    [anon_sym_REPEAT] = ACTIONS(3693),
    [anon_sym_Repeat] = ACTIONS(3693),
    [anon_sym_exit] = ACTIONS(3693),
    [anon_sym_EXIT] = ACTIONS(3693),
    [anon_sym_Exit] = ACTIONS(3693),
    [anon_sym_continue] = ACTIONS(3693),
    [anon_sym_CONTINUE] = ACTIONS(3693),
    [anon_sym_Continue] = ACTIONS(3693),
    [anon_sym_break] = ACTIONS(3693),
    [anon_sym_BREAK] = ACTIONS(3693),
    [anon_sym_Break] = ACTIONS(3693),
    [anon_sym_with] = ACTIONS(3693),
    [anon_sym_WITH] = ACTIONS(3693),
    [anon_sym_With] = ACTIONS(3693),
    [sym_asserterror_keyword] = ACTIONS(3695),
    [anon_sym_in] = ACTIONS(3693),
    [anon_sym_IN] = ACTIONS(3693),
    [anon_sym_In] = ACTIONS(3693),
    [sym_page_keyword] = ACTIONS(3693),
    [anon_sym_codeunit] = ACTIONS(3693),
    [anon_sym_CODEUNIT] = ACTIONS(3693),
    [anon_sym_Codeunit] = ACTIONS(3693),
    [anon_sym_CodeUnit] = ACTIONS(3693),
    [anon_sym_COdeunit] = ACTIONS(3693),
    [anon_sym_codeUnit] = ACTIONS(3693),
    [sym_report_keyword] = ACTIONS(3693),
    [sym_query_keyword] = ACTIONS(3693),
    [anon_sym_xmlport] = ACTIONS(3693),
    [anon_sym_XMLPORT] = ACTIONS(3693),
    [anon_sym_Xmlport] = ACTIONS(3693),
    [anon_sym_XMLport] = ACTIONS(3693),
    [anon_sym_XMLPort] = ACTIONS(3693),
    [anon_sym_XmlPort] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_ENUM] = ACTIONS(3693),
    [anon_sym_Enum] = ACTIONS(3693),
    [anon_sym_eNUM] = ACTIONS(3693),
    [anon_sym_eNum] = ACTIONS(3693),
    [anon_sym_ENum] = ACTIONS(3693),
    [sym_temporary_keyword] = ACTIONS(3693),
    [sym_quoted_identifier] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3695),
    [sym_verbatim_string] = ACTIONS(3695),
    [sym_integer] = ACTIONS(3693),
    [sym_continue_as_identifier] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
    [sym_end_keyword] = ACTIONS(3695),
  },
  [STATE(1993)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2842),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(1994)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2029),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_if] = ACTIONS(3689),
    [anon_sym_IF] = ACTIONS(3689),
    [anon_sym_If] = ACTIONS(3689),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_case] = ACTIONS(3689),
    [anon_sym_CASE] = ACTIONS(3689),
    [anon_sym_Case] = ACTIONS(3689),
    [anon_sym_for] = ACTIONS(3689),
    [anon_sym_FOR] = ACTIONS(3689),
    [anon_sym_For] = ACTIONS(3689),
    [anon_sym_foreach] = ACTIONS(3689),
    [anon_sym_FOREACH] = ACTIONS(3689),
    [anon_sym_Foreach] = ACTIONS(3689),
    [anon_sym_while] = ACTIONS(3689),
    [anon_sym_WHILE] = ACTIONS(3689),
    [anon_sym_While] = ACTIONS(3689),
    [anon_sym_repeat] = ACTIONS(3689),
    [anon_sym_REPEAT] = ACTIONS(3689),
    [anon_sym_Repeat] = ACTIONS(3689),
    [anon_sym_exit] = ACTIONS(3689),
    [anon_sym_EXIT] = ACTIONS(3689),
    [anon_sym_Exit] = ACTIONS(3689),
    [anon_sym_continue] = ACTIONS(3689),
    [anon_sym_CONTINUE] = ACTIONS(3689),
    [anon_sym_Continue] = ACTIONS(3689),
    [anon_sym_break] = ACTIONS(3689),
    [anon_sym_BREAK] = ACTIONS(3689),
    [anon_sym_Break] = ACTIONS(3689),
    [anon_sym_with] = ACTIONS(3689),
    [anon_sym_WITH] = ACTIONS(3689),
    [anon_sym_With] = ACTIONS(3689),
    [sym_asserterror_keyword] = ACTIONS(3691),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
    [sym_end_keyword] = ACTIONS(3691),
  },
  [STATE(1995)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3631),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1996)] = {
    [sym_preproc_conditional_object] = STATE(2013),
    [sym_using_statement] = STATE(2013),
    [sym__object] = STATE(2013),
    [sym_preproc_split_declaration] = STATE(2013),
    [sym_table_declaration] = STATE(2013),
    [sym_page_declaration] = STATE(2013),
    [sym_report_declaration] = STATE(2013),
    [sym_query_declaration] = STATE(2013),
    [sym_xmlport_declaration] = STATE(2013),
    [sym_permissionset_declaration] = STATE(2013),
    [sym_codeunit_declaration] = STATE(2013),
    [sym_enum_declaration] = STATE(2013),
    [sym_tableextension_declaration] = STATE(2013),
    [sym_pageextension_declaration] = STATE(2013),
    [sym_reportextension_declaration] = STATE(2013),
    [sym_enumextension_declaration] = STATE(2013),
    [sym_permissionsetextension_declaration] = STATE(2013),
    [sym_controladdin_declaration] = STATE(2013),
    [sym_profile_declaration] = STATE(2013),
    [sym_entitlement_declaration] = STATE(2013),
    [sym_profileextension_declaration] = STATE(2013),
    [sym_interface_declaration] = STATE(2013),
    [sym_pagecustomization_declaration] = STATE(2013),
    [sym_dotnet_declaration] = STATE(2013),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3740),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(2013),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(1997)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_end_keyword] = ACTIONS(3568),
  },
  [STATE(1998)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_end_keyword] = ACTIONS(3568),
  },
  [STATE(1999)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3734),
    [anon_sym_SEMI] = ACTIONS(3736),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3734),
    [aux_sym_boolean_token2] = ACTIONS(3734),
    [sym_decimal] = ACTIONS(3734),
    [anon_sym_LPAREN] = ACTIONS(3736),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3734),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3734),
    [aux_sym_basic_type_token21] = ACTIONS(3734),
    [aux_sym_basic_type_token22] = ACTIONS(3734),
    [aux_sym_basic_type_token48] = ACTIONS(3734),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3734),
    [anon_sym_POUNDif] = ACTIONS(3736),
    [anon_sym_POUNDIF] = ACTIONS(3736),
    [anon_sym_POUNDIf] = ACTIONS(3736),
    [anon_sym_not] = ACTIONS(3734),
    [anon_sym_NOT] = ACTIONS(3734),
    [anon_sym_Not] = ACTIONS(3734),
    [anon_sym_POUNDelse] = ACTIONS(3736),
    [anon_sym_POUNDELSE] = ACTIONS(3736),
    [anon_sym_POUNDElse] = ACTIONS(3736),
    [anon_sym_POUNDelse2] = ACTIONS(3736),
    [anon_sym_POUNDELSE2] = ACTIONS(3736),
    [anon_sym_POUNDElse2] = ACTIONS(3736),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4342),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3734),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3734),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_OR] = ACTIONS(4330),
    [anon_sym_Or] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_XOR] = ACTIONS(4336),
    [anon_sym_Xor] = ACTIONS(4338),
    [anon_sym_QMARK] = ACTIONS(4340),
    [sym_datetime_literal] = ACTIONS(3736),
    [sym_date_literal] = ACTIONS(3734),
    [sym_time_literal] = ACTIONS(3734),
    [sym_biginteger_literal] = ACTIONS(3736),
    [anon_sym_if] = ACTIONS(3734),
    [anon_sym_IF] = ACTIONS(3734),
    [anon_sym_If] = ACTIONS(3734),
    [anon_sym_else] = ACTIONS(3734),
    [anon_sym_ELSE] = ACTIONS(3734),
    [anon_sym_Else] = ACTIONS(3734),
    [anon_sym_case] = ACTIONS(3734),
    [anon_sym_CASE] = ACTIONS(3734),
    [anon_sym_Case] = ACTIONS(3734),
    [anon_sym_for] = ACTIONS(3734),
    [anon_sym_FOR] = ACTIONS(3734),
    [anon_sym_For] = ACTIONS(3734),
    [anon_sym_foreach] = ACTIONS(3734),
    [anon_sym_FOREACH] = ACTIONS(3734),
    [anon_sym_Foreach] = ACTIONS(3734),
    [anon_sym_while] = ACTIONS(3734),
    [anon_sym_WHILE] = ACTIONS(3734),
    [anon_sym_While] = ACTIONS(3734),
    [anon_sym_repeat] = ACTIONS(3734),
    [anon_sym_REPEAT] = ACTIONS(3734),
    [anon_sym_Repeat] = ACTIONS(3734),
    [anon_sym_exit] = ACTIONS(3734),
    [anon_sym_EXIT] = ACTIONS(3734),
    [anon_sym_Exit] = ACTIONS(3734),
    [anon_sym_continue] = ACTIONS(3734),
    [anon_sym_CONTINUE] = ACTIONS(3734),
    [anon_sym_Continue] = ACTIONS(3734),
    [anon_sym_break] = ACTIONS(3734),
    [anon_sym_BREAK] = ACTIONS(3734),
    [anon_sym_Break] = ACTIONS(3734),
    [anon_sym_with] = ACTIONS(3734),
    [anon_sym_WITH] = ACTIONS(3734),
    [anon_sym_With] = ACTIONS(3734),
    [sym_asserterror_keyword] = ACTIONS(3736),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3734),
    [anon_sym_codeunit] = ACTIONS(3734),
    [anon_sym_CODEUNIT] = ACTIONS(3734),
    [anon_sym_Codeunit] = ACTIONS(3734),
    [anon_sym_CodeUnit] = ACTIONS(3734),
    [anon_sym_COdeunit] = ACTIONS(3734),
    [anon_sym_codeUnit] = ACTIONS(3734),
    [sym_report_keyword] = ACTIONS(3734),
    [sym_query_keyword] = ACTIONS(3734),
    [anon_sym_xmlport] = ACTIONS(3734),
    [anon_sym_XMLPORT] = ACTIONS(3734),
    [anon_sym_Xmlport] = ACTIONS(3734),
    [anon_sym_XMLport] = ACTIONS(3734),
    [anon_sym_XMLPort] = ACTIONS(3734),
    [anon_sym_XmlPort] = ACTIONS(3734),
    [anon_sym_enum] = ACTIONS(3734),
    [anon_sym_ENUM] = ACTIONS(3734),
    [anon_sym_Enum] = ACTIONS(3734),
    [anon_sym_eNUM] = ACTIONS(3734),
    [anon_sym_eNum] = ACTIONS(3734),
    [anon_sym_ENum] = ACTIONS(3734),
    [sym_quoted_identifier] = ACTIONS(3736),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3736),
    [sym_verbatim_string] = ACTIONS(3736),
    [sym_integer] = ACTIONS(3734),
    [sym_continue_as_identifier] = ACTIONS(3736),
    [sym_preproc_open] = ACTIONS(3736),
    [sym_end_keyword] = ACTIONS(3736),
  },
  [STATE(2000)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_end_keyword] = ACTIONS(3568),
  },
  [STATE(2001)] = {
    [sym_preproc_conditional_object] = STATE(1973),
    [sym_using_statement] = STATE(1973),
    [sym__object] = STATE(1973),
    [sym_preproc_split_declaration] = STATE(1973),
    [sym_table_declaration] = STATE(1973),
    [sym_page_declaration] = STATE(1973),
    [sym_report_declaration] = STATE(1973),
    [sym_query_declaration] = STATE(1973),
    [sym_xmlport_declaration] = STATE(1973),
    [sym_permissionset_declaration] = STATE(1973),
    [sym_codeunit_declaration] = STATE(1973),
    [sym_enum_declaration] = STATE(1973),
    [sym_tableextension_declaration] = STATE(1973),
    [sym_pageextension_declaration] = STATE(1973),
    [sym_reportextension_declaration] = STATE(1973),
    [sym_enumextension_declaration] = STATE(1973),
    [sym_permissionsetextension_declaration] = STATE(1973),
    [sym_controladdin_declaration] = STATE(1973),
    [sym_profile_declaration] = STATE(1973),
    [sym_entitlement_declaration] = STATE(1973),
    [sym_profileextension_declaration] = STATE(1973),
    [sym_interface_declaration] = STATE(1973),
    [sym_pagecustomization_declaration] = STATE(1973),
    [sym_dotnet_declaration] = STATE(1973),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2775),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1973),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(2002)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_end_keyword] = ACTIONS(3568),
  },
  [STATE(2003)] = {
    [sym_preproc_conditional_object] = STATE(1995),
    [sym_using_statement] = STATE(1995),
    [sym__object] = STATE(1995),
    [sym_preproc_split_declaration] = STATE(1995),
    [sym_table_declaration] = STATE(1995),
    [sym_page_declaration] = STATE(1995),
    [sym_report_declaration] = STATE(1995),
    [sym_query_declaration] = STATE(1995),
    [sym_xmlport_declaration] = STATE(1995),
    [sym_permissionset_declaration] = STATE(1995),
    [sym_codeunit_declaration] = STATE(1995),
    [sym_enum_declaration] = STATE(1995),
    [sym_tableextension_declaration] = STATE(1995),
    [sym_pageextension_declaration] = STATE(1995),
    [sym_reportextension_declaration] = STATE(1995),
    [sym_enumextension_declaration] = STATE(1995),
    [sym_permissionsetextension_declaration] = STATE(1995),
    [sym_controladdin_declaration] = STATE(1995),
    [sym_profile_declaration] = STATE(1995),
    [sym_entitlement_declaration] = STATE(1995),
    [sym_profileextension_declaration] = STATE(1995),
    [sym_interface_declaration] = STATE(1995),
    [sym_pagecustomization_declaration] = STATE(1995),
    [sym_dotnet_declaration] = STATE(1995),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3661),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1995),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(2004)] = {
    [sym_identifier] = ACTIONS(3937),
    [anon_sym_SEMI] = ACTIONS(3939),
    [anon_sym_DOT] = ACTIONS(3937),
    [anon_sym_EQ] = ACTIONS(3939),
    [anon_sym_DASH] = ACTIONS(3937),
    [aux_sym_boolean_token1] = ACTIONS(3937),
    [aux_sym_boolean_token2] = ACTIONS(3937),
    [sym_decimal] = ACTIONS(3937),
    [anon_sym_LPAREN] = ACTIONS(3939),
    [anon_sym_DOT_DOT] = ACTIONS(3939),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3937),
    [anon_sym_STAR] = ACTIONS(3937),
    [anon_sym_LBRACK] = ACTIONS(3939),
    [aux_sym_record_type_token1] = ACTIONS(3937),
    [aux_sym_basic_type_token21] = ACTIONS(3937),
    [aux_sym_basic_type_token22] = ACTIONS(3937),
    [aux_sym_basic_type_token48] = ACTIONS(3937),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3937),
    [anon_sym_POUNDif] = ACTIONS(3939),
    [anon_sym_POUNDIF] = ACTIONS(3939),
    [anon_sym_POUNDIf] = ACTIONS(3939),
    [anon_sym_not] = ACTIONS(3937),
    [anon_sym_NOT] = ACTIONS(3937),
    [anon_sym_Not] = ACTIONS(3937),
    [anon_sym_POUNDelse] = ACTIONS(3939),
    [anon_sym_POUNDELSE] = ACTIONS(3939),
    [anon_sym_POUNDElse] = ACTIONS(3939),
    [anon_sym_POUNDelse2] = ACTIONS(3939),
    [anon_sym_POUNDELSE2] = ACTIONS(3939),
    [anon_sym_POUNDElse2] = ACTIONS(3939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3939),
    [aux_sym__expression_token1] = ACTIONS(3939),
    [aux_sym__expression_token2] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3937),
    [anon_sym_SLASH] = ACTIONS(3937),
    [anon_sym_div] = ACTIONS(3937),
    [anon_sym_DIV] = ACTIONS(3937),
    [anon_sym_Div] = ACTIONS(3937),
    [anon_sym_mod] = ACTIONS(3937),
    [anon_sym_MOD] = ACTIONS(3937),
    [anon_sym_Mod] = ACTIONS(3937),
    [anon_sym_PLUS] = ACTIONS(3937),
    [anon_sym_GT_EQ] = ACTIONS(3939),
    [anon_sym_LT_EQ] = ACTIONS(3939),
    [anon_sym_GT] = ACTIONS(3937),
    [anon_sym_LT] = ACTIONS(3937),
    [anon_sym_LT_GT] = ACTIONS(3939),
    [anon_sym_and] = ACTIONS(3937),
    [anon_sym_AND] = ACTIONS(3937),
    [anon_sym_And] = ACTIONS(3937),
    [anon_sym_or] = ACTIONS(3937),
    [anon_sym_OR] = ACTIONS(3937),
    [anon_sym_Or] = ACTIONS(3937),
    [anon_sym_xor] = ACTIONS(3937),
    [anon_sym_XOR] = ACTIONS(3937),
    [anon_sym_Xor] = ACTIONS(3937),
    [anon_sym_QMARK] = ACTIONS(3939),
    [sym_datetime_literal] = ACTIONS(3939),
    [sym_date_literal] = ACTIONS(3937),
    [sym_time_literal] = ACTIONS(3937),
    [sym_biginteger_literal] = ACTIONS(3939),
    [anon_sym_if] = ACTIONS(3937),
    [anon_sym_IF] = ACTIONS(3937),
    [anon_sym_If] = ACTIONS(3937),
    [anon_sym_else] = ACTIONS(3937),
    [anon_sym_ELSE] = ACTIONS(3937),
    [anon_sym_Else] = ACTIONS(3937),
    [anon_sym_case] = ACTIONS(3937),
    [anon_sym_CASE] = ACTIONS(3937),
    [anon_sym_Case] = ACTIONS(3937),
    [anon_sym_for] = ACTIONS(3937),
    [anon_sym_FOR] = ACTIONS(3937),
    [anon_sym_For] = ACTIONS(3937),
    [anon_sym_foreach] = ACTIONS(3937),
    [anon_sym_FOREACH] = ACTIONS(3937),
    [anon_sym_Foreach] = ACTIONS(3937),
    [anon_sym_while] = ACTIONS(3937),
    [anon_sym_WHILE] = ACTIONS(3937),
    [anon_sym_While] = ACTIONS(3937),
    [anon_sym_repeat] = ACTIONS(3937),
    [anon_sym_REPEAT] = ACTIONS(3937),
    [anon_sym_Repeat] = ACTIONS(3937),
    [anon_sym_until] = ACTIONS(3937),
    [anon_sym_UNTIL] = ACTIONS(3937),
    [anon_sym_Until] = ACTIONS(3937),
    [anon_sym_exit] = ACTIONS(3937),
    [anon_sym_EXIT] = ACTIONS(3937),
    [anon_sym_Exit] = ACTIONS(3937),
    [anon_sym_continue] = ACTIONS(3937),
    [anon_sym_CONTINUE] = ACTIONS(3937),
    [anon_sym_Continue] = ACTIONS(3937),
    [anon_sym_break] = ACTIONS(3937),
    [anon_sym_BREAK] = ACTIONS(3937),
    [anon_sym_Break] = ACTIONS(3937),
    [anon_sym_with] = ACTIONS(3937),
    [anon_sym_WITH] = ACTIONS(3937),
    [anon_sym_With] = ACTIONS(3937),
    [sym_asserterror_keyword] = ACTIONS(3939),
    [anon_sym_in] = ACTIONS(3937),
    [anon_sym_IN] = ACTIONS(3937),
    [anon_sym_In] = ACTIONS(3937),
    [sym_page_keyword] = ACTIONS(3937),
    [anon_sym_codeunit] = ACTIONS(3937),
    [anon_sym_CODEUNIT] = ACTIONS(3937),
    [anon_sym_Codeunit] = ACTIONS(3937),
    [anon_sym_CodeUnit] = ACTIONS(3937),
    [anon_sym_COdeunit] = ACTIONS(3937),
    [anon_sym_codeUnit] = ACTIONS(3937),
    [sym_report_keyword] = ACTIONS(3937),
    [sym_query_keyword] = ACTIONS(3937),
    [anon_sym_xmlport] = ACTIONS(3937),
    [anon_sym_XMLPORT] = ACTIONS(3937),
    [anon_sym_Xmlport] = ACTIONS(3937),
    [anon_sym_XMLport] = ACTIONS(3937),
    [anon_sym_XMLPort] = ACTIONS(3937),
    [anon_sym_XmlPort] = ACTIONS(3937),
    [anon_sym_enum] = ACTIONS(3937),
    [anon_sym_ENUM] = ACTIONS(3937),
    [anon_sym_Enum] = ACTIONS(3937),
    [anon_sym_eNUM] = ACTIONS(3937),
    [anon_sym_eNum] = ACTIONS(3937),
    [anon_sym_ENum] = ACTIONS(3937),
    [sym_quoted_identifier] = ACTIONS(3939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3939),
    [sym_verbatim_string] = ACTIONS(3939),
    [sym_integer] = ACTIONS(3937),
    [sym_continue_as_identifier] = ACTIONS(3939),
    [sym_preproc_open] = ACTIONS(3939),
  },
  [STATE(2005)] = {
    [sym_identifier] = ACTIONS(3941),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_DOT] = ACTIONS(3941),
    [anon_sym_EQ] = ACTIONS(3943),
    [anon_sym_DASH] = ACTIONS(3941),
    [aux_sym_boolean_token1] = ACTIONS(3941),
    [aux_sym_boolean_token2] = ACTIONS(3941),
    [sym_decimal] = ACTIONS(3941),
    [anon_sym_LPAREN] = ACTIONS(3943),
    [anon_sym_DOT_DOT] = ACTIONS(3943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3941),
    [anon_sym_STAR] = ACTIONS(3941),
    [anon_sym_LBRACK] = ACTIONS(3943),
    [aux_sym_record_type_token1] = ACTIONS(3941),
    [aux_sym_basic_type_token21] = ACTIONS(3941),
    [aux_sym_basic_type_token22] = ACTIONS(3941),
    [aux_sym_basic_type_token48] = ACTIONS(3941),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3941),
    [anon_sym_POUNDif] = ACTIONS(3943),
    [anon_sym_POUNDIF] = ACTIONS(3943),
    [anon_sym_POUNDIf] = ACTIONS(3943),
    [anon_sym_not] = ACTIONS(3941),
    [anon_sym_NOT] = ACTIONS(3941),
    [anon_sym_Not] = ACTIONS(3941),
    [anon_sym_POUNDelse] = ACTIONS(3943),
    [anon_sym_POUNDELSE] = ACTIONS(3943),
    [anon_sym_POUNDElse] = ACTIONS(3943),
    [anon_sym_POUNDelse2] = ACTIONS(3943),
    [anon_sym_POUNDELSE2] = ACTIONS(3943),
    [anon_sym_POUNDElse2] = ACTIONS(3943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3943),
    [aux_sym__expression_token1] = ACTIONS(3943),
    [aux_sym__expression_token2] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3941),
    [anon_sym_SLASH] = ACTIONS(3941),
    [anon_sym_div] = ACTIONS(3941),
    [anon_sym_DIV] = ACTIONS(3941),
    [anon_sym_Div] = ACTIONS(3941),
    [anon_sym_mod] = ACTIONS(3941),
    [anon_sym_MOD] = ACTIONS(3941),
    [anon_sym_Mod] = ACTIONS(3941),
    [anon_sym_PLUS] = ACTIONS(3941),
    [anon_sym_GT_EQ] = ACTIONS(3943),
    [anon_sym_LT_EQ] = ACTIONS(3943),
    [anon_sym_GT] = ACTIONS(3941),
    [anon_sym_LT] = ACTIONS(3941),
    [anon_sym_LT_GT] = ACTIONS(3943),
    [anon_sym_and] = ACTIONS(3941),
    [anon_sym_AND] = ACTIONS(3941),
    [anon_sym_And] = ACTIONS(3941),
    [anon_sym_or] = ACTIONS(3941),
    [anon_sym_OR] = ACTIONS(3941),
    [anon_sym_Or] = ACTIONS(3941),
    [anon_sym_xor] = ACTIONS(3941),
    [anon_sym_XOR] = ACTIONS(3941),
    [anon_sym_Xor] = ACTIONS(3941),
    [anon_sym_QMARK] = ACTIONS(3943),
    [sym_datetime_literal] = ACTIONS(3943),
    [sym_date_literal] = ACTIONS(3941),
    [sym_time_literal] = ACTIONS(3941),
    [sym_biginteger_literal] = ACTIONS(3943),
    [anon_sym_if] = ACTIONS(3941),
    [anon_sym_IF] = ACTIONS(3941),
    [anon_sym_If] = ACTIONS(3941),
    [anon_sym_else] = ACTIONS(3941),
    [anon_sym_ELSE] = ACTIONS(3941),
    [anon_sym_Else] = ACTIONS(3941),
    [anon_sym_case] = ACTIONS(3941),
    [anon_sym_CASE] = ACTIONS(3941),
    [anon_sym_Case] = ACTIONS(3941),
    [anon_sym_for] = ACTIONS(3941),
    [anon_sym_FOR] = ACTIONS(3941),
    [anon_sym_For] = ACTIONS(3941),
    [anon_sym_foreach] = ACTIONS(3941),
    [anon_sym_FOREACH] = ACTIONS(3941),
    [anon_sym_Foreach] = ACTIONS(3941),
    [anon_sym_while] = ACTIONS(3941),
    [anon_sym_WHILE] = ACTIONS(3941),
    [anon_sym_While] = ACTIONS(3941),
    [anon_sym_repeat] = ACTIONS(3941),
    [anon_sym_REPEAT] = ACTIONS(3941),
    [anon_sym_Repeat] = ACTIONS(3941),
    [anon_sym_until] = ACTIONS(3941),
    [anon_sym_UNTIL] = ACTIONS(3941),
    [anon_sym_Until] = ACTIONS(3941),
    [anon_sym_exit] = ACTIONS(3941),
    [anon_sym_EXIT] = ACTIONS(3941),
    [anon_sym_Exit] = ACTIONS(3941),
    [anon_sym_continue] = ACTIONS(3941),
    [anon_sym_CONTINUE] = ACTIONS(3941),
    [anon_sym_Continue] = ACTIONS(3941),
    [anon_sym_break] = ACTIONS(3941),
    [anon_sym_BREAK] = ACTIONS(3941),
    [anon_sym_Break] = ACTIONS(3941),
    [anon_sym_with] = ACTIONS(3941),
    [anon_sym_WITH] = ACTIONS(3941),
    [anon_sym_With] = ACTIONS(3941),
    [sym_asserterror_keyword] = ACTIONS(3943),
    [anon_sym_in] = ACTIONS(3941),
    [anon_sym_IN] = ACTIONS(3941),
    [anon_sym_In] = ACTIONS(3941),
    [sym_page_keyword] = ACTIONS(3941),
    [anon_sym_codeunit] = ACTIONS(3941),
    [anon_sym_CODEUNIT] = ACTIONS(3941),
    [anon_sym_Codeunit] = ACTIONS(3941),
    [anon_sym_CodeUnit] = ACTIONS(3941),
    [anon_sym_COdeunit] = ACTIONS(3941),
    [anon_sym_codeUnit] = ACTIONS(3941),
    [sym_report_keyword] = ACTIONS(3941),
    [sym_query_keyword] = ACTIONS(3941),
    [anon_sym_xmlport] = ACTIONS(3941),
    [anon_sym_XMLPORT] = ACTIONS(3941),
    [anon_sym_Xmlport] = ACTIONS(3941),
    [anon_sym_XMLport] = ACTIONS(3941),
    [anon_sym_XMLPort] = ACTIONS(3941),
    [anon_sym_XmlPort] = ACTIONS(3941),
    [anon_sym_enum] = ACTIONS(3941),
    [anon_sym_ENUM] = ACTIONS(3941),
    [anon_sym_Enum] = ACTIONS(3941),
    [anon_sym_eNUM] = ACTIONS(3941),
    [anon_sym_eNum] = ACTIONS(3941),
    [anon_sym_ENum] = ACTIONS(3941),
    [sym_quoted_identifier] = ACTIONS(3943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3943),
    [sym_verbatim_string] = ACTIONS(3943),
    [sym_integer] = ACTIONS(3941),
    [sym_continue_as_identifier] = ACTIONS(3943),
    [sym_preproc_open] = ACTIONS(3943),
  },
  [STATE(2006)] = {
    [sym_identifier] = ACTIONS(3945),
    [anon_sym_SEMI] = ACTIONS(3947),
    [anon_sym_DOT] = ACTIONS(3945),
    [anon_sym_EQ] = ACTIONS(3947),
    [anon_sym_DASH] = ACTIONS(3945),
    [aux_sym_boolean_token1] = ACTIONS(3945),
    [aux_sym_boolean_token2] = ACTIONS(3945),
    [sym_decimal] = ACTIONS(3945),
    [anon_sym_LPAREN] = ACTIONS(3947),
    [anon_sym_DOT_DOT] = ACTIONS(3947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3945),
    [anon_sym_STAR] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(3947),
    [aux_sym_record_type_token1] = ACTIONS(3945),
    [aux_sym_basic_type_token21] = ACTIONS(3945),
    [aux_sym_basic_type_token22] = ACTIONS(3945),
    [aux_sym_basic_type_token48] = ACTIONS(3945),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3945),
    [anon_sym_POUNDif] = ACTIONS(3947),
    [anon_sym_POUNDIF] = ACTIONS(3947),
    [anon_sym_POUNDIf] = ACTIONS(3947),
    [anon_sym_not] = ACTIONS(3945),
    [anon_sym_NOT] = ACTIONS(3945),
    [anon_sym_Not] = ACTIONS(3945),
    [anon_sym_POUNDelse] = ACTIONS(3947),
    [anon_sym_POUNDELSE] = ACTIONS(3947),
    [anon_sym_POUNDElse] = ACTIONS(3947),
    [anon_sym_POUNDelse2] = ACTIONS(3947),
    [anon_sym_POUNDELSE2] = ACTIONS(3947),
    [anon_sym_POUNDElse2] = ACTIONS(3947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3947),
    [aux_sym__expression_token1] = ACTIONS(3947),
    [aux_sym__expression_token2] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3945),
    [anon_sym_SLASH] = ACTIONS(3945),
    [anon_sym_div] = ACTIONS(3945),
    [anon_sym_DIV] = ACTIONS(3945),
    [anon_sym_Div] = ACTIONS(3945),
    [anon_sym_mod] = ACTIONS(3945),
    [anon_sym_MOD] = ACTIONS(3945),
    [anon_sym_Mod] = ACTIONS(3945),
    [anon_sym_PLUS] = ACTIONS(3945),
    [anon_sym_GT_EQ] = ACTIONS(3947),
    [anon_sym_LT_EQ] = ACTIONS(3947),
    [anon_sym_GT] = ACTIONS(3945),
    [anon_sym_LT] = ACTIONS(3945),
    [anon_sym_LT_GT] = ACTIONS(3947),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_AND] = ACTIONS(3945),
    [anon_sym_And] = ACTIONS(3945),
    [anon_sym_or] = ACTIONS(3945),
    [anon_sym_OR] = ACTIONS(3945),
    [anon_sym_Or] = ACTIONS(3945),
    [anon_sym_xor] = ACTIONS(3945),
    [anon_sym_XOR] = ACTIONS(3945),
    [anon_sym_Xor] = ACTIONS(3945),
    [anon_sym_QMARK] = ACTIONS(3947),
    [sym_datetime_literal] = ACTIONS(3947),
    [sym_date_literal] = ACTIONS(3945),
    [sym_time_literal] = ACTIONS(3945),
    [sym_biginteger_literal] = ACTIONS(3947),
    [anon_sym_if] = ACTIONS(3945),
    [anon_sym_IF] = ACTIONS(3945),
    [anon_sym_If] = ACTIONS(3945),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_ELSE] = ACTIONS(3945),
    [anon_sym_Else] = ACTIONS(3945),
    [anon_sym_case] = ACTIONS(3945),
    [anon_sym_CASE] = ACTIONS(3945),
    [anon_sym_Case] = ACTIONS(3945),
    [anon_sym_for] = ACTIONS(3945),
    [anon_sym_FOR] = ACTIONS(3945),
    [anon_sym_For] = ACTIONS(3945),
    [anon_sym_foreach] = ACTIONS(3945),
    [anon_sym_FOREACH] = ACTIONS(3945),
    [anon_sym_Foreach] = ACTIONS(3945),
    [anon_sym_while] = ACTIONS(3945),
    [anon_sym_WHILE] = ACTIONS(3945),
    [anon_sym_While] = ACTIONS(3945),
    [anon_sym_repeat] = ACTIONS(3945),
    [anon_sym_REPEAT] = ACTIONS(3945),
    [anon_sym_Repeat] = ACTIONS(3945),
    [anon_sym_until] = ACTIONS(3945),
    [anon_sym_UNTIL] = ACTIONS(3945),
    [anon_sym_Until] = ACTIONS(3945),
    [anon_sym_exit] = ACTIONS(3945),
    [anon_sym_EXIT] = ACTIONS(3945),
    [anon_sym_Exit] = ACTIONS(3945),
    [anon_sym_continue] = ACTIONS(3945),
    [anon_sym_CONTINUE] = ACTIONS(3945),
    [anon_sym_Continue] = ACTIONS(3945),
    [anon_sym_break] = ACTIONS(3945),
    [anon_sym_BREAK] = ACTIONS(3945),
    [anon_sym_Break] = ACTIONS(3945),
    [anon_sym_with] = ACTIONS(3945),
    [anon_sym_WITH] = ACTIONS(3945),
    [anon_sym_With] = ACTIONS(3945),
    [sym_asserterror_keyword] = ACTIONS(3947),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_IN] = ACTIONS(3945),
    [anon_sym_In] = ACTIONS(3945),
    [sym_page_keyword] = ACTIONS(3945),
    [anon_sym_codeunit] = ACTIONS(3945),
    [anon_sym_CODEUNIT] = ACTIONS(3945),
    [anon_sym_Codeunit] = ACTIONS(3945),
    [anon_sym_CodeUnit] = ACTIONS(3945),
    [anon_sym_COdeunit] = ACTIONS(3945),
    [anon_sym_codeUnit] = ACTIONS(3945),
    [sym_report_keyword] = ACTIONS(3945),
    [sym_query_keyword] = ACTIONS(3945),
    [anon_sym_xmlport] = ACTIONS(3945),
    [anon_sym_XMLPORT] = ACTIONS(3945),
    [anon_sym_Xmlport] = ACTIONS(3945),
    [anon_sym_XMLport] = ACTIONS(3945),
    [anon_sym_XMLPort] = ACTIONS(3945),
    [anon_sym_XmlPort] = ACTIONS(3945),
    [anon_sym_enum] = ACTIONS(3945),
    [anon_sym_ENUM] = ACTIONS(3945),
    [anon_sym_Enum] = ACTIONS(3945),
    [anon_sym_eNUM] = ACTIONS(3945),
    [anon_sym_eNum] = ACTIONS(3945),
    [anon_sym_ENum] = ACTIONS(3945),
    [sym_quoted_identifier] = ACTIONS(3947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3947),
    [sym_verbatim_string] = ACTIONS(3947),
    [sym_integer] = ACTIONS(3945),
    [sym_continue_as_identifier] = ACTIONS(3947),
    [sym_preproc_open] = ACTIONS(3947),
  },
  [STATE(2007)] = {
    [sym_identifier] = ACTIONS(3885),
    [anon_sym_SEMI] = ACTIONS(3887),
    [anon_sym_DOT] = ACTIONS(3885),
    [anon_sym_EQ] = ACTIONS(3887),
    [anon_sym_DASH] = ACTIONS(3885),
    [aux_sym_boolean_token1] = ACTIONS(3885),
    [aux_sym_boolean_token2] = ACTIONS(3885),
    [sym_decimal] = ACTIONS(3885),
    [anon_sym_LPAREN] = ACTIONS(3887),
    [anon_sym_DOT_DOT] = ACTIONS(3887),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3885),
    [anon_sym_STAR] = ACTIONS(3885),
    [anon_sym_LBRACK] = ACTIONS(3887),
    [aux_sym_record_type_token1] = ACTIONS(3885),
    [aux_sym_basic_type_token21] = ACTIONS(3885),
    [aux_sym_basic_type_token22] = ACTIONS(3885),
    [aux_sym_basic_type_token48] = ACTIONS(3885),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3885),
    [anon_sym_POUNDif] = ACTIONS(3887),
    [anon_sym_POUNDIF] = ACTIONS(3887),
    [anon_sym_POUNDIf] = ACTIONS(3887),
    [anon_sym_not] = ACTIONS(3885),
    [anon_sym_NOT] = ACTIONS(3885),
    [anon_sym_Not] = ACTIONS(3885),
    [anon_sym_POUNDelse] = ACTIONS(3887),
    [anon_sym_POUNDELSE] = ACTIONS(3887),
    [anon_sym_POUNDElse] = ACTIONS(3887),
    [anon_sym_POUNDelse2] = ACTIONS(3887),
    [anon_sym_POUNDELSE2] = ACTIONS(3887),
    [anon_sym_POUNDElse2] = ACTIONS(3887),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3887),
    [aux_sym__expression_token1] = ACTIONS(3887),
    [aux_sym__expression_token2] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3885),
    [anon_sym_SLASH] = ACTIONS(3885),
    [anon_sym_div] = ACTIONS(3885),
    [anon_sym_DIV] = ACTIONS(3885),
    [anon_sym_Div] = ACTIONS(3885),
    [anon_sym_mod] = ACTIONS(3885),
    [anon_sym_MOD] = ACTIONS(3885),
    [anon_sym_Mod] = ACTIONS(3885),
    [anon_sym_PLUS] = ACTIONS(3885),
    [anon_sym_GT_EQ] = ACTIONS(3887),
    [anon_sym_LT_EQ] = ACTIONS(3887),
    [anon_sym_GT] = ACTIONS(3885),
    [anon_sym_LT] = ACTIONS(3885),
    [anon_sym_LT_GT] = ACTIONS(3887),
    [anon_sym_and] = ACTIONS(3885),
    [anon_sym_AND] = ACTIONS(3885),
    [anon_sym_And] = ACTIONS(3885),
    [anon_sym_or] = ACTIONS(3885),
    [anon_sym_OR] = ACTIONS(3885),
    [anon_sym_Or] = ACTIONS(3885),
    [anon_sym_xor] = ACTIONS(3885),
    [anon_sym_XOR] = ACTIONS(3885),
    [anon_sym_Xor] = ACTIONS(3885),
    [anon_sym_QMARK] = ACTIONS(3887),
    [sym_datetime_literal] = ACTIONS(3887),
    [sym_date_literal] = ACTIONS(3885),
    [sym_time_literal] = ACTIONS(3885),
    [sym_biginteger_literal] = ACTIONS(3887),
    [anon_sym_if] = ACTIONS(3885),
    [anon_sym_IF] = ACTIONS(3885),
    [anon_sym_If] = ACTIONS(3885),
    [anon_sym_else] = ACTIONS(3885),
    [anon_sym_ELSE] = ACTIONS(3885),
    [anon_sym_Else] = ACTIONS(3885),
    [anon_sym_case] = ACTIONS(3885),
    [anon_sym_CASE] = ACTIONS(3885),
    [anon_sym_Case] = ACTIONS(3885),
    [anon_sym_for] = ACTIONS(3885),
    [anon_sym_FOR] = ACTIONS(3885),
    [anon_sym_For] = ACTIONS(3885),
    [anon_sym_foreach] = ACTIONS(3885),
    [anon_sym_FOREACH] = ACTIONS(3885),
    [anon_sym_Foreach] = ACTIONS(3885),
    [anon_sym_while] = ACTIONS(3885),
    [anon_sym_WHILE] = ACTIONS(3885),
    [anon_sym_While] = ACTIONS(3885),
    [anon_sym_repeat] = ACTIONS(3885),
    [anon_sym_REPEAT] = ACTIONS(3885),
    [anon_sym_Repeat] = ACTIONS(3885),
    [anon_sym_until] = ACTIONS(3885),
    [anon_sym_UNTIL] = ACTIONS(3885),
    [anon_sym_Until] = ACTIONS(3885),
    [anon_sym_exit] = ACTIONS(3885),
    [anon_sym_EXIT] = ACTIONS(3885),
    [anon_sym_Exit] = ACTIONS(3885),
    [anon_sym_continue] = ACTIONS(3885),
    [anon_sym_CONTINUE] = ACTIONS(3885),
    [anon_sym_Continue] = ACTIONS(3885),
    [anon_sym_break] = ACTIONS(3885),
    [anon_sym_BREAK] = ACTIONS(3885),
    [anon_sym_Break] = ACTIONS(3885),
    [anon_sym_with] = ACTIONS(3885),
    [anon_sym_WITH] = ACTIONS(3885),
    [anon_sym_With] = ACTIONS(3885),
    [sym_asserterror_keyword] = ACTIONS(3887),
    [anon_sym_in] = ACTIONS(3885),
    [anon_sym_IN] = ACTIONS(3885),
    [anon_sym_In] = ACTIONS(3885),
    [sym_page_keyword] = ACTIONS(3885),
    [anon_sym_codeunit] = ACTIONS(3885),
    [anon_sym_CODEUNIT] = ACTIONS(3885),
    [anon_sym_Codeunit] = ACTIONS(3885),
    [anon_sym_CodeUnit] = ACTIONS(3885),
    [anon_sym_COdeunit] = ACTIONS(3885),
    [anon_sym_codeUnit] = ACTIONS(3885),
    [sym_report_keyword] = ACTIONS(3885),
    [sym_query_keyword] = ACTIONS(3885),
    [anon_sym_xmlport] = ACTIONS(3885),
    [anon_sym_XMLPORT] = ACTIONS(3885),
    [anon_sym_Xmlport] = ACTIONS(3885),
    [anon_sym_XMLport] = ACTIONS(3885),
    [anon_sym_XMLPort] = ACTIONS(3885),
    [anon_sym_XmlPort] = ACTIONS(3885),
    [anon_sym_enum] = ACTIONS(3885),
    [anon_sym_ENUM] = ACTIONS(3885),
    [anon_sym_Enum] = ACTIONS(3885),
    [anon_sym_eNUM] = ACTIONS(3885),
    [anon_sym_eNum] = ACTIONS(3885),
    [anon_sym_ENum] = ACTIONS(3885),
    [sym_quoted_identifier] = ACTIONS(3887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3887),
    [sym_verbatim_string] = ACTIONS(3887),
    [sym_integer] = ACTIONS(3885),
    [sym_continue_as_identifier] = ACTIONS(3887),
    [sym_preproc_open] = ACTIONS(3887),
  },
  [STATE(2008)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_until] = ACTIONS(3865),
    [anon_sym_UNTIL] = ACTIONS(3865),
    [anon_sym_Until] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
  },
  [STATE(2009)] = {
    [sym_identifier] = ACTIONS(3881),
    [anon_sym_SEMI] = ACTIONS(3883),
    [anon_sym_DOT] = ACTIONS(3881),
    [anon_sym_EQ] = ACTIONS(3883),
    [anon_sym_DASH] = ACTIONS(3881),
    [aux_sym_boolean_token1] = ACTIONS(3881),
    [aux_sym_boolean_token2] = ACTIONS(3881),
    [sym_decimal] = ACTIONS(3881),
    [anon_sym_LPAREN] = ACTIONS(3883),
    [anon_sym_DOT_DOT] = ACTIONS(3883),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3881),
    [anon_sym_STAR] = ACTIONS(3881),
    [anon_sym_LBRACK] = ACTIONS(3883),
    [aux_sym_record_type_token1] = ACTIONS(3881),
    [aux_sym_basic_type_token21] = ACTIONS(3881),
    [aux_sym_basic_type_token22] = ACTIONS(3881),
    [aux_sym_basic_type_token48] = ACTIONS(3881),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3881),
    [anon_sym_POUNDif] = ACTIONS(3883),
    [anon_sym_POUNDIF] = ACTIONS(3883),
    [anon_sym_POUNDIf] = ACTIONS(3883),
    [anon_sym_not] = ACTIONS(3881),
    [anon_sym_NOT] = ACTIONS(3881),
    [anon_sym_Not] = ACTIONS(3881),
    [anon_sym_POUNDelse] = ACTIONS(3883),
    [anon_sym_POUNDELSE] = ACTIONS(3883),
    [anon_sym_POUNDElse] = ACTIONS(3883),
    [anon_sym_POUNDelse2] = ACTIONS(3883),
    [anon_sym_POUNDELSE2] = ACTIONS(3883),
    [anon_sym_POUNDElse2] = ACTIONS(3883),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3883),
    [aux_sym__expression_token1] = ACTIONS(3883),
    [aux_sym__expression_token2] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3881),
    [anon_sym_SLASH] = ACTIONS(3881),
    [anon_sym_div] = ACTIONS(3881),
    [anon_sym_DIV] = ACTIONS(3881),
    [anon_sym_Div] = ACTIONS(3881),
    [anon_sym_mod] = ACTIONS(3881),
    [anon_sym_MOD] = ACTIONS(3881),
    [anon_sym_Mod] = ACTIONS(3881),
    [anon_sym_PLUS] = ACTIONS(3881),
    [anon_sym_GT_EQ] = ACTIONS(3883),
    [anon_sym_LT_EQ] = ACTIONS(3883),
    [anon_sym_GT] = ACTIONS(3881),
    [anon_sym_LT] = ACTIONS(3881),
    [anon_sym_LT_GT] = ACTIONS(3883),
    [anon_sym_and] = ACTIONS(3881),
    [anon_sym_AND] = ACTIONS(3881),
    [anon_sym_And] = ACTIONS(3881),
    [anon_sym_or] = ACTIONS(3881),
    [anon_sym_OR] = ACTIONS(3881),
    [anon_sym_Or] = ACTIONS(3881),
    [anon_sym_xor] = ACTIONS(3881),
    [anon_sym_XOR] = ACTIONS(3881),
    [anon_sym_Xor] = ACTIONS(3881),
    [anon_sym_QMARK] = ACTIONS(3883),
    [sym_datetime_literal] = ACTIONS(3883),
    [sym_date_literal] = ACTIONS(3881),
    [sym_time_literal] = ACTIONS(3881),
    [sym_biginteger_literal] = ACTIONS(3883),
    [anon_sym_if] = ACTIONS(3881),
    [anon_sym_IF] = ACTIONS(3881),
    [anon_sym_If] = ACTIONS(3881),
    [anon_sym_else] = ACTIONS(3881),
    [anon_sym_ELSE] = ACTIONS(3881),
    [anon_sym_Else] = ACTIONS(3881),
    [anon_sym_case] = ACTIONS(3881),
    [anon_sym_CASE] = ACTIONS(3881),
    [anon_sym_Case] = ACTIONS(3881),
    [anon_sym_for] = ACTIONS(3881),
    [anon_sym_FOR] = ACTIONS(3881),
    [anon_sym_For] = ACTIONS(3881),
    [anon_sym_foreach] = ACTIONS(3881),
    [anon_sym_FOREACH] = ACTIONS(3881),
    [anon_sym_Foreach] = ACTIONS(3881),
    [anon_sym_while] = ACTIONS(3881),
    [anon_sym_WHILE] = ACTIONS(3881),
    [anon_sym_While] = ACTIONS(3881),
    [anon_sym_repeat] = ACTIONS(3881),
    [anon_sym_REPEAT] = ACTIONS(3881),
    [anon_sym_Repeat] = ACTIONS(3881),
    [anon_sym_until] = ACTIONS(3881),
    [anon_sym_UNTIL] = ACTIONS(3881),
    [anon_sym_Until] = ACTIONS(3881),
    [anon_sym_exit] = ACTIONS(3881),
    [anon_sym_EXIT] = ACTIONS(3881),
    [anon_sym_Exit] = ACTIONS(3881),
    [anon_sym_continue] = ACTIONS(3881),
    [anon_sym_CONTINUE] = ACTIONS(3881),
    [anon_sym_Continue] = ACTIONS(3881),
    [anon_sym_break] = ACTIONS(3881),
    [anon_sym_BREAK] = ACTIONS(3881),
    [anon_sym_Break] = ACTIONS(3881),
    [anon_sym_with] = ACTIONS(3881),
    [anon_sym_WITH] = ACTIONS(3881),
    [anon_sym_With] = ACTIONS(3881),
    [sym_asserterror_keyword] = ACTIONS(3883),
    [anon_sym_in] = ACTIONS(3881),
    [anon_sym_IN] = ACTIONS(3881),
    [anon_sym_In] = ACTIONS(3881),
    [sym_page_keyword] = ACTIONS(3881),
    [anon_sym_codeunit] = ACTIONS(3881),
    [anon_sym_CODEUNIT] = ACTIONS(3881),
    [anon_sym_Codeunit] = ACTIONS(3881),
    [anon_sym_CodeUnit] = ACTIONS(3881),
    [anon_sym_COdeunit] = ACTIONS(3881),
    [anon_sym_codeUnit] = ACTIONS(3881),
    [sym_report_keyword] = ACTIONS(3881),
    [sym_query_keyword] = ACTIONS(3881),
    [anon_sym_xmlport] = ACTIONS(3881),
    [anon_sym_XMLPORT] = ACTIONS(3881),
    [anon_sym_Xmlport] = ACTIONS(3881),
    [anon_sym_XMLport] = ACTIONS(3881),
    [anon_sym_XMLPort] = ACTIONS(3881),
    [anon_sym_XmlPort] = ACTIONS(3881),
    [anon_sym_enum] = ACTIONS(3881),
    [anon_sym_ENUM] = ACTIONS(3881),
    [anon_sym_Enum] = ACTIONS(3881),
    [anon_sym_eNUM] = ACTIONS(3881),
    [anon_sym_eNum] = ACTIONS(3881),
    [anon_sym_ENum] = ACTIONS(3881),
    [sym_quoted_identifier] = ACTIONS(3883),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3883),
    [sym_verbatim_string] = ACTIONS(3883),
    [sym_integer] = ACTIONS(3881),
    [sym_continue_as_identifier] = ACTIONS(3883),
    [sym_preproc_open] = ACTIONS(3883),
  },
  [STATE(2010)] = {
    [sym_identifier] = ACTIONS(3889),
    [anon_sym_SEMI] = ACTIONS(3891),
    [anon_sym_DOT] = ACTIONS(3889),
    [anon_sym_EQ] = ACTIONS(3891),
    [anon_sym_DASH] = ACTIONS(3889),
    [aux_sym_boolean_token1] = ACTIONS(3889),
    [aux_sym_boolean_token2] = ACTIONS(3889),
    [sym_decimal] = ACTIONS(3889),
    [anon_sym_LPAREN] = ACTIONS(3891),
    [anon_sym_DOT_DOT] = ACTIONS(3891),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3889),
    [anon_sym_STAR] = ACTIONS(3889),
    [anon_sym_LBRACK] = ACTIONS(3891),
    [aux_sym_record_type_token1] = ACTIONS(3889),
    [aux_sym_basic_type_token21] = ACTIONS(3889),
    [aux_sym_basic_type_token22] = ACTIONS(3889),
    [aux_sym_basic_type_token48] = ACTIONS(3889),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3889),
    [anon_sym_POUNDif] = ACTIONS(3891),
    [anon_sym_POUNDIF] = ACTIONS(3891),
    [anon_sym_POUNDIf] = ACTIONS(3891),
    [anon_sym_not] = ACTIONS(3889),
    [anon_sym_NOT] = ACTIONS(3889),
    [anon_sym_Not] = ACTIONS(3889),
    [anon_sym_POUNDelse] = ACTIONS(3891),
    [anon_sym_POUNDELSE] = ACTIONS(3891),
    [anon_sym_POUNDElse] = ACTIONS(3891),
    [anon_sym_POUNDelse2] = ACTIONS(3891),
    [anon_sym_POUNDELSE2] = ACTIONS(3891),
    [anon_sym_POUNDElse2] = ACTIONS(3891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3891),
    [aux_sym__expression_token1] = ACTIONS(3891),
    [aux_sym__expression_token2] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3889),
    [anon_sym_SLASH] = ACTIONS(3889),
    [anon_sym_div] = ACTIONS(3889),
    [anon_sym_DIV] = ACTIONS(3889),
    [anon_sym_Div] = ACTIONS(3889),
    [anon_sym_mod] = ACTIONS(3889),
    [anon_sym_MOD] = ACTIONS(3889),
    [anon_sym_Mod] = ACTIONS(3889),
    [anon_sym_PLUS] = ACTIONS(3889),
    [anon_sym_GT_EQ] = ACTIONS(3891),
    [anon_sym_LT_EQ] = ACTIONS(3891),
    [anon_sym_GT] = ACTIONS(3889),
    [anon_sym_LT] = ACTIONS(3889),
    [anon_sym_LT_GT] = ACTIONS(3891),
    [anon_sym_and] = ACTIONS(3889),
    [anon_sym_AND] = ACTIONS(3889),
    [anon_sym_And] = ACTIONS(3889),
    [anon_sym_or] = ACTIONS(3889),
    [anon_sym_OR] = ACTIONS(3889),
    [anon_sym_Or] = ACTIONS(3889),
    [anon_sym_xor] = ACTIONS(3889),
    [anon_sym_XOR] = ACTIONS(3889),
    [anon_sym_Xor] = ACTIONS(3889),
    [anon_sym_QMARK] = ACTIONS(3891),
    [sym_datetime_literal] = ACTIONS(3891),
    [sym_date_literal] = ACTIONS(3889),
    [sym_time_literal] = ACTIONS(3889),
    [sym_biginteger_literal] = ACTIONS(3891),
    [anon_sym_if] = ACTIONS(3889),
    [anon_sym_IF] = ACTIONS(3889),
    [anon_sym_If] = ACTIONS(3889),
    [anon_sym_else] = ACTIONS(3889),
    [anon_sym_ELSE] = ACTIONS(3889),
    [anon_sym_Else] = ACTIONS(3889),
    [anon_sym_case] = ACTIONS(3889),
    [anon_sym_CASE] = ACTIONS(3889),
    [anon_sym_Case] = ACTIONS(3889),
    [anon_sym_for] = ACTIONS(3889),
    [anon_sym_FOR] = ACTIONS(3889),
    [anon_sym_For] = ACTIONS(3889),
    [anon_sym_foreach] = ACTIONS(3889),
    [anon_sym_FOREACH] = ACTIONS(3889),
    [anon_sym_Foreach] = ACTIONS(3889),
    [anon_sym_while] = ACTIONS(3889),
    [anon_sym_WHILE] = ACTIONS(3889),
    [anon_sym_While] = ACTIONS(3889),
    [anon_sym_repeat] = ACTIONS(3889),
    [anon_sym_REPEAT] = ACTIONS(3889),
    [anon_sym_Repeat] = ACTIONS(3889),
    [anon_sym_until] = ACTIONS(3889),
    [anon_sym_UNTIL] = ACTIONS(3889),
    [anon_sym_Until] = ACTIONS(3889),
    [anon_sym_exit] = ACTIONS(3889),
    [anon_sym_EXIT] = ACTIONS(3889),
    [anon_sym_Exit] = ACTIONS(3889),
    [anon_sym_continue] = ACTIONS(3889),
    [anon_sym_CONTINUE] = ACTIONS(3889),
    [anon_sym_Continue] = ACTIONS(3889),
    [anon_sym_break] = ACTIONS(3889),
    [anon_sym_BREAK] = ACTIONS(3889),
    [anon_sym_Break] = ACTIONS(3889),
    [anon_sym_with] = ACTIONS(3889),
    [anon_sym_WITH] = ACTIONS(3889),
    [anon_sym_With] = ACTIONS(3889),
    [sym_asserterror_keyword] = ACTIONS(3891),
    [anon_sym_in] = ACTIONS(3889),
    [anon_sym_IN] = ACTIONS(3889),
    [anon_sym_In] = ACTIONS(3889),
    [sym_page_keyword] = ACTIONS(3889),
    [anon_sym_codeunit] = ACTIONS(3889),
    [anon_sym_CODEUNIT] = ACTIONS(3889),
    [anon_sym_Codeunit] = ACTIONS(3889),
    [anon_sym_CodeUnit] = ACTIONS(3889),
    [anon_sym_COdeunit] = ACTIONS(3889),
    [anon_sym_codeUnit] = ACTIONS(3889),
    [sym_report_keyword] = ACTIONS(3889),
    [sym_query_keyword] = ACTIONS(3889),
    [anon_sym_xmlport] = ACTIONS(3889),
    [anon_sym_XMLPORT] = ACTIONS(3889),
    [anon_sym_Xmlport] = ACTIONS(3889),
    [anon_sym_XMLport] = ACTIONS(3889),
    [anon_sym_XMLPort] = ACTIONS(3889),
    [anon_sym_XmlPort] = ACTIONS(3889),
    [anon_sym_enum] = ACTIONS(3889),
    [anon_sym_ENUM] = ACTIONS(3889),
    [anon_sym_Enum] = ACTIONS(3889),
    [anon_sym_eNUM] = ACTIONS(3889),
    [anon_sym_eNum] = ACTIONS(3889),
    [anon_sym_ENum] = ACTIONS(3889),
    [sym_quoted_identifier] = ACTIONS(3891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3891),
    [sym_verbatim_string] = ACTIONS(3891),
    [sym_integer] = ACTIONS(3889),
    [sym_continue_as_identifier] = ACTIONS(3891),
    [sym_preproc_open] = ACTIONS(3891),
  },
  [STATE(2011)] = {
    [sym_identifier] = ACTIONS(3893),
    [anon_sym_SEMI] = ACTIONS(3895),
    [anon_sym_DOT] = ACTIONS(3893),
    [anon_sym_EQ] = ACTIONS(3895),
    [anon_sym_DASH] = ACTIONS(3893),
    [aux_sym_boolean_token1] = ACTIONS(3893),
    [aux_sym_boolean_token2] = ACTIONS(3893),
    [sym_decimal] = ACTIONS(3893),
    [anon_sym_LPAREN] = ACTIONS(3895),
    [anon_sym_DOT_DOT] = ACTIONS(3895),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3893),
    [anon_sym_STAR] = ACTIONS(3893),
    [anon_sym_LBRACK] = ACTIONS(3895),
    [aux_sym_record_type_token1] = ACTIONS(3893),
    [aux_sym_basic_type_token21] = ACTIONS(3893),
    [aux_sym_basic_type_token22] = ACTIONS(3893),
    [aux_sym_basic_type_token48] = ACTIONS(3893),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3893),
    [anon_sym_POUNDif] = ACTIONS(3895),
    [anon_sym_POUNDIF] = ACTIONS(3895),
    [anon_sym_POUNDIf] = ACTIONS(3895),
    [anon_sym_not] = ACTIONS(3893),
    [anon_sym_NOT] = ACTIONS(3893),
    [anon_sym_Not] = ACTIONS(3893),
    [anon_sym_POUNDelse] = ACTIONS(3895),
    [anon_sym_POUNDELSE] = ACTIONS(3895),
    [anon_sym_POUNDElse] = ACTIONS(3895),
    [anon_sym_POUNDelse2] = ACTIONS(3895),
    [anon_sym_POUNDELSE2] = ACTIONS(3895),
    [anon_sym_POUNDElse2] = ACTIONS(3895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3895),
    [aux_sym__expression_token1] = ACTIONS(3895),
    [aux_sym__expression_token2] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3893),
    [anon_sym_SLASH] = ACTIONS(3893),
    [anon_sym_div] = ACTIONS(3893),
    [anon_sym_DIV] = ACTIONS(3893),
    [anon_sym_Div] = ACTIONS(3893),
    [anon_sym_mod] = ACTIONS(3893),
    [anon_sym_MOD] = ACTIONS(3893),
    [anon_sym_Mod] = ACTIONS(3893),
    [anon_sym_PLUS] = ACTIONS(3893),
    [anon_sym_GT_EQ] = ACTIONS(3895),
    [anon_sym_LT_EQ] = ACTIONS(3895),
    [anon_sym_GT] = ACTIONS(3893),
    [anon_sym_LT] = ACTIONS(3893),
    [anon_sym_LT_GT] = ACTIONS(3895),
    [anon_sym_and] = ACTIONS(3893),
    [anon_sym_AND] = ACTIONS(3893),
    [anon_sym_And] = ACTIONS(3893),
    [anon_sym_or] = ACTIONS(3893),
    [anon_sym_OR] = ACTIONS(3893),
    [anon_sym_Or] = ACTIONS(3893),
    [anon_sym_xor] = ACTIONS(3893),
    [anon_sym_XOR] = ACTIONS(3893),
    [anon_sym_Xor] = ACTIONS(3893),
    [anon_sym_QMARK] = ACTIONS(3895),
    [sym_datetime_literal] = ACTIONS(3895),
    [sym_date_literal] = ACTIONS(3893),
    [sym_time_literal] = ACTIONS(3893),
    [sym_biginteger_literal] = ACTIONS(3895),
    [anon_sym_if] = ACTIONS(3893),
    [anon_sym_IF] = ACTIONS(3893),
    [anon_sym_If] = ACTIONS(3893),
    [anon_sym_else] = ACTIONS(3893),
    [anon_sym_ELSE] = ACTIONS(3893),
    [anon_sym_Else] = ACTIONS(3893),
    [anon_sym_case] = ACTIONS(3893),
    [anon_sym_CASE] = ACTIONS(3893),
    [anon_sym_Case] = ACTIONS(3893),
    [anon_sym_for] = ACTIONS(3893),
    [anon_sym_FOR] = ACTIONS(3893),
    [anon_sym_For] = ACTIONS(3893),
    [anon_sym_foreach] = ACTIONS(3893),
    [anon_sym_FOREACH] = ACTIONS(3893),
    [anon_sym_Foreach] = ACTIONS(3893),
    [anon_sym_while] = ACTIONS(3893),
    [anon_sym_WHILE] = ACTIONS(3893),
    [anon_sym_While] = ACTIONS(3893),
    [anon_sym_repeat] = ACTIONS(3893),
    [anon_sym_REPEAT] = ACTIONS(3893),
    [anon_sym_Repeat] = ACTIONS(3893),
    [anon_sym_until] = ACTIONS(3893),
    [anon_sym_UNTIL] = ACTIONS(3893),
    [anon_sym_Until] = ACTIONS(3893),
    [anon_sym_exit] = ACTIONS(3893),
    [anon_sym_EXIT] = ACTIONS(3893),
    [anon_sym_Exit] = ACTIONS(3893),
    [anon_sym_continue] = ACTIONS(3893),
    [anon_sym_CONTINUE] = ACTIONS(3893),
    [anon_sym_Continue] = ACTIONS(3893),
    [anon_sym_break] = ACTIONS(3893),
    [anon_sym_BREAK] = ACTIONS(3893),
    [anon_sym_Break] = ACTIONS(3893),
    [anon_sym_with] = ACTIONS(3893),
    [anon_sym_WITH] = ACTIONS(3893),
    [anon_sym_With] = ACTIONS(3893),
    [sym_asserterror_keyword] = ACTIONS(3895),
    [anon_sym_in] = ACTIONS(3893),
    [anon_sym_IN] = ACTIONS(3893),
    [anon_sym_In] = ACTIONS(3893),
    [sym_page_keyword] = ACTIONS(3893),
    [anon_sym_codeunit] = ACTIONS(3893),
    [anon_sym_CODEUNIT] = ACTIONS(3893),
    [anon_sym_Codeunit] = ACTIONS(3893),
    [anon_sym_CodeUnit] = ACTIONS(3893),
    [anon_sym_COdeunit] = ACTIONS(3893),
    [anon_sym_codeUnit] = ACTIONS(3893),
    [sym_report_keyword] = ACTIONS(3893),
    [sym_query_keyword] = ACTIONS(3893),
    [anon_sym_xmlport] = ACTIONS(3893),
    [anon_sym_XMLPORT] = ACTIONS(3893),
    [anon_sym_Xmlport] = ACTIONS(3893),
    [anon_sym_XMLport] = ACTIONS(3893),
    [anon_sym_XMLPort] = ACTIONS(3893),
    [anon_sym_XmlPort] = ACTIONS(3893),
    [anon_sym_enum] = ACTIONS(3893),
    [anon_sym_ENUM] = ACTIONS(3893),
    [anon_sym_Enum] = ACTIONS(3893),
    [anon_sym_eNUM] = ACTIONS(3893),
    [anon_sym_eNum] = ACTIONS(3893),
    [anon_sym_ENum] = ACTIONS(3893),
    [sym_quoted_identifier] = ACTIONS(3895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3895),
    [sym_verbatim_string] = ACTIONS(3895),
    [sym_integer] = ACTIONS(3893),
    [sym_continue_as_identifier] = ACTIONS(3895),
    [sym_preproc_open] = ACTIONS(3895),
  },
  [STATE(2012)] = {
    [sym_identifier] = ACTIONS(3897),
    [anon_sym_SEMI] = ACTIONS(3899),
    [anon_sym_DOT] = ACTIONS(3897),
    [anon_sym_EQ] = ACTIONS(3899),
    [anon_sym_DASH] = ACTIONS(3897),
    [aux_sym_boolean_token1] = ACTIONS(3897),
    [aux_sym_boolean_token2] = ACTIONS(3897),
    [sym_decimal] = ACTIONS(3897),
    [anon_sym_LPAREN] = ACTIONS(3899),
    [anon_sym_DOT_DOT] = ACTIONS(3899),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3897),
    [anon_sym_STAR] = ACTIONS(3897),
    [anon_sym_LBRACK] = ACTIONS(3899),
    [aux_sym_record_type_token1] = ACTIONS(3897),
    [aux_sym_basic_type_token21] = ACTIONS(3897),
    [aux_sym_basic_type_token22] = ACTIONS(3897),
    [aux_sym_basic_type_token48] = ACTIONS(3897),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3897),
    [anon_sym_POUNDif] = ACTIONS(3899),
    [anon_sym_POUNDIF] = ACTIONS(3899),
    [anon_sym_POUNDIf] = ACTIONS(3899),
    [anon_sym_not] = ACTIONS(3897),
    [anon_sym_NOT] = ACTIONS(3897),
    [anon_sym_Not] = ACTIONS(3897),
    [anon_sym_POUNDelse] = ACTIONS(3899),
    [anon_sym_POUNDELSE] = ACTIONS(3899),
    [anon_sym_POUNDElse] = ACTIONS(3899),
    [anon_sym_POUNDelse2] = ACTIONS(3899),
    [anon_sym_POUNDELSE2] = ACTIONS(3899),
    [anon_sym_POUNDElse2] = ACTIONS(3899),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3899),
    [aux_sym__expression_token1] = ACTIONS(3899),
    [aux_sym__expression_token2] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3897),
    [anon_sym_SLASH] = ACTIONS(3897),
    [anon_sym_div] = ACTIONS(3897),
    [anon_sym_DIV] = ACTIONS(3897),
    [anon_sym_Div] = ACTIONS(3897),
    [anon_sym_mod] = ACTIONS(3897),
    [anon_sym_MOD] = ACTIONS(3897),
    [anon_sym_Mod] = ACTIONS(3897),
    [anon_sym_PLUS] = ACTIONS(3897),
    [anon_sym_GT_EQ] = ACTIONS(3899),
    [anon_sym_LT_EQ] = ACTIONS(3899),
    [anon_sym_GT] = ACTIONS(3897),
    [anon_sym_LT] = ACTIONS(3897),
    [anon_sym_LT_GT] = ACTIONS(3899),
    [anon_sym_and] = ACTIONS(3897),
    [anon_sym_AND] = ACTIONS(3897),
    [anon_sym_And] = ACTIONS(3897),
    [anon_sym_or] = ACTIONS(3897),
    [anon_sym_OR] = ACTIONS(3897),
    [anon_sym_Or] = ACTIONS(3897),
    [anon_sym_xor] = ACTIONS(3897),
    [anon_sym_XOR] = ACTIONS(3897),
    [anon_sym_Xor] = ACTIONS(3897),
    [anon_sym_QMARK] = ACTIONS(3899),
    [sym_datetime_literal] = ACTIONS(3899),
    [sym_date_literal] = ACTIONS(3897),
    [sym_time_literal] = ACTIONS(3897),
    [sym_biginteger_literal] = ACTIONS(3899),
    [anon_sym_if] = ACTIONS(3897),
    [anon_sym_IF] = ACTIONS(3897),
    [anon_sym_If] = ACTIONS(3897),
    [anon_sym_else] = ACTIONS(3897),
    [anon_sym_ELSE] = ACTIONS(3897),
    [anon_sym_Else] = ACTIONS(3897),
    [anon_sym_case] = ACTIONS(3897),
    [anon_sym_CASE] = ACTIONS(3897),
    [anon_sym_Case] = ACTIONS(3897),
    [anon_sym_for] = ACTIONS(3897),
    [anon_sym_FOR] = ACTIONS(3897),
    [anon_sym_For] = ACTIONS(3897),
    [anon_sym_foreach] = ACTIONS(3897),
    [anon_sym_FOREACH] = ACTIONS(3897),
    [anon_sym_Foreach] = ACTIONS(3897),
    [anon_sym_while] = ACTIONS(3897),
    [anon_sym_WHILE] = ACTIONS(3897),
    [anon_sym_While] = ACTIONS(3897),
    [anon_sym_repeat] = ACTIONS(3897),
    [anon_sym_REPEAT] = ACTIONS(3897),
    [anon_sym_Repeat] = ACTIONS(3897),
    [anon_sym_until] = ACTIONS(3897),
    [anon_sym_UNTIL] = ACTIONS(3897),
    [anon_sym_Until] = ACTIONS(3897),
    [anon_sym_exit] = ACTIONS(3897),
    [anon_sym_EXIT] = ACTIONS(3897),
    [anon_sym_Exit] = ACTIONS(3897),
    [anon_sym_continue] = ACTIONS(3897),
    [anon_sym_CONTINUE] = ACTIONS(3897),
    [anon_sym_Continue] = ACTIONS(3897),
    [anon_sym_break] = ACTIONS(3897),
    [anon_sym_BREAK] = ACTIONS(3897),
    [anon_sym_Break] = ACTIONS(3897),
    [anon_sym_with] = ACTIONS(3897),
    [anon_sym_WITH] = ACTIONS(3897),
    [anon_sym_With] = ACTIONS(3897),
    [sym_asserterror_keyword] = ACTIONS(3899),
    [anon_sym_in] = ACTIONS(3897),
    [anon_sym_IN] = ACTIONS(3897),
    [anon_sym_In] = ACTIONS(3897),
    [sym_page_keyword] = ACTIONS(3897),
    [anon_sym_codeunit] = ACTIONS(3897),
    [anon_sym_CODEUNIT] = ACTIONS(3897),
    [anon_sym_Codeunit] = ACTIONS(3897),
    [anon_sym_CodeUnit] = ACTIONS(3897),
    [anon_sym_COdeunit] = ACTIONS(3897),
    [anon_sym_codeUnit] = ACTIONS(3897),
    [sym_report_keyword] = ACTIONS(3897),
    [sym_query_keyword] = ACTIONS(3897),
    [anon_sym_xmlport] = ACTIONS(3897),
    [anon_sym_XMLPORT] = ACTIONS(3897),
    [anon_sym_Xmlport] = ACTIONS(3897),
    [anon_sym_XMLport] = ACTIONS(3897),
    [anon_sym_XMLPort] = ACTIONS(3897),
    [anon_sym_XmlPort] = ACTIONS(3897),
    [anon_sym_enum] = ACTIONS(3897),
    [anon_sym_ENUM] = ACTIONS(3897),
    [anon_sym_Enum] = ACTIONS(3897),
    [anon_sym_eNUM] = ACTIONS(3897),
    [anon_sym_eNum] = ACTIONS(3897),
    [anon_sym_ENum] = ACTIONS(3897),
    [sym_quoted_identifier] = ACTIONS(3899),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3899),
    [sym_verbatim_string] = ACTIONS(3899),
    [sym_integer] = ACTIONS(3897),
    [sym_continue_as_identifier] = ACTIONS(3899),
    [sym_preproc_open] = ACTIONS(3899),
  },
  [STATE(2013)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(3661),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(2014)] = {
    [sym_identifier] = ACTIONS(3901),
    [anon_sym_SEMI] = ACTIONS(3903),
    [anon_sym_DOT] = ACTIONS(3901),
    [anon_sym_EQ] = ACTIONS(3903),
    [anon_sym_DASH] = ACTIONS(3901),
    [aux_sym_boolean_token1] = ACTIONS(3901),
    [aux_sym_boolean_token2] = ACTIONS(3901),
    [sym_decimal] = ACTIONS(3901),
    [anon_sym_LPAREN] = ACTIONS(3903),
    [anon_sym_DOT_DOT] = ACTIONS(3903),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3901),
    [anon_sym_STAR] = ACTIONS(3901),
    [anon_sym_LBRACK] = ACTIONS(3903),
    [aux_sym_record_type_token1] = ACTIONS(3901),
    [aux_sym_basic_type_token21] = ACTIONS(3901),
    [aux_sym_basic_type_token22] = ACTIONS(3901),
    [aux_sym_basic_type_token48] = ACTIONS(3901),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3901),
    [anon_sym_POUNDif] = ACTIONS(3903),
    [anon_sym_POUNDIF] = ACTIONS(3903),
    [anon_sym_POUNDIf] = ACTIONS(3903),
    [anon_sym_not] = ACTIONS(3901),
    [anon_sym_NOT] = ACTIONS(3901),
    [anon_sym_Not] = ACTIONS(3901),
    [anon_sym_POUNDelse] = ACTIONS(3903),
    [anon_sym_POUNDELSE] = ACTIONS(3903),
    [anon_sym_POUNDElse] = ACTIONS(3903),
    [anon_sym_POUNDelse2] = ACTIONS(3903),
    [anon_sym_POUNDELSE2] = ACTIONS(3903),
    [anon_sym_POUNDElse2] = ACTIONS(3903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3903),
    [aux_sym__expression_token1] = ACTIONS(3903),
    [aux_sym__expression_token2] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3901),
    [anon_sym_SLASH] = ACTIONS(3901),
    [anon_sym_div] = ACTIONS(3901),
    [anon_sym_DIV] = ACTIONS(3901),
    [anon_sym_Div] = ACTIONS(3901),
    [anon_sym_mod] = ACTIONS(3901),
    [anon_sym_MOD] = ACTIONS(3901),
    [anon_sym_Mod] = ACTIONS(3901),
    [anon_sym_PLUS] = ACTIONS(3901),
    [anon_sym_GT_EQ] = ACTIONS(3903),
    [anon_sym_LT_EQ] = ACTIONS(3903),
    [anon_sym_GT] = ACTIONS(3901),
    [anon_sym_LT] = ACTIONS(3901),
    [anon_sym_LT_GT] = ACTIONS(3903),
    [anon_sym_and] = ACTIONS(3901),
    [anon_sym_AND] = ACTIONS(3901),
    [anon_sym_And] = ACTIONS(3901),
    [anon_sym_or] = ACTIONS(3901),
    [anon_sym_OR] = ACTIONS(3901),
    [anon_sym_Or] = ACTIONS(3901),
    [anon_sym_xor] = ACTIONS(3901),
    [anon_sym_XOR] = ACTIONS(3901),
    [anon_sym_Xor] = ACTIONS(3901),
    [anon_sym_QMARK] = ACTIONS(3903),
    [sym_datetime_literal] = ACTIONS(3903),
    [sym_date_literal] = ACTIONS(3901),
    [sym_time_literal] = ACTIONS(3901),
    [sym_biginteger_literal] = ACTIONS(3903),
    [anon_sym_if] = ACTIONS(3901),
    [anon_sym_IF] = ACTIONS(3901),
    [anon_sym_If] = ACTIONS(3901),
    [anon_sym_else] = ACTIONS(3901),
    [anon_sym_ELSE] = ACTIONS(3901),
    [anon_sym_Else] = ACTIONS(3901),
    [anon_sym_case] = ACTIONS(3901),
    [anon_sym_CASE] = ACTIONS(3901),
    [anon_sym_Case] = ACTIONS(3901),
    [anon_sym_for] = ACTIONS(3901),
    [anon_sym_FOR] = ACTIONS(3901),
    [anon_sym_For] = ACTIONS(3901),
    [anon_sym_foreach] = ACTIONS(3901),
    [anon_sym_FOREACH] = ACTIONS(3901),
    [anon_sym_Foreach] = ACTIONS(3901),
    [anon_sym_while] = ACTIONS(3901),
    [anon_sym_WHILE] = ACTIONS(3901),
    [anon_sym_While] = ACTIONS(3901),
    [anon_sym_repeat] = ACTIONS(3901),
    [anon_sym_REPEAT] = ACTIONS(3901),
    [anon_sym_Repeat] = ACTIONS(3901),
    [anon_sym_until] = ACTIONS(3901),
    [anon_sym_UNTIL] = ACTIONS(3901),
    [anon_sym_Until] = ACTIONS(3901),
    [anon_sym_exit] = ACTIONS(3901),
    [anon_sym_EXIT] = ACTIONS(3901),
    [anon_sym_Exit] = ACTIONS(3901),
    [anon_sym_continue] = ACTIONS(3901),
    [anon_sym_CONTINUE] = ACTIONS(3901),
    [anon_sym_Continue] = ACTIONS(3901),
    [anon_sym_break] = ACTIONS(3901),
    [anon_sym_BREAK] = ACTIONS(3901),
    [anon_sym_Break] = ACTIONS(3901),
    [anon_sym_with] = ACTIONS(3901),
    [anon_sym_WITH] = ACTIONS(3901),
    [anon_sym_With] = ACTIONS(3901),
    [sym_asserterror_keyword] = ACTIONS(3903),
    [anon_sym_in] = ACTIONS(3901),
    [anon_sym_IN] = ACTIONS(3901),
    [anon_sym_In] = ACTIONS(3901),
    [sym_page_keyword] = ACTIONS(3901),
    [anon_sym_codeunit] = ACTIONS(3901),
    [anon_sym_CODEUNIT] = ACTIONS(3901),
    [anon_sym_Codeunit] = ACTIONS(3901),
    [anon_sym_CodeUnit] = ACTIONS(3901),
    [anon_sym_COdeunit] = ACTIONS(3901),
    [anon_sym_codeUnit] = ACTIONS(3901),
    [sym_report_keyword] = ACTIONS(3901),
    [sym_query_keyword] = ACTIONS(3901),
    [anon_sym_xmlport] = ACTIONS(3901),
    [anon_sym_XMLPORT] = ACTIONS(3901),
    [anon_sym_Xmlport] = ACTIONS(3901),
    [anon_sym_XMLport] = ACTIONS(3901),
    [anon_sym_XMLPort] = ACTIONS(3901),
    [anon_sym_XmlPort] = ACTIONS(3901),
    [anon_sym_enum] = ACTIONS(3901),
    [anon_sym_ENUM] = ACTIONS(3901),
    [anon_sym_Enum] = ACTIONS(3901),
    [anon_sym_eNUM] = ACTIONS(3901),
    [anon_sym_eNum] = ACTIONS(3901),
    [anon_sym_ENum] = ACTIONS(3901),
    [sym_quoted_identifier] = ACTIONS(3903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3903),
    [sym_verbatim_string] = ACTIONS(3903),
    [sym_integer] = ACTIONS(3901),
    [sym_continue_as_identifier] = ACTIONS(3903),
    [sym_preproc_open] = ACTIONS(3903),
  },
  [STATE(2015)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_until] = ACTIONS(3873),
    [anon_sym_UNTIL] = ACTIONS(3873),
    [anon_sym_Until] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
  },
  [STATE(2016)] = {
    [sym_identifier] = ACTIONS(3925),
    [anon_sym_SEMI] = ACTIONS(3927),
    [anon_sym_DOT] = ACTIONS(3925),
    [anon_sym_EQ] = ACTIONS(3927),
    [anon_sym_DASH] = ACTIONS(3925),
    [aux_sym_boolean_token1] = ACTIONS(3925),
    [aux_sym_boolean_token2] = ACTIONS(3925),
    [sym_decimal] = ACTIONS(3925),
    [anon_sym_LPAREN] = ACTIONS(3927),
    [anon_sym_DOT_DOT] = ACTIONS(3927),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3925),
    [anon_sym_STAR] = ACTIONS(3925),
    [anon_sym_LBRACK] = ACTIONS(4348),
    [aux_sym_record_type_token1] = ACTIONS(3925),
    [aux_sym_basic_type_token21] = ACTIONS(3925),
    [aux_sym_basic_type_token22] = ACTIONS(3925),
    [aux_sym_basic_type_token48] = ACTIONS(3925),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3925),
    [anon_sym_POUNDif] = ACTIONS(3927),
    [anon_sym_POUNDIF] = ACTIONS(3927),
    [anon_sym_POUNDIf] = ACTIONS(3927),
    [anon_sym_not] = ACTIONS(3925),
    [anon_sym_NOT] = ACTIONS(3925),
    [anon_sym_Not] = ACTIONS(3925),
    [anon_sym_POUNDelse] = ACTIONS(3927),
    [anon_sym_POUNDELSE] = ACTIONS(3927),
    [anon_sym_POUNDElse] = ACTIONS(3927),
    [anon_sym_POUNDelse2] = ACTIONS(3927),
    [anon_sym_POUNDELSE2] = ACTIONS(3927),
    [anon_sym_POUNDElse2] = ACTIONS(3927),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3927),
    [aux_sym__expression_token1] = ACTIONS(3927),
    [aux_sym__expression_token2] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3925),
    [anon_sym_SLASH] = ACTIONS(3925),
    [anon_sym_div] = ACTIONS(3925),
    [anon_sym_DIV] = ACTIONS(3925),
    [anon_sym_Div] = ACTIONS(3925),
    [anon_sym_mod] = ACTIONS(3925),
    [anon_sym_MOD] = ACTIONS(3925),
    [anon_sym_Mod] = ACTIONS(3925),
    [anon_sym_PLUS] = ACTIONS(3925),
    [anon_sym_GT_EQ] = ACTIONS(3927),
    [anon_sym_LT_EQ] = ACTIONS(3927),
    [anon_sym_GT] = ACTIONS(3925),
    [anon_sym_LT] = ACTIONS(3925),
    [anon_sym_LT_GT] = ACTIONS(3927),
    [anon_sym_and] = ACTIONS(3925),
    [anon_sym_AND] = ACTIONS(3925),
    [anon_sym_And] = ACTIONS(3925),
    [anon_sym_or] = ACTIONS(3925),
    [anon_sym_OR] = ACTIONS(3925),
    [anon_sym_Or] = ACTIONS(3925),
    [anon_sym_xor] = ACTIONS(3925),
    [anon_sym_XOR] = ACTIONS(3925),
    [anon_sym_Xor] = ACTIONS(3925),
    [anon_sym_QMARK] = ACTIONS(3927),
    [sym_datetime_literal] = ACTIONS(3927),
    [sym_date_literal] = ACTIONS(3925),
    [sym_time_literal] = ACTIONS(3925),
    [sym_biginteger_literal] = ACTIONS(3927),
    [anon_sym_if] = ACTIONS(3925),
    [anon_sym_IF] = ACTIONS(3925),
    [anon_sym_If] = ACTIONS(3925),
    [anon_sym_else] = ACTIONS(3925),
    [anon_sym_ELSE] = ACTIONS(3925),
    [anon_sym_Else] = ACTIONS(3925),
    [anon_sym_case] = ACTIONS(3925),
    [anon_sym_CASE] = ACTIONS(3925),
    [anon_sym_Case] = ACTIONS(3925),
    [anon_sym_for] = ACTIONS(3925),
    [anon_sym_FOR] = ACTIONS(3925),
    [anon_sym_For] = ACTIONS(3925),
    [anon_sym_foreach] = ACTIONS(3925),
    [anon_sym_FOREACH] = ACTIONS(3925),
    [anon_sym_Foreach] = ACTIONS(3925),
    [anon_sym_while] = ACTIONS(3925),
    [anon_sym_WHILE] = ACTIONS(3925),
    [anon_sym_While] = ACTIONS(3925),
    [anon_sym_repeat] = ACTIONS(3925),
    [anon_sym_REPEAT] = ACTIONS(3925),
    [anon_sym_Repeat] = ACTIONS(3925),
    [anon_sym_until] = ACTIONS(3925),
    [anon_sym_UNTIL] = ACTIONS(3925),
    [anon_sym_Until] = ACTIONS(3925),
    [anon_sym_exit] = ACTIONS(3925),
    [anon_sym_EXIT] = ACTIONS(3925),
    [anon_sym_Exit] = ACTIONS(3925),
    [anon_sym_continue] = ACTIONS(3925),
    [anon_sym_CONTINUE] = ACTIONS(3925),
    [anon_sym_Continue] = ACTIONS(3925),
    [anon_sym_break] = ACTIONS(3925),
    [anon_sym_BREAK] = ACTIONS(3925),
    [anon_sym_Break] = ACTIONS(3925),
    [anon_sym_with] = ACTIONS(3925),
    [anon_sym_WITH] = ACTIONS(3925),
    [anon_sym_With] = ACTIONS(3925),
    [sym_asserterror_keyword] = ACTIONS(3927),
    [anon_sym_in] = ACTIONS(3925),
    [anon_sym_IN] = ACTIONS(3925),
    [anon_sym_In] = ACTIONS(3925),
    [sym_page_keyword] = ACTIONS(3925),
    [anon_sym_codeunit] = ACTIONS(3925),
    [anon_sym_CODEUNIT] = ACTIONS(3925),
    [anon_sym_Codeunit] = ACTIONS(3925),
    [anon_sym_CodeUnit] = ACTIONS(3925),
    [anon_sym_COdeunit] = ACTIONS(3925),
    [anon_sym_codeUnit] = ACTIONS(3925),
    [sym_report_keyword] = ACTIONS(3925),
    [sym_query_keyword] = ACTIONS(3925),
    [anon_sym_xmlport] = ACTIONS(3925),
    [anon_sym_XMLPORT] = ACTIONS(3925),
    [anon_sym_Xmlport] = ACTIONS(3925),
    [anon_sym_XMLport] = ACTIONS(3925),
    [anon_sym_XMLPort] = ACTIONS(3925),
    [anon_sym_XmlPort] = ACTIONS(3925),
    [anon_sym_enum] = ACTIONS(3925),
    [anon_sym_ENUM] = ACTIONS(3925),
    [anon_sym_Enum] = ACTIONS(3925),
    [anon_sym_eNUM] = ACTIONS(3925),
    [anon_sym_eNum] = ACTIONS(3925),
    [anon_sym_ENum] = ACTIONS(3925),
    [sym_quoted_identifier] = ACTIONS(3927),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3927),
    [sym_verbatim_string] = ACTIONS(3927),
    [sym_integer] = ACTIONS(3925),
    [sym_continue_as_identifier] = ACTIONS(3927),
    [sym_preproc_open] = ACTIONS(3927),
  },
  [STATE(2017)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_until] = ACTIONS(3873),
    [anon_sym_UNTIL] = ACTIONS(3873),
    [anon_sym_Until] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
  },
  [STATE(2018)] = {
    [sym_identifier] = ACTIONS(3905),
    [anon_sym_SEMI] = ACTIONS(3907),
    [anon_sym_DOT] = ACTIONS(3905),
    [anon_sym_EQ] = ACTIONS(3907),
    [anon_sym_DASH] = ACTIONS(3905),
    [aux_sym_boolean_token1] = ACTIONS(3905),
    [aux_sym_boolean_token2] = ACTIONS(3905),
    [sym_decimal] = ACTIONS(3905),
    [anon_sym_LPAREN] = ACTIONS(3907),
    [anon_sym_DOT_DOT] = ACTIONS(3907),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3905),
    [anon_sym_STAR] = ACTIONS(3905),
    [anon_sym_LBRACK] = ACTIONS(3907),
    [aux_sym_record_type_token1] = ACTIONS(3905),
    [aux_sym_basic_type_token21] = ACTIONS(3905),
    [aux_sym_basic_type_token22] = ACTIONS(3905),
    [aux_sym_basic_type_token48] = ACTIONS(3905),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3905),
    [anon_sym_POUNDif] = ACTIONS(3907),
    [anon_sym_POUNDIF] = ACTIONS(3907),
    [anon_sym_POUNDIf] = ACTIONS(3907),
    [anon_sym_not] = ACTIONS(3905),
    [anon_sym_NOT] = ACTIONS(3905),
    [anon_sym_Not] = ACTIONS(3905),
    [anon_sym_POUNDelse] = ACTIONS(3907),
    [anon_sym_POUNDELSE] = ACTIONS(3907),
    [anon_sym_POUNDElse] = ACTIONS(3907),
    [anon_sym_POUNDelse2] = ACTIONS(3907),
    [anon_sym_POUNDELSE2] = ACTIONS(3907),
    [anon_sym_POUNDElse2] = ACTIONS(3907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3907),
    [aux_sym__expression_token1] = ACTIONS(3907),
    [aux_sym__expression_token2] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3905),
    [anon_sym_SLASH] = ACTIONS(3905),
    [anon_sym_div] = ACTIONS(3905),
    [anon_sym_DIV] = ACTIONS(3905),
    [anon_sym_Div] = ACTIONS(3905),
    [anon_sym_mod] = ACTIONS(3905),
    [anon_sym_MOD] = ACTIONS(3905),
    [anon_sym_Mod] = ACTIONS(3905),
    [anon_sym_PLUS] = ACTIONS(3905),
    [anon_sym_GT_EQ] = ACTIONS(3907),
    [anon_sym_LT_EQ] = ACTIONS(3907),
    [anon_sym_GT] = ACTIONS(3905),
    [anon_sym_LT] = ACTIONS(3905),
    [anon_sym_LT_GT] = ACTIONS(3907),
    [anon_sym_and] = ACTIONS(3905),
    [anon_sym_AND] = ACTIONS(3905),
    [anon_sym_And] = ACTIONS(3905),
    [anon_sym_or] = ACTIONS(3905),
    [anon_sym_OR] = ACTIONS(3905),
    [anon_sym_Or] = ACTIONS(3905),
    [anon_sym_xor] = ACTIONS(3905),
    [anon_sym_XOR] = ACTIONS(3905),
    [anon_sym_Xor] = ACTIONS(3905),
    [anon_sym_QMARK] = ACTIONS(3907),
    [sym_datetime_literal] = ACTIONS(3907),
    [sym_date_literal] = ACTIONS(3905),
    [sym_time_literal] = ACTIONS(3905),
    [sym_biginteger_literal] = ACTIONS(3907),
    [anon_sym_if] = ACTIONS(3905),
    [anon_sym_IF] = ACTIONS(3905),
    [anon_sym_If] = ACTIONS(3905),
    [anon_sym_else] = ACTIONS(3905),
    [anon_sym_ELSE] = ACTIONS(3905),
    [anon_sym_Else] = ACTIONS(3905),
    [anon_sym_case] = ACTIONS(3905),
    [anon_sym_CASE] = ACTIONS(3905),
    [anon_sym_Case] = ACTIONS(3905),
    [anon_sym_for] = ACTIONS(3905),
    [anon_sym_FOR] = ACTIONS(3905),
    [anon_sym_For] = ACTIONS(3905),
    [anon_sym_foreach] = ACTIONS(3905),
    [anon_sym_FOREACH] = ACTIONS(3905),
    [anon_sym_Foreach] = ACTIONS(3905),
    [anon_sym_while] = ACTIONS(3905),
    [anon_sym_WHILE] = ACTIONS(3905),
    [anon_sym_While] = ACTIONS(3905),
    [anon_sym_repeat] = ACTIONS(3905),
    [anon_sym_REPEAT] = ACTIONS(3905),
    [anon_sym_Repeat] = ACTIONS(3905),
    [anon_sym_until] = ACTIONS(3905),
    [anon_sym_UNTIL] = ACTIONS(3905),
    [anon_sym_Until] = ACTIONS(3905),
    [anon_sym_exit] = ACTIONS(3905),
    [anon_sym_EXIT] = ACTIONS(3905),
    [anon_sym_Exit] = ACTIONS(3905),
    [anon_sym_continue] = ACTIONS(3905),
    [anon_sym_CONTINUE] = ACTIONS(3905),
    [anon_sym_Continue] = ACTIONS(3905),
    [anon_sym_break] = ACTIONS(3905),
    [anon_sym_BREAK] = ACTIONS(3905),
    [anon_sym_Break] = ACTIONS(3905),
    [anon_sym_with] = ACTIONS(3905),
    [anon_sym_WITH] = ACTIONS(3905),
    [anon_sym_With] = ACTIONS(3905),
    [sym_asserterror_keyword] = ACTIONS(3907),
    [anon_sym_in] = ACTIONS(3905),
    [anon_sym_IN] = ACTIONS(3905),
    [anon_sym_In] = ACTIONS(3905),
    [sym_page_keyword] = ACTIONS(3905),
    [anon_sym_codeunit] = ACTIONS(3905),
    [anon_sym_CODEUNIT] = ACTIONS(3905),
    [anon_sym_Codeunit] = ACTIONS(3905),
    [anon_sym_CodeUnit] = ACTIONS(3905),
    [anon_sym_COdeunit] = ACTIONS(3905),
    [anon_sym_codeUnit] = ACTIONS(3905),
    [sym_report_keyword] = ACTIONS(3905),
    [sym_query_keyword] = ACTIONS(3905),
    [anon_sym_xmlport] = ACTIONS(3905),
    [anon_sym_XMLPORT] = ACTIONS(3905),
    [anon_sym_Xmlport] = ACTIONS(3905),
    [anon_sym_XMLport] = ACTIONS(3905),
    [anon_sym_XMLPort] = ACTIONS(3905),
    [anon_sym_XmlPort] = ACTIONS(3905),
    [anon_sym_enum] = ACTIONS(3905),
    [anon_sym_ENUM] = ACTIONS(3905),
    [anon_sym_Enum] = ACTIONS(3905),
    [anon_sym_eNUM] = ACTIONS(3905),
    [anon_sym_eNum] = ACTIONS(3905),
    [anon_sym_ENum] = ACTIONS(3905),
    [sym_quoted_identifier] = ACTIONS(3907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3907),
    [sym_verbatim_string] = ACTIONS(3907),
    [sym_integer] = ACTIONS(3905),
    [sym_continue_as_identifier] = ACTIONS(3907),
    [sym_preproc_open] = ACTIONS(3907),
  },
  [STATE(2019)] = {
    [sym_identifier] = ACTIONS(3909),
    [anon_sym_SEMI] = ACTIONS(3911),
    [anon_sym_DOT] = ACTIONS(3909),
    [anon_sym_EQ] = ACTIONS(3911),
    [anon_sym_DASH] = ACTIONS(3909),
    [aux_sym_boolean_token1] = ACTIONS(3909),
    [aux_sym_boolean_token2] = ACTIONS(3909),
    [sym_decimal] = ACTIONS(3909),
    [anon_sym_LPAREN] = ACTIONS(3911),
    [anon_sym_DOT_DOT] = ACTIONS(3911),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3909),
    [anon_sym_STAR] = ACTIONS(3909),
    [anon_sym_LBRACK] = ACTIONS(3911),
    [aux_sym_record_type_token1] = ACTIONS(3909),
    [aux_sym_basic_type_token21] = ACTIONS(3909),
    [aux_sym_basic_type_token22] = ACTIONS(3909),
    [aux_sym_basic_type_token48] = ACTIONS(3909),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3909),
    [anon_sym_POUNDif] = ACTIONS(3911),
    [anon_sym_POUNDIF] = ACTIONS(3911),
    [anon_sym_POUNDIf] = ACTIONS(3911),
    [anon_sym_not] = ACTIONS(3909),
    [anon_sym_NOT] = ACTIONS(3909),
    [anon_sym_Not] = ACTIONS(3909),
    [anon_sym_POUNDelse] = ACTIONS(3911),
    [anon_sym_POUNDELSE] = ACTIONS(3911),
    [anon_sym_POUNDElse] = ACTIONS(3911),
    [anon_sym_POUNDelse2] = ACTIONS(3911),
    [anon_sym_POUNDELSE2] = ACTIONS(3911),
    [anon_sym_POUNDElse2] = ACTIONS(3911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3911),
    [aux_sym__expression_token1] = ACTIONS(3911),
    [aux_sym__expression_token2] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3909),
    [anon_sym_SLASH] = ACTIONS(3909),
    [anon_sym_div] = ACTIONS(3909),
    [anon_sym_DIV] = ACTIONS(3909),
    [anon_sym_Div] = ACTIONS(3909),
    [anon_sym_mod] = ACTIONS(3909),
    [anon_sym_MOD] = ACTIONS(3909),
    [anon_sym_Mod] = ACTIONS(3909),
    [anon_sym_PLUS] = ACTIONS(3909),
    [anon_sym_GT_EQ] = ACTIONS(3911),
    [anon_sym_LT_EQ] = ACTIONS(3911),
    [anon_sym_GT] = ACTIONS(3909),
    [anon_sym_LT] = ACTIONS(3909),
    [anon_sym_LT_GT] = ACTIONS(3911),
    [anon_sym_and] = ACTIONS(3909),
    [anon_sym_AND] = ACTIONS(3909),
    [anon_sym_And] = ACTIONS(3909),
    [anon_sym_or] = ACTIONS(3909),
    [anon_sym_OR] = ACTIONS(3909),
    [anon_sym_Or] = ACTIONS(3909),
    [anon_sym_xor] = ACTIONS(3909),
    [anon_sym_XOR] = ACTIONS(3909),
    [anon_sym_Xor] = ACTIONS(3909),
    [anon_sym_QMARK] = ACTIONS(3911),
    [sym_datetime_literal] = ACTIONS(3911),
    [sym_date_literal] = ACTIONS(3909),
    [sym_time_literal] = ACTIONS(3909),
    [sym_biginteger_literal] = ACTIONS(3911),
    [anon_sym_if] = ACTIONS(3909),
    [anon_sym_IF] = ACTIONS(3909),
    [anon_sym_If] = ACTIONS(3909),
    [anon_sym_else] = ACTIONS(3909),
    [anon_sym_ELSE] = ACTIONS(3909),
    [anon_sym_Else] = ACTIONS(3909),
    [anon_sym_case] = ACTIONS(3909),
    [anon_sym_CASE] = ACTIONS(3909),
    [anon_sym_Case] = ACTIONS(3909),
    [anon_sym_for] = ACTIONS(3909),
    [anon_sym_FOR] = ACTIONS(3909),
    [anon_sym_For] = ACTIONS(3909),
    [anon_sym_foreach] = ACTIONS(3909),
    [anon_sym_FOREACH] = ACTIONS(3909),
    [anon_sym_Foreach] = ACTIONS(3909),
    [anon_sym_while] = ACTIONS(3909),
    [anon_sym_WHILE] = ACTIONS(3909),
    [anon_sym_While] = ACTIONS(3909),
    [anon_sym_repeat] = ACTIONS(3909),
    [anon_sym_REPEAT] = ACTIONS(3909),
    [anon_sym_Repeat] = ACTIONS(3909),
    [anon_sym_until] = ACTIONS(3909),
    [anon_sym_UNTIL] = ACTIONS(3909),
    [anon_sym_Until] = ACTIONS(3909),
    [anon_sym_exit] = ACTIONS(3909),
    [anon_sym_EXIT] = ACTIONS(3909),
    [anon_sym_Exit] = ACTIONS(3909),
    [anon_sym_continue] = ACTIONS(3909),
    [anon_sym_CONTINUE] = ACTIONS(3909),
    [anon_sym_Continue] = ACTIONS(3909),
    [anon_sym_break] = ACTIONS(3909),
    [anon_sym_BREAK] = ACTIONS(3909),
    [anon_sym_Break] = ACTIONS(3909),
    [anon_sym_with] = ACTIONS(3909),
    [anon_sym_WITH] = ACTIONS(3909),
    [anon_sym_With] = ACTIONS(3909),
    [sym_asserterror_keyword] = ACTIONS(3911),
    [anon_sym_in] = ACTIONS(3909),
    [anon_sym_IN] = ACTIONS(3909),
    [anon_sym_In] = ACTIONS(3909),
    [sym_page_keyword] = ACTIONS(3909),
    [anon_sym_codeunit] = ACTIONS(3909),
    [anon_sym_CODEUNIT] = ACTIONS(3909),
    [anon_sym_Codeunit] = ACTIONS(3909),
    [anon_sym_CodeUnit] = ACTIONS(3909),
    [anon_sym_COdeunit] = ACTIONS(3909),
    [anon_sym_codeUnit] = ACTIONS(3909),
    [sym_report_keyword] = ACTIONS(3909),
    [sym_query_keyword] = ACTIONS(3909),
    [anon_sym_xmlport] = ACTIONS(3909),
    [anon_sym_XMLPORT] = ACTIONS(3909),
    [anon_sym_Xmlport] = ACTIONS(3909),
    [anon_sym_XMLport] = ACTIONS(3909),
    [anon_sym_XMLPort] = ACTIONS(3909),
    [anon_sym_XmlPort] = ACTIONS(3909),
    [anon_sym_enum] = ACTIONS(3909),
    [anon_sym_ENUM] = ACTIONS(3909),
    [anon_sym_Enum] = ACTIONS(3909),
    [anon_sym_eNUM] = ACTIONS(3909),
    [anon_sym_eNum] = ACTIONS(3909),
    [anon_sym_ENum] = ACTIONS(3909),
    [sym_quoted_identifier] = ACTIONS(3911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3911),
    [sym_verbatim_string] = ACTIONS(3911),
    [sym_integer] = ACTIONS(3909),
    [sym_continue_as_identifier] = ACTIONS(3911),
    [sym_preproc_open] = ACTIONS(3911),
  },
  [STATE(2020)] = {
    [sym_identifier] = ACTIONS(3931),
    [anon_sym_SEMI] = ACTIONS(3933),
    [anon_sym_DOT] = ACTIONS(3931),
    [anon_sym_EQ] = ACTIONS(3933),
    [anon_sym_DASH] = ACTIONS(3931),
    [aux_sym_boolean_token1] = ACTIONS(3931),
    [aux_sym_boolean_token2] = ACTIONS(3931),
    [sym_decimal] = ACTIONS(3931),
    [anon_sym_LPAREN] = ACTIONS(3933),
    [anon_sym_DOT_DOT] = ACTIONS(3933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3931),
    [anon_sym_STAR] = ACTIONS(3931),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [aux_sym_record_type_token1] = ACTIONS(3931),
    [aux_sym_basic_type_token21] = ACTIONS(3931),
    [aux_sym_basic_type_token22] = ACTIONS(3931),
    [aux_sym_basic_type_token48] = ACTIONS(3931),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3931),
    [anon_sym_POUNDif] = ACTIONS(3933),
    [anon_sym_POUNDIF] = ACTIONS(3933),
    [anon_sym_POUNDIf] = ACTIONS(3933),
    [anon_sym_not] = ACTIONS(3931),
    [anon_sym_NOT] = ACTIONS(3931),
    [anon_sym_Not] = ACTIONS(3931),
    [anon_sym_POUNDelse] = ACTIONS(3933),
    [anon_sym_POUNDELSE] = ACTIONS(3933),
    [anon_sym_POUNDElse] = ACTIONS(3933),
    [anon_sym_POUNDelse2] = ACTIONS(3933),
    [anon_sym_POUNDELSE2] = ACTIONS(3933),
    [anon_sym_POUNDElse2] = ACTIONS(3933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3933),
    [aux_sym__expression_token1] = ACTIONS(3933),
    [aux_sym__expression_token2] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3931),
    [anon_sym_SLASH] = ACTIONS(3931),
    [anon_sym_div] = ACTIONS(3931),
    [anon_sym_DIV] = ACTIONS(3931),
    [anon_sym_Div] = ACTIONS(3931),
    [anon_sym_mod] = ACTIONS(3931),
    [anon_sym_MOD] = ACTIONS(3931),
    [anon_sym_Mod] = ACTIONS(3931),
    [anon_sym_PLUS] = ACTIONS(3931),
    [anon_sym_GT_EQ] = ACTIONS(3933),
    [anon_sym_LT_EQ] = ACTIONS(3933),
    [anon_sym_GT] = ACTIONS(3931),
    [anon_sym_LT] = ACTIONS(3931),
    [anon_sym_LT_GT] = ACTIONS(3933),
    [anon_sym_and] = ACTIONS(3931),
    [anon_sym_AND] = ACTIONS(3931),
    [anon_sym_And] = ACTIONS(3931),
    [anon_sym_or] = ACTIONS(3931),
    [anon_sym_OR] = ACTIONS(3931),
    [anon_sym_Or] = ACTIONS(3931),
    [anon_sym_xor] = ACTIONS(3931),
    [anon_sym_XOR] = ACTIONS(3931),
    [anon_sym_Xor] = ACTIONS(3931),
    [anon_sym_QMARK] = ACTIONS(3933),
    [sym_datetime_literal] = ACTIONS(3933),
    [sym_date_literal] = ACTIONS(3931),
    [sym_time_literal] = ACTIONS(3931),
    [sym_biginteger_literal] = ACTIONS(3933),
    [anon_sym_if] = ACTIONS(3931),
    [anon_sym_IF] = ACTIONS(3931),
    [anon_sym_If] = ACTIONS(3931),
    [anon_sym_else] = ACTIONS(3931),
    [anon_sym_ELSE] = ACTIONS(3931),
    [anon_sym_Else] = ACTIONS(3931),
    [anon_sym_case] = ACTIONS(3931),
    [anon_sym_CASE] = ACTIONS(3931),
    [anon_sym_Case] = ACTIONS(3931),
    [anon_sym_for] = ACTIONS(3931),
    [anon_sym_FOR] = ACTIONS(3931),
    [anon_sym_For] = ACTIONS(3931),
    [anon_sym_foreach] = ACTIONS(3931),
    [anon_sym_FOREACH] = ACTIONS(3931),
    [anon_sym_Foreach] = ACTIONS(3931),
    [anon_sym_while] = ACTIONS(3931),
    [anon_sym_WHILE] = ACTIONS(3931),
    [anon_sym_While] = ACTIONS(3931),
    [anon_sym_repeat] = ACTIONS(3931),
    [anon_sym_REPEAT] = ACTIONS(3931),
    [anon_sym_Repeat] = ACTIONS(3931),
    [anon_sym_until] = ACTIONS(3931),
    [anon_sym_UNTIL] = ACTIONS(3931),
    [anon_sym_Until] = ACTIONS(3931),
    [anon_sym_exit] = ACTIONS(3931),
    [anon_sym_EXIT] = ACTIONS(3931),
    [anon_sym_Exit] = ACTIONS(3931),
    [anon_sym_continue] = ACTIONS(3931),
    [anon_sym_CONTINUE] = ACTIONS(3931),
    [anon_sym_Continue] = ACTIONS(3931),
    [anon_sym_break] = ACTIONS(3931),
    [anon_sym_BREAK] = ACTIONS(3931),
    [anon_sym_Break] = ACTIONS(3931),
    [anon_sym_with] = ACTIONS(3931),
    [anon_sym_WITH] = ACTIONS(3931),
    [anon_sym_With] = ACTIONS(3931),
    [sym_asserterror_keyword] = ACTIONS(3933),
    [anon_sym_in] = ACTIONS(3931),
    [anon_sym_IN] = ACTIONS(3931),
    [anon_sym_In] = ACTIONS(3931),
    [sym_page_keyword] = ACTIONS(3931),
    [anon_sym_codeunit] = ACTIONS(3931),
    [anon_sym_CODEUNIT] = ACTIONS(3931),
    [anon_sym_Codeunit] = ACTIONS(3931),
    [anon_sym_CodeUnit] = ACTIONS(3931),
    [anon_sym_COdeunit] = ACTIONS(3931),
    [anon_sym_codeUnit] = ACTIONS(3931),
    [sym_report_keyword] = ACTIONS(3931),
    [sym_query_keyword] = ACTIONS(3931),
    [anon_sym_xmlport] = ACTIONS(3931),
    [anon_sym_XMLPORT] = ACTIONS(3931),
    [anon_sym_Xmlport] = ACTIONS(3931),
    [anon_sym_XMLport] = ACTIONS(3931),
    [anon_sym_XMLPort] = ACTIONS(3931),
    [anon_sym_XmlPort] = ACTIONS(3931),
    [anon_sym_enum] = ACTIONS(3931),
    [anon_sym_ENUM] = ACTIONS(3931),
    [anon_sym_Enum] = ACTIONS(3931),
    [anon_sym_eNUM] = ACTIONS(3931),
    [anon_sym_eNum] = ACTIONS(3931),
    [anon_sym_ENum] = ACTIONS(3931),
    [sym_quoted_identifier] = ACTIONS(3933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3933),
    [sym_verbatim_string] = ACTIONS(3933),
    [sym_integer] = ACTIONS(3931),
    [sym_continue_as_identifier] = ACTIONS(3933),
    [sym_preproc_open] = ACTIONS(3933),
  },
  [STATE(2021)] = {
    [sym_identifier] = ACTIONS(3913),
    [anon_sym_SEMI] = ACTIONS(3915),
    [anon_sym_DOT] = ACTIONS(3913),
    [anon_sym_EQ] = ACTIONS(3915),
    [anon_sym_DASH] = ACTIONS(3913),
    [aux_sym_boolean_token1] = ACTIONS(3913),
    [aux_sym_boolean_token2] = ACTIONS(3913),
    [sym_decimal] = ACTIONS(3913),
    [anon_sym_LPAREN] = ACTIONS(3915),
    [anon_sym_DOT_DOT] = ACTIONS(3915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3913),
    [anon_sym_STAR] = ACTIONS(3913),
    [anon_sym_LBRACK] = ACTIONS(3915),
    [aux_sym_record_type_token1] = ACTIONS(3913),
    [aux_sym_basic_type_token21] = ACTIONS(3913),
    [aux_sym_basic_type_token22] = ACTIONS(3913),
    [aux_sym_basic_type_token48] = ACTIONS(3913),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3913),
    [anon_sym_POUNDif] = ACTIONS(3915),
    [anon_sym_POUNDIF] = ACTIONS(3915),
    [anon_sym_POUNDIf] = ACTIONS(3915),
    [anon_sym_not] = ACTIONS(3913),
    [anon_sym_NOT] = ACTIONS(3913),
    [anon_sym_Not] = ACTIONS(3913),
    [anon_sym_POUNDelse] = ACTIONS(3915),
    [anon_sym_POUNDELSE] = ACTIONS(3915),
    [anon_sym_POUNDElse] = ACTIONS(3915),
    [anon_sym_POUNDelse2] = ACTIONS(3915),
    [anon_sym_POUNDELSE2] = ACTIONS(3915),
    [anon_sym_POUNDElse2] = ACTIONS(3915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3915),
    [aux_sym__expression_token1] = ACTIONS(3915),
    [aux_sym__expression_token2] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3913),
    [anon_sym_SLASH] = ACTIONS(3913),
    [anon_sym_div] = ACTIONS(3913),
    [anon_sym_DIV] = ACTIONS(3913),
    [anon_sym_Div] = ACTIONS(3913),
    [anon_sym_mod] = ACTIONS(3913),
    [anon_sym_MOD] = ACTIONS(3913),
    [anon_sym_Mod] = ACTIONS(3913),
    [anon_sym_PLUS] = ACTIONS(3913),
    [anon_sym_GT_EQ] = ACTIONS(3915),
    [anon_sym_LT_EQ] = ACTIONS(3915),
    [anon_sym_GT] = ACTIONS(3913),
    [anon_sym_LT] = ACTIONS(3913),
    [anon_sym_LT_GT] = ACTIONS(3915),
    [anon_sym_and] = ACTIONS(3913),
    [anon_sym_AND] = ACTIONS(3913),
    [anon_sym_And] = ACTIONS(3913),
    [anon_sym_or] = ACTIONS(3913),
    [anon_sym_OR] = ACTIONS(3913),
    [anon_sym_Or] = ACTIONS(3913),
    [anon_sym_xor] = ACTIONS(3913),
    [anon_sym_XOR] = ACTIONS(3913),
    [anon_sym_Xor] = ACTIONS(3913),
    [anon_sym_QMARK] = ACTIONS(3915),
    [sym_datetime_literal] = ACTIONS(3915),
    [sym_date_literal] = ACTIONS(3913),
    [sym_time_literal] = ACTIONS(3913),
    [sym_biginteger_literal] = ACTIONS(3915),
    [anon_sym_if] = ACTIONS(3913),
    [anon_sym_IF] = ACTIONS(3913),
    [anon_sym_If] = ACTIONS(3913),
    [anon_sym_else] = ACTIONS(3913),
    [anon_sym_ELSE] = ACTIONS(3913),
    [anon_sym_Else] = ACTIONS(3913),
    [anon_sym_case] = ACTIONS(3913),
    [anon_sym_CASE] = ACTIONS(3913),
    [anon_sym_Case] = ACTIONS(3913),
    [anon_sym_for] = ACTIONS(3913),
    [anon_sym_FOR] = ACTIONS(3913),
    [anon_sym_For] = ACTIONS(3913),
    [anon_sym_foreach] = ACTIONS(3913),
    [anon_sym_FOREACH] = ACTIONS(3913),
    [anon_sym_Foreach] = ACTIONS(3913),
    [anon_sym_while] = ACTIONS(3913),
    [anon_sym_WHILE] = ACTIONS(3913),
    [anon_sym_While] = ACTIONS(3913),
    [anon_sym_repeat] = ACTIONS(3913),
    [anon_sym_REPEAT] = ACTIONS(3913),
    [anon_sym_Repeat] = ACTIONS(3913),
    [anon_sym_until] = ACTIONS(3913),
    [anon_sym_UNTIL] = ACTIONS(3913),
    [anon_sym_Until] = ACTIONS(3913),
    [anon_sym_exit] = ACTIONS(3913),
    [anon_sym_EXIT] = ACTIONS(3913),
    [anon_sym_Exit] = ACTIONS(3913),
    [anon_sym_continue] = ACTIONS(3913),
    [anon_sym_CONTINUE] = ACTIONS(3913),
    [anon_sym_Continue] = ACTIONS(3913),
    [anon_sym_break] = ACTIONS(3913),
    [anon_sym_BREAK] = ACTIONS(3913),
    [anon_sym_Break] = ACTIONS(3913),
    [anon_sym_with] = ACTIONS(3913),
    [anon_sym_WITH] = ACTIONS(3913),
    [anon_sym_With] = ACTIONS(3913),
    [sym_asserterror_keyword] = ACTIONS(3915),
    [anon_sym_in] = ACTIONS(3913),
    [anon_sym_IN] = ACTIONS(3913),
    [anon_sym_In] = ACTIONS(3913),
    [sym_page_keyword] = ACTIONS(3913),
    [anon_sym_codeunit] = ACTIONS(3913),
    [anon_sym_CODEUNIT] = ACTIONS(3913),
    [anon_sym_Codeunit] = ACTIONS(3913),
    [anon_sym_CodeUnit] = ACTIONS(3913),
    [anon_sym_COdeunit] = ACTIONS(3913),
    [anon_sym_codeUnit] = ACTIONS(3913),
    [sym_report_keyword] = ACTIONS(3913),
    [sym_query_keyword] = ACTIONS(3913),
    [anon_sym_xmlport] = ACTIONS(3913),
    [anon_sym_XMLPORT] = ACTIONS(3913),
    [anon_sym_Xmlport] = ACTIONS(3913),
    [anon_sym_XMLport] = ACTIONS(3913),
    [anon_sym_XMLPort] = ACTIONS(3913),
    [anon_sym_XmlPort] = ACTIONS(3913),
    [anon_sym_enum] = ACTIONS(3913),
    [anon_sym_ENUM] = ACTIONS(3913),
    [anon_sym_Enum] = ACTIONS(3913),
    [anon_sym_eNUM] = ACTIONS(3913),
    [anon_sym_eNum] = ACTIONS(3913),
    [anon_sym_ENum] = ACTIONS(3913),
    [sym_quoted_identifier] = ACTIONS(3915),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3915),
    [sym_verbatim_string] = ACTIONS(3915),
    [sym_integer] = ACTIONS(3913),
    [sym_continue_as_identifier] = ACTIONS(3915),
    [sym_preproc_open] = ACTIONS(3915),
  },
  [STATE(2022)] = {
    [sym_identifier] = ACTIONS(3917),
    [anon_sym_SEMI] = ACTIONS(3919),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_EQ] = ACTIONS(3919),
    [anon_sym_DASH] = ACTIONS(3917),
    [aux_sym_boolean_token1] = ACTIONS(3917),
    [aux_sym_boolean_token2] = ACTIONS(3917),
    [sym_decimal] = ACTIONS(3917),
    [anon_sym_LPAREN] = ACTIONS(3919),
    [anon_sym_DOT_DOT] = ACTIONS(3919),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3919),
    [aux_sym_record_type_token1] = ACTIONS(3917),
    [aux_sym_basic_type_token21] = ACTIONS(3917),
    [aux_sym_basic_type_token22] = ACTIONS(3917),
    [aux_sym_basic_type_token48] = ACTIONS(3917),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3917),
    [anon_sym_POUNDif] = ACTIONS(3919),
    [anon_sym_POUNDIF] = ACTIONS(3919),
    [anon_sym_POUNDIf] = ACTIONS(3919),
    [anon_sym_not] = ACTIONS(3917),
    [anon_sym_NOT] = ACTIONS(3917),
    [anon_sym_Not] = ACTIONS(3917),
    [anon_sym_POUNDelse] = ACTIONS(3919),
    [anon_sym_POUNDELSE] = ACTIONS(3919),
    [anon_sym_POUNDElse] = ACTIONS(3919),
    [anon_sym_POUNDelse2] = ACTIONS(3919),
    [anon_sym_POUNDELSE2] = ACTIONS(3919),
    [anon_sym_POUNDElse2] = ACTIONS(3919),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3919),
    [aux_sym__expression_token1] = ACTIONS(3919),
    [aux_sym__expression_token2] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_div] = ACTIONS(3917),
    [anon_sym_DIV] = ACTIONS(3917),
    [anon_sym_Div] = ACTIONS(3917),
    [anon_sym_mod] = ACTIONS(3917),
    [anon_sym_MOD] = ACTIONS(3917),
    [anon_sym_Mod] = ACTIONS(3917),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3919),
    [anon_sym_LT_EQ] = ACTIONS(3919),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_LT_GT] = ACTIONS(3919),
    [anon_sym_and] = ACTIONS(3917),
    [anon_sym_AND] = ACTIONS(3917),
    [anon_sym_And] = ACTIONS(3917),
    [anon_sym_or] = ACTIONS(3917),
    [anon_sym_OR] = ACTIONS(3917),
    [anon_sym_Or] = ACTIONS(3917),
    [anon_sym_xor] = ACTIONS(3917),
    [anon_sym_XOR] = ACTIONS(3917),
    [anon_sym_Xor] = ACTIONS(3917),
    [anon_sym_QMARK] = ACTIONS(3919),
    [sym_datetime_literal] = ACTIONS(3919),
    [sym_date_literal] = ACTIONS(3917),
    [sym_time_literal] = ACTIONS(3917),
    [sym_biginteger_literal] = ACTIONS(3919),
    [anon_sym_if] = ACTIONS(3917),
    [anon_sym_IF] = ACTIONS(3917),
    [anon_sym_If] = ACTIONS(3917),
    [anon_sym_else] = ACTIONS(3917),
    [anon_sym_ELSE] = ACTIONS(3917),
    [anon_sym_Else] = ACTIONS(3917),
    [anon_sym_case] = ACTIONS(3917),
    [anon_sym_CASE] = ACTIONS(3917),
    [anon_sym_Case] = ACTIONS(3917),
    [anon_sym_for] = ACTIONS(3917),
    [anon_sym_FOR] = ACTIONS(3917),
    [anon_sym_For] = ACTIONS(3917),
    [anon_sym_foreach] = ACTIONS(3917),
    [anon_sym_FOREACH] = ACTIONS(3917),
    [anon_sym_Foreach] = ACTIONS(3917),
    [anon_sym_while] = ACTIONS(3917),
    [anon_sym_WHILE] = ACTIONS(3917),
    [anon_sym_While] = ACTIONS(3917),
    [anon_sym_repeat] = ACTIONS(3917),
    [anon_sym_REPEAT] = ACTIONS(3917),
    [anon_sym_Repeat] = ACTIONS(3917),
    [anon_sym_until] = ACTIONS(3917),
    [anon_sym_UNTIL] = ACTIONS(3917),
    [anon_sym_Until] = ACTIONS(3917),
    [anon_sym_exit] = ACTIONS(3917),
    [anon_sym_EXIT] = ACTIONS(3917),
    [anon_sym_Exit] = ACTIONS(3917),
    [anon_sym_continue] = ACTIONS(3917),
    [anon_sym_CONTINUE] = ACTIONS(3917),
    [anon_sym_Continue] = ACTIONS(3917),
    [anon_sym_break] = ACTIONS(3917),
    [anon_sym_BREAK] = ACTIONS(3917),
    [anon_sym_Break] = ACTIONS(3917),
    [anon_sym_with] = ACTIONS(3917),
    [anon_sym_WITH] = ACTIONS(3917),
    [anon_sym_With] = ACTIONS(3917),
    [sym_asserterror_keyword] = ACTIONS(3919),
    [anon_sym_in] = ACTIONS(3917),
    [anon_sym_IN] = ACTIONS(3917),
    [anon_sym_In] = ACTIONS(3917),
    [sym_page_keyword] = ACTIONS(3917),
    [anon_sym_codeunit] = ACTIONS(3917),
    [anon_sym_CODEUNIT] = ACTIONS(3917),
    [anon_sym_Codeunit] = ACTIONS(3917),
    [anon_sym_CodeUnit] = ACTIONS(3917),
    [anon_sym_COdeunit] = ACTIONS(3917),
    [anon_sym_codeUnit] = ACTIONS(3917),
    [sym_report_keyword] = ACTIONS(3917),
    [sym_query_keyword] = ACTIONS(3917),
    [anon_sym_xmlport] = ACTIONS(3917),
    [anon_sym_XMLPORT] = ACTIONS(3917),
    [anon_sym_Xmlport] = ACTIONS(3917),
    [anon_sym_XMLport] = ACTIONS(3917),
    [anon_sym_XMLPort] = ACTIONS(3917),
    [anon_sym_XmlPort] = ACTIONS(3917),
    [anon_sym_enum] = ACTIONS(3917),
    [anon_sym_ENUM] = ACTIONS(3917),
    [anon_sym_Enum] = ACTIONS(3917),
    [anon_sym_eNUM] = ACTIONS(3917),
    [anon_sym_eNum] = ACTIONS(3917),
    [anon_sym_ENum] = ACTIONS(3917),
    [sym_quoted_identifier] = ACTIONS(3919),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3919),
    [sym_verbatim_string] = ACTIONS(3919),
    [sym_integer] = ACTIONS(3917),
    [sym_continue_as_identifier] = ACTIONS(3919),
    [sym_preproc_open] = ACTIONS(3919),
  },
  [STATE(2023)] = {
    [sym_identifier] = ACTIONS(3651),
    [anon_sym_SEMI] = ACTIONS(3653),
    [anon_sym_DOT] = ACTIONS(3651),
    [anon_sym_EQ] = ACTIONS(3653),
    [anon_sym_COMMA] = ACTIONS(3653),
    [anon_sym_DASH] = ACTIONS(3651),
    [aux_sym_boolean_token1] = ACTIONS(3651),
    [aux_sym_boolean_token2] = ACTIONS(3651),
    [sym_decimal] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3653),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3651),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_LBRACK] = ACTIONS(3653),
    [aux_sym_record_type_token1] = ACTIONS(3651),
    [aux_sym_basic_type_token21] = ACTIONS(3651),
    [aux_sym_basic_type_token22] = ACTIONS(3651),
    [aux_sym_basic_type_token48] = ACTIONS(3651),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3651),
    [anon_sym_COLON_COLON] = ACTIONS(3653),
    [anon_sym_POUNDif] = ACTIONS(3653),
    [anon_sym_POUNDIF] = ACTIONS(3653),
    [anon_sym_POUNDIf] = ACTIONS(3653),
    [anon_sym_not] = ACTIONS(3651),
    [anon_sym_NOT] = ACTIONS(3651),
    [anon_sym_Not] = ACTIONS(3651),
    [anon_sym_POUNDelse] = ACTIONS(3653),
    [anon_sym_POUNDELSE] = ACTIONS(3653),
    [anon_sym_POUNDElse] = ACTIONS(3653),
    [anon_sym_POUNDelse2] = ACTIONS(3653),
    [anon_sym_POUNDELSE2] = ACTIONS(3653),
    [anon_sym_POUNDElse2] = ACTIONS(3653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3653),
    [aux_sym__expression_token1] = ACTIONS(3653),
    [aux_sym__expression_token2] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3651),
    [anon_sym_SLASH] = ACTIONS(3651),
    [anon_sym_div] = ACTIONS(3651),
    [anon_sym_DIV] = ACTIONS(3651),
    [anon_sym_Div] = ACTIONS(3651),
    [anon_sym_mod] = ACTIONS(3651),
    [anon_sym_MOD] = ACTIONS(3651),
    [anon_sym_Mod] = ACTIONS(3651),
    [anon_sym_PLUS] = ACTIONS(3651),
    [anon_sym_GT_EQ] = ACTIONS(3653),
    [anon_sym_LT_EQ] = ACTIONS(3653),
    [anon_sym_GT] = ACTIONS(3651),
    [anon_sym_LT] = ACTIONS(3651),
    [anon_sym_LT_GT] = ACTIONS(3653),
    [anon_sym_and] = ACTIONS(3651),
    [anon_sym_AND] = ACTIONS(3651),
    [anon_sym_And] = ACTIONS(3651),
    [anon_sym_or] = ACTIONS(3651),
    [anon_sym_OR] = ACTIONS(3651),
    [anon_sym_Or] = ACTIONS(3651),
    [anon_sym_xor] = ACTIONS(3651),
    [anon_sym_XOR] = ACTIONS(3651),
    [anon_sym_Xor] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [sym_datetime_literal] = ACTIONS(3653),
    [sym_date_literal] = ACTIONS(3651),
    [sym_time_literal] = ACTIONS(3651),
    [sym_biginteger_literal] = ACTIONS(3653),
    [anon_sym_if] = ACTIONS(3651),
    [anon_sym_IF] = ACTIONS(3651),
    [anon_sym_If] = ACTIONS(3651),
    [anon_sym_else] = ACTIONS(3651),
    [anon_sym_ELSE] = ACTIONS(3651),
    [anon_sym_Else] = ACTIONS(3651),
    [anon_sym_case] = ACTIONS(3651),
    [anon_sym_CASE] = ACTIONS(3651),
    [anon_sym_Case] = ACTIONS(3651),
    [anon_sym_for] = ACTIONS(3651),
    [anon_sym_FOR] = ACTIONS(3651),
    [anon_sym_For] = ACTIONS(3651),
    [anon_sym_foreach] = ACTIONS(3651),
    [anon_sym_FOREACH] = ACTIONS(3651),
    [anon_sym_Foreach] = ACTIONS(3651),
    [anon_sym_while] = ACTIONS(3651),
    [anon_sym_WHILE] = ACTIONS(3651),
    [anon_sym_While] = ACTIONS(3651),
    [anon_sym_repeat] = ACTIONS(3651),
    [anon_sym_REPEAT] = ACTIONS(3651),
    [anon_sym_Repeat] = ACTIONS(3651),
    [anon_sym_exit] = ACTIONS(3651),
    [anon_sym_EXIT] = ACTIONS(3651),
    [anon_sym_Exit] = ACTIONS(3651),
    [anon_sym_continue] = ACTIONS(3651),
    [anon_sym_CONTINUE] = ACTIONS(3651),
    [anon_sym_Continue] = ACTIONS(3651),
    [anon_sym_break] = ACTIONS(3651),
    [anon_sym_BREAK] = ACTIONS(3651),
    [anon_sym_Break] = ACTIONS(3651),
    [anon_sym_with] = ACTIONS(3651),
    [anon_sym_WITH] = ACTIONS(3651),
    [anon_sym_With] = ACTIONS(3651),
    [sym_asserterror_keyword] = ACTIONS(3653),
    [anon_sym_in] = ACTIONS(3651),
    [anon_sym_IN] = ACTIONS(3651),
    [anon_sym_In] = ACTIONS(3651),
    [sym_page_keyword] = ACTIONS(3651),
    [anon_sym_codeunit] = ACTIONS(3651),
    [anon_sym_CODEUNIT] = ACTIONS(3651),
    [anon_sym_Codeunit] = ACTIONS(3651),
    [anon_sym_CodeUnit] = ACTIONS(3651),
    [anon_sym_COdeunit] = ACTIONS(3651),
    [anon_sym_codeUnit] = ACTIONS(3651),
    [sym_report_keyword] = ACTIONS(3651),
    [sym_query_keyword] = ACTIONS(3651),
    [anon_sym_xmlport] = ACTIONS(3651),
    [anon_sym_XMLPORT] = ACTIONS(3651),
    [anon_sym_Xmlport] = ACTIONS(3651),
    [anon_sym_XMLport] = ACTIONS(3651),
    [anon_sym_XMLPort] = ACTIONS(3651),
    [anon_sym_XmlPort] = ACTIONS(3651),
    [anon_sym_enum] = ACTIONS(3651),
    [anon_sym_ENUM] = ACTIONS(3651),
    [anon_sym_Enum] = ACTIONS(3651),
    [anon_sym_eNUM] = ACTIONS(3651),
    [anon_sym_eNum] = ACTIONS(3651),
    [anon_sym_ENum] = ACTIONS(3651),
    [sym_quoted_identifier] = ACTIONS(3653),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3653),
    [sym_verbatim_string] = ACTIONS(3653),
    [sym_integer] = ACTIONS(3651),
    [sym_continue_as_identifier] = ACTIONS(3653),
    [sym_preproc_open] = ACTIONS(3653),
    [sym_end_keyword] = ACTIONS(3653),
  },
  [STATE(2024)] = {
    [sym_identifier] = ACTIONS(3655),
    [anon_sym_SEMI] = ACTIONS(3657),
    [anon_sym_DOT] = ACTIONS(3655),
    [anon_sym_EQ] = ACTIONS(3657),
    [anon_sym_COMMA] = ACTIONS(3657),
    [anon_sym_DASH] = ACTIONS(3655),
    [aux_sym_boolean_token1] = ACTIONS(3655),
    [aux_sym_boolean_token2] = ACTIONS(3655),
    [sym_decimal] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3657),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3655),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [aux_sym_record_type_token1] = ACTIONS(3655),
    [aux_sym_basic_type_token21] = ACTIONS(3655),
    [aux_sym_basic_type_token22] = ACTIONS(3655),
    [aux_sym_basic_type_token48] = ACTIONS(3655),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3655),
    [anon_sym_COLON_COLON] = ACTIONS(3657),
    [anon_sym_POUNDif] = ACTIONS(3657),
    [anon_sym_POUNDIF] = ACTIONS(3657),
    [anon_sym_POUNDIf] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3655),
    [anon_sym_NOT] = ACTIONS(3655),
    [anon_sym_Not] = ACTIONS(3655),
    [anon_sym_POUNDelse] = ACTIONS(3657),
    [anon_sym_POUNDELSE] = ACTIONS(3657),
    [anon_sym_POUNDElse] = ACTIONS(3657),
    [anon_sym_POUNDelse2] = ACTIONS(3657),
    [anon_sym_POUNDELSE2] = ACTIONS(3657),
    [anon_sym_POUNDElse2] = ACTIONS(3657),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3657),
    [aux_sym__expression_token1] = ACTIONS(3657),
    [aux_sym__expression_token2] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3655),
    [anon_sym_SLASH] = ACTIONS(3655),
    [anon_sym_div] = ACTIONS(3655),
    [anon_sym_DIV] = ACTIONS(3655),
    [anon_sym_Div] = ACTIONS(3655),
    [anon_sym_mod] = ACTIONS(3655),
    [anon_sym_MOD] = ACTIONS(3655),
    [anon_sym_Mod] = ACTIONS(3655),
    [anon_sym_PLUS] = ACTIONS(3655),
    [anon_sym_GT_EQ] = ACTIONS(3657),
    [anon_sym_LT_EQ] = ACTIONS(3657),
    [anon_sym_GT] = ACTIONS(3655),
    [anon_sym_LT] = ACTIONS(3655),
    [anon_sym_LT_GT] = ACTIONS(3657),
    [anon_sym_and] = ACTIONS(3655),
    [anon_sym_AND] = ACTIONS(3655),
    [anon_sym_And] = ACTIONS(3655),
    [anon_sym_or] = ACTIONS(3655),
    [anon_sym_OR] = ACTIONS(3655),
    [anon_sym_Or] = ACTIONS(3655),
    [anon_sym_xor] = ACTIONS(3655),
    [anon_sym_XOR] = ACTIONS(3655),
    [anon_sym_Xor] = ACTIONS(3655),
    [anon_sym_QMARK] = ACTIONS(3657),
    [sym_datetime_literal] = ACTIONS(3657),
    [sym_date_literal] = ACTIONS(3655),
    [sym_time_literal] = ACTIONS(3655),
    [sym_biginteger_literal] = ACTIONS(3657),
    [anon_sym_if] = ACTIONS(3655),
    [anon_sym_IF] = ACTIONS(3655),
    [anon_sym_If] = ACTIONS(3655),
    [anon_sym_else] = ACTIONS(3655),
    [anon_sym_ELSE] = ACTIONS(3655),
    [anon_sym_Else] = ACTIONS(3655),
    [anon_sym_case] = ACTIONS(3655),
    [anon_sym_CASE] = ACTIONS(3655),
    [anon_sym_Case] = ACTIONS(3655),
    [anon_sym_for] = ACTIONS(3655),
    [anon_sym_FOR] = ACTIONS(3655),
    [anon_sym_For] = ACTIONS(3655),
    [anon_sym_foreach] = ACTIONS(3655),
    [anon_sym_FOREACH] = ACTIONS(3655),
    [anon_sym_Foreach] = ACTIONS(3655),
    [anon_sym_while] = ACTIONS(3655),
    [anon_sym_WHILE] = ACTIONS(3655),
    [anon_sym_While] = ACTIONS(3655),
    [anon_sym_repeat] = ACTIONS(3655),
    [anon_sym_REPEAT] = ACTIONS(3655),
    [anon_sym_Repeat] = ACTIONS(3655),
    [anon_sym_exit] = ACTIONS(3655),
    [anon_sym_EXIT] = ACTIONS(3655),
    [anon_sym_Exit] = ACTIONS(3655),
    [anon_sym_continue] = ACTIONS(3655),
    [anon_sym_CONTINUE] = ACTIONS(3655),
    [anon_sym_Continue] = ACTIONS(3655),
    [anon_sym_break] = ACTIONS(3655),
    [anon_sym_BREAK] = ACTIONS(3655),
    [anon_sym_Break] = ACTIONS(3655),
    [anon_sym_with] = ACTIONS(3655),
    [anon_sym_WITH] = ACTIONS(3655),
    [anon_sym_With] = ACTIONS(3655),
    [sym_asserterror_keyword] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3655),
    [anon_sym_IN] = ACTIONS(3655),
    [anon_sym_In] = ACTIONS(3655),
    [sym_page_keyword] = ACTIONS(3655),
    [anon_sym_codeunit] = ACTIONS(3655),
    [anon_sym_CODEUNIT] = ACTIONS(3655),
    [anon_sym_Codeunit] = ACTIONS(3655),
    [anon_sym_CodeUnit] = ACTIONS(3655),
    [anon_sym_COdeunit] = ACTIONS(3655),
    [anon_sym_codeUnit] = ACTIONS(3655),
    [sym_report_keyword] = ACTIONS(3655),
    [sym_query_keyword] = ACTIONS(3655),
    [anon_sym_xmlport] = ACTIONS(3655),
    [anon_sym_XMLPORT] = ACTIONS(3655),
    [anon_sym_Xmlport] = ACTIONS(3655),
    [anon_sym_XMLport] = ACTIONS(3655),
    [anon_sym_XMLPort] = ACTIONS(3655),
    [anon_sym_XmlPort] = ACTIONS(3655),
    [anon_sym_enum] = ACTIONS(3655),
    [anon_sym_ENUM] = ACTIONS(3655),
    [anon_sym_Enum] = ACTIONS(3655),
    [anon_sym_eNUM] = ACTIONS(3655),
    [anon_sym_eNum] = ACTIONS(3655),
    [anon_sym_ENum] = ACTIONS(3655),
    [sym_quoted_identifier] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3657),
    [sym_verbatim_string] = ACTIONS(3657),
    [sym_integer] = ACTIONS(3655),
    [sym_continue_as_identifier] = ACTIONS(3657),
    [sym_preproc_open] = ACTIONS(3657),
    [sym_end_keyword] = ACTIONS(3657),
  },
  [STATE(2025)] = {
    [sym_identifier] = ACTIONS(3659),
    [anon_sym_SEMI] = ACTIONS(3661),
    [anon_sym_DOT] = ACTIONS(3659),
    [anon_sym_EQ] = ACTIONS(3661),
    [anon_sym_COMMA] = ACTIONS(3661),
    [anon_sym_DASH] = ACTIONS(3659),
    [aux_sym_boolean_token1] = ACTIONS(3659),
    [aux_sym_boolean_token2] = ACTIONS(3659),
    [sym_decimal] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3661),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3661),
    [aux_sym_record_type_token1] = ACTIONS(3659),
    [aux_sym_basic_type_token21] = ACTIONS(3659),
    [aux_sym_basic_type_token22] = ACTIONS(3659),
    [aux_sym_basic_type_token48] = ACTIONS(3659),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3659),
    [anon_sym_COLON_COLON] = ACTIONS(3661),
    [anon_sym_POUNDif] = ACTIONS(3661),
    [anon_sym_POUNDIF] = ACTIONS(3661),
    [anon_sym_POUNDIf] = ACTIONS(3661),
    [anon_sym_not] = ACTIONS(3659),
    [anon_sym_NOT] = ACTIONS(3659),
    [anon_sym_Not] = ACTIONS(3659),
    [anon_sym_POUNDelse] = ACTIONS(3661),
    [anon_sym_POUNDELSE] = ACTIONS(3661),
    [anon_sym_POUNDElse] = ACTIONS(3661),
    [anon_sym_POUNDelse2] = ACTIONS(3661),
    [anon_sym_POUNDELSE2] = ACTIONS(3661),
    [anon_sym_POUNDElse2] = ACTIONS(3661),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3661),
    [aux_sym__expression_token1] = ACTIONS(3661),
    [aux_sym__expression_token2] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3659),
    [anon_sym_SLASH] = ACTIONS(3659),
    [anon_sym_div] = ACTIONS(3659),
    [anon_sym_DIV] = ACTIONS(3659),
    [anon_sym_Div] = ACTIONS(3659),
    [anon_sym_mod] = ACTIONS(3659),
    [anon_sym_MOD] = ACTIONS(3659),
    [anon_sym_Mod] = ACTIONS(3659),
    [anon_sym_PLUS] = ACTIONS(3659),
    [anon_sym_GT_EQ] = ACTIONS(3661),
    [anon_sym_LT_EQ] = ACTIONS(3661),
    [anon_sym_GT] = ACTIONS(3659),
    [anon_sym_LT] = ACTIONS(3659),
    [anon_sym_LT_GT] = ACTIONS(3661),
    [anon_sym_and] = ACTIONS(3659),
    [anon_sym_AND] = ACTIONS(3659),
    [anon_sym_And] = ACTIONS(3659),
    [anon_sym_or] = ACTIONS(3659),
    [anon_sym_OR] = ACTIONS(3659),
    [anon_sym_Or] = ACTIONS(3659),
    [anon_sym_xor] = ACTIONS(3659),
    [anon_sym_XOR] = ACTIONS(3659),
    [anon_sym_Xor] = ACTIONS(3659),
    [anon_sym_QMARK] = ACTIONS(3661),
    [sym_datetime_literal] = ACTIONS(3661),
    [sym_date_literal] = ACTIONS(3659),
    [sym_time_literal] = ACTIONS(3659),
    [sym_biginteger_literal] = ACTIONS(3661),
    [anon_sym_if] = ACTIONS(3659),
    [anon_sym_IF] = ACTIONS(3659),
    [anon_sym_If] = ACTIONS(3659),
    [anon_sym_else] = ACTIONS(3659),
    [anon_sym_ELSE] = ACTIONS(3659),
    [anon_sym_Else] = ACTIONS(3659),
    [anon_sym_case] = ACTIONS(3659),
    [anon_sym_CASE] = ACTIONS(3659),
    [anon_sym_Case] = ACTIONS(3659),
    [anon_sym_for] = ACTIONS(3659),
    [anon_sym_FOR] = ACTIONS(3659),
    [anon_sym_For] = ACTIONS(3659),
    [anon_sym_foreach] = ACTIONS(3659),
    [anon_sym_FOREACH] = ACTIONS(3659),
    [anon_sym_Foreach] = ACTIONS(3659),
    [anon_sym_while] = ACTIONS(3659),
    [anon_sym_WHILE] = ACTIONS(3659),
    [anon_sym_While] = ACTIONS(3659),
    [anon_sym_repeat] = ACTIONS(3659),
    [anon_sym_REPEAT] = ACTIONS(3659),
    [anon_sym_Repeat] = ACTIONS(3659),
    [anon_sym_exit] = ACTIONS(3659),
    [anon_sym_EXIT] = ACTIONS(3659),
    [anon_sym_Exit] = ACTIONS(3659),
    [anon_sym_continue] = ACTIONS(3659),
    [anon_sym_CONTINUE] = ACTIONS(3659),
    [anon_sym_Continue] = ACTIONS(3659),
    [anon_sym_break] = ACTIONS(3659),
    [anon_sym_BREAK] = ACTIONS(3659),
    [anon_sym_Break] = ACTIONS(3659),
    [anon_sym_with] = ACTIONS(3659),
    [anon_sym_WITH] = ACTIONS(3659),
    [anon_sym_With] = ACTIONS(3659),
    [sym_asserterror_keyword] = ACTIONS(3661),
    [anon_sym_in] = ACTIONS(3659),
    [anon_sym_IN] = ACTIONS(3659),
    [anon_sym_In] = ACTIONS(3659),
    [sym_page_keyword] = ACTIONS(3659),
    [anon_sym_codeunit] = ACTIONS(3659),
    [anon_sym_CODEUNIT] = ACTIONS(3659),
    [anon_sym_Codeunit] = ACTIONS(3659),
    [anon_sym_CodeUnit] = ACTIONS(3659),
    [anon_sym_COdeunit] = ACTIONS(3659),
    [anon_sym_codeUnit] = ACTIONS(3659),
    [sym_report_keyword] = ACTIONS(3659),
    [sym_query_keyword] = ACTIONS(3659),
    [anon_sym_xmlport] = ACTIONS(3659),
    [anon_sym_XMLPORT] = ACTIONS(3659),
    [anon_sym_Xmlport] = ACTIONS(3659),
    [anon_sym_XMLport] = ACTIONS(3659),
    [anon_sym_XMLPort] = ACTIONS(3659),
    [anon_sym_XmlPort] = ACTIONS(3659),
    [anon_sym_enum] = ACTIONS(3659),
    [anon_sym_ENUM] = ACTIONS(3659),
    [anon_sym_Enum] = ACTIONS(3659),
    [anon_sym_eNUM] = ACTIONS(3659),
    [anon_sym_eNum] = ACTIONS(3659),
    [anon_sym_ENum] = ACTIONS(3659),
    [sym_quoted_identifier] = ACTIONS(3661),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3661),
    [sym_verbatim_string] = ACTIONS(3661),
    [sym_integer] = ACTIONS(3659),
    [sym_continue_as_identifier] = ACTIONS(3661),
    [sym_preproc_open] = ACTIONS(3661),
    [sym_end_keyword] = ACTIONS(3661),
  },
  [STATE(2026)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_if] = ACTIONS(3566),
    [anon_sym_IF] = ACTIONS(3566),
    [anon_sym_If] = ACTIONS(3566),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_case] = ACTIONS(3566),
    [anon_sym_CASE] = ACTIONS(3566),
    [anon_sym_Case] = ACTIONS(3566),
    [anon_sym_for] = ACTIONS(3566),
    [anon_sym_FOR] = ACTIONS(3566),
    [anon_sym_For] = ACTIONS(3566),
    [anon_sym_foreach] = ACTIONS(3566),
    [anon_sym_FOREACH] = ACTIONS(3566),
    [anon_sym_Foreach] = ACTIONS(3566),
    [anon_sym_while] = ACTIONS(3566),
    [anon_sym_WHILE] = ACTIONS(3566),
    [anon_sym_While] = ACTIONS(3566),
    [anon_sym_repeat] = ACTIONS(3566),
    [anon_sym_REPEAT] = ACTIONS(3566),
    [anon_sym_Repeat] = ACTIONS(3566),
    [anon_sym_exit] = ACTIONS(3566),
    [anon_sym_EXIT] = ACTIONS(3566),
    [anon_sym_Exit] = ACTIONS(3566),
    [anon_sym_continue] = ACTIONS(3566),
    [anon_sym_CONTINUE] = ACTIONS(3566),
    [anon_sym_Continue] = ACTIONS(3566),
    [anon_sym_break] = ACTIONS(3566),
    [anon_sym_BREAK] = ACTIONS(3566),
    [anon_sym_Break] = ACTIONS(3566),
    [anon_sym_with] = ACTIONS(3566),
    [anon_sym_WITH] = ACTIONS(3566),
    [anon_sym_With] = ACTIONS(3566),
    [sym_asserterror_keyword] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_end_keyword] = ACTIONS(3568),
  },
  [STATE(2027)] = {
    [sym_preproc_conditional_object] = STATE(1834),
    [sym_using_statement] = STATE(1834),
    [sym__object] = STATE(1834),
    [sym_preproc_split_declaration] = STATE(1834),
    [sym_table_declaration] = STATE(1834),
    [sym_page_declaration] = STATE(1834),
    [sym_report_declaration] = STATE(1834),
    [sym_query_declaration] = STATE(1834),
    [sym_xmlport_declaration] = STATE(1834),
    [sym_permissionset_declaration] = STATE(1834),
    [sym_codeunit_declaration] = STATE(1834),
    [sym_enum_declaration] = STATE(1834),
    [sym_tableextension_declaration] = STATE(1834),
    [sym_pageextension_declaration] = STATE(1834),
    [sym_reportextension_declaration] = STATE(1834),
    [sym_enumextension_declaration] = STATE(1834),
    [sym_permissionsetextension_declaration] = STATE(1834),
    [sym_controladdin_declaration] = STATE(1834),
    [sym_profile_declaration] = STATE(1834),
    [sym_entitlement_declaration] = STATE(1834),
    [sym_profileextension_declaration] = STATE(1834),
    [sym_interface_declaration] = STATE(1834),
    [sym_pagecustomization_declaration] = STATE(1834),
    [sym_dotnet_declaration] = STATE(1834),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_endif] = STATE(2763),
    [sym_tableextension_keyword] = STATE(17829),
    [sym_pageextension_keyword] = STATE(17830),
    [sym_codeunit_keyword] = STATE(17027),
    [sym_reportextension_keyword] = STATE(17831),
    [sym_xmlport_keyword] = STATE(17028),
    [sym_enum_keyword] = STATE(17029),
    [sym_enumextension_keyword] = STATE(17832),
    [sym_controladdin_keyword] = STATE(11968),
    [sym_dotnet_keyword] = STATE(16870),
    [sym_profileextension_keyword] = STATE(11993),
    [sym_permissionset_keyword] = STATE(17030),
    [sym_permissionsetextension_keyword] = STATE(17833),
    [sym_pagecustomization_keyword] = STATE(11994),
    [aux_sym_source_file_repeat1] = STATE(1834),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [anon_sym_POUNDendif] = ACTIONS(1012),
    [anon_sym_POUNDENDIF] = ACTIONS(1012),
    [anon_sym_POUNDEndif] = ACTIONS(1012),
    [anon_sym_POUNDendif2] = ACTIONS(1012),
    [anon_sym_POUNDENDIF2] = ACTIONS(1012),
    [anon_sym_POUNDEndif2] = ACTIONS(1012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(3550),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(3552),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(3554),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(3556),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(3558),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(1004),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(1006),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(1010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
    [sym_preproc_close] = ACTIONS(1012),
  },
  [STATE(2028)] = {
    [sym_comparison_operator] = STATE(4772),
    [sym_in_keyword] = STATE(16490),
    [sym_identifier] = ACTIONS(3730),
    [anon_sym_SEMI] = ACTIONS(3732),
    [anon_sym_DOT] = ACTIONS(4282),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(4304),
    [aux_sym_boolean_token1] = ACTIONS(3730),
    [aux_sym_boolean_token2] = ACTIONS(3730),
    [sym_decimal] = ACTIONS(3730),
    [anon_sym_LPAREN] = ACTIONS(3732),
    [anon_sym_DOT_DOT] = ACTIONS(4284),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3730),
    [anon_sym_STAR] = ACTIONS(4288),
    [anon_sym_LBRACK] = ACTIONS(4286),
    [aux_sym_record_type_token1] = ACTIONS(3730),
    [aux_sym_basic_type_token21] = ACTIONS(3730),
    [aux_sym_basic_type_token22] = ACTIONS(3730),
    [aux_sym_basic_type_token48] = ACTIONS(3730),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3730),
    [anon_sym_POUNDif] = ACTIONS(3732),
    [anon_sym_POUNDIF] = ACTIONS(3732),
    [anon_sym_POUNDIf] = ACTIONS(3732),
    [anon_sym_not] = ACTIONS(3730),
    [anon_sym_NOT] = ACTIONS(3730),
    [anon_sym_Not] = ACTIONS(3730),
    [anon_sym_POUNDelse] = ACTIONS(3732),
    [anon_sym_POUNDELSE] = ACTIONS(3732),
    [anon_sym_POUNDElse] = ACTIONS(3732),
    [anon_sym_POUNDelse2] = ACTIONS(3732),
    [anon_sym_POUNDELSE2] = ACTIONS(3732),
    [anon_sym_POUNDElse2] = ACTIONS(3732),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(4342),
    [aux_sym__expression_token1] = ACTIONS(4306),
    [aux_sym__expression_token2] = ACTIONS(4308),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3730),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3730),
    [anon_sym_SLASH] = ACTIONS(4290),
    [anon_sym_div] = ACTIONS(4292),
    [anon_sym_DIV] = ACTIONS(4294),
    [anon_sym_Div] = ACTIONS(4296),
    [anon_sym_mod] = ACTIONS(4298),
    [anon_sym_MOD] = ACTIONS(4300),
    [anon_sym_Mod] = ACTIONS(4302),
    [anon_sym_PLUS] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(4312),
    [anon_sym_AND] = ACTIONS(4314),
    [anon_sym_And] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_OR] = ACTIONS(4330),
    [anon_sym_Or] = ACTIONS(4332),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_XOR] = ACTIONS(4336),
    [anon_sym_Xor] = ACTIONS(4338),
    [anon_sym_QMARK] = ACTIONS(4340),
    [sym_datetime_literal] = ACTIONS(3732),
    [sym_date_literal] = ACTIONS(3730),
    [sym_time_literal] = ACTIONS(3730),
    [sym_biginteger_literal] = ACTIONS(3732),
    [anon_sym_if] = ACTIONS(3730),
    [anon_sym_IF] = ACTIONS(3730),
    [anon_sym_If] = ACTIONS(3730),
    [anon_sym_else] = ACTIONS(3730),
    [anon_sym_ELSE] = ACTIONS(3730),
    [anon_sym_Else] = ACTIONS(3730),
    [anon_sym_case] = ACTIONS(3730),
    [anon_sym_CASE] = ACTIONS(3730),
    [anon_sym_Case] = ACTIONS(3730),
    [anon_sym_for] = ACTIONS(3730),
    [anon_sym_FOR] = ACTIONS(3730),
    [anon_sym_For] = ACTIONS(3730),
    [anon_sym_foreach] = ACTIONS(3730),
    [anon_sym_FOREACH] = ACTIONS(3730),
    [anon_sym_Foreach] = ACTIONS(3730),
    [anon_sym_while] = ACTIONS(3730),
    [anon_sym_WHILE] = ACTIONS(3730),
    [anon_sym_While] = ACTIONS(3730),
    [anon_sym_repeat] = ACTIONS(3730),
    [anon_sym_REPEAT] = ACTIONS(3730),
    [anon_sym_Repeat] = ACTIONS(3730),
    [anon_sym_exit] = ACTIONS(3730),
    [anon_sym_EXIT] = ACTIONS(3730),
    [anon_sym_Exit] = ACTIONS(3730),
    [anon_sym_continue] = ACTIONS(3730),
    [anon_sym_CONTINUE] = ACTIONS(3730),
    [anon_sym_Continue] = ACTIONS(3730),
    [anon_sym_break] = ACTIONS(3730),
    [anon_sym_BREAK] = ACTIONS(3730),
    [anon_sym_Break] = ACTIONS(3730),
    [anon_sym_with] = ACTIONS(3730),
    [anon_sym_WITH] = ACTIONS(3730),
    [anon_sym_With] = ACTIONS(3730),
    [sym_asserterror_keyword] = ACTIONS(3732),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3730),
    [anon_sym_codeunit] = ACTIONS(3730),
    [anon_sym_CODEUNIT] = ACTIONS(3730),
    [anon_sym_Codeunit] = ACTIONS(3730),
    [anon_sym_CodeUnit] = ACTIONS(3730),
    [anon_sym_COdeunit] = ACTIONS(3730),
    [anon_sym_codeUnit] = ACTIONS(3730),
    [sym_report_keyword] = ACTIONS(3730),
    [sym_query_keyword] = ACTIONS(3730),
    [anon_sym_xmlport] = ACTIONS(3730),
    [anon_sym_XMLPORT] = ACTIONS(3730),
    [anon_sym_Xmlport] = ACTIONS(3730),
    [anon_sym_XMLport] = ACTIONS(3730),
    [anon_sym_XMLPort] = ACTIONS(3730),
    [anon_sym_XmlPort] = ACTIONS(3730),
    [anon_sym_enum] = ACTIONS(3730),
    [anon_sym_ENUM] = ACTIONS(3730),
    [anon_sym_Enum] = ACTIONS(3730),
    [anon_sym_eNUM] = ACTIONS(3730),
    [anon_sym_eNum] = ACTIONS(3730),
    [anon_sym_ENum] = ACTIONS(3730),
    [sym_quoted_identifier] = ACTIONS(3732),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3732),
    [sym_verbatim_string] = ACTIONS(3732),
    [sym_integer] = ACTIONS(3730),
    [sym_continue_as_identifier] = ACTIONS(3732),
    [sym_preproc_open] = ACTIONS(3732),
    [sym_end_keyword] = ACTIONS(3732),
  },
  [STATE(2029)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2029),
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(4352),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_if] = ACTIONS(3632),
    [anon_sym_IF] = ACTIONS(3632),
    [anon_sym_If] = ACTIONS(3632),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_case] = ACTIONS(3632),
    [anon_sym_CASE] = ACTIONS(3632),
    [anon_sym_Case] = ACTIONS(3632),
    [anon_sym_for] = ACTIONS(3632),
    [anon_sym_FOR] = ACTIONS(3632),
    [anon_sym_For] = ACTIONS(3632),
    [anon_sym_foreach] = ACTIONS(3632),
    [anon_sym_FOREACH] = ACTIONS(3632),
    [anon_sym_Foreach] = ACTIONS(3632),
    [anon_sym_while] = ACTIONS(3632),
    [anon_sym_WHILE] = ACTIONS(3632),
    [anon_sym_While] = ACTIONS(3632),
    [anon_sym_repeat] = ACTIONS(3632),
    [anon_sym_REPEAT] = ACTIONS(3632),
    [anon_sym_Repeat] = ACTIONS(3632),
    [anon_sym_exit] = ACTIONS(3632),
    [anon_sym_EXIT] = ACTIONS(3632),
    [anon_sym_Exit] = ACTIONS(3632),
    [anon_sym_continue] = ACTIONS(3632),
    [anon_sym_CONTINUE] = ACTIONS(3632),
    [anon_sym_Continue] = ACTIONS(3632),
    [anon_sym_break] = ACTIONS(3632),
    [anon_sym_BREAK] = ACTIONS(3632),
    [anon_sym_Break] = ACTIONS(3632),
    [anon_sym_with] = ACTIONS(3632),
    [anon_sym_WITH] = ACTIONS(3632),
    [anon_sym_With] = ACTIONS(3632),
    [sym_asserterror_keyword] = ACTIONS(3634),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
    [sym_end_keyword] = ACTIONS(3634),
  },
  [STATE(2030)] = {
    [sym_identifier] = ACTIONS(3742),
    [anon_sym_SEMI] = ACTIONS(3744),
    [anon_sym_DOT] = ACTIONS(3742),
    [anon_sym_EQ] = ACTIONS(3744),
    [anon_sym_COMMA] = ACTIONS(3744),
    [anon_sym_DASH] = ACTIONS(3742),
    [aux_sym_boolean_token1] = ACTIONS(3742),
    [aux_sym_boolean_token2] = ACTIONS(3742),
    [sym_decimal] = ACTIONS(3742),
    [anon_sym_LPAREN] = ACTIONS(3744),
    [anon_sym_DOT_DOT] = ACTIONS(3744),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3742),
    [anon_sym_STAR] = ACTIONS(3742),
    [anon_sym_LBRACK] = ACTIONS(3744),
    [aux_sym_record_type_token1] = ACTIONS(3742),
    [aux_sym_basic_type_token21] = ACTIONS(3742),
    [aux_sym_basic_type_token22] = ACTIONS(3742),
    [aux_sym_basic_type_token48] = ACTIONS(3742),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3742),
    [anon_sym_POUNDif] = ACTIONS(3744),
    [anon_sym_POUNDIF] = ACTIONS(3744),
    [anon_sym_POUNDIf] = ACTIONS(3744),
    [anon_sym_not] = ACTIONS(3742),
    [anon_sym_NOT] = ACTIONS(3742),
    [anon_sym_Not] = ACTIONS(3742),
    [anon_sym_POUNDelse] = ACTIONS(3744),
    [anon_sym_POUNDELSE] = ACTIONS(3744),
    [anon_sym_POUNDElse] = ACTIONS(3744),
    [anon_sym_POUNDelse2] = ACTIONS(3744),
    [anon_sym_POUNDELSE2] = ACTIONS(3744),
    [anon_sym_POUNDElse2] = ACTIONS(3744),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3744),
    [aux_sym__expression_token1] = ACTIONS(3744),
    [aux_sym__expression_token2] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3742),
    [anon_sym_SLASH] = ACTIONS(3742),
    [anon_sym_div] = ACTIONS(3742),
    [anon_sym_DIV] = ACTIONS(3742),
    [anon_sym_Div] = ACTIONS(3742),
    [anon_sym_mod] = ACTIONS(3742),
    [anon_sym_MOD] = ACTIONS(3742),
    [anon_sym_Mod] = ACTIONS(3742),
    [anon_sym_PLUS] = ACTIONS(3742),
    [anon_sym_GT_EQ] = ACTIONS(3744),
    [anon_sym_LT_EQ] = ACTIONS(3744),
    [anon_sym_GT] = ACTIONS(3742),
    [anon_sym_LT] = ACTIONS(3742),
    [anon_sym_LT_GT] = ACTIONS(3744),
    [anon_sym_and] = ACTIONS(3742),
    [anon_sym_AND] = ACTIONS(3742),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3742),
    [anon_sym_OR] = ACTIONS(3742),
    [anon_sym_Or] = ACTIONS(3742),
    [anon_sym_xor] = ACTIONS(3742),
    [anon_sym_XOR] = ACTIONS(3742),
    [anon_sym_Xor] = ACTIONS(3742),
    [anon_sym_QMARK] = ACTIONS(3744),
    [sym_datetime_literal] = ACTIONS(3744),
    [sym_date_literal] = ACTIONS(3742),
    [sym_time_literal] = ACTIONS(3742),
    [sym_biginteger_literal] = ACTIONS(3744),
    [anon_sym_if] = ACTIONS(3742),
    [anon_sym_IF] = ACTIONS(3742),
    [anon_sym_If] = ACTIONS(3742),
    [anon_sym_else] = ACTIONS(3742),
    [anon_sym_ELSE] = ACTIONS(3742),
    [anon_sym_Else] = ACTIONS(3742),
    [anon_sym_case] = ACTIONS(3742),
    [anon_sym_CASE] = ACTIONS(3742),
    [anon_sym_Case] = ACTIONS(3742),
    [anon_sym_for] = ACTIONS(3742),
    [anon_sym_FOR] = ACTIONS(3742),
    [anon_sym_For] = ACTIONS(3742),
    [anon_sym_foreach] = ACTIONS(3742),
    [anon_sym_FOREACH] = ACTIONS(3742),
    [anon_sym_Foreach] = ACTIONS(3742),
    [anon_sym_while] = ACTIONS(3742),
    [anon_sym_WHILE] = ACTIONS(3742),
    [anon_sym_While] = ACTIONS(3742),
    [anon_sym_repeat] = ACTIONS(3742),
    [anon_sym_REPEAT] = ACTIONS(3742),
    [anon_sym_Repeat] = ACTIONS(3742),
    [anon_sym_exit] = ACTIONS(3742),
    [anon_sym_EXIT] = ACTIONS(3742),
    [anon_sym_Exit] = ACTIONS(3742),
    [anon_sym_continue] = ACTIONS(3742),
    [anon_sym_CONTINUE] = ACTIONS(3742),
    [anon_sym_Continue] = ACTIONS(3742),
    [anon_sym_break] = ACTIONS(3742),
    [anon_sym_BREAK] = ACTIONS(3742),
    [anon_sym_Break] = ACTIONS(3742),
    [anon_sym_with] = ACTIONS(3742),
    [anon_sym_WITH] = ACTIONS(3742),
    [anon_sym_With] = ACTIONS(3742),
    [sym_asserterror_keyword] = ACTIONS(3744),
    [anon_sym_in] = ACTIONS(3742),
    [anon_sym_IN] = ACTIONS(3742),
    [anon_sym_In] = ACTIONS(3742),
    [sym_page_keyword] = ACTIONS(3742),
    [anon_sym_codeunit] = ACTIONS(3742),
    [anon_sym_CODEUNIT] = ACTIONS(3742),
    [anon_sym_Codeunit] = ACTIONS(3742),
    [anon_sym_CodeUnit] = ACTIONS(3742),
    [anon_sym_COdeunit] = ACTIONS(3742),
    [anon_sym_codeUnit] = ACTIONS(3742),
    [sym_report_keyword] = ACTIONS(3742),
    [sym_query_keyword] = ACTIONS(3742),
    [anon_sym_xmlport] = ACTIONS(3742),
    [anon_sym_XMLPORT] = ACTIONS(3742),
    [anon_sym_Xmlport] = ACTIONS(3742),
    [anon_sym_XMLport] = ACTIONS(3742),
    [anon_sym_XMLPort] = ACTIONS(3742),
    [anon_sym_XmlPort] = ACTIONS(3742),
    [anon_sym_enum] = ACTIONS(3742),
    [anon_sym_ENUM] = ACTIONS(3742),
    [anon_sym_Enum] = ACTIONS(3742),
    [anon_sym_eNUM] = ACTIONS(3742),
    [anon_sym_eNum] = ACTIONS(3742),
    [anon_sym_ENum] = ACTIONS(3742),
    [sym_quoted_identifier] = ACTIONS(3744),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3744),
    [sym_verbatim_string] = ACTIONS(3744),
    [sym_integer] = ACTIONS(3742),
    [sym_continue_as_identifier] = ACTIONS(3744),
    [sym_preproc_open] = ACTIONS(3744),
    [sym_end_keyword] = ACTIONS(3744),
  },
  [STATE(2031)] = {
    [sym_identifier] = ACTIONS(3760),
    [anon_sym_SEMI] = ACTIONS(3762),
    [anon_sym_DOT] = ACTIONS(3760),
    [anon_sym_EQ] = ACTIONS(3762),
    [anon_sym_DASH] = ACTIONS(3760),
    [aux_sym_boolean_token1] = ACTIONS(3760),
    [aux_sym_boolean_token2] = ACTIONS(3760),
    [sym_decimal] = ACTIONS(3760),
    [anon_sym_LPAREN] = ACTIONS(3762),
    [anon_sym_DOT_DOT] = ACTIONS(3762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3760),
    [anon_sym_STAR] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3762),
    [aux_sym_record_type_token1] = ACTIONS(3760),
    [aux_sym_basic_type_token21] = ACTIONS(3760),
    [aux_sym_basic_type_token22] = ACTIONS(3760),
    [aux_sym_basic_type_token48] = ACTIONS(3760),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3760),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(3762),
    [anon_sym_POUNDIF] = ACTIONS(3762),
    [anon_sym_POUNDIf] = ACTIONS(3762),
    [anon_sym_not] = ACTIONS(3760),
    [anon_sym_NOT] = ACTIONS(3760),
    [anon_sym_Not] = ACTIONS(3760),
    [anon_sym_POUNDelse] = ACTIONS(3762),
    [anon_sym_POUNDELSE] = ACTIONS(3762),
    [anon_sym_POUNDElse] = ACTIONS(3762),
    [anon_sym_POUNDelse2] = ACTIONS(3762),
    [anon_sym_POUNDELSE2] = ACTIONS(3762),
    [anon_sym_POUNDElse2] = ACTIONS(3762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3762),
    [aux_sym__expression_token1] = ACTIONS(3762),
    [aux_sym__expression_token2] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3760),
    [anon_sym_SLASH] = ACTIONS(3760),
    [anon_sym_div] = ACTIONS(3760),
    [anon_sym_DIV] = ACTIONS(3760),
    [anon_sym_Div] = ACTIONS(3760),
    [anon_sym_mod] = ACTIONS(3760),
    [anon_sym_MOD] = ACTIONS(3760),
    [anon_sym_Mod] = ACTIONS(3760),
    [anon_sym_PLUS] = ACTIONS(3760),
    [anon_sym_GT_EQ] = ACTIONS(3762),
    [anon_sym_LT_EQ] = ACTIONS(3762),
    [anon_sym_GT] = ACTIONS(3760),
    [anon_sym_LT] = ACTIONS(3760),
    [anon_sym_LT_GT] = ACTIONS(3762),
    [anon_sym_and] = ACTIONS(3760),
    [anon_sym_AND] = ACTIONS(3760),
    [anon_sym_And] = ACTIONS(3760),
    [anon_sym_or] = ACTIONS(3760),
    [anon_sym_OR] = ACTIONS(3760),
    [anon_sym_Or] = ACTIONS(3760),
    [anon_sym_xor] = ACTIONS(3760),
    [anon_sym_XOR] = ACTIONS(3760),
    [anon_sym_Xor] = ACTIONS(3760),
    [anon_sym_QMARK] = ACTIONS(3762),
    [sym_datetime_literal] = ACTIONS(3762),
    [sym_date_literal] = ACTIONS(3760),
    [sym_time_literal] = ACTIONS(3760),
    [sym_biginteger_literal] = ACTIONS(3762),
    [anon_sym_if] = ACTIONS(3760),
    [anon_sym_IF] = ACTIONS(3760),
    [anon_sym_If] = ACTIONS(3760),
    [anon_sym_else] = ACTIONS(3760),
    [anon_sym_ELSE] = ACTIONS(3760),
    [anon_sym_Else] = ACTIONS(3760),
    [anon_sym_case] = ACTIONS(3760),
    [anon_sym_CASE] = ACTIONS(3760),
    [anon_sym_Case] = ACTIONS(3760),
    [anon_sym_for] = ACTIONS(3760),
    [anon_sym_FOR] = ACTIONS(3760),
    [anon_sym_For] = ACTIONS(3760),
    [anon_sym_foreach] = ACTIONS(3760),
    [anon_sym_FOREACH] = ACTIONS(3760),
    [anon_sym_Foreach] = ACTIONS(3760),
    [anon_sym_while] = ACTIONS(3760),
    [anon_sym_WHILE] = ACTIONS(3760),
    [anon_sym_While] = ACTIONS(3760),
    [anon_sym_repeat] = ACTIONS(3760),
    [anon_sym_REPEAT] = ACTIONS(3760),
    [anon_sym_Repeat] = ACTIONS(3760),
    [anon_sym_exit] = ACTIONS(3760),
    [anon_sym_EXIT] = ACTIONS(3760),
    [anon_sym_Exit] = ACTIONS(3760),
    [anon_sym_continue] = ACTIONS(3760),
    [anon_sym_CONTINUE] = ACTIONS(3760),
    [anon_sym_Continue] = ACTIONS(3760),
    [anon_sym_break] = ACTIONS(3760),
    [anon_sym_BREAK] = ACTIONS(3760),
    [anon_sym_Break] = ACTIONS(3760),
    [anon_sym_with] = ACTIONS(3760),
    [anon_sym_WITH] = ACTIONS(3760),
    [anon_sym_With] = ACTIONS(3760),
    [sym_asserterror_keyword] = ACTIONS(3762),
    [anon_sym_in] = ACTIONS(3760),
    [anon_sym_IN] = ACTIONS(3760),
    [anon_sym_In] = ACTIONS(3760),
    [sym_page_keyword] = ACTIONS(3760),
    [anon_sym_codeunit] = ACTIONS(3760),
    [anon_sym_CODEUNIT] = ACTIONS(3760),
    [anon_sym_Codeunit] = ACTIONS(3760),
    [anon_sym_CodeUnit] = ACTIONS(3760),
    [anon_sym_COdeunit] = ACTIONS(3760),
    [anon_sym_codeUnit] = ACTIONS(3760),
    [sym_report_keyword] = ACTIONS(3760),
    [sym_query_keyword] = ACTIONS(3760),
    [anon_sym_xmlport] = ACTIONS(3760),
    [anon_sym_XMLPORT] = ACTIONS(3760),
    [anon_sym_Xmlport] = ACTIONS(3760),
    [anon_sym_XMLport] = ACTIONS(3760),
    [anon_sym_XMLPort] = ACTIONS(3760),
    [anon_sym_XmlPort] = ACTIONS(3760),
    [anon_sym_enum] = ACTIONS(3760),
    [anon_sym_ENUM] = ACTIONS(3760),
    [anon_sym_Enum] = ACTIONS(3760),
    [anon_sym_eNUM] = ACTIONS(3760),
    [anon_sym_eNum] = ACTIONS(3760),
    [anon_sym_ENum] = ACTIONS(3760),
    [sym_quoted_identifier] = ACTIONS(3762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3762),
    [sym_verbatim_string] = ACTIONS(3762),
    [sym_integer] = ACTIONS(3760),
    [sym_continue_as_identifier] = ACTIONS(3762),
    [sym_preproc_open] = ACTIONS(3762),
    [sym_end_keyword] = ACTIONS(3762),
  },
  [STATE(2032)] = {
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(3703),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_if] = ACTIONS(3703),
    [anon_sym_IF] = ACTIONS(3703),
    [anon_sym_If] = ACTIONS(3703),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_case] = ACTIONS(3703),
    [anon_sym_CASE] = ACTIONS(3703),
    [anon_sym_Case] = ACTIONS(3703),
    [anon_sym_for] = ACTIONS(3703),
    [anon_sym_FOR] = ACTIONS(3703),
    [anon_sym_For] = ACTIONS(3703),
    [anon_sym_foreach] = ACTIONS(3703),
    [anon_sym_FOREACH] = ACTIONS(3703),
    [anon_sym_Foreach] = ACTIONS(3703),
    [anon_sym_while] = ACTIONS(3703),
    [anon_sym_WHILE] = ACTIONS(3703),
    [anon_sym_While] = ACTIONS(3703),
    [anon_sym_repeat] = ACTIONS(3703),
    [anon_sym_REPEAT] = ACTIONS(3703),
    [anon_sym_Repeat] = ACTIONS(3703),
    [anon_sym_exit] = ACTIONS(3703),
    [anon_sym_EXIT] = ACTIONS(3703),
    [anon_sym_Exit] = ACTIONS(3703),
    [anon_sym_continue] = ACTIONS(3703),
    [anon_sym_CONTINUE] = ACTIONS(3703),
    [anon_sym_Continue] = ACTIONS(3703),
    [anon_sym_break] = ACTIONS(3703),
    [anon_sym_BREAK] = ACTIONS(3703),
    [anon_sym_Break] = ACTIONS(3703),
    [anon_sym_with] = ACTIONS(3703),
    [anon_sym_WITH] = ACTIONS(3703),
    [anon_sym_With] = ACTIONS(3703),
    [sym_asserterror_keyword] = ACTIONS(3705),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
    [sym_end_keyword] = ACTIONS(3705),
  },
  [STATE(2033)] = {
    [sym_identifier] = ACTIONS(3752),
    [anon_sym_SEMI] = ACTIONS(3754),
    [anon_sym_DOT] = ACTIONS(3752),
    [anon_sym_EQ] = ACTIONS(3754),
    [anon_sym_COMMA] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3752),
    [aux_sym_boolean_token1] = ACTIONS(3752),
    [aux_sym_boolean_token2] = ACTIONS(3752),
    [sym_decimal] = ACTIONS(3752),
    [anon_sym_LPAREN] = ACTIONS(3754),
    [anon_sym_DOT_DOT] = ACTIONS(3754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3752),
    [anon_sym_STAR] = ACTIONS(3752),
    [anon_sym_LBRACK] = ACTIONS(3754),
    [aux_sym_record_type_token1] = ACTIONS(3752),
    [aux_sym_basic_type_token21] = ACTIONS(3752),
    [aux_sym_basic_type_token22] = ACTIONS(3752),
    [aux_sym_basic_type_token48] = ACTIONS(3752),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3752),
    [anon_sym_POUNDif] = ACTIONS(3754),
    [anon_sym_POUNDIF] = ACTIONS(3754),
    [anon_sym_POUNDIf] = ACTIONS(3754),
    [anon_sym_not] = ACTIONS(3752),
    [anon_sym_NOT] = ACTIONS(3752),
    [anon_sym_Not] = ACTIONS(3752),
    [anon_sym_POUNDelse] = ACTIONS(3754),
    [anon_sym_POUNDELSE] = ACTIONS(3754),
    [anon_sym_POUNDElse] = ACTIONS(3754),
    [anon_sym_POUNDelse2] = ACTIONS(3754),
    [anon_sym_POUNDELSE2] = ACTIONS(3754),
    [anon_sym_POUNDElse2] = ACTIONS(3754),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3754),
    [aux_sym__expression_token1] = ACTIONS(3754),
    [aux_sym__expression_token2] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3752),
    [anon_sym_SLASH] = ACTIONS(3752),
    [anon_sym_div] = ACTIONS(3752),
    [anon_sym_DIV] = ACTIONS(3752),
    [anon_sym_Div] = ACTIONS(3752),
    [anon_sym_mod] = ACTIONS(3752),
    [anon_sym_MOD] = ACTIONS(3752),
    [anon_sym_Mod] = ACTIONS(3752),
    [anon_sym_PLUS] = ACTIONS(3752),
    [anon_sym_GT_EQ] = ACTIONS(3754),
    [anon_sym_LT_EQ] = ACTIONS(3754),
    [anon_sym_GT] = ACTIONS(3752),
    [anon_sym_LT] = ACTIONS(3752),
    [anon_sym_LT_GT] = ACTIONS(3754),
    [anon_sym_and] = ACTIONS(3752),
    [anon_sym_AND] = ACTIONS(3752),
    [anon_sym_And] = ACTIONS(3752),
    [anon_sym_or] = ACTIONS(3752),
    [anon_sym_OR] = ACTIONS(3752),
    [anon_sym_Or] = ACTIONS(3752),
    [anon_sym_xor] = ACTIONS(3752),
    [anon_sym_XOR] = ACTIONS(3752),
    [anon_sym_Xor] = ACTIONS(3752),
    [anon_sym_QMARK] = ACTIONS(3754),
    [sym_datetime_literal] = ACTIONS(3754),
    [sym_date_literal] = ACTIONS(3752),
    [sym_time_literal] = ACTIONS(3752),
    [sym_biginteger_literal] = ACTIONS(3754),
    [anon_sym_if] = ACTIONS(3752),
    [anon_sym_IF] = ACTIONS(3752),
    [anon_sym_If] = ACTIONS(3752),
    [anon_sym_else] = ACTIONS(3752),
    [anon_sym_ELSE] = ACTIONS(3752),
    [anon_sym_Else] = ACTIONS(3752),
    [anon_sym_case] = ACTIONS(3752),
    [anon_sym_CASE] = ACTIONS(3752),
    [anon_sym_Case] = ACTIONS(3752),
    [anon_sym_for] = ACTIONS(3752),
    [anon_sym_FOR] = ACTIONS(3752),
    [anon_sym_For] = ACTIONS(3752),
    [anon_sym_foreach] = ACTIONS(3752),
    [anon_sym_FOREACH] = ACTIONS(3752),
    [anon_sym_Foreach] = ACTIONS(3752),
    [anon_sym_while] = ACTIONS(3752),
    [anon_sym_WHILE] = ACTIONS(3752),
    [anon_sym_While] = ACTIONS(3752),
    [anon_sym_repeat] = ACTIONS(3752),
    [anon_sym_REPEAT] = ACTIONS(3752),
    [anon_sym_Repeat] = ACTIONS(3752),
    [anon_sym_exit] = ACTIONS(3752),
    [anon_sym_EXIT] = ACTIONS(3752),
    [anon_sym_Exit] = ACTIONS(3752),
    [anon_sym_continue] = ACTIONS(3752),
    [anon_sym_CONTINUE] = ACTIONS(3752),
    [anon_sym_Continue] = ACTIONS(3752),
    [anon_sym_break] = ACTIONS(3752),
    [anon_sym_BREAK] = ACTIONS(3752),
    [anon_sym_Break] = ACTIONS(3752),
    [anon_sym_with] = ACTIONS(3752),
    [anon_sym_WITH] = ACTIONS(3752),
    [anon_sym_With] = ACTIONS(3752),
    [sym_asserterror_keyword] = ACTIONS(3754),
    [anon_sym_in] = ACTIONS(3752),
    [anon_sym_IN] = ACTIONS(3752),
    [anon_sym_In] = ACTIONS(3752),
    [sym_page_keyword] = ACTIONS(3752),
    [anon_sym_codeunit] = ACTIONS(3752),
    [anon_sym_CODEUNIT] = ACTIONS(3752),
    [anon_sym_Codeunit] = ACTIONS(3752),
    [anon_sym_CodeUnit] = ACTIONS(3752),
    [anon_sym_COdeunit] = ACTIONS(3752),
    [anon_sym_codeUnit] = ACTIONS(3752),
    [sym_report_keyword] = ACTIONS(3752),
    [sym_query_keyword] = ACTIONS(3752),
    [anon_sym_xmlport] = ACTIONS(3752),
    [anon_sym_XMLPORT] = ACTIONS(3752),
    [anon_sym_Xmlport] = ACTIONS(3752),
    [anon_sym_XMLport] = ACTIONS(3752),
    [anon_sym_XMLPort] = ACTIONS(3752),
    [anon_sym_XmlPort] = ACTIONS(3752),
    [anon_sym_enum] = ACTIONS(3752),
    [anon_sym_ENUM] = ACTIONS(3752),
    [anon_sym_Enum] = ACTIONS(3752),
    [anon_sym_eNUM] = ACTIONS(3752),
    [anon_sym_eNum] = ACTIONS(3752),
    [anon_sym_ENum] = ACTIONS(3752),
    [sym_quoted_identifier] = ACTIONS(3754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3754),
    [sym_verbatim_string] = ACTIONS(3754),
    [sym_integer] = ACTIONS(3752),
    [sym_continue_as_identifier] = ACTIONS(3754),
    [sym_preproc_open] = ACTIONS(3754),
    [sym_end_keyword] = ACTIONS(3754),
  },
  [STATE(2034)] = {
    [sym_identifier] = ACTIONS(3738),
    [anon_sym_SEMI] = ACTIONS(3740),
    [anon_sym_DOT] = ACTIONS(3738),
    [anon_sym_EQ] = ACTIONS(3740),
    [anon_sym_COMMA] = ACTIONS(3740),
    [anon_sym_DASH] = ACTIONS(3738),
    [aux_sym_boolean_token1] = ACTIONS(3738),
    [aux_sym_boolean_token2] = ACTIONS(3738),
    [sym_decimal] = ACTIONS(3738),
    [anon_sym_LPAREN] = ACTIONS(3740),
    [anon_sym_DOT_DOT] = ACTIONS(3740),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3738),
    [anon_sym_STAR] = ACTIONS(3738),
    [anon_sym_LBRACK] = ACTIONS(3740),
    [aux_sym_record_type_token1] = ACTIONS(3738),
    [aux_sym_basic_type_token21] = ACTIONS(3738),
    [aux_sym_basic_type_token22] = ACTIONS(3738),
    [aux_sym_basic_type_token48] = ACTIONS(3738),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3738),
    [anon_sym_POUNDif] = ACTIONS(3740),
    [anon_sym_POUNDIF] = ACTIONS(3740),
    [anon_sym_POUNDIf] = ACTIONS(3740),
    [anon_sym_not] = ACTIONS(3738),
    [anon_sym_NOT] = ACTIONS(3738),
    [anon_sym_Not] = ACTIONS(3738),
    [anon_sym_POUNDelse] = ACTIONS(3740),
    [anon_sym_POUNDELSE] = ACTIONS(3740),
    [anon_sym_POUNDElse] = ACTIONS(3740),
    [anon_sym_POUNDelse2] = ACTIONS(3740),
    [anon_sym_POUNDELSE2] = ACTIONS(3740),
    [anon_sym_POUNDElse2] = ACTIONS(3740),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3740),
    [aux_sym__expression_token1] = ACTIONS(3740),
    [aux_sym__expression_token2] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3738),
    [anon_sym_SLASH] = ACTIONS(3738),
    [anon_sym_div] = ACTIONS(3738),
    [anon_sym_DIV] = ACTIONS(3738),
    [anon_sym_Div] = ACTIONS(3738),
    [anon_sym_mod] = ACTIONS(3738),
    [anon_sym_MOD] = ACTIONS(3738),
    [anon_sym_Mod] = ACTIONS(3738),
    [anon_sym_PLUS] = ACTIONS(3738),
    [anon_sym_GT_EQ] = ACTIONS(3740),
    [anon_sym_LT_EQ] = ACTIONS(3740),
    [anon_sym_GT] = ACTIONS(3738),
    [anon_sym_LT] = ACTIONS(3738),
    [anon_sym_LT_GT] = ACTIONS(3740),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3738),
    [anon_sym_And] = ACTIONS(3738),
    [anon_sym_or] = ACTIONS(3738),
    [anon_sym_OR] = ACTIONS(3738),
    [anon_sym_Or] = ACTIONS(3738),
    [anon_sym_xor] = ACTIONS(3738),
    [anon_sym_XOR] = ACTIONS(3738),
    [anon_sym_Xor] = ACTIONS(3738),
    [anon_sym_QMARK] = ACTIONS(3740),
    [sym_datetime_literal] = ACTIONS(3740),
    [sym_date_literal] = ACTIONS(3738),
    [sym_time_literal] = ACTIONS(3738),
    [sym_biginteger_literal] = ACTIONS(3740),
    [anon_sym_if] = ACTIONS(3738),
    [anon_sym_IF] = ACTIONS(3738),
    [anon_sym_If] = ACTIONS(3738),
    [anon_sym_else] = ACTIONS(3738),
    [anon_sym_ELSE] = ACTIONS(3738),
    [anon_sym_Else] = ACTIONS(3738),
    [anon_sym_case] = ACTIONS(3738),
    [anon_sym_CASE] = ACTIONS(3738),
    [anon_sym_Case] = ACTIONS(3738),
    [anon_sym_for] = ACTIONS(3738),
    [anon_sym_FOR] = ACTIONS(3738),
    [anon_sym_For] = ACTIONS(3738),
    [anon_sym_foreach] = ACTIONS(3738),
    [anon_sym_FOREACH] = ACTIONS(3738),
    [anon_sym_Foreach] = ACTIONS(3738),
    [anon_sym_while] = ACTIONS(3738),
    [anon_sym_WHILE] = ACTIONS(3738),
    [anon_sym_While] = ACTIONS(3738),
    [anon_sym_repeat] = ACTIONS(3738),
    [anon_sym_REPEAT] = ACTIONS(3738),
    [anon_sym_Repeat] = ACTIONS(3738),
    [anon_sym_exit] = ACTIONS(3738),
    [anon_sym_EXIT] = ACTIONS(3738),
    [anon_sym_Exit] = ACTIONS(3738),
    [anon_sym_continue] = ACTIONS(3738),
    [anon_sym_CONTINUE] = ACTIONS(3738),
    [anon_sym_Continue] = ACTIONS(3738),
    [anon_sym_break] = ACTIONS(3738),
    [anon_sym_BREAK] = ACTIONS(3738),
    [anon_sym_Break] = ACTIONS(3738),
    [anon_sym_with] = ACTIONS(3738),
    [anon_sym_WITH] = ACTIONS(3738),
    [anon_sym_With] = ACTIONS(3738),
    [sym_asserterror_keyword] = ACTIONS(3740),
    [anon_sym_in] = ACTIONS(3738),
    [anon_sym_IN] = ACTIONS(3738),
    [anon_sym_In] = ACTIONS(3738),
    [sym_page_keyword] = ACTIONS(3738),
    [anon_sym_codeunit] = ACTIONS(3738),
    [anon_sym_CODEUNIT] = ACTIONS(3738),
    [anon_sym_Codeunit] = ACTIONS(3738),
    [anon_sym_CodeUnit] = ACTIONS(3738),
    [anon_sym_COdeunit] = ACTIONS(3738),
    [anon_sym_codeUnit] = ACTIONS(3738),
    [sym_report_keyword] = ACTIONS(3738),
    [sym_query_keyword] = ACTIONS(3738),
    [anon_sym_xmlport] = ACTIONS(3738),
    [anon_sym_XMLPORT] = ACTIONS(3738),
    [anon_sym_Xmlport] = ACTIONS(3738),
    [anon_sym_XMLport] = ACTIONS(3738),
    [anon_sym_XMLPort] = ACTIONS(3738),
    [anon_sym_XmlPort] = ACTIONS(3738),
    [anon_sym_enum] = ACTIONS(3738),
    [anon_sym_ENUM] = ACTIONS(3738),
    [anon_sym_Enum] = ACTIONS(3738),
    [anon_sym_eNUM] = ACTIONS(3738),
    [anon_sym_eNum] = ACTIONS(3738),
    [anon_sym_ENum] = ACTIONS(3738),
    [sym_quoted_identifier] = ACTIONS(3740),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3740),
    [sym_verbatim_string] = ACTIONS(3740),
    [sym_integer] = ACTIONS(3738),
    [sym_continue_as_identifier] = ACTIONS(3740),
    [sym_preproc_open] = ACTIONS(3740),
    [sym_end_keyword] = ACTIONS(3740),
  },
  [STATE(2035)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(4355),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_end_keyword] = ACTIONS(3665),
  },
  [STATE(2036)] = {
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(3634),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_if] = ACTIONS(3632),
    [anon_sym_IF] = ACTIONS(3632),
    [anon_sym_If] = ACTIONS(3632),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_case] = ACTIONS(3632),
    [anon_sym_CASE] = ACTIONS(3632),
    [anon_sym_Case] = ACTIONS(3632),
    [anon_sym_for] = ACTIONS(3632),
    [anon_sym_FOR] = ACTIONS(3632),
    [anon_sym_For] = ACTIONS(3632),
    [anon_sym_foreach] = ACTIONS(3632),
    [anon_sym_FOREACH] = ACTIONS(3632),
    [anon_sym_Foreach] = ACTIONS(3632),
    [anon_sym_while] = ACTIONS(3632),
    [anon_sym_WHILE] = ACTIONS(3632),
    [anon_sym_While] = ACTIONS(3632),
    [anon_sym_repeat] = ACTIONS(3632),
    [anon_sym_REPEAT] = ACTIONS(3632),
    [anon_sym_Repeat] = ACTIONS(3632),
    [anon_sym_exit] = ACTIONS(3632),
    [anon_sym_EXIT] = ACTIONS(3632),
    [anon_sym_Exit] = ACTIONS(3632),
    [anon_sym_continue] = ACTIONS(3632),
    [anon_sym_CONTINUE] = ACTIONS(3632),
    [anon_sym_Continue] = ACTIONS(3632),
    [anon_sym_break] = ACTIONS(3632),
    [anon_sym_BREAK] = ACTIONS(3632),
    [anon_sym_Break] = ACTIONS(3632),
    [anon_sym_with] = ACTIONS(3632),
    [anon_sym_WITH] = ACTIONS(3632),
    [anon_sym_With] = ACTIONS(3632),
    [sym_asserterror_keyword] = ACTIONS(3634),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
    [sym_end_keyword] = ACTIONS(3634),
  },
  [STATE(2037)] = {
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_SEMI] = ACTIONS(3748),
    [anon_sym_DOT] = ACTIONS(3746),
    [anon_sym_EQ] = ACTIONS(3748),
    [anon_sym_DASH] = ACTIONS(3746),
    [aux_sym_boolean_token1] = ACTIONS(3746),
    [aux_sym_boolean_token2] = ACTIONS(3746),
    [sym_decimal] = ACTIONS(3746),
    [anon_sym_LPAREN] = ACTIONS(3748),
    [anon_sym_DOT_DOT] = ACTIONS(3748),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3746),
    [anon_sym_STAR] = ACTIONS(3746),
    [anon_sym_LBRACK] = ACTIONS(3748),
    [aux_sym_record_type_token1] = ACTIONS(3746),
    [aux_sym_basic_type_token21] = ACTIONS(3746),
    [aux_sym_basic_type_token22] = ACTIONS(3746),
    [aux_sym_basic_type_token48] = ACTIONS(3746),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3746),
    [anon_sym_POUNDif] = ACTIONS(3748),
    [anon_sym_POUNDIF] = ACTIONS(3748),
    [anon_sym_POUNDIf] = ACTIONS(3748),
    [anon_sym_not] = ACTIONS(3746),
    [anon_sym_NOT] = ACTIONS(3746),
    [anon_sym_Not] = ACTIONS(3746),
    [anon_sym_POUNDelse] = ACTIONS(3748),
    [anon_sym_POUNDELSE] = ACTIONS(3748),
    [anon_sym_POUNDElse] = ACTIONS(3748),
    [anon_sym_POUNDelse2] = ACTIONS(3748),
    [anon_sym_POUNDELSE2] = ACTIONS(3748),
    [anon_sym_POUNDElse2] = ACTIONS(3748),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3748),
    [aux_sym__expression_token1] = ACTIONS(3748),
    [aux_sym__expression_token2] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3746),
    [anon_sym_SLASH] = ACTIONS(3746),
    [anon_sym_div] = ACTIONS(3746),
    [anon_sym_DIV] = ACTIONS(3746),
    [anon_sym_Div] = ACTIONS(3746),
    [anon_sym_mod] = ACTIONS(3746),
    [anon_sym_MOD] = ACTIONS(3746),
    [anon_sym_Mod] = ACTIONS(3746),
    [anon_sym_PLUS] = ACTIONS(3746),
    [anon_sym_GT_EQ] = ACTIONS(3748),
    [anon_sym_LT_EQ] = ACTIONS(3748),
    [anon_sym_GT] = ACTIONS(3746),
    [anon_sym_LT] = ACTIONS(3746),
    [anon_sym_LT_GT] = ACTIONS(3748),
    [anon_sym_and] = ACTIONS(3746),
    [anon_sym_AND] = ACTIONS(3746),
    [anon_sym_And] = ACTIONS(3746),
    [anon_sym_or] = ACTIONS(3746),
    [anon_sym_OR] = ACTIONS(3746),
    [anon_sym_Or] = ACTIONS(3746),
    [anon_sym_xor] = ACTIONS(3746),
    [anon_sym_XOR] = ACTIONS(3746),
    [anon_sym_Xor] = ACTIONS(3746),
    [anon_sym_QMARK] = ACTIONS(3748),
    [sym_datetime_literal] = ACTIONS(3748),
    [sym_date_literal] = ACTIONS(3746),
    [sym_time_literal] = ACTIONS(3746),
    [sym_biginteger_literal] = ACTIONS(3748),
    [anon_sym_if] = ACTIONS(3746),
    [anon_sym_IF] = ACTIONS(3746),
    [anon_sym_If] = ACTIONS(3746),
    [anon_sym_else] = ACTIONS(3746),
    [anon_sym_ELSE] = ACTIONS(3746),
    [anon_sym_Else] = ACTIONS(3746),
    [anon_sym_case] = ACTIONS(3746),
    [anon_sym_CASE] = ACTIONS(3746),
    [anon_sym_Case] = ACTIONS(3746),
    [anon_sym_for] = ACTIONS(3746),
    [anon_sym_FOR] = ACTIONS(3746),
    [anon_sym_For] = ACTIONS(3746),
    [anon_sym_foreach] = ACTIONS(3746),
    [anon_sym_FOREACH] = ACTIONS(3746),
    [anon_sym_Foreach] = ACTIONS(3746),
    [anon_sym_while] = ACTIONS(3746),
    [anon_sym_WHILE] = ACTIONS(3746),
    [anon_sym_While] = ACTIONS(3746),
    [anon_sym_repeat] = ACTIONS(3746),
    [anon_sym_REPEAT] = ACTIONS(3746),
    [anon_sym_Repeat] = ACTIONS(3746),
    [anon_sym_exit] = ACTIONS(3746),
    [anon_sym_EXIT] = ACTIONS(3746),
    [anon_sym_Exit] = ACTIONS(3746),
    [anon_sym_continue] = ACTIONS(3746),
    [anon_sym_CONTINUE] = ACTIONS(3746),
    [anon_sym_Continue] = ACTIONS(3746),
    [anon_sym_break] = ACTIONS(3746),
    [anon_sym_BREAK] = ACTIONS(3746),
    [anon_sym_Break] = ACTIONS(3746),
    [anon_sym_with] = ACTIONS(3746),
    [anon_sym_WITH] = ACTIONS(3746),
    [anon_sym_With] = ACTIONS(3746),
    [sym_asserterror_keyword] = ACTIONS(3748),
    [anon_sym_in] = ACTIONS(3746),
    [anon_sym_IN] = ACTIONS(3746),
    [anon_sym_In] = ACTIONS(3746),
    [sym_page_keyword] = ACTIONS(3746),
    [anon_sym_codeunit] = ACTIONS(3746),
    [anon_sym_CODEUNIT] = ACTIONS(3746),
    [anon_sym_Codeunit] = ACTIONS(3746),
    [anon_sym_CodeUnit] = ACTIONS(3746),
    [anon_sym_COdeunit] = ACTIONS(3746),
    [anon_sym_codeUnit] = ACTIONS(3746),
    [sym_report_keyword] = ACTIONS(3746),
    [sym_query_keyword] = ACTIONS(3746),
    [anon_sym_xmlport] = ACTIONS(3746),
    [anon_sym_XMLPORT] = ACTIONS(3746),
    [anon_sym_Xmlport] = ACTIONS(3746),
    [anon_sym_XMLport] = ACTIONS(3746),
    [anon_sym_XMLPort] = ACTIONS(3746),
    [anon_sym_XmlPort] = ACTIONS(3746),
    [anon_sym_enum] = ACTIONS(3746),
    [anon_sym_ENUM] = ACTIONS(3746),
    [anon_sym_Enum] = ACTIONS(3746),
    [anon_sym_eNUM] = ACTIONS(3746),
    [anon_sym_eNum] = ACTIONS(3746),
    [anon_sym_ENum] = ACTIONS(3746),
    [sym_temporary_keyword] = ACTIONS(4357),
    [sym_quoted_identifier] = ACTIONS(3748),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3748),
    [sym_verbatim_string] = ACTIONS(3748),
    [sym_integer] = ACTIONS(3746),
    [sym_continue_as_identifier] = ACTIONS(3748),
    [sym_preproc_open] = ACTIONS(3748),
    [sym_end_keyword] = ACTIONS(3748),
  },
  [STATE(2038)] = {
    [sym_identifier] = ACTIONS(3784),
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [aux_sym_boolean_token1] = ACTIONS(3784),
    [aux_sym_boolean_token2] = ACTIONS(3784),
    [sym_decimal] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3784),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_record_type_token1] = ACTIONS(3784),
    [aux_sym_basic_type_token21] = ACTIONS(3784),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_basic_type_token48] = ACTIONS(3784),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_not] = ACTIONS(3784),
    [anon_sym_NOT] = ACTIONS(3784),
    [anon_sym_Not] = ACTIONS(3784),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3784),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3784),
    [anon_sym_DIV] = ACTIONS(3784),
    [anon_sym_Div] = ACTIONS(3784),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3784),
    [anon_sym_AND] = ACTIONS(3784),
    [anon_sym_And] = ACTIONS(3784),
    [anon_sym_or] = ACTIONS(3784),
    [anon_sym_OR] = ACTIONS(3784),
    [anon_sym_Or] = ACTIONS(3784),
    [anon_sym_xor] = ACTIONS(3784),
    [anon_sym_XOR] = ACTIONS(3784),
    [anon_sym_Xor] = ACTIONS(3784),
    [anon_sym_QMARK] = ACTIONS(3786),
    [sym_datetime_literal] = ACTIONS(3786),
    [sym_date_literal] = ACTIONS(3784),
    [sym_time_literal] = ACTIONS(3784),
    [sym_biginteger_literal] = ACTIONS(3786),
    [anon_sym_if] = ACTIONS(3784),
    [anon_sym_IF] = ACTIONS(3784),
    [anon_sym_If] = ACTIONS(3784),
    [anon_sym_else] = ACTIONS(3784),
    [anon_sym_ELSE] = ACTIONS(3784),
    [anon_sym_Else] = ACTIONS(3784),
    [anon_sym_case] = ACTIONS(3784),
    [anon_sym_CASE] = ACTIONS(3784),
    [anon_sym_Case] = ACTIONS(3784),
    [anon_sym_for] = ACTIONS(3784),
    [anon_sym_FOR] = ACTIONS(3784),
    [anon_sym_For] = ACTIONS(3784),
    [anon_sym_foreach] = ACTIONS(3784),
    [anon_sym_FOREACH] = ACTIONS(3784),
    [anon_sym_Foreach] = ACTIONS(3784),
    [anon_sym_while] = ACTIONS(3784),
    [anon_sym_WHILE] = ACTIONS(3784),
    [anon_sym_While] = ACTIONS(3784),
    [anon_sym_repeat] = ACTIONS(3784),
    [anon_sym_REPEAT] = ACTIONS(3784),
    [anon_sym_Repeat] = ACTIONS(3784),
    [anon_sym_exit] = ACTIONS(3784),
    [anon_sym_EXIT] = ACTIONS(3784),
    [anon_sym_Exit] = ACTIONS(3784),
    [anon_sym_continue] = ACTIONS(3784),
    [anon_sym_CONTINUE] = ACTIONS(3784),
    [anon_sym_Continue] = ACTIONS(3784),
    [anon_sym_break] = ACTIONS(3784),
    [anon_sym_BREAK] = ACTIONS(3784),
    [anon_sym_Break] = ACTIONS(3784),
    [anon_sym_with] = ACTIONS(3784),
    [anon_sym_WITH] = ACTIONS(3784),
    [anon_sym_With] = ACTIONS(3784),
    [sym_asserterror_keyword] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_page_keyword] = ACTIONS(3784),
    [anon_sym_codeunit] = ACTIONS(3784),
    [anon_sym_CODEUNIT] = ACTIONS(3784),
    [anon_sym_Codeunit] = ACTIONS(3784),
    [anon_sym_CodeUnit] = ACTIONS(3784),
    [anon_sym_COdeunit] = ACTIONS(3784),
    [anon_sym_codeUnit] = ACTIONS(3784),
    [sym_report_keyword] = ACTIONS(3784),
    [sym_query_keyword] = ACTIONS(3784),
    [anon_sym_xmlport] = ACTIONS(3784),
    [anon_sym_XMLPORT] = ACTIONS(3784),
    [anon_sym_Xmlport] = ACTIONS(3784),
    [anon_sym_XMLport] = ACTIONS(3784),
    [anon_sym_XMLPort] = ACTIONS(3784),
    [anon_sym_XmlPort] = ACTIONS(3784),
    [anon_sym_enum] = ACTIONS(3784),
    [anon_sym_ENUM] = ACTIONS(3784),
    [anon_sym_Enum] = ACTIONS(3784),
    [anon_sym_eNUM] = ACTIONS(3784),
    [anon_sym_eNum] = ACTIONS(3784),
    [anon_sym_ENum] = ACTIONS(3784),
    [sym_quoted_identifier] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3786),
    [sym_verbatim_string] = ACTIONS(3786),
    [sym_integer] = ACTIONS(3784),
    [sym_continue_as_identifier] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
    [sym_end_keyword] = ACTIONS(3786),
  },
  [STATE(2039)] = {
    [sym_identifier] = ACTIONS(3756),
    [anon_sym_SEMI] = ACTIONS(3758),
    [anon_sym_DOT] = ACTIONS(3756),
    [anon_sym_EQ] = ACTIONS(3758),
    [anon_sym_DASH] = ACTIONS(3756),
    [aux_sym_boolean_token1] = ACTIONS(3756),
    [aux_sym_boolean_token2] = ACTIONS(3756),
    [sym_decimal] = ACTIONS(3756),
    [anon_sym_LPAREN] = ACTIONS(3758),
    [anon_sym_DOT_DOT] = ACTIONS(3758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3756),
    [anon_sym_LBRACK] = ACTIONS(3758),
    [aux_sym_record_type_token1] = ACTIONS(3756),
    [aux_sym_basic_type_token21] = ACTIONS(3756),
    [aux_sym_basic_type_token22] = ACTIONS(3756),
    [aux_sym_basic_type_token48] = ACTIONS(3756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3756),
    [anon_sym_COLON_COLON] = ACTIONS(3758),
    [anon_sym_POUNDif] = ACTIONS(3758),
    [anon_sym_POUNDIF] = ACTIONS(3758),
    [anon_sym_POUNDIf] = ACTIONS(3758),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_NOT] = ACTIONS(3756),
    [anon_sym_Not] = ACTIONS(3756),
    [anon_sym_POUNDelse] = ACTIONS(3758),
    [anon_sym_POUNDELSE] = ACTIONS(3758),
    [anon_sym_POUNDElse] = ACTIONS(3758),
    [anon_sym_POUNDelse2] = ACTIONS(3758),
    [anon_sym_POUNDELSE2] = ACTIONS(3758),
    [anon_sym_POUNDElse2] = ACTIONS(3758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3758),
    [aux_sym__expression_token1] = ACTIONS(3758),
    [aux_sym__expression_token2] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3756),
    [anon_sym_SLASH] = ACTIONS(3756),
    [anon_sym_div] = ACTIONS(3756),
    [anon_sym_DIV] = ACTIONS(3756),
    [anon_sym_Div] = ACTIONS(3756),
    [anon_sym_mod] = ACTIONS(3756),
    [anon_sym_MOD] = ACTIONS(3756),
    [anon_sym_Mod] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_GT_EQ] = ACTIONS(3758),
    [anon_sym_LT_EQ] = ACTIONS(3758),
    [anon_sym_GT] = ACTIONS(3756),
    [anon_sym_LT] = ACTIONS(3756),
    [anon_sym_LT_GT] = ACTIONS(3758),
    [anon_sym_and] = ACTIONS(3756),
    [anon_sym_AND] = ACTIONS(3756),
    [anon_sym_And] = ACTIONS(3756),
    [anon_sym_or] = ACTIONS(3756),
    [anon_sym_OR] = ACTIONS(3756),
    [anon_sym_Or] = ACTIONS(3756),
    [anon_sym_xor] = ACTIONS(3756),
    [anon_sym_XOR] = ACTIONS(3756),
    [anon_sym_Xor] = ACTIONS(3756),
    [anon_sym_QMARK] = ACTIONS(3758),
    [sym_datetime_literal] = ACTIONS(3758),
    [sym_date_literal] = ACTIONS(3756),
    [sym_time_literal] = ACTIONS(3756),
    [sym_biginteger_literal] = ACTIONS(3758),
    [anon_sym_if] = ACTIONS(3756),
    [anon_sym_IF] = ACTIONS(3756),
    [anon_sym_If] = ACTIONS(3756),
    [anon_sym_else] = ACTIONS(3756),
    [anon_sym_ELSE] = ACTIONS(3756),
    [anon_sym_Else] = ACTIONS(3756),
    [anon_sym_case] = ACTIONS(3756),
    [anon_sym_CASE] = ACTIONS(3756),
    [anon_sym_Case] = ACTIONS(3756),
    [anon_sym_for] = ACTIONS(3756),
    [anon_sym_FOR] = ACTIONS(3756),
    [anon_sym_For] = ACTIONS(3756),
    [anon_sym_foreach] = ACTIONS(3756),
    [anon_sym_FOREACH] = ACTIONS(3756),
    [anon_sym_Foreach] = ACTIONS(3756),
    [anon_sym_while] = ACTIONS(3756),
    [anon_sym_WHILE] = ACTIONS(3756),
    [anon_sym_While] = ACTIONS(3756),
    [anon_sym_repeat] = ACTIONS(3756),
    [anon_sym_REPEAT] = ACTIONS(3756),
    [anon_sym_Repeat] = ACTIONS(3756),
    [anon_sym_exit] = ACTIONS(3756),
    [anon_sym_EXIT] = ACTIONS(3756),
    [anon_sym_Exit] = ACTIONS(3756),
    [anon_sym_continue] = ACTIONS(3756),
    [anon_sym_CONTINUE] = ACTIONS(3756),
    [anon_sym_Continue] = ACTIONS(3756),
    [anon_sym_break] = ACTIONS(3756),
    [anon_sym_BREAK] = ACTIONS(3756),
    [anon_sym_Break] = ACTIONS(3756),
    [anon_sym_with] = ACTIONS(3756),
    [anon_sym_WITH] = ACTIONS(3756),
    [anon_sym_With] = ACTIONS(3756),
    [sym_asserterror_keyword] = ACTIONS(3758),
    [anon_sym_in] = ACTIONS(3756),
    [anon_sym_IN] = ACTIONS(3756),
    [anon_sym_In] = ACTIONS(3756),
    [sym_page_keyword] = ACTIONS(3756),
    [anon_sym_codeunit] = ACTIONS(3756),
    [anon_sym_CODEUNIT] = ACTIONS(3756),
    [anon_sym_Codeunit] = ACTIONS(3756),
    [anon_sym_CodeUnit] = ACTIONS(3756),
    [anon_sym_COdeunit] = ACTIONS(3756),
    [anon_sym_codeUnit] = ACTIONS(3756),
    [sym_report_keyword] = ACTIONS(3756),
    [sym_query_keyword] = ACTIONS(3756),
    [anon_sym_xmlport] = ACTIONS(3756),
    [anon_sym_XMLPORT] = ACTIONS(3756),
    [anon_sym_Xmlport] = ACTIONS(3756),
    [anon_sym_XMLport] = ACTIONS(3756),
    [anon_sym_XMLPort] = ACTIONS(3756),
    [anon_sym_XmlPort] = ACTIONS(3756),
    [anon_sym_enum] = ACTIONS(3756),
    [anon_sym_ENUM] = ACTIONS(3756),
    [anon_sym_Enum] = ACTIONS(3756),
    [anon_sym_eNUM] = ACTIONS(3756),
    [anon_sym_eNum] = ACTIONS(3756),
    [anon_sym_ENum] = ACTIONS(3756),
    [sym_quoted_identifier] = ACTIONS(3758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3758),
    [sym_verbatim_string] = ACTIONS(3758),
    [sym_integer] = ACTIONS(3756),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_open] = ACTIONS(3758),
    [sym_end_keyword] = ACTIONS(3758),
  },
  [STATE(2040)] = {
    [sym_identifier] = ACTIONS(3764),
    [anon_sym_SEMI] = ACTIONS(3766),
    [anon_sym_DOT] = ACTIONS(3764),
    [anon_sym_EQ] = ACTIONS(3766),
    [anon_sym_DASH] = ACTIONS(3764),
    [aux_sym_boolean_token1] = ACTIONS(3764),
    [aux_sym_boolean_token2] = ACTIONS(3764),
    [sym_decimal] = ACTIONS(3764),
    [anon_sym_LPAREN] = ACTIONS(3766),
    [anon_sym_DOT_DOT] = ACTIONS(3766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3764),
    [anon_sym_STAR] = ACTIONS(3764),
    [anon_sym_LBRACK] = ACTIONS(3766),
    [aux_sym_record_type_token1] = ACTIONS(3764),
    [aux_sym_basic_type_token21] = ACTIONS(3764),
    [aux_sym_basic_type_token22] = ACTIONS(3764),
    [aux_sym_basic_type_token48] = ACTIONS(3764),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3764),
    [anon_sym_COLON_COLON] = ACTIONS(3766),
    [anon_sym_POUNDif] = ACTIONS(3766),
    [anon_sym_POUNDIF] = ACTIONS(3766),
    [anon_sym_POUNDIf] = ACTIONS(3766),
    [anon_sym_not] = ACTIONS(3764),
    [anon_sym_NOT] = ACTIONS(3764),
    [anon_sym_Not] = ACTIONS(3764),
    [anon_sym_POUNDelse] = ACTIONS(3766),
    [anon_sym_POUNDELSE] = ACTIONS(3766),
    [anon_sym_POUNDElse] = ACTIONS(3766),
    [anon_sym_POUNDelse2] = ACTIONS(3766),
    [anon_sym_POUNDELSE2] = ACTIONS(3766),
    [anon_sym_POUNDElse2] = ACTIONS(3766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3766),
    [aux_sym__expression_token1] = ACTIONS(3766),
    [aux_sym__expression_token2] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3764),
    [anon_sym_SLASH] = ACTIONS(3764),
    [anon_sym_div] = ACTIONS(3764),
    [anon_sym_DIV] = ACTIONS(3764),
    [anon_sym_Div] = ACTIONS(3764),
    [anon_sym_mod] = ACTIONS(3764),
    [anon_sym_MOD] = ACTIONS(3764),
    [anon_sym_Mod] = ACTIONS(3764),
    [anon_sym_PLUS] = ACTIONS(3764),
    [anon_sym_GT_EQ] = ACTIONS(3766),
    [anon_sym_LT_EQ] = ACTIONS(3766),
    [anon_sym_GT] = ACTIONS(3764),
    [anon_sym_LT] = ACTIONS(3764),
    [anon_sym_LT_GT] = ACTIONS(3766),
    [anon_sym_and] = ACTIONS(3764),
    [anon_sym_AND] = ACTIONS(3764),
    [anon_sym_And] = ACTIONS(3764),
    [anon_sym_or] = ACTIONS(3764),
    [anon_sym_OR] = ACTIONS(3764),
    [anon_sym_Or] = ACTIONS(3764),
    [anon_sym_xor] = ACTIONS(3764),
    [anon_sym_XOR] = ACTIONS(3764),
    [anon_sym_Xor] = ACTIONS(3764),
    [anon_sym_QMARK] = ACTIONS(3766),
    [sym_datetime_literal] = ACTIONS(3766),
    [sym_date_literal] = ACTIONS(3764),
    [sym_time_literal] = ACTIONS(3764),
    [sym_biginteger_literal] = ACTIONS(3766),
    [anon_sym_if] = ACTIONS(3764),
    [anon_sym_IF] = ACTIONS(3764),
    [anon_sym_If] = ACTIONS(3764),
    [anon_sym_else] = ACTIONS(3764),
    [anon_sym_ELSE] = ACTIONS(3764),
    [anon_sym_Else] = ACTIONS(3764),
    [anon_sym_case] = ACTIONS(3764),
    [anon_sym_CASE] = ACTIONS(3764),
    [anon_sym_Case] = ACTIONS(3764),
    [anon_sym_for] = ACTIONS(3764),
    [anon_sym_FOR] = ACTIONS(3764),
    [anon_sym_For] = ACTIONS(3764),
    [anon_sym_foreach] = ACTIONS(3764),
    [anon_sym_FOREACH] = ACTIONS(3764),
    [anon_sym_Foreach] = ACTIONS(3764),
    [anon_sym_while] = ACTIONS(3764),
    [anon_sym_WHILE] = ACTIONS(3764),
    [anon_sym_While] = ACTIONS(3764),
    [anon_sym_repeat] = ACTIONS(3764),
    [anon_sym_REPEAT] = ACTIONS(3764),
    [anon_sym_Repeat] = ACTIONS(3764),
    [anon_sym_exit] = ACTIONS(3764),
    [anon_sym_EXIT] = ACTIONS(3764),
    [anon_sym_Exit] = ACTIONS(3764),
    [anon_sym_continue] = ACTIONS(3764),
    [anon_sym_CONTINUE] = ACTIONS(3764),
    [anon_sym_Continue] = ACTIONS(3764),
    [anon_sym_break] = ACTIONS(3764),
    [anon_sym_BREAK] = ACTIONS(3764),
    [anon_sym_Break] = ACTIONS(3764),
    [anon_sym_with] = ACTIONS(3764),
    [anon_sym_WITH] = ACTIONS(3764),
    [anon_sym_With] = ACTIONS(3764),
    [sym_asserterror_keyword] = ACTIONS(3766),
    [anon_sym_in] = ACTIONS(3764),
    [anon_sym_IN] = ACTIONS(3764),
    [anon_sym_In] = ACTIONS(3764),
    [sym_page_keyword] = ACTIONS(3764),
    [anon_sym_codeunit] = ACTIONS(3764),
    [anon_sym_CODEUNIT] = ACTIONS(3764),
    [anon_sym_Codeunit] = ACTIONS(3764),
    [anon_sym_CodeUnit] = ACTIONS(3764),
    [anon_sym_COdeunit] = ACTIONS(3764),
    [anon_sym_codeUnit] = ACTIONS(3764),
    [sym_report_keyword] = ACTIONS(3764),
    [sym_query_keyword] = ACTIONS(3764),
    [anon_sym_xmlport] = ACTIONS(3764),
    [anon_sym_XMLPORT] = ACTIONS(3764),
    [anon_sym_Xmlport] = ACTIONS(3764),
    [anon_sym_XMLport] = ACTIONS(3764),
    [anon_sym_XMLPort] = ACTIONS(3764),
    [anon_sym_XmlPort] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3764),
    [anon_sym_ENUM] = ACTIONS(3764),
    [anon_sym_Enum] = ACTIONS(3764),
    [anon_sym_eNUM] = ACTIONS(3764),
    [anon_sym_eNum] = ACTIONS(3764),
    [anon_sym_ENum] = ACTIONS(3764),
    [sym_quoted_identifier] = ACTIONS(3766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3766),
    [sym_verbatim_string] = ACTIONS(3766),
    [sym_integer] = ACTIONS(3764),
    [sym_continue_as_identifier] = ACTIONS(3766),
    [sym_preproc_open] = ACTIONS(3766),
    [sym_end_keyword] = ACTIONS(3766),
  },
  [STATE(2041)] = {
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(4346),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_IF] = ACTIONS(3681),
    [anon_sym_If] = ACTIONS(3681),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_case] = ACTIONS(3681),
    [anon_sym_CASE] = ACTIONS(3681),
    [anon_sym_Case] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_FOR] = ACTIONS(3681),
    [anon_sym_For] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_FOREACH] = ACTIONS(3681),
    [anon_sym_Foreach] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_WHILE] = ACTIONS(3681),
    [anon_sym_While] = ACTIONS(3681),
    [anon_sym_repeat] = ACTIONS(3681),
    [anon_sym_REPEAT] = ACTIONS(3681),
    [anon_sym_Repeat] = ACTIONS(3681),
    [anon_sym_exit] = ACTIONS(3681),
    [anon_sym_EXIT] = ACTIONS(3681),
    [anon_sym_Exit] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_CONTINUE] = ACTIONS(3681),
    [anon_sym_Continue] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_BREAK] = ACTIONS(3681),
    [anon_sym_Break] = ACTIONS(3681),
    [anon_sym_with] = ACTIONS(3681),
    [anon_sym_WITH] = ACTIONS(3681),
    [anon_sym_With] = ACTIONS(3681),
    [sym_asserterror_keyword] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
    [sym_end_keyword] = ACTIONS(3683),
  },
  [STATE(2042)] = {
    [sym_identifier] = ACTIONS(3768),
    [anon_sym_SEMI] = ACTIONS(3770),
    [anon_sym_DOT] = ACTIONS(3768),
    [anon_sym_EQ] = ACTIONS(3770),
    [anon_sym_DASH] = ACTIONS(3768),
    [aux_sym_boolean_token1] = ACTIONS(3768),
    [aux_sym_boolean_token2] = ACTIONS(3768),
    [sym_decimal] = ACTIONS(3768),
    [anon_sym_LPAREN] = ACTIONS(3770),
    [anon_sym_DOT_DOT] = ACTIONS(3770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3768),
    [anon_sym_STAR] = ACTIONS(3768),
    [anon_sym_LBRACK] = ACTIONS(3770),
    [aux_sym_record_type_token1] = ACTIONS(3768),
    [aux_sym_basic_type_token21] = ACTIONS(3768),
    [aux_sym_basic_type_token22] = ACTIONS(3768),
    [aux_sym_basic_type_token48] = ACTIONS(3768),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3768),
    [anon_sym_COLON_COLON] = ACTIONS(3770),
    [anon_sym_POUNDif] = ACTIONS(3770),
    [anon_sym_POUNDIF] = ACTIONS(3770),
    [anon_sym_POUNDIf] = ACTIONS(3770),
    [anon_sym_not] = ACTIONS(3768),
    [anon_sym_NOT] = ACTIONS(3768),
    [anon_sym_Not] = ACTIONS(3768),
    [anon_sym_POUNDelse] = ACTIONS(3770),
    [anon_sym_POUNDELSE] = ACTIONS(3770),
    [anon_sym_POUNDElse] = ACTIONS(3770),
    [anon_sym_POUNDelse2] = ACTIONS(3770),
    [anon_sym_POUNDELSE2] = ACTIONS(3770),
    [anon_sym_POUNDElse2] = ACTIONS(3770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3770),
    [aux_sym__expression_token1] = ACTIONS(3770),
    [aux_sym__expression_token2] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3768),
    [anon_sym_SLASH] = ACTIONS(3768),
    [anon_sym_div] = ACTIONS(3768),
    [anon_sym_DIV] = ACTIONS(3768),
    [anon_sym_Div] = ACTIONS(3768),
    [anon_sym_mod] = ACTIONS(3768),
    [anon_sym_MOD] = ACTIONS(3768),
    [anon_sym_Mod] = ACTIONS(3768),
    [anon_sym_PLUS] = ACTIONS(3768),
    [anon_sym_GT_EQ] = ACTIONS(3770),
    [anon_sym_LT_EQ] = ACTIONS(3770),
    [anon_sym_GT] = ACTIONS(3768),
    [anon_sym_LT] = ACTIONS(3768),
    [anon_sym_LT_GT] = ACTIONS(3770),
    [anon_sym_and] = ACTIONS(3768),
    [anon_sym_AND] = ACTIONS(3768),
    [anon_sym_And] = ACTIONS(3768),
    [anon_sym_or] = ACTIONS(3768),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3768),
    [anon_sym_xor] = ACTIONS(3768),
    [anon_sym_XOR] = ACTIONS(3768),
    [anon_sym_Xor] = ACTIONS(3768),
    [anon_sym_QMARK] = ACTIONS(3770),
    [sym_datetime_literal] = ACTIONS(3770),
    [sym_date_literal] = ACTIONS(3768),
    [sym_time_literal] = ACTIONS(3768),
    [sym_biginteger_literal] = ACTIONS(3770),
    [anon_sym_if] = ACTIONS(3768),
    [anon_sym_IF] = ACTIONS(3768),
    [anon_sym_If] = ACTIONS(3768),
    [anon_sym_else] = ACTIONS(3768),
    [anon_sym_ELSE] = ACTIONS(3768),
    [anon_sym_Else] = ACTIONS(3768),
    [anon_sym_case] = ACTIONS(3768),
    [anon_sym_CASE] = ACTIONS(3768),
    [anon_sym_Case] = ACTIONS(3768),
    [anon_sym_for] = ACTIONS(3768),
    [anon_sym_FOR] = ACTIONS(3768),
    [anon_sym_For] = ACTIONS(3768),
    [anon_sym_foreach] = ACTIONS(3768),
    [anon_sym_FOREACH] = ACTIONS(3768),
    [anon_sym_Foreach] = ACTIONS(3768),
    [anon_sym_while] = ACTIONS(3768),
    [anon_sym_WHILE] = ACTIONS(3768),
    [anon_sym_While] = ACTIONS(3768),
    [anon_sym_repeat] = ACTIONS(3768),
    [anon_sym_REPEAT] = ACTIONS(3768),
    [anon_sym_Repeat] = ACTIONS(3768),
    [anon_sym_exit] = ACTIONS(3768),
    [anon_sym_EXIT] = ACTIONS(3768),
    [anon_sym_Exit] = ACTIONS(3768),
    [anon_sym_continue] = ACTIONS(3768),
    [anon_sym_CONTINUE] = ACTIONS(3768),
    [anon_sym_Continue] = ACTIONS(3768),
    [anon_sym_break] = ACTIONS(3768),
    [anon_sym_BREAK] = ACTIONS(3768),
    [anon_sym_Break] = ACTIONS(3768),
    [anon_sym_with] = ACTIONS(3768),
    [anon_sym_WITH] = ACTIONS(3768),
    [anon_sym_With] = ACTIONS(3768),
    [sym_asserterror_keyword] = ACTIONS(3770),
    [anon_sym_in] = ACTIONS(3768),
    [anon_sym_IN] = ACTIONS(3768),
    [anon_sym_In] = ACTIONS(3768),
    [sym_page_keyword] = ACTIONS(3768),
    [anon_sym_codeunit] = ACTIONS(3768),
    [anon_sym_CODEUNIT] = ACTIONS(3768),
    [anon_sym_Codeunit] = ACTIONS(3768),
    [anon_sym_CodeUnit] = ACTIONS(3768),
    [anon_sym_COdeunit] = ACTIONS(3768),
    [anon_sym_codeUnit] = ACTIONS(3768),
    [sym_report_keyword] = ACTIONS(3768),
    [sym_query_keyword] = ACTIONS(3768),
    [anon_sym_xmlport] = ACTIONS(3768),
    [anon_sym_XMLPORT] = ACTIONS(3768),
    [anon_sym_Xmlport] = ACTIONS(3768),
    [anon_sym_XMLport] = ACTIONS(3768),
    [anon_sym_XMLPort] = ACTIONS(3768),
    [anon_sym_XmlPort] = ACTIONS(3768),
    [anon_sym_enum] = ACTIONS(3768),
    [anon_sym_ENUM] = ACTIONS(3768),
    [anon_sym_Enum] = ACTIONS(3768),
    [anon_sym_eNUM] = ACTIONS(3768),
    [anon_sym_eNum] = ACTIONS(3768),
    [anon_sym_ENum] = ACTIONS(3768),
    [sym_quoted_identifier] = ACTIONS(3770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3770),
    [sym_verbatim_string] = ACTIONS(3770),
    [sym_integer] = ACTIONS(3768),
    [sym_continue_as_identifier] = ACTIONS(3770),
    [sym_preproc_open] = ACTIONS(3770),
    [sym_end_keyword] = ACTIONS(3770),
  },
  [STATE(2043)] = {
    [sym_identifier] = ACTIONS(3772),
    [anon_sym_SEMI] = ACTIONS(3774),
    [anon_sym_DOT] = ACTIONS(3772),
    [anon_sym_EQ] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [aux_sym_boolean_token1] = ACTIONS(3772),
    [aux_sym_boolean_token2] = ACTIONS(3772),
    [sym_decimal] = ACTIONS(3772),
    [anon_sym_LPAREN] = ACTIONS(3774),
    [anon_sym_DOT_DOT] = ACTIONS(3774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(3772),
    [anon_sym_LBRACK] = ACTIONS(3774),
    [aux_sym_record_type_token1] = ACTIONS(3772),
    [aux_sym_basic_type_token21] = ACTIONS(3772),
    [aux_sym_basic_type_token22] = ACTIONS(3772),
    [aux_sym_basic_type_token48] = ACTIONS(3772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3772),
    [anon_sym_COLON_COLON] = ACTIONS(3774),
    [anon_sym_POUNDif] = ACTIONS(3774),
    [anon_sym_POUNDIF] = ACTIONS(3774),
    [anon_sym_POUNDIf] = ACTIONS(3774),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_NOT] = ACTIONS(3772),
    [anon_sym_Not] = ACTIONS(3772),
    [anon_sym_POUNDelse] = ACTIONS(3774),
    [anon_sym_POUNDELSE] = ACTIONS(3774),
    [anon_sym_POUNDElse] = ACTIONS(3774),
    [anon_sym_POUNDelse2] = ACTIONS(3774),
    [anon_sym_POUNDELSE2] = ACTIONS(3774),
    [anon_sym_POUNDElse2] = ACTIONS(3774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3774),
    [aux_sym__expression_token1] = ACTIONS(3774),
    [aux_sym__expression_token2] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3772),
    [anon_sym_SLASH] = ACTIONS(3772),
    [anon_sym_div] = ACTIONS(3772),
    [anon_sym_DIV] = ACTIONS(3772),
    [anon_sym_Div] = ACTIONS(3772),
    [anon_sym_mod] = ACTIONS(3772),
    [anon_sym_MOD] = ACTIONS(3772),
    [anon_sym_Mod] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_GT_EQ] = ACTIONS(3774),
    [anon_sym_LT_EQ] = ACTIONS(3774),
    [anon_sym_GT] = ACTIONS(3772),
    [anon_sym_LT] = ACTIONS(3772),
    [anon_sym_LT_GT] = ACTIONS(3774),
    [anon_sym_and] = ACTIONS(3772),
    [anon_sym_AND] = ACTIONS(3772),
    [anon_sym_And] = ACTIONS(3772),
    [anon_sym_or] = ACTIONS(3772),
    [anon_sym_OR] = ACTIONS(3772),
    [anon_sym_Or] = ACTIONS(3772),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3772),
    [anon_sym_Xor] = ACTIONS(3772),
    [anon_sym_QMARK] = ACTIONS(3774),
    [sym_datetime_literal] = ACTIONS(3774),
    [sym_date_literal] = ACTIONS(3772),
    [sym_time_literal] = ACTIONS(3772),
    [sym_biginteger_literal] = ACTIONS(3774),
    [anon_sym_if] = ACTIONS(3772),
    [anon_sym_IF] = ACTIONS(3772),
    [anon_sym_If] = ACTIONS(3772),
    [anon_sym_else] = ACTIONS(3772),
    [anon_sym_ELSE] = ACTIONS(3772),
    [anon_sym_Else] = ACTIONS(3772),
    [anon_sym_case] = ACTIONS(3772),
    [anon_sym_CASE] = ACTIONS(3772),
    [anon_sym_Case] = ACTIONS(3772),
    [anon_sym_for] = ACTIONS(3772),
    [anon_sym_FOR] = ACTIONS(3772),
    [anon_sym_For] = ACTIONS(3772),
    [anon_sym_foreach] = ACTIONS(3772),
    [anon_sym_FOREACH] = ACTIONS(3772),
    [anon_sym_Foreach] = ACTIONS(3772),
    [anon_sym_while] = ACTIONS(3772),
    [anon_sym_WHILE] = ACTIONS(3772),
    [anon_sym_While] = ACTIONS(3772),
    [anon_sym_repeat] = ACTIONS(3772),
    [anon_sym_REPEAT] = ACTIONS(3772),
    [anon_sym_Repeat] = ACTIONS(3772),
    [anon_sym_exit] = ACTIONS(3772),
    [anon_sym_EXIT] = ACTIONS(3772),
    [anon_sym_Exit] = ACTIONS(3772),
    [anon_sym_continue] = ACTIONS(3772),
    [anon_sym_CONTINUE] = ACTIONS(3772),
    [anon_sym_Continue] = ACTIONS(3772),
    [anon_sym_break] = ACTIONS(3772),
    [anon_sym_BREAK] = ACTIONS(3772),
    [anon_sym_Break] = ACTIONS(3772),
    [anon_sym_with] = ACTIONS(3772),
    [anon_sym_WITH] = ACTIONS(3772),
    [anon_sym_With] = ACTIONS(3772),
    [sym_asserterror_keyword] = ACTIONS(3774),
    [anon_sym_in] = ACTIONS(3772),
    [anon_sym_IN] = ACTIONS(3772),
    [anon_sym_In] = ACTIONS(3772),
    [sym_page_keyword] = ACTIONS(3772),
    [anon_sym_codeunit] = ACTIONS(3772),
    [anon_sym_CODEUNIT] = ACTIONS(3772),
    [anon_sym_Codeunit] = ACTIONS(3772),
    [anon_sym_CodeUnit] = ACTIONS(3772),
    [anon_sym_COdeunit] = ACTIONS(3772),
    [anon_sym_codeUnit] = ACTIONS(3772),
    [sym_report_keyword] = ACTIONS(3772),
    [sym_query_keyword] = ACTIONS(3772),
    [anon_sym_xmlport] = ACTIONS(3772),
    [anon_sym_XMLPORT] = ACTIONS(3772),
    [anon_sym_Xmlport] = ACTIONS(3772),
    [anon_sym_XMLport] = ACTIONS(3772),
    [anon_sym_XMLPort] = ACTIONS(3772),
    [anon_sym_XmlPort] = ACTIONS(3772),
    [anon_sym_enum] = ACTIONS(3772),
    [anon_sym_ENUM] = ACTIONS(3772),
    [anon_sym_Enum] = ACTIONS(3772),
    [anon_sym_eNUM] = ACTIONS(3772),
    [anon_sym_eNum] = ACTIONS(3772),
    [anon_sym_ENum] = ACTIONS(3772),
    [sym_quoted_identifier] = ACTIONS(3774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3774),
    [sym_verbatim_string] = ACTIONS(3774),
    [sym_integer] = ACTIONS(3772),
    [sym_continue_as_identifier] = ACTIONS(3774),
    [sym_preproc_open] = ACTIONS(3774),
    [sym_end_keyword] = ACTIONS(3774),
  },
  [STATE(2044)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3663),
    [anon_sym_IF] = ACTIONS(3663),
    [anon_sym_If] = ACTIONS(3663),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_case] = ACTIONS(3663),
    [anon_sym_CASE] = ACTIONS(3663),
    [anon_sym_Case] = ACTIONS(3663),
    [anon_sym_for] = ACTIONS(3663),
    [anon_sym_FOR] = ACTIONS(3663),
    [anon_sym_For] = ACTIONS(3663),
    [anon_sym_foreach] = ACTIONS(3663),
    [anon_sym_FOREACH] = ACTIONS(3663),
    [anon_sym_Foreach] = ACTIONS(3663),
    [anon_sym_while] = ACTIONS(3663),
    [anon_sym_WHILE] = ACTIONS(3663),
    [anon_sym_While] = ACTIONS(3663),
    [anon_sym_repeat] = ACTIONS(3663),
    [anon_sym_REPEAT] = ACTIONS(3663),
    [anon_sym_Repeat] = ACTIONS(3663),
    [anon_sym_exit] = ACTIONS(3663),
    [anon_sym_EXIT] = ACTIONS(3663),
    [anon_sym_Exit] = ACTIONS(3663),
    [anon_sym_continue] = ACTIONS(3663),
    [anon_sym_CONTINUE] = ACTIONS(3663),
    [anon_sym_Continue] = ACTIONS(3663),
    [anon_sym_break] = ACTIONS(3663),
    [anon_sym_BREAK] = ACTIONS(3663),
    [anon_sym_Break] = ACTIONS(3663),
    [anon_sym_with] = ACTIONS(3663),
    [anon_sym_WITH] = ACTIONS(3663),
    [anon_sym_With] = ACTIONS(3663),
    [sym_asserterror_keyword] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_end_keyword] = ACTIONS(3665),
  },
  [STATE(2045)] = {
    [sym_identifier] = ACTIONS(3790),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_DOT] = ACTIONS(3790),
    [anon_sym_EQ] = ACTIONS(3792),
    [anon_sym_DASH] = ACTIONS(3790),
    [aux_sym_boolean_token1] = ACTIONS(3790),
    [aux_sym_boolean_token2] = ACTIONS(3790),
    [sym_decimal] = ACTIONS(3790),
    [anon_sym_LPAREN] = ACTIONS(3792),
    [anon_sym_DOT_DOT] = ACTIONS(3792),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3790),
    [anon_sym_STAR] = ACTIONS(3790),
    [anon_sym_LBRACK] = ACTIONS(3792),
    [aux_sym_record_type_token1] = ACTIONS(3790),
    [aux_sym_basic_type_token21] = ACTIONS(3790),
    [aux_sym_basic_type_token22] = ACTIONS(3790),
    [aux_sym_basic_type_token48] = ACTIONS(3790),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3790),
    [anon_sym_COLON_COLON] = ACTIONS(3792),
    [anon_sym_POUNDif] = ACTIONS(3792),
    [anon_sym_POUNDIF] = ACTIONS(3792),
    [anon_sym_POUNDIf] = ACTIONS(3792),
    [anon_sym_not] = ACTIONS(3790),
    [anon_sym_NOT] = ACTIONS(3790),
    [anon_sym_Not] = ACTIONS(3790),
    [anon_sym_POUNDelse] = ACTIONS(3792),
    [anon_sym_POUNDELSE] = ACTIONS(3792),
    [anon_sym_POUNDElse] = ACTIONS(3792),
    [anon_sym_POUNDelse2] = ACTIONS(3792),
    [anon_sym_POUNDELSE2] = ACTIONS(3792),
    [anon_sym_POUNDElse2] = ACTIONS(3792),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3792),
    [aux_sym__expression_token1] = ACTIONS(3792),
    [aux_sym__expression_token2] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3790),
    [anon_sym_SLASH] = ACTIONS(3790),
    [anon_sym_div] = ACTIONS(3790),
    [anon_sym_DIV] = ACTIONS(3790),
    [anon_sym_Div] = ACTIONS(3790),
    [anon_sym_mod] = ACTIONS(3790),
    [anon_sym_MOD] = ACTIONS(3790),
    [anon_sym_Mod] = ACTIONS(3790),
    [anon_sym_PLUS] = ACTIONS(3790),
    [anon_sym_GT_EQ] = ACTIONS(3792),
    [anon_sym_LT_EQ] = ACTIONS(3792),
    [anon_sym_GT] = ACTIONS(3790),
    [anon_sym_LT] = ACTIONS(3790),
    [anon_sym_LT_GT] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3790),
    [anon_sym_AND] = ACTIONS(3790),
    [anon_sym_And] = ACTIONS(3790),
    [anon_sym_or] = ACTIONS(3790),
    [anon_sym_OR] = ACTIONS(3790),
    [anon_sym_Or] = ACTIONS(3790),
    [anon_sym_xor] = ACTIONS(3790),
    [anon_sym_XOR] = ACTIONS(3790),
    [anon_sym_Xor] = ACTIONS(3790),
    [anon_sym_QMARK] = ACTIONS(3792),
    [sym_datetime_literal] = ACTIONS(3792),
    [sym_date_literal] = ACTIONS(3790),
    [sym_time_literal] = ACTIONS(3790),
    [sym_biginteger_literal] = ACTIONS(3792),
    [anon_sym_if] = ACTIONS(3790),
    [anon_sym_IF] = ACTIONS(3790),
    [anon_sym_If] = ACTIONS(3790),
    [anon_sym_else] = ACTIONS(3790),
    [anon_sym_ELSE] = ACTIONS(3790),
    [anon_sym_Else] = ACTIONS(3790),
    [anon_sym_case] = ACTIONS(3790),
    [anon_sym_CASE] = ACTIONS(3790),
    [anon_sym_Case] = ACTIONS(3790),
    [anon_sym_for] = ACTIONS(3790),
    [anon_sym_FOR] = ACTIONS(3790),
    [anon_sym_For] = ACTIONS(3790),
    [anon_sym_foreach] = ACTIONS(3790),
    [anon_sym_FOREACH] = ACTIONS(3790),
    [anon_sym_Foreach] = ACTIONS(3790),
    [anon_sym_while] = ACTIONS(3790),
    [anon_sym_WHILE] = ACTIONS(3790),
    [anon_sym_While] = ACTIONS(3790),
    [anon_sym_repeat] = ACTIONS(3790),
    [anon_sym_REPEAT] = ACTIONS(3790),
    [anon_sym_Repeat] = ACTIONS(3790),
    [anon_sym_exit] = ACTIONS(3790),
    [anon_sym_EXIT] = ACTIONS(3790),
    [anon_sym_Exit] = ACTIONS(3790),
    [anon_sym_continue] = ACTIONS(3790),
    [anon_sym_CONTINUE] = ACTIONS(3790),
    [anon_sym_Continue] = ACTIONS(3790),
    [anon_sym_break] = ACTIONS(3790),
    [anon_sym_BREAK] = ACTIONS(3790),
    [anon_sym_Break] = ACTIONS(3790),
    [anon_sym_with] = ACTIONS(3790),
    [anon_sym_WITH] = ACTIONS(3790),
    [anon_sym_With] = ACTIONS(3790),
    [sym_asserterror_keyword] = ACTIONS(3792),
    [anon_sym_in] = ACTIONS(3790),
    [anon_sym_IN] = ACTIONS(3790),
    [anon_sym_In] = ACTIONS(3790),
    [sym_page_keyword] = ACTIONS(3790),
    [anon_sym_codeunit] = ACTIONS(3790),
    [anon_sym_CODEUNIT] = ACTIONS(3790),
    [anon_sym_Codeunit] = ACTIONS(3790),
    [anon_sym_CodeUnit] = ACTIONS(3790),
    [anon_sym_COdeunit] = ACTIONS(3790),
    [anon_sym_codeUnit] = ACTIONS(3790),
    [sym_report_keyword] = ACTIONS(3790),
    [sym_query_keyword] = ACTIONS(3790),
    [anon_sym_xmlport] = ACTIONS(3790),
    [anon_sym_XMLPORT] = ACTIONS(3790),
    [anon_sym_Xmlport] = ACTIONS(3790),
    [anon_sym_XMLport] = ACTIONS(3790),
    [anon_sym_XMLPort] = ACTIONS(3790),
    [anon_sym_XmlPort] = ACTIONS(3790),
    [anon_sym_enum] = ACTIONS(3790),
    [anon_sym_ENUM] = ACTIONS(3790),
    [anon_sym_Enum] = ACTIONS(3790),
    [anon_sym_eNUM] = ACTIONS(3790),
    [anon_sym_eNum] = ACTIONS(3790),
    [anon_sym_ENum] = ACTIONS(3790),
    [sym_quoted_identifier] = ACTIONS(3792),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3792),
    [sym_verbatim_string] = ACTIONS(3792),
    [sym_integer] = ACTIONS(3790),
    [sym_continue_as_identifier] = ACTIONS(3792),
    [sym_preproc_open] = ACTIONS(3792),
    [sym_end_keyword] = ACTIONS(3792),
  },
  [STATE(2046)] = {
    [sym_identifier] = ACTIONS(3776),
    [anon_sym_SEMI] = ACTIONS(3778),
    [anon_sym_DOT] = ACTIONS(3776),
    [anon_sym_EQ] = ACTIONS(3778),
    [anon_sym_DASH] = ACTIONS(3776),
    [aux_sym_boolean_token1] = ACTIONS(3776),
    [aux_sym_boolean_token2] = ACTIONS(3776),
    [sym_decimal] = ACTIONS(3776),
    [anon_sym_LPAREN] = ACTIONS(3778),
    [anon_sym_DOT_DOT] = ACTIONS(3778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3776),
    [anon_sym_STAR] = ACTIONS(3776),
    [anon_sym_LBRACK] = ACTIONS(3778),
    [aux_sym_record_type_token1] = ACTIONS(3776),
    [aux_sym_basic_type_token21] = ACTIONS(3776),
    [aux_sym_basic_type_token22] = ACTIONS(3776),
    [aux_sym_basic_type_token48] = ACTIONS(3776),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_POUNDif] = ACTIONS(3778),
    [anon_sym_POUNDIF] = ACTIONS(3778),
    [anon_sym_POUNDIf] = ACTIONS(3778),
    [anon_sym_not] = ACTIONS(3776),
    [anon_sym_NOT] = ACTIONS(3776),
    [anon_sym_Not] = ACTIONS(3776),
    [anon_sym_POUNDelse] = ACTIONS(3778),
    [anon_sym_POUNDELSE] = ACTIONS(3778),
    [anon_sym_POUNDElse] = ACTIONS(3778),
    [anon_sym_POUNDelse2] = ACTIONS(3778),
    [anon_sym_POUNDELSE2] = ACTIONS(3778),
    [anon_sym_POUNDElse2] = ACTIONS(3778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3778),
    [aux_sym__expression_token1] = ACTIONS(3778),
    [aux_sym__expression_token2] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3776),
    [anon_sym_SLASH] = ACTIONS(3776),
    [anon_sym_div] = ACTIONS(3776),
    [anon_sym_DIV] = ACTIONS(3776),
    [anon_sym_Div] = ACTIONS(3776),
    [anon_sym_mod] = ACTIONS(3776),
    [anon_sym_MOD] = ACTIONS(3776),
    [anon_sym_Mod] = ACTIONS(3776),
    [anon_sym_PLUS] = ACTIONS(3776),
    [anon_sym_GT_EQ] = ACTIONS(3778),
    [anon_sym_LT_EQ] = ACTIONS(3778),
    [anon_sym_GT] = ACTIONS(3776),
    [anon_sym_LT] = ACTIONS(3776),
    [anon_sym_LT_GT] = ACTIONS(3778),
    [anon_sym_and] = ACTIONS(3776),
    [anon_sym_AND] = ACTIONS(3776),
    [anon_sym_And] = ACTIONS(3776),
    [anon_sym_or] = ACTIONS(3776),
    [anon_sym_OR] = ACTIONS(3776),
    [anon_sym_Or] = ACTIONS(3776),
    [anon_sym_xor] = ACTIONS(3776),
    [anon_sym_XOR] = ACTIONS(3776),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(3778),
    [sym_date_literal] = ACTIONS(3776),
    [sym_time_literal] = ACTIONS(3776),
    [sym_biginteger_literal] = ACTIONS(3778),
    [anon_sym_if] = ACTIONS(3776),
    [anon_sym_IF] = ACTIONS(3776),
    [anon_sym_If] = ACTIONS(3776),
    [anon_sym_else] = ACTIONS(3776),
    [anon_sym_ELSE] = ACTIONS(3776),
    [anon_sym_Else] = ACTIONS(3776),
    [anon_sym_case] = ACTIONS(3776),
    [anon_sym_CASE] = ACTIONS(3776),
    [anon_sym_Case] = ACTIONS(3776),
    [anon_sym_for] = ACTIONS(3776),
    [anon_sym_FOR] = ACTIONS(3776),
    [anon_sym_For] = ACTIONS(3776),
    [anon_sym_foreach] = ACTIONS(3776),
    [anon_sym_FOREACH] = ACTIONS(3776),
    [anon_sym_Foreach] = ACTIONS(3776),
    [anon_sym_while] = ACTIONS(3776),
    [anon_sym_WHILE] = ACTIONS(3776),
    [anon_sym_While] = ACTIONS(3776),
    [anon_sym_repeat] = ACTIONS(3776),
    [anon_sym_REPEAT] = ACTIONS(3776),
    [anon_sym_Repeat] = ACTIONS(3776),
    [anon_sym_exit] = ACTIONS(3776),
    [anon_sym_EXIT] = ACTIONS(3776),
    [anon_sym_Exit] = ACTIONS(3776),
    [anon_sym_continue] = ACTIONS(3776),
    [anon_sym_CONTINUE] = ACTIONS(3776),
    [anon_sym_Continue] = ACTIONS(3776),
    [anon_sym_break] = ACTIONS(3776),
    [anon_sym_BREAK] = ACTIONS(3776),
    [anon_sym_Break] = ACTIONS(3776),
    [anon_sym_with] = ACTIONS(3776),
    [anon_sym_WITH] = ACTIONS(3776),
    [anon_sym_With] = ACTIONS(3776),
    [sym_asserterror_keyword] = ACTIONS(3778),
    [anon_sym_in] = ACTIONS(3776),
    [anon_sym_IN] = ACTIONS(3776),
    [anon_sym_In] = ACTIONS(3776),
    [sym_page_keyword] = ACTIONS(3776),
    [anon_sym_codeunit] = ACTIONS(3776),
    [anon_sym_CODEUNIT] = ACTIONS(3776),
    [anon_sym_Codeunit] = ACTIONS(3776),
    [anon_sym_CodeUnit] = ACTIONS(3776),
    [anon_sym_COdeunit] = ACTIONS(3776),
    [anon_sym_codeUnit] = ACTIONS(3776),
    [sym_report_keyword] = ACTIONS(3776),
    [sym_query_keyword] = ACTIONS(3776),
    [anon_sym_xmlport] = ACTIONS(3776),
    [anon_sym_XMLPORT] = ACTIONS(3776),
    [anon_sym_Xmlport] = ACTIONS(3776),
    [anon_sym_XMLport] = ACTIONS(3776),
    [anon_sym_XMLPort] = ACTIONS(3776),
    [anon_sym_XmlPort] = ACTIONS(3776),
    [anon_sym_enum] = ACTIONS(3776),
    [anon_sym_ENUM] = ACTIONS(3776),
    [anon_sym_Enum] = ACTIONS(3776),
    [anon_sym_eNUM] = ACTIONS(3776),
    [anon_sym_eNum] = ACTIONS(3776),
    [anon_sym_ENum] = ACTIONS(3776),
    [sym_quoted_identifier] = ACTIONS(3778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3778),
    [sym_verbatim_string] = ACTIONS(3778),
    [sym_integer] = ACTIONS(3776),
    [sym_continue_as_identifier] = ACTIONS(3778),
    [sym_preproc_open] = ACTIONS(3778),
    [sym_end_keyword] = ACTIONS(3778),
  },
  [STATE(2047)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10639),
    [sym_else_table_relation_fragment] = STATE(10639),
    [sym_table_relation_expression] = STATE(10639),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8031),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2235),
    [sym_preproc_endif] = STATE(4012),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(11016),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8031),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(10666),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4361),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(2048)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_end_keyword] = ACTIONS(3875),
  },
  [STATE(2049)] = {
    [sym_identifier] = ACTIONS(3945),
    [anon_sym_SEMI] = ACTIONS(3947),
    [anon_sym_DOT] = ACTIONS(3945),
    [anon_sym_EQ] = ACTIONS(3947),
    [anon_sym_DASH] = ACTIONS(3945),
    [aux_sym_boolean_token1] = ACTIONS(3945),
    [aux_sym_boolean_token2] = ACTIONS(3945),
    [sym_decimal] = ACTIONS(3945),
    [anon_sym_LPAREN] = ACTIONS(3947),
    [anon_sym_DOT_DOT] = ACTIONS(3947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3945),
    [anon_sym_STAR] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(3947),
    [aux_sym_record_type_token1] = ACTIONS(3945),
    [aux_sym_basic_type_token21] = ACTIONS(3945),
    [aux_sym_basic_type_token22] = ACTIONS(3945),
    [aux_sym_basic_type_token48] = ACTIONS(3945),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3945),
    [anon_sym_POUNDif] = ACTIONS(3947),
    [anon_sym_POUNDIF] = ACTIONS(3947),
    [anon_sym_POUNDIf] = ACTIONS(3947),
    [anon_sym_not] = ACTIONS(3945),
    [anon_sym_NOT] = ACTIONS(3945),
    [anon_sym_Not] = ACTIONS(3945),
    [anon_sym_POUNDelse] = ACTIONS(3947),
    [anon_sym_POUNDELSE] = ACTIONS(3947),
    [anon_sym_POUNDElse] = ACTIONS(3947),
    [anon_sym_POUNDelse2] = ACTIONS(3947),
    [anon_sym_POUNDELSE2] = ACTIONS(3947),
    [anon_sym_POUNDElse2] = ACTIONS(3947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3947),
    [aux_sym__expression_token1] = ACTIONS(3947),
    [aux_sym__expression_token2] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3945),
    [anon_sym_SLASH] = ACTIONS(3945),
    [anon_sym_div] = ACTIONS(3945),
    [anon_sym_DIV] = ACTIONS(3945),
    [anon_sym_Div] = ACTIONS(3945),
    [anon_sym_mod] = ACTIONS(3945),
    [anon_sym_MOD] = ACTIONS(3945),
    [anon_sym_Mod] = ACTIONS(3945),
    [anon_sym_PLUS] = ACTIONS(3945),
    [anon_sym_GT_EQ] = ACTIONS(3947),
    [anon_sym_LT_EQ] = ACTIONS(3947),
    [anon_sym_GT] = ACTIONS(3945),
    [anon_sym_LT] = ACTIONS(3945),
    [anon_sym_LT_GT] = ACTIONS(3947),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_AND] = ACTIONS(3945),
    [anon_sym_And] = ACTIONS(3945),
    [anon_sym_or] = ACTIONS(3945),
    [anon_sym_OR] = ACTIONS(3945),
    [anon_sym_Or] = ACTIONS(3945),
    [anon_sym_xor] = ACTIONS(3945),
    [anon_sym_XOR] = ACTIONS(3945),
    [anon_sym_Xor] = ACTIONS(3945),
    [anon_sym_QMARK] = ACTIONS(3947),
    [sym_datetime_literal] = ACTIONS(3947),
    [sym_date_literal] = ACTIONS(3945),
    [sym_time_literal] = ACTIONS(3945),
    [sym_biginteger_literal] = ACTIONS(3947),
    [anon_sym_if] = ACTIONS(3945),
    [anon_sym_IF] = ACTIONS(3945),
    [anon_sym_If] = ACTIONS(3945),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_ELSE] = ACTIONS(3945),
    [anon_sym_Else] = ACTIONS(3945),
    [anon_sym_case] = ACTIONS(3945),
    [anon_sym_CASE] = ACTIONS(3945),
    [anon_sym_Case] = ACTIONS(3945),
    [anon_sym_for] = ACTIONS(3945),
    [anon_sym_FOR] = ACTIONS(3945),
    [anon_sym_For] = ACTIONS(3945),
    [anon_sym_foreach] = ACTIONS(3945),
    [anon_sym_FOREACH] = ACTIONS(3945),
    [anon_sym_Foreach] = ACTIONS(3945),
    [anon_sym_while] = ACTIONS(3945),
    [anon_sym_WHILE] = ACTIONS(3945),
    [anon_sym_While] = ACTIONS(3945),
    [anon_sym_repeat] = ACTIONS(3945),
    [anon_sym_REPEAT] = ACTIONS(3945),
    [anon_sym_Repeat] = ACTIONS(3945),
    [anon_sym_exit] = ACTIONS(3945),
    [anon_sym_EXIT] = ACTIONS(3945),
    [anon_sym_Exit] = ACTIONS(3945),
    [anon_sym_continue] = ACTIONS(3945),
    [anon_sym_CONTINUE] = ACTIONS(3945),
    [anon_sym_Continue] = ACTIONS(3945),
    [anon_sym_break] = ACTIONS(3945),
    [anon_sym_BREAK] = ACTIONS(3945),
    [anon_sym_Break] = ACTIONS(3945),
    [anon_sym_with] = ACTIONS(3945),
    [anon_sym_WITH] = ACTIONS(3945),
    [anon_sym_With] = ACTIONS(3945),
    [sym_asserterror_keyword] = ACTIONS(3947),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_IN] = ACTIONS(3945),
    [anon_sym_In] = ACTIONS(3945),
    [sym_page_keyword] = ACTIONS(3945),
    [anon_sym_codeunit] = ACTIONS(3945),
    [anon_sym_CODEUNIT] = ACTIONS(3945),
    [anon_sym_Codeunit] = ACTIONS(3945),
    [anon_sym_CodeUnit] = ACTIONS(3945),
    [anon_sym_COdeunit] = ACTIONS(3945),
    [anon_sym_codeUnit] = ACTIONS(3945),
    [sym_report_keyword] = ACTIONS(3945),
    [sym_query_keyword] = ACTIONS(3945),
    [anon_sym_xmlport] = ACTIONS(3945),
    [anon_sym_XMLPORT] = ACTIONS(3945),
    [anon_sym_Xmlport] = ACTIONS(3945),
    [anon_sym_XMLport] = ACTIONS(3945),
    [anon_sym_XMLPort] = ACTIONS(3945),
    [anon_sym_XmlPort] = ACTIONS(3945),
    [anon_sym_enum] = ACTIONS(3945),
    [anon_sym_ENUM] = ACTIONS(3945),
    [anon_sym_Enum] = ACTIONS(3945),
    [anon_sym_eNUM] = ACTIONS(3945),
    [anon_sym_eNum] = ACTIONS(3945),
    [anon_sym_ENum] = ACTIONS(3945),
    [sym_quoted_identifier] = ACTIONS(3947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3947),
    [sym_verbatim_string] = ACTIONS(3947),
    [sym_integer] = ACTIONS(3945),
    [sym_continue_as_identifier] = ACTIONS(3947),
    [sym_preproc_open] = ACTIONS(3947),
    [sym_end_keyword] = ACTIONS(3947),
  },
  [STATE(2050)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_end_keyword] = ACTIONS(3867),
  },
  [STATE(2051)] = {
    [sym_identifier] = ACTIONS(3885),
    [anon_sym_SEMI] = ACTIONS(3887),
    [anon_sym_DOT] = ACTIONS(3885),
    [anon_sym_EQ] = ACTIONS(3887),
    [anon_sym_DASH] = ACTIONS(3885),
    [aux_sym_boolean_token1] = ACTIONS(3885),
    [aux_sym_boolean_token2] = ACTIONS(3885),
    [sym_decimal] = ACTIONS(3885),
    [anon_sym_LPAREN] = ACTIONS(3887),
    [anon_sym_DOT_DOT] = ACTIONS(3887),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3885),
    [anon_sym_STAR] = ACTIONS(3885),
    [anon_sym_LBRACK] = ACTIONS(3887),
    [aux_sym_record_type_token1] = ACTIONS(3885),
    [aux_sym_basic_type_token21] = ACTIONS(3885),
    [aux_sym_basic_type_token22] = ACTIONS(3885),
    [aux_sym_basic_type_token48] = ACTIONS(3885),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3885),
    [anon_sym_POUNDif] = ACTIONS(3887),
    [anon_sym_POUNDIF] = ACTIONS(3887),
    [anon_sym_POUNDIf] = ACTIONS(3887),
    [anon_sym_not] = ACTIONS(3885),
    [anon_sym_NOT] = ACTIONS(3885),
    [anon_sym_Not] = ACTIONS(3885),
    [anon_sym_POUNDelse] = ACTIONS(3887),
    [anon_sym_POUNDELSE] = ACTIONS(3887),
    [anon_sym_POUNDElse] = ACTIONS(3887),
    [anon_sym_POUNDelse2] = ACTIONS(3887),
    [anon_sym_POUNDELSE2] = ACTIONS(3887),
    [anon_sym_POUNDElse2] = ACTIONS(3887),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3887),
    [aux_sym__expression_token1] = ACTIONS(3887),
    [aux_sym__expression_token2] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3885),
    [anon_sym_SLASH] = ACTIONS(3885),
    [anon_sym_div] = ACTIONS(3885),
    [anon_sym_DIV] = ACTIONS(3885),
    [anon_sym_Div] = ACTIONS(3885),
    [anon_sym_mod] = ACTIONS(3885),
    [anon_sym_MOD] = ACTIONS(3885),
    [anon_sym_Mod] = ACTIONS(3885),
    [anon_sym_PLUS] = ACTIONS(3885),
    [anon_sym_GT_EQ] = ACTIONS(3887),
    [anon_sym_LT_EQ] = ACTIONS(3887),
    [anon_sym_GT] = ACTIONS(3885),
    [anon_sym_LT] = ACTIONS(3885),
    [anon_sym_LT_GT] = ACTIONS(3887),
    [anon_sym_and] = ACTIONS(3885),
    [anon_sym_AND] = ACTIONS(3885),
    [anon_sym_And] = ACTIONS(3885),
    [anon_sym_or] = ACTIONS(3885),
    [anon_sym_OR] = ACTIONS(3885),
    [anon_sym_Or] = ACTIONS(3885),
    [anon_sym_xor] = ACTIONS(3885),
    [anon_sym_XOR] = ACTIONS(3885),
    [anon_sym_Xor] = ACTIONS(3885),
    [anon_sym_QMARK] = ACTIONS(3887),
    [sym_datetime_literal] = ACTIONS(3887),
    [sym_date_literal] = ACTIONS(3885),
    [sym_time_literal] = ACTIONS(3885),
    [sym_biginteger_literal] = ACTIONS(3887),
    [anon_sym_if] = ACTIONS(3885),
    [anon_sym_IF] = ACTIONS(3885),
    [anon_sym_If] = ACTIONS(3885),
    [anon_sym_else] = ACTIONS(3885),
    [anon_sym_ELSE] = ACTIONS(3885),
    [anon_sym_Else] = ACTIONS(3885),
    [anon_sym_case] = ACTIONS(3885),
    [anon_sym_CASE] = ACTIONS(3885),
    [anon_sym_Case] = ACTIONS(3885),
    [anon_sym_for] = ACTIONS(3885),
    [anon_sym_FOR] = ACTIONS(3885),
    [anon_sym_For] = ACTIONS(3885),
    [anon_sym_foreach] = ACTIONS(3885),
    [anon_sym_FOREACH] = ACTIONS(3885),
    [anon_sym_Foreach] = ACTIONS(3885),
    [anon_sym_while] = ACTIONS(3885),
    [anon_sym_WHILE] = ACTIONS(3885),
    [anon_sym_While] = ACTIONS(3885),
    [anon_sym_repeat] = ACTIONS(3885),
    [anon_sym_REPEAT] = ACTIONS(3885),
    [anon_sym_Repeat] = ACTIONS(3885),
    [anon_sym_exit] = ACTIONS(3885),
    [anon_sym_EXIT] = ACTIONS(3885),
    [anon_sym_Exit] = ACTIONS(3885),
    [anon_sym_continue] = ACTIONS(3885),
    [anon_sym_CONTINUE] = ACTIONS(3885),
    [anon_sym_Continue] = ACTIONS(3885),
    [anon_sym_break] = ACTIONS(3885),
    [anon_sym_BREAK] = ACTIONS(3885),
    [anon_sym_Break] = ACTIONS(3885),
    [anon_sym_with] = ACTIONS(3885),
    [anon_sym_WITH] = ACTIONS(3885),
    [anon_sym_With] = ACTIONS(3885),
    [sym_asserterror_keyword] = ACTIONS(3887),
    [anon_sym_in] = ACTIONS(3885),
    [anon_sym_IN] = ACTIONS(3885),
    [anon_sym_In] = ACTIONS(3885),
    [sym_page_keyword] = ACTIONS(3885),
    [anon_sym_codeunit] = ACTIONS(3885),
    [anon_sym_CODEUNIT] = ACTIONS(3885),
    [anon_sym_Codeunit] = ACTIONS(3885),
    [anon_sym_CodeUnit] = ACTIONS(3885),
    [anon_sym_COdeunit] = ACTIONS(3885),
    [anon_sym_codeUnit] = ACTIONS(3885),
    [sym_report_keyword] = ACTIONS(3885),
    [sym_query_keyword] = ACTIONS(3885),
    [anon_sym_xmlport] = ACTIONS(3885),
    [anon_sym_XMLPORT] = ACTIONS(3885),
    [anon_sym_Xmlport] = ACTIONS(3885),
    [anon_sym_XMLport] = ACTIONS(3885),
    [anon_sym_XMLPort] = ACTIONS(3885),
    [anon_sym_XmlPort] = ACTIONS(3885),
    [anon_sym_enum] = ACTIONS(3885),
    [anon_sym_ENUM] = ACTIONS(3885),
    [anon_sym_Enum] = ACTIONS(3885),
    [anon_sym_eNUM] = ACTIONS(3885),
    [anon_sym_eNum] = ACTIONS(3885),
    [anon_sym_ENum] = ACTIONS(3885),
    [sym_quoted_identifier] = ACTIONS(3887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3887),
    [sym_verbatim_string] = ACTIONS(3887),
    [sym_integer] = ACTIONS(3885),
    [sym_continue_as_identifier] = ACTIONS(3887),
    [sym_preproc_open] = ACTIONS(3887),
    [sym_end_keyword] = ACTIONS(3887),
  },
  [STATE(2052)] = {
    [sym_identifier] = ACTIONS(3905),
    [anon_sym_SEMI] = ACTIONS(3907),
    [anon_sym_DOT] = ACTIONS(3905),
    [anon_sym_EQ] = ACTIONS(3907),
    [anon_sym_DASH] = ACTIONS(3905),
    [aux_sym_boolean_token1] = ACTIONS(3905),
    [aux_sym_boolean_token2] = ACTIONS(3905),
    [sym_decimal] = ACTIONS(3905),
    [anon_sym_LPAREN] = ACTIONS(3907),
    [anon_sym_DOT_DOT] = ACTIONS(3907),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3905),
    [anon_sym_STAR] = ACTIONS(3905),
    [anon_sym_LBRACK] = ACTIONS(3907),
    [aux_sym_record_type_token1] = ACTIONS(3905),
    [aux_sym_basic_type_token21] = ACTIONS(3905),
    [aux_sym_basic_type_token22] = ACTIONS(3905),
    [aux_sym_basic_type_token48] = ACTIONS(3905),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3905),
    [anon_sym_POUNDif] = ACTIONS(3907),
    [anon_sym_POUNDIF] = ACTIONS(3907),
    [anon_sym_POUNDIf] = ACTIONS(3907),
    [anon_sym_not] = ACTIONS(3905),
    [anon_sym_NOT] = ACTIONS(3905),
    [anon_sym_Not] = ACTIONS(3905),
    [anon_sym_POUNDelse] = ACTIONS(3907),
    [anon_sym_POUNDELSE] = ACTIONS(3907),
    [anon_sym_POUNDElse] = ACTIONS(3907),
    [anon_sym_POUNDelse2] = ACTIONS(3907),
    [anon_sym_POUNDELSE2] = ACTIONS(3907),
    [anon_sym_POUNDElse2] = ACTIONS(3907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3907),
    [aux_sym__expression_token1] = ACTIONS(3907),
    [aux_sym__expression_token2] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3905),
    [anon_sym_SLASH] = ACTIONS(3905),
    [anon_sym_div] = ACTIONS(3905),
    [anon_sym_DIV] = ACTIONS(3905),
    [anon_sym_Div] = ACTIONS(3905),
    [anon_sym_mod] = ACTIONS(3905),
    [anon_sym_MOD] = ACTIONS(3905),
    [anon_sym_Mod] = ACTIONS(3905),
    [anon_sym_PLUS] = ACTIONS(3905),
    [anon_sym_GT_EQ] = ACTIONS(3907),
    [anon_sym_LT_EQ] = ACTIONS(3907),
    [anon_sym_GT] = ACTIONS(3905),
    [anon_sym_LT] = ACTIONS(3905),
    [anon_sym_LT_GT] = ACTIONS(3907),
    [anon_sym_and] = ACTIONS(3905),
    [anon_sym_AND] = ACTIONS(3905),
    [anon_sym_And] = ACTIONS(3905),
    [anon_sym_or] = ACTIONS(3905),
    [anon_sym_OR] = ACTIONS(3905),
    [anon_sym_Or] = ACTIONS(3905),
    [anon_sym_xor] = ACTIONS(3905),
    [anon_sym_XOR] = ACTIONS(3905),
    [anon_sym_Xor] = ACTIONS(3905),
    [anon_sym_QMARK] = ACTIONS(3907),
    [sym_datetime_literal] = ACTIONS(3907),
    [sym_date_literal] = ACTIONS(3905),
    [sym_time_literal] = ACTIONS(3905),
    [sym_biginteger_literal] = ACTIONS(3907),
    [anon_sym_if] = ACTIONS(3905),
    [anon_sym_IF] = ACTIONS(3905),
    [anon_sym_If] = ACTIONS(3905),
    [anon_sym_else] = ACTIONS(3905),
    [anon_sym_ELSE] = ACTIONS(3905),
    [anon_sym_Else] = ACTIONS(3905),
    [anon_sym_case] = ACTIONS(3905),
    [anon_sym_CASE] = ACTIONS(3905),
    [anon_sym_Case] = ACTIONS(3905),
    [anon_sym_for] = ACTIONS(3905),
    [anon_sym_FOR] = ACTIONS(3905),
    [anon_sym_For] = ACTIONS(3905),
    [anon_sym_foreach] = ACTIONS(3905),
    [anon_sym_FOREACH] = ACTIONS(3905),
    [anon_sym_Foreach] = ACTIONS(3905),
    [anon_sym_while] = ACTIONS(3905),
    [anon_sym_WHILE] = ACTIONS(3905),
    [anon_sym_While] = ACTIONS(3905),
    [anon_sym_repeat] = ACTIONS(3905),
    [anon_sym_REPEAT] = ACTIONS(3905),
    [anon_sym_Repeat] = ACTIONS(3905),
    [anon_sym_exit] = ACTIONS(3905),
    [anon_sym_EXIT] = ACTIONS(3905),
    [anon_sym_Exit] = ACTIONS(3905),
    [anon_sym_continue] = ACTIONS(3905),
    [anon_sym_CONTINUE] = ACTIONS(3905),
    [anon_sym_Continue] = ACTIONS(3905),
    [anon_sym_break] = ACTIONS(3905),
    [anon_sym_BREAK] = ACTIONS(3905),
    [anon_sym_Break] = ACTIONS(3905),
    [anon_sym_with] = ACTIONS(3905),
    [anon_sym_WITH] = ACTIONS(3905),
    [anon_sym_With] = ACTIONS(3905),
    [sym_asserterror_keyword] = ACTIONS(3907),
    [anon_sym_in] = ACTIONS(3905),
    [anon_sym_IN] = ACTIONS(3905),
    [anon_sym_In] = ACTIONS(3905),
    [sym_page_keyword] = ACTIONS(3905),
    [anon_sym_codeunit] = ACTIONS(3905),
    [anon_sym_CODEUNIT] = ACTIONS(3905),
    [anon_sym_Codeunit] = ACTIONS(3905),
    [anon_sym_CodeUnit] = ACTIONS(3905),
    [anon_sym_COdeunit] = ACTIONS(3905),
    [anon_sym_codeUnit] = ACTIONS(3905),
    [sym_report_keyword] = ACTIONS(3905),
    [sym_query_keyword] = ACTIONS(3905),
    [anon_sym_xmlport] = ACTIONS(3905),
    [anon_sym_XMLPORT] = ACTIONS(3905),
    [anon_sym_Xmlport] = ACTIONS(3905),
    [anon_sym_XMLport] = ACTIONS(3905),
    [anon_sym_XMLPort] = ACTIONS(3905),
    [anon_sym_XmlPort] = ACTIONS(3905),
    [anon_sym_enum] = ACTIONS(3905),
    [anon_sym_ENUM] = ACTIONS(3905),
    [anon_sym_Enum] = ACTIONS(3905),
    [anon_sym_eNUM] = ACTIONS(3905),
    [anon_sym_eNum] = ACTIONS(3905),
    [anon_sym_ENum] = ACTIONS(3905),
    [sym_quoted_identifier] = ACTIONS(3907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3907),
    [sym_verbatim_string] = ACTIONS(3907),
    [sym_integer] = ACTIONS(3905),
    [sym_continue_as_identifier] = ACTIONS(3907),
    [sym_preproc_open] = ACTIONS(3907),
    [sym_end_keyword] = ACTIONS(3907),
  },
  [STATE(2053)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10515),
    [sym_else_table_relation_fragment] = STATE(10515),
    [sym_table_relation_expression] = STATE(10515),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8084),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2240),
    [sym_preproc_endif] = STATE(5323),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10855),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8084),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(10856),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4397),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4399),
    [anon_sym_POUNDENDIF] = ACTIONS(4399),
    [anon_sym_POUNDEndif] = ACTIONS(4399),
    [anon_sym_POUNDendif2] = ACTIONS(4399),
    [anon_sym_POUNDENDIF2] = ACTIONS(4399),
    [anon_sym_POUNDEndif2] = ACTIONS(4399),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4399),
  },
  [STATE(2054)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10535),
    [sym_else_table_relation_fragment] = STATE(10535),
    [sym_table_relation_expression] = STATE(10535),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8033),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2241),
    [sym_preproc_endif] = STATE(4301),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10882),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8033),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(10884),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4403),
    [anon_sym_POUNDENDIF] = ACTIONS(4403),
    [anon_sym_POUNDEndif] = ACTIONS(4403),
    [anon_sym_POUNDendif2] = ACTIONS(4403),
    [anon_sym_POUNDENDIF2] = ACTIONS(4403),
    [anon_sym_POUNDEndif2] = ACTIONS(4403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4403),
  },
  [STATE(2055)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_end_keyword] = ACTIONS(3875),
  },
  [STATE(2056)] = {
    [sym_identifier] = ACTIONS(3921),
    [anon_sym_SEMI] = ACTIONS(3923),
    [anon_sym_DOT] = ACTIONS(3921),
    [anon_sym_EQ] = ACTIONS(3923),
    [anon_sym_DASH] = ACTIONS(3921),
    [aux_sym_boolean_token1] = ACTIONS(3921),
    [aux_sym_boolean_token2] = ACTIONS(3921),
    [sym_decimal] = ACTIONS(3921),
    [anon_sym_LPAREN] = ACTIONS(3923),
    [anon_sym_DOT_DOT] = ACTIONS(3923),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3921),
    [anon_sym_STAR] = ACTIONS(3921),
    [anon_sym_LBRACK] = ACTIONS(3923),
    [aux_sym_record_type_token1] = ACTIONS(3921),
    [aux_sym_basic_type_token21] = ACTIONS(3921),
    [aux_sym_basic_type_token22] = ACTIONS(3921),
    [aux_sym_basic_type_token48] = ACTIONS(3921),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3921),
    [anon_sym_POUNDif] = ACTIONS(3923),
    [anon_sym_POUNDIF] = ACTIONS(3923),
    [anon_sym_POUNDIf] = ACTIONS(3923),
    [anon_sym_not] = ACTIONS(3921),
    [anon_sym_NOT] = ACTIONS(3921),
    [anon_sym_Not] = ACTIONS(3921),
    [anon_sym_POUNDelse] = ACTIONS(3923),
    [anon_sym_POUNDELSE] = ACTIONS(3923),
    [anon_sym_POUNDElse] = ACTIONS(3923),
    [anon_sym_POUNDelse2] = ACTIONS(3923),
    [anon_sym_POUNDELSE2] = ACTIONS(3923),
    [anon_sym_POUNDElse2] = ACTIONS(3923),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3923),
    [aux_sym__expression_token1] = ACTIONS(3923),
    [aux_sym__expression_token2] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3921),
    [anon_sym_SLASH] = ACTIONS(3921),
    [anon_sym_div] = ACTIONS(3921),
    [anon_sym_DIV] = ACTIONS(3921),
    [anon_sym_Div] = ACTIONS(3921),
    [anon_sym_mod] = ACTIONS(3921),
    [anon_sym_MOD] = ACTIONS(3921),
    [anon_sym_Mod] = ACTIONS(3921),
    [anon_sym_PLUS] = ACTIONS(3921),
    [anon_sym_GT_EQ] = ACTIONS(3923),
    [anon_sym_LT_EQ] = ACTIONS(3923),
    [anon_sym_GT] = ACTIONS(3921),
    [anon_sym_LT] = ACTIONS(3921),
    [anon_sym_LT_GT] = ACTIONS(3923),
    [anon_sym_and] = ACTIONS(3921),
    [anon_sym_AND] = ACTIONS(3921),
    [anon_sym_And] = ACTIONS(3921),
    [anon_sym_or] = ACTIONS(3921),
    [anon_sym_OR] = ACTIONS(3921),
    [anon_sym_Or] = ACTIONS(3921),
    [anon_sym_xor] = ACTIONS(3921),
    [anon_sym_XOR] = ACTIONS(3921),
    [anon_sym_Xor] = ACTIONS(3921),
    [anon_sym_QMARK] = ACTIONS(3923),
    [sym_datetime_literal] = ACTIONS(3923),
    [sym_date_literal] = ACTIONS(3921),
    [sym_time_literal] = ACTIONS(3921),
    [sym_biginteger_literal] = ACTIONS(3923),
    [anon_sym_if] = ACTIONS(3921),
    [anon_sym_IF] = ACTIONS(3921),
    [anon_sym_If] = ACTIONS(3921),
    [anon_sym_else] = ACTIONS(3921),
    [anon_sym_ELSE] = ACTIONS(3921),
    [anon_sym_Else] = ACTIONS(3921),
    [anon_sym_case] = ACTIONS(3921),
    [anon_sym_CASE] = ACTIONS(3921),
    [anon_sym_Case] = ACTIONS(3921),
    [anon_sym_for] = ACTIONS(3921),
    [anon_sym_FOR] = ACTIONS(3921),
    [anon_sym_For] = ACTIONS(3921),
    [anon_sym_foreach] = ACTIONS(3921),
    [anon_sym_FOREACH] = ACTIONS(3921),
    [anon_sym_Foreach] = ACTIONS(3921),
    [anon_sym_while] = ACTIONS(3921),
    [anon_sym_WHILE] = ACTIONS(3921),
    [anon_sym_While] = ACTIONS(3921),
    [anon_sym_repeat] = ACTIONS(3921),
    [anon_sym_REPEAT] = ACTIONS(3921),
    [anon_sym_Repeat] = ACTIONS(3921),
    [anon_sym_exit] = ACTIONS(3921),
    [anon_sym_EXIT] = ACTIONS(3921),
    [anon_sym_Exit] = ACTIONS(3921),
    [anon_sym_continue] = ACTIONS(3921),
    [anon_sym_CONTINUE] = ACTIONS(3921),
    [anon_sym_Continue] = ACTIONS(3921),
    [anon_sym_break] = ACTIONS(3921),
    [anon_sym_BREAK] = ACTIONS(3921),
    [anon_sym_Break] = ACTIONS(3921),
    [anon_sym_with] = ACTIONS(3921),
    [anon_sym_WITH] = ACTIONS(3921),
    [anon_sym_With] = ACTIONS(3921),
    [sym_asserterror_keyword] = ACTIONS(3923),
    [anon_sym_in] = ACTIONS(3921),
    [anon_sym_IN] = ACTIONS(3921),
    [anon_sym_In] = ACTIONS(3921),
    [sym_page_keyword] = ACTIONS(3921),
    [anon_sym_codeunit] = ACTIONS(3921),
    [anon_sym_CODEUNIT] = ACTIONS(3921),
    [anon_sym_Codeunit] = ACTIONS(3921),
    [anon_sym_CodeUnit] = ACTIONS(3921),
    [anon_sym_COdeunit] = ACTIONS(3921),
    [anon_sym_codeUnit] = ACTIONS(3921),
    [sym_report_keyword] = ACTIONS(3921),
    [sym_query_keyword] = ACTIONS(3921),
    [anon_sym_xmlport] = ACTIONS(3921),
    [anon_sym_XMLPORT] = ACTIONS(3921),
    [anon_sym_Xmlport] = ACTIONS(3921),
    [anon_sym_XMLport] = ACTIONS(3921),
    [anon_sym_XMLPort] = ACTIONS(3921),
    [anon_sym_XmlPort] = ACTIONS(3921),
    [anon_sym_enum] = ACTIONS(3921),
    [anon_sym_ENUM] = ACTIONS(3921),
    [anon_sym_Enum] = ACTIONS(3921),
    [anon_sym_eNUM] = ACTIONS(3921),
    [anon_sym_eNum] = ACTIONS(3921),
    [anon_sym_ENum] = ACTIONS(3921),
    [sym_quoted_identifier] = ACTIONS(3923),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3923),
    [sym_verbatim_string] = ACTIONS(3923),
    [sym_integer] = ACTIONS(3921),
    [sym_continue_as_identifier] = ACTIONS(3923),
    [sym_preproc_open] = ACTIONS(3923),
    [sym_end_keyword] = ACTIONS(3923),
  },
  [STATE(2057)] = {
    [sym_identifier] = ACTIONS(3881),
    [anon_sym_SEMI] = ACTIONS(3883),
    [anon_sym_DOT] = ACTIONS(3881),
    [anon_sym_EQ] = ACTIONS(3883),
    [anon_sym_DASH] = ACTIONS(3881),
    [aux_sym_boolean_token1] = ACTIONS(3881),
    [aux_sym_boolean_token2] = ACTIONS(3881),
    [sym_decimal] = ACTIONS(3881),
    [anon_sym_LPAREN] = ACTIONS(3883),
    [anon_sym_DOT_DOT] = ACTIONS(3883),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3881),
    [anon_sym_STAR] = ACTIONS(3881),
    [anon_sym_LBRACK] = ACTIONS(3883),
    [aux_sym_record_type_token1] = ACTIONS(3881),
    [aux_sym_basic_type_token21] = ACTIONS(3881),
    [aux_sym_basic_type_token22] = ACTIONS(3881),
    [aux_sym_basic_type_token48] = ACTIONS(3881),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3881),
    [anon_sym_POUNDif] = ACTIONS(3883),
    [anon_sym_POUNDIF] = ACTIONS(3883),
    [anon_sym_POUNDIf] = ACTIONS(3883),
    [anon_sym_not] = ACTIONS(3881),
    [anon_sym_NOT] = ACTIONS(3881),
    [anon_sym_Not] = ACTIONS(3881),
    [anon_sym_POUNDelse] = ACTIONS(3883),
    [anon_sym_POUNDELSE] = ACTIONS(3883),
    [anon_sym_POUNDElse] = ACTIONS(3883),
    [anon_sym_POUNDelse2] = ACTIONS(3883),
    [anon_sym_POUNDELSE2] = ACTIONS(3883),
    [anon_sym_POUNDElse2] = ACTIONS(3883),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3883),
    [aux_sym__expression_token1] = ACTIONS(3883),
    [aux_sym__expression_token2] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3881),
    [anon_sym_SLASH] = ACTIONS(3881),
    [anon_sym_div] = ACTIONS(3881),
    [anon_sym_DIV] = ACTIONS(3881),
    [anon_sym_Div] = ACTIONS(3881),
    [anon_sym_mod] = ACTIONS(3881),
    [anon_sym_MOD] = ACTIONS(3881),
    [anon_sym_Mod] = ACTIONS(3881),
    [anon_sym_PLUS] = ACTIONS(3881),
    [anon_sym_GT_EQ] = ACTIONS(3883),
    [anon_sym_LT_EQ] = ACTIONS(3883),
    [anon_sym_GT] = ACTIONS(3881),
    [anon_sym_LT] = ACTIONS(3881),
    [anon_sym_LT_GT] = ACTIONS(3883),
    [anon_sym_and] = ACTIONS(3881),
    [anon_sym_AND] = ACTIONS(3881),
    [anon_sym_And] = ACTIONS(3881),
    [anon_sym_or] = ACTIONS(3881),
    [anon_sym_OR] = ACTIONS(3881),
    [anon_sym_Or] = ACTIONS(3881),
    [anon_sym_xor] = ACTIONS(3881),
    [anon_sym_XOR] = ACTIONS(3881),
    [anon_sym_Xor] = ACTIONS(3881),
    [anon_sym_QMARK] = ACTIONS(3883),
    [sym_datetime_literal] = ACTIONS(3883),
    [sym_date_literal] = ACTIONS(3881),
    [sym_time_literal] = ACTIONS(3881),
    [sym_biginteger_literal] = ACTIONS(3883),
    [anon_sym_if] = ACTIONS(3881),
    [anon_sym_IF] = ACTIONS(3881),
    [anon_sym_If] = ACTIONS(3881),
    [anon_sym_else] = ACTIONS(3881),
    [anon_sym_ELSE] = ACTIONS(3881),
    [anon_sym_Else] = ACTIONS(3881),
    [anon_sym_case] = ACTIONS(3881),
    [anon_sym_CASE] = ACTIONS(3881),
    [anon_sym_Case] = ACTIONS(3881),
    [anon_sym_for] = ACTIONS(3881),
    [anon_sym_FOR] = ACTIONS(3881),
    [anon_sym_For] = ACTIONS(3881),
    [anon_sym_foreach] = ACTIONS(3881),
    [anon_sym_FOREACH] = ACTIONS(3881),
    [anon_sym_Foreach] = ACTIONS(3881),
    [anon_sym_while] = ACTIONS(3881),
    [anon_sym_WHILE] = ACTIONS(3881),
    [anon_sym_While] = ACTIONS(3881),
    [anon_sym_repeat] = ACTIONS(3881),
    [anon_sym_REPEAT] = ACTIONS(3881),
    [anon_sym_Repeat] = ACTIONS(3881),
    [anon_sym_exit] = ACTIONS(3881),
    [anon_sym_EXIT] = ACTIONS(3881),
    [anon_sym_Exit] = ACTIONS(3881),
    [anon_sym_continue] = ACTIONS(3881),
    [anon_sym_CONTINUE] = ACTIONS(3881),
    [anon_sym_Continue] = ACTIONS(3881),
    [anon_sym_break] = ACTIONS(3881),
    [anon_sym_BREAK] = ACTIONS(3881),
    [anon_sym_Break] = ACTIONS(3881),
    [anon_sym_with] = ACTIONS(3881),
    [anon_sym_WITH] = ACTIONS(3881),
    [anon_sym_With] = ACTIONS(3881),
    [sym_asserterror_keyword] = ACTIONS(3883),
    [anon_sym_in] = ACTIONS(3881),
    [anon_sym_IN] = ACTIONS(3881),
    [anon_sym_In] = ACTIONS(3881),
    [sym_page_keyword] = ACTIONS(3881),
    [anon_sym_codeunit] = ACTIONS(3881),
    [anon_sym_CODEUNIT] = ACTIONS(3881),
    [anon_sym_Codeunit] = ACTIONS(3881),
    [anon_sym_CodeUnit] = ACTIONS(3881),
    [anon_sym_COdeunit] = ACTIONS(3881),
    [anon_sym_codeUnit] = ACTIONS(3881),
    [sym_report_keyword] = ACTIONS(3881),
    [sym_query_keyword] = ACTIONS(3881),
    [anon_sym_xmlport] = ACTIONS(3881),
    [anon_sym_XMLPORT] = ACTIONS(3881),
    [anon_sym_Xmlport] = ACTIONS(3881),
    [anon_sym_XMLport] = ACTIONS(3881),
    [anon_sym_XMLPort] = ACTIONS(3881),
    [anon_sym_XmlPort] = ACTIONS(3881),
    [anon_sym_enum] = ACTIONS(3881),
    [anon_sym_ENUM] = ACTIONS(3881),
    [anon_sym_Enum] = ACTIONS(3881),
    [anon_sym_eNUM] = ACTIONS(3881),
    [anon_sym_eNum] = ACTIONS(3881),
    [anon_sym_ENum] = ACTIONS(3881),
    [sym_quoted_identifier] = ACTIONS(3883),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3883),
    [sym_verbatim_string] = ACTIONS(3883),
    [sym_integer] = ACTIONS(3881),
    [sym_continue_as_identifier] = ACTIONS(3883),
    [sym_preproc_open] = ACTIONS(3883),
    [sym_end_keyword] = ACTIONS(3883),
  },
  [STATE(2058)] = {
    [sym_identifier] = ACTIONS(3889),
    [anon_sym_SEMI] = ACTIONS(3891),
    [anon_sym_DOT] = ACTIONS(3889),
    [anon_sym_EQ] = ACTIONS(3891),
    [anon_sym_DASH] = ACTIONS(3889),
    [aux_sym_boolean_token1] = ACTIONS(3889),
    [aux_sym_boolean_token2] = ACTIONS(3889),
    [sym_decimal] = ACTIONS(3889),
    [anon_sym_LPAREN] = ACTIONS(3891),
    [anon_sym_DOT_DOT] = ACTIONS(3891),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3889),
    [anon_sym_STAR] = ACTIONS(3889),
    [anon_sym_LBRACK] = ACTIONS(3891),
    [aux_sym_record_type_token1] = ACTIONS(3889),
    [aux_sym_basic_type_token21] = ACTIONS(3889),
    [aux_sym_basic_type_token22] = ACTIONS(3889),
    [aux_sym_basic_type_token48] = ACTIONS(3889),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3889),
    [anon_sym_POUNDif] = ACTIONS(3891),
    [anon_sym_POUNDIF] = ACTIONS(3891),
    [anon_sym_POUNDIf] = ACTIONS(3891),
    [anon_sym_not] = ACTIONS(3889),
    [anon_sym_NOT] = ACTIONS(3889),
    [anon_sym_Not] = ACTIONS(3889),
    [anon_sym_POUNDelse] = ACTIONS(3891),
    [anon_sym_POUNDELSE] = ACTIONS(3891),
    [anon_sym_POUNDElse] = ACTIONS(3891),
    [anon_sym_POUNDelse2] = ACTIONS(3891),
    [anon_sym_POUNDELSE2] = ACTIONS(3891),
    [anon_sym_POUNDElse2] = ACTIONS(3891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3891),
    [aux_sym__expression_token1] = ACTIONS(3891),
    [aux_sym__expression_token2] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3889),
    [anon_sym_SLASH] = ACTIONS(3889),
    [anon_sym_div] = ACTIONS(3889),
    [anon_sym_DIV] = ACTIONS(3889),
    [anon_sym_Div] = ACTIONS(3889),
    [anon_sym_mod] = ACTIONS(3889),
    [anon_sym_MOD] = ACTIONS(3889),
    [anon_sym_Mod] = ACTIONS(3889),
    [anon_sym_PLUS] = ACTIONS(3889),
    [anon_sym_GT_EQ] = ACTIONS(3891),
    [anon_sym_LT_EQ] = ACTIONS(3891),
    [anon_sym_GT] = ACTIONS(3889),
    [anon_sym_LT] = ACTIONS(3889),
    [anon_sym_LT_GT] = ACTIONS(3891),
    [anon_sym_and] = ACTIONS(3889),
    [anon_sym_AND] = ACTIONS(3889),
    [anon_sym_And] = ACTIONS(3889),
    [anon_sym_or] = ACTIONS(3889),
    [anon_sym_OR] = ACTIONS(3889),
    [anon_sym_Or] = ACTIONS(3889),
    [anon_sym_xor] = ACTIONS(3889),
    [anon_sym_XOR] = ACTIONS(3889),
    [anon_sym_Xor] = ACTIONS(3889),
    [anon_sym_QMARK] = ACTIONS(3891),
    [sym_datetime_literal] = ACTIONS(3891),
    [sym_date_literal] = ACTIONS(3889),
    [sym_time_literal] = ACTIONS(3889),
    [sym_biginteger_literal] = ACTIONS(3891),
    [anon_sym_if] = ACTIONS(3889),
    [anon_sym_IF] = ACTIONS(3889),
    [anon_sym_If] = ACTIONS(3889),
    [anon_sym_else] = ACTIONS(3889),
    [anon_sym_ELSE] = ACTIONS(3889),
    [anon_sym_Else] = ACTIONS(3889),
    [anon_sym_case] = ACTIONS(3889),
    [anon_sym_CASE] = ACTIONS(3889),
    [anon_sym_Case] = ACTIONS(3889),
    [anon_sym_for] = ACTIONS(3889),
    [anon_sym_FOR] = ACTIONS(3889),
    [anon_sym_For] = ACTIONS(3889),
    [anon_sym_foreach] = ACTIONS(3889),
    [anon_sym_FOREACH] = ACTIONS(3889),
    [anon_sym_Foreach] = ACTIONS(3889),
    [anon_sym_while] = ACTIONS(3889),
    [anon_sym_WHILE] = ACTIONS(3889),
    [anon_sym_While] = ACTIONS(3889),
    [anon_sym_repeat] = ACTIONS(3889),
    [anon_sym_REPEAT] = ACTIONS(3889),
    [anon_sym_Repeat] = ACTIONS(3889),
    [anon_sym_exit] = ACTIONS(3889),
    [anon_sym_EXIT] = ACTIONS(3889),
    [anon_sym_Exit] = ACTIONS(3889),
    [anon_sym_continue] = ACTIONS(3889),
    [anon_sym_CONTINUE] = ACTIONS(3889),
    [anon_sym_Continue] = ACTIONS(3889),
    [anon_sym_break] = ACTIONS(3889),
    [anon_sym_BREAK] = ACTIONS(3889),
    [anon_sym_Break] = ACTIONS(3889),
    [anon_sym_with] = ACTIONS(3889),
    [anon_sym_WITH] = ACTIONS(3889),
    [anon_sym_With] = ACTIONS(3889),
    [sym_asserterror_keyword] = ACTIONS(3891),
    [anon_sym_in] = ACTIONS(3889),
    [anon_sym_IN] = ACTIONS(3889),
    [anon_sym_In] = ACTIONS(3889),
    [sym_page_keyword] = ACTIONS(3889),
    [anon_sym_codeunit] = ACTIONS(3889),
    [anon_sym_CODEUNIT] = ACTIONS(3889),
    [anon_sym_Codeunit] = ACTIONS(3889),
    [anon_sym_CodeUnit] = ACTIONS(3889),
    [anon_sym_COdeunit] = ACTIONS(3889),
    [anon_sym_codeUnit] = ACTIONS(3889),
    [sym_report_keyword] = ACTIONS(3889),
    [sym_query_keyword] = ACTIONS(3889),
    [anon_sym_xmlport] = ACTIONS(3889),
    [anon_sym_XMLPORT] = ACTIONS(3889),
    [anon_sym_Xmlport] = ACTIONS(3889),
    [anon_sym_XMLport] = ACTIONS(3889),
    [anon_sym_XMLPort] = ACTIONS(3889),
    [anon_sym_XmlPort] = ACTIONS(3889),
    [anon_sym_enum] = ACTIONS(3889),
    [anon_sym_ENUM] = ACTIONS(3889),
    [anon_sym_Enum] = ACTIONS(3889),
    [anon_sym_eNUM] = ACTIONS(3889),
    [anon_sym_eNum] = ACTIONS(3889),
    [anon_sym_ENum] = ACTIONS(3889),
    [sym_quoted_identifier] = ACTIONS(3891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3891),
    [sym_verbatim_string] = ACTIONS(3891),
    [sym_integer] = ACTIONS(3889),
    [sym_continue_as_identifier] = ACTIONS(3891),
    [sym_preproc_open] = ACTIONS(3891),
    [sym_end_keyword] = ACTIONS(3891),
  },
  [STATE(2059)] = {
    [sym_identifier] = ACTIONS(3893),
    [anon_sym_SEMI] = ACTIONS(3895),
    [anon_sym_DOT] = ACTIONS(3893),
    [anon_sym_EQ] = ACTIONS(3895),
    [anon_sym_DASH] = ACTIONS(3893),
    [aux_sym_boolean_token1] = ACTIONS(3893),
    [aux_sym_boolean_token2] = ACTIONS(3893),
    [sym_decimal] = ACTIONS(3893),
    [anon_sym_LPAREN] = ACTIONS(3895),
    [anon_sym_DOT_DOT] = ACTIONS(3895),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3893),
    [anon_sym_STAR] = ACTIONS(3893),
    [anon_sym_LBRACK] = ACTIONS(3895),
    [aux_sym_record_type_token1] = ACTIONS(3893),
    [aux_sym_basic_type_token21] = ACTIONS(3893),
    [aux_sym_basic_type_token22] = ACTIONS(3893),
    [aux_sym_basic_type_token48] = ACTIONS(3893),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3893),
    [anon_sym_POUNDif] = ACTIONS(3895),
    [anon_sym_POUNDIF] = ACTIONS(3895),
    [anon_sym_POUNDIf] = ACTIONS(3895),
    [anon_sym_not] = ACTIONS(3893),
    [anon_sym_NOT] = ACTIONS(3893),
    [anon_sym_Not] = ACTIONS(3893),
    [anon_sym_POUNDelse] = ACTIONS(3895),
    [anon_sym_POUNDELSE] = ACTIONS(3895),
    [anon_sym_POUNDElse] = ACTIONS(3895),
    [anon_sym_POUNDelse2] = ACTIONS(3895),
    [anon_sym_POUNDELSE2] = ACTIONS(3895),
    [anon_sym_POUNDElse2] = ACTIONS(3895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3895),
    [aux_sym__expression_token1] = ACTIONS(3895),
    [aux_sym__expression_token2] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3893),
    [anon_sym_SLASH] = ACTIONS(3893),
    [anon_sym_div] = ACTIONS(3893),
    [anon_sym_DIV] = ACTIONS(3893),
    [anon_sym_Div] = ACTIONS(3893),
    [anon_sym_mod] = ACTIONS(3893),
    [anon_sym_MOD] = ACTIONS(3893),
    [anon_sym_Mod] = ACTIONS(3893),
    [anon_sym_PLUS] = ACTIONS(3893),
    [anon_sym_GT_EQ] = ACTIONS(3895),
    [anon_sym_LT_EQ] = ACTIONS(3895),
    [anon_sym_GT] = ACTIONS(3893),
    [anon_sym_LT] = ACTIONS(3893),
    [anon_sym_LT_GT] = ACTIONS(3895),
    [anon_sym_and] = ACTIONS(3893),
    [anon_sym_AND] = ACTIONS(3893),
    [anon_sym_And] = ACTIONS(3893),
    [anon_sym_or] = ACTIONS(3893),
    [anon_sym_OR] = ACTIONS(3893),
    [anon_sym_Or] = ACTIONS(3893),
    [anon_sym_xor] = ACTIONS(3893),
    [anon_sym_XOR] = ACTIONS(3893),
    [anon_sym_Xor] = ACTIONS(3893),
    [anon_sym_QMARK] = ACTIONS(3895),
    [sym_datetime_literal] = ACTIONS(3895),
    [sym_date_literal] = ACTIONS(3893),
    [sym_time_literal] = ACTIONS(3893),
    [sym_biginteger_literal] = ACTIONS(3895),
    [anon_sym_if] = ACTIONS(3893),
    [anon_sym_IF] = ACTIONS(3893),
    [anon_sym_If] = ACTIONS(3893),
    [anon_sym_else] = ACTIONS(3893),
    [anon_sym_ELSE] = ACTIONS(3893),
    [anon_sym_Else] = ACTIONS(3893),
    [anon_sym_case] = ACTIONS(3893),
    [anon_sym_CASE] = ACTIONS(3893),
    [anon_sym_Case] = ACTIONS(3893),
    [anon_sym_for] = ACTIONS(3893),
    [anon_sym_FOR] = ACTIONS(3893),
    [anon_sym_For] = ACTIONS(3893),
    [anon_sym_foreach] = ACTIONS(3893),
    [anon_sym_FOREACH] = ACTIONS(3893),
    [anon_sym_Foreach] = ACTIONS(3893),
    [anon_sym_while] = ACTIONS(3893),
    [anon_sym_WHILE] = ACTIONS(3893),
    [anon_sym_While] = ACTIONS(3893),
    [anon_sym_repeat] = ACTIONS(3893),
    [anon_sym_REPEAT] = ACTIONS(3893),
    [anon_sym_Repeat] = ACTIONS(3893),
    [anon_sym_exit] = ACTIONS(3893),
    [anon_sym_EXIT] = ACTIONS(3893),
    [anon_sym_Exit] = ACTIONS(3893),
    [anon_sym_continue] = ACTIONS(3893),
    [anon_sym_CONTINUE] = ACTIONS(3893),
    [anon_sym_Continue] = ACTIONS(3893),
    [anon_sym_break] = ACTIONS(3893),
    [anon_sym_BREAK] = ACTIONS(3893),
    [anon_sym_Break] = ACTIONS(3893),
    [anon_sym_with] = ACTIONS(3893),
    [anon_sym_WITH] = ACTIONS(3893),
    [anon_sym_With] = ACTIONS(3893),
    [sym_asserterror_keyword] = ACTIONS(3895),
    [anon_sym_in] = ACTIONS(3893),
    [anon_sym_IN] = ACTIONS(3893),
    [anon_sym_In] = ACTIONS(3893),
    [sym_page_keyword] = ACTIONS(3893),
    [anon_sym_codeunit] = ACTIONS(3893),
    [anon_sym_CODEUNIT] = ACTIONS(3893),
    [anon_sym_Codeunit] = ACTIONS(3893),
    [anon_sym_CodeUnit] = ACTIONS(3893),
    [anon_sym_COdeunit] = ACTIONS(3893),
    [anon_sym_codeUnit] = ACTIONS(3893),
    [sym_report_keyword] = ACTIONS(3893),
    [sym_query_keyword] = ACTIONS(3893),
    [anon_sym_xmlport] = ACTIONS(3893),
    [anon_sym_XMLPORT] = ACTIONS(3893),
    [anon_sym_Xmlport] = ACTIONS(3893),
    [anon_sym_XMLport] = ACTIONS(3893),
    [anon_sym_XMLPort] = ACTIONS(3893),
    [anon_sym_XmlPort] = ACTIONS(3893),
    [anon_sym_enum] = ACTIONS(3893),
    [anon_sym_ENUM] = ACTIONS(3893),
    [anon_sym_Enum] = ACTIONS(3893),
    [anon_sym_eNUM] = ACTIONS(3893),
    [anon_sym_eNum] = ACTIONS(3893),
    [anon_sym_ENum] = ACTIONS(3893),
    [sym_quoted_identifier] = ACTIONS(3895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3895),
    [sym_verbatim_string] = ACTIONS(3895),
    [sym_integer] = ACTIONS(3893),
    [sym_continue_as_identifier] = ACTIONS(3895),
    [sym_preproc_open] = ACTIONS(3895),
    [sym_end_keyword] = ACTIONS(3895),
  },
  [STATE(2060)] = {
    [sym_boolean] = STATE(2330),
    [sym_option_member_list] = STATE(2343),
    [sym_option_member] = STATE(2312),
    [sym_keyword_identifier] = STATE(2330),
    [sym_codeunit_keyword] = STATE(2308),
    [sym_xmlport_keyword] = STATE(2308),
    [sym_enum_keyword] = STATE(2308),
    [sym_keyword_as_identifier] = STATE(2330),
    [aux_sym_option_member_list_repeat2] = STATE(2085),
    [sym_identifier] = ACTIONS(4405),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(4407),
    [anon_sym_COLON] = ACTIONS(584),
    [anon_sym_DASH] = ACTIONS(4409),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(584),
    [anon_sym_LPAREN] = ACTIONS(582),
    [aux_sym_where_condition_token1] = ACTIONS(4411),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(4413),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_basic_type_token53] = ACTIONS(4411),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4411),
    [aux_sym_separator_action_token1] = ACTIONS(4411),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4411),
    [aux_sym_type_declaration_token1] = ACTIONS(4411),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(584),
    [anon_sym_NOT] = ACTIONS(584),
    [anon_sym_Not] = ACTIONS(584),
    [anon_sym_POUNDelif] = ACTIONS(582),
    [anon_sym_POUNDELIF] = ACTIONS(582),
    [anon_sym_POUNDElif] = ACTIONS(582),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [anon_sym_POUNDendif] = ACTIONS(582),
    [anon_sym_POUNDENDIF] = ACTIONS(582),
    [anon_sym_POUNDEndif] = ACTIONS(582),
    [anon_sym_POUNDendif2] = ACTIONS(582),
    [anon_sym_POUNDENDIF2] = ACTIONS(582),
    [anon_sym_POUNDEndif2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(582),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [sym_datetime_literal] = ACTIONS(582),
    [sym_date_literal] = ACTIONS(584),
    [sym_time_literal] = ACTIONS(584),
    [sym_biginteger_literal] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(584),
    [anon_sym_ELSE] = ACTIONS(584),
    [anon_sym_Else] = ACTIONS(584),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(4411),
    [sym_page_keyword] = ACTIONS(369),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(369),
    [sym_query_keyword] = ACTIONS(369),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_local_keyword] = ACTIONS(4405),
    [sym_internal_keyword] = ACTIONS(4405),
    [sym_protected_keyword] = ACTIONS(4405),
    [sym_key_keyword] = ACTIONS(4411),
    [sym_dataset_keyword] = ACTIONS(4411),
    [sym_quoted_identifier] = ACTIONS(4415),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4415),
    [sym_verbatim_string] = ACTIONS(582),
    [sym_integer] = ACTIONS(4405),
    [sym_continue_as_identifier] = ACTIONS(582),
    [sym_preproc_open] = ACTIONS(582),
    [sym_preproc_close] = ACTIONS(582),
  },
  [STATE(2061)] = {
    [sym_identifier] = ACTIONS(3913),
    [anon_sym_SEMI] = ACTIONS(3915),
    [anon_sym_DOT] = ACTIONS(3913),
    [anon_sym_EQ] = ACTIONS(3915),
    [anon_sym_DASH] = ACTIONS(3913),
    [aux_sym_boolean_token1] = ACTIONS(3913),
    [aux_sym_boolean_token2] = ACTIONS(3913),
    [sym_decimal] = ACTIONS(3913),
    [anon_sym_LPAREN] = ACTIONS(3915),
    [anon_sym_DOT_DOT] = ACTIONS(3915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3913),
    [anon_sym_STAR] = ACTIONS(3913),
    [anon_sym_LBRACK] = ACTIONS(3915),
    [aux_sym_record_type_token1] = ACTIONS(3913),
    [aux_sym_basic_type_token21] = ACTIONS(3913),
    [aux_sym_basic_type_token22] = ACTIONS(3913),
    [aux_sym_basic_type_token48] = ACTIONS(3913),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3913),
    [anon_sym_POUNDif] = ACTIONS(3915),
    [anon_sym_POUNDIF] = ACTIONS(3915),
    [anon_sym_POUNDIf] = ACTIONS(3915),
    [anon_sym_not] = ACTIONS(3913),
    [anon_sym_NOT] = ACTIONS(3913),
    [anon_sym_Not] = ACTIONS(3913),
    [anon_sym_POUNDelse] = ACTIONS(3915),
    [anon_sym_POUNDELSE] = ACTIONS(3915),
    [anon_sym_POUNDElse] = ACTIONS(3915),
    [anon_sym_POUNDelse2] = ACTIONS(3915),
    [anon_sym_POUNDELSE2] = ACTIONS(3915),
    [anon_sym_POUNDElse2] = ACTIONS(3915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3915),
    [aux_sym__expression_token1] = ACTIONS(3915),
    [aux_sym__expression_token2] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3913),
    [anon_sym_SLASH] = ACTIONS(3913),
    [anon_sym_div] = ACTIONS(3913),
    [anon_sym_DIV] = ACTIONS(3913),
    [anon_sym_Div] = ACTIONS(3913),
    [anon_sym_mod] = ACTIONS(3913),
    [anon_sym_MOD] = ACTIONS(3913),
    [anon_sym_Mod] = ACTIONS(3913),
    [anon_sym_PLUS] = ACTIONS(3913),
    [anon_sym_GT_EQ] = ACTIONS(3915),
    [anon_sym_LT_EQ] = ACTIONS(3915),
    [anon_sym_GT] = ACTIONS(3913),
    [anon_sym_LT] = ACTIONS(3913),
    [anon_sym_LT_GT] = ACTIONS(3915),
    [anon_sym_and] = ACTIONS(3913),
    [anon_sym_AND] = ACTIONS(3913),
    [anon_sym_And] = ACTIONS(3913),
    [anon_sym_or] = ACTIONS(3913),
    [anon_sym_OR] = ACTIONS(3913),
    [anon_sym_Or] = ACTIONS(3913),
    [anon_sym_xor] = ACTIONS(3913),
    [anon_sym_XOR] = ACTIONS(3913),
    [anon_sym_Xor] = ACTIONS(3913),
    [anon_sym_QMARK] = ACTIONS(3915),
    [sym_datetime_literal] = ACTIONS(3915),
    [sym_date_literal] = ACTIONS(3913),
    [sym_time_literal] = ACTIONS(3913),
    [sym_biginteger_literal] = ACTIONS(3915),
    [anon_sym_if] = ACTIONS(3913),
    [anon_sym_IF] = ACTIONS(3913),
    [anon_sym_If] = ACTIONS(3913),
    [anon_sym_else] = ACTIONS(3913),
    [anon_sym_ELSE] = ACTIONS(3913),
    [anon_sym_Else] = ACTIONS(3913),
    [anon_sym_case] = ACTIONS(3913),
    [anon_sym_CASE] = ACTIONS(3913),
    [anon_sym_Case] = ACTIONS(3913),
    [anon_sym_for] = ACTIONS(3913),
    [anon_sym_FOR] = ACTIONS(3913),
    [anon_sym_For] = ACTIONS(3913),
    [anon_sym_foreach] = ACTIONS(3913),
    [anon_sym_FOREACH] = ACTIONS(3913),
    [anon_sym_Foreach] = ACTIONS(3913),
    [anon_sym_while] = ACTIONS(3913),
    [anon_sym_WHILE] = ACTIONS(3913),
    [anon_sym_While] = ACTIONS(3913),
    [anon_sym_repeat] = ACTIONS(3913),
    [anon_sym_REPEAT] = ACTIONS(3913),
    [anon_sym_Repeat] = ACTIONS(3913),
    [anon_sym_exit] = ACTIONS(3913),
    [anon_sym_EXIT] = ACTIONS(3913),
    [anon_sym_Exit] = ACTIONS(3913),
    [anon_sym_continue] = ACTIONS(3913),
    [anon_sym_CONTINUE] = ACTIONS(3913),
    [anon_sym_Continue] = ACTIONS(3913),
    [anon_sym_break] = ACTIONS(3913),
    [anon_sym_BREAK] = ACTIONS(3913),
    [anon_sym_Break] = ACTIONS(3913),
    [anon_sym_with] = ACTIONS(3913),
    [anon_sym_WITH] = ACTIONS(3913),
    [anon_sym_With] = ACTIONS(3913),
    [sym_asserterror_keyword] = ACTIONS(3915),
    [anon_sym_in] = ACTIONS(3913),
    [anon_sym_IN] = ACTIONS(3913),
    [anon_sym_In] = ACTIONS(3913),
    [sym_page_keyword] = ACTIONS(3913),
    [anon_sym_codeunit] = ACTIONS(3913),
    [anon_sym_CODEUNIT] = ACTIONS(3913),
    [anon_sym_Codeunit] = ACTIONS(3913),
    [anon_sym_CodeUnit] = ACTIONS(3913),
    [anon_sym_COdeunit] = ACTIONS(3913),
    [anon_sym_codeUnit] = ACTIONS(3913),
    [sym_report_keyword] = ACTIONS(3913),
    [sym_query_keyword] = ACTIONS(3913),
    [anon_sym_xmlport] = ACTIONS(3913),
    [anon_sym_XMLPORT] = ACTIONS(3913),
    [anon_sym_Xmlport] = ACTIONS(3913),
    [anon_sym_XMLport] = ACTIONS(3913),
    [anon_sym_XMLPort] = ACTIONS(3913),
    [anon_sym_XmlPort] = ACTIONS(3913),
    [anon_sym_enum] = ACTIONS(3913),
    [anon_sym_ENUM] = ACTIONS(3913),
    [anon_sym_Enum] = ACTIONS(3913),
    [anon_sym_eNUM] = ACTIONS(3913),
    [anon_sym_eNum] = ACTIONS(3913),
    [anon_sym_ENum] = ACTIONS(3913),
    [sym_quoted_identifier] = ACTIONS(3915),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3915),
    [sym_verbatim_string] = ACTIONS(3915),
    [sym_integer] = ACTIONS(3913),
    [sym_continue_as_identifier] = ACTIONS(3915),
    [sym_preproc_open] = ACTIONS(3915),
    [sym_end_keyword] = ACTIONS(3915),
  },
  [STATE(2062)] = {
    [sym_identifier] = ACTIONS(3925),
    [anon_sym_SEMI] = ACTIONS(3927),
    [anon_sym_DOT] = ACTIONS(3925),
    [anon_sym_EQ] = ACTIONS(3927),
    [anon_sym_DASH] = ACTIONS(3925),
    [aux_sym_boolean_token1] = ACTIONS(3925),
    [aux_sym_boolean_token2] = ACTIONS(3925),
    [sym_decimal] = ACTIONS(3925),
    [anon_sym_LPAREN] = ACTIONS(3927),
    [anon_sym_DOT_DOT] = ACTIONS(3927),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3925),
    [anon_sym_STAR] = ACTIONS(3925),
    [anon_sym_LBRACK] = ACTIONS(4417),
    [aux_sym_record_type_token1] = ACTIONS(3925),
    [aux_sym_basic_type_token21] = ACTIONS(3925),
    [aux_sym_basic_type_token22] = ACTIONS(3925),
    [aux_sym_basic_type_token48] = ACTIONS(3925),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3925),
    [anon_sym_POUNDif] = ACTIONS(3927),
    [anon_sym_POUNDIF] = ACTIONS(3927),
    [anon_sym_POUNDIf] = ACTIONS(3927),
    [anon_sym_not] = ACTIONS(3925),
    [anon_sym_NOT] = ACTIONS(3925),
    [anon_sym_Not] = ACTIONS(3925),
    [anon_sym_POUNDelse] = ACTIONS(3927),
    [anon_sym_POUNDELSE] = ACTIONS(3927),
    [anon_sym_POUNDElse] = ACTIONS(3927),
    [anon_sym_POUNDelse2] = ACTIONS(3927),
    [anon_sym_POUNDELSE2] = ACTIONS(3927),
    [anon_sym_POUNDElse2] = ACTIONS(3927),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3927),
    [aux_sym__expression_token1] = ACTIONS(3927),
    [aux_sym__expression_token2] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3925),
    [anon_sym_SLASH] = ACTIONS(3925),
    [anon_sym_div] = ACTIONS(3925),
    [anon_sym_DIV] = ACTIONS(3925),
    [anon_sym_Div] = ACTIONS(3925),
    [anon_sym_mod] = ACTIONS(3925),
    [anon_sym_MOD] = ACTIONS(3925),
    [anon_sym_Mod] = ACTIONS(3925),
    [anon_sym_PLUS] = ACTIONS(3925),
    [anon_sym_GT_EQ] = ACTIONS(3927),
    [anon_sym_LT_EQ] = ACTIONS(3927),
    [anon_sym_GT] = ACTIONS(3925),
    [anon_sym_LT] = ACTIONS(3925),
    [anon_sym_LT_GT] = ACTIONS(3927),
    [anon_sym_and] = ACTIONS(3925),
    [anon_sym_AND] = ACTIONS(3925),
    [anon_sym_And] = ACTIONS(3925),
    [anon_sym_or] = ACTIONS(3925),
    [anon_sym_OR] = ACTIONS(3925),
    [anon_sym_Or] = ACTIONS(3925),
    [anon_sym_xor] = ACTIONS(3925),
    [anon_sym_XOR] = ACTIONS(3925),
    [anon_sym_Xor] = ACTIONS(3925),
    [anon_sym_QMARK] = ACTIONS(3927),
    [sym_datetime_literal] = ACTIONS(3927),
    [sym_date_literal] = ACTIONS(3925),
    [sym_time_literal] = ACTIONS(3925),
    [sym_biginteger_literal] = ACTIONS(3927),
    [anon_sym_if] = ACTIONS(3925),
    [anon_sym_IF] = ACTIONS(3925),
    [anon_sym_If] = ACTIONS(3925),
    [anon_sym_else] = ACTIONS(3925),
    [anon_sym_ELSE] = ACTIONS(3925),
    [anon_sym_Else] = ACTIONS(3925),
    [anon_sym_case] = ACTIONS(3925),
    [anon_sym_CASE] = ACTIONS(3925),
    [anon_sym_Case] = ACTIONS(3925),
    [anon_sym_for] = ACTIONS(3925),
    [anon_sym_FOR] = ACTIONS(3925),
    [anon_sym_For] = ACTIONS(3925),
    [anon_sym_foreach] = ACTIONS(3925),
    [anon_sym_FOREACH] = ACTIONS(3925),
    [anon_sym_Foreach] = ACTIONS(3925),
    [anon_sym_while] = ACTIONS(3925),
    [anon_sym_WHILE] = ACTIONS(3925),
    [anon_sym_While] = ACTIONS(3925),
    [anon_sym_repeat] = ACTIONS(3925),
    [anon_sym_REPEAT] = ACTIONS(3925),
    [anon_sym_Repeat] = ACTIONS(3925),
    [anon_sym_exit] = ACTIONS(3925),
    [anon_sym_EXIT] = ACTIONS(3925),
    [anon_sym_Exit] = ACTIONS(3925),
    [anon_sym_continue] = ACTIONS(3925),
    [anon_sym_CONTINUE] = ACTIONS(3925),
    [anon_sym_Continue] = ACTIONS(3925),
    [anon_sym_break] = ACTIONS(3925),
    [anon_sym_BREAK] = ACTIONS(3925),
    [anon_sym_Break] = ACTIONS(3925),
    [anon_sym_with] = ACTIONS(3925),
    [anon_sym_WITH] = ACTIONS(3925),
    [anon_sym_With] = ACTIONS(3925),
    [sym_asserterror_keyword] = ACTIONS(3927),
    [anon_sym_in] = ACTIONS(3925),
    [anon_sym_IN] = ACTIONS(3925),
    [anon_sym_In] = ACTIONS(3925),
    [sym_page_keyword] = ACTIONS(3925),
    [anon_sym_codeunit] = ACTIONS(3925),
    [anon_sym_CODEUNIT] = ACTIONS(3925),
    [anon_sym_Codeunit] = ACTIONS(3925),
    [anon_sym_CodeUnit] = ACTIONS(3925),
    [anon_sym_COdeunit] = ACTIONS(3925),
    [anon_sym_codeUnit] = ACTIONS(3925),
    [sym_report_keyword] = ACTIONS(3925),
    [sym_query_keyword] = ACTIONS(3925),
    [anon_sym_xmlport] = ACTIONS(3925),
    [anon_sym_XMLPORT] = ACTIONS(3925),
    [anon_sym_Xmlport] = ACTIONS(3925),
    [anon_sym_XMLport] = ACTIONS(3925),
    [anon_sym_XMLPort] = ACTIONS(3925),
    [anon_sym_XmlPort] = ACTIONS(3925),
    [anon_sym_enum] = ACTIONS(3925),
    [anon_sym_ENUM] = ACTIONS(3925),
    [anon_sym_Enum] = ACTIONS(3925),
    [anon_sym_eNUM] = ACTIONS(3925),
    [anon_sym_eNum] = ACTIONS(3925),
    [anon_sym_ENum] = ACTIONS(3925),
    [sym_quoted_identifier] = ACTIONS(3927),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3927),
    [sym_verbatim_string] = ACTIONS(3927),
    [sym_integer] = ACTIONS(3925),
    [sym_continue_as_identifier] = ACTIONS(3927),
    [sym_preproc_open] = ACTIONS(3927),
    [sym_end_keyword] = ACTIONS(3927),
  },
  [STATE(2063)] = {
    [sym_identifier] = ACTIONS(3877),
    [anon_sym_SEMI] = ACTIONS(3879),
    [anon_sym_DOT] = ACTIONS(3877),
    [anon_sym_EQ] = ACTIONS(3879),
    [anon_sym_DASH] = ACTIONS(3877),
    [aux_sym_boolean_token1] = ACTIONS(3877),
    [aux_sym_boolean_token2] = ACTIONS(3877),
    [sym_decimal] = ACTIONS(3877),
    [anon_sym_LPAREN] = ACTIONS(3879),
    [anon_sym_DOT_DOT] = ACTIONS(3879),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3877),
    [anon_sym_STAR] = ACTIONS(3877),
    [anon_sym_LBRACK] = ACTIONS(3879),
    [aux_sym_record_type_token1] = ACTIONS(3877),
    [aux_sym_basic_type_token21] = ACTIONS(3877),
    [aux_sym_basic_type_token22] = ACTIONS(3877),
    [aux_sym_basic_type_token48] = ACTIONS(3877),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3877),
    [anon_sym_POUNDif] = ACTIONS(3879),
    [anon_sym_POUNDIF] = ACTIONS(3879),
    [anon_sym_POUNDIf] = ACTIONS(3879),
    [anon_sym_not] = ACTIONS(3877),
    [anon_sym_NOT] = ACTIONS(3877),
    [anon_sym_Not] = ACTIONS(3877),
    [anon_sym_POUNDelse] = ACTIONS(3879),
    [anon_sym_POUNDELSE] = ACTIONS(3879),
    [anon_sym_POUNDElse] = ACTIONS(3879),
    [anon_sym_POUNDelse2] = ACTIONS(3879),
    [anon_sym_POUNDELSE2] = ACTIONS(3879),
    [anon_sym_POUNDElse2] = ACTIONS(3879),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3879),
    [aux_sym__expression_token1] = ACTIONS(3879),
    [aux_sym__expression_token2] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3877),
    [anon_sym_SLASH] = ACTIONS(3877),
    [anon_sym_div] = ACTIONS(3877),
    [anon_sym_DIV] = ACTIONS(3877),
    [anon_sym_Div] = ACTIONS(3877),
    [anon_sym_mod] = ACTIONS(3877),
    [anon_sym_MOD] = ACTIONS(3877),
    [anon_sym_Mod] = ACTIONS(3877),
    [anon_sym_PLUS] = ACTIONS(3877),
    [anon_sym_GT_EQ] = ACTIONS(3879),
    [anon_sym_LT_EQ] = ACTIONS(3879),
    [anon_sym_GT] = ACTIONS(3877),
    [anon_sym_LT] = ACTIONS(3877),
    [anon_sym_LT_GT] = ACTIONS(3879),
    [anon_sym_and] = ACTIONS(3877),
    [anon_sym_AND] = ACTIONS(3877),
    [anon_sym_And] = ACTIONS(3877),
    [anon_sym_or] = ACTIONS(3877),
    [anon_sym_OR] = ACTIONS(3877),
    [anon_sym_Or] = ACTIONS(3877),
    [anon_sym_xor] = ACTIONS(3877),
    [anon_sym_XOR] = ACTIONS(3877),
    [anon_sym_Xor] = ACTIONS(3877),
    [anon_sym_QMARK] = ACTIONS(3879),
    [sym_datetime_literal] = ACTIONS(3879),
    [sym_date_literal] = ACTIONS(3877),
    [sym_time_literal] = ACTIONS(3877),
    [sym_biginteger_literal] = ACTIONS(3879),
    [anon_sym_if] = ACTIONS(3877),
    [anon_sym_IF] = ACTIONS(3877),
    [anon_sym_If] = ACTIONS(3877),
    [anon_sym_else] = ACTIONS(3877),
    [anon_sym_ELSE] = ACTIONS(3877),
    [anon_sym_Else] = ACTIONS(3877),
    [anon_sym_case] = ACTIONS(3877),
    [anon_sym_CASE] = ACTIONS(3877),
    [anon_sym_Case] = ACTIONS(3877),
    [anon_sym_for] = ACTIONS(3877),
    [anon_sym_FOR] = ACTIONS(3877),
    [anon_sym_For] = ACTIONS(3877),
    [anon_sym_foreach] = ACTIONS(3877),
    [anon_sym_FOREACH] = ACTIONS(3877),
    [anon_sym_Foreach] = ACTIONS(3877),
    [anon_sym_while] = ACTIONS(3877),
    [anon_sym_WHILE] = ACTIONS(3877),
    [anon_sym_While] = ACTIONS(3877),
    [anon_sym_repeat] = ACTIONS(3877),
    [anon_sym_REPEAT] = ACTIONS(3877),
    [anon_sym_Repeat] = ACTIONS(3877),
    [anon_sym_exit] = ACTIONS(3877),
    [anon_sym_EXIT] = ACTIONS(3877),
    [anon_sym_Exit] = ACTIONS(3877),
    [anon_sym_continue] = ACTIONS(3877),
    [anon_sym_CONTINUE] = ACTIONS(3877),
    [anon_sym_Continue] = ACTIONS(3877),
    [anon_sym_break] = ACTIONS(3877),
    [anon_sym_BREAK] = ACTIONS(3877),
    [anon_sym_Break] = ACTIONS(3877),
    [anon_sym_with] = ACTIONS(3877),
    [anon_sym_WITH] = ACTIONS(3877),
    [anon_sym_With] = ACTIONS(3877),
    [sym_asserterror_keyword] = ACTIONS(3879),
    [anon_sym_in] = ACTIONS(3877),
    [anon_sym_IN] = ACTIONS(3877),
    [anon_sym_In] = ACTIONS(3877),
    [sym_page_keyword] = ACTIONS(3877),
    [anon_sym_codeunit] = ACTIONS(3877),
    [anon_sym_CODEUNIT] = ACTIONS(3877),
    [anon_sym_Codeunit] = ACTIONS(3877),
    [anon_sym_CodeUnit] = ACTIONS(3877),
    [anon_sym_COdeunit] = ACTIONS(3877),
    [anon_sym_codeUnit] = ACTIONS(3877),
    [sym_report_keyword] = ACTIONS(3877),
    [sym_query_keyword] = ACTIONS(3877),
    [anon_sym_xmlport] = ACTIONS(3877),
    [anon_sym_XMLPORT] = ACTIONS(3877),
    [anon_sym_Xmlport] = ACTIONS(3877),
    [anon_sym_XMLport] = ACTIONS(3877),
    [anon_sym_XMLPort] = ACTIONS(3877),
    [anon_sym_XmlPort] = ACTIONS(3877),
    [anon_sym_enum] = ACTIONS(3877),
    [anon_sym_ENUM] = ACTIONS(3877),
    [anon_sym_Enum] = ACTIONS(3877),
    [anon_sym_eNUM] = ACTIONS(3877),
    [anon_sym_eNum] = ACTIONS(3877),
    [anon_sym_ENum] = ACTIONS(3877),
    [sym_quoted_identifier] = ACTIONS(3879),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3879),
    [sym_verbatim_string] = ACTIONS(3879),
    [sym_integer] = ACTIONS(3877),
    [sym_continue_as_identifier] = ACTIONS(3879),
    [sym_preproc_open] = ACTIONS(3879),
    [sym_end_keyword] = ACTIONS(3879),
  },
  [STATE(2064)] = {
    [sym_identifier] = ACTIONS(3931),
    [anon_sym_SEMI] = ACTIONS(3933),
    [anon_sym_DOT] = ACTIONS(3931),
    [anon_sym_EQ] = ACTIONS(3933),
    [anon_sym_DASH] = ACTIONS(3931),
    [aux_sym_boolean_token1] = ACTIONS(3931),
    [aux_sym_boolean_token2] = ACTIONS(3931),
    [sym_decimal] = ACTIONS(3931),
    [anon_sym_LPAREN] = ACTIONS(3933),
    [anon_sym_DOT_DOT] = ACTIONS(3933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3931),
    [anon_sym_STAR] = ACTIONS(3931),
    [anon_sym_LBRACK] = ACTIONS(4419),
    [aux_sym_record_type_token1] = ACTIONS(3931),
    [aux_sym_basic_type_token21] = ACTIONS(3931),
    [aux_sym_basic_type_token22] = ACTIONS(3931),
    [aux_sym_basic_type_token48] = ACTIONS(3931),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3931),
    [anon_sym_POUNDif] = ACTIONS(3933),
    [anon_sym_POUNDIF] = ACTIONS(3933),
    [anon_sym_POUNDIf] = ACTIONS(3933),
    [anon_sym_not] = ACTIONS(3931),
    [anon_sym_NOT] = ACTIONS(3931),
    [anon_sym_Not] = ACTIONS(3931),
    [anon_sym_POUNDelse] = ACTIONS(3933),
    [anon_sym_POUNDELSE] = ACTIONS(3933),
    [anon_sym_POUNDElse] = ACTIONS(3933),
    [anon_sym_POUNDelse2] = ACTIONS(3933),
    [anon_sym_POUNDELSE2] = ACTIONS(3933),
    [anon_sym_POUNDElse2] = ACTIONS(3933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3933),
    [aux_sym__expression_token1] = ACTIONS(3933),
    [aux_sym__expression_token2] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3931),
    [anon_sym_SLASH] = ACTIONS(3931),
    [anon_sym_div] = ACTIONS(3931),
    [anon_sym_DIV] = ACTIONS(3931),
    [anon_sym_Div] = ACTIONS(3931),
    [anon_sym_mod] = ACTIONS(3931),
    [anon_sym_MOD] = ACTIONS(3931),
    [anon_sym_Mod] = ACTIONS(3931),
    [anon_sym_PLUS] = ACTIONS(3931),
    [anon_sym_GT_EQ] = ACTIONS(3933),
    [anon_sym_LT_EQ] = ACTIONS(3933),
    [anon_sym_GT] = ACTIONS(3931),
    [anon_sym_LT] = ACTIONS(3931),
    [anon_sym_LT_GT] = ACTIONS(3933),
    [anon_sym_and] = ACTIONS(3931),
    [anon_sym_AND] = ACTIONS(3931),
    [anon_sym_And] = ACTIONS(3931),
    [anon_sym_or] = ACTIONS(3931),
    [anon_sym_OR] = ACTIONS(3931),
    [anon_sym_Or] = ACTIONS(3931),
    [anon_sym_xor] = ACTIONS(3931),
    [anon_sym_XOR] = ACTIONS(3931),
    [anon_sym_Xor] = ACTIONS(3931),
    [anon_sym_QMARK] = ACTIONS(3933),
    [sym_datetime_literal] = ACTIONS(3933),
    [sym_date_literal] = ACTIONS(3931),
    [sym_time_literal] = ACTIONS(3931),
    [sym_biginteger_literal] = ACTIONS(3933),
    [anon_sym_if] = ACTIONS(3931),
    [anon_sym_IF] = ACTIONS(3931),
    [anon_sym_If] = ACTIONS(3931),
    [anon_sym_else] = ACTIONS(3931),
    [anon_sym_ELSE] = ACTIONS(3931),
    [anon_sym_Else] = ACTIONS(3931),
    [anon_sym_case] = ACTIONS(3931),
    [anon_sym_CASE] = ACTIONS(3931),
    [anon_sym_Case] = ACTIONS(3931),
    [anon_sym_for] = ACTIONS(3931),
    [anon_sym_FOR] = ACTIONS(3931),
    [anon_sym_For] = ACTIONS(3931),
    [anon_sym_foreach] = ACTIONS(3931),
    [anon_sym_FOREACH] = ACTIONS(3931),
    [anon_sym_Foreach] = ACTIONS(3931),
    [anon_sym_while] = ACTIONS(3931),
    [anon_sym_WHILE] = ACTIONS(3931),
    [anon_sym_While] = ACTIONS(3931),
    [anon_sym_repeat] = ACTIONS(3931),
    [anon_sym_REPEAT] = ACTIONS(3931),
    [anon_sym_Repeat] = ACTIONS(3931),
    [anon_sym_exit] = ACTIONS(3931),
    [anon_sym_EXIT] = ACTIONS(3931),
    [anon_sym_Exit] = ACTIONS(3931),
    [anon_sym_continue] = ACTIONS(3931),
    [anon_sym_CONTINUE] = ACTIONS(3931),
    [anon_sym_Continue] = ACTIONS(3931),
    [anon_sym_break] = ACTIONS(3931),
    [anon_sym_BREAK] = ACTIONS(3931),
    [anon_sym_Break] = ACTIONS(3931),
    [anon_sym_with] = ACTIONS(3931),
    [anon_sym_WITH] = ACTIONS(3931),
    [anon_sym_With] = ACTIONS(3931),
    [sym_asserterror_keyword] = ACTIONS(3933),
    [anon_sym_in] = ACTIONS(3931),
    [anon_sym_IN] = ACTIONS(3931),
    [anon_sym_In] = ACTIONS(3931),
    [sym_page_keyword] = ACTIONS(3931),
    [anon_sym_codeunit] = ACTIONS(3931),
    [anon_sym_CODEUNIT] = ACTIONS(3931),
    [anon_sym_Codeunit] = ACTIONS(3931),
    [anon_sym_CodeUnit] = ACTIONS(3931),
    [anon_sym_COdeunit] = ACTIONS(3931),
    [anon_sym_codeUnit] = ACTIONS(3931),
    [sym_report_keyword] = ACTIONS(3931),
    [sym_query_keyword] = ACTIONS(3931),
    [anon_sym_xmlport] = ACTIONS(3931),
    [anon_sym_XMLPORT] = ACTIONS(3931),
    [anon_sym_Xmlport] = ACTIONS(3931),
    [anon_sym_XMLport] = ACTIONS(3931),
    [anon_sym_XMLPort] = ACTIONS(3931),
    [anon_sym_XmlPort] = ACTIONS(3931),
    [anon_sym_enum] = ACTIONS(3931),
    [anon_sym_ENUM] = ACTIONS(3931),
    [anon_sym_Enum] = ACTIONS(3931),
    [anon_sym_eNUM] = ACTIONS(3931),
    [anon_sym_eNum] = ACTIONS(3931),
    [anon_sym_ENum] = ACTIONS(3931),
    [sym_quoted_identifier] = ACTIONS(3933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3933),
    [sym_verbatim_string] = ACTIONS(3933),
    [sym_integer] = ACTIONS(3931),
    [sym_continue_as_identifier] = ACTIONS(3933),
    [sym_preproc_open] = ACTIONS(3933),
    [sym_end_keyword] = ACTIONS(3933),
  },
  [STATE(2065)] = {
    [sym_identifier] = ACTIONS(3909),
    [anon_sym_SEMI] = ACTIONS(3911),
    [anon_sym_DOT] = ACTIONS(3909),
    [anon_sym_EQ] = ACTIONS(3911),
    [anon_sym_DASH] = ACTIONS(3909),
    [aux_sym_boolean_token1] = ACTIONS(3909),
    [aux_sym_boolean_token2] = ACTIONS(3909),
    [sym_decimal] = ACTIONS(3909),
    [anon_sym_LPAREN] = ACTIONS(3911),
    [anon_sym_DOT_DOT] = ACTIONS(3911),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3909),
    [anon_sym_STAR] = ACTIONS(3909),
    [anon_sym_LBRACK] = ACTIONS(3911),
    [aux_sym_record_type_token1] = ACTIONS(3909),
    [aux_sym_basic_type_token21] = ACTIONS(3909),
    [aux_sym_basic_type_token22] = ACTIONS(3909),
    [aux_sym_basic_type_token48] = ACTIONS(3909),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3909),
    [anon_sym_POUNDif] = ACTIONS(3911),
    [anon_sym_POUNDIF] = ACTIONS(3911),
    [anon_sym_POUNDIf] = ACTIONS(3911),
    [anon_sym_not] = ACTIONS(3909),
    [anon_sym_NOT] = ACTIONS(3909),
    [anon_sym_Not] = ACTIONS(3909),
    [anon_sym_POUNDelse] = ACTIONS(3911),
    [anon_sym_POUNDELSE] = ACTIONS(3911),
    [anon_sym_POUNDElse] = ACTIONS(3911),
    [anon_sym_POUNDelse2] = ACTIONS(3911),
    [anon_sym_POUNDELSE2] = ACTIONS(3911),
    [anon_sym_POUNDElse2] = ACTIONS(3911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3911),
    [aux_sym__expression_token1] = ACTIONS(3911),
    [aux_sym__expression_token2] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3909),
    [anon_sym_SLASH] = ACTIONS(3909),
    [anon_sym_div] = ACTIONS(3909),
    [anon_sym_DIV] = ACTIONS(3909),
    [anon_sym_Div] = ACTIONS(3909),
    [anon_sym_mod] = ACTIONS(3909),
    [anon_sym_MOD] = ACTIONS(3909),
    [anon_sym_Mod] = ACTIONS(3909),
    [anon_sym_PLUS] = ACTIONS(3909),
    [anon_sym_GT_EQ] = ACTIONS(3911),
    [anon_sym_LT_EQ] = ACTIONS(3911),
    [anon_sym_GT] = ACTIONS(3909),
    [anon_sym_LT] = ACTIONS(3909),
    [anon_sym_LT_GT] = ACTIONS(3911),
    [anon_sym_and] = ACTIONS(3909),
    [anon_sym_AND] = ACTIONS(3909),
    [anon_sym_And] = ACTIONS(3909),
    [anon_sym_or] = ACTIONS(3909),
    [anon_sym_OR] = ACTIONS(3909),
    [anon_sym_Or] = ACTIONS(3909),
    [anon_sym_xor] = ACTIONS(3909),
    [anon_sym_XOR] = ACTIONS(3909),
    [anon_sym_Xor] = ACTIONS(3909),
    [anon_sym_QMARK] = ACTIONS(3911),
    [sym_datetime_literal] = ACTIONS(3911),
    [sym_date_literal] = ACTIONS(3909),
    [sym_time_literal] = ACTIONS(3909),
    [sym_biginteger_literal] = ACTIONS(3911),
    [anon_sym_if] = ACTIONS(3909),
    [anon_sym_IF] = ACTIONS(3909),
    [anon_sym_If] = ACTIONS(3909),
    [anon_sym_else] = ACTIONS(3909),
    [anon_sym_ELSE] = ACTIONS(3909),
    [anon_sym_Else] = ACTIONS(3909),
    [anon_sym_case] = ACTIONS(3909),
    [anon_sym_CASE] = ACTIONS(3909),
    [anon_sym_Case] = ACTIONS(3909),
    [anon_sym_for] = ACTIONS(3909),
    [anon_sym_FOR] = ACTIONS(3909),
    [anon_sym_For] = ACTIONS(3909),
    [anon_sym_foreach] = ACTIONS(3909),
    [anon_sym_FOREACH] = ACTIONS(3909),
    [anon_sym_Foreach] = ACTIONS(3909),
    [anon_sym_while] = ACTIONS(3909),
    [anon_sym_WHILE] = ACTIONS(3909),
    [anon_sym_While] = ACTIONS(3909),
    [anon_sym_repeat] = ACTIONS(3909),
    [anon_sym_REPEAT] = ACTIONS(3909),
    [anon_sym_Repeat] = ACTIONS(3909),
    [anon_sym_exit] = ACTIONS(3909),
    [anon_sym_EXIT] = ACTIONS(3909),
    [anon_sym_Exit] = ACTIONS(3909),
    [anon_sym_continue] = ACTIONS(3909),
    [anon_sym_CONTINUE] = ACTIONS(3909),
    [anon_sym_Continue] = ACTIONS(3909),
    [anon_sym_break] = ACTIONS(3909),
    [anon_sym_BREAK] = ACTIONS(3909),
    [anon_sym_Break] = ACTIONS(3909),
    [anon_sym_with] = ACTIONS(3909),
    [anon_sym_WITH] = ACTIONS(3909),
    [anon_sym_With] = ACTIONS(3909),
    [sym_asserterror_keyword] = ACTIONS(3911),
    [anon_sym_in] = ACTIONS(3909),
    [anon_sym_IN] = ACTIONS(3909),
    [anon_sym_In] = ACTIONS(3909),
    [sym_page_keyword] = ACTIONS(3909),
    [anon_sym_codeunit] = ACTIONS(3909),
    [anon_sym_CODEUNIT] = ACTIONS(3909),
    [anon_sym_Codeunit] = ACTIONS(3909),
    [anon_sym_CodeUnit] = ACTIONS(3909),
    [anon_sym_COdeunit] = ACTIONS(3909),
    [anon_sym_codeUnit] = ACTIONS(3909),
    [sym_report_keyword] = ACTIONS(3909),
    [sym_query_keyword] = ACTIONS(3909),
    [anon_sym_xmlport] = ACTIONS(3909),
    [anon_sym_XMLPORT] = ACTIONS(3909),
    [anon_sym_Xmlport] = ACTIONS(3909),
    [anon_sym_XMLport] = ACTIONS(3909),
    [anon_sym_XMLPort] = ACTIONS(3909),
    [anon_sym_XmlPort] = ACTIONS(3909),
    [anon_sym_enum] = ACTIONS(3909),
    [anon_sym_ENUM] = ACTIONS(3909),
    [anon_sym_Enum] = ACTIONS(3909),
    [anon_sym_eNUM] = ACTIONS(3909),
    [anon_sym_eNum] = ACTIONS(3909),
    [anon_sym_ENum] = ACTIONS(3909),
    [sym_quoted_identifier] = ACTIONS(3911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3911),
    [sym_verbatim_string] = ACTIONS(3911),
    [sym_integer] = ACTIONS(3909),
    [sym_continue_as_identifier] = ACTIONS(3911),
    [sym_preproc_open] = ACTIONS(3911),
    [sym_end_keyword] = ACTIONS(3911),
  },
  [STATE(2066)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10515),
    [sym_else_table_relation_fragment] = STATE(10515),
    [sym_table_relation_expression] = STATE(10515),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8089),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2236),
    [sym_preproc_endif] = STATE(4063),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10855),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8089),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(10917),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4421),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4423),
    [anon_sym_POUNDENDIF] = ACTIONS(4423),
    [anon_sym_POUNDEndif] = ACTIONS(4423),
    [anon_sym_POUNDendif2] = ACTIONS(4423),
    [anon_sym_POUNDENDIF2] = ACTIONS(4423),
    [anon_sym_POUNDEndif2] = ACTIONS(4423),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4423),
  },
  [STATE(2067)] = {
    [sym_identifier] = ACTIONS(3897),
    [anon_sym_SEMI] = ACTIONS(3899),
    [anon_sym_DOT] = ACTIONS(3897),
    [anon_sym_EQ] = ACTIONS(3899),
    [anon_sym_DASH] = ACTIONS(3897),
    [aux_sym_boolean_token1] = ACTIONS(3897),
    [aux_sym_boolean_token2] = ACTIONS(3897),
    [sym_decimal] = ACTIONS(3897),
    [anon_sym_LPAREN] = ACTIONS(3899),
    [anon_sym_DOT_DOT] = ACTIONS(3899),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3897),
    [anon_sym_STAR] = ACTIONS(3897),
    [anon_sym_LBRACK] = ACTIONS(3899),
    [aux_sym_record_type_token1] = ACTIONS(3897),
    [aux_sym_basic_type_token21] = ACTIONS(3897),
    [aux_sym_basic_type_token22] = ACTIONS(3897),
    [aux_sym_basic_type_token48] = ACTIONS(3897),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3897),
    [anon_sym_POUNDif] = ACTIONS(3899),
    [anon_sym_POUNDIF] = ACTIONS(3899),
    [anon_sym_POUNDIf] = ACTIONS(3899),
    [anon_sym_not] = ACTIONS(3897),
    [anon_sym_NOT] = ACTIONS(3897),
    [anon_sym_Not] = ACTIONS(3897),
    [anon_sym_POUNDelse] = ACTIONS(3899),
    [anon_sym_POUNDELSE] = ACTIONS(3899),
    [anon_sym_POUNDElse] = ACTIONS(3899),
    [anon_sym_POUNDelse2] = ACTIONS(3899),
    [anon_sym_POUNDELSE2] = ACTIONS(3899),
    [anon_sym_POUNDElse2] = ACTIONS(3899),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3899),
    [aux_sym__expression_token1] = ACTIONS(3899),
    [aux_sym__expression_token2] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3897),
    [anon_sym_SLASH] = ACTIONS(3897),
    [anon_sym_div] = ACTIONS(3897),
    [anon_sym_DIV] = ACTIONS(3897),
    [anon_sym_Div] = ACTIONS(3897),
    [anon_sym_mod] = ACTIONS(3897),
    [anon_sym_MOD] = ACTIONS(3897),
    [anon_sym_Mod] = ACTIONS(3897),
    [anon_sym_PLUS] = ACTIONS(3897),
    [anon_sym_GT_EQ] = ACTIONS(3899),
    [anon_sym_LT_EQ] = ACTIONS(3899),
    [anon_sym_GT] = ACTIONS(3897),
    [anon_sym_LT] = ACTIONS(3897),
    [anon_sym_LT_GT] = ACTIONS(3899),
    [anon_sym_and] = ACTIONS(3897),
    [anon_sym_AND] = ACTIONS(3897),
    [anon_sym_And] = ACTIONS(3897),
    [anon_sym_or] = ACTIONS(3897),
    [anon_sym_OR] = ACTIONS(3897),
    [anon_sym_Or] = ACTIONS(3897),
    [anon_sym_xor] = ACTIONS(3897),
    [anon_sym_XOR] = ACTIONS(3897),
    [anon_sym_Xor] = ACTIONS(3897),
    [anon_sym_QMARK] = ACTIONS(3899),
    [sym_datetime_literal] = ACTIONS(3899),
    [sym_date_literal] = ACTIONS(3897),
    [sym_time_literal] = ACTIONS(3897),
    [sym_biginteger_literal] = ACTIONS(3899),
    [anon_sym_if] = ACTIONS(3897),
    [anon_sym_IF] = ACTIONS(3897),
    [anon_sym_If] = ACTIONS(3897),
    [anon_sym_else] = ACTIONS(3897),
    [anon_sym_ELSE] = ACTIONS(3897),
    [anon_sym_Else] = ACTIONS(3897),
    [anon_sym_case] = ACTIONS(3897),
    [anon_sym_CASE] = ACTIONS(3897),
    [anon_sym_Case] = ACTIONS(3897),
    [anon_sym_for] = ACTIONS(3897),
    [anon_sym_FOR] = ACTIONS(3897),
    [anon_sym_For] = ACTIONS(3897),
    [anon_sym_foreach] = ACTIONS(3897),
    [anon_sym_FOREACH] = ACTIONS(3897),
    [anon_sym_Foreach] = ACTIONS(3897),
    [anon_sym_while] = ACTIONS(3897),
    [anon_sym_WHILE] = ACTIONS(3897),
    [anon_sym_While] = ACTIONS(3897),
    [anon_sym_repeat] = ACTIONS(3897),
    [anon_sym_REPEAT] = ACTIONS(3897),
    [anon_sym_Repeat] = ACTIONS(3897),
    [anon_sym_exit] = ACTIONS(3897),
    [anon_sym_EXIT] = ACTIONS(3897),
    [anon_sym_Exit] = ACTIONS(3897),
    [anon_sym_continue] = ACTIONS(3897),
    [anon_sym_CONTINUE] = ACTIONS(3897),
    [anon_sym_Continue] = ACTIONS(3897),
    [anon_sym_break] = ACTIONS(3897),
    [anon_sym_BREAK] = ACTIONS(3897),
    [anon_sym_Break] = ACTIONS(3897),
    [anon_sym_with] = ACTIONS(3897),
    [anon_sym_WITH] = ACTIONS(3897),
    [anon_sym_With] = ACTIONS(3897),
    [sym_asserterror_keyword] = ACTIONS(3899),
    [anon_sym_in] = ACTIONS(3897),
    [anon_sym_IN] = ACTIONS(3897),
    [anon_sym_In] = ACTIONS(3897),
    [sym_page_keyword] = ACTIONS(3897),
    [anon_sym_codeunit] = ACTIONS(3897),
    [anon_sym_CODEUNIT] = ACTIONS(3897),
    [anon_sym_Codeunit] = ACTIONS(3897),
    [anon_sym_CodeUnit] = ACTIONS(3897),
    [anon_sym_COdeunit] = ACTIONS(3897),
    [anon_sym_codeUnit] = ACTIONS(3897),
    [sym_report_keyword] = ACTIONS(3897),
    [sym_query_keyword] = ACTIONS(3897),
    [anon_sym_xmlport] = ACTIONS(3897),
    [anon_sym_XMLPORT] = ACTIONS(3897),
    [anon_sym_Xmlport] = ACTIONS(3897),
    [anon_sym_XMLport] = ACTIONS(3897),
    [anon_sym_XMLPort] = ACTIONS(3897),
    [anon_sym_XmlPort] = ACTIONS(3897),
    [anon_sym_enum] = ACTIONS(3897),
    [anon_sym_ENUM] = ACTIONS(3897),
    [anon_sym_Enum] = ACTIONS(3897),
    [anon_sym_eNUM] = ACTIONS(3897),
    [anon_sym_eNum] = ACTIONS(3897),
    [anon_sym_ENum] = ACTIONS(3897),
    [sym_quoted_identifier] = ACTIONS(3899),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3899),
    [sym_verbatim_string] = ACTIONS(3899),
    [sym_integer] = ACTIONS(3897),
    [sym_continue_as_identifier] = ACTIONS(3899),
    [sym_preproc_open] = ACTIONS(3899),
    [sym_end_keyword] = ACTIONS(3899),
  },
  [STATE(2068)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10562),
    [sym_else_table_relation_fragment] = STATE(10562),
    [sym_table_relation_expression] = STATE(10562),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8094),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2239),
    [sym_preproc_endif] = STATE(5701),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10916),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8094),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(10959),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4425),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(2069)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10640),
    [sym_else_table_relation_fragment] = STATE(10640),
    [sym_table_relation_expression] = STATE(10640),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8108),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2246),
    [sym_preproc_endif] = STATE(4068),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(11017),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8108),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(11018),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4429),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(2070)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_end_keyword] = ACTIONS(3867),
  },
  [STATE(2071)] = {
    [sym_identifier] = ACTIONS(3901),
    [anon_sym_SEMI] = ACTIONS(3903),
    [anon_sym_DOT] = ACTIONS(3901),
    [anon_sym_EQ] = ACTIONS(3903),
    [anon_sym_DASH] = ACTIONS(3901),
    [aux_sym_boolean_token1] = ACTIONS(3901),
    [aux_sym_boolean_token2] = ACTIONS(3901),
    [sym_decimal] = ACTIONS(3901),
    [anon_sym_LPAREN] = ACTIONS(3903),
    [anon_sym_DOT_DOT] = ACTIONS(3903),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3901),
    [anon_sym_STAR] = ACTIONS(3901),
    [anon_sym_LBRACK] = ACTIONS(3903),
    [aux_sym_record_type_token1] = ACTIONS(3901),
    [aux_sym_basic_type_token21] = ACTIONS(3901),
    [aux_sym_basic_type_token22] = ACTIONS(3901),
    [aux_sym_basic_type_token48] = ACTIONS(3901),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3901),
    [anon_sym_POUNDif] = ACTIONS(3903),
    [anon_sym_POUNDIF] = ACTIONS(3903),
    [anon_sym_POUNDIf] = ACTIONS(3903),
    [anon_sym_not] = ACTIONS(3901),
    [anon_sym_NOT] = ACTIONS(3901),
    [anon_sym_Not] = ACTIONS(3901),
    [anon_sym_POUNDelse] = ACTIONS(3903),
    [anon_sym_POUNDELSE] = ACTIONS(3903),
    [anon_sym_POUNDElse] = ACTIONS(3903),
    [anon_sym_POUNDelse2] = ACTIONS(3903),
    [anon_sym_POUNDELSE2] = ACTIONS(3903),
    [anon_sym_POUNDElse2] = ACTIONS(3903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3903),
    [aux_sym__expression_token1] = ACTIONS(3903),
    [aux_sym__expression_token2] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3901),
    [anon_sym_SLASH] = ACTIONS(3901),
    [anon_sym_div] = ACTIONS(3901),
    [anon_sym_DIV] = ACTIONS(3901),
    [anon_sym_Div] = ACTIONS(3901),
    [anon_sym_mod] = ACTIONS(3901),
    [anon_sym_MOD] = ACTIONS(3901),
    [anon_sym_Mod] = ACTIONS(3901),
    [anon_sym_PLUS] = ACTIONS(3901),
    [anon_sym_GT_EQ] = ACTIONS(3903),
    [anon_sym_LT_EQ] = ACTIONS(3903),
    [anon_sym_GT] = ACTIONS(3901),
    [anon_sym_LT] = ACTIONS(3901),
    [anon_sym_LT_GT] = ACTIONS(3903),
    [anon_sym_and] = ACTIONS(3901),
    [anon_sym_AND] = ACTIONS(3901),
    [anon_sym_And] = ACTIONS(3901),
    [anon_sym_or] = ACTIONS(3901),
    [anon_sym_OR] = ACTIONS(3901),
    [anon_sym_Or] = ACTIONS(3901),
    [anon_sym_xor] = ACTIONS(3901),
    [anon_sym_XOR] = ACTIONS(3901),
    [anon_sym_Xor] = ACTIONS(3901),
    [anon_sym_QMARK] = ACTIONS(3903),
    [sym_datetime_literal] = ACTIONS(3903),
    [sym_date_literal] = ACTIONS(3901),
    [sym_time_literal] = ACTIONS(3901),
    [sym_biginteger_literal] = ACTIONS(3903),
    [anon_sym_if] = ACTIONS(3901),
    [anon_sym_IF] = ACTIONS(3901),
    [anon_sym_If] = ACTIONS(3901),
    [anon_sym_else] = ACTIONS(3901),
    [anon_sym_ELSE] = ACTIONS(3901),
    [anon_sym_Else] = ACTIONS(3901),
    [anon_sym_case] = ACTIONS(3901),
    [anon_sym_CASE] = ACTIONS(3901),
    [anon_sym_Case] = ACTIONS(3901),
    [anon_sym_for] = ACTIONS(3901),
    [anon_sym_FOR] = ACTIONS(3901),
    [anon_sym_For] = ACTIONS(3901),
    [anon_sym_foreach] = ACTIONS(3901),
    [anon_sym_FOREACH] = ACTIONS(3901),
    [anon_sym_Foreach] = ACTIONS(3901),
    [anon_sym_while] = ACTIONS(3901),
    [anon_sym_WHILE] = ACTIONS(3901),
    [anon_sym_While] = ACTIONS(3901),
    [anon_sym_repeat] = ACTIONS(3901),
    [anon_sym_REPEAT] = ACTIONS(3901),
    [anon_sym_Repeat] = ACTIONS(3901),
    [anon_sym_exit] = ACTIONS(3901),
    [anon_sym_EXIT] = ACTIONS(3901),
    [anon_sym_Exit] = ACTIONS(3901),
    [anon_sym_continue] = ACTIONS(3901),
    [anon_sym_CONTINUE] = ACTIONS(3901),
    [anon_sym_Continue] = ACTIONS(3901),
    [anon_sym_break] = ACTIONS(3901),
    [anon_sym_BREAK] = ACTIONS(3901),
    [anon_sym_Break] = ACTIONS(3901),
    [anon_sym_with] = ACTIONS(3901),
    [anon_sym_WITH] = ACTIONS(3901),
    [anon_sym_With] = ACTIONS(3901),
    [sym_asserterror_keyword] = ACTIONS(3903),
    [anon_sym_in] = ACTIONS(3901),
    [anon_sym_IN] = ACTIONS(3901),
    [anon_sym_In] = ACTIONS(3901),
    [sym_page_keyword] = ACTIONS(3901),
    [anon_sym_codeunit] = ACTIONS(3901),
    [anon_sym_CODEUNIT] = ACTIONS(3901),
    [anon_sym_Codeunit] = ACTIONS(3901),
    [anon_sym_CodeUnit] = ACTIONS(3901),
    [anon_sym_COdeunit] = ACTIONS(3901),
    [anon_sym_codeUnit] = ACTIONS(3901),
    [sym_report_keyword] = ACTIONS(3901),
    [sym_query_keyword] = ACTIONS(3901),
    [anon_sym_xmlport] = ACTIONS(3901),
    [anon_sym_XMLPORT] = ACTIONS(3901),
    [anon_sym_Xmlport] = ACTIONS(3901),
    [anon_sym_XMLport] = ACTIONS(3901),
    [anon_sym_XMLPort] = ACTIONS(3901),
    [anon_sym_XmlPort] = ACTIONS(3901),
    [anon_sym_enum] = ACTIONS(3901),
    [anon_sym_ENUM] = ACTIONS(3901),
    [anon_sym_Enum] = ACTIONS(3901),
    [anon_sym_eNUM] = ACTIONS(3901),
    [anon_sym_eNum] = ACTIONS(3901),
    [anon_sym_ENum] = ACTIONS(3901),
    [sym_quoted_identifier] = ACTIONS(3903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3903),
    [sym_verbatim_string] = ACTIONS(3903),
    [sym_integer] = ACTIONS(3901),
    [sym_continue_as_identifier] = ACTIONS(3903),
    [sym_preproc_open] = ACTIONS(3903),
    [sym_end_keyword] = ACTIONS(3903),
  },
  [STATE(2072)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10418),
    [sym_else_table_relation_fragment] = STATE(10418),
    [sym_table_relation_expression] = STATE(10418),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8071),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2245),
    [sym_preproc_endif] = STATE(9718),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10729),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8071),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(10731),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4435),
    [anon_sym_POUNDENDIF] = ACTIONS(4435),
    [anon_sym_POUNDEndif] = ACTIONS(4435),
    [anon_sym_POUNDendif2] = ACTIONS(4435),
    [anon_sym_POUNDENDIF2] = ACTIONS(4435),
    [anon_sym_POUNDEndif2] = ACTIONS(4435),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4435),
  },
  [STATE(2073)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_if] = ACTIONS(3873),
    [anon_sym_IF] = ACTIONS(3873),
    [anon_sym_If] = ACTIONS(3873),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_case] = ACTIONS(3873),
    [anon_sym_CASE] = ACTIONS(3873),
    [anon_sym_Case] = ACTIONS(3873),
    [anon_sym_for] = ACTIONS(3873),
    [anon_sym_FOR] = ACTIONS(3873),
    [anon_sym_For] = ACTIONS(3873),
    [anon_sym_foreach] = ACTIONS(3873),
    [anon_sym_FOREACH] = ACTIONS(3873),
    [anon_sym_Foreach] = ACTIONS(3873),
    [anon_sym_while] = ACTIONS(3873),
    [anon_sym_WHILE] = ACTIONS(3873),
    [anon_sym_While] = ACTIONS(3873),
    [anon_sym_repeat] = ACTIONS(3873),
    [anon_sym_REPEAT] = ACTIONS(3873),
    [anon_sym_Repeat] = ACTIONS(3873),
    [anon_sym_exit] = ACTIONS(3873),
    [anon_sym_EXIT] = ACTIONS(3873),
    [anon_sym_Exit] = ACTIONS(3873),
    [anon_sym_continue] = ACTIONS(3873),
    [anon_sym_CONTINUE] = ACTIONS(3873),
    [anon_sym_Continue] = ACTIONS(3873),
    [anon_sym_break] = ACTIONS(3873),
    [anon_sym_BREAK] = ACTIONS(3873),
    [anon_sym_Break] = ACTIONS(3873),
    [anon_sym_with] = ACTIONS(3873),
    [anon_sym_WITH] = ACTIONS(3873),
    [anon_sym_With] = ACTIONS(3873),
    [sym_asserterror_keyword] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_end_keyword] = ACTIONS(3875),
  },
  [STATE(2074)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_if] = ACTIONS(3865),
    [anon_sym_IF] = ACTIONS(3865),
    [anon_sym_If] = ACTIONS(3865),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_case] = ACTIONS(3865),
    [anon_sym_CASE] = ACTIONS(3865),
    [anon_sym_Case] = ACTIONS(3865),
    [anon_sym_for] = ACTIONS(3865),
    [anon_sym_FOR] = ACTIONS(3865),
    [anon_sym_For] = ACTIONS(3865),
    [anon_sym_foreach] = ACTIONS(3865),
    [anon_sym_FOREACH] = ACTIONS(3865),
    [anon_sym_Foreach] = ACTIONS(3865),
    [anon_sym_while] = ACTIONS(3865),
    [anon_sym_WHILE] = ACTIONS(3865),
    [anon_sym_While] = ACTIONS(3865),
    [anon_sym_repeat] = ACTIONS(3865),
    [anon_sym_REPEAT] = ACTIONS(3865),
    [anon_sym_Repeat] = ACTIONS(3865),
    [anon_sym_exit] = ACTIONS(3865),
    [anon_sym_EXIT] = ACTIONS(3865),
    [anon_sym_Exit] = ACTIONS(3865),
    [anon_sym_continue] = ACTIONS(3865),
    [anon_sym_CONTINUE] = ACTIONS(3865),
    [anon_sym_Continue] = ACTIONS(3865),
    [anon_sym_break] = ACTIONS(3865),
    [anon_sym_BREAK] = ACTIONS(3865),
    [anon_sym_Break] = ACTIONS(3865),
    [anon_sym_with] = ACTIONS(3865),
    [anon_sym_WITH] = ACTIONS(3865),
    [anon_sym_With] = ACTIONS(3865),
    [sym_asserterror_keyword] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_end_keyword] = ACTIONS(3867),
  },
  [STATE(2075)] = {
    [sym__body_element] = STATE(3838),
    [sym_empty_statement] = STATE(3838),
    [sym_property] = STATE(3838),
    [sym_permissions_property] = STATE(3838),
    [sym_table_relation_property] = STATE(3838),
    [sym_fields_section] = STATE(3838),
    [sym_keys_section] = STATE(3838),
    [sym_fieldgroups_section] = STATE(3838),
    [sym_enum_value_declaration] = STATE(3838),
    [sym_labels_section] = STATE(3838),
    [sym_layout_section] = STATE(3838),
    [sym__layout_element] = STATE(4889),
    [sym_area_section] = STATE(4889),
    [sym_group_section] = STATE(4889),
    [sym_repeater_section] = STATE(4889),
    [sym_cuegroup_section] = STATE(4889),
    [sym_fixed_section] = STATE(4889),
    [sym_grid_section] = STATE(4889),
    [sym_page_field] = STATE(4889),
    [sym_part_section] = STATE(4889),
    [sym_systempart_section] = STATE(4889),
    [sym_usercontrol_section] = STATE(4889),
    [sym_preproc_split_field] = STATE(4889),
    [sym__field_header] = STATE(10830),
    [sym_label_section] = STATE(4889),
    [sym_addfirst_modification] = STATE(4889),
    [sym_addlast_modification] = STATE(4889),
    [sym_addafter_modification] = STATE(4889),
    [sym_addbefore_modification] = STATE(4889),
    [sym_modify_modification] = STATE(5402),
    [sym_movefirst_modification] = STATE(4889),
    [sym_movelast_modification] = STATE(4889),
    [sym_moveafter_modification] = STATE(4889),
    [sym_movebefore_modification] = STATE(4889),
    [sym_actions_section] = STATE(3838),
    [sym_views_section] = STATE(3838),
    [sym_dataset_section] = STATE(3838),
    [sym_requestpage_section] = STATE(3838),
    [sym_rendering_section] = STATE(3838),
    [sym_elements_section] = STATE(3838),
    [sym_schema_section] = STATE(3838),
    [sym_assembly_declaration] = STATE(3838),
    [sym_event_declaration] = STATE(3838),
    [sym_procedure] = STATE(3838),
    [sym_preproc_split_procedure] = STATE(3838),
    [sym__procedure_preamble] = STATE(11033),
    [sym_preproc_split_procedure_preamble] = STATE(3838),
    [sym__procedure_header] = STATE(9969),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(3838),
    [sym_var_section] = STATE(3838),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(3838),
    [sym_preproc_if] = STATE(2080),
    [sym_preproc_elif] = STATE(2099),
    [sym_preproc_else] = STATE(2251),
    [sym_preproc_endif] = STATE(5389),
    [sym_preproc_conditional_layout] = STATE(4889),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3838),
    [aux_sym_layout_section_repeat1] = STATE(4889),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10847),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10832),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4437),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2076)] = {
    [sym_identifier] = ACTIONS(3917),
    [anon_sym_SEMI] = ACTIONS(3919),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_EQ] = ACTIONS(3919),
    [anon_sym_DASH] = ACTIONS(3917),
    [aux_sym_boolean_token1] = ACTIONS(3917),
    [aux_sym_boolean_token2] = ACTIONS(3917),
    [sym_decimal] = ACTIONS(3917),
    [anon_sym_LPAREN] = ACTIONS(3919),
    [anon_sym_DOT_DOT] = ACTIONS(3919),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3919),
    [aux_sym_record_type_token1] = ACTIONS(3917),
    [aux_sym_basic_type_token21] = ACTIONS(3917),
    [aux_sym_basic_type_token22] = ACTIONS(3917),
    [aux_sym_basic_type_token48] = ACTIONS(3917),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3917),
    [anon_sym_POUNDif] = ACTIONS(3919),
    [anon_sym_POUNDIF] = ACTIONS(3919),
    [anon_sym_POUNDIf] = ACTIONS(3919),
    [anon_sym_not] = ACTIONS(3917),
    [anon_sym_NOT] = ACTIONS(3917),
    [anon_sym_Not] = ACTIONS(3917),
    [anon_sym_POUNDelse] = ACTIONS(3919),
    [anon_sym_POUNDELSE] = ACTIONS(3919),
    [anon_sym_POUNDElse] = ACTIONS(3919),
    [anon_sym_POUNDelse2] = ACTIONS(3919),
    [anon_sym_POUNDELSE2] = ACTIONS(3919),
    [anon_sym_POUNDElse2] = ACTIONS(3919),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3919),
    [aux_sym__expression_token1] = ACTIONS(3919),
    [aux_sym__expression_token2] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_div] = ACTIONS(3917),
    [anon_sym_DIV] = ACTIONS(3917),
    [anon_sym_Div] = ACTIONS(3917),
    [anon_sym_mod] = ACTIONS(3917),
    [anon_sym_MOD] = ACTIONS(3917),
    [anon_sym_Mod] = ACTIONS(3917),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3919),
    [anon_sym_LT_EQ] = ACTIONS(3919),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_LT_GT] = ACTIONS(3919),
    [anon_sym_and] = ACTIONS(3917),
    [anon_sym_AND] = ACTIONS(3917),
    [anon_sym_And] = ACTIONS(3917),
    [anon_sym_or] = ACTIONS(3917),
    [anon_sym_OR] = ACTIONS(3917),
    [anon_sym_Or] = ACTIONS(3917),
    [anon_sym_xor] = ACTIONS(3917),
    [anon_sym_XOR] = ACTIONS(3917),
    [anon_sym_Xor] = ACTIONS(3917),
    [anon_sym_QMARK] = ACTIONS(3919),
    [sym_datetime_literal] = ACTIONS(3919),
    [sym_date_literal] = ACTIONS(3917),
    [sym_time_literal] = ACTIONS(3917),
    [sym_biginteger_literal] = ACTIONS(3919),
    [anon_sym_if] = ACTIONS(3917),
    [anon_sym_IF] = ACTIONS(3917),
    [anon_sym_If] = ACTIONS(3917),
    [anon_sym_else] = ACTIONS(3917),
    [anon_sym_ELSE] = ACTIONS(3917),
    [anon_sym_Else] = ACTIONS(3917),
    [anon_sym_case] = ACTIONS(3917),
    [anon_sym_CASE] = ACTIONS(3917),
    [anon_sym_Case] = ACTIONS(3917),
    [anon_sym_for] = ACTIONS(3917),
    [anon_sym_FOR] = ACTIONS(3917),
    [anon_sym_For] = ACTIONS(3917),
    [anon_sym_foreach] = ACTIONS(3917),
    [anon_sym_FOREACH] = ACTIONS(3917),
    [anon_sym_Foreach] = ACTIONS(3917),
    [anon_sym_while] = ACTIONS(3917),
    [anon_sym_WHILE] = ACTIONS(3917),
    [anon_sym_While] = ACTIONS(3917),
    [anon_sym_repeat] = ACTIONS(3917),
    [anon_sym_REPEAT] = ACTIONS(3917),
    [anon_sym_Repeat] = ACTIONS(3917),
    [anon_sym_exit] = ACTIONS(3917),
    [anon_sym_EXIT] = ACTIONS(3917),
    [anon_sym_Exit] = ACTIONS(3917),
    [anon_sym_continue] = ACTIONS(3917),
    [anon_sym_CONTINUE] = ACTIONS(3917),
    [anon_sym_Continue] = ACTIONS(3917),
    [anon_sym_break] = ACTIONS(3917),
    [anon_sym_BREAK] = ACTIONS(3917),
    [anon_sym_Break] = ACTIONS(3917),
    [anon_sym_with] = ACTIONS(3917),
    [anon_sym_WITH] = ACTIONS(3917),
    [anon_sym_With] = ACTIONS(3917),
    [sym_asserterror_keyword] = ACTIONS(3919),
    [anon_sym_in] = ACTIONS(3917),
    [anon_sym_IN] = ACTIONS(3917),
    [anon_sym_In] = ACTIONS(3917),
    [sym_page_keyword] = ACTIONS(3917),
    [anon_sym_codeunit] = ACTIONS(3917),
    [anon_sym_CODEUNIT] = ACTIONS(3917),
    [anon_sym_Codeunit] = ACTIONS(3917),
    [anon_sym_CodeUnit] = ACTIONS(3917),
    [anon_sym_COdeunit] = ACTIONS(3917),
    [anon_sym_codeUnit] = ACTIONS(3917),
    [sym_report_keyword] = ACTIONS(3917),
    [sym_query_keyword] = ACTIONS(3917),
    [anon_sym_xmlport] = ACTIONS(3917),
    [anon_sym_XMLPORT] = ACTIONS(3917),
    [anon_sym_Xmlport] = ACTIONS(3917),
    [anon_sym_XMLport] = ACTIONS(3917),
    [anon_sym_XMLPort] = ACTIONS(3917),
    [anon_sym_XmlPort] = ACTIONS(3917),
    [anon_sym_enum] = ACTIONS(3917),
    [anon_sym_ENUM] = ACTIONS(3917),
    [anon_sym_Enum] = ACTIONS(3917),
    [anon_sym_eNUM] = ACTIONS(3917),
    [anon_sym_eNum] = ACTIONS(3917),
    [anon_sym_ENum] = ACTIONS(3917),
    [sym_quoted_identifier] = ACTIONS(3919),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3919),
    [sym_verbatim_string] = ACTIONS(3919),
    [sym_integer] = ACTIONS(3917),
    [sym_continue_as_identifier] = ACTIONS(3919),
    [sym_preproc_open] = ACTIONS(3919),
    [sym_end_keyword] = ACTIONS(3919),
  },
  [STATE(2077)] = {
    [sym_identifier] = ACTIONS(3941),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_DOT] = ACTIONS(3941),
    [anon_sym_EQ] = ACTIONS(3943),
    [anon_sym_DASH] = ACTIONS(3941),
    [aux_sym_boolean_token1] = ACTIONS(3941),
    [aux_sym_boolean_token2] = ACTIONS(3941),
    [sym_decimal] = ACTIONS(3941),
    [anon_sym_LPAREN] = ACTIONS(3943),
    [anon_sym_DOT_DOT] = ACTIONS(3943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3941),
    [anon_sym_STAR] = ACTIONS(3941),
    [anon_sym_LBRACK] = ACTIONS(3943),
    [aux_sym_record_type_token1] = ACTIONS(3941),
    [aux_sym_basic_type_token21] = ACTIONS(3941),
    [aux_sym_basic_type_token22] = ACTIONS(3941),
    [aux_sym_basic_type_token48] = ACTIONS(3941),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3941),
    [anon_sym_POUNDif] = ACTIONS(3943),
    [anon_sym_POUNDIF] = ACTIONS(3943),
    [anon_sym_POUNDIf] = ACTIONS(3943),
    [anon_sym_not] = ACTIONS(3941),
    [anon_sym_NOT] = ACTIONS(3941),
    [anon_sym_Not] = ACTIONS(3941),
    [anon_sym_POUNDelse] = ACTIONS(3943),
    [anon_sym_POUNDELSE] = ACTIONS(3943),
    [anon_sym_POUNDElse] = ACTIONS(3943),
    [anon_sym_POUNDelse2] = ACTIONS(3943),
    [anon_sym_POUNDELSE2] = ACTIONS(3943),
    [anon_sym_POUNDElse2] = ACTIONS(3943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3943),
    [aux_sym__expression_token1] = ACTIONS(3943),
    [aux_sym__expression_token2] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3941),
    [anon_sym_SLASH] = ACTIONS(3941),
    [anon_sym_div] = ACTIONS(3941),
    [anon_sym_DIV] = ACTIONS(3941),
    [anon_sym_Div] = ACTIONS(3941),
    [anon_sym_mod] = ACTIONS(3941),
    [anon_sym_MOD] = ACTIONS(3941),
    [anon_sym_Mod] = ACTIONS(3941),
    [anon_sym_PLUS] = ACTIONS(3941),
    [anon_sym_GT_EQ] = ACTIONS(3943),
    [anon_sym_LT_EQ] = ACTIONS(3943),
    [anon_sym_GT] = ACTIONS(3941),
    [anon_sym_LT] = ACTIONS(3941),
    [anon_sym_LT_GT] = ACTIONS(3943),
    [anon_sym_and] = ACTIONS(3941),
    [anon_sym_AND] = ACTIONS(3941),
    [anon_sym_And] = ACTIONS(3941),
    [anon_sym_or] = ACTIONS(3941),
    [anon_sym_OR] = ACTIONS(3941),
    [anon_sym_Or] = ACTIONS(3941),
    [anon_sym_xor] = ACTIONS(3941),
    [anon_sym_XOR] = ACTIONS(3941),
    [anon_sym_Xor] = ACTIONS(3941),
    [anon_sym_QMARK] = ACTIONS(3943),
    [sym_datetime_literal] = ACTIONS(3943),
    [sym_date_literal] = ACTIONS(3941),
    [sym_time_literal] = ACTIONS(3941),
    [sym_biginteger_literal] = ACTIONS(3943),
    [anon_sym_if] = ACTIONS(3941),
    [anon_sym_IF] = ACTIONS(3941),
    [anon_sym_If] = ACTIONS(3941),
    [anon_sym_else] = ACTIONS(3941),
    [anon_sym_ELSE] = ACTIONS(3941),
    [anon_sym_Else] = ACTIONS(3941),
    [anon_sym_case] = ACTIONS(3941),
    [anon_sym_CASE] = ACTIONS(3941),
    [anon_sym_Case] = ACTIONS(3941),
    [anon_sym_for] = ACTIONS(3941),
    [anon_sym_FOR] = ACTIONS(3941),
    [anon_sym_For] = ACTIONS(3941),
    [anon_sym_foreach] = ACTIONS(3941),
    [anon_sym_FOREACH] = ACTIONS(3941),
    [anon_sym_Foreach] = ACTIONS(3941),
    [anon_sym_while] = ACTIONS(3941),
    [anon_sym_WHILE] = ACTIONS(3941),
    [anon_sym_While] = ACTIONS(3941),
    [anon_sym_repeat] = ACTIONS(3941),
    [anon_sym_REPEAT] = ACTIONS(3941),
    [anon_sym_Repeat] = ACTIONS(3941),
    [anon_sym_exit] = ACTIONS(3941),
    [anon_sym_EXIT] = ACTIONS(3941),
    [anon_sym_Exit] = ACTIONS(3941),
    [anon_sym_continue] = ACTIONS(3941),
    [anon_sym_CONTINUE] = ACTIONS(3941),
    [anon_sym_Continue] = ACTIONS(3941),
    [anon_sym_break] = ACTIONS(3941),
    [anon_sym_BREAK] = ACTIONS(3941),
    [anon_sym_Break] = ACTIONS(3941),
    [anon_sym_with] = ACTIONS(3941),
    [anon_sym_WITH] = ACTIONS(3941),
    [anon_sym_With] = ACTIONS(3941),
    [sym_asserterror_keyword] = ACTIONS(3943),
    [anon_sym_in] = ACTIONS(3941),
    [anon_sym_IN] = ACTIONS(3941),
    [anon_sym_In] = ACTIONS(3941),
    [sym_page_keyword] = ACTIONS(3941),
    [anon_sym_codeunit] = ACTIONS(3941),
    [anon_sym_CODEUNIT] = ACTIONS(3941),
    [anon_sym_Codeunit] = ACTIONS(3941),
    [anon_sym_CodeUnit] = ACTIONS(3941),
    [anon_sym_COdeunit] = ACTIONS(3941),
    [anon_sym_codeUnit] = ACTIONS(3941),
    [sym_report_keyword] = ACTIONS(3941),
    [sym_query_keyword] = ACTIONS(3941),
    [anon_sym_xmlport] = ACTIONS(3941),
    [anon_sym_XMLPORT] = ACTIONS(3941),
    [anon_sym_Xmlport] = ACTIONS(3941),
    [anon_sym_XMLport] = ACTIONS(3941),
    [anon_sym_XMLPort] = ACTIONS(3941),
    [anon_sym_XmlPort] = ACTIONS(3941),
    [anon_sym_enum] = ACTIONS(3941),
    [anon_sym_ENUM] = ACTIONS(3941),
    [anon_sym_Enum] = ACTIONS(3941),
    [anon_sym_eNUM] = ACTIONS(3941),
    [anon_sym_eNum] = ACTIONS(3941),
    [anon_sym_ENum] = ACTIONS(3941),
    [sym_quoted_identifier] = ACTIONS(3943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3943),
    [sym_verbatim_string] = ACTIONS(3943),
    [sym_integer] = ACTIONS(3941),
    [sym_continue_as_identifier] = ACTIONS(3943),
    [sym_preproc_open] = ACTIONS(3943),
    [sym_end_keyword] = ACTIONS(3943),
  },
  [STATE(2078)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_end_keyword] = ACTIONS(3871),
  },
  [STATE(2079)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_end_keyword] = ACTIONS(3871),
  },
  [STATE(2080)] = {
    [sym__body_element] = STATE(3834),
    [sym_empty_statement] = STATE(3834),
    [sym_property] = STATE(3834),
    [sym_permissions_property] = STATE(3834),
    [sym_table_relation_property] = STATE(3834),
    [sym_fields_section] = STATE(3834),
    [sym_keys_section] = STATE(3834),
    [sym_fieldgroups_section] = STATE(3834),
    [sym_enum_value_declaration] = STATE(3834),
    [sym_labels_section] = STATE(3834),
    [sym_layout_section] = STATE(3834),
    [sym__layout_element] = STATE(4895),
    [sym_area_section] = STATE(4895),
    [sym_group_section] = STATE(4895),
    [sym_repeater_section] = STATE(4895),
    [sym_cuegroup_section] = STATE(4895),
    [sym_fixed_section] = STATE(4895),
    [sym_grid_section] = STATE(4895),
    [sym_page_field] = STATE(4895),
    [sym_part_section] = STATE(4895),
    [sym_systempart_section] = STATE(4895),
    [sym_usercontrol_section] = STATE(4895),
    [sym_preproc_split_field] = STATE(4895),
    [sym__field_header] = STATE(10798),
    [sym_label_section] = STATE(4895),
    [sym_addfirst_modification] = STATE(4895),
    [sym_addlast_modification] = STATE(4895),
    [sym_addafter_modification] = STATE(4895),
    [sym_addbefore_modification] = STATE(4895),
    [sym_modify_modification] = STATE(5402),
    [sym_movefirst_modification] = STATE(4895),
    [sym_movelast_modification] = STATE(4895),
    [sym_moveafter_modification] = STATE(4895),
    [sym_movebefore_modification] = STATE(4895),
    [sym_actions_section] = STATE(3834),
    [sym_views_section] = STATE(3834),
    [sym_dataset_section] = STATE(3834),
    [sym_requestpage_section] = STATE(3834),
    [sym_rendering_section] = STATE(3834),
    [sym_elements_section] = STATE(3834),
    [sym_schema_section] = STATE(3834),
    [sym_assembly_declaration] = STATE(3834),
    [sym_event_declaration] = STATE(3834),
    [sym_procedure] = STATE(3834),
    [sym_preproc_split_procedure] = STATE(3834),
    [sym__procedure_preamble] = STATE(10930),
    [sym_preproc_split_procedure_preamble] = STATE(3834),
    [sym__procedure_header] = STATE(9970),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(3834),
    [sym_var_section] = STATE(3834),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(3834),
    [sym_preproc_if] = STATE(2080),
    [sym_preproc_elif] = STATE(2099),
    [sym_preproc_else] = STATE(2253),
    [sym_preproc_endif] = STATE(5377),
    [sym_preproc_conditional_layout] = STATE(4895),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3834),
    [aux_sym_layout_section_repeat1] = STATE(4895),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10978),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10803),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4437),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2081)] = {
    [sym_identifier] = ACTIONS(3937),
    [anon_sym_SEMI] = ACTIONS(3939),
    [anon_sym_DOT] = ACTIONS(3937),
    [anon_sym_EQ] = ACTIONS(3939),
    [anon_sym_DASH] = ACTIONS(3937),
    [aux_sym_boolean_token1] = ACTIONS(3937),
    [aux_sym_boolean_token2] = ACTIONS(3937),
    [sym_decimal] = ACTIONS(3937),
    [anon_sym_LPAREN] = ACTIONS(3939),
    [anon_sym_DOT_DOT] = ACTIONS(3939),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3937),
    [anon_sym_STAR] = ACTIONS(3937),
    [anon_sym_LBRACK] = ACTIONS(3939),
    [aux_sym_record_type_token1] = ACTIONS(3937),
    [aux_sym_basic_type_token21] = ACTIONS(3937),
    [aux_sym_basic_type_token22] = ACTIONS(3937),
    [aux_sym_basic_type_token48] = ACTIONS(3937),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3937),
    [anon_sym_POUNDif] = ACTIONS(3939),
    [anon_sym_POUNDIF] = ACTIONS(3939),
    [anon_sym_POUNDIf] = ACTIONS(3939),
    [anon_sym_not] = ACTIONS(3937),
    [anon_sym_NOT] = ACTIONS(3937),
    [anon_sym_Not] = ACTIONS(3937),
    [anon_sym_POUNDelse] = ACTIONS(3939),
    [anon_sym_POUNDELSE] = ACTIONS(3939),
    [anon_sym_POUNDElse] = ACTIONS(3939),
    [anon_sym_POUNDelse2] = ACTIONS(3939),
    [anon_sym_POUNDELSE2] = ACTIONS(3939),
    [anon_sym_POUNDElse2] = ACTIONS(3939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3939),
    [aux_sym__expression_token1] = ACTIONS(3939),
    [aux_sym__expression_token2] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3937),
    [anon_sym_SLASH] = ACTIONS(3937),
    [anon_sym_div] = ACTIONS(3937),
    [anon_sym_DIV] = ACTIONS(3937),
    [anon_sym_Div] = ACTIONS(3937),
    [anon_sym_mod] = ACTIONS(3937),
    [anon_sym_MOD] = ACTIONS(3937),
    [anon_sym_Mod] = ACTIONS(3937),
    [anon_sym_PLUS] = ACTIONS(3937),
    [anon_sym_GT_EQ] = ACTIONS(3939),
    [anon_sym_LT_EQ] = ACTIONS(3939),
    [anon_sym_GT] = ACTIONS(3937),
    [anon_sym_LT] = ACTIONS(3937),
    [anon_sym_LT_GT] = ACTIONS(3939),
    [anon_sym_and] = ACTIONS(3937),
    [anon_sym_AND] = ACTIONS(3937),
    [anon_sym_And] = ACTIONS(3937),
    [anon_sym_or] = ACTIONS(3937),
    [anon_sym_OR] = ACTIONS(3937),
    [anon_sym_Or] = ACTIONS(3937),
    [anon_sym_xor] = ACTIONS(3937),
    [anon_sym_XOR] = ACTIONS(3937),
    [anon_sym_Xor] = ACTIONS(3937),
    [anon_sym_QMARK] = ACTIONS(3939),
    [sym_datetime_literal] = ACTIONS(3939),
    [sym_date_literal] = ACTIONS(3937),
    [sym_time_literal] = ACTIONS(3937),
    [sym_biginteger_literal] = ACTIONS(3939),
    [anon_sym_if] = ACTIONS(3937),
    [anon_sym_IF] = ACTIONS(3937),
    [anon_sym_If] = ACTIONS(3937),
    [anon_sym_else] = ACTIONS(3937),
    [anon_sym_ELSE] = ACTIONS(3937),
    [anon_sym_Else] = ACTIONS(3937),
    [anon_sym_case] = ACTIONS(3937),
    [anon_sym_CASE] = ACTIONS(3937),
    [anon_sym_Case] = ACTIONS(3937),
    [anon_sym_for] = ACTIONS(3937),
    [anon_sym_FOR] = ACTIONS(3937),
    [anon_sym_For] = ACTIONS(3937),
    [anon_sym_foreach] = ACTIONS(3937),
    [anon_sym_FOREACH] = ACTIONS(3937),
    [anon_sym_Foreach] = ACTIONS(3937),
    [anon_sym_while] = ACTIONS(3937),
    [anon_sym_WHILE] = ACTIONS(3937),
    [anon_sym_While] = ACTIONS(3937),
    [anon_sym_repeat] = ACTIONS(3937),
    [anon_sym_REPEAT] = ACTIONS(3937),
    [anon_sym_Repeat] = ACTIONS(3937),
    [anon_sym_exit] = ACTIONS(3937),
    [anon_sym_EXIT] = ACTIONS(3937),
    [anon_sym_Exit] = ACTIONS(3937),
    [anon_sym_continue] = ACTIONS(3937),
    [anon_sym_CONTINUE] = ACTIONS(3937),
    [anon_sym_Continue] = ACTIONS(3937),
    [anon_sym_break] = ACTIONS(3937),
    [anon_sym_BREAK] = ACTIONS(3937),
    [anon_sym_Break] = ACTIONS(3937),
    [anon_sym_with] = ACTIONS(3937),
    [anon_sym_WITH] = ACTIONS(3937),
    [anon_sym_With] = ACTIONS(3937),
    [sym_asserterror_keyword] = ACTIONS(3939),
    [anon_sym_in] = ACTIONS(3937),
    [anon_sym_IN] = ACTIONS(3937),
    [anon_sym_In] = ACTIONS(3937),
    [sym_page_keyword] = ACTIONS(3937),
    [anon_sym_codeunit] = ACTIONS(3937),
    [anon_sym_CODEUNIT] = ACTIONS(3937),
    [anon_sym_Codeunit] = ACTIONS(3937),
    [anon_sym_CodeUnit] = ACTIONS(3937),
    [anon_sym_COdeunit] = ACTIONS(3937),
    [anon_sym_codeUnit] = ACTIONS(3937),
    [sym_report_keyword] = ACTIONS(3937),
    [sym_query_keyword] = ACTIONS(3937),
    [anon_sym_xmlport] = ACTIONS(3937),
    [anon_sym_XMLPORT] = ACTIONS(3937),
    [anon_sym_Xmlport] = ACTIONS(3937),
    [anon_sym_XMLport] = ACTIONS(3937),
    [anon_sym_XMLPort] = ACTIONS(3937),
    [anon_sym_XmlPort] = ACTIONS(3937),
    [anon_sym_enum] = ACTIONS(3937),
    [anon_sym_ENUM] = ACTIONS(3937),
    [anon_sym_Enum] = ACTIONS(3937),
    [anon_sym_eNUM] = ACTIONS(3937),
    [anon_sym_eNum] = ACTIONS(3937),
    [anon_sym_ENum] = ACTIONS(3937),
    [sym_quoted_identifier] = ACTIONS(3939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3939),
    [sym_verbatim_string] = ACTIONS(3939),
    [sym_integer] = ACTIONS(3937),
    [sym_continue_as_identifier] = ACTIONS(3939),
    [sym_preproc_open] = ACTIONS(3939),
    [sym_end_keyword] = ACTIONS(3939),
  },
  [STATE(2082)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10605),
    [sym_else_table_relation_fragment] = STATE(10605),
    [sym_table_relation_expression] = STATE(10605),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8107),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2242),
    [sym_preproc_endif] = STATE(3564),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10958),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8107),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(11019),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4483),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4485),
    [anon_sym_POUNDENDIF] = ACTIONS(4485),
    [anon_sym_POUNDEndif] = ACTIONS(4485),
    [anon_sym_POUNDendif2] = ACTIONS(4485),
    [anon_sym_POUNDENDIF2] = ACTIONS(4485),
    [anon_sym_POUNDEndif2] = ACTIONS(4485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4485),
  },
  [STATE(2083)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10421),
    [sym_else_table_relation_fragment] = STATE(10421),
    [sym_table_relation_expression] = STATE(10421),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8104),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2095),
    [sym_preproc_else] = STATE(2243),
    [sym_preproc_endif] = STATE(5934),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(8981),
    [aux_sym_preproc_conditional_link_values_repeat2] = STATE(10746),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10748),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8104),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(10749),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9024),
    [aux_sym_preproc_conditional_impl_values_repeat2] = STATE(10763),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(2084)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_if] = ACTIONS(3869),
    [anon_sym_IF] = ACTIONS(3869),
    [anon_sym_If] = ACTIONS(3869),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_case] = ACTIONS(3869),
    [anon_sym_CASE] = ACTIONS(3869),
    [anon_sym_Case] = ACTIONS(3869),
    [anon_sym_for] = ACTIONS(3869),
    [anon_sym_FOR] = ACTIONS(3869),
    [anon_sym_For] = ACTIONS(3869),
    [anon_sym_foreach] = ACTIONS(3869),
    [anon_sym_FOREACH] = ACTIONS(3869),
    [anon_sym_Foreach] = ACTIONS(3869),
    [anon_sym_while] = ACTIONS(3869),
    [anon_sym_WHILE] = ACTIONS(3869),
    [anon_sym_While] = ACTIONS(3869),
    [anon_sym_repeat] = ACTIONS(3869),
    [anon_sym_REPEAT] = ACTIONS(3869),
    [anon_sym_Repeat] = ACTIONS(3869),
    [anon_sym_exit] = ACTIONS(3869),
    [anon_sym_EXIT] = ACTIONS(3869),
    [anon_sym_Exit] = ACTIONS(3869),
    [anon_sym_continue] = ACTIONS(3869),
    [anon_sym_CONTINUE] = ACTIONS(3869),
    [anon_sym_Continue] = ACTIONS(3869),
    [anon_sym_break] = ACTIONS(3869),
    [anon_sym_BREAK] = ACTIONS(3869),
    [anon_sym_Break] = ACTIONS(3869),
    [anon_sym_with] = ACTIONS(3869),
    [anon_sym_WITH] = ACTIONS(3869),
    [anon_sym_With] = ACTIONS(3869),
    [sym_asserterror_keyword] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_end_keyword] = ACTIONS(3871),
  },
  [STATE(2085)] = {
    [sym_boolean] = STATE(2330),
    [sym_option_member] = STATE(2316),
    [sym_keyword_identifier] = STATE(2330),
    [sym_codeunit_keyword] = STATE(2308),
    [sym_xmlport_keyword] = STATE(2308),
    [sym_enum_keyword] = STATE(2308),
    [sym_keyword_as_identifier] = STATE(2330),
    [aux_sym_option_member_list_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(4405),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(4491),
    [anon_sym_COLON] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(4409),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [aux_sym_where_condition_token1] = ACTIONS(4411),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(4413),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_basic_type_token53] = ACTIONS(4411),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4411),
    [aux_sym_separator_action_token1] = ACTIONS(4411),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4411),
    [aux_sym_type_declaration_token1] = ACTIONS(4411),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(4411),
    [sym_page_keyword] = ACTIONS(369),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(369),
    [sym_query_keyword] = ACTIONS(369),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_local_keyword] = ACTIONS(4405),
    [sym_internal_keyword] = ACTIONS(4405),
    [sym_protected_keyword] = ACTIONS(4405),
    [sym_key_keyword] = ACTIONS(4411),
    [sym_dataset_keyword] = ACTIONS(4411),
    [sym_quoted_identifier] = ACTIONS(4415),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4415),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(4405),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
  },
  [STATE(2086)] = {
    [sym_boolean] = STATE(2330),
    [sym_option_member] = STATE(2340),
    [sym_keyword_identifier] = STATE(2330),
    [sym_codeunit_keyword] = STATE(2308),
    [sym_xmlport_keyword] = STATE(2308),
    [sym_enum_keyword] = STATE(2308),
    [sym_keyword_as_identifier] = STATE(2330),
    [sym_identifier] = ACTIONS(4493),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(4496),
    [aux_sym_boolean_token1] = ACTIONS(4499),
    [aux_sym_boolean_token2] = ACTIONS(4499),
    [sym_decimal] = ACTIONS(613),
    [anon_sym_LPAREN] = ACTIONS(611),
    [aux_sym_where_condition_token1] = ACTIONS(4411),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4502),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(4502),
    [aux_sym_basic_type_token21] = ACTIONS(4502),
    [aux_sym_basic_type_token22] = ACTIONS(4505),
    [aux_sym_basic_type_token48] = ACTIONS(4502),
    [aux_sym_basic_type_token53] = ACTIONS(4411),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4411),
    [aux_sym_separator_action_token1] = ACTIONS(4411),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4411),
    [aux_sym_type_declaration_token1] = ACTIONS(4411),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [anon_sym_not] = ACTIONS(613),
    [anon_sym_NOT] = ACTIONS(613),
    [anon_sym_Not] = ACTIONS(613),
    [anon_sym_POUNDelif] = ACTIONS(611),
    [anon_sym_POUNDELIF] = ACTIONS(611),
    [anon_sym_POUNDElif] = ACTIONS(611),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [anon_sym_POUNDendif] = ACTIONS(611),
    [anon_sym_POUNDENDIF] = ACTIONS(611),
    [anon_sym_POUNDEndif] = ACTIONS(611),
    [anon_sym_POUNDendif2] = ACTIONS(611),
    [anon_sym_POUNDENDIF2] = ACTIONS(611),
    [anon_sym_POUNDEndif2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4502),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4502),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [sym_datetime_literal] = ACTIONS(611),
    [sym_date_literal] = ACTIONS(613),
    [sym_time_literal] = ACTIONS(613),
    [sym_biginteger_literal] = ACTIONS(611),
    [anon_sym_else] = ACTIONS(613),
    [anon_sym_ELSE] = ACTIONS(613),
    [anon_sym_Else] = ACTIONS(613),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(4411),
    [sym_page_keyword] = ACTIONS(4502),
    [anon_sym_codeunit] = ACTIONS(4508),
    [anon_sym_CODEUNIT] = ACTIONS(4508),
    [anon_sym_Codeunit] = ACTIONS(4508),
    [anon_sym_CodeUnit] = ACTIONS(4508),
    [anon_sym_COdeunit] = ACTIONS(4508),
    [anon_sym_codeUnit] = ACTIONS(4508),
    [sym_report_keyword] = ACTIONS(4502),
    [sym_query_keyword] = ACTIONS(4502),
    [anon_sym_xmlport] = ACTIONS(4511),
    [anon_sym_XMLPORT] = ACTIONS(4511),
    [anon_sym_Xmlport] = ACTIONS(4511),
    [anon_sym_XMLport] = ACTIONS(4511),
    [anon_sym_XMLPort] = ACTIONS(4511),
    [anon_sym_XmlPort] = ACTIONS(4511),
    [anon_sym_enum] = ACTIONS(4514),
    [anon_sym_ENUM] = ACTIONS(4514),
    [anon_sym_Enum] = ACTIONS(4514),
    [anon_sym_eNUM] = ACTIONS(4514),
    [anon_sym_eNum] = ACTIONS(4514),
    [anon_sym_ENum] = ACTIONS(4514),
    [sym_local_keyword] = ACTIONS(4405),
    [sym_internal_keyword] = ACTIONS(4405),
    [sym_protected_keyword] = ACTIONS(4405),
    [sym_key_keyword] = ACTIONS(4411),
    [sym_dataset_keyword] = ACTIONS(4411),
    [sym_quoted_identifier] = ACTIONS(4517),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4517),
    [sym_verbatim_string] = ACTIONS(611),
    [sym_integer] = ACTIONS(4493),
    [sym_continue_as_identifier] = ACTIONS(611),
    [sym_preproc_open] = ACTIONS(611),
    [sym_preproc_close] = ACTIONS(611),
  },
  [STATE(2087)] = {
    [sym_preproc_conditional_object] = STATE(2089),
    [sym_using_statement] = STATE(2089),
    [sym__object] = STATE(2089),
    [sym_preproc_split_declaration] = STATE(2089),
    [sym_table_declaration] = STATE(2089),
    [sym_page_declaration] = STATE(2089),
    [sym_report_declaration] = STATE(2089),
    [sym_query_declaration] = STATE(2089),
    [sym_xmlport_declaration] = STATE(2089),
    [sym_permissionset_declaration] = STATE(2089),
    [sym_codeunit_declaration] = STATE(2089),
    [sym_enum_declaration] = STATE(2089),
    [sym_tableextension_declaration] = STATE(2089),
    [sym_pageextension_declaration] = STATE(2089),
    [sym_reportextension_declaration] = STATE(2089),
    [sym_enumextension_declaration] = STATE(2089),
    [sym_permissionsetextension_declaration] = STATE(2089),
    [sym_controladdin_declaration] = STATE(2089),
    [sym_profile_declaration] = STATE(2089),
    [sym_entitlement_declaration] = STATE(2089),
    [sym_profileextension_declaration] = STATE(2089),
    [sym_interface_declaration] = STATE(2089),
    [sym_pagecustomization_declaration] = STATE(2089),
    [sym_dotnet_declaration] = STATE(2089),
    [sym_preproc_if] = STATE(307),
    [sym_tableextension_keyword] = STATE(17066),
    [sym_pageextension_keyword] = STATE(17469),
    [sym_codeunit_keyword] = STATE(17512),
    [sym_reportextension_keyword] = STATE(17404),
    [sym_xmlport_keyword] = STATE(17405),
    [sym_enum_keyword] = STATE(17453),
    [sym_enumextension_keyword] = STATE(17340),
    [sym_controladdin_keyword] = STATE(12142),
    [sym_dotnet_keyword] = STATE(17810),
    [sym_profileextension_keyword] = STATE(12155),
    [sym_permissionset_keyword] = STATE(17872),
    [sym_permissionsetextension_keyword] = STATE(18217),
    [sym_pagecustomization_keyword] = STATE(12241),
    [aux_sym_source_file_repeat1] = STATE(2089),
    [ts_builtin_sym_end] = ACTIONS(4520),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(13),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(19),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(23),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(33),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(39),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(47),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(53),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
  },
  [STATE(2088)] = {
    [sym_boolean] = STATE(1881),
    [sym_code_block] = STATE(3091),
    [sym_assignment_expression] = STATE(1881),
    [sym__expression] = STATE(1881),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1881),
    [sym_multiplicative_expression] = STATE(1881),
    [sym_additive_expression] = STATE(1881),
    [sym_comparison_expression] = STATE(1881),
    [sym_logical_expression] = STATE(1881),
    [sym_ternary_expression] = STATE(1881),
    [sym_unary_expression] = STATE(1881),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1881),
    [sym_list_literal] = STATE(1881),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1881),
    [sym__literal_value] = STATE(1881),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(4522),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4322),
    [anon_sym_POUNDif] = ACTIONS(4318),
    [anon_sym_POUNDIF] = ACTIONS(4318),
    [anon_sym_POUNDIf] = ACTIONS(4318),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [anon_sym_POUNDelse] = ACTIONS(4318),
    [anon_sym_POUNDELSE] = ACTIONS(4318),
    [anon_sym_POUNDElse] = ACTIONS(4318),
    [anon_sym_POUNDelse2] = ACTIONS(4318),
    [anon_sym_POUNDELSE2] = ACTIONS(4318),
    [anon_sym_POUNDElse2] = ACTIONS(4318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(4524),
    [sym_date_literal] = ACTIONS(4522),
    [sym_time_literal] = ACTIONS(4522),
    [sym_biginteger_literal] = ACTIONS(4524),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_IF] = ACTIONS(4322),
    [anon_sym_If] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_ELSE] = ACTIONS(4322),
    [anon_sym_Else] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_CASE] = ACTIONS(4322),
    [anon_sym_Case] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_FOR] = ACTIONS(4322),
    [anon_sym_For] = ACTIONS(4322),
    [anon_sym_foreach] = ACTIONS(4322),
    [anon_sym_FOREACH] = ACTIONS(4322),
    [anon_sym_Foreach] = ACTIONS(4322),
    [anon_sym_while] = ACTIONS(4322),
    [anon_sym_WHILE] = ACTIONS(4322),
    [anon_sym_While] = ACTIONS(4322),
    [anon_sym_repeat] = ACTIONS(4322),
    [anon_sym_REPEAT] = ACTIONS(4322),
    [anon_sym_Repeat] = ACTIONS(4322),
    [anon_sym_until] = ACTIONS(4322),
    [anon_sym_UNTIL] = ACTIONS(4322),
    [anon_sym_Until] = ACTIONS(4322),
    [anon_sym_exit] = ACTIONS(4322),
    [anon_sym_EXIT] = ACTIONS(4322),
    [anon_sym_Exit] = ACTIONS(4322),
    [anon_sym_continue] = ACTIONS(4322),
    [anon_sym_CONTINUE] = ACTIONS(4322),
    [anon_sym_Continue] = ACTIONS(4322),
    [anon_sym_break] = ACTIONS(4322),
    [anon_sym_BREAK] = ACTIONS(4322),
    [anon_sym_Break] = ACTIONS(4322),
    [anon_sym_with] = ACTIONS(4322),
    [anon_sym_WITH] = ACTIONS(4322),
    [anon_sym_With] = ACTIONS(4322),
    [sym_asserterror_keyword] = ACTIONS(4318),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4524),
    [sym_verbatim_string] = ACTIONS(4524),
    [sym_integer] = ACTIONS(4522),
    [sym_continue_as_identifier] = ACTIONS(4524),
    [sym_preproc_open] = ACTIONS(4318),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(2089)] = {
    [sym_preproc_conditional_object] = STATE(2091),
    [sym_using_statement] = STATE(2091),
    [sym__object] = STATE(2091),
    [sym_preproc_split_declaration] = STATE(2091),
    [sym_table_declaration] = STATE(2091),
    [sym_page_declaration] = STATE(2091),
    [sym_report_declaration] = STATE(2091),
    [sym_query_declaration] = STATE(2091),
    [sym_xmlport_declaration] = STATE(2091),
    [sym_permissionset_declaration] = STATE(2091),
    [sym_codeunit_declaration] = STATE(2091),
    [sym_enum_declaration] = STATE(2091),
    [sym_tableextension_declaration] = STATE(2091),
    [sym_pageextension_declaration] = STATE(2091),
    [sym_reportextension_declaration] = STATE(2091),
    [sym_enumextension_declaration] = STATE(2091),
    [sym_permissionsetextension_declaration] = STATE(2091),
    [sym_controladdin_declaration] = STATE(2091),
    [sym_profile_declaration] = STATE(2091),
    [sym_entitlement_declaration] = STATE(2091),
    [sym_profileextension_declaration] = STATE(2091),
    [sym_interface_declaration] = STATE(2091),
    [sym_pagecustomization_declaration] = STATE(2091),
    [sym_dotnet_declaration] = STATE(2091),
    [sym_preproc_if] = STATE(307),
    [sym_tableextension_keyword] = STATE(17066),
    [sym_pageextension_keyword] = STATE(17469),
    [sym_codeunit_keyword] = STATE(17512),
    [sym_reportextension_keyword] = STATE(17404),
    [sym_xmlport_keyword] = STATE(17405),
    [sym_enum_keyword] = STATE(17453),
    [sym_enumextension_keyword] = STATE(17340),
    [sym_controladdin_keyword] = STATE(12142),
    [sym_dotnet_keyword] = STATE(17810),
    [sym_profileextension_keyword] = STATE(12155),
    [sym_permissionset_keyword] = STATE(17872),
    [sym_permissionsetextension_keyword] = STATE(18217),
    [sym_pagecustomization_keyword] = STATE(12241),
    [aux_sym_source_file_repeat1] = STATE(2091),
    [ts_builtin_sym_end] = ACTIONS(4526),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(13),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(19),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(23),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(33),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(39),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(47),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(53),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
  },
  [STATE(2090)] = {
    [sym_preproc_conditional_object] = STATE(2091),
    [sym_using_statement] = STATE(2091),
    [sym__object] = STATE(2091),
    [sym_preproc_split_declaration] = STATE(2091),
    [sym_table_declaration] = STATE(2091),
    [sym_page_declaration] = STATE(2091),
    [sym_report_declaration] = STATE(2091),
    [sym_query_declaration] = STATE(2091),
    [sym_xmlport_declaration] = STATE(2091),
    [sym_permissionset_declaration] = STATE(2091),
    [sym_codeunit_declaration] = STATE(2091),
    [sym_enum_declaration] = STATE(2091),
    [sym_tableextension_declaration] = STATE(2091),
    [sym_pageextension_declaration] = STATE(2091),
    [sym_reportextension_declaration] = STATE(2091),
    [sym_enumextension_declaration] = STATE(2091),
    [sym_permissionsetextension_declaration] = STATE(2091),
    [sym_controladdin_declaration] = STATE(2091),
    [sym_profile_declaration] = STATE(2091),
    [sym_entitlement_declaration] = STATE(2091),
    [sym_profileextension_declaration] = STATE(2091),
    [sym_interface_declaration] = STATE(2091),
    [sym_pagecustomization_declaration] = STATE(2091),
    [sym_dotnet_declaration] = STATE(2091),
    [sym_preproc_if] = STATE(307),
    [sym_tableextension_keyword] = STATE(17066),
    [sym_pageextension_keyword] = STATE(17469),
    [sym_codeunit_keyword] = STATE(17512),
    [sym_reportextension_keyword] = STATE(17404),
    [sym_xmlport_keyword] = STATE(17405),
    [sym_enum_keyword] = STATE(17453),
    [sym_enumextension_keyword] = STATE(17340),
    [sym_controladdin_keyword] = STATE(12142),
    [sym_dotnet_keyword] = STATE(17810),
    [sym_profileextension_keyword] = STATE(12155),
    [sym_permissionset_keyword] = STATE(17872),
    [sym_permissionsetextension_keyword] = STATE(18217),
    [sym_pagecustomization_keyword] = STATE(12241),
    [aux_sym_source_file_repeat1] = STATE(2091),
    [ts_builtin_sym_end] = ACTIONS(4520),
    [anon_sym_POUNDif] = ACTIONS(7),
    [anon_sym_POUNDIF] = ACTIONS(7),
    [anon_sym_POUNDIf] = ACTIONS(7),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(13),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(19),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(23),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(33),
    [anon_sym_controladdin] = ACTIONS(35),
    [anon_sym_CONTROLADDIN] = ACTIONS(35),
    [anon_sym_Controladdin] = ACTIONS(35),
    [anon_sym_ControlAddIn] = ACTIONS(35),
    [anon_sym_ControlAddin] = ACTIONS(35),
    [anon_sym_controlAddIn] = ACTIONS(35),
    [anon_sym_controlAddin] = ACTIONS(35),
    [anon_sym_dotnet] = ACTIONS(37),
    [anon_sym_DOTNET] = ACTIONS(37),
    [anon_sym_Dotnet] = ACTIONS(37),
    [anon_sym_DotNet] = ACTIONS(37),
    [anon_sym_dotNet] = ACTIONS(37),
    [sym_profile_keyword] = ACTIONS(39),
    [anon_sym_profileextension] = ACTIONS(41),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(41),
    [anon_sym_Profileextension] = ACTIONS(41),
    [anon_sym_ProfileExtension] = ACTIONS(41),
    [anon_sym_profileExtension] = ACTIONS(41),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_entitlement_keyword] = ACTIONS(47),
    [anon_sym_pagecustomization] = ACTIONS(49),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(49),
    [anon_sym_Pagecustomization] = ACTIONS(49),
    [anon_sym_PageCustomization] = ACTIONS(49),
    [anon_sym_pageCustomization] = ACTIONS(49),
    [sym_using_keyword] = ACTIONS(53),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7),
  },
  [STATE(2091)] = {
    [sym_preproc_conditional_object] = STATE(2091),
    [sym_using_statement] = STATE(2091),
    [sym__object] = STATE(2091),
    [sym_preproc_split_declaration] = STATE(2091),
    [sym_table_declaration] = STATE(2091),
    [sym_page_declaration] = STATE(2091),
    [sym_report_declaration] = STATE(2091),
    [sym_query_declaration] = STATE(2091),
    [sym_xmlport_declaration] = STATE(2091),
    [sym_permissionset_declaration] = STATE(2091),
    [sym_codeunit_declaration] = STATE(2091),
    [sym_enum_declaration] = STATE(2091),
    [sym_tableextension_declaration] = STATE(2091),
    [sym_pageextension_declaration] = STATE(2091),
    [sym_reportextension_declaration] = STATE(2091),
    [sym_enumextension_declaration] = STATE(2091),
    [sym_permissionsetextension_declaration] = STATE(2091),
    [sym_controladdin_declaration] = STATE(2091),
    [sym_profile_declaration] = STATE(2091),
    [sym_entitlement_declaration] = STATE(2091),
    [sym_profileextension_declaration] = STATE(2091),
    [sym_interface_declaration] = STATE(2091),
    [sym_pagecustomization_declaration] = STATE(2091),
    [sym_dotnet_declaration] = STATE(2091),
    [sym_preproc_if] = STATE(307),
    [sym_tableextension_keyword] = STATE(17066),
    [sym_pageextension_keyword] = STATE(17469),
    [sym_codeunit_keyword] = STATE(17512),
    [sym_reportextension_keyword] = STATE(17404),
    [sym_xmlport_keyword] = STATE(17405),
    [sym_enum_keyword] = STATE(17453),
    [sym_enumextension_keyword] = STATE(17340),
    [sym_controladdin_keyword] = STATE(12142),
    [sym_dotnet_keyword] = STATE(17810),
    [sym_profileextension_keyword] = STATE(12155),
    [sym_permissionset_keyword] = STATE(17872),
    [sym_permissionsetextension_keyword] = STATE(18217),
    [sym_pagecustomization_keyword] = STATE(12241),
    [aux_sym_source_file_repeat1] = STATE(2091),
    [ts_builtin_sym_end] = ACTIONS(3797),
    [anon_sym_POUNDif] = ACTIONS(3794),
    [anon_sym_POUNDIF] = ACTIONS(3794),
    [anon_sym_POUNDIf] = ACTIONS(3794),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4528),
    [anon_sym_tableextension] = ACTIONS(3802),
    [anon_sym_TABLEEXTENSION] = ACTIONS(3802),
    [anon_sym_Tableextension] = ACTIONS(3802),
    [anon_sym_TableExtension] = ACTIONS(3802),
    [anon_sym_tableExtension] = ACTIONS(3802),
    [sym_page_keyword] = ACTIONS(4531),
    [anon_sym_pageextension] = ACTIONS(3808),
    [anon_sym_PAGEEXTENSION] = ACTIONS(3808),
    [anon_sym_Pageextension] = ACTIONS(3808),
    [anon_sym_PageExtension] = ACTIONS(3808),
    [anon_sym_pageExtension] = ACTIONS(3808),
    [anon_sym_codeunit] = ACTIONS(3811),
    [anon_sym_CODEUNIT] = ACTIONS(3811),
    [anon_sym_Codeunit] = ACTIONS(3811),
    [anon_sym_CodeUnit] = ACTIONS(3811),
    [anon_sym_COdeunit] = ACTIONS(3811),
    [anon_sym_codeUnit] = ACTIONS(3811),
    [sym_report_keyword] = ACTIONS(4534),
    [anon_sym_reportextension] = ACTIONS(3817),
    [anon_sym_REPORTEXTENSION] = ACTIONS(3817),
    [anon_sym_Reportextension] = ACTIONS(3817),
    [anon_sym_ReportExtension] = ACTIONS(3817),
    [anon_sym_reportExtension] = ACTIONS(3817),
    [sym_query_keyword] = ACTIONS(4537),
    [anon_sym_xmlport] = ACTIONS(3823),
    [anon_sym_XMLPORT] = ACTIONS(3823),
    [anon_sym_Xmlport] = ACTIONS(3823),
    [anon_sym_XMLport] = ACTIONS(3823),
    [anon_sym_XMLPort] = ACTIONS(3823),
    [anon_sym_XmlPort] = ACTIONS(3823),
    [anon_sym_enum] = ACTIONS(3826),
    [anon_sym_ENUM] = ACTIONS(3826),
    [anon_sym_Enum] = ACTIONS(3826),
    [anon_sym_eNUM] = ACTIONS(3829),
    [anon_sym_eNum] = ACTIONS(3829),
    [anon_sym_ENum] = ACTIONS(3829),
    [anon_sym_enumextension] = ACTIONS(3832),
    [anon_sym_ENUMEXTENSION] = ACTIONS(3832),
    [anon_sym_Enumextension] = ACTIONS(3832),
    [anon_sym_EnumExtension] = ACTIONS(3832),
    [anon_sym_enumExtension] = ACTIONS(3832),
    [sym_interface_keyword] = ACTIONS(4540),
    [anon_sym_controladdin] = ACTIONS(3838),
    [anon_sym_CONTROLADDIN] = ACTIONS(3838),
    [anon_sym_Controladdin] = ACTIONS(3838),
    [anon_sym_ControlAddIn] = ACTIONS(3838),
    [anon_sym_ControlAddin] = ACTIONS(3838),
    [anon_sym_controlAddIn] = ACTIONS(3838),
    [anon_sym_controlAddin] = ACTIONS(3838),
    [anon_sym_dotnet] = ACTIONS(3841),
    [anon_sym_DOTNET] = ACTIONS(3841),
    [anon_sym_Dotnet] = ACTIONS(3841),
    [anon_sym_DotNet] = ACTIONS(3841),
    [anon_sym_dotNet] = ACTIONS(3841),
    [sym_profile_keyword] = ACTIONS(4543),
    [anon_sym_profileextension] = ACTIONS(3847),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(3847),
    [anon_sym_Profileextension] = ACTIONS(3847),
    [anon_sym_ProfileExtension] = ACTIONS(3847),
    [anon_sym_profileExtension] = ACTIONS(3847),
    [anon_sym_permissionset] = ACTIONS(3850),
    [anon_sym_PERMISSIONSET] = ACTIONS(3850),
    [anon_sym_Permissionset] = ACTIONS(3850),
    [anon_sym_PermissionSet] = ACTIONS(3850),
    [anon_sym_permissionSet] = ACTIONS(3850),
    [anon_sym_permissionsetextension] = ACTIONS(3853),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(3853),
    [anon_sym_Permissionsetextension] = ACTIONS(3853),
    [anon_sym_PermissionSetExtension] = ACTIONS(3853),
    [anon_sym_permissionSetExtension] = ACTIONS(3853),
    [sym_entitlement_keyword] = ACTIONS(4546),
    [anon_sym_pagecustomization] = ACTIONS(3859),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(3859),
    [anon_sym_Pagecustomization] = ACTIONS(3859),
    [anon_sym_PageCustomization] = ACTIONS(3859),
    [anon_sym_pageCustomization] = ACTIONS(3859),
    [sym_using_keyword] = ACTIONS(4549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(3794),
  },
  [STATE(2092)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10387),
    [sym_else_table_relation_fragment] = STATE(10387),
    [sym_table_relation_expression] = STATE(10387),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8052),
    [sym_tabledata_permission] = STATE(8680),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_elif] = STATE(2105),
    [sym_preproc_else] = STATE(2261),
    [sym_preproc_endif] = STATE(8686),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10681),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8052),
    [aux_sym_preproc_conditional_permissions_repeat2] = STATE(10682),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_COMMA] = ACTIONS(4554),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4381),
    [anon_sym_POUNDELIF] = ACTIONS(4381),
    [anon_sym_POUNDElif] = ACTIONS(4381),
    [anon_sym_POUNDelse] = ACTIONS(4383),
    [anon_sym_POUNDELSE] = ACTIONS(4383),
    [anon_sym_POUNDElse] = ACTIONS(4383),
    [anon_sym_POUNDelse2] = ACTIONS(4383),
    [anon_sym_POUNDELSE2] = ACTIONS(4383),
    [anon_sym_POUNDElse2] = ACTIONS(4383),
    [anon_sym_POUNDendif] = ACTIONS(4556),
    [anon_sym_POUNDENDIF] = ACTIONS(4556),
    [anon_sym_POUNDEndif] = ACTIONS(4556),
    [anon_sym_POUNDendif2] = ACTIONS(4556),
    [anon_sym_POUNDENDIF2] = ACTIONS(4556),
    [anon_sym_POUNDEndif2] = ACTIONS(4556),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4556),
  },
  [STATE(2093)] = {
    [sym__body_element] = STATE(2102),
    [sym_empty_statement] = STATE(2102),
    [sym_property] = STATE(2102),
    [sym_permissions_property] = STATE(2102),
    [sym_table_relation_property] = STATE(2102),
    [sym_fields_section] = STATE(2102),
    [sym_keys_section] = STATE(2102),
    [sym_fieldgroups_section] = STATE(2102),
    [sym_enum_value_declaration] = STATE(2102),
    [sym_labels_section] = STATE(2102),
    [sym_layout_section] = STATE(2102),
    [sym__layout_element] = STATE(2102),
    [sym_area_section] = STATE(2102),
    [sym_group_section] = STATE(2102),
    [sym_repeater_section] = STATE(2102),
    [sym_cuegroup_section] = STATE(2102),
    [sym_fixed_section] = STATE(2102),
    [sym_grid_section] = STATE(2102),
    [sym_page_field] = STATE(2102),
    [sym_part_section] = STATE(2102),
    [sym_systempart_section] = STATE(2102),
    [sym_usercontrol_section] = STATE(2102),
    [sym_preproc_split_field] = STATE(2102),
    [sym_label_section] = STATE(2102),
    [sym_addfirst_modification] = STATE(2102),
    [sym_addlast_modification] = STATE(2102),
    [sym_addafter_modification] = STATE(2102),
    [sym_addbefore_modification] = STATE(2102),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2102),
    [sym_movelast_modification] = STATE(2102),
    [sym_moveafter_modification] = STATE(2102),
    [sym_movebefore_modification] = STATE(2102),
    [sym_actions_section] = STATE(2102),
    [sym_views_section] = STATE(2102),
    [sym_dataset_section] = STATE(2102),
    [sym_requestpage_section] = STATE(2102),
    [sym_rendering_section] = STATE(2102),
    [sym_elements_section] = STATE(2102),
    [sym_schema_section] = STATE(2102),
    [sym_assembly_declaration] = STATE(2102),
    [sym_event_declaration] = STATE(2102),
    [sym_procedure] = STATE(2102),
    [sym_preproc_split_procedure] = STATE(2102),
    [sym_preproc_split_procedure_preamble] = STATE(2102),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2102),
    [sym_var_section] = STATE(2102),
    [sym_attribute_item] = STATE(2102),
    [sym_preproc_conditional] = STATE(2102),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_elif] = STATE(2100),
    [sym_preproc_else] = STATE(2255),
    [sym_preproc_endif] = STATE(7951),
    [sym_preproc_conditional_layout] = STATE(2102),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2102),
    [aux_sym_preproc_conditional_layout_mixed_repeat2] = STATE(11002),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2094)] = {
    [sym_boolean] = STATE(1979),
    [sym_code_block] = STATE(3274),
    [sym_assignment_expression] = STATE(1979),
    [sym__expression] = STATE(1979),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1979),
    [sym_multiplicative_expression] = STATE(1979),
    [sym_additive_expression] = STATE(1979),
    [sym_comparison_expression] = STATE(1979),
    [sym_logical_expression] = STATE(1979),
    [sym_ternary_expression] = STATE(1979),
    [sym_unary_expression] = STATE(1979),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1979),
    [sym_list_literal] = STATE(1979),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1979),
    [sym__literal_value] = STATE(1979),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(4564),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(1182),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4322),
    [anon_sym_POUNDif] = ACTIONS(4318),
    [anon_sym_POUNDIF] = ACTIONS(4318),
    [anon_sym_POUNDIf] = ACTIONS(4318),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [anon_sym_POUNDelse] = ACTIONS(4318),
    [anon_sym_POUNDELSE] = ACTIONS(4318),
    [anon_sym_POUNDElse] = ACTIONS(4318),
    [anon_sym_POUNDelse2] = ACTIONS(4318),
    [anon_sym_POUNDELSE2] = ACTIONS(4318),
    [anon_sym_POUNDElse2] = ACTIONS(4318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(4566),
    [sym_date_literal] = ACTIONS(4564),
    [sym_time_literal] = ACTIONS(4564),
    [sym_biginteger_literal] = ACTIONS(4566),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_IF] = ACTIONS(4322),
    [anon_sym_If] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_ELSE] = ACTIONS(4322),
    [anon_sym_Else] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_CASE] = ACTIONS(4322),
    [anon_sym_Case] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_FOR] = ACTIONS(4322),
    [anon_sym_For] = ACTIONS(4322),
    [anon_sym_foreach] = ACTIONS(4322),
    [anon_sym_FOREACH] = ACTIONS(4322),
    [anon_sym_Foreach] = ACTIONS(4322),
    [anon_sym_while] = ACTIONS(4322),
    [anon_sym_WHILE] = ACTIONS(4322),
    [anon_sym_While] = ACTIONS(4322),
    [anon_sym_repeat] = ACTIONS(4322),
    [anon_sym_REPEAT] = ACTIONS(4322),
    [anon_sym_Repeat] = ACTIONS(4322),
    [anon_sym_exit] = ACTIONS(4322),
    [anon_sym_EXIT] = ACTIONS(4322),
    [anon_sym_Exit] = ACTIONS(4322),
    [anon_sym_continue] = ACTIONS(4322),
    [anon_sym_CONTINUE] = ACTIONS(4322),
    [anon_sym_Continue] = ACTIONS(4322),
    [anon_sym_break] = ACTIONS(4322),
    [anon_sym_BREAK] = ACTIONS(4322),
    [anon_sym_Break] = ACTIONS(4322),
    [anon_sym_with] = ACTIONS(4322),
    [anon_sym_WITH] = ACTIONS(4322),
    [anon_sym_With] = ACTIONS(4322),
    [sym_asserterror_keyword] = ACTIONS(4318),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4566),
    [sym_verbatim_string] = ACTIONS(4566),
    [sym_integer] = ACTIONS(4564),
    [sym_continue_as_identifier] = ACTIONS(4566),
    [sym_preproc_open] = ACTIONS(4318),
    [sym_begin_keyword] = ACTIONS(1184),
    [sym_end_keyword] = ACTIONS(4318),
  },
  [STATE(2095)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(11295),
    [sym_else_table_relation_fragment] = STATE(11295),
    [sym_table_relation_expression] = STATE(11295),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8242),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(9882),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8242),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(9887),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(4568),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4570),
    [anon_sym_POUNDELIF] = ACTIONS(4570),
    [anon_sym_POUNDElif] = ACTIONS(4570),
    [anon_sym_POUNDelse] = ACTIONS(4570),
    [anon_sym_POUNDELSE] = ACTIONS(4570),
    [anon_sym_POUNDElse] = ACTIONS(4570),
    [anon_sym_POUNDelse2] = ACTIONS(4570),
    [anon_sym_POUNDELSE2] = ACTIONS(4570),
    [anon_sym_POUNDElse2] = ACTIONS(4570),
    [anon_sym_POUNDendif] = ACTIONS(4570),
    [anon_sym_POUNDENDIF] = ACTIONS(4570),
    [anon_sym_POUNDEndif] = ACTIONS(4570),
    [anon_sym_POUNDendif2] = ACTIONS(4570),
    [anon_sym_POUNDENDIF2] = ACTIONS(4570),
    [anon_sym_POUNDEndif2] = ACTIONS(4570),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4570),
  },
  [STATE(2096)] = {
    [aux_sym_option_member_list_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_EQ] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(4575),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [sym_decimal] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(838),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(838),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [anon_sym_not] = ACTIONS(836),
    [anon_sym_NOT] = ACTIONS(836),
    [anon_sym_Not] = ACTIONS(836),
    [anon_sym_POUNDelif] = ACTIONS(838),
    [anon_sym_POUNDELIF] = ACTIONS(838),
    [anon_sym_POUNDElif] = ACTIONS(838),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [anon_sym_POUNDendif] = ACTIONS(838),
    [anon_sym_POUNDENDIF] = ACTIONS(838),
    [anon_sym_POUNDEndif] = ACTIONS(838),
    [anon_sym_POUNDendif2] = ACTIONS(838),
    [anon_sym_POUNDENDIF2] = ACTIONS(838),
    [anon_sym_POUNDEndif2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(838),
    [aux_sym__expression_token1] = ACTIONS(838),
    [aux_sym__expression_token2] = ACTIONS(838),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_div] = ACTIONS(836),
    [anon_sym_DIV] = ACTIONS(836),
    [anon_sym_Div] = ACTIONS(836),
    [anon_sym_mod] = ACTIONS(836),
    [anon_sym_MOD] = ACTIONS(836),
    [anon_sym_Mod] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_LT_GT] = ACTIONS(838),
    [anon_sym_and] = ACTIONS(836),
    [anon_sym_AND] = ACTIONS(836),
    [anon_sym_And] = ACTIONS(836),
    [anon_sym_or] = ACTIONS(836),
    [anon_sym_OR] = ACTIONS(836),
    [anon_sym_Or] = ACTIONS(836),
    [anon_sym_xor] = ACTIONS(836),
    [anon_sym_XOR] = ACTIONS(836),
    [anon_sym_Xor] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(838),
    [sym_datetime_literal] = ACTIONS(838),
    [sym_date_literal] = ACTIONS(836),
    [sym_time_literal] = ACTIONS(836),
    [sym_biginteger_literal] = ACTIONS(838),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_ELSE] = ACTIONS(836),
    [anon_sym_Else] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_IN] = ACTIONS(836),
    [anon_sym_In] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_verbatim_string] = ACTIONS(838),
    [sym_integer] = ACTIONS(836),
    [sym_continue_as_identifier] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
    [sym_preproc_close] = ACTIONS(838),
  },
  [STATE(2097)] = {
    [sym__body_element] = STATE(5388),
    [sym_empty_statement] = STATE(5388),
    [sym_property] = STATE(5388),
    [sym_permissions_property] = STATE(5388),
    [sym_table_relation_property] = STATE(5388),
    [sym_fields_section] = STATE(5388),
    [sym_keys_section] = STATE(5388),
    [sym_fieldgroups_section] = STATE(5388),
    [sym_enum_value_declaration] = STATE(5388),
    [sym_labels_section] = STATE(5388),
    [sym_layout_section] = STATE(5388),
    [sym__layout_element] = STATE(5406),
    [sym_area_section] = STATE(5406),
    [sym_group_section] = STATE(5406),
    [sym_repeater_section] = STATE(5406),
    [sym_cuegroup_section] = STATE(5406),
    [sym_fixed_section] = STATE(5406),
    [sym_grid_section] = STATE(5406),
    [sym_page_field] = STATE(5406),
    [sym_part_section] = STATE(5406),
    [sym_systempart_section] = STATE(5406),
    [sym_usercontrol_section] = STATE(5406),
    [sym_preproc_split_field] = STATE(5406),
    [sym_label_section] = STATE(5406),
    [sym_addfirst_modification] = STATE(5406),
    [sym_addlast_modification] = STATE(5406),
    [sym_addafter_modification] = STATE(5406),
    [sym_addbefore_modification] = STATE(5406),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(5406),
    [sym_movelast_modification] = STATE(5406),
    [sym_moveafter_modification] = STATE(5406),
    [sym_movebefore_modification] = STATE(5406),
    [sym_actions_section] = STATE(5388),
    [sym_views_section] = STATE(5388),
    [sym_dataset_section] = STATE(5388),
    [sym_requestpage_section] = STATE(5388),
    [sym_rendering_section] = STATE(5388),
    [sym_elements_section] = STATE(5388),
    [sym_schema_section] = STATE(5388),
    [sym_assembly_declaration] = STATE(5388),
    [sym_event_declaration] = STATE(5388),
    [sym_procedure] = STATE(5388),
    [sym_preproc_split_procedure] = STATE(5388),
    [sym_preproc_split_procedure_preamble] = STATE(5388),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(5388),
    [sym_var_section] = STATE(5388),
    [sym_attribute_item] = STATE(5388),
    [sym_preproc_conditional] = STATE(5388),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_conditional_layout] = STATE(5406),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4033),
    [aux_sym_layout_section_repeat1] = STATE(5343),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2101),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4578),
    [anon_sym_POUNDELIF] = ACTIONS(4578),
    [anon_sym_POUNDElif] = ACTIONS(4578),
    [anon_sym_POUNDelse] = ACTIONS(4578),
    [anon_sym_POUNDELSE] = ACTIONS(4578),
    [anon_sym_POUNDElse] = ACTIONS(4578),
    [anon_sym_POUNDelse2] = ACTIONS(4578),
    [anon_sym_POUNDELSE2] = ACTIONS(4578),
    [anon_sym_POUNDElse2] = ACTIONS(4578),
    [anon_sym_POUNDendif] = ACTIONS(4578),
    [anon_sym_POUNDENDIF] = ACTIONS(4578),
    [anon_sym_POUNDEndif] = ACTIONS(4578),
    [anon_sym_POUNDendif2] = ACTIONS(4578),
    [anon_sym_POUNDENDIF2] = ACTIONS(4578),
    [anon_sym_POUNDEndif2] = ACTIONS(4578),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4578),
  },
  [STATE(2098)] = {
    [sym_boolean] = STATE(3139),
    [sym_option_member_list] = STATE(3068),
    [sym_option_member] = STATE(2873),
    [sym_keyword_identifier] = STATE(3139),
    [sym_codeunit_keyword] = STATE(2858),
    [sym_xmlport_keyword] = STATE(2858),
    [sym_enum_keyword] = STATE(2858),
    [sym_keyword_as_identifier] = STATE(3139),
    [aux_sym_option_member_list_repeat2] = STATE(2103),
    [sym_identifier] = ACTIONS(4582),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(4584),
    [anon_sym_DASH] = ACTIONS(4586),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(584),
    [anon_sym_LPAREN] = ACTIONS(582),
    [aux_sym_where_condition_token1] = ACTIONS(4590),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4594),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [aux_sym_basic_type_token53] = ACTIONS(4590),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4590),
    [aux_sym_separator_action_token1] = ACTIONS(4590),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4590),
    [aux_sym_type_declaration_token1] = ACTIONS(4590),
    [anon_sym_not] = ACTIONS(584),
    [anon_sym_NOT] = ACTIONS(584),
    [anon_sym_Not] = ACTIONS(584),
    [anon_sym_POUNDelif] = ACTIONS(582),
    [anon_sym_POUNDELIF] = ACTIONS(582),
    [anon_sym_POUNDElif] = ACTIONS(582),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [anon_sym_POUNDendif] = ACTIONS(582),
    [anon_sym_POUNDENDIF] = ACTIONS(582),
    [anon_sym_POUNDEndif] = ACTIONS(582),
    [anon_sym_POUNDendif2] = ACTIONS(582),
    [anon_sym_POUNDENDIF2] = ACTIONS(582),
    [anon_sym_POUNDEndif2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(582),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4592),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [sym_datetime_literal] = ACTIONS(582),
    [sym_date_literal] = ACTIONS(584),
    [sym_time_literal] = ACTIONS(584),
    [sym_biginteger_literal] = ACTIONS(582),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(4590),
    [sym_page_keyword] = ACTIONS(4592),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(4592),
    [sym_query_keyword] = ACTIONS(4592),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_local_keyword] = ACTIONS(4582),
    [sym_internal_keyword] = ACTIONS(4582),
    [sym_protected_keyword] = ACTIONS(4582),
    [sym_key_keyword] = ACTIONS(4590),
    [sym_dataset_keyword] = ACTIONS(4590),
    [sym_quoted_identifier] = ACTIONS(4602),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4602),
    [sym_verbatim_string] = ACTIONS(582),
    [sym_integer] = ACTIONS(4582),
    [sym_continue_as_identifier] = ACTIONS(582),
    [sym_preproc_close] = ACTIONS(582),
  },
  [STATE(2099)] = {
    [sym__body_element] = STATE(4033),
    [sym_empty_statement] = STATE(4033),
    [sym_property] = STATE(4033),
    [sym_permissions_property] = STATE(4033),
    [sym_table_relation_property] = STATE(4033),
    [sym_fields_section] = STATE(4033),
    [sym_keys_section] = STATE(4033),
    [sym_fieldgroups_section] = STATE(4033),
    [sym_enum_value_declaration] = STATE(4033),
    [sym_labels_section] = STATE(4033),
    [sym_layout_section] = STATE(4033),
    [sym__layout_element] = STATE(5343),
    [sym_area_section] = STATE(5343),
    [sym_group_section] = STATE(5343),
    [sym_repeater_section] = STATE(5343),
    [sym_cuegroup_section] = STATE(5343),
    [sym_fixed_section] = STATE(5343),
    [sym_grid_section] = STATE(5343),
    [sym_page_field] = STATE(5343),
    [sym_part_section] = STATE(5343),
    [sym_systempart_section] = STATE(5343),
    [sym_usercontrol_section] = STATE(5343),
    [sym_preproc_split_field] = STATE(5343),
    [sym_label_section] = STATE(5343),
    [sym_addfirst_modification] = STATE(5343),
    [sym_addlast_modification] = STATE(5343),
    [sym_addafter_modification] = STATE(5343),
    [sym_addbefore_modification] = STATE(5343),
    [sym_modify_modification] = STATE(5402),
    [sym_movefirst_modification] = STATE(5343),
    [sym_movelast_modification] = STATE(5343),
    [sym_moveafter_modification] = STATE(5343),
    [sym_movebefore_modification] = STATE(5343),
    [sym_actions_section] = STATE(4033),
    [sym_views_section] = STATE(4033),
    [sym_dataset_section] = STATE(4033),
    [sym_requestpage_section] = STATE(4033),
    [sym_rendering_section] = STATE(4033),
    [sym_elements_section] = STATE(4033),
    [sym_schema_section] = STATE(4033),
    [sym_assembly_declaration] = STATE(4033),
    [sym_event_declaration] = STATE(4033),
    [sym_procedure] = STATE(4033),
    [sym_preproc_split_procedure] = STATE(4033),
    [sym_preproc_split_procedure_preamble] = STATE(4033),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4033),
    [sym_var_section] = STATE(4033),
    [sym_attribute_item] = STATE(4033),
    [sym_preproc_conditional] = STATE(4033),
    [sym_preproc_if] = STATE(2080),
    [sym_preproc_conditional_layout] = STATE(5343),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4033),
    [aux_sym_layout_section_repeat1] = STATE(5343),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4604),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4606),
    [anon_sym_POUNDELIF] = ACTIONS(4606),
    [anon_sym_POUNDElif] = ACTIONS(4606),
    [anon_sym_POUNDelse] = ACTIONS(4606),
    [anon_sym_POUNDELSE] = ACTIONS(4606),
    [anon_sym_POUNDElse] = ACTIONS(4606),
    [anon_sym_POUNDelse2] = ACTIONS(4606),
    [anon_sym_POUNDELSE2] = ACTIONS(4606),
    [anon_sym_POUNDElse2] = ACTIONS(4606),
    [anon_sym_POUNDendif] = ACTIONS(4606),
    [anon_sym_POUNDENDIF] = ACTIONS(4606),
    [anon_sym_POUNDEndif] = ACTIONS(4606),
    [anon_sym_POUNDendif2] = ACTIONS(4606),
    [anon_sym_POUNDENDIF2] = ACTIONS(4606),
    [anon_sym_POUNDEndif2] = ACTIONS(4606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4606),
  },
  [STATE(2100)] = {
    [sym__body_element] = STATE(2101),
    [sym_empty_statement] = STATE(2101),
    [sym_property] = STATE(2101),
    [sym_permissions_property] = STATE(2101),
    [sym_table_relation_property] = STATE(2101),
    [sym_fields_section] = STATE(2101),
    [sym_keys_section] = STATE(2101),
    [sym_fieldgroups_section] = STATE(2101),
    [sym_enum_value_declaration] = STATE(2101),
    [sym_labels_section] = STATE(2101),
    [sym_layout_section] = STATE(2101),
    [sym__layout_element] = STATE(2101),
    [sym_area_section] = STATE(2101),
    [sym_group_section] = STATE(2101),
    [sym_repeater_section] = STATE(2101),
    [sym_cuegroup_section] = STATE(2101),
    [sym_fixed_section] = STATE(2101),
    [sym_grid_section] = STATE(2101),
    [sym_page_field] = STATE(2101),
    [sym_part_section] = STATE(2101),
    [sym_systempart_section] = STATE(2101),
    [sym_usercontrol_section] = STATE(2101),
    [sym_preproc_split_field] = STATE(2101),
    [sym_label_section] = STATE(2101),
    [sym_addfirst_modification] = STATE(2101),
    [sym_addlast_modification] = STATE(2101),
    [sym_addafter_modification] = STATE(2101),
    [sym_addbefore_modification] = STATE(2101),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2101),
    [sym_movelast_modification] = STATE(2101),
    [sym_moveafter_modification] = STATE(2101),
    [sym_movebefore_modification] = STATE(2101),
    [sym_actions_section] = STATE(2101),
    [sym_views_section] = STATE(2101),
    [sym_dataset_section] = STATE(2101),
    [sym_requestpage_section] = STATE(2101),
    [sym_rendering_section] = STATE(2101),
    [sym_elements_section] = STATE(2101),
    [sym_schema_section] = STATE(2101),
    [sym_assembly_declaration] = STATE(2101),
    [sym_event_declaration] = STATE(2101),
    [sym_procedure] = STATE(2101),
    [sym_preproc_split_procedure] = STATE(2101),
    [sym_preproc_split_procedure_preamble] = STATE(2101),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2101),
    [sym_var_section] = STATE(2101),
    [sym_attribute_item] = STATE(2101),
    [sym_preproc_conditional] = STATE(2101),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_conditional_layout] = STATE(2101),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2101),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4611),
    [anon_sym_POUNDELIF] = ACTIONS(4611),
    [anon_sym_POUNDElif] = ACTIONS(4611),
    [anon_sym_POUNDelse] = ACTIONS(4611),
    [anon_sym_POUNDELSE] = ACTIONS(4611),
    [anon_sym_POUNDElse] = ACTIONS(4611),
    [anon_sym_POUNDelse2] = ACTIONS(4611),
    [anon_sym_POUNDELSE2] = ACTIONS(4611),
    [anon_sym_POUNDElse2] = ACTIONS(4611),
    [anon_sym_POUNDendif] = ACTIONS(4611),
    [anon_sym_POUNDENDIF] = ACTIONS(4611),
    [anon_sym_POUNDEndif] = ACTIONS(4611),
    [anon_sym_POUNDendif2] = ACTIONS(4611),
    [anon_sym_POUNDENDIF2] = ACTIONS(4611),
    [anon_sym_POUNDEndif2] = ACTIONS(4611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4611),
  },
  [STATE(2101)] = {
    [sym__body_element] = STATE(2102),
    [sym_empty_statement] = STATE(2102),
    [sym_property] = STATE(2102),
    [sym_permissions_property] = STATE(2102),
    [sym_table_relation_property] = STATE(2102),
    [sym_fields_section] = STATE(2102),
    [sym_keys_section] = STATE(2102),
    [sym_fieldgroups_section] = STATE(2102),
    [sym_enum_value_declaration] = STATE(2102),
    [sym_labels_section] = STATE(2102),
    [sym_layout_section] = STATE(2102),
    [sym__layout_element] = STATE(2102),
    [sym_area_section] = STATE(2102),
    [sym_group_section] = STATE(2102),
    [sym_repeater_section] = STATE(2102),
    [sym_cuegroup_section] = STATE(2102),
    [sym_fixed_section] = STATE(2102),
    [sym_grid_section] = STATE(2102),
    [sym_page_field] = STATE(2102),
    [sym_part_section] = STATE(2102),
    [sym_systempart_section] = STATE(2102),
    [sym_usercontrol_section] = STATE(2102),
    [sym_preproc_split_field] = STATE(2102),
    [sym_label_section] = STATE(2102),
    [sym_addfirst_modification] = STATE(2102),
    [sym_addlast_modification] = STATE(2102),
    [sym_addafter_modification] = STATE(2102),
    [sym_addbefore_modification] = STATE(2102),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2102),
    [sym_movelast_modification] = STATE(2102),
    [sym_moveafter_modification] = STATE(2102),
    [sym_movebefore_modification] = STATE(2102),
    [sym_actions_section] = STATE(2102),
    [sym_views_section] = STATE(2102),
    [sym_dataset_section] = STATE(2102),
    [sym_requestpage_section] = STATE(2102),
    [sym_rendering_section] = STATE(2102),
    [sym_elements_section] = STATE(2102),
    [sym_schema_section] = STATE(2102),
    [sym_assembly_declaration] = STATE(2102),
    [sym_event_declaration] = STATE(2102),
    [sym_procedure] = STATE(2102),
    [sym_preproc_split_procedure] = STATE(2102),
    [sym_preproc_split_procedure_preamble] = STATE(2102),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2102),
    [sym_var_section] = STATE(2102),
    [sym_attribute_item] = STATE(2102),
    [sym_preproc_conditional] = STATE(2102),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_conditional_layout] = STATE(2102),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2102),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4613),
    [anon_sym_POUNDELIF] = ACTIONS(4613),
    [anon_sym_POUNDElif] = ACTIONS(4613),
    [anon_sym_POUNDelse] = ACTIONS(4613),
    [anon_sym_POUNDELSE] = ACTIONS(4613),
    [anon_sym_POUNDElse] = ACTIONS(4613),
    [anon_sym_POUNDelse2] = ACTIONS(4613),
    [anon_sym_POUNDELSE2] = ACTIONS(4613),
    [anon_sym_POUNDElse2] = ACTIONS(4613),
    [anon_sym_POUNDendif] = ACTIONS(4613),
    [anon_sym_POUNDENDIF] = ACTIONS(4613),
    [anon_sym_POUNDEndif] = ACTIONS(4613),
    [anon_sym_POUNDendif2] = ACTIONS(4613),
    [anon_sym_POUNDENDIF2] = ACTIONS(4613),
    [anon_sym_POUNDEndif2] = ACTIONS(4613),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4613),
  },
  [STATE(2102)] = {
    [sym__body_element] = STATE(2102),
    [sym_empty_statement] = STATE(2102),
    [sym_property] = STATE(2102),
    [sym_permissions_property] = STATE(2102),
    [sym_table_relation_property] = STATE(2102),
    [sym_fields_section] = STATE(2102),
    [sym_keys_section] = STATE(2102),
    [sym_fieldgroups_section] = STATE(2102),
    [sym_enum_value_declaration] = STATE(2102),
    [sym_labels_section] = STATE(2102),
    [sym_layout_section] = STATE(2102),
    [sym__layout_element] = STATE(2102),
    [sym_area_section] = STATE(2102),
    [sym_group_section] = STATE(2102),
    [sym_repeater_section] = STATE(2102),
    [sym_cuegroup_section] = STATE(2102),
    [sym_fixed_section] = STATE(2102),
    [sym_grid_section] = STATE(2102),
    [sym_page_field] = STATE(2102),
    [sym_part_section] = STATE(2102),
    [sym_systempart_section] = STATE(2102),
    [sym_usercontrol_section] = STATE(2102),
    [sym_preproc_split_field] = STATE(2102),
    [sym_label_section] = STATE(2102),
    [sym_addfirst_modification] = STATE(2102),
    [sym_addlast_modification] = STATE(2102),
    [sym_addafter_modification] = STATE(2102),
    [sym_addbefore_modification] = STATE(2102),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2102),
    [sym_movelast_modification] = STATE(2102),
    [sym_moveafter_modification] = STATE(2102),
    [sym_movebefore_modification] = STATE(2102),
    [sym_actions_section] = STATE(2102),
    [sym_views_section] = STATE(2102),
    [sym_dataset_section] = STATE(2102),
    [sym_requestpage_section] = STATE(2102),
    [sym_rendering_section] = STATE(2102),
    [sym_elements_section] = STATE(2102),
    [sym_schema_section] = STATE(2102),
    [sym_assembly_declaration] = STATE(2102),
    [sym_event_declaration] = STATE(2102),
    [sym_procedure] = STATE(2102),
    [sym_preproc_split_procedure] = STATE(2102),
    [sym_preproc_split_procedure_preamble] = STATE(2102),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2102),
    [sym_var_section] = STATE(2102),
    [sym_attribute_item] = STATE(2102),
    [sym_preproc_conditional] = STATE(2102),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_conditional_layout] = STATE(2102),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2102),
    [anon_sym_SEMI] = ACTIONS(4615),
    [aux_sym_where_condition_token1] = ACTIONS(4618),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4621),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4627),
    [aux_sym_basic_type_token6] = ACTIONS(4630),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4633),
    [aux_sym_addafter_modification_token1] = ACTIONS(4636),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4639),
    [aux_sym_modify_modification_token1] = ACTIONS(4642),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4645),
    [aux_sym_movelast_modification_token1] = ACTIONS(4648),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4651),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4654),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4657),
    [anon_sym_POUNDif] = ACTIONS(4660),
    [anon_sym_POUNDIF] = ACTIONS(4660),
    [anon_sym_POUNDIf] = ACTIONS(4660),
    [anon_sym_POUNDelif] = ACTIONS(4663),
    [anon_sym_POUNDELIF] = ACTIONS(4663),
    [anon_sym_POUNDElif] = ACTIONS(4663),
    [anon_sym_POUNDelse] = ACTIONS(4663),
    [anon_sym_POUNDELSE] = ACTIONS(4663),
    [anon_sym_POUNDElse] = ACTIONS(4663),
    [anon_sym_POUNDelse2] = ACTIONS(4663),
    [anon_sym_POUNDELSE2] = ACTIONS(4663),
    [anon_sym_POUNDElse2] = ACTIONS(4663),
    [anon_sym_POUNDendif] = ACTIONS(4663),
    [anon_sym_POUNDENDIF] = ACTIONS(4663),
    [anon_sym_POUNDEndif] = ACTIONS(4663),
    [anon_sym_POUNDendif2] = ACTIONS(4663),
    [anon_sym_POUNDENDIF2] = ACTIONS(4663),
    [anon_sym_POUNDEndif2] = ACTIONS(4663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4665),
    [sym_trigger_keyword] = ACTIONS(4668),
    [sym_var_keyword] = ACTIONS(4671),
    [sym_local_keyword] = ACTIONS(4674),
    [sym_internal_keyword] = ACTIONS(4677),
    [sym_protected_keyword] = ACTIONS(4674),
    [sym_event_keyword] = ACTIONS(4680),
    [sym_fields_keyword] = ACTIONS(4683),
    [sym_keys_keyword] = ACTIONS(4686),
    [sym_fieldgroups_keyword] = ACTIONS(4689),
    [sym_actions_keyword] = ACTIONS(4692),
    [sym_layout_keyword] = ACTIONS(4695),
    [sym_area_keyword] = ACTIONS(4698),
    [sym_group_keyword] = ACTIONS(4701),
    [sym_repeater_keyword] = ACTIONS(4704),
    [sym_cuegroup_keyword] = ACTIONS(4707),
    [sym_fixed_keyword] = ACTIONS(4710),
    [sym_grid_keyword] = ACTIONS(4713),
    [sym_part_keyword] = ACTIONS(4716),
    [sym_systempart_keyword] = ACTIONS(4719),
    [sym_usercontrol_keyword] = ACTIONS(4722),
    [sym_dataset_keyword] = ACTIONS(4725),
    [sym_elements_keyword] = ACTIONS(4728),
    [sym_labels_keyword] = ACTIONS(4731),
    [sym_rendering_keyword] = ACTIONS(4734),
    [sym_requestpage_keyword] = ACTIONS(4737),
    [sym_schema_keyword] = ACTIONS(4740),
    [sym_views_keyword] = ACTIONS(4743),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4746),
    [sym_preproc_open] = ACTIONS(4660),
    [sym_preproc_close] = ACTIONS(4663),
  },
  [STATE(2103)] = {
    [sym_boolean] = STATE(3139),
    [sym_option_member] = STATE(2875),
    [sym_keyword_identifier] = STATE(3139),
    [sym_codeunit_keyword] = STATE(2858),
    [sym_xmlport_keyword] = STATE(2858),
    [sym_enum_keyword] = STATE(2858),
    [sym_keyword_as_identifier] = STATE(3139),
    [aux_sym_option_member_list_repeat2] = STATE(2252),
    [sym_identifier] = ACTIONS(4582),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(4749),
    [anon_sym_DASH] = ACTIONS(4586),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [aux_sym_where_condition_token1] = ACTIONS(4590),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4594),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [aux_sym_basic_type_token53] = ACTIONS(4590),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4590),
    [aux_sym_separator_action_token1] = ACTIONS(4590),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4590),
    [aux_sym_type_declaration_token1] = ACTIONS(4590),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4592),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(4590),
    [sym_page_keyword] = ACTIONS(4592),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(4592),
    [sym_query_keyword] = ACTIONS(4592),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_local_keyword] = ACTIONS(4582),
    [sym_internal_keyword] = ACTIONS(4582),
    [sym_protected_keyword] = ACTIONS(4582),
    [sym_key_keyword] = ACTIONS(4590),
    [sym_dataset_keyword] = ACTIONS(4590),
    [sym_quoted_identifier] = ACTIONS(4602),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4602),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(4582),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
  },
  [STATE(2104)] = {
    [sym_boolean] = STATE(3139),
    [sym_option_member] = STATE(3131),
    [sym_keyword_identifier] = STATE(3139),
    [sym_codeunit_keyword] = STATE(2858),
    [sym_xmlport_keyword] = STATE(2858),
    [sym_enum_keyword] = STATE(2858),
    [sym_keyword_as_identifier] = STATE(3139),
    [sym_identifier] = ACTIONS(4751),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(4754),
    [aux_sym_boolean_token1] = ACTIONS(4757),
    [aux_sym_boolean_token2] = ACTIONS(4757),
    [sym_decimal] = ACTIONS(613),
    [anon_sym_LPAREN] = ACTIONS(611),
    [aux_sym_where_condition_token1] = ACTIONS(4590),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4760),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(4760),
    [aux_sym_basic_type_token21] = ACTIONS(4760),
    [aux_sym_basic_type_token22] = ACTIONS(4763),
    [aux_sym_basic_type_token48] = ACTIONS(4760),
    [aux_sym_basic_type_token53] = ACTIONS(4590),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4590),
    [aux_sym_separator_action_token1] = ACTIONS(4590),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4590),
    [aux_sym_type_declaration_token1] = ACTIONS(4590),
    [anon_sym_not] = ACTIONS(613),
    [anon_sym_NOT] = ACTIONS(613),
    [anon_sym_Not] = ACTIONS(613),
    [anon_sym_POUNDelif] = ACTIONS(611),
    [anon_sym_POUNDELIF] = ACTIONS(611),
    [anon_sym_POUNDElif] = ACTIONS(611),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [anon_sym_POUNDendif] = ACTIONS(611),
    [anon_sym_POUNDENDIF] = ACTIONS(611),
    [anon_sym_POUNDEndif] = ACTIONS(611),
    [anon_sym_POUNDendif2] = ACTIONS(611),
    [anon_sym_POUNDENDIF2] = ACTIONS(611),
    [anon_sym_POUNDEndif2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(4760),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [sym_datetime_literal] = ACTIONS(611),
    [sym_date_literal] = ACTIONS(613),
    [sym_time_literal] = ACTIONS(613),
    [sym_biginteger_literal] = ACTIONS(611),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(4590),
    [sym_page_keyword] = ACTIONS(4760),
    [anon_sym_codeunit] = ACTIONS(4766),
    [anon_sym_CODEUNIT] = ACTIONS(4766),
    [anon_sym_Codeunit] = ACTIONS(4766),
    [anon_sym_CodeUnit] = ACTIONS(4766),
    [anon_sym_COdeunit] = ACTIONS(4766),
    [anon_sym_codeUnit] = ACTIONS(4766),
    [sym_report_keyword] = ACTIONS(4760),
    [sym_query_keyword] = ACTIONS(4760),
    [anon_sym_xmlport] = ACTIONS(4769),
    [anon_sym_XMLPORT] = ACTIONS(4769),
    [anon_sym_Xmlport] = ACTIONS(4769),
    [anon_sym_XMLport] = ACTIONS(4769),
    [anon_sym_XMLPort] = ACTIONS(4769),
    [anon_sym_XmlPort] = ACTIONS(4769),
    [anon_sym_enum] = ACTIONS(4772),
    [anon_sym_ENUM] = ACTIONS(4772),
    [anon_sym_Enum] = ACTIONS(4772),
    [anon_sym_eNUM] = ACTIONS(4772),
    [anon_sym_eNum] = ACTIONS(4772),
    [anon_sym_ENum] = ACTIONS(4772),
    [sym_local_keyword] = ACTIONS(4582),
    [sym_internal_keyword] = ACTIONS(4582),
    [sym_protected_keyword] = ACTIONS(4582),
    [sym_key_keyword] = ACTIONS(4590),
    [sym_dataset_keyword] = ACTIONS(4590),
    [sym_quoted_identifier] = ACTIONS(4775),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4775),
    [sym_verbatim_string] = ACTIONS(611),
    [sym_integer] = ACTIONS(4751),
    [sym_continue_as_identifier] = ACTIONS(611),
    [sym_preproc_close] = ACTIONS(611),
  },
  [STATE(2105)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(11295),
    [sym_else_table_relation_fragment] = STATE(11295),
    [sym_table_relation_expression] = STATE(11295),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8242),
    [sym_tabledata_permission] = STATE(8680),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8242),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_COMMA] = ACTIONS(4568),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4778),
    [anon_sym_POUNDELIF] = ACTIONS(4778),
    [anon_sym_POUNDElif] = ACTIONS(4778),
    [anon_sym_POUNDelse] = ACTIONS(4778),
    [anon_sym_POUNDELSE] = ACTIONS(4778),
    [anon_sym_POUNDElse] = ACTIONS(4778),
    [anon_sym_POUNDelse2] = ACTIONS(4778),
    [anon_sym_POUNDELSE2] = ACTIONS(4778),
    [anon_sym_POUNDElse2] = ACTIONS(4778),
    [anon_sym_POUNDendif] = ACTIONS(4778),
    [anon_sym_POUNDENDIF] = ACTIONS(4778),
    [anon_sym_POUNDEndif] = ACTIONS(4778),
    [anon_sym_POUNDendif2] = ACTIONS(4778),
    [anon_sym_POUNDENDIF2] = ACTIONS(4778),
    [anon_sym_POUNDEndif2] = ACTIONS(4778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4778),
  },
  [STATE(2106)] = {
    [sym_type_specification] = STATE(3534),
    [sym_text_type] = STATE(3520),
    [sym_code_type] = STATE(3520),
    [sym_option_type] = STATE(3519),
    [sym_record_type] = STATE(3519),
    [sym_dotnet_type] = STATE(3519),
    [sym_object_reference_type] = STATE(3519),
    [sym_array_type] = STATE(3521),
    [sym_list_type] = STATE(3521),
    [sym_dictionary_type] = STATE(3521),
    [sym_basic_type] = STATE(3519),
    [sym_codeunit_keyword] = STATE(11499),
    [sym_xmlport_keyword] = STATE(11499),
    [sym_enum_keyword] = STATE(11499),
    [sym_controladdin_keyword] = STATE(11499),
    [sym_dotnet_keyword] = STATE(11334),
    [sym_identifier] = ACTIONS(4781),
    [aux_sym_text_type_token1] = ACTIONS(4783),
    [aux_sym_code_type_token1] = ACTIONS(4785),
    [aux_sym_option_type_token1] = ACTIONS(4787),
    [aux_sym_record_type_token1] = ACTIONS(4789),
    [aux_sym_object_reference_type_token1] = ACTIONS(4791),
    [aux_sym_object_reference_type_token2] = ACTIONS(4791),
    [aux_sym_array_type_token1] = ACTIONS(4793),
    [aux_sym_list_type_token1] = ACTIONS(4795),
    [aux_sym_dictionary_type_token1] = ACTIONS(4797),
    [aux_sym_basic_type_token1] = ACTIONS(4799),
    [aux_sym_basic_type_token2] = ACTIONS(4799),
    [aux_sym_basic_type_token3] = ACTIONS(4799),
    [aux_sym_basic_type_token4] = ACTIONS(4799),
    [aux_sym_basic_type_token5] = ACTIONS(4799),
    [aux_sym_basic_type_token6] = ACTIONS(4801),
    [aux_sym_basic_type_token7] = ACTIONS(4799),
    [aux_sym_basic_type_token8] = ACTIONS(4799),
    [aux_sym_basic_type_token9] = ACTIONS(4799),
    [aux_sym_basic_type_token10] = ACTIONS(4799),
    [aux_sym_basic_type_token11] = ACTIONS(4799),
    [aux_sym_basic_type_token12] = ACTIONS(4799),
    [aux_sym_basic_type_token13] = ACTIONS(4803),
    [aux_sym_basic_type_token14] = ACTIONS(4799),
    [aux_sym_basic_type_token15] = ACTIONS(4799),
    [aux_sym_basic_type_token16] = ACTIONS(4799),
    [aux_sym_basic_type_token17] = ACTIONS(4799),
    [aux_sym_basic_type_token18] = ACTIONS(4799),
    [aux_sym_basic_type_token19] = ACTIONS(4799),
    [aux_sym_basic_type_token20] = ACTIONS(4799),
    [aux_sym_basic_type_token21] = ACTIONS(4799),
    [aux_sym_basic_type_token22] = ACTIONS(4799),
    [aux_sym_basic_type_token23] = ACTIONS(4799),
    [aux_sym_basic_type_token24] = ACTIONS(4799),
    [aux_sym_basic_type_token25] = ACTIONS(4799),
    [aux_sym_basic_type_token26] = ACTIONS(4799),
    [aux_sym_basic_type_token27] = ACTIONS(4799),
    [aux_sym_basic_type_token28] = ACTIONS(4799),
    [aux_sym_basic_type_token29] = ACTIONS(4799),
    [aux_sym_basic_type_token30] = ACTIONS(4799),
    [aux_sym_basic_type_token31] = ACTIONS(4799),
    [aux_sym_basic_type_token32] = ACTIONS(4799),
    [aux_sym_basic_type_token33] = ACTIONS(4799),
    [aux_sym_basic_type_token34] = ACTIONS(4799),
    [aux_sym_basic_type_token35] = ACTIONS(4799),
    [aux_sym_basic_type_token36] = ACTIONS(4799),
    [aux_sym_basic_type_token37] = ACTIONS(4799),
    [aux_sym_basic_type_token38] = ACTIONS(4799),
    [aux_sym_basic_type_token39] = ACTIONS(4799),
    [aux_sym_basic_type_token40] = ACTIONS(4799),
    [aux_sym_basic_type_token41] = ACTIONS(4799),
    [aux_sym_basic_type_token42] = ACTIONS(4799),
    [aux_sym_basic_type_token43] = ACTIONS(4799),
    [aux_sym_basic_type_token44] = ACTIONS(4799),
    [aux_sym_basic_type_token45] = ACTIONS(4799),
    [aux_sym_basic_type_token46] = ACTIONS(4799),
    [aux_sym_basic_type_token47] = ACTIONS(4799),
    [aux_sym_basic_type_token48] = ACTIONS(4799),
    [aux_sym_basic_type_token49] = ACTIONS(4799),
    [aux_sym_basic_type_token50] = ACTIONS(4799),
    [aux_sym_basic_type_token51] = ACTIONS(4799),
    [aux_sym_basic_type_token52] = ACTIONS(4799),
    [aux_sym_basic_type_token53] = ACTIONS(4799),
    [aux_sym_basic_type_token54] = ACTIONS(4799),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4791),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4791),
    [sym_query_keyword] = ACTIONS(4791),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4791),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2107)] = {
    [sym_type_specification] = STATE(2318),
    [sym_text_type] = STATE(2338),
    [sym_code_type] = STATE(2338),
    [sym_option_type] = STATE(2337),
    [sym_record_type] = STATE(2337),
    [sym_dotnet_type] = STATE(2337),
    [sym_object_reference_type] = STATE(2337),
    [sym_array_type] = STATE(2339),
    [sym_list_type] = STATE(2339),
    [sym_dictionary_type] = STATE(2339),
    [sym_basic_type] = STATE(2337),
    [sym_codeunit_keyword] = STATE(11546),
    [sym_xmlport_keyword] = STATE(11546),
    [sym_enum_keyword] = STATE(11546),
    [sym_controladdin_keyword] = STATE(11546),
    [sym_dotnet_keyword] = STATE(11326),
    [sym_identifier] = ACTIONS(4811),
    [aux_sym_text_type_token1] = ACTIONS(4813),
    [aux_sym_code_type_token1] = ACTIONS(4815),
    [aux_sym_option_type_token1] = ACTIONS(4817),
    [aux_sym_record_type_token1] = ACTIONS(4819),
    [aux_sym_object_reference_type_token1] = ACTIONS(4821),
    [aux_sym_object_reference_type_token2] = ACTIONS(4821),
    [aux_sym_array_type_token1] = ACTIONS(4823),
    [aux_sym_list_type_token1] = ACTIONS(4825),
    [aux_sym_dictionary_type_token1] = ACTIONS(4827),
    [aux_sym_basic_type_token1] = ACTIONS(4829),
    [aux_sym_basic_type_token2] = ACTIONS(4829),
    [aux_sym_basic_type_token3] = ACTIONS(4829),
    [aux_sym_basic_type_token4] = ACTIONS(4829),
    [aux_sym_basic_type_token5] = ACTIONS(4829),
    [aux_sym_basic_type_token6] = ACTIONS(4831),
    [aux_sym_basic_type_token7] = ACTIONS(4829),
    [aux_sym_basic_type_token8] = ACTIONS(4829),
    [aux_sym_basic_type_token9] = ACTIONS(4829),
    [aux_sym_basic_type_token10] = ACTIONS(4829),
    [aux_sym_basic_type_token11] = ACTIONS(4829),
    [aux_sym_basic_type_token12] = ACTIONS(4829),
    [aux_sym_basic_type_token13] = ACTIONS(4833),
    [aux_sym_basic_type_token14] = ACTIONS(4829),
    [aux_sym_basic_type_token15] = ACTIONS(4829),
    [aux_sym_basic_type_token16] = ACTIONS(4829),
    [aux_sym_basic_type_token17] = ACTIONS(4829),
    [aux_sym_basic_type_token18] = ACTIONS(4829),
    [aux_sym_basic_type_token19] = ACTIONS(4829),
    [aux_sym_basic_type_token20] = ACTIONS(4829),
    [aux_sym_basic_type_token21] = ACTIONS(4829),
    [aux_sym_basic_type_token22] = ACTIONS(4829),
    [aux_sym_basic_type_token23] = ACTIONS(4829),
    [aux_sym_basic_type_token24] = ACTIONS(4829),
    [aux_sym_basic_type_token25] = ACTIONS(4829),
    [aux_sym_basic_type_token26] = ACTIONS(4829),
    [aux_sym_basic_type_token27] = ACTIONS(4829),
    [aux_sym_basic_type_token28] = ACTIONS(4829),
    [aux_sym_basic_type_token29] = ACTIONS(4829),
    [aux_sym_basic_type_token30] = ACTIONS(4829),
    [aux_sym_basic_type_token31] = ACTIONS(4829),
    [aux_sym_basic_type_token32] = ACTIONS(4829),
    [aux_sym_basic_type_token33] = ACTIONS(4829),
    [aux_sym_basic_type_token34] = ACTIONS(4829),
    [aux_sym_basic_type_token35] = ACTIONS(4829),
    [aux_sym_basic_type_token36] = ACTIONS(4829),
    [aux_sym_basic_type_token37] = ACTIONS(4829),
    [aux_sym_basic_type_token38] = ACTIONS(4829),
    [aux_sym_basic_type_token39] = ACTIONS(4829),
    [aux_sym_basic_type_token40] = ACTIONS(4829),
    [aux_sym_basic_type_token41] = ACTIONS(4829),
    [aux_sym_basic_type_token42] = ACTIONS(4829),
    [aux_sym_basic_type_token43] = ACTIONS(4829),
    [aux_sym_basic_type_token44] = ACTIONS(4829),
    [aux_sym_basic_type_token45] = ACTIONS(4829),
    [aux_sym_basic_type_token46] = ACTIONS(4829),
    [aux_sym_basic_type_token47] = ACTIONS(4829),
    [aux_sym_basic_type_token48] = ACTIONS(4829),
    [aux_sym_basic_type_token49] = ACTIONS(4829),
    [aux_sym_basic_type_token50] = ACTIONS(4829),
    [aux_sym_basic_type_token51] = ACTIONS(4829),
    [aux_sym_basic_type_token52] = ACTIONS(4829),
    [aux_sym_basic_type_token53] = ACTIONS(4829),
    [aux_sym_basic_type_token54] = ACTIONS(4829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4821),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4821),
    [sym_query_keyword] = ACTIONS(4821),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4821),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4835),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2108)] = {
    [sym_type_specification] = STATE(2352),
    [sym_text_type] = STATE(2338),
    [sym_code_type] = STATE(2338),
    [sym_option_type] = STATE(2337),
    [sym_record_type] = STATE(2337),
    [sym_dotnet_type] = STATE(2337),
    [sym_object_reference_type] = STATE(2337),
    [sym_array_type] = STATE(2339),
    [sym_list_type] = STATE(2339),
    [sym_dictionary_type] = STATE(2339),
    [sym_basic_type] = STATE(2337),
    [sym_codeunit_keyword] = STATE(11546),
    [sym_xmlport_keyword] = STATE(11546),
    [sym_enum_keyword] = STATE(11546),
    [sym_controladdin_keyword] = STATE(11546),
    [sym_dotnet_keyword] = STATE(11326),
    [sym_identifier] = ACTIONS(4811),
    [aux_sym_text_type_token1] = ACTIONS(4813),
    [aux_sym_code_type_token1] = ACTIONS(4815),
    [aux_sym_option_type_token1] = ACTIONS(4817),
    [aux_sym_record_type_token1] = ACTIONS(4819),
    [aux_sym_object_reference_type_token1] = ACTIONS(4821),
    [aux_sym_object_reference_type_token2] = ACTIONS(4821),
    [aux_sym_array_type_token1] = ACTIONS(4823),
    [aux_sym_list_type_token1] = ACTIONS(4825),
    [aux_sym_dictionary_type_token1] = ACTIONS(4827),
    [aux_sym_basic_type_token1] = ACTIONS(4829),
    [aux_sym_basic_type_token2] = ACTIONS(4829),
    [aux_sym_basic_type_token3] = ACTIONS(4829),
    [aux_sym_basic_type_token4] = ACTIONS(4829),
    [aux_sym_basic_type_token5] = ACTIONS(4829),
    [aux_sym_basic_type_token6] = ACTIONS(4831),
    [aux_sym_basic_type_token7] = ACTIONS(4829),
    [aux_sym_basic_type_token8] = ACTIONS(4829),
    [aux_sym_basic_type_token9] = ACTIONS(4829),
    [aux_sym_basic_type_token10] = ACTIONS(4829),
    [aux_sym_basic_type_token11] = ACTIONS(4829),
    [aux_sym_basic_type_token12] = ACTIONS(4829),
    [aux_sym_basic_type_token13] = ACTIONS(4833),
    [aux_sym_basic_type_token14] = ACTIONS(4829),
    [aux_sym_basic_type_token15] = ACTIONS(4829),
    [aux_sym_basic_type_token16] = ACTIONS(4829),
    [aux_sym_basic_type_token17] = ACTIONS(4829),
    [aux_sym_basic_type_token18] = ACTIONS(4829),
    [aux_sym_basic_type_token19] = ACTIONS(4829),
    [aux_sym_basic_type_token20] = ACTIONS(4829),
    [aux_sym_basic_type_token21] = ACTIONS(4829),
    [aux_sym_basic_type_token22] = ACTIONS(4829),
    [aux_sym_basic_type_token23] = ACTIONS(4829),
    [aux_sym_basic_type_token24] = ACTIONS(4829),
    [aux_sym_basic_type_token25] = ACTIONS(4829),
    [aux_sym_basic_type_token26] = ACTIONS(4829),
    [aux_sym_basic_type_token27] = ACTIONS(4829),
    [aux_sym_basic_type_token28] = ACTIONS(4829),
    [aux_sym_basic_type_token29] = ACTIONS(4829),
    [aux_sym_basic_type_token30] = ACTIONS(4829),
    [aux_sym_basic_type_token31] = ACTIONS(4829),
    [aux_sym_basic_type_token32] = ACTIONS(4829),
    [aux_sym_basic_type_token33] = ACTIONS(4829),
    [aux_sym_basic_type_token34] = ACTIONS(4829),
    [aux_sym_basic_type_token35] = ACTIONS(4829),
    [aux_sym_basic_type_token36] = ACTIONS(4829),
    [aux_sym_basic_type_token37] = ACTIONS(4829),
    [aux_sym_basic_type_token38] = ACTIONS(4829),
    [aux_sym_basic_type_token39] = ACTIONS(4829),
    [aux_sym_basic_type_token40] = ACTIONS(4829),
    [aux_sym_basic_type_token41] = ACTIONS(4829),
    [aux_sym_basic_type_token42] = ACTIONS(4829),
    [aux_sym_basic_type_token43] = ACTIONS(4829),
    [aux_sym_basic_type_token44] = ACTIONS(4829),
    [aux_sym_basic_type_token45] = ACTIONS(4829),
    [aux_sym_basic_type_token46] = ACTIONS(4829),
    [aux_sym_basic_type_token47] = ACTIONS(4829),
    [aux_sym_basic_type_token48] = ACTIONS(4829),
    [aux_sym_basic_type_token49] = ACTIONS(4829),
    [aux_sym_basic_type_token50] = ACTIONS(4829),
    [aux_sym_basic_type_token51] = ACTIONS(4829),
    [aux_sym_basic_type_token52] = ACTIONS(4829),
    [aux_sym_basic_type_token53] = ACTIONS(4829),
    [aux_sym_basic_type_token54] = ACTIONS(4829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4821),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4821),
    [sym_query_keyword] = ACTIONS(4821),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4821),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4835),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2109)] = {
    [sym_type_specification] = STATE(3092),
    [sym_text_type] = STATE(3087),
    [sym_code_type] = STATE(3087),
    [sym_option_type] = STATE(3071),
    [sym_record_type] = STATE(3071),
    [sym_dotnet_type] = STATE(3071),
    [sym_object_reference_type] = STATE(3071),
    [sym_array_type] = STATE(3130),
    [sym_list_type] = STATE(3130),
    [sym_dictionary_type] = STATE(3130),
    [sym_basic_type] = STATE(3071),
    [sym_codeunit_keyword] = STATE(11510),
    [sym_xmlport_keyword] = STATE(11510),
    [sym_enum_keyword] = STATE(11510),
    [sym_controladdin_keyword] = STATE(11510),
    [sym_dotnet_keyword] = STATE(11364),
    [sym_identifier] = ACTIONS(4837),
    [aux_sym_text_type_token1] = ACTIONS(4839),
    [aux_sym_code_type_token1] = ACTIONS(4841),
    [aux_sym_option_type_token1] = ACTIONS(4843),
    [aux_sym_record_type_token1] = ACTIONS(4845),
    [aux_sym_object_reference_type_token1] = ACTIONS(4847),
    [aux_sym_object_reference_type_token2] = ACTIONS(4847),
    [aux_sym_array_type_token1] = ACTIONS(4849),
    [aux_sym_list_type_token1] = ACTIONS(4851),
    [aux_sym_dictionary_type_token1] = ACTIONS(4853),
    [aux_sym_basic_type_token1] = ACTIONS(4855),
    [aux_sym_basic_type_token2] = ACTIONS(4855),
    [aux_sym_basic_type_token3] = ACTIONS(4855),
    [aux_sym_basic_type_token4] = ACTIONS(4855),
    [aux_sym_basic_type_token5] = ACTIONS(4855),
    [aux_sym_basic_type_token6] = ACTIONS(4857),
    [aux_sym_basic_type_token7] = ACTIONS(4855),
    [aux_sym_basic_type_token8] = ACTIONS(4855),
    [aux_sym_basic_type_token9] = ACTIONS(4855),
    [aux_sym_basic_type_token10] = ACTIONS(4855),
    [aux_sym_basic_type_token11] = ACTIONS(4855),
    [aux_sym_basic_type_token12] = ACTIONS(4855),
    [aux_sym_basic_type_token13] = ACTIONS(4859),
    [aux_sym_basic_type_token14] = ACTIONS(4855),
    [aux_sym_basic_type_token15] = ACTIONS(4855),
    [aux_sym_basic_type_token16] = ACTIONS(4855),
    [aux_sym_basic_type_token17] = ACTIONS(4855),
    [aux_sym_basic_type_token18] = ACTIONS(4855),
    [aux_sym_basic_type_token19] = ACTIONS(4855),
    [aux_sym_basic_type_token20] = ACTIONS(4855),
    [aux_sym_basic_type_token21] = ACTIONS(4855),
    [aux_sym_basic_type_token22] = ACTIONS(4855),
    [aux_sym_basic_type_token23] = ACTIONS(4855),
    [aux_sym_basic_type_token24] = ACTIONS(4855),
    [aux_sym_basic_type_token25] = ACTIONS(4855),
    [aux_sym_basic_type_token26] = ACTIONS(4855),
    [aux_sym_basic_type_token27] = ACTIONS(4855),
    [aux_sym_basic_type_token28] = ACTIONS(4855),
    [aux_sym_basic_type_token29] = ACTIONS(4855),
    [aux_sym_basic_type_token30] = ACTIONS(4855),
    [aux_sym_basic_type_token31] = ACTIONS(4855),
    [aux_sym_basic_type_token32] = ACTIONS(4855),
    [aux_sym_basic_type_token33] = ACTIONS(4855),
    [aux_sym_basic_type_token34] = ACTIONS(4855),
    [aux_sym_basic_type_token35] = ACTIONS(4855),
    [aux_sym_basic_type_token36] = ACTIONS(4855),
    [aux_sym_basic_type_token37] = ACTIONS(4855),
    [aux_sym_basic_type_token38] = ACTIONS(4855),
    [aux_sym_basic_type_token39] = ACTIONS(4855),
    [aux_sym_basic_type_token40] = ACTIONS(4855),
    [aux_sym_basic_type_token41] = ACTIONS(4855),
    [aux_sym_basic_type_token42] = ACTIONS(4855),
    [aux_sym_basic_type_token43] = ACTIONS(4855),
    [aux_sym_basic_type_token44] = ACTIONS(4855),
    [aux_sym_basic_type_token45] = ACTIONS(4855),
    [aux_sym_basic_type_token46] = ACTIONS(4855),
    [aux_sym_basic_type_token47] = ACTIONS(4855),
    [aux_sym_basic_type_token48] = ACTIONS(4855),
    [aux_sym_basic_type_token49] = ACTIONS(4855),
    [aux_sym_basic_type_token50] = ACTIONS(4855),
    [aux_sym_basic_type_token51] = ACTIONS(4855),
    [aux_sym_basic_type_token52] = ACTIONS(4855),
    [aux_sym_basic_type_token53] = ACTIONS(4855),
    [aux_sym_basic_type_token54] = ACTIONS(4855),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4847),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4847),
    [sym_query_keyword] = ACTIONS(4847),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4847),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2110)] = {
    [sym_type_specification] = STATE(3093),
    [sym_text_type] = STATE(3087),
    [sym_code_type] = STATE(3087),
    [sym_option_type] = STATE(3071),
    [sym_record_type] = STATE(3071),
    [sym_dotnet_type] = STATE(3071),
    [sym_object_reference_type] = STATE(3071),
    [sym_array_type] = STATE(3130),
    [sym_list_type] = STATE(3130),
    [sym_dictionary_type] = STATE(3130),
    [sym_basic_type] = STATE(3071),
    [sym_codeunit_keyword] = STATE(11510),
    [sym_xmlport_keyword] = STATE(11510),
    [sym_enum_keyword] = STATE(11510),
    [sym_controladdin_keyword] = STATE(11510),
    [sym_dotnet_keyword] = STATE(11364),
    [sym_identifier] = ACTIONS(4837),
    [aux_sym_text_type_token1] = ACTIONS(4839),
    [aux_sym_code_type_token1] = ACTIONS(4841),
    [aux_sym_option_type_token1] = ACTIONS(4843),
    [aux_sym_record_type_token1] = ACTIONS(4845),
    [aux_sym_object_reference_type_token1] = ACTIONS(4847),
    [aux_sym_object_reference_type_token2] = ACTIONS(4847),
    [aux_sym_array_type_token1] = ACTIONS(4849),
    [aux_sym_list_type_token1] = ACTIONS(4851),
    [aux_sym_dictionary_type_token1] = ACTIONS(4853),
    [aux_sym_basic_type_token1] = ACTIONS(4855),
    [aux_sym_basic_type_token2] = ACTIONS(4855),
    [aux_sym_basic_type_token3] = ACTIONS(4855),
    [aux_sym_basic_type_token4] = ACTIONS(4855),
    [aux_sym_basic_type_token5] = ACTIONS(4855),
    [aux_sym_basic_type_token6] = ACTIONS(4857),
    [aux_sym_basic_type_token7] = ACTIONS(4855),
    [aux_sym_basic_type_token8] = ACTIONS(4855),
    [aux_sym_basic_type_token9] = ACTIONS(4855),
    [aux_sym_basic_type_token10] = ACTIONS(4855),
    [aux_sym_basic_type_token11] = ACTIONS(4855),
    [aux_sym_basic_type_token12] = ACTIONS(4855),
    [aux_sym_basic_type_token13] = ACTIONS(4859),
    [aux_sym_basic_type_token14] = ACTIONS(4855),
    [aux_sym_basic_type_token15] = ACTIONS(4855),
    [aux_sym_basic_type_token16] = ACTIONS(4855),
    [aux_sym_basic_type_token17] = ACTIONS(4855),
    [aux_sym_basic_type_token18] = ACTIONS(4855),
    [aux_sym_basic_type_token19] = ACTIONS(4855),
    [aux_sym_basic_type_token20] = ACTIONS(4855),
    [aux_sym_basic_type_token21] = ACTIONS(4855),
    [aux_sym_basic_type_token22] = ACTIONS(4855),
    [aux_sym_basic_type_token23] = ACTIONS(4855),
    [aux_sym_basic_type_token24] = ACTIONS(4855),
    [aux_sym_basic_type_token25] = ACTIONS(4855),
    [aux_sym_basic_type_token26] = ACTIONS(4855),
    [aux_sym_basic_type_token27] = ACTIONS(4855),
    [aux_sym_basic_type_token28] = ACTIONS(4855),
    [aux_sym_basic_type_token29] = ACTIONS(4855),
    [aux_sym_basic_type_token30] = ACTIONS(4855),
    [aux_sym_basic_type_token31] = ACTIONS(4855),
    [aux_sym_basic_type_token32] = ACTIONS(4855),
    [aux_sym_basic_type_token33] = ACTIONS(4855),
    [aux_sym_basic_type_token34] = ACTIONS(4855),
    [aux_sym_basic_type_token35] = ACTIONS(4855),
    [aux_sym_basic_type_token36] = ACTIONS(4855),
    [aux_sym_basic_type_token37] = ACTIONS(4855),
    [aux_sym_basic_type_token38] = ACTIONS(4855),
    [aux_sym_basic_type_token39] = ACTIONS(4855),
    [aux_sym_basic_type_token40] = ACTIONS(4855),
    [aux_sym_basic_type_token41] = ACTIONS(4855),
    [aux_sym_basic_type_token42] = ACTIONS(4855),
    [aux_sym_basic_type_token43] = ACTIONS(4855),
    [aux_sym_basic_type_token44] = ACTIONS(4855),
    [aux_sym_basic_type_token45] = ACTIONS(4855),
    [aux_sym_basic_type_token46] = ACTIONS(4855),
    [aux_sym_basic_type_token47] = ACTIONS(4855),
    [aux_sym_basic_type_token48] = ACTIONS(4855),
    [aux_sym_basic_type_token49] = ACTIONS(4855),
    [aux_sym_basic_type_token50] = ACTIONS(4855),
    [aux_sym_basic_type_token51] = ACTIONS(4855),
    [aux_sym_basic_type_token52] = ACTIONS(4855),
    [aux_sym_basic_type_token53] = ACTIONS(4855),
    [aux_sym_basic_type_token54] = ACTIONS(4855),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4847),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4847),
    [sym_query_keyword] = ACTIONS(4847),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4847),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2111)] = {
    [sym_type_specification] = STATE(7211),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11397),
    [sym_xmlport_keyword] = STATE(11397),
    [sym_enum_keyword] = STATE(11397),
    [sym_controladdin_keyword] = STATE(11397),
    [sym_dotnet_keyword] = STATE(11320),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(4869),
    [aux_sym_record_type_token1] = ACTIONS(4871),
    [aux_sym_object_reference_type_token1] = ACTIONS(4873),
    [aux_sym_object_reference_type_token2] = ACTIONS(4873),
    [aux_sym_array_type_token1] = ACTIONS(4875),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4873),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4873),
    [sym_query_keyword] = ACTIONS(4873),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4873),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2112)] = {
    [sym_type_specification] = STATE(7228),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11397),
    [sym_xmlport_keyword] = STATE(11397),
    [sym_enum_keyword] = STATE(11397),
    [sym_controladdin_keyword] = STATE(11397),
    [sym_dotnet_keyword] = STATE(11320),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(4869),
    [aux_sym_record_type_token1] = ACTIONS(4871),
    [aux_sym_object_reference_type_token1] = ACTIONS(4873),
    [aux_sym_object_reference_type_token2] = ACTIONS(4873),
    [aux_sym_array_type_token1] = ACTIONS(4875),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4873),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4873),
    [sym_query_keyword] = ACTIONS(4873),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4873),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2113)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10387),
    [sym_else_table_relation_fragment] = STATE(10387),
    [sym_table_relation_expression] = STATE(10387),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2679),
    [sym_preproc_endif] = STATE(11324),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10681),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(4895),
    [anon_sym_POUNDENDIF] = ACTIONS(4895),
    [anon_sym_POUNDEndif] = ACTIONS(4895),
    [anon_sym_POUNDendif2] = ACTIONS(4895),
    [anon_sym_POUNDENDIF2] = ACTIONS(4895),
    [anon_sym_POUNDEndif2] = ACTIONS(4895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4895),
  },
  [STATE(2114)] = {
    [sym_type_specification] = STATE(2055),
    [sym_text_type] = STATE(2079),
    [sym_code_type] = STATE(2079),
    [sym_option_type] = STATE(2078),
    [sym_record_type] = STATE(2078),
    [sym_dotnet_type] = STATE(2078),
    [sym_object_reference_type] = STATE(2078),
    [sym_array_type] = STATE(2084),
    [sym_list_type] = STATE(2084),
    [sym_dictionary_type] = STATE(2084),
    [sym_basic_type] = STATE(2078),
    [sym_codeunit_keyword] = STATE(11454),
    [sym_xmlport_keyword] = STATE(11454),
    [sym_enum_keyword] = STATE(11454),
    [sym_controladdin_keyword] = STATE(11454),
    [sym_dotnet_keyword] = STATE(11273),
    [sym_identifier] = ACTIONS(4897),
    [aux_sym_text_type_token1] = ACTIONS(4899),
    [aux_sym_code_type_token1] = ACTIONS(4901),
    [aux_sym_option_type_token1] = ACTIONS(4903),
    [aux_sym_record_type_token1] = ACTIONS(4905),
    [aux_sym_object_reference_type_token1] = ACTIONS(4907),
    [aux_sym_object_reference_type_token2] = ACTIONS(4907),
    [aux_sym_array_type_token1] = ACTIONS(4909),
    [aux_sym_list_type_token1] = ACTIONS(4911),
    [aux_sym_dictionary_type_token1] = ACTIONS(4913),
    [aux_sym_basic_type_token1] = ACTIONS(4915),
    [aux_sym_basic_type_token2] = ACTIONS(4915),
    [aux_sym_basic_type_token3] = ACTIONS(4915),
    [aux_sym_basic_type_token4] = ACTIONS(4915),
    [aux_sym_basic_type_token5] = ACTIONS(4915),
    [aux_sym_basic_type_token6] = ACTIONS(4917),
    [aux_sym_basic_type_token7] = ACTIONS(4915),
    [aux_sym_basic_type_token8] = ACTIONS(4915),
    [aux_sym_basic_type_token9] = ACTIONS(4915),
    [aux_sym_basic_type_token10] = ACTIONS(4915),
    [aux_sym_basic_type_token11] = ACTIONS(4915),
    [aux_sym_basic_type_token12] = ACTIONS(4915),
    [aux_sym_basic_type_token13] = ACTIONS(4919),
    [aux_sym_basic_type_token14] = ACTIONS(4915),
    [aux_sym_basic_type_token15] = ACTIONS(4915),
    [aux_sym_basic_type_token16] = ACTIONS(4915),
    [aux_sym_basic_type_token17] = ACTIONS(4915),
    [aux_sym_basic_type_token18] = ACTIONS(4915),
    [aux_sym_basic_type_token19] = ACTIONS(4915),
    [aux_sym_basic_type_token20] = ACTIONS(4915),
    [aux_sym_basic_type_token21] = ACTIONS(4915),
    [aux_sym_basic_type_token22] = ACTIONS(4915),
    [aux_sym_basic_type_token23] = ACTIONS(4915),
    [aux_sym_basic_type_token24] = ACTIONS(4915),
    [aux_sym_basic_type_token25] = ACTIONS(4915),
    [aux_sym_basic_type_token26] = ACTIONS(4915),
    [aux_sym_basic_type_token27] = ACTIONS(4915),
    [aux_sym_basic_type_token28] = ACTIONS(4915),
    [aux_sym_basic_type_token29] = ACTIONS(4915),
    [aux_sym_basic_type_token30] = ACTIONS(4915),
    [aux_sym_basic_type_token31] = ACTIONS(4915),
    [aux_sym_basic_type_token32] = ACTIONS(4915),
    [aux_sym_basic_type_token33] = ACTIONS(4915),
    [aux_sym_basic_type_token34] = ACTIONS(4915),
    [aux_sym_basic_type_token35] = ACTIONS(4915),
    [aux_sym_basic_type_token36] = ACTIONS(4915),
    [aux_sym_basic_type_token37] = ACTIONS(4915),
    [aux_sym_basic_type_token38] = ACTIONS(4915),
    [aux_sym_basic_type_token39] = ACTIONS(4915),
    [aux_sym_basic_type_token40] = ACTIONS(4915),
    [aux_sym_basic_type_token41] = ACTIONS(4915),
    [aux_sym_basic_type_token42] = ACTIONS(4915),
    [aux_sym_basic_type_token43] = ACTIONS(4915),
    [aux_sym_basic_type_token44] = ACTIONS(4915),
    [aux_sym_basic_type_token45] = ACTIONS(4915),
    [aux_sym_basic_type_token46] = ACTIONS(4915),
    [aux_sym_basic_type_token47] = ACTIONS(4915),
    [aux_sym_basic_type_token48] = ACTIONS(4915),
    [aux_sym_basic_type_token49] = ACTIONS(4915),
    [aux_sym_basic_type_token50] = ACTIONS(4915),
    [aux_sym_basic_type_token51] = ACTIONS(4915),
    [aux_sym_basic_type_token52] = ACTIONS(4915),
    [aux_sym_basic_type_token53] = ACTIONS(4915),
    [aux_sym_basic_type_token54] = ACTIONS(4915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4907),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4907),
    [sym_query_keyword] = ACTIONS(4907),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4907),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4921),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2115)] = {
    [sym_type_specification] = STATE(2073),
    [sym_text_type] = STATE(2079),
    [sym_code_type] = STATE(2079),
    [sym_option_type] = STATE(2078),
    [sym_record_type] = STATE(2078),
    [sym_dotnet_type] = STATE(2078),
    [sym_object_reference_type] = STATE(2078),
    [sym_array_type] = STATE(2084),
    [sym_list_type] = STATE(2084),
    [sym_dictionary_type] = STATE(2084),
    [sym_basic_type] = STATE(2078),
    [sym_codeunit_keyword] = STATE(11454),
    [sym_xmlport_keyword] = STATE(11454),
    [sym_enum_keyword] = STATE(11454),
    [sym_controladdin_keyword] = STATE(11454),
    [sym_dotnet_keyword] = STATE(11273),
    [sym_identifier] = ACTIONS(4897),
    [aux_sym_text_type_token1] = ACTIONS(4899),
    [aux_sym_code_type_token1] = ACTIONS(4901),
    [aux_sym_option_type_token1] = ACTIONS(4903),
    [aux_sym_record_type_token1] = ACTIONS(4905),
    [aux_sym_object_reference_type_token1] = ACTIONS(4907),
    [aux_sym_object_reference_type_token2] = ACTIONS(4907),
    [aux_sym_array_type_token1] = ACTIONS(4909),
    [aux_sym_list_type_token1] = ACTIONS(4911),
    [aux_sym_dictionary_type_token1] = ACTIONS(4913),
    [aux_sym_basic_type_token1] = ACTIONS(4915),
    [aux_sym_basic_type_token2] = ACTIONS(4915),
    [aux_sym_basic_type_token3] = ACTIONS(4915),
    [aux_sym_basic_type_token4] = ACTIONS(4915),
    [aux_sym_basic_type_token5] = ACTIONS(4915),
    [aux_sym_basic_type_token6] = ACTIONS(4917),
    [aux_sym_basic_type_token7] = ACTIONS(4915),
    [aux_sym_basic_type_token8] = ACTIONS(4915),
    [aux_sym_basic_type_token9] = ACTIONS(4915),
    [aux_sym_basic_type_token10] = ACTIONS(4915),
    [aux_sym_basic_type_token11] = ACTIONS(4915),
    [aux_sym_basic_type_token12] = ACTIONS(4915),
    [aux_sym_basic_type_token13] = ACTIONS(4919),
    [aux_sym_basic_type_token14] = ACTIONS(4915),
    [aux_sym_basic_type_token15] = ACTIONS(4915),
    [aux_sym_basic_type_token16] = ACTIONS(4915),
    [aux_sym_basic_type_token17] = ACTIONS(4915),
    [aux_sym_basic_type_token18] = ACTIONS(4915),
    [aux_sym_basic_type_token19] = ACTIONS(4915),
    [aux_sym_basic_type_token20] = ACTIONS(4915),
    [aux_sym_basic_type_token21] = ACTIONS(4915),
    [aux_sym_basic_type_token22] = ACTIONS(4915),
    [aux_sym_basic_type_token23] = ACTIONS(4915),
    [aux_sym_basic_type_token24] = ACTIONS(4915),
    [aux_sym_basic_type_token25] = ACTIONS(4915),
    [aux_sym_basic_type_token26] = ACTIONS(4915),
    [aux_sym_basic_type_token27] = ACTIONS(4915),
    [aux_sym_basic_type_token28] = ACTIONS(4915),
    [aux_sym_basic_type_token29] = ACTIONS(4915),
    [aux_sym_basic_type_token30] = ACTIONS(4915),
    [aux_sym_basic_type_token31] = ACTIONS(4915),
    [aux_sym_basic_type_token32] = ACTIONS(4915),
    [aux_sym_basic_type_token33] = ACTIONS(4915),
    [aux_sym_basic_type_token34] = ACTIONS(4915),
    [aux_sym_basic_type_token35] = ACTIONS(4915),
    [aux_sym_basic_type_token36] = ACTIONS(4915),
    [aux_sym_basic_type_token37] = ACTIONS(4915),
    [aux_sym_basic_type_token38] = ACTIONS(4915),
    [aux_sym_basic_type_token39] = ACTIONS(4915),
    [aux_sym_basic_type_token40] = ACTIONS(4915),
    [aux_sym_basic_type_token41] = ACTIONS(4915),
    [aux_sym_basic_type_token42] = ACTIONS(4915),
    [aux_sym_basic_type_token43] = ACTIONS(4915),
    [aux_sym_basic_type_token44] = ACTIONS(4915),
    [aux_sym_basic_type_token45] = ACTIONS(4915),
    [aux_sym_basic_type_token46] = ACTIONS(4915),
    [aux_sym_basic_type_token47] = ACTIONS(4915),
    [aux_sym_basic_type_token48] = ACTIONS(4915),
    [aux_sym_basic_type_token49] = ACTIONS(4915),
    [aux_sym_basic_type_token50] = ACTIONS(4915),
    [aux_sym_basic_type_token51] = ACTIONS(4915),
    [aux_sym_basic_type_token52] = ACTIONS(4915),
    [aux_sym_basic_type_token53] = ACTIONS(4915),
    [aux_sym_basic_type_token54] = ACTIONS(4915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4907),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4907),
    [sym_query_keyword] = ACTIONS(4907),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4907),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4921),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2116)] = {
    [sym_type_specification] = STATE(12498),
    [sym_text_type] = STATE(12502),
    [sym_code_type] = STATE(12502),
    [sym_option_type] = STATE(12493),
    [sym_record_type] = STATE(12493),
    [sym_dotnet_type] = STATE(12493),
    [sym_object_reference_type] = STATE(12493),
    [sym_array_type] = STATE(12489),
    [sym_list_type] = STATE(12489),
    [sym_dictionary_type] = STATE(12489),
    [sym_basic_type] = STATE(12493),
    [sym_codeunit_keyword] = STATE(11591),
    [sym_xmlport_keyword] = STATE(11591),
    [sym_enum_keyword] = STATE(11591),
    [sym_controladdin_keyword] = STATE(11591),
    [sym_dotnet_keyword] = STATE(11267),
    [sym_identifier] = ACTIONS(4923),
    [aux_sym_text_type_token1] = ACTIONS(4925),
    [aux_sym_code_type_token1] = ACTIONS(4927),
    [aux_sym_option_type_token1] = ACTIONS(4929),
    [aux_sym_record_type_token1] = ACTIONS(4931),
    [aux_sym_object_reference_type_token1] = ACTIONS(4933),
    [aux_sym_object_reference_type_token2] = ACTIONS(4933),
    [aux_sym_array_type_token1] = ACTIONS(4935),
    [aux_sym_list_type_token1] = ACTIONS(4937),
    [aux_sym_dictionary_type_token1] = ACTIONS(4939),
    [aux_sym_basic_type_token1] = ACTIONS(4941),
    [aux_sym_basic_type_token2] = ACTIONS(4941),
    [aux_sym_basic_type_token3] = ACTIONS(4941),
    [aux_sym_basic_type_token4] = ACTIONS(4941),
    [aux_sym_basic_type_token5] = ACTIONS(4941),
    [aux_sym_basic_type_token6] = ACTIONS(4943),
    [aux_sym_basic_type_token7] = ACTIONS(4941),
    [aux_sym_basic_type_token8] = ACTIONS(4941),
    [aux_sym_basic_type_token9] = ACTIONS(4941),
    [aux_sym_basic_type_token10] = ACTIONS(4941),
    [aux_sym_basic_type_token11] = ACTIONS(4941),
    [aux_sym_basic_type_token12] = ACTIONS(4941),
    [aux_sym_basic_type_token13] = ACTIONS(4945),
    [aux_sym_basic_type_token14] = ACTIONS(4941),
    [aux_sym_basic_type_token15] = ACTIONS(4941),
    [aux_sym_basic_type_token16] = ACTIONS(4941),
    [aux_sym_basic_type_token17] = ACTIONS(4941),
    [aux_sym_basic_type_token18] = ACTIONS(4941),
    [aux_sym_basic_type_token19] = ACTIONS(4941),
    [aux_sym_basic_type_token20] = ACTIONS(4941),
    [aux_sym_basic_type_token21] = ACTIONS(4941),
    [aux_sym_basic_type_token22] = ACTIONS(4941),
    [aux_sym_basic_type_token23] = ACTIONS(4941),
    [aux_sym_basic_type_token24] = ACTIONS(4941),
    [aux_sym_basic_type_token25] = ACTIONS(4941),
    [aux_sym_basic_type_token26] = ACTIONS(4941),
    [aux_sym_basic_type_token27] = ACTIONS(4941),
    [aux_sym_basic_type_token28] = ACTIONS(4941),
    [aux_sym_basic_type_token29] = ACTIONS(4941),
    [aux_sym_basic_type_token30] = ACTIONS(4941),
    [aux_sym_basic_type_token31] = ACTIONS(4941),
    [aux_sym_basic_type_token32] = ACTIONS(4941),
    [aux_sym_basic_type_token33] = ACTIONS(4941),
    [aux_sym_basic_type_token34] = ACTIONS(4941),
    [aux_sym_basic_type_token35] = ACTIONS(4941),
    [aux_sym_basic_type_token36] = ACTIONS(4941),
    [aux_sym_basic_type_token37] = ACTIONS(4941),
    [aux_sym_basic_type_token38] = ACTIONS(4941),
    [aux_sym_basic_type_token39] = ACTIONS(4941),
    [aux_sym_basic_type_token40] = ACTIONS(4941),
    [aux_sym_basic_type_token41] = ACTIONS(4941),
    [aux_sym_basic_type_token42] = ACTIONS(4941),
    [aux_sym_basic_type_token43] = ACTIONS(4941),
    [aux_sym_basic_type_token44] = ACTIONS(4941),
    [aux_sym_basic_type_token45] = ACTIONS(4941),
    [aux_sym_basic_type_token46] = ACTIONS(4941),
    [aux_sym_basic_type_token47] = ACTIONS(4941),
    [aux_sym_basic_type_token48] = ACTIONS(4941),
    [aux_sym_basic_type_token49] = ACTIONS(4941),
    [aux_sym_basic_type_token50] = ACTIONS(4941),
    [aux_sym_basic_type_token51] = ACTIONS(4941),
    [aux_sym_basic_type_token52] = ACTIONS(4941),
    [aux_sym_basic_type_token53] = ACTIONS(4941),
    [aux_sym_basic_type_token54] = ACTIONS(4941),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4933),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4933),
    [sym_query_keyword] = ACTIONS(4933),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4933),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2117)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10640),
    [sym_else_table_relation_fragment] = STATE(10640),
    [sym_table_relation_expression] = STATE(10640),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2698),
    [sym_preproc_endif] = STATE(5215),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(11017),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(2118)] = {
    [sym_type_specification] = STATE(1854),
    [sym_text_type] = STATE(1844),
    [sym_code_type] = STATE(1844),
    [sym_option_type] = STATE(1836),
    [sym_record_type] = STATE(1836),
    [sym_dotnet_type] = STATE(1836),
    [sym_object_reference_type] = STATE(1836),
    [sym_array_type] = STATE(1845),
    [sym_list_type] = STATE(1845),
    [sym_dictionary_type] = STATE(1845),
    [sym_basic_type] = STATE(1836),
    [sym_codeunit_keyword] = STATE(11561),
    [sym_xmlport_keyword] = STATE(11561),
    [sym_enum_keyword] = STATE(11561),
    [sym_controladdin_keyword] = STATE(11561),
    [sym_dotnet_keyword] = STATE(11341),
    [sym_identifier] = ACTIONS(4949),
    [aux_sym_text_type_token1] = ACTIONS(4951),
    [aux_sym_code_type_token1] = ACTIONS(4953),
    [aux_sym_option_type_token1] = ACTIONS(4955),
    [aux_sym_record_type_token1] = ACTIONS(4957),
    [aux_sym_object_reference_type_token1] = ACTIONS(4959),
    [aux_sym_object_reference_type_token2] = ACTIONS(4959),
    [aux_sym_array_type_token1] = ACTIONS(4961),
    [aux_sym_list_type_token1] = ACTIONS(4963),
    [aux_sym_dictionary_type_token1] = ACTIONS(4965),
    [aux_sym_basic_type_token1] = ACTIONS(4967),
    [aux_sym_basic_type_token2] = ACTIONS(4967),
    [aux_sym_basic_type_token3] = ACTIONS(4967),
    [aux_sym_basic_type_token4] = ACTIONS(4967),
    [aux_sym_basic_type_token5] = ACTIONS(4967),
    [aux_sym_basic_type_token6] = ACTIONS(4969),
    [aux_sym_basic_type_token7] = ACTIONS(4967),
    [aux_sym_basic_type_token8] = ACTIONS(4967),
    [aux_sym_basic_type_token9] = ACTIONS(4967),
    [aux_sym_basic_type_token10] = ACTIONS(4967),
    [aux_sym_basic_type_token11] = ACTIONS(4967),
    [aux_sym_basic_type_token12] = ACTIONS(4967),
    [aux_sym_basic_type_token13] = ACTIONS(4971),
    [aux_sym_basic_type_token14] = ACTIONS(4967),
    [aux_sym_basic_type_token15] = ACTIONS(4967),
    [aux_sym_basic_type_token16] = ACTIONS(4967),
    [aux_sym_basic_type_token17] = ACTIONS(4967),
    [aux_sym_basic_type_token18] = ACTIONS(4967),
    [aux_sym_basic_type_token19] = ACTIONS(4967),
    [aux_sym_basic_type_token20] = ACTIONS(4967),
    [aux_sym_basic_type_token21] = ACTIONS(4967),
    [aux_sym_basic_type_token22] = ACTIONS(4967),
    [aux_sym_basic_type_token23] = ACTIONS(4967),
    [aux_sym_basic_type_token24] = ACTIONS(4967),
    [aux_sym_basic_type_token25] = ACTIONS(4967),
    [aux_sym_basic_type_token26] = ACTIONS(4967),
    [aux_sym_basic_type_token27] = ACTIONS(4967),
    [aux_sym_basic_type_token28] = ACTIONS(4967),
    [aux_sym_basic_type_token29] = ACTIONS(4967),
    [aux_sym_basic_type_token30] = ACTIONS(4967),
    [aux_sym_basic_type_token31] = ACTIONS(4967),
    [aux_sym_basic_type_token32] = ACTIONS(4967),
    [aux_sym_basic_type_token33] = ACTIONS(4967),
    [aux_sym_basic_type_token34] = ACTIONS(4967),
    [aux_sym_basic_type_token35] = ACTIONS(4967),
    [aux_sym_basic_type_token36] = ACTIONS(4967),
    [aux_sym_basic_type_token37] = ACTIONS(4967),
    [aux_sym_basic_type_token38] = ACTIONS(4967),
    [aux_sym_basic_type_token39] = ACTIONS(4967),
    [aux_sym_basic_type_token40] = ACTIONS(4967),
    [aux_sym_basic_type_token41] = ACTIONS(4967),
    [aux_sym_basic_type_token42] = ACTIONS(4967),
    [aux_sym_basic_type_token43] = ACTIONS(4967),
    [aux_sym_basic_type_token44] = ACTIONS(4967),
    [aux_sym_basic_type_token45] = ACTIONS(4967),
    [aux_sym_basic_type_token46] = ACTIONS(4967),
    [aux_sym_basic_type_token47] = ACTIONS(4967),
    [aux_sym_basic_type_token48] = ACTIONS(4967),
    [aux_sym_basic_type_token49] = ACTIONS(4967),
    [aux_sym_basic_type_token50] = ACTIONS(4967),
    [aux_sym_basic_type_token51] = ACTIONS(4967),
    [aux_sym_basic_type_token52] = ACTIONS(4967),
    [aux_sym_basic_type_token53] = ACTIONS(4967),
    [aux_sym_basic_type_token54] = ACTIONS(4967),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4959),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4959),
    [sym_query_keyword] = ACTIONS(4959),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4959),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4973),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2119)] = {
    [sym_type_specification] = STATE(1840),
    [sym_text_type] = STATE(1844),
    [sym_code_type] = STATE(1844),
    [sym_option_type] = STATE(1836),
    [sym_record_type] = STATE(1836),
    [sym_dotnet_type] = STATE(1836),
    [sym_object_reference_type] = STATE(1836),
    [sym_array_type] = STATE(1845),
    [sym_list_type] = STATE(1845),
    [sym_dictionary_type] = STATE(1845),
    [sym_basic_type] = STATE(1836),
    [sym_codeunit_keyword] = STATE(11561),
    [sym_xmlport_keyword] = STATE(11561),
    [sym_enum_keyword] = STATE(11561),
    [sym_controladdin_keyword] = STATE(11561),
    [sym_dotnet_keyword] = STATE(11341),
    [sym_identifier] = ACTIONS(4949),
    [aux_sym_text_type_token1] = ACTIONS(4951),
    [aux_sym_code_type_token1] = ACTIONS(4953),
    [aux_sym_option_type_token1] = ACTIONS(4955),
    [aux_sym_record_type_token1] = ACTIONS(4957),
    [aux_sym_object_reference_type_token1] = ACTIONS(4959),
    [aux_sym_object_reference_type_token2] = ACTIONS(4959),
    [aux_sym_array_type_token1] = ACTIONS(4961),
    [aux_sym_list_type_token1] = ACTIONS(4963),
    [aux_sym_dictionary_type_token1] = ACTIONS(4965),
    [aux_sym_basic_type_token1] = ACTIONS(4967),
    [aux_sym_basic_type_token2] = ACTIONS(4967),
    [aux_sym_basic_type_token3] = ACTIONS(4967),
    [aux_sym_basic_type_token4] = ACTIONS(4967),
    [aux_sym_basic_type_token5] = ACTIONS(4967),
    [aux_sym_basic_type_token6] = ACTIONS(4969),
    [aux_sym_basic_type_token7] = ACTIONS(4967),
    [aux_sym_basic_type_token8] = ACTIONS(4967),
    [aux_sym_basic_type_token9] = ACTIONS(4967),
    [aux_sym_basic_type_token10] = ACTIONS(4967),
    [aux_sym_basic_type_token11] = ACTIONS(4967),
    [aux_sym_basic_type_token12] = ACTIONS(4967),
    [aux_sym_basic_type_token13] = ACTIONS(4971),
    [aux_sym_basic_type_token14] = ACTIONS(4967),
    [aux_sym_basic_type_token15] = ACTIONS(4967),
    [aux_sym_basic_type_token16] = ACTIONS(4967),
    [aux_sym_basic_type_token17] = ACTIONS(4967),
    [aux_sym_basic_type_token18] = ACTIONS(4967),
    [aux_sym_basic_type_token19] = ACTIONS(4967),
    [aux_sym_basic_type_token20] = ACTIONS(4967),
    [aux_sym_basic_type_token21] = ACTIONS(4967),
    [aux_sym_basic_type_token22] = ACTIONS(4967),
    [aux_sym_basic_type_token23] = ACTIONS(4967),
    [aux_sym_basic_type_token24] = ACTIONS(4967),
    [aux_sym_basic_type_token25] = ACTIONS(4967),
    [aux_sym_basic_type_token26] = ACTIONS(4967),
    [aux_sym_basic_type_token27] = ACTIONS(4967),
    [aux_sym_basic_type_token28] = ACTIONS(4967),
    [aux_sym_basic_type_token29] = ACTIONS(4967),
    [aux_sym_basic_type_token30] = ACTIONS(4967),
    [aux_sym_basic_type_token31] = ACTIONS(4967),
    [aux_sym_basic_type_token32] = ACTIONS(4967),
    [aux_sym_basic_type_token33] = ACTIONS(4967),
    [aux_sym_basic_type_token34] = ACTIONS(4967),
    [aux_sym_basic_type_token35] = ACTIONS(4967),
    [aux_sym_basic_type_token36] = ACTIONS(4967),
    [aux_sym_basic_type_token37] = ACTIONS(4967),
    [aux_sym_basic_type_token38] = ACTIONS(4967),
    [aux_sym_basic_type_token39] = ACTIONS(4967),
    [aux_sym_basic_type_token40] = ACTIONS(4967),
    [aux_sym_basic_type_token41] = ACTIONS(4967),
    [aux_sym_basic_type_token42] = ACTIONS(4967),
    [aux_sym_basic_type_token43] = ACTIONS(4967),
    [aux_sym_basic_type_token44] = ACTIONS(4967),
    [aux_sym_basic_type_token45] = ACTIONS(4967),
    [aux_sym_basic_type_token46] = ACTIONS(4967),
    [aux_sym_basic_type_token47] = ACTIONS(4967),
    [aux_sym_basic_type_token48] = ACTIONS(4967),
    [aux_sym_basic_type_token49] = ACTIONS(4967),
    [aux_sym_basic_type_token50] = ACTIONS(4967),
    [aux_sym_basic_type_token51] = ACTIONS(4967),
    [aux_sym_basic_type_token52] = ACTIONS(4967),
    [aux_sym_basic_type_token53] = ACTIONS(4967),
    [aux_sym_basic_type_token54] = ACTIONS(4967),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4959),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4959),
    [sym_query_keyword] = ACTIONS(4959),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4959),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4973),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2120)] = {
    [sym_type_specification] = STATE(10075),
    [sym_text_type] = STATE(10057),
    [sym_code_type] = STATE(10057),
    [sym_option_type] = STATE(10053),
    [sym_record_type] = STATE(10053),
    [sym_dotnet_type] = STATE(10053),
    [sym_object_reference_type] = STATE(10053),
    [sym_array_type] = STATE(10058),
    [sym_list_type] = STATE(10058),
    [sym_dictionary_type] = STATE(10058),
    [sym_basic_type] = STATE(10053),
    [sym_codeunit_keyword] = STATE(11439),
    [sym_xmlport_keyword] = STATE(11439),
    [sym_enum_keyword] = STATE(11439),
    [sym_controladdin_keyword] = STATE(11439),
    [sym_dotnet_keyword] = STATE(11275),
    [sym_identifier] = ACTIONS(4975),
    [aux_sym_text_type_token1] = ACTIONS(4977),
    [aux_sym_code_type_token1] = ACTIONS(4979),
    [aux_sym_option_type_token1] = ACTIONS(4981),
    [aux_sym_record_type_token1] = ACTIONS(4983),
    [aux_sym_object_reference_type_token1] = ACTIONS(4985),
    [aux_sym_object_reference_type_token2] = ACTIONS(4985),
    [aux_sym_array_type_token1] = ACTIONS(4987),
    [aux_sym_list_type_token1] = ACTIONS(4989),
    [aux_sym_dictionary_type_token1] = ACTIONS(4991),
    [aux_sym_basic_type_token1] = ACTIONS(4993),
    [aux_sym_basic_type_token2] = ACTIONS(4993),
    [aux_sym_basic_type_token3] = ACTIONS(4993),
    [aux_sym_basic_type_token4] = ACTIONS(4993),
    [aux_sym_basic_type_token5] = ACTIONS(4993),
    [aux_sym_basic_type_token6] = ACTIONS(4995),
    [aux_sym_basic_type_token7] = ACTIONS(4993),
    [aux_sym_basic_type_token8] = ACTIONS(4993),
    [aux_sym_basic_type_token9] = ACTIONS(4993),
    [aux_sym_basic_type_token10] = ACTIONS(4993),
    [aux_sym_basic_type_token11] = ACTIONS(4993),
    [aux_sym_basic_type_token12] = ACTIONS(4993),
    [aux_sym_basic_type_token13] = ACTIONS(4997),
    [aux_sym_basic_type_token14] = ACTIONS(4993),
    [aux_sym_basic_type_token15] = ACTIONS(4993),
    [aux_sym_basic_type_token16] = ACTIONS(4993),
    [aux_sym_basic_type_token17] = ACTIONS(4993),
    [aux_sym_basic_type_token18] = ACTIONS(4993),
    [aux_sym_basic_type_token19] = ACTIONS(4993),
    [aux_sym_basic_type_token20] = ACTIONS(4993),
    [aux_sym_basic_type_token21] = ACTIONS(4993),
    [aux_sym_basic_type_token22] = ACTIONS(4993),
    [aux_sym_basic_type_token23] = ACTIONS(4993),
    [aux_sym_basic_type_token24] = ACTIONS(4993),
    [aux_sym_basic_type_token25] = ACTIONS(4993),
    [aux_sym_basic_type_token26] = ACTIONS(4993),
    [aux_sym_basic_type_token27] = ACTIONS(4993),
    [aux_sym_basic_type_token28] = ACTIONS(4993),
    [aux_sym_basic_type_token29] = ACTIONS(4993),
    [aux_sym_basic_type_token30] = ACTIONS(4993),
    [aux_sym_basic_type_token31] = ACTIONS(4993),
    [aux_sym_basic_type_token32] = ACTIONS(4993),
    [aux_sym_basic_type_token33] = ACTIONS(4993),
    [aux_sym_basic_type_token34] = ACTIONS(4993),
    [aux_sym_basic_type_token35] = ACTIONS(4993),
    [aux_sym_basic_type_token36] = ACTIONS(4993),
    [aux_sym_basic_type_token37] = ACTIONS(4993),
    [aux_sym_basic_type_token38] = ACTIONS(4993),
    [aux_sym_basic_type_token39] = ACTIONS(4993),
    [aux_sym_basic_type_token40] = ACTIONS(4993),
    [aux_sym_basic_type_token41] = ACTIONS(4993),
    [aux_sym_basic_type_token42] = ACTIONS(4993),
    [aux_sym_basic_type_token43] = ACTIONS(4993),
    [aux_sym_basic_type_token44] = ACTIONS(4993),
    [aux_sym_basic_type_token45] = ACTIONS(4993),
    [aux_sym_basic_type_token46] = ACTIONS(4993),
    [aux_sym_basic_type_token47] = ACTIONS(4993),
    [aux_sym_basic_type_token48] = ACTIONS(4993),
    [aux_sym_basic_type_token49] = ACTIONS(4993),
    [aux_sym_basic_type_token50] = ACTIONS(4993),
    [aux_sym_basic_type_token51] = ACTIONS(4993),
    [aux_sym_basic_type_token52] = ACTIONS(4993),
    [aux_sym_basic_type_token53] = ACTIONS(4993),
    [aux_sym_basic_type_token54] = ACTIONS(4993),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4985),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4985),
    [sym_query_keyword] = ACTIONS(4985),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4985),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2121)] = {
    [sym_type_specification] = STATE(16533),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2122)] = {
    [sym_type_specification] = STATE(17508),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2123)] = {
    [sym_type_specification] = STATE(16665),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2124)] = {
    [sym_type_specification] = STATE(16738),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2125)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10535),
    [sym_else_table_relation_fragment] = STATE(10535),
    [sym_table_relation_expression] = STATE(10535),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2696),
    [sym_preproc_endif] = STATE(6860),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10882),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(2126)] = {
    [sym_type_specification] = STATE(2015),
    [sym_text_type] = STATE(1947),
    [sym_code_type] = STATE(1947),
    [sym_option_type] = STATE(1945),
    [sym_record_type] = STATE(1945),
    [sym_dotnet_type] = STATE(1945),
    [sym_object_reference_type] = STATE(1945),
    [sym_array_type] = STATE(1957),
    [sym_list_type] = STATE(1957),
    [sym_dictionary_type] = STATE(1957),
    [sym_basic_type] = STATE(1945),
    [sym_codeunit_keyword] = STATE(11489),
    [sym_xmlport_keyword] = STATE(11489),
    [sym_enum_keyword] = STATE(11489),
    [sym_controladdin_keyword] = STATE(11489),
    [sym_dotnet_keyword] = STATE(11269),
    [sym_identifier] = ACTIONS(5011),
    [aux_sym_text_type_token1] = ACTIONS(5013),
    [aux_sym_code_type_token1] = ACTIONS(5015),
    [aux_sym_option_type_token1] = ACTIONS(5017),
    [aux_sym_record_type_token1] = ACTIONS(5019),
    [aux_sym_object_reference_type_token1] = ACTIONS(5021),
    [aux_sym_object_reference_type_token2] = ACTIONS(5021),
    [aux_sym_array_type_token1] = ACTIONS(5023),
    [aux_sym_list_type_token1] = ACTIONS(5025),
    [aux_sym_dictionary_type_token1] = ACTIONS(5027),
    [aux_sym_basic_type_token1] = ACTIONS(5029),
    [aux_sym_basic_type_token2] = ACTIONS(5029),
    [aux_sym_basic_type_token3] = ACTIONS(5029),
    [aux_sym_basic_type_token4] = ACTIONS(5029),
    [aux_sym_basic_type_token5] = ACTIONS(5029),
    [aux_sym_basic_type_token6] = ACTIONS(5031),
    [aux_sym_basic_type_token7] = ACTIONS(5029),
    [aux_sym_basic_type_token8] = ACTIONS(5029),
    [aux_sym_basic_type_token9] = ACTIONS(5029),
    [aux_sym_basic_type_token10] = ACTIONS(5029),
    [aux_sym_basic_type_token11] = ACTIONS(5029),
    [aux_sym_basic_type_token12] = ACTIONS(5029),
    [aux_sym_basic_type_token13] = ACTIONS(5033),
    [aux_sym_basic_type_token14] = ACTIONS(5029),
    [aux_sym_basic_type_token15] = ACTIONS(5029),
    [aux_sym_basic_type_token16] = ACTIONS(5029),
    [aux_sym_basic_type_token17] = ACTIONS(5029),
    [aux_sym_basic_type_token18] = ACTIONS(5029),
    [aux_sym_basic_type_token19] = ACTIONS(5029),
    [aux_sym_basic_type_token20] = ACTIONS(5029),
    [aux_sym_basic_type_token21] = ACTIONS(5029),
    [aux_sym_basic_type_token22] = ACTIONS(5029),
    [aux_sym_basic_type_token23] = ACTIONS(5029),
    [aux_sym_basic_type_token24] = ACTIONS(5029),
    [aux_sym_basic_type_token25] = ACTIONS(5029),
    [aux_sym_basic_type_token26] = ACTIONS(5029),
    [aux_sym_basic_type_token27] = ACTIONS(5029),
    [aux_sym_basic_type_token28] = ACTIONS(5029),
    [aux_sym_basic_type_token29] = ACTIONS(5029),
    [aux_sym_basic_type_token30] = ACTIONS(5029),
    [aux_sym_basic_type_token31] = ACTIONS(5029),
    [aux_sym_basic_type_token32] = ACTIONS(5029),
    [aux_sym_basic_type_token33] = ACTIONS(5029),
    [aux_sym_basic_type_token34] = ACTIONS(5029),
    [aux_sym_basic_type_token35] = ACTIONS(5029),
    [aux_sym_basic_type_token36] = ACTIONS(5029),
    [aux_sym_basic_type_token37] = ACTIONS(5029),
    [aux_sym_basic_type_token38] = ACTIONS(5029),
    [aux_sym_basic_type_token39] = ACTIONS(5029),
    [aux_sym_basic_type_token40] = ACTIONS(5029),
    [aux_sym_basic_type_token41] = ACTIONS(5029),
    [aux_sym_basic_type_token42] = ACTIONS(5029),
    [aux_sym_basic_type_token43] = ACTIONS(5029),
    [aux_sym_basic_type_token44] = ACTIONS(5029),
    [aux_sym_basic_type_token45] = ACTIONS(5029),
    [aux_sym_basic_type_token46] = ACTIONS(5029),
    [aux_sym_basic_type_token47] = ACTIONS(5029),
    [aux_sym_basic_type_token48] = ACTIONS(5029),
    [aux_sym_basic_type_token49] = ACTIONS(5029),
    [aux_sym_basic_type_token50] = ACTIONS(5029),
    [aux_sym_basic_type_token51] = ACTIONS(5029),
    [aux_sym_basic_type_token52] = ACTIONS(5029),
    [aux_sym_basic_type_token53] = ACTIONS(5029),
    [aux_sym_basic_type_token54] = ACTIONS(5029),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5021),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5021),
    [sym_query_keyword] = ACTIONS(5021),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5021),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5035),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2127)] = {
    [sym_type_specification] = STATE(2017),
    [sym_text_type] = STATE(1947),
    [sym_code_type] = STATE(1947),
    [sym_option_type] = STATE(1945),
    [sym_record_type] = STATE(1945),
    [sym_dotnet_type] = STATE(1945),
    [sym_object_reference_type] = STATE(1945),
    [sym_array_type] = STATE(1957),
    [sym_list_type] = STATE(1957),
    [sym_dictionary_type] = STATE(1957),
    [sym_basic_type] = STATE(1945),
    [sym_codeunit_keyword] = STATE(11489),
    [sym_xmlport_keyword] = STATE(11489),
    [sym_enum_keyword] = STATE(11489),
    [sym_controladdin_keyword] = STATE(11489),
    [sym_dotnet_keyword] = STATE(11269),
    [sym_identifier] = ACTIONS(5011),
    [aux_sym_text_type_token1] = ACTIONS(5013),
    [aux_sym_code_type_token1] = ACTIONS(5015),
    [aux_sym_option_type_token1] = ACTIONS(5017),
    [aux_sym_record_type_token1] = ACTIONS(5019),
    [aux_sym_object_reference_type_token1] = ACTIONS(5021),
    [aux_sym_object_reference_type_token2] = ACTIONS(5021),
    [aux_sym_array_type_token1] = ACTIONS(5023),
    [aux_sym_list_type_token1] = ACTIONS(5025),
    [aux_sym_dictionary_type_token1] = ACTIONS(5027),
    [aux_sym_basic_type_token1] = ACTIONS(5029),
    [aux_sym_basic_type_token2] = ACTIONS(5029),
    [aux_sym_basic_type_token3] = ACTIONS(5029),
    [aux_sym_basic_type_token4] = ACTIONS(5029),
    [aux_sym_basic_type_token5] = ACTIONS(5029),
    [aux_sym_basic_type_token6] = ACTIONS(5031),
    [aux_sym_basic_type_token7] = ACTIONS(5029),
    [aux_sym_basic_type_token8] = ACTIONS(5029),
    [aux_sym_basic_type_token9] = ACTIONS(5029),
    [aux_sym_basic_type_token10] = ACTIONS(5029),
    [aux_sym_basic_type_token11] = ACTIONS(5029),
    [aux_sym_basic_type_token12] = ACTIONS(5029),
    [aux_sym_basic_type_token13] = ACTIONS(5033),
    [aux_sym_basic_type_token14] = ACTIONS(5029),
    [aux_sym_basic_type_token15] = ACTIONS(5029),
    [aux_sym_basic_type_token16] = ACTIONS(5029),
    [aux_sym_basic_type_token17] = ACTIONS(5029),
    [aux_sym_basic_type_token18] = ACTIONS(5029),
    [aux_sym_basic_type_token19] = ACTIONS(5029),
    [aux_sym_basic_type_token20] = ACTIONS(5029),
    [aux_sym_basic_type_token21] = ACTIONS(5029),
    [aux_sym_basic_type_token22] = ACTIONS(5029),
    [aux_sym_basic_type_token23] = ACTIONS(5029),
    [aux_sym_basic_type_token24] = ACTIONS(5029),
    [aux_sym_basic_type_token25] = ACTIONS(5029),
    [aux_sym_basic_type_token26] = ACTIONS(5029),
    [aux_sym_basic_type_token27] = ACTIONS(5029),
    [aux_sym_basic_type_token28] = ACTIONS(5029),
    [aux_sym_basic_type_token29] = ACTIONS(5029),
    [aux_sym_basic_type_token30] = ACTIONS(5029),
    [aux_sym_basic_type_token31] = ACTIONS(5029),
    [aux_sym_basic_type_token32] = ACTIONS(5029),
    [aux_sym_basic_type_token33] = ACTIONS(5029),
    [aux_sym_basic_type_token34] = ACTIONS(5029),
    [aux_sym_basic_type_token35] = ACTIONS(5029),
    [aux_sym_basic_type_token36] = ACTIONS(5029),
    [aux_sym_basic_type_token37] = ACTIONS(5029),
    [aux_sym_basic_type_token38] = ACTIONS(5029),
    [aux_sym_basic_type_token39] = ACTIONS(5029),
    [aux_sym_basic_type_token40] = ACTIONS(5029),
    [aux_sym_basic_type_token41] = ACTIONS(5029),
    [aux_sym_basic_type_token42] = ACTIONS(5029),
    [aux_sym_basic_type_token43] = ACTIONS(5029),
    [aux_sym_basic_type_token44] = ACTIONS(5029),
    [aux_sym_basic_type_token45] = ACTIONS(5029),
    [aux_sym_basic_type_token46] = ACTIONS(5029),
    [aux_sym_basic_type_token47] = ACTIONS(5029),
    [aux_sym_basic_type_token48] = ACTIONS(5029),
    [aux_sym_basic_type_token49] = ACTIONS(5029),
    [aux_sym_basic_type_token50] = ACTIONS(5029),
    [aux_sym_basic_type_token51] = ACTIONS(5029),
    [aux_sym_basic_type_token52] = ACTIONS(5029),
    [aux_sym_basic_type_token53] = ACTIONS(5029),
    [aux_sym_basic_type_token54] = ACTIONS(5029),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5021),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5021),
    [sym_query_keyword] = ACTIONS(5021),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5021),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5035),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2128)] = {
    [sym_type_specification] = STATE(8114),
    [sym_text_type] = STATE(8133),
    [sym_code_type] = STATE(8133),
    [sym_option_type] = STATE(8132),
    [sym_record_type] = STATE(8132),
    [sym_dotnet_type] = STATE(8132),
    [sym_object_reference_type] = STATE(8132),
    [sym_array_type] = STATE(8113),
    [sym_list_type] = STATE(8113),
    [sym_dictionary_type] = STATE(8113),
    [sym_basic_type] = STATE(8132),
    [sym_codeunit_keyword] = STATE(11424),
    [sym_xmlport_keyword] = STATE(11424),
    [sym_enum_keyword] = STATE(11424),
    [sym_controladdin_keyword] = STATE(11424),
    [sym_dotnet_keyword] = STATE(11298),
    [sym_identifier] = ACTIONS(5037),
    [aux_sym_text_type_token1] = ACTIONS(5039),
    [aux_sym_code_type_token1] = ACTIONS(5041),
    [aux_sym_option_type_token1] = ACTIONS(5043),
    [aux_sym_record_type_token1] = ACTIONS(5045),
    [aux_sym_object_reference_type_token1] = ACTIONS(5047),
    [aux_sym_object_reference_type_token2] = ACTIONS(5047),
    [aux_sym_array_type_token1] = ACTIONS(5049),
    [aux_sym_list_type_token1] = ACTIONS(5051),
    [aux_sym_dictionary_type_token1] = ACTIONS(5053),
    [aux_sym_basic_type_token1] = ACTIONS(5055),
    [aux_sym_basic_type_token2] = ACTIONS(5055),
    [aux_sym_basic_type_token3] = ACTIONS(5055),
    [aux_sym_basic_type_token4] = ACTIONS(5055),
    [aux_sym_basic_type_token5] = ACTIONS(5055),
    [aux_sym_basic_type_token6] = ACTIONS(5057),
    [aux_sym_basic_type_token7] = ACTIONS(5055),
    [aux_sym_basic_type_token8] = ACTIONS(5055),
    [aux_sym_basic_type_token9] = ACTIONS(5055),
    [aux_sym_basic_type_token10] = ACTIONS(5055),
    [aux_sym_basic_type_token11] = ACTIONS(5055),
    [aux_sym_basic_type_token12] = ACTIONS(5055),
    [aux_sym_basic_type_token13] = ACTIONS(5059),
    [aux_sym_basic_type_token14] = ACTIONS(5055),
    [aux_sym_basic_type_token15] = ACTIONS(5055),
    [aux_sym_basic_type_token16] = ACTIONS(5055),
    [aux_sym_basic_type_token17] = ACTIONS(5055),
    [aux_sym_basic_type_token18] = ACTIONS(5055),
    [aux_sym_basic_type_token19] = ACTIONS(5055),
    [aux_sym_basic_type_token20] = ACTIONS(5055),
    [aux_sym_basic_type_token21] = ACTIONS(5055),
    [aux_sym_basic_type_token22] = ACTIONS(5055),
    [aux_sym_basic_type_token23] = ACTIONS(5055),
    [aux_sym_basic_type_token24] = ACTIONS(5055),
    [aux_sym_basic_type_token25] = ACTIONS(5055),
    [aux_sym_basic_type_token26] = ACTIONS(5055),
    [aux_sym_basic_type_token27] = ACTIONS(5055),
    [aux_sym_basic_type_token28] = ACTIONS(5055),
    [aux_sym_basic_type_token29] = ACTIONS(5055),
    [aux_sym_basic_type_token30] = ACTIONS(5055),
    [aux_sym_basic_type_token31] = ACTIONS(5055),
    [aux_sym_basic_type_token32] = ACTIONS(5055),
    [aux_sym_basic_type_token33] = ACTIONS(5055),
    [aux_sym_basic_type_token34] = ACTIONS(5055),
    [aux_sym_basic_type_token35] = ACTIONS(5055),
    [aux_sym_basic_type_token36] = ACTIONS(5055),
    [aux_sym_basic_type_token37] = ACTIONS(5055),
    [aux_sym_basic_type_token38] = ACTIONS(5055),
    [aux_sym_basic_type_token39] = ACTIONS(5055),
    [aux_sym_basic_type_token40] = ACTIONS(5055),
    [aux_sym_basic_type_token41] = ACTIONS(5055),
    [aux_sym_basic_type_token42] = ACTIONS(5055),
    [aux_sym_basic_type_token43] = ACTIONS(5055),
    [aux_sym_basic_type_token44] = ACTIONS(5055),
    [aux_sym_basic_type_token45] = ACTIONS(5055),
    [aux_sym_basic_type_token46] = ACTIONS(5055),
    [aux_sym_basic_type_token47] = ACTIONS(5055),
    [aux_sym_basic_type_token48] = ACTIONS(5055),
    [aux_sym_basic_type_token49] = ACTIONS(5055),
    [aux_sym_basic_type_token50] = ACTIONS(5055),
    [aux_sym_basic_type_token51] = ACTIONS(5055),
    [aux_sym_basic_type_token52] = ACTIONS(5055),
    [aux_sym_basic_type_token53] = ACTIONS(5055),
    [aux_sym_basic_type_token54] = ACTIONS(5055),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5047),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5047),
    [sym_query_keyword] = ACTIONS(5047),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5047),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2129)] = {
    [sym_type_specification] = STATE(7211),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5063),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5065),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2130)] = {
    [sym_type_specification] = STATE(7228),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5063),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5065),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2131)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10418),
    [sym_else_table_relation_fragment] = STATE(10418),
    [sym_table_relation_expression] = STATE(10418),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2659),
    [sym_preproc_endif] = STATE(17261),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10729),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(2132)] = {
    [sym_type_specification] = STATE(8452),
    [sym_text_type] = STATE(8385),
    [sym_code_type] = STATE(8385),
    [sym_option_type] = STATE(8381),
    [sym_record_type] = STATE(8381),
    [sym_dotnet_type] = STATE(8381),
    [sym_object_reference_type] = STATE(8381),
    [sym_array_type] = STATE(8388),
    [sym_list_type] = STATE(8388),
    [sym_dictionary_type] = STATE(8388),
    [sym_basic_type] = STATE(8381),
    [sym_codeunit_keyword] = STATE(11394),
    [sym_xmlport_keyword] = STATE(11394),
    [sym_enum_keyword] = STATE(11394),
    [sym_controladdin_keyword] = STATE(11394),
    [sym_dotnet_keyword] = STATE(11271),
    [sym_identifier] = ACTIONS(5067),
    [aux_sym_text_type_token1] = ACTIONS(5069),
    [aux_sym_code_type_token1] = ACTIONS(5071),
    [aux_sym_option_type_token1] = ACTIONS(5073),
    [aux_sym_record_type_token1] = ACTIONS(5075),
    [aux_sym_object_reference_type_token1] = ACTIONS(5077),
    [aux_sym_object_reference_type_token2] = ACTIONS(5077),
    [aux_sym_array_type_token1] = ACTIONS(5079),
    [aux_sym_list_type_token1] = ACTIONS(5081),
    [aux_sym_dictionary_type_token1] = ACTIONS(5083),
    [aux_sym_basic_type_token1] = ACTIONS(5085),
    [aux_sym_basic_type_token2] = ACTIONS(5085),
    [aux_sym_basic_type_token3] = ACTIONS(5085),
    [aux_sym_basic_type_token4] = ACTIONS(5085),
    [aux_sym_basic_type_token5] = ACTIONS(5085),
    [aux_sym_basic_type_token6] = ACTIONS(5087),
    [aux_sym_basic_type_token7] = ACTIONS(5085),
    [aux_sym_basic_type_token8] = ACTIONS(5085),
    [aux_sym_basic_type_token9] = ACTIONS(5085),
    [aux_sym_basic_type_token10] = ACTIONS(5085),
    [aux_sym_basic_type_token11] = ACTIONS(5085),
    [aux_sym_basic_type_token12] = ACTIONS(5085),
    [aux_sym_basic_type_token13] = ACTIONS(5089),
    [aux_sym_basic_type_token14] = ACTIONS(5085),
    [aux_sym_basic_type_token15] = ACTIONS(5085),
    [aux_sym_basic_type_token16] = ACTIONS(5085),
    [aux_sym_basic_type_token17] = ACTIONS(5085),
    [aux_sym_basic_type_token18] = ACTIONS(5085),
    [aux_sym_basic_type_token19] = ACTIONS(5085),
    [aux_sym_basic_type_token20] = ACTIONS(5085),
    [aux_sym_basic_type_token21] = ACTIONS(5085),
    [aux_sym_basic_type_token22] = ACTIONS(5085),
    [aux_sym_basic_type_token23] = ACTIONS(5085),
    [aux_sym_basic_type_token24] = ACTIONS(5085),
    [aux_sym_basic_type_token25] = ACTIONS(5085),
    [aux_sym_basic_type_token26] = ACTIONS(5085),
    [aux_sym_basic_type_token27] = ACTIONS(5085),
    [aux_sym_basic_type_token28] = ACTIONS(5085),
    [aux_sym_basic_type_token29] = ACTIONS(5085),
    [aux_sym_basic_type_token30] = ACTIONS(5085),
    [aux_sym_basic_type_token31] = ACTIONS(5085),
    [aux_sym_basic_type_token32] = ACTIONS(5085),
    [aux_sym_basic_type_token33] = ACTIONS(5085),
    [aux_sym_basic_type_token34] = ACTIONS(5085),
    [aux_sym_basic_type_token35] = ACTIONS(5085),
    [aux_sym_basic_type_token36] = ACTIONS(5085),
    [aux_sym_basic_type_token37] = ACTIONS(5085),
    [aux_sym_basic_type_token38] = ACTIONS(5085),
    [aux_sym_basic_type_token39] = ACTIONS(5085),
    [aux_sym_basic_type_token40] = ACTIONS(5085),
    [aux_sym_basic_type_token41] = ACTIONS(5085),
    [aux_sym_basic_type_token42] = ACTIONS(5085),
    [aux_sym_basic_type_token43] = ACTIONS(5085),
    [aux_sym_basic_type_token44] = ACTIONS(5085),
    [aux_sym_basic_type_token45] = ACTIONS(5085),
    [aux_sym_basic_type_token46] = ACTIONS(5085),
    [aux_sym_basic_type_token47] = ACTIONS(5085),
    [aux_sym_basic_type_token48] = ACTIONS(5085),
    [aux_sym_basic_type_token49] = ACTIONS(5085),
    [aux_sym_basic_type_token50] = ACTIONS(5085),
    [aux_sym_basic_type_token51] = ACTIONS(5085),
    [aux_sym_basic_type_token52] = ACTIONS(5085),
    [aux_sym_basic_type_token53] = ACTIONS(5085),
    [aux_sym_basic_type_token54] = ACTIONS(5085),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5077),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5077),
    [sym_query_keyword] = ACTIONS(5077),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5077),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5091),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2133)] = {
    [sym_type_specification] = STATE(8453),
    [sym_text_type] = STATE(8385),
    [sym_code_type] = STATE(8385),
    [sym_option_type] = STATE(8381),
    [sym_record_type] = STATE(8381),
    [sym_dotnet_type] = STATE(8381),
    [sym_object_reference_type] = STATE(8381),
    [sym_array_type] = STATE(8388),
    [sym_list_type] = STATE(8388),
    [sym_dictionary_type] = STATE(8388),
    [sym_basic_type] = STATE(8381),
    [sym_codeunit_keyword] = STATE(11394),
    [sym_xmlport_keyword] = STATE(11394),
    [sym_enum_keyword] = STATE(11394),
    [sym_controladdin_keyword] = STATE(11394),
    [sym_dotnet_keyword] = STATE(11271),
    [sym_identifier] = ACTIONS(5067),
    [aux_sym_text_type_token1] = ACTIONS(5069),
    [aux_sym_code_type_token1] = ACTIONS(5071),
    [aux_sym_option_type_token1] = ACTIONS(5073),
    [aux_sym_record_type_token1] = ACTIONS(5075),
    [aux_sym_object_reference_type_token1] = ACTIONS(5077),
    [aux_sym_object_reference_type_token2] = ACTIONS(5077),
    [aux_sym_array_type_token1] = ACTIONS(5079),
    [aux_sym_list_type_token1] = ACTIONS(5081),
    [aux_sym_dictionary_type_token1] = ACTIONS(5083),
    [aux_sym_basic_type_token1] = ACTIONS(5085),
    [aux_sym_basic_type_token2] = ACTIONS(5085),
    [aux_sym_basic_type_token3] = ACTIONS(5085),
    [aux_sym_basic_type_token4] = ACTIONS(5085),
    [aux_sym_basic_type_token5] = ACTIONS(5085),
    [aux_sym_basic_type_token6] = ACTIONS(5087),
    [aux_sym_basic_type_token7] = ACTIONS(5085),
    [aux_sym_basic_type_token8] = ACTIONS(5085),
    [aux_sym_basic_type_token9] = ACTIONS(5085),
    [aux_sym_basic_type_token10] = ACTIONS(5085),
    [aux_sym_basic_type_token11] = ACTIONS(5085),
    [aux_sym_basic_type_token12] = ACTIONS(5085),
    [aux_sym_basic_type_token13] = ACTIONS(5089),
    [aux_sym_basic_type_token14] = ACTIONS(5085),
    [aux_sym_basic_type_token15] = ACTIONS(5085),
    [aux_sym_basic_type_token16] = ACTIONS(5085),
    [aux_sym_basic_type_token17] = ACTIONS(5085),
    [aux_sym_basic_type_token18] = ACTIONS(5085),
    [aux_sym_basic_type_token19] = ACTIONS(5085),
    [aux_sym_basic_type_token20] = ACTIONS(5085),
    [aux_sym_basic_type_token21] = ACTIONS(5085),
    [aux_sym_basic_type_token22] = ACTIONS(5085),
    [aux_sym_basic_type_token23] = ACTIONS(5085),
    [aux_sym_basic_type_token24] = ACTIONS(5085),
    [aux_sym_basic_type_token25] = ACTIONS(5085),
    [aux_sym_basic_type_token26] = ACTIONS(5085),
    [aux_sym_basic_type_token27] = ACTIONS(5085),
    [aux_sym_basic_type_token28] = ACTIONS(5085),
    [aux_sym_basic_type_token29] = ACTIONS(5085),
    [aux_sym_basic_type_token30] = ACTIONS(5085),
    [aux_sym_basic_type_token31] = ACTIONS(5085),
    [aux_sym_basic_type_token32] = ACTIONS(5085),
    [aux_sym_basic_type_token33] = ACTIONS(5085),
    [aux_sym_basic_type_token34] = ACTIONS(5085),
    [aux_sym_basic_type_token35] = ACTIONS(5085),
    [aux_sym_basic_type_token36] = ACTIONS(5085),
    [aux_sym_basic_type_token37] = ACTIONS(5085),
    [aux_sym_basic_type_token38] = ACTIONS(5085),
    [aux_sym_basic_type_token39] = ACTIONS(5085),
    [aux_sym_basic_type_token40] = ACTIONS(5085),
    [aux_sym_basic_type_token41] = ACTIONS(5085),
    [aux_sym_basic_type_token42] = ACTIONS(5085),
    [aux_sym_basic_type_token43] = ACTIONS(5085),
    [aux_sym_basic_type_token44] = ACTIONS(5085),
    [aux_sym_basic_type_token45] = ACTIONS(5085),
    [aux_sym_basic_type_token46] = ACTIONS(5085),
    [aux_sym_basic_type_token47] = ACTIONS(5085),
    [aux_sym_basic_type_token48] = ACTIONS(5085),
    [aux_sym_basic_type_token49] = ACTIONS(5085),
    [aux_sym_basic_type_token50] = ACTIONS(5085),
    [aux_sym_basic_type_token51] = ACTIONS(5085),
    [aux_sym_basic_type_token52] = ACTIONS(5085),
    [aux_sym_basic_type_token53] = ACTIONS(5085),
    [aux_sym_basic_type_token54] = ACTIONS(5085),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5077),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5077),
    [sym_query_keyword] = ACTIONS(5077),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5077),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5091),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2134)] = {
    [sym_type_specification] = STATE(10215),
    [sym_text_type] = STATE(10207),
    [sym_code_type] = STATE(10207),
    [sym_option_type] = STATE(10199),
    [sym_record_type] = STATE(10199),
    [sym_dotnet_type] = STATE(10199),
    [sym_object_reference_type] = STATE(10199),
    [sym_array_type] = STATE(10216),
    [sym_list_type] = STATE(10216),
    [sym_dictionary_type] = STATE(10216),
    [sym_basic_type] = STATE(10199),
    [sym_codeunit_keyword] = STATE(11399),
    [sym_xmlport_keyword] = STATE(11399),
    [sym_enum_keyword] = STATE(11399),
    [sym_controladdin_keyword] = STATE(11399),
    [sym_dotnet_keyword] = STATE(11285),
    [sym_identifier] = ACTIONS(5093),
    [aux_sym_text_type_token1] = ACTIONS(5095),
    [aux_sym_code_type_token1] = ACTIONS(5097),
    [aux_sym_option_type_token1] = ACTIONS(5099),
    [aux_sym_record_type_token1] = ACTIONS(5101),
    [aux_sym_object_reference_type_token1] = ACTIONS(5103),
    [aux_sym_object_reference_type_token2] = ACTIONS(5103),
    [aux_sym_array_type_token1] = ACTIONS(5105),
    [aux_sym_list_type_token1] = ACTIONS(5107),
    [aux_sym_dictionary_type_token1] = ACTIONS(5109),
    [aux_sym_basic_type_token1] = ACTIONS(5111),
    [aux_sym_basic_type_token2] = ACTIONS(5111),
    [aux_sym_basic_type_token3] = ACTIONS(5111),
    [aux_sym_basic_type_token4] = ACTIONS(5111),
    [aux_sym_basic_type_token5] = ACTIONS(5111),
    [aux_sym_basic_type_token6] = ACTIONS(5113),
    [aux_sym_basic_type_token7] = ACTIONS(5111),
    [aux_sym_basic_type_token8] = ACTIONS(5111),
    [aux_sym_basic_type_token9] = ACTIONS(5111),
    [aux_sym_basic_type_token10] = ACTIONS(5111),
    [aux_sym_basic_type_token11] = ACTIONS(5111),
    [aux_sym_basic_type_token12] = ACTIONS(5111),
    [aux_sym_basic_type_token13] = ACTIONS(5115),
    [aux_sym_basic_type_token14] = ACTIONS(5111),
    [aux_sym_basic_type_token15] = ACTIONS(5111),
    [aux_sym_basic_type_token16] = ACTIONS(5111),
    [aux_sym_basic_type_token17] = ACTIONS(5111),
    [aux_sym_basic_type_token18] = ACTIONS(5111),
    [aux_sym_basic_type_token19] = ACTIONS(5111),
    [aux_sym_basic_type_token20] = ACTIONS(5111),
    [aux_sym_basic_type_token21] = ACTIONS(5111),
    [aux_sym_basic_type_token22] = ACTIONS(5111),
    [aux_sym_basic_type_token23] = ACTIONS(5111),
    [aux_sym_basic_type_token24] = ACTIONS(5111),
    [aux_sym_basic_type_token25] = ACTIONS(5111),
    [aux_sym_basic_type_token26] = ACTIONS(5111),
    [aux_sym_basic_type_token27] = ACTIONS(5111),
    [aux_sym_basic_type_token28] = ACTIONS(5111),
    [aux_sym_basic_type_token29] = ACTIONS(5111),
    [aux_sym_basic_type_token30] = ACTIONS(5111),
    [aux_sym_basic_type_token31] = ACTIONS(5111),
    [aux_sym_basic_type_token32] = ACTIONS(5111),
    [aux_sym_basic_type_token33] = ACTIONS(5111),
    [aux_sym_basic_type_token34] = ACTIONS(5111),
    [aux_sym_basic_type_token35] = ACTIONS(5111),
    [aux_sym_basic_type_token36] = ACTIONS(5111),
    [aux_sym_basic_type_token37] = ACTIONS(5111),
    [aux_sym_basic_type_token38] = ACTIONS(5111),
    [aux_sym_basic_type_token39] = ACTIONS(5111),
    [aux_sym_basic_type_token40] = ACTIONS(5111),
    [aux_sym_basic_type_token41] = ACTIONS(5111),
    [aux_sym_basic_type_token42] = ACTIONS(5111),
    [aux_sym_basic_type_token43] = ACTIONS(5111),
    [aux_sym_basic_type_token44] = ACTIONS(5111),
    [aux_sym_basic_type_token45] = ACTIONS(5111),
    [aux_sym_basic_type_token46] = ACTIONS(5111),
    [aux_sym_basic_type_token47] = ACTIONS(5111),
    [aux_sym_basic_type_token48] = ACTIONS(5111),
    [aux_sym_basic_type_token49] = ACTIONS(5111),
    [aux_sym_basic_type_token50] = ACTIONS(5111),
    [aux_sym_basic_type_token51] = ACTIONS(5111),
    [aux_sym_basic_type_token52] = ACTIONS(5111),
    [aux_sym_basic_type_token53] = ACTIONS(5111),
    [aux_sym_basic_type_token54] = ACTIONS(5111),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5103),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5103),
    [sym_query_keyword] = ACTIONS(5103),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5103),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5117),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2135)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10515),
    [sym_else_table_relation_fragment] = STATE(10515),
    [sym_table_relation_expression] = STATE(10515),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2702),
    [sym_preproc_endif] = STATE(6082),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10855),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2136)] = {
    [sym_type_specification] = STATE(3536),
    [sym_text_type] = STATE(3520),
    [sym_code_type] = STATE(3520),
    [sym_option_type] = STATE(3519),
    [sym_record_type] = STATE(3519),
    [sym_dotnet_type] = STATE(3519),
    [sym_object_reference_type] = STATE(3519),
    [sym_array_type] = STATE(3521),
    [sym_list_type] = STATE(3521),
    [sym_dictionary_type] = STATE(3521),
    [sym_basic_type] = STATE(3519),
    [sym_codeunit_keyword] = STATE(11499),
    [sym_xmlport_keyword] = STATE(11499),
    [sym_enum_keyword] = STATE(11499),
    [sym_controladdin_keyword] = STATE(11499),
    [sym_dotnet_keyword] = STATE(11334),
    [sym_identifier] = ACTIONS(4781),
    [aux_sym_text_type_token1] = ACTIONS(4783),
    [aux_sym_code_type_token1] = ACTIONS(4785),
    [aux_sym_option_type_token1] = ACTIONS(4787),
    [aux_sym_record_type_token1] = ACTIONS(4789),
    [aux_sym_object_reference_type_token1] = ACTIONS(4791),
    [aux_sym_object_reference_type_token2] = ACTIONS(4791),
    [aux_sym_array_type_token1] = ACTIONS(4793),
    [aux_sym_list_type_token1] = ACTIONS(4795),
    [aux_sym_dictionary_type_token1] = ACTIONS(4797),
    [aux_sym_basic_type_token1] = ACTIONS(4799),
    [aux_sym_basic_type_token2] = ACTIONS(4799),
    [aux_sym_basic_type_token3] = ACTIONS(4799),
    [aux_sym_basic_type_token4] = ACTIONS(4799),
    [aux_sym_basic_type_token5] = ACTIONS(4799),
    [aux_sym_basic_type_token6] = ACTIONS(4801),
    [aux_sym_basic_type_token7] = ACTIONS(4799),
    [aux_sym_basic_type_token8] = ACTIONS(4799),
    [aux_sym_basic_type_token9] = ACTIONS(4799),
    [aux_sym_basic_type_token10] = ACTIONS(4799),
    [aux_sym_basic_type_token11] = ACTIONS(4799),
    [aux_sym_basic_type_token12] = ACTIONS(4799),
    [aux_sym_basic_type_token13] = ACTIONS(4803),
    [aux_sym_basic_type_token14] = ACTIONS(4799),
    [aux_sym_basic_type_token15] = ACTIONS(4799),
    [aux_sym_basic_type_token16] = ACTIONS(4799),
    [aux_sym_basic_type_token17] = ACTIONS(4799),
    [aux_sym_basic_type_token18] = ACTIONS(4799),
    [aux_sym_basic_type_token19] = ACTIONS(4799),
    [aux_sym_basic_type_token20] = ACTIONS(4799),
    [aux_sym_basic_type_token21] = ACTIONS(4799),
    [aux_sym_basic_type_token22] = ACTIONS(4799),
    [aux_sym_basic_type_token23] = ACTIONS(4799),
    [aux_sym_basic_type_token24] = ACTIONS(4799),
    [aux_sym_basic_type_token25] = ACTIONS(4799),
    [aux_sym_basic_type_token26] = ACTIONS(4799),
    [aux_sym_basic_type_token27] = ACTIONS(4799),
    [aux_sym_basic_type_token28] = ACTIONS(4799),
    [aux_sym_basic_type_token29] = ACTIONS(4799),
    [aux_sym_basic_type_token30] = ACTIONS(4799),
    [aux_sym_basic_type_token31] = ACTIONS(4799),
    [aux_sym_basic_type_token32] = ACTIONS(4799),
    [aux_sym_basic_type_token33] = ACTIONS(4799),
    [aux_sym_basic_type_token34] = ACTIONS(4799),
    [aux_sym_basic_type_token35] = ACTIONS(4799),
    [aux_sym_basic_type_token36] = ACTIONS(4799),
    [aux_sym_basic_type_token37] = ACTIONS(4799),
    [aux_sym_basic_type_token38] = ACTIONS(4799),
    [aux_sym_basic_type_token39] = ACTIONS(4799),
    [aux_sym_basic_type_token40] = ACTIONS(4799),
    [aux_sym_basic_type_token41] = ACTIONS(4799),
    [aux_sym_basic_type_token42] = ACTIONS(4799),
    [aux_sym_basic_type_token43] = ACTIONS(4799),
    [aux_sym_basic_type_token44] = ACTIONS(4799),
    [aux_sym_basic_type_token45] = ACTIONS(4799),
    [aux_sym_basic_type_token46] = ACTIONS(4799),
    [aux_sym_basic_type_token47] = ACTIONS(4799),
    [aux_sym_basic_type_token48] = ACTIONS(4799),
    [aux_sym_basic_type_token49] = ACTIONS(4799),
    [aux_sym_basic_type_token50] = ACTIONS(4799),
    [aux_sym_basic_type_token51] = ACTIONS(4799),
    [aux_sym_basic_type_token52] = ACTIONS(4799),
    [aux_sym_basic_type_token53] = ACTIONS(4799),
    [aux_sym_basic_type_token54] = ACTIONS(4799),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4791),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4791),
    [sym_query_keyword] = ACTIONS(4791),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4791),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2137)] = {
    [sym_type_specification] = STATE(3541),
    [sym_text_type] = STATE(3520),
    [sym_code_type] = STATE(3520),
    [sym_option_type] = STATE(3519),
    [sym_record_type] = STATE(3519),
    [sym_dotnet_type] = STATE(3519),
    [sym_object_reference_type] = STATE(3519),
    [sym_array_type] = STATE(3521),
    [sym_list_type] = STATE(3521),
    [sym_dictionary_type] = STATE(3521),
    [sym_basic_type] = STATE(3519),
    [sym_codeunit_keyword] = STATE(11499),
    [sym_xmlport_keyword] = STATE(11499),
    [sym_enum_keyword] = STATE(11499),
    [sym_controladdin_keyword] = STATE(11499),
    [sym_dotnet_keyword] = STATE(11334),
    [sym_identifier] = ACTIONS(4781),
    [aux_sym_text_type_token1] = ACTIONS(4783),
    [aux_sym_code_type_token1] = ACTIONS(4785),
    [aux_sym_option_type_token1] = ACTIONS(4787),
    [aux_sym_record_type_token1] = ACTIONS(4789),
    [aux_sym_object_reference_type_token1] = ACTIONS(4791),
    [aux_sym_object_reference_type_token2] = ACTIONS(4791),
    [aux_sym_array_type_token1] = ACTIONS(4793),
    [aux_sym_list_type_token1] = ACTIONS(4795),
    [aux_sym_dictionary_type_token1] = ACTIONS(4797),
    [aux_sym_basic_type_token1] = ACTIONS(4799),
    [aux_sym_basic_type_token2] = ACTIONS(4799),
    [aux_sym_basic_type_token3] = ACTIONS(4799),
    [aux_sym_basic_type_token4] = ACTIONS(4799),
    [aux_sym_basic_type_token5] = ACTIONS(4799),
    [aux_sym_basic_type_token6] = ACTIONS(4801),
    [aux_sym_basic_type_token7] = ACTIONS(4799),
    [aux_sym_basic_type_token8] = ACTIONS(4799),
    [aux_sym_basic_type_token9] = ACTIONS(4799),
    [aux_sym_basic_type_token10] = ACTIONS(4799),
    [aux_sym_basic_type_token11] = ACTIONS(4799),
    [aux_sym_basic_type_token12] = ACTIONS(4799),
    [aux_sym_basic_type_token13] = ACTIONS(4803),
    [aux_sym_basic_type_token14] = ACTIONS(4799),
    [aux_sym_basic_type_token15] = ACTIONS(4799),
    [aux_sym_basic_type_token16] = ACTIONS(4799),
    [aux_sym_basic_type_token17] = ACTIONS(4799),
    [aux_sym_basic_type_token18] = ACTIONS(4799),
    [aux_sym_basic_type_token19] = ACTIONS(4799),
    [aux_sym_basic_type_token20] = ACTIONS(4799),
    [aux_sym_basic_type_token21] = ACTIONS(4799),
    [aux_sym_basic_type_token22] = ACTIONS(4799),
    [aux_sym_basic_type_token23] = ACTIONS(4799),
    [aux_sym_basic_type_token24] = ACTIONS(4799),
    [aux_sym_basic_type_token25] = ACTIONS(4799),
    [aux_sym_basic_type_token26] = ACTIONS(4799),
    [aux_sym_basic_type_token27] = ACTIONS(4799),
    [aux_sym_basic_type_token28] = ACTIONS(4799),
    [aux_sym_basic_type_token29] = ACTIONS(4799),
    [aux_sym_basic_type_token30] = ACTIONS(4799),
    [aux_sym_basic_type_token31] = ACTIONS(4799),
    [aux_sym_basic_type_token32] = ACTIONS(4799),
    [aux_sym_basic_type_token33] = ACTIONS(4799),
    [aux_sym_basic_type_token34] = ACTIONS(4799),
    [aux_sym_basic_type_token35] = ACTIONS(4799),
    [aux_sym_basic_type_token36] = ACTIONS(4799),
    [aux_sym_basic_type_token37] = ACTIONS(4799),
    [aux_sym_basic_type_token38] = ACTIONS(4799),
    [aux_sym_basic_type_token39] = ACTIONS(4799),
    [aux_sym_basic_type_token40] = ACTIONS(4799),
    [aux_sym_basic_type_token41] = ACTIONS(4799),
    [aux_sym_basic_type_token42] = ACTIONS(4799),
    [aux_sym_basic_type_token43] = ACTIONS(4799),
    [aux_sym_basic_type_token44] = ACTIONS(4799),
    [aux_sym_basic_type_token45] = ACTIONS(4799),
    [aux_sym_basic_type_token46] = ACTIONS(4799),
    [aux_sym_basic_type_token47] = ACTIONS(4799),
    [aux_sym_basic_type_token48] = ACTIONS(4799),
    [aux_sym_basic_type_token49] = ACTIONS(4799),
    [aux_sym_basic_type_token50] = ACTIONS(4799),
    [aux_sym_basic_type_token51] = ACTIONS(4799),
    [aux_sym_basic_type_token52] = ACTIONS(4799),
    [aux_sym_basic_type_token53] = ACTIONS(4799),
    [aux_sym_basic_type_token54] = ACTIONS(4799),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4791),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4791),
    [sym_query_keyword] = ACTIONS(4791),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4791),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2138)] = {
    [sym_type_specification] = STATE(11282),
    [sym_text_type] = STATE(11382),
    [sym_code_type] = STATE(11382),
    [sym_option_type] = STATE(11323),
    [sym_record_type] = STATE(11323),
    [sym_dotnet_type] = STATE(11323),
    [sym_object_reference_type] = STATE(11323),
    [sym_array_type] = STATE(11313),
    [sym_list_type] = STATE(11313),
    [sym_dictionary_type] = STATE(11313),
    [sym_basic_type] = STATE(11323),
    [sym_codeunit_keyword] = STATE(11421),
    [sym_xmlport_keyword] = STATE(11421),
    [sym_enum_keyword] = STATE(11421),
    [sym_controladdin_keyword] = STATE(11421),
    [sym_dotnet_keyword] = STATE(11291),
    [sym_identifier] = ACTIONS(5119),
    [aux_sym_text_type_token1] = ACTIONS(5121),
    [aux_sym_code_type_token1] = ACTIONS(5123),
    [aux_sym_option_type_token1] = ACTIONS(5125),
    [aux_sym_record_type_token1] = ACTIONS(5127),
    [aux_sym_object_reference_type_token1] = ACTIONS(5129),
    [aux_sym_object_reference_type_token2] = ACTIONS(5129),
    [aux_sym_array_type_token1] = ACTIONS(5131),
    [aux_sym_list_type_token1] = ACTIONS(5133),
    [aux_sym_dictionary_type_token1] = ACTIONS(5135),
    [aux_sym_basic_type_token1] = ACTIONS(5137),
    [aux_sym_basic_type_token2] = ACTIONS(5137),
    [aux_sym_basic_type_token3] = ACTIONS(5137),
    [aux_sym_basic_type_token4] = ACTIONS(5137),
    [aux_sym_basic_type_token5] = ACTIONS(5137),
    [aux_sym_basic_type_token6] = ACTIONS(5139),
    [aux_sym_basic_type_token7] = ACTIONS(5137),
    [aux_sym_basic_type_token8] = ACTIONS(5137),
    [aux_sym_basic_type_token9] = ACTIONS(5137),
    [aux_sym_basic_type_token10] = ACTIONS(5137),
    [aux_sym_basic_type_token11] = ACTIONS(5137),
    [aux_sym_basic_type_token12] = ACTIONS(5137),
    [aux_sym_basic_type_token13] = ACTIONS(5141),
    [aux_sym_basic_type_token14] = ACTIONS(5137),
    [aux_sym_basic_type_token15] = ACTIONS(5137),
    [aux_sym_basic_type_token16] = ACTIONS(5137),
    [aux_sym_basic_type_token17] = ACTIONS(5137),
    [aux_sym_basic_type_token18] = ACTIONS(5137),
    [aux_sym_basic_type_token19] = ACTIONS(5137),
    [aux_sym_basic_type_token20] = ACTIONS(5137),
    [aux_sym_basic_type_token21] = ACTIONS(5137),
    [aux_sym_basic_type_token22] = ACTIONS(5137),
    [aux_sym_basic_type_token23] = ACTIONS(5137),
    [aux_sym_basic_type_token24] = ACTIONS(5137),
    [aux_sym_basic_type_token25] = ACTIONS(5137),
    [aux_sym_basic_type_token26] = ACTIONS(5137),
    [aux_sym_basic_type_token27] = ACTIONS(5137),
    [aux_sym_basic_type_token28] = ACTIONS(5137),
    [aux_sym_basic_type_token29] = ACTIONS(5137),
    [aux_sym_basic_type_token30] = ACTIONS(5137),
    [aux_sym_basic_type_token31] = ACTIONS(5137),
    [aux_sym_basic_type_token32] = ACTIONS(5137),
    [aux_sym_basic_type_token33] = ACTIONS(5137),
    [aux_sym_basic_type_token34] = ACTIONS(5137),
    [aux_sym_basic_type_token35] = ACTIONS(5137),
    [aux_sym_basic_type_token36] = ACTIONS(5137),
    [aux_sym_basic_type_token37] = ACTIONS(5137),
    [aux_sym_basic_type_token38] = ACTIONS(5137),
    [aux_sym_basic_type_token39] = ACTIONS(5137),
    [aux_sym_basic_type_token40] = ACTIONS(5137),
    [aux_sym_basic_type_token41] = ACTIONS(5137),
    [aux_sym_basic_type_token42] = ACTIONS(5137),
    [aux_sym_basic_type_token43] = ACTIONS(5137),
    [aux_sym_basic_type_token44] = ACTIONS(5137),
    [aux_sym_basic_type_token45] = ACTIONS(5137),
    [aux_sym_basic_type_token46] = ACTIONS(5137),
    [aux_sym_basic_type_token47] = ACTIONS(5137),
    [aux_sym_basic_type_token48] = ACTIONS(5137),
    [aux_sym_basic_type_token49] = ACTIONS(5137),
    [aux_sym_basic_type_token50] = ACTIONS(5137),
    [aux_sym_basic_type_token51] = ACTIONS(5137),
    [aux_sym_basic_type_token52] = ACTIONS(5137),
    [aux_sym_basic_type_token53] = ACTIONS(5137),
    [aux_sym_basic_type_token54] = ACTIONS(5137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5129),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5129),
    [sym_query_keyword] = ACTIONS(5129),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5129),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5143),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2139)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10562),
    [sym_else_table_relation_fragment] = STATE(10562),
    [sym_table_relation_expression] = STATE(10562),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2711),
    [sym_preproc_endif] = STATE(9496),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10916),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(2140)] = {
    [sym_type_specification] = STATE(2319),
    [sym_text_type] = STATE(2338),
    [sym_code_type] = STATE(2338),
    [sym_option_type] = STATE(2337),
    [sym_record_type] = STATE(2337),
    [sym_dotnet_type] = STATE(2337),
    [sym_object_reference_type] = STATE(2337),
    [sym_array_type] = STATE(2339),
    [sym_list_type] = STATE(2339),
    [sym_dictionary_type] = STATE(2339),
    [sym_basic_type] = STATE(2337),
    [sym_codeunit_keyword] = STATE(11546),
    [sym_xmlport_keyword] = STATE(11546),
    [sym_enum_keyword] = STATE(11546),
    [sym_controladdin_keyword] = STATE(11546),
    [sym_dotnet_keyword] = STATE(11326),
    [sym_identifier] = ACTIONS(4811),
    [aux_sym_text_type_token1] = ACTIONS(4813),
    [aux_sym_code_type_token1] = ACTIONS(4815),
    [aux_sym_option_type_token1] = ACTIONS(4817),
    [aux_sym_record_type_token1] = ACTIONS(4819),
    [aux_sym_object_reference_type_token1] = ACTIONS(4821),
    [aux_sym_object_reference_type_token2] = ACTIONS(4821),
    [aux_sym_array_type_token1] = ACTIONS(4823),
    [aux_sym_list_type_token1] = ACTIONS(4825),
    [aux_sym_dictionary_type_token1] = ACTIONS(4827),
    [aux_sym_basic_type_token1] = ACTIONS(4829),
    [aux_sym_basic_type_token2] = ACTIONS(4829),
    [aux_sym_basic_type_token3] = ACTIONS(4829),
    [aux_sym_basic_type_token4] = ACTIONS(4829),
    [aux_sym_basic_type_token5] = ACTIONS(4829),
    [aux_sym_basic_type_token6] = ACTIONS(4831),
    [aux_sym_basic_type_token7] = ACTIONS(4829),
    [aux_sym_basic_type_token8] = ACTIONS(4829),
    [aux_sym_basic_type_token9] = ACTIONS(4829),
    [aux_sym_basic_type_token10] = ACTIONS(4829),
    [aux_sym_basic_type_token11] = ACTIONS(4829),
    [aux_sym_basic_type_token12] = ACTIONS(4829),
    [aux_sym_basic_type_token13] = ACTIONS(4833),
    [aux_sym_basic_type_token14] = ACTIONS(4829),
    [aux_sym_basic_type_token15] = ACTIONS(4829),
    [aux_sym_basic_type_token16] = ACTIONS(4829),
    [aux_sym_basic_type_token17] = ACTIONS(4829),
    [aux_sym_basic_type_token18] = ACTIONS(4829),
    [aux_sym_basic_type_token19] = ACTIONS(4829),
    [aux_sym_basic_type_token20] = ACTIONS(4829),
    [aux_sym_basic_type_token21] = ACTIONS(4829),
    [aux_sym_basic_type_token22] = ACTIONS(4829),
    [aux_sym_basic_type_token23] = ACTIONS(4829),
    [aux_sym_basic_type_token24] = ACTIONS(4829),
    [aux_sym_basic_type_token25] = ACTIONS(4829),
    [aux_sym_basic_type_token26] = ACTIONS(4829),
    [aux_sym_basic_type_token27] = ACTIONS(4829),
    [aux_sym_basic_type_token28] = ACTIONS(4829),
    [aux_sym_basic_type_token29] = ACTIONS(4829),
    [aux_sym_basic_type_token30] = ACTIONS(4829),
    [aux_sym_basic_type_token31] = ACTIONS(4829),
    [aux_sym_basic_type_token32] = ACTIONS(4829),
    [aux_sym_basic_type_token33] = ACTIONS(4829),
    [aux_sym_basic_type_token34] = ACTIONS(4829),
    [aux_sym_basic_type_token35] = ACTIONS(4829),
    [aux_sym_basic_type_token36] = ACTIONS(4829),
    [aux_sym_basic_type_token37] = ACTIONS(4829),
    [aux_sym_basic_type_token38] = ACTIONS(4829),
    [aux_sym_basic_type_token39] = ACTIONS(4829),
    [aux_sym_basic_type_token40] = ACTIONS(4829),
    [aux_sym_basic_type_token41] = ACTIONS(4829),
    [aux_sym_basic_type_token42] = ACTIONS(4829),
    [aux_sym_basic_type_token43] = ACTIONS(4829),
    [aux_sym_basic_type_token44] = ACTIONS(4829),
    [aux_sym_basic_type_token45] = ACTIONS(4829),
    [aux_sym_basic_type_token46] = ACTIONS(4829),
    [aux_sym_basic_type_token47] = ACTIONS(4829),
    [aux_sym_basic_type_token48] = ACTIONS(4829),
    [aux_sym_basic_type_token49] = ACTIONS(4829),
    [aux_sym_basic_type_token50] = ACTIONS(4829),
    [aux_sym_basic_type_token51] = ACTIONS(4829),
    [aux_sym_basic_type_token52] = ACTIONS(4829),
    [aux_sym_basic_type_token53] = ACTIONS(4829),
    [aux_sym_basic_type_token54] = ACTIONS(4829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4821),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4821),
    [sym_query_keyword] = ACTIONS(4821),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4821),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4835),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2141)] = {
    [sym_type_specification] = STATE(2322),
    [sym_text_type] = STATE(2338),
    [sym_code_type] = STATE(2338),
    [sym_option_type] = STATE(2337),
    [sym_record_type] = STATE(2337),
    [sym_dotnet_type] = STATE(2337),
    [sym_object_reference_type] = STATE(2337),
    [sym_array_type] = STATE(2339),
    [sym_list_type] = STATE(2339),
    [sym_dictionary_type] = STATE(2339),
    [sym_basic_type] = STATE(2337),
    [sym_codeunit_keyword] = STATE(11546),
    [sym_xmlport_keyword] = STATE(11546),
    [sym_enum_keyword] = STATE(11546),
    [sym_controladdin_keyword] = STATE(11546),
    [sym_dotnet_keyword] = STATE(11326),
    [sym_identifier] = ACTIONS(4811),
    [aux_sym_text_type_token1] = ACTIONS(4813),
    [aux_sym_code_type_token1] = ACTIONS(4815),
    [aux_sym_option_type_token1] = ACTIONS(4817),
    [aux_sym_record_type_token1] = ACTIONS(4819),
    [aux_sym_object_reference_type_token1] = ACTIONS(4821),
    [aux_sym_object_reference_type_token2] = ACTIONS(4821),
    [aux_sym_array_type_token1] = ACTIONS(4823),
    [aux_sym_list_type_token1] = ACTIONS(4825),
    [aux_sym_dictionary_type_token1] = ACTIONS(4827),
    [aux_sym_basic_type_token1] = ACTIONS(4829),
    [aux_sym_basic_type_token2] = ACTIONS(4829),
    [aux_sym_basic_type_token3] = ACTIONS(4829),
    [aux_sym_basic_type_token4] = ACTIONS(4829),
    [aux_sym_basic_type_token5] = ACTIONS(4829),
    [aux_sym_basic_type_token6] = ACTIONS(4831),
    [aux_sym_basic_type_token7] = ACTIONS(4829),
    [aux_sym_basic_type_token8] = ACTIONS(4829),
    [aux_sym_basic_type_token9] = ACTIONS(4829),
    [aux_sym_basic_type_token10] = ACTIONS(4829),
    [aux_sym_basic_type_token11] = ACTIONS(4829),
    [aux_sym_basic_type_token12] = ACTIONS(4829),
    [aux_sym_basic_type_token13] = ACTIONS(4833),
    [aux_sym_basic_type_token14] = ACTIONS(4829),
    [aux_sym_basic_type_token15] = ACTIONS(4829),
    [aux_sym_basic_type_token16] = ACTIONS(4829),
    [aux_sym_basic_type_token17] = ACTIONS(4829),
    [aux_sym_basic_type_token18] = ACTIONS(4829),
    [aux_sym_basic_type_token19] = ACTIONS(4829),
    [aux_sym_basic_type_token20] = ACTIONS(4829),
    [aux_sym_basic_type_token21] = ACTIONS(4829),
    [aux_sym_basic_type_token22] = ACTIONS(4829),
    [aux_sym_basic_type_token23] = ACTIONS(4829),
    [aux_sym_basic_type_token24] = ACTIONS(4829),
    [aux_sym_basic_type_token25] = ACTIONS(4829),
    [aux_sym_basic_type_token26] = ACTIONS(4829),
    [aux_sym_basic_type_token27] = ACTIONS(4829),
    [aux_sym_basic_type_token28] = ACTIONS(4829),
    [aux_sym_basic_type_token29] = ACTIONS(4829),
    [aux_sym_basic_type_token30] = ACTIONS(4829),
    [aux_sym_basic_type_token31] = ACTIONS(4829),
    [aux_sym_basic_type_token32] = ACTIONS(4829),
    [aux_sym_basic_type_token33] = ACTIONS(4829),
    [aux_sym_basic_type_token34] = ACTIONS(4829),
    [aux_sym_basic_type_token35] = ACTIONS(4829),
    [aux_sym_basic_type_token36] = ACTIONS(4829),
    [aux_sym_basic_type_token37] = ACTIONS(4829),
    [aux_sym_basic_type_token38] = ACTIONS(4829),
    [aux_sym_basic_type_token39] = ACTIONS(4829),
    [aux_sym_basic_type_token40] = ACTIONS(4829),
    [aux_sym_basic_type_token41] = ACTIONS(4829),
    [aux_sym_basic_type_token42] = ACTIONS(4829),
    [aux_sym_basic_type_token43] = ACTIONS(4829),
    [aux_sym_basic_type_token44] = ACTIONS(4829),
    [aux_sym_basic_type_token45] = ACTIONS(4829),
    [aux_sym_basic_type_token46] = ACTIONS(4829),
    [aux_sym_basic_type_token47] = ACTIONS(4829),
    [aux_sym_basic_type_token48] = ACTIONS(4829),
    [aux_sym_basic_type_token49] = ACTIONS(4829),
    [aux_sym_basic_type_token50] = ACTIONS(4829),
    [aux_sym_basic_type_token51] = ACTIONS(4829),
    [aux_sym_basic_type_token52] = ACTIONS(4829),
    [aux_sym_basic_type_token53] = ACTIONS(4829),
    [aux_sym_basic_type_token54] = ACTIONS(4829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4821),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4821),
    [sym_query_keyword] = ACTIONS(4821),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4821),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4835),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2142)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10605),
    [sym_else_table_relation_fragment] = STATE(10605),
    [sym_table_relation_expression] = STATE(10605),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2638),
    [sym_preproc_endif] = STATE(5215),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10958),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2143)] = {
    [sym_type_specification] = STATE(3082),
    [sym_text_type] = STATE(3087),
    [sym_code_type] = STATE(3087),
    [sym_option_type] = STATE(3071),
    [sym_record_type] = STATE(3071),
    [sym_dotnet_type] = STATE(3071),
    [sym_object_reference_type] = STATE(3071),
    [sym_array_type] = STATE(3130),
    [sym_list_type] = STATE(3130),
    [sym_dictionary_type] = STATE(3130),
    [sym_basic_type] = STATE(3071),
    [sym_codeunit_keyword] = STATE(11510),
    [sym_xmlport_keyword] = STATE(11510),
    [sym_enum_keyword] = STATE(11510),
    [sym_controladdin_keyword] = STATE(11510),
    [sym_dotnet_keyword] = STATE(11364),
    [sym_identifier] = ACTIONS(4837),
    [aux_sym_text_type_token1] = ACTIONS(4839),
    [aux_sym_code_type_token1] = ACTIONS(4841),
    [aux_sym_option_type_token1] = ACTIONS(4843),
    [aux_sym_record_type_token1] = ACTIONS(4845),
    [aux_sym_object_reference_type_token1] = ACTIONS(4847),
    [aux_sym_object_reference_type_token2] = ACTIONS(4847),
    [aux_sym_array_type_token1] = ACTIONS(4849),
    [aux_sym_list_type_token1] = ACTIONS(4851),
    [aux_sym_dictionary_type_token1] = ACTIONS(4853),
    [aux_sym_basic_type_token1] = ACTIONS(4855),
    [aux_sym_basic_type_token2] = ACTIONS(4855),
    [aux_sym_basic_type_token3] = ACTIONS(4855),
    [aux_sym_basic_type_token4] = ACTIONS(4855),
    [aux_sym_basic_type_token5] = ACTIONS(4855),
    [aux_sym_basic_type_token6] = ACTIONS(4857),
    [aux_sym_basic_type_token7] = ACTIONS(4855),
    [aux_sym_basic_type_token8] = ACTIONS(4855),
    [aux_sym_basic_type_token9] = ACTIONS(4855),
    [aux_sym_basic_type_token10] = ACTIONS(4855),
    [aux_sym_basic_type_token11] = ACTIONS(4855),
    [aux_sym_basic_type_token12] = ACTIONS(4855),
    [aux_sym_basic_type_token13] = ACTIONS(4859),
    [aux_sym_basic_type_token14] = ACTIONS(4855),
    [aux_sym_basic_type_token15] = ACTIONS(4855),
    [aux_sym_basic_type_token16] = ACTIONS(4855),
    [aux_sym_basic_type_token17] = ACTIONS(4855),
    [aux_sym_basic_type_token18] = ACTIONS(4855),
    [aux_sym_basic_type_token19] = ACTIONS(4855),
    [aux_sym_basic_type_token20] = ACTIONS(4855),
    [aux_sym_basic_type_token21] = ACTIONS(4855),
    [aux_sym_basic_type_token22] = ACTIONS(4855),
    [aux_sym_basic_type_token23] = ACTIONS(4855),
    [aux_sym_basic_type_token24] = ACTIONS(4855),
    [aux_sym_basic_type_token25] = ACTIONS(4855),
    [aux_sym_basic_type_token26] = ACTIONS(4855),
    [aux_sym_basic_type_token27] = ACTIONS(4855),
    [aux_sym_basic_type_token28] = ACTIONS(4855),
    [aux_sym_basic_type_token29] = ACTIONS(4855),
    [aux_sym_basic_type_token30] = ACTIONS(4855),
    [aux_sym_basic_type_token31] = ACTIONS(4855),
    [aux_sym_basic_type_token32] = ACTIONS(4855),
    [aux_sym_basic_type_token33] = ACTIONS(4855),
    [aux_sym_basic_type_token34] = ACTIONS(4855),
    [aux_sym_basic_type_token35] = ACTIONS(4855),
    [aux_sym_basic_type_token36] = ACTIONS(4855),
    [aux_sym_basic_type_token37] = ACTIONS(4855),
    [aux_sym_basic_type_token38] = ACTIONS(4855),
    [aux_sym_basic_type_token39] = ACTIONS(4855),
    [aux_sym_basic_type_token40] = ACTIONS(4855),
    [aux_sym_basic_type_token41] = ACTIONS(4855),
    [aux_sym_basic_type_token42] = ACTIONS(4855),
    [aux_sym_basic_type_token43] = ACTIONS(4855),
    [aux_sym_basic_type_token44] = ACTIONS(4855),
    [aux_sym_basic_type_token45] = ACTIONS(4855),
    [aux_sym_basic_type_token46] = ACTIONS(4855),
    [aux_sym_basic_type_token47] = ACTIONS(4855),
    [aux_sym_basic_type_token48] = ACTIONS(4855),
    [aux_sym_basic_type_token49] = ACTIONS(4855),
    [aux_sym_basic_type_token50] = ACTIONS(4855),
    [aux_sym_basic_type_token51] = ACTIONS(4855),
    [aux_sym_basic_type_token52] = ACTIONS(4855),
    [aux_sym_basic_type_token53] = ACTIONS(4855),
    [aux_sym_basic_type_token54] = ACTIONS(4855),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4847),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4847),
    [sym_query_keyword] = ACTIONS(4847),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4847),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2144)] = {
    [sym_type_specification] = STATE(3083),
    [sym_text_type] = STATE(3087),
    [sym_code_type] = STATE(3087),
    [sym_option_type] = STATE(3071),
    [sym_record_type] = STATE(3071),
    [sym_dotnet_type] = STATE(3071),
    [sym_object_reference_type] = STATE(3071),
    [sym_array_type] = STATE(3130),
    [sym_list_type] = STATE(3130),
    [sym_dictionary_type] = STATE(3130),
    [sym_basic_type] = STATE(3071),
    [sym_codeunit_keyword] = STATE(11510),
    [sym_xmlport_keyword] = STATE(11510),
    [sym_enum_keyword] = STATE(11510),
    [sym_controladdin_keyword] = STATE(11510),
    [sym_dotnet_keyword] = STATE(11364),
    [sym_identifier] = ACTIONS(4837),
    [aux_sym_text_type_token1] = ACTIONS(4839),
    [aux_sym_code_type_token1] = ACTIONS(4841),
    [aux_sym_option_type_token1] = ACTIONS(4843),
    [aux_sym_record_type_token1] = ACTIONS(4845),
    [aux_sym_object_reference_type_token1] = ACTIONS(4847),
    [aux_sym_object_reference_type_token2] = ACTIONS(4847),
    [aux_sym_array_type_token1] = ACTIONS(4849),
    [aux_sym_list_type_token1] = ACTIONS(4851),
    [aux_sym_dictionary_type_token1] = ACTIONS(4853),
    [aux_sym_basic_type_token1] = ACTIONS(4855),
    [aux_sym_basic_type_token2] = ACTIONS(4855),
    [aux_sym_basic_type_token3] = ACTIONS(4855),
    [aux_sym_basic_type_token4] = ACTIONS(4855),
    [aux_sym_basic_type_token5] = ACTIONS(4855),
    [aux_sym_basic_type_token6] = ACTIONS(4857),
    [aux_sym_basic_type_token7] = ACTIONS(4855),
    [aux_sym_basic_type_token8] = ACTIONS(4855),
    [aux_sym_basic_type_token9] = ACTIONS(4855),
    [aux_sym_basic_type_token10] = ACTIONS(4855),
    [aux_sym_basic_type_token11] = ACTIONS(4855),
    [aux_sym_basic_type_token12] = ACTIONS(4855),
    [aux_sym_basic_type_token13] = ACTIONS(4859),
    [aux_sym_basic_type_token14] = ACTIONS(4855),
    [aux_sym_basic_type_token15] = ACTIONS(4855),
    [aux_sym_basic_type_token16] = ACTIONS(4855),
    [aux_sym_basic_type_token17] = ACTIONS(4855),
    [aux_sym_basic_type_token18] = ACTIONS(4855),
    [aux_sym_basic_type_token19] = ACTIONS(4855),
    [aux_sym_basic_type_token20] = ACTIONS(4855),
    [aux_sym_basic_type_token21] = ACTIONS(4855),
    [aux_sym_basic_type_token22] = ACTIONS(4855),
    [aux_sym_basic_type_token23] = ACTIONS(4855),
    [aux_sym_basic_type_token24] = ACTIONS(4855),
    [aux_sym_basic_type_token25] = ACTIONS(4855),
    [aux_sym_basic_type_token26] = ACTIONS(4855),
    [aux_sym_basic_type_token27] = ACTIONS(4855),
    [aux_sym_basic_type_token28] = ACTIONS(4855),
    [aux_sym_basic_type_token29] = ACTIONS(4855),
    [aux_sym_basic_type_token30] = ACTIONS(4855),
    [aux_sym_basic_type_token31] = ACTIONS(4855),
    [aux_sym_basic_type_token32] = ACTIONS(4855),
    [aux_sym_basic_type_token33] = ACTIONS(4855),
    [aux_sym_basic_type_token34] = ACTIONS(4855),
    [aux_sym_basic_type_token35] = ACTIONS(4855),
    [aux_sym_basic_type_token36] = ACTIONS(4855),
    [aux_sym_basic_type_token37] = ACTIONS(4855),
    [aux_sym_basic_type_token38] = ACTIONS(4855),
    [aux_sym_basic_type_token39] = ACTIONS(4855),
    [aux_sym_basic_type_token40] = ACTIONS(4855),
    [aux_sym_basic_type_token41] = ACTIONS(4855),
    [aux_sym_basic_type_token42] = ACTIONS(4855),
    [aux_sym_basic_type_token43] = ACTIONS(4855),
    [aux_sym_basic_type_token44] = ACTIONS(4855),
    [aux_sym_basic_type_token45] = ACTIONS(4855),
    [aux_sym_basic_type_token46] = ACTIONS(4855),
    [aux_sym_basic_type_token47] = ACTIONS(4855),
    [aux_sym_basic_type_token48] = ACTIONS(4855),
    [aux_sym_basic_type_token49] = ACTIONS(4855),
    [aux_sym_basic_type_token50] = ACTIONS(4855),
    [aux_sym_basic_type_token51] = ACTIONS(4855),
    [aux_sym_basic_type_token52] = ACTIONS(4855),
    [aux_sym_basic_type_token53] = ACTIONS(4855),
    [aux_sym_basic_type_token54] = ACTIONS(4855),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4847),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4847),
    [sym_query_keyword] = ACTIONS(4847),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4847),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2145)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10639),
    [sym_else_table_relation_fragment] = STATE(10639),
    [sym_table_relation_expression] = STATE(10639),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2663),
    [sym_preproc_endif] = STATE(7902),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(11016),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(2146)] = {
    [sym_type_specification] = STATE(7219),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11397),
    [sym_xmlport_keyword] = STATE(11397),
    [sym_enum_keyword] = STATE(11397),
    [sym_controladdin_keyword] = STATE(11397),
    [sym_dotnet_keyword] = STATE(11320),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(4869),
    [aux_sym_record_type_token1] = ACTIONS(4871),
    [aux_sym_object_reference_type_token1] = ACTIONS(4873),
    [aux_sym_object_reference_type_token2] = ACTIONS(4873),
    [aux_sym_array_type_token1] = ACTIONS(4875),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4873),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4873),
    [sym_query_keyword] = ACTIONS(4873),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4873),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2147)] = {
    [sym_type_specification] = STATE(7191),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11397),
    [sym_xmlport_keyword] = STATE(11397),
    [sym_enum_keyword] = STATE(11397),
    [sym_controladdin_keyword] = STATE(11397),
    [sym_dotnet_keyword] = STATE(11320),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(4869),
    [aux_sym_record_type_token1] = ACTIONS(4871),
    [aux_sym_object_reference_type_token1] = ACTIONS(4873),
    [aux_sym_object_reference_type_token2] = ACTIONS(4873),
    [aux_sym_array_type_token1] = ACTIONS(4875),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4873),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4873),
    [sym_query_keyword] = ACTIONS(4873),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4873),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2148)] = {
    [sym_type_specification] = STATE(17239),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(15943),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(5145),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2149)] = {
    [sym_type_specification] = STATE(17604),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2150)] = {
    [sym_type_specification] = STATE(17264),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2151)] = {
    [sym_type_specification] = STATE(16947),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2152)] = {
    [sym_type_specification] = STATE(17105),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2153)] = {
    [sym_type_specification] = STATE(17476),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(16219),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(5147),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2154)] = {
    [sym_type_specification] = STATE(16710),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2155)] = {
    [sym_type_specification] = STATE(17386),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2156)] = {
    [sym_type_specification] = STATE(18154),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2157)] = {
    [sym_type_specification] = STATE(7211),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2158)] = {
    [sym_type_specification] = STATE(16751),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2159)] = {
    [sym_type_specification] = STATE(16779),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2160)] = {
    [sym_type_specification] = STATE(17862),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(15797),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(5149),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2161)] = {
    [sym_type_specification] = STATE(9855),
    [sym_text_type] = STATE(9959),
    [sym_code_type] = STATE(9959),
    [sym_option_type] = STATE(9958),
    [sym_record_type] = STATE(9958),
    [sym_dotnet_type] = STATE(9958),
    [sym_object_reference_type] = STATE(9958),
    [sym_array_type] = STATE(9961),
    [sym_list_type] = STATE(9961),
    [sym_dictionary_type] = STATE(9961),
    [sym_basic_type] = STATE(9958),
    [sym_codeunit_keyword] = STATE(11563),
    [sym_xmlport_keyword] = STATE(11563),
    [sym_enum_keyword] = STATE(11563),
    [sym_controladdin_keyword] = STATE(11563),
    [sym_dotnet_keyword] = STATE(11266),
    [sym_identifier] = ACTIONS(5151),
    [aux_sym_text_type_token1] = ACTIONS(5153),
    [aux_sym_code_type_token1] = ACTIONS(5155),
    [aux_sym_option_type_token1] = ACTIONS(5157),
    [aux_sym_record_type_token1] = ACTIONS(5159),
    [aux_sym_object_reference_type_token1] = ACTIONS(5161),
    [aux_sym_object_reference_type_token2] = ACTIONS(5161),
    [aux_sym_array_type_token1] = ACTIONS(5163),
    [aux_sym_list_type_token1] = ACTIONS(5165),
    [aux_sym_dictionary_type_token1] = ACTIONS(5167),
    [aux_sym_basic_type_token1] = ACTIONS(5169),
    [aux_sym_basic_type_token2] = ACTIONS(5169),
    [aux_sym_basic_type_token3] = ACTIONS(5169),
    [aux_sym_basic_type_token4] = ACTIONS(5169),
    [aux_sym_basic_type_token5] = ACTIONS(5169),
    [aux_sym_basic_type_token6] = ACTIONS(5171),
    [aux_sym_basic_type_token7] = ACTIONS(5169),
    [aux_sym_basic_type_token8] = ACTIONS(5169),
    [aux_sym_basic_type_token9] = ACTIONS(5169),
    [aux_sym_basic_type_token10] = ACTIONS(5169),
    [aux_sym_basic_type_token11] = ACTIONS(5169),
    [aux_sym_basic_type_token12] = ACTIONS(5169),
    [aux_sym_basic_type_token13] = ACTIONS(5173),
    [aux_sym_basic_type_token14] = ACTIONS(5169),
    [aux_sym_basic_type_token15] = ACTIONS(5169),
    [aux_sym_basic_type_token16] = ACTIONS(5169),
    [aux_sym_basic_type_token17] = ACTIONS(5169),
    [aux_sym_basic_type_token18] = ACTIONS(5169),
    [aux_sym_basic_type_token19] = ACTIONS(5169),
    [aux_sym_basic_type_token20] = ACTIONS(5169),
    [aux_sym_basic_type_token21] = ACTIONS(5169),
    [aux_sym_basic_type_token22] = ACTIONS(5169),
    [aux_sym_basic_type_token23] = ACTIONS(5169),
    [aux_sym_basic_type_token24] = ACTIONS(5169),
    [aux_sym_basic_type_token25] = ACTIONS(5169),
    [aux_sym_basic_type_token26] = ACTIONS(5169),
    [aux_sym_basic_type_token27] = ACTIONS(5169),
    [aux_sym_basic_type_token28] = ACTIONS(5169),
    [aux_sym_basic_type_token29] = ACTIONS(5169),
    [aux_sym_basic_type_token30] = ACTIONS(5169),
    [aux_sym_basic_type_token31] = ACTIONS(5169),
    [aux_sym_basic_type_token32] = ACTIONS(5169),
    [aux_sym_basic_type_token33] = ACTIONS(5169),
    [aux_sym_basic_type_token34] = ACTIONS(5169),
    [aux_sym_basic_type_token35] = ACTIONS(5169),
    [aux_sym_basic_type_token36] = ACTIONS(5169),
    [aux_sym_basic_type_token37] = ACTIONS(5169),
    [aux_sym_basic_type_token38] = ACTIONS(5169),
    [aux_sym_basic_type_token39] = ACTIONS(5169),
    [aux_sym_basic_type_token40] = ACTIONS(5169),
    [aux_sym_basic_type_token41] = ACTIONS(5169),
    [aux_sym_basic_type_token42] = ACTIONS(5169),
    [aux_sym_basic_type_token43] = ACTIONS(5169),
    [aux_sym_basic_type_token44] = ACTIONS(5169),
    [aux_sym_basic_type_token45] = ACTIONS(5169),
    [aux_sym_basic_type_token46] = ACTIONS(5169),
    [aux_sym_basic_type_token47] = ACTIONS(5169),
    [aux_sym_basic_type_token48] = ACTIONS(5169),
    [aux_sym_basic_type_token49] = ACTIONS(5169),
    [aux_sym_basic_type_token50] = ACTIONS(5169),
    [aux_sym_basic_type_token51] = ACTIONS(5169),
    [aux_sym_basic_type_token52] = ACTIONS(5169),
    [aux_sym_basic_type_token53] = ACTIONS(5169),
    [aux_sym_basic_type_token54] = ACTIONS(5169),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5161),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5161),
    [sym_query_keyword] = ACTIONS(5161),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5161),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5175),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2162)] = {
    [sym_type_specification] = STATE(17356),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(15515),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(5177),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2163)] = {
    [sym_type_specification] = STATE(17429),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2164)] = {
    [sym_type_specification] = STATE(17739),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2165)] = {
    [sym_type_specification] = STATE(17903),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2166)] = {
    [sym_type_specification] = STATE(9869),
    [sym_text_type] = STATE(9959),
    [sym_code_type] = STATE(9959),
    [sym_option_type] = STATE(9958),
    [sym_record_type] = STATE(9958),
    [sym_dotnet_type] = STATE(9958),
    [sym_object_reference_type] = STATE(9958),
    [sym_array_type] = STATE(9961),
    [sym_list_type] = STATE(9961),
    [sym_dictionary_type] = STATE(9961),
    [sym_basic_type] = STATE(9958),
    [sym_codeunit_keyword] = STATE(11563),
    [sym_xmlport_keyword] = STATE(11563),
    [sym_enum_keyword] = STATE(11563),
    [sym_controladdin_keyword] = STATE(11563),
    [sym_dotnet_keyword] = STATE(11266),
    [sym_identifier] = ACTIONS(5151),
    [aux_sym_text_type_token1] = ACTIONS(5153),
    [aux_sym_code_type_token1] = ACTIONS(5155),
    [aux_sym_option_type_token1] = ACTIONS(5157),
    [aux_sym_record_type_token1] = ACTIONS(5159),
    [aux_sym_object_reference_type_token1] = ACTIONS(5161),
    [aux_sym_object_reference_type_token2] = ACTIONS(5161),
    [aux_sym_array_type_token1] = ACTIONS(5163),
    [aux_sym_list_type_token1] = ACTIONS(5165),
    [aux_sym_dictionary_type_token1] = ACTIONS(5167),
    [aux_sym_basic_type_token1] = ACTIONS(5169),
    [aux_sym_basic_type_token2] = ACTIONS(5169),
    [aux_sym_basic_type_token3] = ACTIONS(5169),
    [aux_sym_basic_type_token4] = ACTIONS(5169),
    [aux_sym_basic_type_token5] = ACTIONS(5169),
    [aux_sym_basic_type_token6] = ACTIONS(5171),
    [aux_sym_basic_type_token7] = ACTIONS(5169),
    [aux_sym_basic_type_token8] = ACTIONS(5169),
    [aux_sym_basic_type_token9] = ACTIONS(5169),
    [aux_sym_basic_type_token10] = ACTIONS(5169),
    [aux_sym_basic_type_token11] = ACTIONS(5169),
    [aux_sym_basic_type_token12] = ACTIONS(5169),
    [aux_sym_basic_type_token13] = ACTIONS(5173),
    [aux_sym_basic_type_token14] = ACTIONS(5169),
    [aux_sym_basic_type_token15] = ACTIONS(5169),
    [aux_sym_basic_type_token16] = ACTIONS(5169),
    [aux_sym_basic_type_token17] = ACTIONS(5169),
    [aux_sym_basic_type_token18] = ACTIONS(5169),
    [aux_sym_basic_type_token19] = ACTIONS(5169),
    [aux_sym_basic_type_token20] = ACTIONS(5169),
    [aux_sym_basic_type_token21] = ACTIONS(5169),
    [aux_sym_basic_type_token22] = ACTIONS(5169),
    [aux_sym_basic_type_token23] = ACTIONS(5169),
    [aux_sym_basic_type_token24] = ACTIONS(5169),
    [aux_sym_basic_type_token25] = ACTIONS(5169),
    [aux_sym_basic_type_token26] = ACTIONS(5169),
    [aux_sym_basic_type_token27] = ACTIONS(5169),
    [aux_sym_basic_type_token28] = ACTIONS(5169),
    [aux_sym_basic_type_token29] = ACTIONS(5169),
    [aux_sym_basic_type_token30] = ACTIONS(5169),
    [aux_sym_basic_type_token31] = ACTIONS(5169),
    [aux_sym_basic_type_token32] = ACTIONS(5169),
    [aux_sym_basic_type_token33] = ACTIONS(5169),
    [aux_sym_basic_type_token34] = ACTIONS(5169),
    [aux_sym_basic_type_token35] = ACTIONS(5169),
    [aux_sym_basic_type_token36] = ACTIONS(5169),
    [aux_sym_basic_type_token37] = ACTIONS(5169),
    [aux_sym_basic_type_token38] = ACTIONS(5169),
    [aux_sym_basic_type_token39] = ACTIONS(5169),
    [aux_sym_basic_type_token40] = ACTIONS(5169),
    [aux_sym_basic_type_token41] = ACTIONS(5169),
    [aux_sym_basic_type_token42] = ACTIONS(5169),
    [aux_sym_basic_type_token43] = ACTIONS(5169),
    [aux_sym_basic_type_token44] = ACTIONS(5169),
    [aux_sym_basic_type_token45] = ACTIONS(5169),
    [aux_sym_basic_type_token46] = ACTIONS(5169),
    [aux_sym_basic_type_token47] = ACTIONS(5169),
    [aux_sym_basic_type_token48] = ACTIONS(5169),
    [aux_sym_basic_type_token49] = ACTIONS(5169),
    [aux_sym_basic_type_token50] = ACTIONS(5169),
    [aux_sym_basic_type_token51] = ACTIONS(5169),
    [aux_sym_basic_type_token52] = ACTIONS(5169),
    [aux_sym_basic_type_token53] = ACTIONS(5169),
    [aux_sym_basic_type_token54] = ACTIONS(5169),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5161),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5161),
    [sym_query_keyword] = ACTIONS(5161),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5161),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5175),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2167)] = {
    [sym_type_specification] = STATE(16740),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(16211),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(5179),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2168)] = {
    [sym_type_specification] = STATE(16822),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2169)] = {
    [sym_type_specification] = STATE(17669),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2170)] = {
    [sym_type_specification] = STATE(16755),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2171)] = {
    [sym_type_specification] = STATE(16860),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(15485),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(5181),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2172)] = {
    [sym_type_specification] = STATE(16645),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2173)] = {
    [sym_type_specification] = STATE(16754),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2174)] = {
    [sym_type_specification] = STATE(18091),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(15526),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(5183),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2175)] = {
    [sym_type_specification] = STATE(16651),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2176)] = {
    [sym_type_specification] = STATE(16743),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2177)] = {
    [sym_type_specification] = STATE(17714),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2178)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(10421),
    [sym_else_table_relation_fragment] = STATE(10421),
    [sym_table_relation_expression] = STATE(10421),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_elif] = STATE(2247),
    [sym_preproc_else] = STATE(2667),
    [sym_preproc_endif] = STATE(6082),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_table_relation_repeat1] = STATE(10748),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(4891),
    [anon_sym_POUNDELIF] = ACTIONS(4891),
    [anon_sym_POUNDElif] = ACTIONS(4891),
    [anon_sym_POUNDelse] = ACTIONS(4893),
    [anon_sym_POUNDELSE] = ACTIONS(4893),
    [anon_sym_POUNDElse] = ACTIONS(4893),
    [anon_sym_POUNDelse2] = ACTIONS(4893),
    [anon_sym_POUNDELSE2] = ACTIONS(4893),
    [anon_sym_POUNDElse2] = ACTIONS(4893),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(2179)] = {
    [sym_type_specification] = STATE(7228),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2180)] = {
    [sym_type_specification] = STATE(17584),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2181)] = {
    [sym_type_specification] = STATE(12496),
    [sym_text_type] = STATE(12502),
    [sym_code_type] = STATE(12502),
    [sym_option_type] = STATE(12493),
    [sym_record_type] = STATE(12493),
    [sym_dotnet_type] = STATE(12493),
    [sym_object_reference_type] = STATE(12493),
    [sym_array_type] = STATE(12489),
    [sym_list_type] = STATE(12489),
    [sym_dictionary_type] = STATE(12489),
    [sym_basic_type] = STATE(12493),
    [sym_codeunit_keyword] = STATE(11591),
    [sym_xmlport_keyword] = STATE(11591),
    [sym_enum_keyword] = STATE(11591),
    [sym_controladdin_keyword] = STATE(11591),
    [sym_dotnet_keyword] = STATE(11267),
    [sym_identifier] = ACTIONS(4923),
    [aux_sym_text_type_token1] = ACTIONS(4925),
    [aux_sym_code_type_token1] = ACTIONS(4927),
    [aux_sym_option_type_token1] = ACTIONS(4929),
    [aux_sym_record_type_token1] = ACTIONS(4931),
    [aux_sym_object_reference_type_token1] = ACTIONS(4933),
    [aux_sym_object_reference_type_token2] = ACTIONS(4933),
    [aux_sym_array_type_token1] = ACTIONS(4935),
    [aux_sym_list_type_token1] = ACTIONS(4937),
    [aux_sym_dictionary_type_token1] = ACTIONS(4939),
    [aux_sym_basic_type_token1] = ACTIONS(4941),
    [aux_sym_basic_type_token2] = ACTIONS(4941),
    [aux_sym_basic_type_token3] = ACTIONS(4941),
    [aux_sym_basic_type_token4] = ACTIONS(4941),
    [aux_sym_basic_type_token5] = ACTIONS(4941),
    [aux_sym_basic_type_token6] = ACTIONS(4943),
    [aux_sym_basic_type_token7] = ACTIONS(4941),
    [aux_sym_basic_type_token8] = ACTIONS(4941),
    [aux_sym_basic_type_token9] = ACTIONS(4941),
    [aux_sym_basic_type_token10] = ACTIONS(4941),
    [aux_sym_basic_type_token11] = ACTIONS(4941),
    [aux_sym_basic_type_token12] = ACTIONS(4941),
    [aux_sym_basic_type_token13] = ACTIONS(4945),
    [aux_sym_basic_type_token14] = ACTIONS(4941),
    [aux_sym_basic_type_token15] = ACTIONS(4941),
    [aux_sym_basic_type_token16] = ACTIONS(4941),
    [aux_sym_basic_type_token17] = ACTIONS(4941),
    [aux_sym_basic_type_token18] = ACTIONS(4941),
    [aux_sym_basic_type_token19] = ACTIONS(4941),
    [aux_sym_basic_type_token20] = ACTIONS(4941),
    [aux_sym_basic_type_token21] = ACTIONS(4941),
    [aux_sym_basic_type_token22] = ACTIONS(4941),
    [aux_sym_basic_type_token23] = ACTIONS(4941),
    [aux_sym_basic_type_token24] = ACTIONS(4941),
    [aux_sym_basic_type_token25] = ACTIONS(4941),
    [aux_sym_basic_type_token26] = ACTIONS(4941),
    [aux_sym_basic_type_token27] = ACTIONS(4941),
    [aux_sym_basic_type_token28] = ACTIONS(4941),
    [aux_sym_basic_type_token29] = ACTIONS(4941),
    [aux_sym_basic_type_token30] = ACTIONS(4941),
    [aux_sym_basic_type_token31] = ACTIONS(4941),
    [aux_sym_basic_type_token32] = ACTIONS(4941),
    [aux_sym_basic_type_token33] = ACTIONS(4941),
    [aux_sym_basic_type_token34] = ACTIONS(4941),
    [aux_sym_basic_type_token35] = ACTIONS(4941),
    [aux_sym_basic_type_token36] = ACTIONS(4941),
    [aux_sym_basic_type_token37] = ACTIONS(4941),
    [aux_sym_basic_type_token38] = ACTIONS(4941),
    [aux_sym_basic_type_token39] = ACTIONS(4941),
    [aux_sym_basic_type_token40] = ACTIONS(4941),
    [aux_sym_basic_type_token41] = ACTIONS(4941),
    [aux_sym_basic_type_token42] = ACTIONS(4941),
    [aux_sym_basic_type_token43] = ACTIONS(4941),
    [aux_sym_basic_type_token44] = ACTIONS(4941),
    [aux_sym_basic_type_token45] = ACTIONS(4941),
    [aux_sym_basic_type_token46] = ACTIONS(4941),
    [aux_sym_basic_type_token47] = ACTIONS(4941),
    [aux_sym_basic_type_token48] = ACTIONS(4941),
    [aux_sym_basic_type_token49] = ACTIONS(4941),
    [aux_sym_basic_type_token50] = ACTIONS(4941),
    [aux_sym_basic_type_token51] = ACTIONS(4941),
    [aux_sym_basic_type_token52] = ACTIONS(4941),
    [aux_sym_basic_type_token53] = ACTIONS(4941),
    [aux_sym_basic_type_token54] = ACTIONS(4941),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4933),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4933),
    [sym_query_keyword] = ACTIONS(4933),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4933),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2182)] = {
    [sym_type_specification] = STATE(12469),
    [sym_text_type] = STATE(12502),
    [sym_code_type] = STATE(12502),
    [sym_option_type] = STATE(12493),
    [sym_record_type] = STATE(12493),
    [sym_dotnet_type] = STATE(12493),
    [sym_object_reference_type] = STATE(12493),
    [sym_array_type] = STATE(12489),
    [sym_list_type] = STATE(12489),
    [sym_dictionary_type] = STATE(12489),
    [sym_basic_type] = STATE(12493),
    [sym_codeunit_keyword] = STATE(11591),
    [sym_xmlport_keyword] = STATE(11591),
    [sym_enum_keyword] = STATE(11591),
    [sym_controladdin_keyword] = STATE(11591),
    [sym_dotnet_keyword] = STATE(11267),
    [sym_identifier] = ACTIONS(4923),
    [aux_sym_text_type_token1] = ACTIONS(4925),
    [aux_sym_code_type_token1] = ACTIONS(4927),
    [aux_sym_option_type_token1] = ACTIONS(4929),
    [aux_sym_record_type_token1] = ACTIONS(4931),
    [aux_sym_object_reference_type_token1] = ACTIONS(4933),
    [aux_sym_object_reference_type_token2] = ACTIONS(4933),
    [aux_sym_array_type_token1] = ACTIONS(4935),
    [aux_sym_list_type_token1] = ACTIONS(4937),
    [aux_sym_dictionary_type_token1] = ACTIONS(4939),
    [aux_sym_basic_type_token1] = ACTIONS(4941),
    [aux_sym_basic_type_token2] = ACTIONS(4941),
    [aux_sym_basic_type_token3] = ACTIONS(4941),
    [aux_sym_basic_type_token4] = ACTIONS(4941),
    [aux_sym_basic_type_token5] = ACTIONS(4941),
    [aux_sym_basic_type_token6] = ACTIONS(4943),
    [aux_sym_basic_type_token7] = ACTIONS(4941),
    [aux_sym_basic_type_token8] = ACTIONS(4941),
    [aux_sym_basic_type_token9] = ACTIONS(4941),
    [aux_sym_basic_type_token10] = ACTIONS(4941),
    [aux_sym_basic_type_token11] = ACTIONS(4941),
    [aux_sym_basic_type_token12] = ACTIONS(4941),
    [aux_sym_basic_type_token13] = ACTIONS(4945),
    [aux_sym_basic_type_token14] = ACTIONS(4941),
    [aux_sym_basic_type_token15] = ACTIONS(4941),
    [aux_sym_basic_type_token16] = ACTIONS(4941),
    [aux_sym_basic_type_token17] = ACTIONS(4941),
    [aux_sym_basic_type_token18] = ACTIONS(4941),
    [aux_sym_basic_type_token19] = ACTIONS(4941),
    [aux_sym_basic_type_token20] = ACTIONS(4941),
    [aux_sym_basic_type_token21] = ACTIONS(4941),
    [aux_sym_basic_type_token22] = ACTIONS(4941),
    [aux_sym_basic_type_token23] = ACTIONS(4941),
    [aux_sym_basic_type_token24] = ACTIONS(4941),
    [aux_sym_basic_type_token25] = ACTIONS(4941),
    [aux_sym_basic_type_token26] = ACTIONS(4941),
    [aux_sym_basic_type_token27] = ACTIONS(4941),
    [aux_sym_basic_type_token28] = ACTIONS(4941),
    [aux_sym_basic_type_token29] = ACTIONS(4941),
    [aux_sym_basic_type_token30] = ACTIONS(4941),
    [aux_sym_basic_type_token31] = ACTIONS(4941),
    [aux_sym_basic_type_token32] = ACTIONS(4941),
    [aux_sym_basic_type_token33] = ACTIONS(4941),
    [aux_sym_basic_type_token34] = ACTIONS(4941),
    [aux_sym_basic_type_token35] = ACTIONS(4941),
    [aux_sym_basic_type_token36] = ACTIONS(4941),
    [aux_sym_basic_type_token37] = ACTIONS(4941),
    [aux_sym_basic_type_token38] = ACTIONS(4941),
    [aux_sym_basic_type_token39] = ACTIONS(4941),
    [aux_sym_basic_type_token40] = ACTIONS(4941),
    [aux_sym_basic_type_token41] = ACTIONS(4941),
    [aux_sym_basic_type_token42] = ACTIONS(4941),
    [aux_sym_basic_type_token43] = ACTIONS(4941),
    [aux_sym_basic_type_token44] = ACTIONS(4941),
    [aux_sym_basic_type_token45] = ACTIONS(4941),
    [aux_sym_basic_type_token46] = ACTIONS(4941),
    [aux_sym_basic_type_token47] = ACTIONS(4941),
    [aux_sym_basic_type_token48] = ACTIONS(4941),
    [aux_sym_basic_type_token49] = ACTIONS(4941),
    [aux_sym_basic_type_token50] = ACTIONS(4941),
    [aux_sym_basic_type_token51] = ACTIONS(4941),
    [aux_sym_basic_type_token52] = ACTIONS(4941),
    [aux_sym_basic_type_token53] = ACTIONS(4941),
    [aux_sym_basic_type_token54] = ACTIONS(4941),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4933),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4933),
    [sym_query_keyword] = ACTIONS(4933),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4933),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2183)] = {
    [sym_type_specification] = STATE(7219),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5063),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5065),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2184)] = {
    [sym_type_specification] = STATE(7191),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5063),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5065),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2185)] = {
    [sym_type_specification] = STATE(18122),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2186)] = {
    [sym_type_specification] = STATE(16824),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(15568),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(5185),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2187)] = {
    [sym_type_specification] = STATE(17112),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2188)] = {
    [sym_type_specification] = STATE(17291),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2189)] = {
    [sym_type_specification] = STATE(17973),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2190)] = {
    [sym_type_specification] = STATE(17501),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2191)] = {
    [sym_type_specification] = STATE(18049),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2192)] = {
    [sym_type_specification] = STATE(10068),
    [sym_text_type] = STATE(10057),
    [sym_code_type] = STATE(10057),
    [sym_option_type] = STATE(10053),
    [sym_record_type] = STATE(10053),
    [sym_dotnet_type] = STATE(10053),
    [sym_object_reference_type] = STATE(10053),
    [sym_array_type] = STATE(10058),
    [sym_list_type] = STATE(10058),
    [sym_dictionary_type] = STATE(10058),
    [sym_basic_type] = STATE(10053),
    [sym_codeunit_keyword] = STATE(11439),
    [sym_xmlport_keyword] = STATE(11439),
    [sym_enum_keyword] = STATE(11439),
    [sym_controladdin_keyword] = STATE(11439),
    [sym_dotnet_keyword] = STATE(11275),
    [sym_identifier] = ACTIONS(4975),
    [aux_sym_text_type_token1] = ACTIONS(4977),
    [aux_sym_code_type_token1] = ACTIONS(4979),
    [aux_sym_option_type_token1] = ACTIONS(4981),
    [aux_sym_record_type_token1] = ACTIONS(4983),
    [aux_sym_object_reference_type_token1] = ACTIONS(4985),
    [aux_sym_object_reference_type_token2] = ACTIONS(4985),
    [aux_sym_array_type_token1] = ACTIONS(4987),
    [aux_sym_list_type_token1] = ACTIONS(4989),
    [aux_sym_dictionary_type_token1] = ACTIONS(4991),
    [aux_sym_basic_type_token1] = ACTIONS(4993),
    [aux_sym_basic_type_token2] = ACTIONS(4993),
    [aux_sym_basic_type_token3] = ACTIONS(4993),
    [aux_sym_basic_type_token4] = ACTIONS(4993),
    [aux_sym_basic_type_token5] = ACTIONS(4993),
    [aux_sym_basic_type_token6] = ACTIONS(4995),
    [aux_sym_basic_type_token7] = ACTIONS(4993),
    [aux_sym_basic_type_token8] = ACTIONS(4993),
    [aux_sym_basic_type_token9] = ACTIONS(4993),
    [aux_sym_basic_type_token10] = ACTIONS(4993),
    [aux_sym_basic_type_token11] = ACTIONS(4993),
    [aux_sym_basic_type_token12] = ACTIONS(4993),
    [aux_sym_basic_type_token13] = ACTIONS(4997),
    [aux_sym_basic_type_token14] = ACTIONS(4993),
    [aux_sym_basic_type_token15] = ACTIONS(4993),
    [aux_sym_basic_type_token16] = ACTIONS(4993),
    [aux_sym_basic_type_token17] = ACTIONS(4993),
    [aux_sym_basic_type_token18] = ACTIONS(4993),
    [aux_sym_basic_type_token19] = ACTIONS(4993),
    [aux_sym_basic_type_token20] = ACTIONS(4993),
    [aux_sym_basic_type_token21] = ACTIONS(4993),
    [aux_sym_basic_type_token22] = ACTIONS(4993),
    [aux_sym_basic_type_token23] = ACTIONS(4993),
    [aux_sym_basic_type_token24] = ACTIONS(4993),
    [aux_sym_basic_type_token25] = ACTIONS(4993),
    [aux_sym_basic_type_token26] = ACTIONS(4993),
    [aux_sym_basic_type_token27] = ACTIONS(4993),
    [aux_sym_basic_type_token28] = ACTIONS(4993),
    [aux_sym_basic_type_token29] = ACTIONS(4993),
    [aux_sym_basic_type_token30] = ACTIONS(4993),
    [aux_sym_basic_type_token31] = ACTIONS(4993),
    [aux_sym_basic_type_token32] = ACTIONS(4993),
    [aux_sym_basic_type_token33] = ACTIONS(4993),
    [aux_sym_basic_type_token34] = ACTIONS(4993),
    [aux_sym_basic_type_token35] = ACTIONS(4993),
    [aux_sym_basic_type_token36] = ACTIONS(4993),
    [aux_sym_basic_type_token37] = ACTIONS(4993),
    [aux_sym_basic_type_token38] = ACTIONS(4993),
    [aux_sym_basic_type_token39] = ACTIONS(4993),
    [aux_sym_basic_type_token40] = ACTIONS(4993),
    [aux_sym_basic_type_token41] = ACTIONS(4993),
    [aux_sym_basic_type_token42] = ACTIONS(4993),
    [aux_sym_basic_type_token43] = ACTIONS(4993),
    [aux_sym_basic_type_token44] = ACTIONS(4993),
    [aux_sym_basic_type_token45] = ACTIONS(4993),
    [aux_sym_basic_type_token46] = ACTIONS(4993),
    [aux_sym_basic_type_token47] = ACTIONS(4993),
    [aux_sym_basic_type_token48] = ACTIONS(4993),
    [aux_sym_basic_type_token49] = ACTIONS(4993),
    [aux_sym_basic_type_token50] = ACTIONS(4993),
    [aux_sym_basic_type_token51] = ACTIONS(4993),
    [aux_sym_basic_type_token52] = ACTIONS(4993),
    [aux_sym_basic_type_token53] = ACTIONS(4993),
    [aux_sym_basic_type_token54] = ACTIONS(4993),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4985),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4985),
    [sym_query_keyword] = ACTIONS(4985),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4985),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2193)] = {
    [sym_type_specification] = STATE(10064),
    [sym_text_type] = STATE(10057),
    [sym_code_type] = STATE(10057),
    [sym_option_type] = STATE(10053),
    [sym_record_type] = STATE(10053),
    [sym_dotnet_type] = STATE(10053),
    [sym_object_reference_type] = STATE(10053),
    [sym_array_type] = STATE(10058),
    [sym_list_type] = STATE(10058),
    [sym_dictionary_type] = STATE(10058),
    [sym_basic_type] = STATE(10053),
    [sym_codeunit_keyword] = STATE(11439),
    [sym_xmlport_keyword] = STATE(11439),
    [sym_enum_keyword] = STATE(11439),
    [sym_controladdin_keyword] = STATE(11439),
    [sym_dotnet_keyword] = STATE(11275),
    [sym_identifier] = ACTIONS(4975),
    [aux_sym_text_type_token1] = ACTIONS(4977),
    [aux_sym_code_type_token1] = ACTIONS(4979),
    [aux_sym_option_type_token1] = ACTIONS(4981),
    [aux_sym_record_type_token1] = ACTIONS(4983),
    [aux_sym_object_reference_type_token1] = ACTIONS(4985),
    [aux_sym_object_reference_type_token2] = ACTIONS(4985),
    [aux_sym_array_type_token1] = ACTIONS(4987),
    [aux_sym_list_type_token1] = ACTIONS(4989),
    [aux_sym_dictionary_type_token1] = ACTIONS(4991),
    [aux_sym_basic_type_token1] = ACTIONS(4993),
    [aux_sym_basic_type_token2] = ACTIONS(4993),
    [aux_sym_basic_type_token3] = ACTIONS(4993),
    [aux_sym_basic_type_token4] = ACTIONS(4993),
    [aux_sym_basic_type_token5] = ACTIONS(4993),
    [aux_sym_basic_type_token6] = ACTIONS(4995),
    [aux_sym_basic_type_token7] = ACTIONS(4993),
    [aux_sym_basic_type_token8] = ACTIONS(4993),
    [aux_sym_basic_type_token9] = ACTIONS(4993),
    [aux_sym_basic_type_token10] = ACTIONS(4993),
    [aux_sym_basic_type_token11] = ACTIONS(4993),
    [aux_sym_basic_type_token12] = ACTIONS(4993),
    [aux_sym_basic_type_token13] = ACTIONS(4997),
    [aux_sym_basic_type_token14] = ACTIONS(4993),
    [aux_sym_basic_type_token15] = ACTIONS(4993),
    [aux_sym_basic_type_token16] = ACTIONS(4993),
    [aux_sym_basic_type_token17] = ACTIONS(4993),
    [aux_sym_basic_type_token18] = ACTIONS(4993),
    [aux_sym_basic_type_token19] = ACTIONS(4993),
    [aux_sym_basic_type_token20] = ACTIONS(4993),
    [aux_sym_basic_type_token21] = ACTIONS(4993),
    [aux_sym_basic_type_token22] = ACTIONS(4993),
    [aux_sym_basic_type_token23] = ACTIONS(4993),
    [aux_sym_basic_type_token24] = ACTIONS(4993),
    [aux_sym_basic_type_token25] = ACTIONS(4993),
    [aux_sym_basic_type_token26] = ACTIONS(4993),
    [aux_sym_basic_type_token27] = ACTIONS(4993),
    [aux_sym_basic_type_token28] = ACTIONS(4993),
    [aux_sym_basic_type_token29] = ACTIONS(4993),
    [aux_sym_basic_type_token30] = ACTIONS(4993),
    [aux_sym_basic_type_token31] = ACTIONS(4993),
    [aux_sym_basic_type_token32] = ACTIONS(4993),
    [aux_sym_basic_type_token33] = ACTIONS(4993),
    [aux_sym_basic_type_token34] = ACTIONS(4993),
    [aux_sym_basic_type_token35] = ACTIONS(4993),
    [aux_sym_basic_type_token36] = ACTIONS(4993),
    [aux_sym_basic_type_token37] = ACTIONS(4993),
    [aux_sym_basic_type_token38] = ACTIONS(4993),
    [aux_sym_basic_type_token39] = ACTIONS(4993),
    [aux_sym_basic_type_token40] = ACTIONS(4993),
    [aux_sym_basic_type_token41] = ACTIONS(4993),
    [aux_sym_basic_type_token42] = ACTIONS(4993),
    [aux_sym_basic_type_token43] = ACTIONS(4993),
    [aux_sym_basic_type_token44] = ACTIONS(4993),
    [aux_sym_basic_type_token45] = ACTIONS(4993),
    [aux_sym_basic_type_token46] = ACTIONS(4993),
    [aux_sym_basic_type_token47] = ACTIONS(4993),
    [aux_sym_basic_type_token48] = ACTIONS(4993),
    [aux_sym_basic_type_token49] = ACTIONS(4993),
    [aux_sym_basic_type_token50] = ACTIONS(4993),
    [aux_sym_basic_type_token51] = ACTIONS(4993),
    [aux_sym_basic_type_token52] = ACTIONS(4993),
    [aux_sym_basic_type_token53] = ACTIONS(4993),
    [aux_sym_basic_type_token54] = ACTIONS(4993),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4985),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4985),
    [sym_query_keyword] = ACTIONS(4985),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4985),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2194)] = {
    [sym_type_specification] = STATE(18228),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2195)] = {
    [sym_type_specification] = STATE(16652),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2196)] = {
    [sym_type_specification] = STATE(3553),
    [sym_text_type] = STATE(3520),
    [sym_code_type] = STATE(3520),
    [sym_option_type] = STATE(3519),
    [sym_record_type] = STATE(3519),
    [sym_dotnet_type] = STATE(3519),
    [sym_object_reference_type] = STATE(3519),
    [sym_array_type] = STATE(3521),
    [sym_list_type] = STATE(3521),
    [sym_dictionary_type] = STATE(3521),
    [sym_basic_type] = STATE(3519),
    [sym_codeunit_keyword] = STATE(11499),
    [sym_xmlport_keyword] = STATE(11499),
    [sym_enum_keyword] = STATE(11499),
    [sym_controladdin_keyword] = STATE(11499),
    [sym_dotnet_keyword] = STATE(11334),
    [sym_identifier] = ACTIONS(4781),
    [aux_sym_text_type_token1] = ACTIONS(4783),
    [aux_sym_code_type_token1] = ACTIONS(4785),
    [aux_sym_option_type_token1] = ACTIONS(4787),
    [aux_sym_record_type_token1] = ACTIONS(4789),
    [aux_sym_object_reference_type_token1] = ACTIONS(4791),
    [aux_sym_object_reference_type_token2] = ACTIONS(4791),
    [aux_sym_array_type_token1] = ACTIONS(4793),
    [aux_sym_list_type_token1] = ACTIONS(4795),
    [aux_sym_dictionary_type_token1] = ACTIONS(4797),
    [aux_sym_basic_type_token1] = ACTIONS(4799),
    [aux_sym_basic_type_token2] = ACTIONS(4799),
    [aux_sym_basic_type_token3] = ACTIONS(4799),
    [aux_sym_basic_type_token4] = ACTIONS(4799),
    [aux_sym_basic_type_token5] = ACTIONS(4799),
    [aux_sym_basic_type_token6] = ACTIONS(4801),
    [aux_sym_basic_type_token7] = ACTIONS(4799),
    [aux_sym_basic_type_token8] = ACTIONS(4799),
    [aux_sym_basic_type_token9] = ACTIONS(4799),
    [aux_sym_basic_type_token10] = ACTIONS(4799),
    [aux_sym_basic_type_token11] = ACTIONS(4799),
    [aux_sym_basic_type_token12] = ACTIONS(4799),
    [aux_sym_basic_type_token13] = ACTIONS(4803),
    [aux_sym_basic_type_token14] = ACTIONS(4799),
    [aux_sym_basic_type_token15] = ACTIONS(4799),
    [aux_sym_basic_type_token16] = ACTIONS(4799),
    [aux_sym_basic_type_token17] = ACTIONS(4799),
    [aux_sym_basic_type_token18] = ACTIONS(4799),
    [aux_sym_basic_type_token19] = ACTIONS(4799),
    [aux_sym_basic_type_token20] = ACTIONS(4799),
    [aux_sym_basic_type_token21] = ACTIONS(4799),
    [aux_sym_basic_type_token22] = ACTIONS(4799),
    [aux_sym_basic_type_token23] = ACTIONS(4799),
    [aux_sym_basic_type_token24] = ACTIONS(4799),
    [aux_sym_basic_type_token25] = ACTIONS(4799),
    [aux_sym_basic_type_token26] = ACTIONS(4799),
    [aux_sym_basic_type_token27] = ACTIONS(4799),
    [aux_sym_basic_type_token28] = ACTIONS(4799),
    [aux_sym_basic_type_token29] = ACTIONS(4799),
    [aux_sym_basic_type_token30] = ACTIONS(4799),
    [aux_sym_basic_type_token31] = ACTIONS(4799),
    [aux_sym_basic_type_token32] = ACTIONS(4799),
    [aux_sym_basic_type_token33] = ACTIONS(4799),
    [aux_sym_basic_type_token34] = ACTIONS(4799),
    [aux_sym_basic_type_token35] = ACTIONS(4799),
    [aux_sym_basic_type_token36] = ACTIONS(4799),
    [aux_sym_basic_type_token37] = ACTIONS(4799),
    [aux_sym_basic_type_token38] = ACTIONS(4799),
    [aux_sym_basic_type_token39] = ACTIONS(4799),
    [aux_sym_basic_type_token40] = ACTIONS(4799),
    [aux_sym_basic_type_token41] = ACTIONS(4799),
    [aux_sym_basic_type_token42] = ACTIONS(4799),
    [aux_sym_basic_type_token43] = ACTIONS(4799),
    [aux_sym_basic_type_token44] = ACTIONS(4799),
    [aux_sym_basic_type_token45] = ACTIONS(4799),
    [aux_sym_basic_type_token46] = ACTIONS(4799),
    [aux_sym_basic_type_token47] = ACTIONS(4799),
    [aux_sym_basic_type_token48] = ACTIONS(4799),
    [aux_sym_basic_type_token49] = ACTIONS(4799),
    [aux_sym_basic_type_token50] = ACTIONS(4799),
    [aux_sym_basic_type_token51] = ACTIONS(4799),
    [aux_sym_basic_type_token52] = ACTIONS(4799),
    [aux_sym_basic_type_token53] = ACTIONS(4799),
    [aux_sym_basic_type_token54] = ACTIONS(4799),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4791),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4791),
    [sym_query_keyword] = ACTIONS(4791),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4791),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2197)] = {
    [sym_type_specification] = STATE(17461),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2198)] = {
    [sym_type_specification] = STATE(17511),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2199)] = {
    [sym_type_specification] = STATE(18085),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2200)] = {
    [sym_type_specification] = STATE(18114),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2201)] = {
    [sym_type_specification] = STATE(18287),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2202)] = {
    [sym_type_specification] = STATE(17550),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2203)] = {
    [sym_type_specification] = STATE(17410),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2204)] = {
    [sym_type_specification] = STATE(17420),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2205)] = {
    [sym_type_specification] = STATE(2065),
    [sym_text_type] = STATE(2079),
    [sym_code_type] = STATE(2079),
    [sym_option_type] = STATE(2078),
    [sym_record_type] = STATE(2078),
    [sym_dotnet_type] = STATE(2078),
    [sym_object_reference_type] = STATE(2078),
    [sym_array_type] = STATE(2084),
    [sym_list_type] = STATE(2084),
    [sym_dictionary_type] = STATE(2084),
    [sym_basic_type] = STATE(2078),
    [sym_codeunit_keyword] = STATE(11454),
    [sym_xmlport_keyword] = STATE(11454),
    [sym_enum_keyword] = STATE(11454),
    [sym_controladdin_keyword] = STATE(11454),
    [sym_dotnet_keyword] = STATE(11273),
    [sym_identifier] = ACTIONS(4897),
    [aux_sym_text_type_token1] = ACTIONS(4899),
    [aux_sym_code_type_token1] = ACTIONS(4901),
    [aux_sym_option_type_token1] = ACTIONS(4903),
    [aux_sym_record_type_token1] = ACTIONS(4905),
    [aux_sym_object_reference_type_token1] = ACTIONS(4907),
    [aux_sym_object_reference_type_token2] = ACTIONS(4907),
    [aux_sym_array_type_token1] = ACTIONS(4909),
    [aux_sym_list_type_token1] = ACTIONS(4911),
    [aux_sym_dictionary_type_token1] = ACTIONS(4913),
    [aux_sym_basic_type_token1] = ACTIONS(4915),
    [aux_sym_basic_type_token2] = ACTIONS(4915),
    [aux_sym_basic_type_token3] = ACTIONS(4915),
    [aux_sym_basic_type_token4] = ACTIONS(4915),
    [aux_sym_basic_type_token5] = ACTIONS(4915),
    [aux_sym_basic_type_token6] = ACTIONS(4917),
    [aux_sym_basic_type_token7] = ACTIONS(4915),
    [aux_sym_basic_type_token8] = ACTIONS(4915),
    [aux_sym_basic_type_token9] = ACTIONS(4915),
    [aux_sym_basic_type_token10] = ACTIONS(4915),
    [aux_sym_basic_type_token11] = ACTIONS(4915),
    [aux_sym_basic_type_token12] = ACTIONS(4915),
    [aux_sym_basic_type_token13] = ACTIONS(4919),
    [aux_sym_basic_type_token14] = ACTIONS(4915),
    [aux_sym_basic_type_token15] = ACTIONS(4915),
    [aux_sym_basic_type_token16] = ACTIONS(4915),
    [aux_sym_basic_type_token17] = ACTIONS(4915),
    [aux_sym_basic_type_token18] = ACTIONS(4915),
    [aux_sym_basic_type_token19] = ACTIONS(4915),
    [aux_sym_basic_type_token20] = ACTIONS(4915),
    [aux_sym_basic_type_token21] = ACTIONS(4915),
    [aux_sym_basic_type_token22] = ACTIONS(4915),
    [aux_sym_basic_type_token23] = ACTIONS(4915),
    [aux_sym_basic_type_token24] = ACTIONS(4915),
    [aux_sym_basic_type_token25] = ACTIONS(4915),
    [aux_sym_basic_type_token26] = ACTIONS(4915),
    [aux_sym_basic_type_token27] = ACTIONS(4915),
    [aux_sym_basic_type_token28] = ACTIONS(4915),
    [aux_sym_basic_type_token29] = ACTIONS(4915),
    [aux_sym_basic_type_token30] = ACTIONS(4915),
    [aux_sym_basic_type_token31] = ACTIONS(4915),
    [aux_sym_basic_type_token32] = ACTIONS(4915),
    [aux_sym_basic_type_token33] = ACTIONS(4915),
    [aux_sym_basic_type_token34] = ACTIONS(4915),
    [aux_sym_basic_type_token35] = ACTIONS(4915),
    [aux_sym_basic_type_token36] = ACTIONS(4915),
    [aux_sym_basic_type_token37] = ACTIONS(4915),
    [aux_sym_basic_type_token38] = ACTIONS(4915),
    [aux_sym_basic_type_token39] = ACTIONS(4915),
    [aux_sym_basic_type_token40] = ACTIONS(4915),
    [aux_sym_basic_type_token41] = ACTIONS(4915),
    [aux_sym_basic_type_token42] = ACTIONS(4915),
    [aux_sym_basic_type_token43] = ACTIONS(4915),
    [aux_sym_basic_type_token44] = ACTIONS(4915),
    [aux_sym_basic_type_token45] = ACTIONS(4915),
    [aux_sym_basic_type_token46] = ACTIONS(4915),
    [aux_sym_basic_type_token47] = ACTIONS(4915),
    [aux_sym_basic_type_token48] = ACTIONS(4915),
    [aux_sym_basic_type_token49] = ACTIONS(4915),
    [aux_sym_basic_type_token50] = ACTIONS(4915),
    [aux_sym_basic_type_token51] = ACTIONS(4915),
    [aux_sym_basic_type_token52] = ACTIONS(4915),
    [aux_sym_basic_type_token53] = ACTIONS(4915),
    [aux_sym_basic_type_token54] = ACTIONS(4915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4907),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4907),
    [sym_query_keyword] = ACTIONS(4907),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4907),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4921),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2206)] = {
    [sym_type_specification] = STATE(2061),
    [sym_text_type] = STATE(2079),
    [sym_code_type] = STATE(2079),
    [sym_option_type] = STATE(2078),
    [sym_record_type] = STATE(2078),
    [sym_dotnet_type] = STATE(2078),
    [sym_object_reference_type] = STATE(2078),
    [sym_array_type] = STATE(2084),
    [sym_list_type] = STATE(2084),
    [sym_dictionary_type] = STATE(2084),
    [sym_basic_type] = STATE(2078),
    [sym_codeunit_keyword] = STATE(11454),
    [sym_xmlport_keyword] = STATE(11454),
    [sym_enum_keyword] = STATE(11454),
    [sym_controladdin_keyword] = STATE(11454),
    [sym_dotnet_keyword] = STATE(11273),
    [sym_identifier] = ACTIONS(4897),
    [aux_sym_text_type_token1] = ACTIONS(4899),
    [aux_sym_code_type_token1] = ACTIONS(4901),
    [aux_sym_option_type_token1] = ACTIONS(4903),
    [aux_sym_record_type_token1] = ACTIONS(4905),
    [aux_sym_object_reference_type_token1] = ACTIONS(4907),
    [aux_sym_object_reference_type_token2] = ACTIONS(4907),
    [aux_sym_array_type_token1] = ACTIONS(4909),
    [aux_sym_list_type_token1] = ACTIONS(4911),
    [aux_sym_dictionary_type_token1] = ACTIONS(4913),
    [aux_sym_basic_type_token1] = ACTIONS(4915),
    [aux_sym_basic_type_token2] = ACTIONS(4915),
    [aux_sym_basic_type_token3] = ACTIONS(4915),
    [aux_sym_basic_type_token4] = ACTIONS(4915),
    [aux_sym_basic_type_token5] = ACTIONS(4915),
    [aux_sym_basic_type_token6] = ACTIONS(4917),
    [aux_sym_basic_type_token7] = ACTIONS(4915),
    [aux_sym_basic_type_token8] = ACTIONS(4915),
    [aux_sym_basic_type_token9] = ACTIONS(4915),
    [aux_sym_basic_type_token10] = ACTIONS(4915),
    [aux_sym_basic_type_token11] = ACTIONS(4915),
    [aux_sym_basic_type_token12] = ACTIONS(4915),
    [aux_sym_basic_type_token13] = ACTIONS(4919),
    [aux_sym_basic_type_token14] = ACTIONS(4915),
    [aux_sym_basic_type_token15] = ACTIONS(4915),
    [aux_sym_basic_type_token16] = ACTIONS(4915),
    [aux_sym_basic_type_token17] = ACTIONS(4915),
    [aux_sym_basic_type_token18] = ACTIONS(4915),
    [aux_sym_basic_type_token19] = ACTIONS(4915),
    [aux_sym_basic_type_token20] = ACTIONS(4915),
    [aux_sym_basic_type_token21] = ACTIONS(4915),
    [aux_sym_basic_type_token22] = ACTIONS(4915),
    [aux_sym_basic_type_token23] = ACTIONS(4915),
    [aux_sym_basic_type_token24] = ACTIONS(4915),
    [aux_sym_basic_type_token25] = ACTIONS(4915),
    [aux_sym_basic_type_token26] = ACTIONS(4915),
    [aux_sym_basic_type_token27] = ACTIONS(4915),
    [aux_sym_basic_type_token28] = ACTIONS(4915),
    [aux_sym_basic_type_token29] = ACTIONS(4915),
    [aux_sym_basic_type_token30] = ACTIONS(4915),
    [aux_sym_basic_type_token31] = ACTIONS(4915),
    [aux_sym_basic_type_token32] = ACTIONS(4915),
    [aux_sym_basic_type_token33] = ACTIONS(4915),
    [aux_sym_basic_type_token34] = ACTIONS(4915),
    [aux_sym_basic_type_token35] = ACTIONS(4915),
    [aux_sym_basic_type_token36] = ACTIONS(4915),
    [aux_sym_basic_type_token37] = ACTIONS(4915),
    [aux_sym_basic_type_token38] = ACTIONS(4915),
    [aux_sym_basic_type_token39] = ACTIONS(4915),
    [aux_sym_basic_type_token40] = ACTIONS(4915),
    [aux_sym_basic_type_token41] = ACTIONS(4915),
    [aux_sym_basic_type_token42] = ACTIONS(4915),
    [aux_sym_basic_type_token43] = ACTIONS(4915),
    [aux_sym_basic_type_token44] = ACTIONS(4915),
    [aux_sym_basic_type_token45] = ACTIONS(4915),
    [aux_sym_basic_type_token46] = ACTIONS(4915),
    [aux_sym_basic_type_token47] = ACTIONS(4915),
    [aux_sym_basic_type_token48] = ACTIONS(4915),
    [aux_sym_basic_type_token49] = ACTIONS(4915),
    [aux_sym_basic_type_token50] = ACTIONS(4915),
    [aux_sym_basic_type_token51] = ACTIONS(4915),
    [aux_sym_basic_type_token52] = ACTIONS(4915),
    [aux_sym_basic_type_token53] = ACTIONS(4915),
    [aux_sym_basic_type_token54] = ACTIONS(4915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4907),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4907),
    [sym_query_keyword] = ACTIONS(4907),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4907),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4921),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2207)] = {
    [sym_type_specification] = STATE(9944),
    [sym_text_type] = STATE(9959),
    [sym_code_type] = STATE(9959),
    [sym_option_type] = STATE(9958),
    [sym_record_type] = STATE(9958),
    [sym_dotnet_type] = STATE(9958),
    [sym_object_reference_type] = STATE(9958),
    [sym_array_type] = STATE(9961),
    [sym_list_type] = STATE(9961),
    [sym_dictionary_type] = STATE(9961),
    [sym_basic_type] = STATE(9958),
    [sym_codeunit_keyword] = STATE(11563),
    [sym_xmlport_keyword] = STATE(11563),
    [sym_enum_keyword] = STATE(11563),
    [sym_controladdin_keyword] = STATE(11563),
    [sym_dotnet_keyword] = STATE(11266),
    [sym_identifier] = ACTIONS(5151),
    [aux_sym_text_type_token1] = ACTIONS(5153),
    [aux_sym_code_type_token1] = ACTIONS(5155),
    [aux_sym_option_type_token1] = ACTIONS(5157),
    [aux_sym_record_type_token1] = ACTIONS(5159),
    [aux_sym_object_reference_type_token1] = ACTIONS(5161),
    [aux_sym_object_reference_type_token2] = ACTIONS(5161),
    [aux_sym_array_type_token1] = ACTIONS(5163),
    [aux_sym_list_type_token1] = ACTIONS(5165),
    [aux_sym_dictionary_type_token1] = ACTIONS(5167),
    [aux_sym_basic_type_token1] = ACTIONS(5169),
    [aux_sym_basic_type_token2] = ACTIONS(5169),
    [aux_sym_basic_type_token3] = ACTIONS(5169),
    [aux_sym_basic_type_token4] = ACTIONS(5169),
    [aux_sym_basic_type_token5] = ACTIONS(5169),
    [aux_sym_basic_type_token6] = ACTIONS(5171),
    [aux_sym_basic_type_token7] = ACTIONS(5169),
    [aux_sym_basic_type_token8] = ACTIONS(5169),
    [aux_sym_basic_type_token9] = ACTIONS(5169),
    [aux_sym_basic_type_token10] = ACTIONS(5169),
    [aux_sym_basic_type_token11] = ACTIONS(5169),
    [aux_sym_basic_type_token12] = ACTIONS(5169),
    [aux_sym_basic_type_token13] = ACTIONS(5173),
    [aux_sym_basic_type_token14] = ACTIONS(5169),
    [aux_sym_basic_type_token15] = ACTIONS(5169),
    [aux_sym_basic_type_token16] = ACTIONS(5169),
    [aux_sym_basic_type_token17] = ACTIONS(5169),
    [aux_sym_basic_type_token18] = ACTIONS(5169),
    [aux_sym_basic_type_token19] = ACTIONS(5169),
    [aux_sym_basic_type_token20] = ACTIONS(5169),
    [aux_sym_basic_type_token21] = ACTIONS(5169),
    [aux_sym_basic_type_token22] = ACTIONS(5169),
    [aux_sym_basic_type_token23] = ACTIONS(5169),
    [aux_sym_basic_type_token24] = ACTIONS(5169),
    [aux_sym_basic_type_token25] = ACTIONS(5169),
    [aux_sym_basic_type_token26] = ACTIONS(5169),
    [aux_sym_basic_type_token27] = ACTIONS(5169),
    [aux_sym_basic_type_token28] = ACTIONS(5169),
    [aux_sym_basic_type_token29] = ACTIONS(5169),
    [aux_sym_basic_type_token30] = ACTIONS(5169),
    [aux_sym_basic_type_token31] = ACTIONS(5169),
    [aux_sym_basic_type_token32] = ACTIONS(5169),
    [aux_sym_basic_type_token33] = ACTIONS(5169),
    [aux_sym_basic_type_token34] = ACTIONS(5169),
    [aux_sym_basic_type_token35] = ACTIONS(5169),
    [aux_sym_basic_type_token36] = ACTIONS(5169),
    [aux_sym_basic_type_token37] = ACTIONS(5169),
    [aux_sym_basic_type_token38] = ACTIONS(5169),
    [aux_sym_basic_type_token39] = ACTIONS(5169),
    [aux_sym_basic_type_token40] = ACTIONS(5169),
    [aux_sym_basic_type_token41] = ACTIONS(5169),
    [aux_sym_basic_type_token42] = ACTIONS(5169),
    [aux_sym_basic_type_token43] = ACTIONS(5169),
    [aux_sym_basic_type_token44] = ACTIONS(5169),
    [aux_sym_basic_type_token45] = ACTIONS(5169),
    [aux_sym_basic_type_token46] = ACTIONS(5169),
    [aux_sym_basic_type_token47] = ACTIONS(5169),
    [aux_sym_basic_type_token48] = ACTIONS(5169),
    [aux_sym_basic_type_token49] = ACTIONS(5169),
    [aux_sym_basic_type_token50] = ACTIONS(5169),
    [aux_sym_basic_type_token51] = ACTIONS(5169),
    [aux_sym_basic_type_token52] = ACTIONS(5169),
    [aux_sym_basic_type_token53] = ACTIONS(5169),
    [aux_sym_basic_type_token54] = ACTIONS(5169),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5161),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5161),
    [sym_query_keyword] = ACTIONS(5161),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5161),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5175),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2208)] = {
    [sym_type_specification] = STATE(16475),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2209)] = {
    [sym_type_specification] = STATE(8144),
    [sym_text_type] = STATE(8133),
    [sym_code_type] = STATE(8133),
    [sym_option_type] = STATE(8132),
    [sym_record_type] = STATE(8132),
    [sym_dotnet_type] = STATE(8132),
    [sym_object_reference_type] = STATE(8132),
    [sym_array_type] = STATE(8113),
    [sym_list_type] = STATE(8113),
    [sym_dictionary_type] = STATE(8113),
    [sym_basic_type] = STATE(8132),
    [sym_codeunit_keyword] = STATE(11424),
    [sym_xmlport_keyword] = STATE(11424),
    [sym_enum_keyword] = STATE(11424),
    [sym_controladdin_keyword] = STATE(11424),
    [sym_dotnet_keyword] = STATE(11298),
    [sym_identifier] = ACTIONS(5037),
    [aux_sym_text_type_token1] = ACTIONS(5039),
    [aux_sym_code_type_token1] = ACTIONS(5041),
    [aux_sym_option_type_token1] = ACTIONS(5043),
    [aux_sym_record_type_token1] = ACTIONS(5045),
    [aux_sym_object_reference_type_token1] = ACTIONS(5047),
    [aux_sym_object_reference_type_token2] = ACTIONS(5047),
    [aux_sym_array_type_token1] = ACTIONS(5049),
    [aux_sym_list_type_token1] = ACTIONS(5051),
    [aux_sym_dictionary_type_token1] = ACTIONS(5053),
    [aux_sym_basic_type_token1] = ACTIONS(5055),
    [aux_sym_basic_type_token2] = ACTIONS(5055),
    [aux_sym_basic_type_token3] = ACTIONS(5055),
    [aux_sym_basic_type_token4] = ACTIONS(5055),
    [aux_sym_basic_type_token5] = ACTIONS(5055),
    [aux_sym_basic_type_token6] = ACTIONS(5057),
    [aux_sym_basic_type_token7] = ACTIONS(5055),
    [aux_sym_basic_type_token8] = ACTIONS(5055),
    [aux_sym_basic_type_token9] = ACTIONS(5055),
    [aux_sym_basic_type_token10] = ACTIONS(5055),
    [aux_sym_basic_type_token11] = ACTIONS(5055),
    [aux_sym_basic_type_token12] = ACTIONS(5055),
    [aux_sym_basic_type_token13] = ACTIONS(5059),
    [aux_sym_basic_type_token14] = ACTIONS(5055),
    [aux_sym_basic_type_token15] = ACTIONS(5055),
    [aux_sym_basic_type_token16] = ACTIONS(5055),
    [aux_sym_basic_type_token17] = ACTIONS(5055),
    [aux_sym_basic_type_token18] = ACTIONS(5055),
    [aux_sym_basic_type_token19] = ACTIONS(5055),
    [aux_sym_basic_type_token20] = ACTIONS(5055),
    [aux_sym_basic_type_token21] = ACTIONS(5055),
    [aux_sym_basic_type_token22] = ACTIONS(5055),
    [aux_sym_basic_type_token23] = ACTIONS(5055),
    [aux_sym_basic_type_token24] = ACTIONS(5055),
    [aux_sym_basic_type_token25] = ACTIONS(5055),
    [aux_sym_basic_type_token26] = ACTIONS(5055),
    [aux_sym_basic_type_token27] = ACTIONS(5055),
    [aux_sym_basic_type_token28] = ACTIONS(5055),
    [aux_sym_basic_type_token29] = ACTIONS(5055),
    [aux_sym_basic_type_token30] = ACTIONS(5055),
    [aux_sym_basic_type_token31] = ACTIONS(5055),
    [aux_sym_basic_type_token32] = ACTIONS(5055),
    [aux_sym_basic_type_token33] = ACTIONS(5055),
    [aux_sym_basic_type_token34] = ACTIONS(5055),
    [aux_sym_basic_type_token35] = ACTIONS(5055),
    [aux_sym_basic_type_token36] = ACTIONS(5055),
    [aux_sym_basic_type_token37] = ACTIONS(5055),
    [aux_sym_basic_type_token38] = ACTIONS(5055),
    [aux_sym_basic_type_token39] = ACTIONS(5055),
    [aux_sym_basic_type_token40] = ACTIONS(5055),
    [aux_sym_basic_type_token41] = ACTIONS(5055),
    [aux_sym_basic_type_token42] = ACTIONS(5055),
    [aux_sym_basic_type_token43] = ACTIONS(5055),
    [aux_sym_basic_type_token44] = ACTIONS(5055),
    [aux_sym_basic_type_token45] = ACTIONS(5055),
    [aux_sym_basic_type_token46] = ACTIONS(5055),
    [aux_sym_basic_type_token47] = ACTIONS(5055),
    [aux_sym_basic_type_token48] = ACTIONS(5055),
    [aux_sym_basic_type_token49] = ACTIONS(5055),
    [aux_sym_basic_type_token50] = ACTIONS(5055),
    [aux_sym_basic_type_token51] = ACTIONS(5055),
    [aux_sym_basic_type_token52] = ACTIONS(5055),
    [aux_sym_basic_type_token53] = ACTIONS(5055),
    [aux_sym_basic_type_token54] = ACTIONS(5055),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5047),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5047),
    [sym_query_keyword] = ACTIONS(5047),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5047),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2210)] = {
    [sym_type_specification] = STATE(8145),
    [sym_text_type] = STATE(8133),
    [sym_code_type] = STATE(8133),
    [sym_option_type] = STATE(8132),
    [sym_record_type] = STATE(8132),
    [sym_dotnet_type] = STATE(8132),
    [sym_object_reference_type] = STATE(8132),
    [sym_array_type] = STATE(8113),
    [sym_list_type] = STATE(8113),
    [sym_dictionary_type] = STATE(8113),
    [sym_basic_type] = STATE(8132),
    [sym_codeunit_keyword] = STATE(11424),
    [sym_xmlport_keyword] = STATE(11424),
    [sym_enum_keyword] = STATE(11424),
    [sym_controladdin_keyword] = STATE(11424),
    [sym_dotnet_keyword] = STATE(11298),
    [sym_identifier] = ACTIONS(5037),
    [aux_sym_text_type_token1] = ACTIONS(5039),
    [aux_sym_code_type_token1] = ACTIONS(5041),
    [aux_sym_option_type_token1] = ACTIONS(5043),
    [aux_sym_record_type_token1] = ACTIONS(5045),
    [aux_sym_object_reference_type_token1] = ACTIONS(5047),
    [aux_sym_object_reference_type_token2] = ACTIONS(5047),
    [aux_sym_array_type_token1] = ACTIONS(5049),
    [aux_sym_list_type_token1] = ACTIONS(5051),
    [aux_sym_dictionary_type_token1] = ACTIONS(5053),
    [aux_sym_basic_type_token1] = ACTIONS(5055),
    [aux_sym_basic_type_token2] = ACTIONS(5055),
    [aux_sym_basic_type_token3] = ACTIONS(5055),
    [aux_sym_basic_type_token4] = ACTIONS(5055),
    [aux_sym_basic_type_token5] = ACTIONS(5055),
    [aux_sym_basic_type_token6] = ACTIONS(5057),
    [aux_sym_basic_type_token7] = ACTIONS(5055),
    [aux_sym_basic_type_token8] = ACTIONS(5055),
    [aux_sym_basic_type_token9] = ACTIONS(5055),
    [aux_sym_basic_type_token10] = ACTIONS(5055),
    [aux_sym_basic_type_token11] = ACTIONS(5055),
    [aux_sym_basic_type_token12] = ACTIONS(5055),
    [aux_sym_basic_type_token13] = ACTIONS(5059),
    [aux_sym_basic_type_token14] = ACTIONS(5055),
    [aux_sym_basic_type_token15] = ACTIONS(5055),
    [aux_sym_basic_type_token16] = ACTIONS(5055),
    [aux_sym_basic_type_token17] = ACTIONS(5055),
    [aux_sym_basic_type_token18] = ACTIONS(5055),
    [aux_sym_basic_type_token19] = ACTIONS(5055),
    [aux_sym_basic_type_token20] = ACTIONS(5055),
    [aux_sym_basic_type_token21] = ACTIONS(5055),
    [aux_sym_basic_type_token22] = ACTIONS(5055),
    [aux_sym_basic_type_token23] = ACTIONS(5055),
    [aux_sym_basic_type_token24] = ACTIONS(5055),
    [aux_sym_basic_type_token25] = ACTIONS(5055),
    [aux_sym_basic_type_token26] = ACTIONS(5055),
    [aux_sym_basic_type_token27] = ACTIONS(5055),
    [aux_sym_basic_type_token28] = ACTIONS(5055),
    [aux_sym_basic_type_token29] = ACTIONS(5055),
    [aux_sym_basic_type_token30] = ACTIONS(5055),
    [aux_sym_basic_type_token31] = ACTIONS(5055),
    [aux_sym_basic_type_token32] = ACTIONS(5055),
    [aux_sym_basic_type_token33] = ACTIONS(5055),
    [aux_sym_basic_type_token34] = ACTIONS(5055),
    [aux_sym_basic_type_token35] = ACTIONS(5055),
    [aux_sym_basic_type_token36] = ACTIONS(5055),
    [aux_sym_basic_type_token37] = ACTIONS(5055),
    [aux_sym_basic_type_token38] = ACTIONS(5055),
    [aux_sym_basic_type_token39] = ACTIONS(5055),
    [aux_sym_basic_type_token40] = ACTIONS(5055),
    [aux_sym_basic_type_token41] = ACTIONS(5055),
    [aux_sym_basic_type_token42] = ACTIONS(5055),
    [aux_sym_basic_type_token43] = ACTIONS(5055),
    [aux_sym_basic_type_token44] = ACTIONS(5055),
    [aux_sym_basic_type_token45] = ACTIONS(5055),
    [aux_sym_basic_type_token46] = ACTIONS(5055),
    [aux_sym_basic_type_token47] = ACTIONS(5055),
    [aux_sym_basic_type_token48] = ACTIONS(5055),
    [aux_sym_basic_type_token49] = ACTIONS(5055),
    [aux_sym_basic_type_token50] = ACTIONS(5055),
    [aux_sym_basic_type_token51] = ACTIONS(5055),
    [aux_sym_basic_type_token52] = ACTIONS(5055),
    [aux_sym_basic_type_token53] = ACTIONS(5055),
    [aux_sym_basic_type_token54] = ACTIONS(5055),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5047),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5047),
    [sym_query_keyword] = ACTIONS(5047),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5047),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2211)] = {
    [sym_type_specification] = STATE(17951),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2212)] = {
    [sym_type_specification] = STATE(18266),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2213)] = {
    [sym_type_specification] = STATE(18087),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2214)] = {
    [sym_type_specification] = STATE(1849),
    [sym_text_type] = STATE(1844),
    [sym_code_type] = STATE(1844),
    [sym_option_type] = STATE(1836),
    [sym_record_type] = STATE(1836),
    [sym_dotnet_type] = STATE(1836),
    [sym_object_reference_type] = STATE(1836),
    [sym_array_type] = STATE(1845),
    [sym_list_type] = STATE(1845),
    [sym_dictionary_type] = STATE(1845),
    [sym_basic_type] = STATE(1836),
    [sym_codeunit_keyword] = STATE(11561),
    [sym_xmlport_keyword] = STATE(11561),
    [sym_enum_keyword] = STATE(11561),
    [sym_controladdin_keyword] = STATE(11561),
    [sym_dotnet_keyword] = STATE(11341),
    [sym_identifier] = ACTIONS(4949),
    [aux_sym_text_type_token1] = ACTIONS(4951),
    [aux_sym_code_type_token1] = ACTIONS(4953),
    [aux_sym_option_type_token1] = ACTIONS(4955),
    [aux_sym_record_type_token1] = ACTIONS(4957),
    [aux_sym_object_reference_type_token1] = ACTIONS(4959),
    [aux_sym_object_reference_type_token2] = ACTIONS(4959),
    [aux_sym_array_type_token1] = ACTIONS(4961),
    [aux_sym_list_type_token1] = ACTIONS(4963),
    [aux_sym_dictionary_type_token1] = ACTIONS(4965),
    [aux_sym_basic_type_token1] = ACTIONS(4967),
    [aux_sym_basic_type_token2] = ACTIONS(4967),
    [aux_sym_basic_type_token3] = ACTIONS(4967),
    [aux_sym_basic_type_token4] = ACTIONS(4967),
    [aux_sym_basic_type_token5] = ACTIONS(4967),
    [aux_sym_basic_type_token6] = ACTIONS(4969),
    [aux_sym_basic_type_token7] = ACTIONS(4967),
    [aux_sym_basic_type_token8] = ACTIONS(4967),
    [aux_sym_basic_type_token9] = ACTIONS(4967),
    [aux_sym_basic_type_token10] = ACTIONS(4967),
    [aux_sym_basic_type_token11] = ACTIONS(4967),
    [aux_sym_basic_type_token12] = ACTIONS(4967),
    [aux_sym_basic_type_token13] = ACTIONS(4971),
    [aux_sym_basic_type_token14] = ACTIONS(4967),
    [aux_sym_basic_type_token15] = ACTIONS(4967),
    [aux_sym_basic_type_token16] = ACTIONS(4967),
    [aux_sym_basic_type_token17] = ACTIONS(4967),
    [aux_sym_basic_type_token18] = ACTIONS(4967),
    [aux_sym_basic_type_token19] = ACTIONS(4967),
    [aux_sym_basic_type_token20] = ACTIONS(4967),
    [aux_sym_basic_type_token21] = ACTIONS(4967),
    [aux_sym_basic_type_token22] = ACTIONS(4967),
    [aux_sym_basic_type_token23] = ACTIONS(4967),
    [aux_sym_basic_type_token24] = ACTIONS(4967),
    [aux_sym_basic_type_token25] = ACTIONS(4967),
    [aux_sym_basic_type_token26] = ACTIONS(4967),
    [aux_sym_basic_type_token27] = ACTIONS(4967),
    [aux_sym_basic_type_token28] = ACTIONS(4967),
    [aux_sym_basic_type_token29] = ACTIONS(4967),
    [aux_sym_basic_type_token30] = ACTIONS(4967),
    [aux_sym_basic_type_token31] = ACTIONS(4967),
    [aux_sym_basic_type_token32] = ACTIONS(4967),
    [aux_sym_basic_type_token33] = ACTIONS(4967),
    [aux_sym_basic_type_token34] = ACTIONS(4967),
    [aux_sym_basic_type_token35] = ACTIONS(4967),
    [aux_sym_basic_type_token36] = ACTIONS(4967),
    [aux_sym_basic_type_token37] = ACTIONS(4967),
    [aux_sym_basic_type_token38] = ACTIONS(4967),
    [aux_sym_basic_type_token39] = ACTIONS(4967),
    [aux_sym_basic_type_token40] = ACTIONS(4967),
    [aux_sym_basic_type_token41] = ACTIONS(4967),
    [aux_sym_basic_type_token42] = ACTIONS(4967),
    [aux_sym_basic_type_token43] = ACTIONS(4967),
    [aux_sym_basic_type_token44] = ACTIONS(4967),
    [aux_sym_basic_type_token45] = ACTIONS(4967),
    [aux_sym_basic_type_token46] = ACTIONS(4967),
    [aux_sym_basic_type_token47] = ACTIONS(4967),
    [aux_sym_basic_type_token48] = ACTIONS(4967),
    [aux_sym_basic_type_token49] = ACTIONS(4967),
    [aux_sym_basic_type_token50] = ACTIONS(4967),
    [aux_sym_basic_type_token51] = ACTIONS(4967),
    [aux_sym_basic_type_token52] = ACTIONS(4967),
    [aux_sym_basic_type_token53] = ACTIONS(4967),
    [aux_sym_basic_type_token54] = ACTIONS(4967),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4959),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4959),
    [sym_query_keyword] = ACTIONS(4959),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4959),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4973),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2215)] = {
    [sym_type_specification] = STATE(1850),
    [sym_text_type] = STATE(1844),
    [sym_code_type] = STATE(1844),
    [sym_option_type] = STATE(1836),
    [sym_record_type] = STATE(1836),
    [sym_dotnet_type] = STATE(1836),
    [sym_object_reference_type] = STATE(1836),
    [sym_array_type] = STATE(1845),
    [sym_list_type] = STATE(1845),
    [sym_dictionary_type] = STATE(1845),
    [sym_basic_type] = STATE(1836),
    [sym_codeunit_keyword] = STATE(11561),
    [sym_xmlport_keyword] = STATE(11561),
    [sym_enum_keyword] = STATE(11561),
    [sym_controladdin_keyword] = STATE(11561),
    [sym_dotnet_keyword] = STATE(11341),
    [sym_identifier] = ACTIONS(4949),
    [aux_sym_text_type_token1] = ACTIONS(4951),
    [aux_sym_code_type_token1] = ACTIONS(4953),
    [aux_sym_option_type_token1] = ACTIONS(4955),
    [aux_sym_record_type_token1] = ACTIONS(4957),
    [aux_sym_object_reference_type_token1] = ACTIONS(4959),
    [aux_sym_object_reference_type_token2] = ACTIONS(4959),
    [aux_sym_array_type_token1] = ACTIONS(4961),
    [aux_sym_list_type_token1] = ACTIONS(4963),
    [aux_sym_dictionary_type_token1] = ACTIONS(4965),
    [aux_sym_basic_type_token1] = ACTIONS(4967),
    [aux_sym_basic_type_token2] = ACTIONS(4967),
    [aux_sym_basic_type_token3] = ACTIONS(4967),
    [aux_sym_basic_type_token4] = ACTIONS(4967),
    [aux_sym_basic_type_token5] = ACTIONS(4967),
    [aux_sym_basic_type_token6] = ACTIONS(4969),
    [aux_sym_basic_type_token7] = ACTIONS(4967),
    [aux_sym_basic_type_token8] = ACTIONS(4967),
    [aux_sym_basic_type_token9] = ACTIONS(4967),
    [aux_sym_basic_type_token10] = ACTIONS(4967),
    [aux_sym_basic_type_token11] = ACTIONS(4967),
    [aux_sym_basic_type_token12] = ACTIONS(4967),
    [aux_sym_basic_type_token13] = ACTIONS(4971),
    [aux_sym_basic_type_token14] = ACTIONS(4967),
    [aux_sym_basic_type_token15] = ACTIONS(4967),
    [aux_sym_basic_type_token16] = ACTIONS(4967),
    [aux_sym_basic_type_token17] = ACTIONS(4967),
    [aux_sym_basic_type_token18] = ACTIONS(4967),
    [aux_sym_basic_type_token19] = ACTIONS(4967),
    [aux_sym_basic_type_token20] = ACTIONS(4967),
    [aux_sym_basic_type_token21] = ACTIONS(4967),
    [aux_sym_basic_type_token22] = ACTIONS(4967),
    [aux_sym_basic_type_token23] = ACTIONS(4967),
    [aux_sym_basic_type_token24] = ACTIONS(4967),
    [aux_sym_basic_type_token25] = ACTIONS(4967),
    [aux_sym_basic_type_token26] = ACTIONS(4967),
    [aux_sym_basic_type_token27] = ACTIONS(4967),
    [aux_sym_basic_type_token28] = ACTIONS(4967),
    [aux_sym_basic_type_token29] = ACTIONS(4967),
    [aux_sym_basic_type_token30] = ACTIONS(4967),
    [aux_sym_basic_type_token31] = ACTIONS(4967),
    [aux_sym_basic_type_token32] = ACTIONS(4967),
    [aux_sym_basic_type_token33] = ACTIONS(4967),
    [aux_sym_basic_type_token34] = ACTIONS(4967),
    [aux_sym_basic_type_token35] = ACTIONS(4967),
    [aux_sym_basic_type_token36] = ACTIONS(4967),
    [aux_sym_basic_type_token37] = ACTIONS(4967),
    [aux_sym_basic_type_token38] = ACTIONS(4967),
    [aux_sym_basic_type_token39] = ACTIONS(4967),
    [aux_sym_basic_type_token40] = ACTIONS(4967),
    [aux_sym_basic_type_token41] = ACTIONS(4967),
    [aux_sym_basic_type_token42] = ACTIONS(4967),
    [aux_sym_basic_type_token43] = ACTIONS(4967),
    [aux_sym_basic_type_token44] = ACTIONS(4967),
    [aux_sym_basic_type_token45] = ACTIONS(4967),
    [aux_sym_basic_type_token46] = ACTIONS(4967),
    [aux_sym_basic_type_token47] = ACTIONS(4967),
    [aux_sym_basic_type_token48] = ACTIONS(4967),
    [aux_sym_basic_type_token49] = ACTIONS(4967),
    [aux_sym_basic_type_token50] = ACTIONS(4967),
    [aux_sym_basic_type_token51] = ACTIONS(4967),
    [aux_sym_basic_type_token52] = ACTIONS(4967),
    [aux_sym_basic_type_token53] = ACTIONS(4967),
    [aux_sym_basic_type_token54] = ACTIONS(4967),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(4959),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4959),
    [sym_query_keyword] = ACTIONS(4959),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(4959),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4973),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2216)] = {
    [sym_type_specification] = STATE(16686),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2217)] = {
    [sym_type_specification] = STATE(16762),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2218)] = {
    [sym_type_specification] = STATE(16820),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2219)] = {
    [sym_type_specification] = STATE(16869),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2220)] = {
    [sym_type_specification] = STATE(16915),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2221)] = {
    [sym_type_specification] = STATE(16956),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2222)] = {
    [sym_type_specification] = STATE(16965),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2223)] = {
    [sym_type_specification] = STATE(16974),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2224)] = {
    [sym_type_specification] = STATE(16981),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2225)] = {
    [sym_type_specification] = STATE(16988),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2226)] = {
    [sym_type_specification] = STATE(2019),
    [sym_text_type] = STATE(1947),
    [sym_code_type] = STATE(1947),
    [sym_option_type] = STATE(1945),
    [sym_record_type] = STATE(1945),
    [sym_dotnet_type] = STATE(1945),
    [sym_object_reference_type] = STATE(1945),
    [sym_array_type] = STATE(1957),
    [sym_list_type] = STATE(1957),
    [sym_dictionary_type] = STATE(1957),
    [sym_basic_type] = STATE(1945),
    [sym_codeunit_keyword] = STATE(11489),
    [sym_xmlport_keyword] = STATE(11489),
    [sym_enum_keyword] = STATE(11489),
    [sym_controladdin_keyword] = STATE(11489),
    [sym_dotnet_keyword] = STATE(11269),
    [sym_identifier] = ACTIONS(5011),
    [aux_sym_text_type_token1] = ACTIONS(5013),
    [aux_sym_code_type_token1] = ACTIONS(5015),
    [aux_sym_option_type_token1] = ACTIONS(5017),
    [aux_sym_record_type_token1] = ACTIONS(5019),
    [aux_sym_object_reference_type_token1] = ACTIONS(5021),
    [aux_sym_object_reference_type_token2] = ACTIONS(5021),
    [aux_sym_array_type_token1] = ACTIONS(5023),
    [aux_sym_list_type_token1] = ACTIONS(5025),
    [aux_sym_dictionary_type_token1] = ACTIONS(5027),
    [aux_sym_basic_type_token1] = ACTIONS(5029),
    [aux_sym_basic_type_token2] = ACTIONS(5029),
    [aux_sym_basic_type_token3] = ACTIONS(5029),
    [aux_sym_basic_type_token4] = ACTIONS(5029),
    [aux_sym_basic_type_token5] = ACTIONS(5029),
    [aux_sym_basic_type_token6] = ACTIONS(5031),
    [aux_sym_basic_type_token7] = ACTIONS(5029),
    [aux_sym_basic_type_token8] = ACTIONS(5029),
    [aux_sym_basic_type_token9] = ACTIONS(5029),
    [aux_sym_basic_type_token10] = ACTIONS(5029),
    [aux_sym_basic_type_token11] = ACTIONS(5029),
    [aux_sym_basic_type_token12] = ACTIONS(5029),
    [aux_sym_basic_type_token13] = ACTIONS(5033),
    [aux_sym_basic_type_token14] = ACTIONS(5029),
    [aux_sym_basic_type_token15] = ACTIONS(5029),
    [aux_sym_basic_type_token16] = ACTIONS(5029),
    [aux_sym_basic_type_token17] = ACTIONS(5029),
    [aux_sym_basic_type_token18] = ACTIONS(5029),
    [aux_sym_basic_type_token19] = ACTIONS(5029),
    [aux_sym_basic_type_token20] = ACTIONS(5029),
    [aux_sym_basic_type_token21] = ACTIONS(5029),
    [aux_sym_basic_type_token22] = ACTIONS(5029),
    [aux_sym_basic_type_token23] = ACTIONS(5029),
    [aux_sym_basic_type_token24] = ACTIONS(5029),
    [aux_sym_basic_type_token25] = ACTIONS(5029),
    [aux_sym_basic_type_token26] = ACTIONS(5029),
    [aux_sym_basic_type_token27] = ACTIONS(5029),
    [aux_sym_basic_type_token28] = ACTIONS(5029),
    [aux_sym_basic_type_token29] = ACTIONS(5029),
    [aux_sym_basic_type_token30] = ACTIONS(5029),
    [aux_sym_basic_type_token31] = ACTIONS(5029),
    [aux_sym_basic_type_token32] = ACTIONS(5029),
    [aux_sym_basic_type_token33] = ACTIONS(5029),
    [aux_sym_basic_type_token34] = ACTIONS(5029),
    [aux_sym_basic_type_token35] = ACTIONS(5029),
    [aux_sym_basic_type_token36] = ACTIONS(5029),
    [aux_sym_basic_type_token37] = ACTIONS(5029),
    [aux_sym_basic_type_token38] = ACTIONS(5029),
    [aux_sym_basic_type_token39] = ACTIONS(5029),
    [aux_sym_basic_type_token40] = ACTIONS(5029),
    [aux_sym_basic_type_token41] = ACTIONS(5029),
    [aux_sym_basic_type_token42] = ACTIONS(5029),
    [aux_sym_basic_type_token43] = ACTIONS(5029),
    [aux_sym_basic_type_token44] = ACTIONS(5029),
    [aux_sym_basic_type_token45] = ACTIONS(5029),
    [aux_sym_basic_type_token46] = ACTIONS(5029),
    [aux_sym_basic_type_token47] = ACTIONS(5029),
    [aux_sym_basic_type_token48] = ACTIONS(5029),
    [aux_sym_basic_type_token49] = ACTIONS(5029),
    [aux_sym_basic_type_token50] = ACTIONS(5029),
    [aux_sym_basic_type_token51] = ACTIONS(5029),
    [aux_sym_basic_type_token52] = ACTIONS(5029),
    [aux_sym_basic_type_token53] = ACTIONS(5029),
    [aux_sym_basic_type_token54] = ACTIONS(5029),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5021),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5021),
    [sym_query_keyword] = ACTIONS(5021),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5021),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5035),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2227)] = {
    [sym_type_specification] = STATE(2021),
    [sym_text_type] = STATE(1947),
    [sym_code_type] = STATE(1947),
    [sym_option_type] = STATE(1945),
    [sym_record_type] = STATE(1945),
    [sym_dotnet_type] = STATE(1945),
    [sym_object_reference_type] = STATE(1945),
    [sym_array_type] = STATE(1957),
    [sym_list_type] = STATE(1957),
    [sym_dictionary_type] = STATE(1957),
    [sym_basic_type] = STATE(1945),
    [sym_codeunit_keyword] = STATE(11489),
    [sym_xmlport_keyword] = STATE(11489),
    [sym_enum_keyword] = STATE(11489),
    [sym_controladdin_keyword] = STATE(11489),
    [sym_dotnet_keyword] = STATE(11269),
    [sym_identifier] = ACTIONS(5011),
    [aux_sym_text_type_token1] = ACTIONS(5013),
    [aux_sym_code_type_token1] = ACTIONS(5015),
    [aux_sym_option_type_token1] = ACTIONS(5017),
    [aux_sym_record_type_token1] = ACTIONS(5019),
    [aux_sym_object_reference_type_token1] = ACTIONS(5021),
    [aux_sym_object_reference_type_token2] = ACTIONS(5021),
    [aux_sym_array_type_token1] = ACTIONS(5023),
    [aux_sym_list_type_token1] = ACTIONS(5025),
    [aux_sym_dictionary_type_token1] = ACTIONS(5027),
    [aux_sym_basic_type_token1] = ACTIONS(5029),
    [aux_sym_basic_type_token2] = ACTIONS(5029),
    [aux_sym_basic_type_token3] = ACTIONS(5029),
    [aux_sym_basic_type_token4] = ACTIONS(5029),
    [aux_sym_basic_type_token5] = ACTIONS(5029),
    [aux_sym_basic_type_token6] = ACTIONS(5031),
    [aux_sym_basic_type_token7] = ACTIONS(5029),
    [aux_sym_basic_type_token8] = ACTIONS(5029),
    [aux_sym_basic_type_token9] = ACTIONS(5029),
    [aux_sym_basic_type_token10] = ACTIONS(5029),
    [aux_sym_basic_type_token11] = ACTIONS(5029),
    [aux_sym_basic_type_token12] = ACTIONS(5029),
    [aux_sym_basic_type_token13] = ACTIONS(5033),
    [aux_sym_basic_type_token14] = ACTIONS(5029),
    [aux_sym_basic_type_token15] = ACTIONS(5029),
    [aux_sym_basic_type_token16] = ACTIONS(5029),
    [aux_sym_basic_type_token17] = ACTIONS(5029),
    [aux_sym_basic_type_token18] = ACTIONS(5029),
    [aux_sym_basic_type_token19] = ACTIONS(5029),
    [aux_sym_basic_type_token20] = ACTIONS(5029),
    [aux_sym_basic_type_token21] = ACTIONS(5029),
    [aux_sym_basic_type_token22] = ACTIONS(5029),
    [aux_sym_basic_type_token23] = ACTIONS(5029),
    [aux_sym_basic_type_token24] = ACTIONS(5029),
    [aux_sym_basic_type_token25] = ACTIONS(5029),
    [aux_sym_basic_type_token26] = ACTIONS(5029),
    [aux_sym_basic_type_token27] = ACTIONS(5029),
    [aux_sym_basic_type_token28] = ACTIONS(5029),
    [aux_sym_basic_type_token29] = ACTIONS(5029),
    [aux_sym_basic_type_token30] = ACTIONS(5029),
    [aux_sym_basic_type_token31] = ACTIONS(5029),
    [aux_sym_basic_type_token32] = ACTIONS(5029),
    [aux_sym_basic_type_token33] = ACTIONS(5029),
    [aux_sym_basic_type_token34] = ACTIONS(5029),
    [aux_sym_basic_type_token35] = ACTIONS(5029),
    [aux_sym_basic_type_token36] = ACTIONS(5029),
    [aux_sym_basic_type_token37] = ACTIONS(5029),
    [aux_sym_basic_type_token38] = ACTIONS(5029),
    [aux_sym_basic_type_token39] = ACTIONS(5029),
    [aux_sym_basic_type_token40] = ACTIONS(5029),
    [aux_sym_basic_type_token41] = ACTIONS(5029),
    [aux_sym_basic_type_token42] = ACTIONS(5029),
    [aux_sym_basic_type_token43] = ACTIONS(5029),
    [aux_sym_basic_type_token44] = ACTIONS(5029),
    [aux_sym_basic_type_token45] = ACTIONS(5029),
    [aux_sym_basic_type_token46] = ACTIONS(5029),
    [aux_sym_basic_type_token47] = ACTIONS(5029),
    [aux_sym_basic_type_token48] = ACTIONS(5029),
    [aux_sym_basic_type_token49] = ACTIONS(5029),
    [aux_sym_basic_type_token50] = ACTIONS(5029),
    [aux_sym_basic_type_token51] = ACTIONS(5029),
    [aux_sym_basic_type_token52] = ACTIONS(5029),
    [aux_sym_basic_type_token53] = ACTIONS(5029),
    [aux_sym_basic_type_token54] = ACTIONS(5029),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5021),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5021),
    [sym_query_keyword] = ACTIONS(5021),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5021),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5035),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2228)] = {
    [sym_type_specification] = STATE(10233),
    [sym_text_type] = STATE(10207),
    [sym_code_type] = STATE(10207),
    [sym_option_type] = STATE(10199),
    [sym_record_type] = STATE(10199),
    [sym_dotnet_type] = STATE(10199),
    [sym_object_reference_type] = STATE(10199),
    [sym_array_type] = STATE(10216),
    [sym_list_type] = STATE(10216),
    [sym_dictionary_type] = STATE(10216),
    [sym_basic_type] = STATE(10199),
    [sym_codeunit_keyword] = STATE(11399),
    [sym_xmlport_keyword] = STATE(11399),
    [sym_enum_keyword] = STATE(11399),
    [sym_controladdin_keyword] = STATE(11399),
    [sym_dotnet_keyword] = STATE(11285),
    [sym_identifier] = ACTIONS(5093),
    [aux_sym_text_type_token1] = ACTIONS(5095),
    [aux_sym_code_type_token1] = ACTIONS(5097),
    [aux_sym_option_type_token1] = ACTIONS(5099),
    [aux_sym_record_type_token1] = ACTIONS(5101),
    [aux_sym_object_reference_type_token1] = ACTIONS(5103),
    [aux_sym_object_reference_type_token2] = ACTIONS(5103),
    [aux_sym_array_type_token1] = ACTIONS(5105),
    [aux_sym_list_type_token1] = ACTIONS(5107),
    [aux_sym_dictionary_type_token1] = ACTIONS(5109),
    [aux_sym_basic_type_token1] = ACTIONS(5111),
    [aux_sym_basic_type_token2] = ACTIONS(5111),
    [aux_sym_basic_type_token3] = ACTIONS(5111),
    [aux_sym_basic_type_token4] = ACTIONS(5111),
    [aux_sym_basic_type_token5] = ACTIONS(5111),
    [aux_sym_basic_type_token6] = ACTIONS(5113),
    [aux_sym_basic_type_token7] = ACTIONS(5111),
    [aux_sym_basic_type_token8] = ACTIONS(5111),
    [aux_sym_basic_type_token9] = ACTIONS(5111),
    [aux_sym_basic_type_token10] = ACTIONS(5111),
    [aux_sym_basic_type_token11] = ACTIONS(5111),
    [aux_sym_basic_type_token12] = ACTIONS(5111),
    [aux_sym_basic_type_token13] = ACTIONS(5115),
    [aux_sym_basic_type_token14] = ACTIONS(5111),
    [aux_sym_basic_type_token15] = ACTIONS(5111),
    [aux_sym_basic_type_token16] = ACTIONS(5111),
    [aux_sym_basic_type_token17] = ACTIONS(5111),
    [aux_sym_basic_type_token18] = ACTIONS(5111),
    [aux_sym_basic_type_token19] = ACTIONS(5111),
    [aux_sym_basic_type_token20] = ACTIONS(5111),
    [aux_sym_basic_type_token21] = ACTIONS(5111),
    [aux_sym_basic_type_token22] = ACTIONS(5111),
    [aux_sym_basic_type_token23] = ACTIONS(5111),
    [aux_sym_basic_type_token24] = ACTIONS(5111),
    [aux_sym_basic_type_token25] = ACTIONS(5111),
    [aux_sym_basic_type_token26] = ACTIONS(5111),
    [aux_sym_basic_type_token27] = ACTIONS(5111),
    [aux_sym_basic_type_token28] = ACTIONS(5111),
    [aux_sym_basic_type_token29] = ACTIONS(5111),
    [aux_sym_basic_type_token30] = ACTIONS(5111),
    [aux_sym_basic_type_token31] = ACTIONS(5111),
    [aux_sym_basic_type_token32] = ACTIONS(5111),
    [aux_sym_basic_type_token33] = ACTIONS(5111),
    [aux_sym_basic_type_token34] = ACTIONS(5111),
    [aux_sym_basic_type_token35] = ACTIONS(5111),
    [aux_sym_basic_type_token36] = ACTIONS(5111),
    [aux_sym_basic_type_token37] = ACTIONS(5111),
    [aux_sym_basic_type_token38] = ACTIONS(5111),
    [aux_sym_basic_type_token39] = ACTIONS(5111),
    [aux_sym_basic_type_token40] = ACTIONS(5111),
    [aux_sym_basic_type_token41] = ACTIONS(5111),
    [aux_sym_basic_type_token42] = ACTIONS(5111),
    [aux_sym_basic_type_token43] = ACTIONS(5111),
    [aux_sym_basic_type_token44] = ACTIONS(5111),
    [aux_sym_basic_type_token45] = ACTIONS(5111),
    [aux_sym_basic_type_token46] = ACTIONS(5111),
    [aux_sym_basic_type_token47] = ACTIONS(5111),
    [aux_sym_basic_type_token48] = ACTIONS(5111),
    [aux_sym_basic_type_token49] = ACTIONS(5111),
    [aux_sym_basic_type_token50] = ACTIONS(5111),
    [aux_sym_basic_type_token51] = ACTIONS(5111),
    [aux_sym_basic_type_token52] = ACTIONS(5111),
    [aux_sym_basic_type_token53] = ACTIONS(5111),
    [aux_sym_basic_type_token54] = ACTIONS(5111),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5103),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5103),
    [sym_query_keyword] = ACTIONS(5103),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5103),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5117),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2229)] = {
    [sym_type_specification] = STATE(10222),
    [sym_text_type] = STATE(10207),
    [sym_code_type] = STATE(10207),
    [sym_option_type] = STATE(10199),
    [sym_record_type] = STATE(10199),
    [sym_dotnet_type] = STATE(10199),
    [sym_object_reference_type] = STATE(10199),
    [sym_array_type] = STATE(10216),
    [sym_list_type] = STATE(10216),
    [sym_dictionary_type] = STATE(10216),
    [sym_basic_type] = STATE(10199),
    [sym_codeunit_keyword] = STATE(11399),
    [sym_xmlport_keyword] = STATE(11399),
    [sym_enum_keyword] = STATE(11399),
    [sym_controladdin_keyword] = STATE(11399),
    [sym_dotnet_keyword] = STATE(11285),
    [sym_identifier] = ACTIONS(5093),
    [aux_sym_text_type_token1] = ACTIONS(5095),
    [aux_sym_code_type_token1] = ACTIONS(5097),
    [aux_sym_option_type_token1] = ACTIONS(5099),
    [aux_sym_record_type_token1] = ACTIONS(5101),
    [aux_sym_object_reference_type_token1] = ACTIONS(5103),
    [aux_sym_object_reference_type_token2] = ACTIONS(5103),
    [aux_sym_array_type_token1] = ACTIONS(5105),
    [aux_sym_list_type_token1] = ACTIONS(5107),
    [aux_sym_dictionary_type_token1] = ACTIONS(5109),
    [aux_sym_basic_type_token1] = ACTIONS(5111),
    [aux_sym_basic_type_token2] = ACTIONS(5111),
    [aux_sym_basic_type_token3] = ACTIONS(5111),
    [aux_sym_basic_type_token4] = ACTIONS(5111),
    [aux_sym_basic_type_token5] = ACTIONS(5111),
    [aux_sym_basic_type_token6] = ACTIONS(5113),
    [aux_sym_basic_type_token7] = ACTIONS(5111),
    [aux_sym_basic_type_token8] = ACTIONS(5111),
    [aux_sym_basic_type_token9] = ACTIONS(5111),
    [aux_sym_basic_type_token10] = ACTIONS(5111),
    [aux_sym_basic_type_token11] = ACTIONS(5111),
    [aux_sym_basic_type_token12] = ACTIONS(5111),
    [aux_sym_basic_type_token13] = ACTIONS(5115),
    [aux_sym_basic_type_token14] = ACTIONS(5111),
    [aux_sym_basic_type_token15] = ACTIONS(5111),
    [aux_sym_basic_type_token16] = ACTIONS(5111),
    [aux_sym_basic_type_token17] = ACTIONS(5111),
    [aux_sym_basic_type_token18] = ACTIONS(5111),
    [aux_sym_basic_type_token19] = ACTIONS(5111),
    [aux_sym_basic_type_token20] = ACTIONS(5111),
    [aux_sym_basic_type_token21] = ACTIONS(5111),
    [aux_sym_basic_type_token22] = ACTIONS(5111),
    [aux_sym_basic_type_token23] = ACTIONS(5111),
    [aux_sym_basic_type_token24] = ACTIONS(5111),
    [aux_sym_basic_type_token25] = ACTIONS(5111),
    [aux_sym_basic_type_token26] = ACTIONS(5111),
    [aux_sym_basic_type_token27] = ACTIONS(5111),
    [aux_sym_basic_type_token28] = ACTIONS(5111),
    [aux_sym_basic_type_token29] = ACTIONS(5111),
    [aux_sym_basic_type_token30] = ACTIONS(5111),
    [aux_sym_basic_type_token31] = ACTIONS(5111),
    [aux_sym_basic_type_token32] = ACTIONS(5111),
    [aux_sym_basic_type_token33] = ACTIONS(5111),
    [aux_sym_basic_type_token34] = ACTIONS(5111),
    [aux_sym_basic_type_token35] = ACTIONS(5111),
    [aux_sym_basic_type_token36] = ACTIONS(5111),
    [aux_sym_basic_type_token37] = ACTIONS(5111),
    [aux_sym_basic_type_token38] = ACTIONS(5111),
    [aux_sym_basic_type_token39] = ACTIONS(5111),
    [aux_sym_basic_type_token40] = ACTIONS(5111),
    [aux_sym_basic_type_token41] = ACTIONS(5111),
    [aux_sym_basic_type_token42] = ACTIONS(5111),
    [aux_sym_basic_type_token43] = ACTIONS(5111),
    [aux_sym_basic_type_token44] = ACTIONS(5111),
    [aux_sym_basic_type_token45] = ACTIONS(5111),
    [aux_sym_basic_type_token46] = ACTIONS(5111),
    [aux_sym_basic_type_token47] = ACTIONS(5111),
    [aux_sym_basic_type_token48] = ACTIONS(5111),
    [aux_sym_basic_type_token49] = ACTIONS(5111),
    [aux_sym_basic_type_token50] = ACTIONS(5111),
    [aux_sym_basic_type_token51] = ACTIONS(5111),
    [aux_sym_basic_type_token52] = ACTIONS(5111),
    [aux_sym_basic_type_token53] = ACTIONS(5111),
    [aux_sym_basic_type_token54] = ACTIONS(5111),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5103),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5103),
    [sym_query_keyword] = ACTIONS(5103),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5103),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5117),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2230)] = {
    [sym_type_specification] = STATE(11343),
    [sym_text_type] = STATE(11382),
    [sym_code_type] = STATE(11382),
    [sym_option_type] = STATE(11323),
    [sym_record_type] = STATE(11323),
    [sym_dotnet_type] = STATE(11323),
    [sym_object_reference_type] = STATE(11323),
    [sym_array_type] = STATE(11313),
    [sym_list_type] = STATE(11313),
    [sym_dictionary_type] = STATE(11313),
    [sym_basic_type] = STATE(11323),
    [sym_codeunit_keyword] = STATE(11421),
    [sym_xmlport_keyword] = STATE(11421),
    [sym_enum_keyword] = STATE(11421),
    [sym_controladdin_keyword] = STATE(11421),
    [sym_dotnet_keyword] = STATE(11291),
    [sym_identifier] = ACTIONS(5119),
    [aux_sym_text_type_token1] = ACTIONS(5121),
    [aux_sym_code_type_token1] = ACTIONS(5123),
    [aux_sym_option_type_token1] = ACTIONS(5125),
    [aux_sym_record_type_token1] = ACTIONS(5127),
    [aux_sym_object_reference_type_token1] = ACTIONS(5129),
    [aux_sym_object_reference_type_token2] = ACTIONS(5129),
    [aux_sym_array_type_token1] = ACTIONS(5131),
    [aux_sym_list_type_token1] = ACTIONS(5133),
    [aux_sym_dictionary_type_token1] = ACTIONS(5135),
    [aux_sym_basic_type_token1] = ACTIONS(5137),
    [aux_sym_basic_type_token2] = ACTIONS(5137),
    [aux_sym_basic_type_token3] = ACTIONS(5137),
    [aux_sym_basic_type_token4] = ACTIONS(5137),
    [aux_sym_basic_type_token5] = ACTIONS(5137),
    [aux_sym_basic_type_token6] = ACTIONS(5139),
    [aux_sym_basic_type_token7] = ACTIONS(5137),
    [aux_sym_basic_type_token8] = ACTIONS(5137),
    [aux_sym_basic_type_token9] = ACTIONS(5137),
    [aux_sym_basic_type_token10] = ACTIONS(5137),
    [aux_sym_basic_type_token11] = ACTIONS(5137),
    [aux_sym_basic_type_token12] = ACTIONS(5137),
    [aux_sym_basic_type_token13] = ACTIONS(5141),
    [aux_sym_basic_type_token14] = ACTIONS(5137),
    [aux_sym_basic_type_token15] = ACTIONS(5137),
    [aux_sym_basic_type_token16] = ACTIONS(5137),
    [aux_sym_basic_type_token17] = ACTIONS(5137),
    [aux_sym_basic_type_token18] = ACTIONS(5137),
    [aux_sym_basic_type_token19] = ACTIONS(5137),
    [aux_sym_basic_type_token20] = ACTIONS(5137),
    [aux_sym_basic_type_token21] = ACTIONS(5137),
    [aux_sym_basic_type_token22] = ACTIONS(5137),
    [aux_sym_basic_type_token23] = ACTIONS(5137),
    [aux_sym_basic_type_token24] = ACTIONS(5137),
    [aux_sym_basic_type_token25] = ACTIONS(5137),
    [aux_sym_basic_type_token26] = ACTIONS(5137),
    [aux_sym_basic_type_token27] = ACTIONS(5137),
    [aux_sym_basic_type_token28] = ACTIONS(5137),
    [aux_sym_basic_type_token29] = ACTIONS(5137),
    [aux_sym_basic_type_token30] = ACTIONS(5137),
    [aux_sym_basic_type_token31] = ACTIONS(5137),
    [aux_sym_basic_type_token32] = ACTIONS(5137),
    [aux_sym_basic_type_token33] = ACTIONS(5137),
    [aux_sym_basic_type_token34] = ACTIONS(5137),
    [aux_sym_basic_type_token35] = ACTIONS(5137),
    [aux_sym_basic_type_token36] = ACTIONS(5137),
    [aux_sym_basic_type_token37] = ACTIONS(5137),
    [aux_sym_basic_type_token38] = ACTIONS(5137),
    [aux_sym_basic_type_token39] = ACTIONS(5137),
    [aux_sym_basic_type_token40] = ACTIONS(5137),
    [aux_sym_basic_type_token41] = ACTIONS(5137),
    [aux_sym_basic_type_token42] = ACTIONS(5137),
    [aux_sym_basic_type_token43] = ACTIONS(5137),
    [aux_sym_basic_type_token44] = ACTIONS(5137),
    [aux_sym_basic_type_token45] = ACTIONS(5137),
    [aux_sym_basic_type_token46] = ACTIONS(5137),
    [aux_sym_basic_type_token47] = ACTIONS(5137),
    [aux_sym_basic_type_token48] = ACTIONS(5137),
    [aux_sym_basic_type_token49] = ACTIONS(5137),
    [aux_sym_basic_type_token50] = ACTIONS(5137),
    [aux_sym_basic_type_token51] = ACTIONS(5137),
    [aux_sym_basic_type_token52] = ACTIONS(5137),
    [aux_sym_basic_type_token53] = ACTIONS(5137),
    [aux_sym_basic_type_token54] = ACTIONS(5137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5129),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5129),
    [sym_query_keyword] = ACTIONS(5129),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5129),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5143),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2231)] = {
    [sym_type_specification] = STATE(11367),
    [sym_text_type] = STATE(11382),
    [sym_code_type] = STATE(11382),
    [sym_option_type] = STATE(11323),
    [sym_record_type] = STATE(11323),
    [sym_dotnet_type] = STATE(11323),
    [sym_object_reference_type] = STATE(11323),
    [sym_array_type] = STATE(11313),
    [sym_list_type] = STATE(11313),
    [sym_dictionary_type] = STATE(11313),
    [sym_basic_type] = STATE(11323),
    [sym_codeunit_keyword] = STATE(11421),
    [sym_xmlport_keyword] = STATE(11421),
    [sym_enum_keyword] = STATE(11421),
    [sym_controladdin_keyword] = STATE(11421),
    [sym_dotnet_keyword] = STATE(11291),
    [sym_identifier] = ACTIONS(5119),
    [aux_sym_text_type_token1] = ACTIONS(5121),
    [aux_sym_code_type_token1] = ACTIONS(5123),
    [aux_sym_option_type_token1] = ACTIONS(5125),
    [aux_sym_record_type_token1] = ACTIONS(5127),
    [aux_sym_object_reference_type_token1] = ACTIONS(5129),
    [aux_sym_object_reference_type_token2] = ACTIONS(5129),
    [aux_sym_array_type_token1] = ACTIONS(5131),
    [aux_sym_list_type_token1] = ACTIONS(5133),
    [aux_sym_dictionary_type_token1] = ACTIONS(5135),
    [aux_sym_basic_type_token1] = ACTIONS(5137),
    [aux_sym_basic_type_token2] = ACTIONS(5137),
    [aux_sym_basic_type_token3] = ACTIONS(5137),
    [aux_sym_basic_type_token4] = ACTIONS(5137),
    [aux_sym_basic_type_token5] = ACTIONS(5137),
    [aux_sym_basic_type_token6] = ACTIONS(5139),
    [aux_sym_basic_type_token7] = ACTIONS(5137),
    [aux_sym_basic_type_token8] = ACTIONS(5137),
    [aux_sym_basic_type_token9] = ACTIONS(5137),
    [aux_sym_basic_type_token10] = ACTIONS(5137),
    [aux_sym_basic_type_token11] = ACTIONS(5137),
    [aux_sym_basic_type_token12] = ACTIONS(5137),
    [aux_sym_basic_type_token13] = ACTIONS(5141),
    [aux_sym_basic_type_token14] = ACTIONS(5137),
    [aux_sym_basic_type_token15] = ACTIONS(5137),
    [aux_sym_basic_type_token16] = ACTIONS(5137),
    [aux_sym_basic_type_token17] = ACTIONS(5137),
    [aux_sym_basic_type_token18] = ACTIONS(5137),
    [aux_sym_basic_type_token19] = ACTIONS(5137),
    [aux_sym_basic_type_token20] = ACTIONS(5137),
    [aux_sym_basic_type_token21] = ACTIONS(5137),
    [aux_sym_basic_type_token22] = ACTIONS(5137),
    [aux_sym_basic_type_token23] = ACTIONS(5137),
    [aux_sym_basic_type_token24] = ACTIONS(5137),
    [aux_sym_basic_type_token25] = ACTIONS(5137),
    [aux_sym_basic_type_token26] = ACTIONS(5137),
    [aux_sym_basic_type_token27] = ACTIONS(5137),
    [aux_sym_basic_type_token28] = ACTIONS(5137),
    [aux_sym_basic_type_token29] = ACTIONS(5137),
    [aux_sym_basic_type_token30] = ACTIONS(5137),
    [aux_sym_basic_type_token31] = ACTIONS(5137),
    [aux_sym_basic_type_token32] = ACTIONS(5137),
    [aux_sym_basic_type_token33] = ACTIONS(5137),
    [aux_sym_basic_type_token34] = ACTIONS(5137),
    [aux_sym_basic_type_token35] = ACTIONS(5137),
    [aux_sym_basic_type_token36] = ACTIONS(5137),
    [aux_sym_basic_type_token37] = ACTIONS(5137),
    [aux_sym_basic_type_token38] = ACTIONS(5137),
    [aux_sym_basic_type_token39] = ACTIONS(5137),
    [aux_sym_basic_type_token40] = ACTIONS(5137),
    [aux_sym_basic_type_token41] = ACTIONS(5137),
    [aux_sym_basic_type_token42] = ACTIONS(5137),
    [aux_sym_basic_type_token43] = ACTIONS(5137),
    [aux_sym_basic_type_token44] = ACTIONS(5137),
    [aux_sym_basic_type_token45] = ACTIONS(5137),
    [aux_sym_basic_type_token46] = ACTIONS(5137),
    [aux_sym_basic_type_token47] = ACTIONS(5137),
    [aux_sym_basic_type_token48] = ACTIONS(5137),
    [aux_sym_basic_type_token49] = ACTIONS(5137),
    [aux_sym_basic_type_token50] = ACTIONS(5137),
    [aux_sym_basic_type_token51] = ACTIONS(5137),
    [aux_sym_basic_type_token52] = ACTIONS(5137),
    [aux_sym_basic_type_token53] = ACTIONS(5137),
    [aux_sym_basic_type_token54] = ACTIONS(5137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5129),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5129),
    [sym_query_keyword] = ACTIONS(5129),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5129),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5143),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2232)] = {
    [sym_type_specification] = STATE(8398),
    [sym_text_type] = STATE(8385),
    [sym_code_type] = STATE(8385),
    [sym_option_type] = STATE(8381),
    [sym_record_type] = STATE(8381),
    [sym_dotnet_type] = STATE(8381),
    [sym_object_reference_type] = STATE(8381),
    [sym_array_type] = STATE(8388),
    [sym_list_type] = STATE(8388),
    [sym_dictionary_type] = STATE(8388),
    [sym_basic_type] = STATE(8381),
    [sym_codeunit_keyword] = STATE(11394),
    [sym_xmlport_keyword] = STATE(11394),
    [sym_enum_keyword] = STATE(11394),
    [sym_controladdin_keyword] = STATE(11394),
    [sym_dotnet_keyword] = STATE(11271),
    [sym_identifier] = ACTIONS(5067),
    [aux_sym_text_type_token1] = ACTIONS(5069),
    [aux_sym_code_type_token1] = ACTIONS(5071),
    [aux_sym_option_type_token1] = ACTIONS(5073),
    [aux_sym_record_type_token1] = ACTIONS(5075),
    [aux_sym_object_reference_type_token1] = ACTIONS(5077),
    [aux_sym_object_reference_type_token2] = ACTIONS(5077),
    [aux_sym_array_type_token1] = ACTIONS(5079),
    [aux_sym_list_type_token1] = ACTIONS(5081),
    [aux_sym_dictionary_type_token1] = ACTIONS(5083),
    [aux_sym_basic_type_token1] = ACTIONS(5085),
    [aux_sym_basic_type_token2] = ACTIONS(5085),
    [aux_sym_basic_type_token3] = ACTIONS(5085),
    [aux_sym_basic_type_token4] = ACTIONS(5085),
    [aux_sym_basic_type_token5] = ACTIONS(5085),
    [aux_sym_basic_type_token6] = ACTIONS(5087),
    [aux_sym_basic_type_token7] = ACTIONS(5085),
    [aux_sym_basic_type_token8] = ACTIONS(5085),
    [aux_sym_basic_type_token9] = ACTIONS(5085),
    [aux_sym_basic_type_token10] = ACTIONS(5085),
    [aux_sym_basic_type_token11] = ACTIONS(5085),
    [aux_sym_basic_type_token12] = ACTIONS(5085),
    [aux_sym_basic_type_token13] = ACTIONS(5089),
    [aux_sym_basic_type_token14] = ACTIONS(5085),
    [aux_sym_basic_type_token15] = ACTIONS(5085),
    [aux_sym_basic_type_token16] = ACTIONS(5085),
    [aux_sym_basic_type_token17] = ACTIONS(5085),
    [aux_sym_basic_type_token18] = ACTIONS(5085),
    [aux_sym_basic_type_token19] = ACTIONS(5085),
    [aux_sym_basic_type_token20] = ACTIONS(5085),
    [aux_sym_basic_type_token21] = ACTIONS(5085),
    [aux_sym_basic_type_token22] = ACTIONS(5085),
    [aux_sym_basic_type_token23] = ACTIONS(5085),
    [aux_sym_basic_type_token24] = ACTIONS(5085),
    [aux_sym_basic_type_token25] = ACTIONS(5085),
    [aux_sym_basic_type_token26] = ACTIONS(5085),
    [aux_sym_basic_type_token27] = ACTIONS(5085),
    [aux_sym_basic_type_token28] = ACTIONS(5085),
    [aux_sym_basic_type_token29] = ACTIONS(5085),
    [aux_sym_basic_type_token30] = ACTIONS(5085),
    [aux_sym_basic_type_token31] = ACTIONS(5085),
    [aux_sym_basic_type_token32] = ACTIONS(5085),
    [aux_sym_basic_type_token33] = ACTIONS(5085),
    [aux_sym_basic_type_token34] = ACTIONS(5085),
    [aux_sym_basic_type_token35] = ACTIONS(5085),
    [aux_sym_basic_type_token36] = ACTIONS(5085),
    [aux_sym_basic_type_token37] = ACTIONS(5085),
    [aux_sym_basic_type_token38] = ACTIONS(5085),
    [aux_sym_basic_type_token39] = ACTIONS(5085),
    [aux_sym_basic_type_token40] = ACTIONS(5085),
    [aux_sym_basic_type_token41] = ACTIONS(5085),
    [aux_sym_basic_type_token42] = ACTIONS(5085),
    [aux_sym_basic_type_token43] = ACTIONS(5085),
    [aux_sym_basic_type_token44] = ACTIONS(5085),
    [aux_sym_basic_type_token45] = ACTIONS(5085),
    [aux_sym_basic_type_token46] = ACTIONS(5085),
    [aux_sym_basic_type_token47] = ACTIONS(5085),
    [aux_sym_basic_type_token48] = ACTIONS(5085),
    [aux_sym_basic_type_token49] = ACTIONS(5085),
    [aux_sym_basic_type_token50] = ACTIONS(5085),
    [aux_sym_basic_type_token51] = ACTIONS(5085),
    [aux_sym_basic_type_token52] = ACTIONS(5085),
    [aux_sym_basic_type_token53] = ACTIONS(5085),
    [aux_sym_basic_type_token54] = ACTIONS(5085),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5077),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5077),
    [sym_query_keyword] = ACTIONS(5077),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5077),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5091),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2233)] = {
    [sym_type_specification] = STATE(8399),
    [sym_text_type] = STATE(8385),
    [sym_code_type] = STATE(8385),
    [sym_option_type] = STATE(8381),
    [sym_record_type] = STATE(8381),
    [sym_dotnet_type] = STATE(8381),
    [sym_object_reference_type] = STATE(8381),
    [sym_array_type] = STATE(8388),
    [sym_list_type] = STATE(8388),
    [sym_dictionary_type] = STATE(8388),
    [sym_basic_type] = STATE(8381),
    [sym_codeunit_keyword] = STATE(11394),
    [sym_xmlport_keyword] = STATE(11394),
    [sym_enum_keyword] = STATE(11394),
    [sym_controladdin_keyword] = STATE(11394),
    [sym_dotnet_keyword] = STATE(11271),
    [sym_identifier] = ACTIONS(5067),
    [aux_sym_text_type_token1] = ACTIONS(5069),
    [aux_sym_code_type_token1] = ACTIONS(5071),
    [aux_sym_option_type_token1] = ACTIONS(5073),
    [aux_sym_record_type_token1] = ACTIONS(5075),
    [aux_sym_object_reference_type_token1] = ACTIONS(5077),
    [aux_sym_object_reference_type_token2] = ACTIONS(5077),
    [aux_sym_array_type_token1] = ACTIONS(5079),
    [aux_sym_list_type_token1] = ACTIONS(5081),
    [aux_sym_dictionary_type_token1] = ACTIONS(5083),
    [aux_sym_basic_type_token1] = ACTIONS(5085),
    [aux_sym_basic_type_token2] = ACTIONS(5085),
    [aux_sym_basic_type_token3] = ACTIONS(5085),
    [aux_sym_basic_type_token4] = ACTIONS(5085),
    [aux_sym_basic_type_token5] = ACTIONS(5085),
    [aux_sym_basic_type_token6] = ACTIONS(5087),
    [aux_sym_basic_type_token7] = ACTIONS(5085),
    [aux_sym_basic_type_token8] = ACTIONS(5085),
    [aux_sym_basic_type_token9] = ACTIONS(5085),
    [aux_sym_basic_type_token10] = ACTIONS(5085),
    [aux_sym_basic_type_token11] = ACTIONS(5085),
    [aux_sym_basic_type_token12] = ACTIONS(5085),
    [aux_sym_basic_type_token13] = ACTIONS(5089),
    [aux_sym_basic_type_token14] = ACTIONS(5085),
    [aux_sym_basic_type_token15] = ACTIONS(5085),
    [aux_sym_basic_type_token16] = ACTIONS(5085),
    [aux_sym_basic_type_token17] = ACTIONS(5085),
    [aux_sym_basic_type_token18] = ACTIONS(5085),
    [aux_sym_basic_type_token19] = ACTIONS(5085),
    [aux_sym_basic_type_token20] = ACTIONS(5085),
    [aux_sym_basic_type_token21] = ACTIONS(5085),
    [aux_sym_basic_type_token22] = ACTIONS(5085),
    [aux_sym_basic_type_token23] = ACTIONS(5085),
    [aux_sym_basic_type_token24] = ACTIONS(5085),
    [aux_sym_basic_type_token25] = ACTIONS(5085),
    [aux_sym_basic_type_token26] = ACTIONS(5085),
    [aux_sym_basic_type_token27] = ACTIONS(5085),
    [aux_sym_basic_type_token28] = ACTIONS(5085),
    [aux_sym_basic_type_token29] = ACTIONS(5085),
    [aux_sym_basic_type_token30] = ACTIONS(5085),
    [aux_sym_basic_type_token31] = ACTIONS(5085),
    [aux_sym_basic_type_token32] = ACTIONS(5085),
    [aux_sym_basic_type_token33] = ACTIONS(5085),
    [aux_sym_basic_type_token34] = ACTIONS(5085),
    [aux_sym_basic_type_token35] = ACTIONS(5085),
    [aux_sym_basic_type_token36] = ACTIONS(5085),
    [aux_sym_basic_type_token37] = ACTIONS(5085),
    [aux_sym_basic_type_token38] = ACTIONS(5085),
    [aux_sym_basic_type_token39] = ACTIONS(5085),
    [aux_sym_basic_type_token40] = ACTIONS(5085),
    [aux_sym_basic_type_token41] = ACTIONS(5085),
    [aux_sym_basic_type_token42] = ACTIONS(5085),
    [aux_sym_basic_type_token43] = ACTIONS(5085),
    [aux_sym_basic_type_token44] = ACTIONS(5085),
    [aux_sym_basic_type_token45] = ACTIONS(5085),
    [aux_sym_basic_type_token46] = ACTIONS(5085),
    [aux_sym_basic_type_token47] = ACTIONS(5085),
    [aux_sym_basic_type_token48] = ACTIONS(5085),
    [aux_sym_basic_type_token49] = ACTIONS(5085),
    [aux_sym_basic_type_token50] = ACTIONS(5085),
    [aux_sym_basic_type_token51] = ACTIONS(5085),
    [aux_sym_basic_type_token52] = ACTIONS(5085),
    [aux_sym_basic_type_token53] = ACTIONS(5085),
    [aux_sym_basic_type_token54] = ACTIONS(5085),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5077),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5077),
    [sym_query_keyword] = ACTIONS(5077),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5077),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(5091),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2234)] = {
    [sym_type_specification] = STATE(17212),
    [sym_text_type] = STATE(7205),
    [sym_code_type] = STATE(7205),
    [sym_option_type] = STATE(7225),
    [sym_record_type] = STATE(7225),
    [sym_dotnet_type] = STATE(7225),
    [sym_object_reference_type] = STATE(7225),
    [sym_array_type] = STATE(7188),
    [sym_list_type] = STATE(7188),
    [sym_dictionary_type] = STATE(7188),
    [sym_basic_type] = STATE(7225),
    [sym_codeunit_keyword] = STATE(11518),
    [sym_xmlport_keyword] = STATE(11518),
    [sym_enum_keyword] = STATE(11518),
    [sym_controladdin_keyword] = STATE(11518),
    [sym_dotnet_keyword] = STATE(11374),
    [sym_identifier] = ACTIONS(4863),
    [aux_sym_text_type_token1] = ACTIONS(4865),
    [aux_sym_code_type_token1] = ACTIONS(4867),
    [aux_sym_option_type_token1] = ACTIONS(5001),
    [aux_sym_record_type_token1] = ACTIONS(5003),
    [aux_sym_object_reference_type_token1] = ACTIONS(5005),
    [aux_sym_object_reference_type_token2] = ACTIONS(5005),
    [aux_sym_array_type_token1] = ACTIONS(5007),
    [aux_sym_list_type_token1] = ACTIONS(4877),
    [aux_sym_dictionary_type_token1] = ACTIONS(4879),
    [aux_sym_basic_type_token1] = ACTIONS(4881),
    [aux_sym_basic_type_token2] = ACTIONS(4881),
    [aux_sym_basic_type_token3] = ACTIONS(4881),
    [aux_sym_basic_type_token4] = ACTIONS(4881),
    [aux_sym_basic_type_token5] = ACTIONS(4881),
    [aux_sym_basic_type_token6] = ACTIONS(4883),
    [aux_sym_basic_type_token7] = ACTIONS(4881),
    [aux_sym_basic_type_token8] = ACTIONS(4881),
    [aux_sym_basic_type_token9] = ACTIONS(4881),
    [aux_sym_basic_type_token10] = ACTIONS(4881),
    [aux_sym_basic_type_token11] = ACTIONS(4881),
    [aux_sym_basic_type_token12] = ACTIONS(4881),
    [aux_sym_basic_type_token13] = ACTIONS(4885),
    [aux_sym_basic_type_token14] = ACTIONS(4881),
    [aux_sym_basic_type_token15] = ACTIONS(4881),
    [aux_sym_basic_type_token16] = ACTIONS(4881),
    [aux_sym_basic_type_token17] = ACTIONS(4881),
    [aux_sym_basic_type_token18] = ACTIONS(4881),
    [aux_sym_basic_type_token19] = ACTIONS(4881),
    [aux_sym_basic_type_token20] = ACTIONS(4881),
    [aux_sym_basic_type_token21] = ACTIONS(4881),
    [aux_sym_basic_type_token22] = ACTIONS(4881),
    [aux_sym_basic_type_token23] = ACTIONS(4881),
    [aux_sym_basic_type_token24] = ACTIONS(4881),
    [aux_sym_basic_type_token25] = ACTIONS(4881),
    [aux_sym_basic_type_token26] = ACTIONS(4881),
    [aux_sym_basic_type_token27] = ACTIONS(4881),
    [aux_sym_basic_type_token28] = ACTIONS(4881),
    [aux_sym_basic_type_token29] = ACTIONS(4881),
    [aux_sym_basic_type_token30] = ACTIONS(4881),
    [aux_sym_basic_type_token31] = ACTIONS(4881),
    [aux_sym_basic_type_token32] = ACTIONS(4881),
    [aux_sym_basic_type_token33] = ACTIONS(4881),
    [aux_sym_basic_type_token34] = ACTIONS(4881),
    [aux_sym_basic_type_token35] = ACTIONS(4881),
    [aux_sym_basic_type_token36] = ACTIONS(4881),
    [aux_sym_basic_type_token37] = ACTIONS(4881),
    [aux_sym_basic_type_token38] = ACTIONS(4881),
    [aux_sym_basic_type_token39] = ACTIONS(4881),
    [aux_sym_basic_type_token40] = ACTIONS(4881),
    [aux_sym_basic_type_token41] = ACTIONS(4881),
    [aux_sym_basic_type_token42] = ACTIONS(4881),
    [aux_sym_basic_type_token43] = ACTIONS(4881),
    [aux_sym_basic_type_token44] = ACTIONS(4881),
    [aux_sym_basic_type_token45] = ACTIONS(4881),
    [aux_sym_basic_type_token46] = ACTIONS(4881),
    [aux_sym_basic_type_token47] = ACTIONS(4881),
    [aux_sym_basic_type_token48] = ACTIONS(4881),
    [aux_sym_basic_type_token49] = ACTIONS(4881),
    [aux_sym_basic_type_token50] = ACTIONS(4881),
    [aux_sym_basic_type_token51] = ACTIONS(4881),
    [aux_sym_basic_type_token52] = ACTIONS(4881),
    [aux_sym_basic_type_token53] = ACTIONS(4881),
    [aux_sym_basic_type_token54] = ACTIONS(4881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_page_keyword] = ACTIONS(5005),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(5005),
    [sym_query_keyword] = ACTIONS(5005),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_interface_keyword] = ACTIONS(5005),
    [anon_sym_controladdin] = ACTIONS(4805),
    [anon_sym_CONTROLADDIN] = ACTIONS(4805),
    [anon_sym_Controladdin] = ACTIONS(4805),
    [anon_sym_ControlAddIn] = ACTIONS(4805),
    [anon_sym_ControlAddin] = ACTIONS(4805),
    [anon_sym_controlAddIn] = ACTIONS(4805),
    [anon_sym_controlAddin] = ACTIONS(4805),
    [anon_sym_dotnet] = ACTIONS(4807),
    [anon_sym_DOTNET] = ACTIONS(4807),
    [anon_sym_Dotnet] = ACTIONS(4807),
    [anon_sym_DotNet] = ACTIONS(4807),
    [anon_sym_dotNet] = ACTIONS(4807),
    [sym_quoted_identifier] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(2235)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12774),
    [sym_else_table_relation_fragment] = STATE(12774),
    [sym_table_relation_expression] = STATE(12774),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(9033),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(4014),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(9033),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5187),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(2236)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12505),
    [sym_else_table_relation_fragment] = STATE(12505),
    [sym_table_relation_expression] = STATE(12505),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(9130),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(4065),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(9130),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5189),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4423),
    [anon_sym_POUNDENDIF] = ACTIONS(4423),
    [anon_sym_POUNDEndif] = ACTIONS(4423),
    [anon_sym_POUNDendif2] = ACTIONS(4423),
    [anon_sym_POUNDENDIF2] = ACTIONS(4423),
    [anon_sym_POUNDEndif2] = ACTIONS(4423),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4423),
  },
  [STATE(2237)] = {
    [sym__body_element] = STATE(3843),
    [sym_empty_statement] = STATE(3843),
    [sym_property] = STATE(6513),
    [sym_permissions_property] = STATE(3843),
    [sym_table_relation_property] = STATE(3843),
    [sym_fields_section] = STATE(3843),
    [sym_keys_section] = STATE(3843),
    [sym_fieldgroups_section] = STATE(3843),
    [sym_enum_value_declaration] = STATE(3843),
    [sym_labels_section] = STATE(3843),
    [sym_layout_section] = STATE(3843),
    [sym_modify_modification] = STATE(3843),
    [sym_actions_section] = STATE(3843),
    [sym__action_element] = STATE(5859),
    [sym_action_area_section] = STATE(5859),
    [sym_action_group_section] = STATE(5859),
    [sym_action_declaration] = STATE(5859),
    [sym_separator_action] = STATE(5859),
    [sym_actionref_declaration] = STATE(5859),
    [sym_systemaction_declaration] = STATE(5859),
    [sym_fileuploadaction_declaration] = STATE(5859),
    [sym_customaction_declaration] = STATE(5859),
    [sym_addfirst_action_modification] = STATE(5859),
    [sym_addlast_action_modification] = STATE(5859),
    [sym_addafter_action_modification] = STATE(5859),
    [sym_addbefore_action_modification] = STATE(5859),
    [sym_modify_action_modification] = STATE(5859),
    [sym_views_section] = STATE(3843),
    [sym_dataset_section] = STATE(3843),
    [sym_requestpage_section] = STATE(3843),
    [sym_rendering_section] = STATE(3843),
    [sym_elements_section] = STATE(3843),
    [sym_schema_section] = STATE(3843),
    [sym_assembly_declaration] = STATE(3843),
    [sym_event_declaration] = STATE(3843),
    [sym_procedure] = STATE(3843),
    [sym_preproc_split_procedure] = STATE(3843),
    [sym__procedure_preamble] = STATE(10866),
    [sym_preproc_split_procedure_preamble] = STATE(3843),
    [sym__procedure_header] = STATE(9968),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(6513),
    [sym_var_section] = STATE(3843),
    [sym_attribute_item] = STATE(6495),
    [sym_preproc_conditional] = STATE(3843),
    [sym_preproc_if] = STATE(2238),
    [sym_preproc_elif] = STATE(2509),
    [sym_preproc_else] = STATE(3160),
    [sym_preproc_endif] = STATE(8304),
    [sym_preproc_conditional_actions] = STATE(5859),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3843),
    [aux_sym_actions_section_repeat1] = STATE(5859),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10859),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(11030),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(5201),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2238)] = {
    [sym__body_element] = STATE(3834),
    [sym_empty_statement] = STATE(3834),
    [sym_property] = STATE(6513),
    [sym_permissions_property] = STATE(3834),
    [sym_table_relation_property] = STATE(3834),
    [sym_fields_section] = STATE(3834),
    [sym_keys_section] = STATE(3834),
    [sym_fieldgroups_section] = STATE(3834),
    [sym_enum_value_declaration] = STATE(3834),
    [sym_labels_section] = STATE(3834),
    [sym_layout_section] = STATE(3834),
    [sym_modify_modification] = STATE(3834),
    [sym_actions_section] = STATE(3834),
    [sym__action_element] = STATE(5866),
    [sym_action_area_section] = STATE(5866),
    [sym_action_group_section] = STATE(5866),
    [sym_action_declaration] = STATE(5866),
    [sym_separator_action] = STATE(5866),
    [sym_actionref_declaration] = STATE(5866),
    [sym_systemaction_declaration] = STATE(5866),
    [sym_fileuploadaction_declaration] = STATE(5866),
    [sym_customaction_declaration] = STATE(5866),
    [sym_addfirst_action_modification] = STATE(5866),
    [sym_addlast_action_modification] = STATE(5866),
    [sym_addafter_action_modification] = STATE(5866),
    [sym_addbefore_action_modification] = STATE(5866),
    [sym_modify_action_modification] = STATE(5866),
    [sym_views_section] = STATE(3834),
    [sym_dataset_section] = STATE(3834),
    [sym_requestpage_section] = STATE(3834),
    [sym_rendering_section] = STATE(3834),
    [sym_elements_section] = STATE(3834),
    [sym_schema_section] = STATE(3834),
    [sym_assembly_declaration] = STATE(3834),
    [sym_event_declaration] = STATE(3834),
    [sym_procedure] = STATE(3834),
    [sym_preproc_split_procedure] = STATE(3834),
    [sym__procedure_preamble] = STATE(10930),
    [sym_preproc_split_procedure_preamble] = STATE(3834),
    [sym__procedure_header] = STATE(9970),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(6513),
    [sym_var_section] = STATE(3834),
    [sym_attribute_item] = STATE(6495),
    [sym_preproc_conditional] = STATE(3834),
    [sym_preproc_if] = STATE(2238),
    [sym_preproc_elif] = STATE(2509),
    [sym_preproc_else] = STATE(3168),
    [sym_preproc_endif] = STATE(6485),
    [sym_preproc_conditional_actions] = STATE(5866),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3834),
    [aux_sym_actions_section_repeat1] = STATE(5866),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10978),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(10698),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(5201),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2239)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12603),
    [sym_else_table_relation_fragment] = STATE(12603),
    [sym_table_relation_expression] = STATE(12603),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(9135),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(5512),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(9135),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5217),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(2240)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12505),
    [sym_else_table_relation_fragment] = STATE(12505),
    [sym_table_relation_expression] = STATE(12505),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8985),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(5321),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8985),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5219),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4399),
    [anon_sym_POUNDENDIF] = ACTIONS(4399),
    [anon_sym_POUNDEndif] = ACTIONS(4399),
    [anon_sym_POUNDendif2] = ACTIONS(4399),
    [anon_sym_POUNDENDIF2] = ACTIONS(4399),
    [anon_sym_POUNDEndif2] = ACTIONS(4399),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4399),
  },
  [STATE(2241)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13320),
    [sym_else_table_relation_fragment] = STATE(13320),
    [sym_table_relation_expression] = STATE(13320),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(8965),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(4302),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(8965),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5221),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4403),
    [anon_sym_POUNDENDIF] = ACTIONS(4403),
    [anon_sym_POUNDEndif] = ACTIONS(4403),
    [anon_sym_POUNDendif2] = ACTIONS(4403),
    [anon_sym_POUNDENDIF2] = ACTIONS(4403),
    [anon_sym_POUNDEndif2] = ACTIONS(4403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4403),
  },
  [STATE(2242)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12692),
    [sym_else_table_relation_fragment] = STATE(12692),
    [sym_table_relation_expression] = STATE(12692),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(9147),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(3574),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(9147),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5223),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4485),
    [anon_sym_POUNDENDIF] = ACTIONS(4485),
    [anon_sym_POUNDEndif] = ACTIONS(4485),
    [anon_sym_POUNDendif2] = ACTIONS(4485),
    [anon_sym_POUNDENDIF2] = ACTIONS(4485),
    [anon_sym_POUNDEndif2] = ACTIONS(4485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4485),
  },
  [STATE(2243)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13007),
    [sym_else_table_relation_fragment] = STATE(13007),
    [sym_table_relation_expression] = STATE(13007),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(9100),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(5940),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(9100),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5225),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(2244)] = {
    [sym_boolean] = STATE(3551),
    [sym_option_member_list] = STATE(3524),
    [sym_option_member] = STATE(3496),
    [sym_keyword_identifier] = STATE(3551),
    [sym_codeunit_keyword] = STATE(3490),
    [sym_xmlport_keyword] = STATE(3490),
    [sym_enum_keyword] = STATE(3490),
    [sym_keyword_as_identifier] = STATE(3551),
    [aux_sym_option_member_list_repeat2] = STATE(2249),
    [sym_identifier] = ACTIONS(5227),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(5229),
    [anon_sym_COLON] = ACTIONS(584),
    [anon_sym_DASH] = ACTIONS(5231),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(584),
    [anon_sym_LPAREN] = ACTIONS(582),
    [aux_sym_where_condition_token1] = ACTIONS(5233),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(5235),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_basic_type_token53] = ACTIONS(5233),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5233),
    [aux_sym_separator_action_token1] = ACTIONS(5233),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5233),
    [aux_sym_type_declaration_token1] = ACTIONS(5233),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(584),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [anon_sym_not] = ACTIONS(584),
    [anon_sym_NOT] = ACTIONS(584),
    [anon_sym_Not] = ACTIONS(584),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(582),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [sym_datetime_literal] = ACTIONS(582),
    [sym_date_literal] = ACTIONS(584),
    [sym_time_literal] = ACTIONS(584),
    [sym_biginteger_literal] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(584),
    [anon_sym_ELSE] = ACTIONS(584),
    [anon_sym_Else] = ACTIONS(584),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(5233),
    [sym_page_keyword] = ACTIONS(437),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(437),
    [sym_query_keyword] = ACTIONS(437),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_local_keyword] = ACTIONS(5227),
    [sym_internal_keyword] = ACTIONS(5227),
    [sym_protected_keyword] = ACTIONS(5227),
    [sym_key_keyword] = ACTIONS(5233),
    [sym_dataset_keyword] = ACTIONS(5233),
    [sym_quoted_identifier] = ACTIONS(5237),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5237),
    [sym_verbatim_string] = ACTIONS(582),
    [sym_integer] = ACTIONS(5227),
    [sym_continue_as_identifier] = ACTIONS(582),
    [sym_preproc_open] = ACTIONS(582),
  },
  [STATE(2245)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12881),
    [sym_else_table_relation_fragment] = STATE(12881),
    [sym_table_relation_expression] = STATE(12881),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(9160),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(9761),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(9160),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5239),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4435),
    [anon_sym_POUNDENDIF] = ACTIONS(4435),
    [anon_sym_POUNDEndif] = ACTIONS(4435),
    [anon_sym_POUNDendif2] = ACTIONS(4435),
    [anon_sym_POUNDENDIF2] = ACTIONS(4435),
    [anon_sym_POUNDEndif2] = ACTIONS(4435),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4435),
  },
  [STATE(2246)] = {
    [sym_boolean] = STATE(8846),
    [sym_link_value] = STATE(9991),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13141),
    [sym_else_table_relation_fragment] = STATE(13141),
    [sym_table_relation_expression] = STATE(13141),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(9170),
    [sym_tabledata_permission] = STATE(8680),
    [sym_implementation_value] = STATE(9995),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(4070),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10433),
    [sym_keyword_as_identifier] = STATE(10433),
    [aux_sym_preproc_conditional_link_values_repeat1] = STATE(10227),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(9170),
    [aux_sym_preproc_conditional_impl_values_repeat1] = STATE(10213),
    [sym_identifier] = ACTIONS(4359),
    [anon_sym_COMMA] = ACTIONS(5241),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4393),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(2247)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(11295),
    [sym_else_table_relation_fragment] = STATE(11295),
    [sym_table_relation_expression] = STATE(11295),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(5243),
    [anon_sym_POUNDELIF] = ACTIONS(5243),
    [anon_sym_POUNDElif] = ACTIONS(5243),
    [anon_sym_POUNDelse] = ACTIONS(5243),
    [anon_sym_POUNDELSE] = ACTIONS(5243),
    [anon_sym_POUNDElse] = ACTIONS(5243),
    [anon_sym_POUNDelse2] = ACTIONS(5243),
    [anon_sym_POUNDELSE2] = ACTIONS(5243),
    [anon_sym_POUNDElse2] = ACTIONS(5243),
    [anon_sym_POUNDendif] = ACTIONS(5243),
    [anon_sym_POUNDENDIF] = ACTIONS(5243),
    [anon_sym_POUNDEndif] = ACTIONS(5243),
    [anon_sym_POUNDendif2] = ACTIONS(5243),
    [anon_sym_POUNDENDIF2] = ACTIONS(5243),
    [anon_sym_POUNDEndif2] = ACTIONS(5243),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(5243),
  },
  [STATE(2248)] = {
    [sym__body_element] = STATE(5388),
    [sym_empty_statement] = STATE(5388),
    [sym_property] = STATE(5388),
    [sym_permissions_property] = STATE(5388),
    [sym_table_relation_property] = STATE(5388),
    [sym_fields_section] = STATE(5388),
    [sym_keys_section] = STATE(5388),
    [sym_fieldgroups_section] = STATE(5388),
    [sym_enum_value_declaration] = STATE(5388),
    [sym_labels_section] = STATE(5388),
    [sym_layout_section] = STATE(5388),
    [sym__layout_element] = STATE(5406),
    [sym_area_section] = STATE(5406),
    [sym_group_section] = STATE(5406),
    [sym_repeater_section] = STATE(5406),
    [sym_cuegroup_section] = STATE(5406),
    [sym_fixed_section] = STATE(5406),
    [sym_grid_section] = STATE(5406),
    [sym_page_field] = STATE(5406),
    [sym_part_section] = STATE(5406),
    [sym_systempart_section] = STATE(5406),
    [sym_usercontrol_section] = STATE(5406),
    [sym_preproc_split_field] = STATE(5406),
    [sym_label_section] = STATE(5406),
    [sym_addfirst_modification] = STATE(5406),
    [sym_addlast_modification] = STATE(5406),
    [sym_addafter_modification] = STATE(5406),
    [sym_addbefore_modification] = STATE(5406),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(5406),
    [sym_movelast_modification] = STATE(5406),
    [sym_moveafter_modification] = STATE(5406),
    [sym_movebefore_modification] = STATE(5406),
    [sym_actions_section] = STATE(5388),
    [sym_views_section] = STATE(5388),
    [sym_dataset_section] = STATE(5388),
    [sym_requestpage_section] = STATE(5388),
    [sym_rendering_section] = STATE(5388),
    [sym_elements_section] = STATE(5388),
    [sym_schema_section] = STATE(5388),
    [sym_assembly_declaration] = STATE(5388),
    [sym_event_declaration] = STATE(5388),
    [sym_procedure] = STATE(5388),
    [sym_preproc_split_procedure] = STATE(5388),
    [sym_preproc_split_procedure_preamble] = STATE(5388),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(5388),
    [sym_var_section] = STATE(5388),
    [sym_attribute_item] = STATE(5388),
    [sym_preproc_conditional] = STATE(5388),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_endif] = STATE(7949),
    [sym_preproc_conditional_layout] = STATE(5406),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4943),
    [aux_sym_layout_section_repeat1] = STATE(6504),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2254),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2249)] = {
    [sym_boolean] = STATE(3551),
    [sym_option_member] = STATE(3511),
    [sym_keyword_identifier] = STATE(3551),
    [sym_codeunit_keyword] = STATE(3490),
    [sym_xmlport_keyword] = STATE(3490),
    [sym_enum_keyword] = STATE(3490),
    [sym_keyword_as_identifier] = STATE(3551),
    [aux_sym_option_member_list_repeat2] = STATE(2632),
    [sym_identifier] = ACTIONS(5227),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(5245),
    [anon_sym_COLON] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(5231),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [aux_sym_where_condition_token1] = ACTIONS(5233),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(5235),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_basic_type_token53] = ACTIONS(5233),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5233),
    [aux_sym_separator_action_token1] = ACTIONS(5233),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5233),
    [aux_sym_type_declaration_token1] = ACTIONS(5233),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(5233),
    [sym_page_keyword] = ACTIONS(437),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(437),
    [sym_query_keyword] = ACTIONS(437),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_local_keyword] = ACTIONS(5227),
    [sym_internal_keyword] = ACTIONS(5227),
    [sym_protected_keyword] = ACTIONS(5227),
    [sym_key_keyword] = ACTIONS(5233),
    [sym_dataset_keyword] = ACTIONS(5233),
    [sym_quoted_identifier] = ACTIONS(5237),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5237),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(5227),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
  },
  [STATE(2250)] = {
    [sym_boolean] = STATE(3551),
    [sym_option_member] = STATE(3522),
    [sym_keyword_identifier] = STATE(3551),
    [sym_codeunit_keyword] = STATE(3490),
    [sym_xmlport_keyword] = STATE(3490),
    [sym_enum_keyword] = STATE(3490),
    [sym_keyword_as_identifier] = STATE(3551),
    [sym_identifier] = ACTIONS(5247),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(5250),
    [aux_sym_boolean_token1] = ACTIONS(5253),
    [aux_sym_boolean_token2] = ACTIONS(5253),
    [sym_decimal] = ACTIONS(613),
    [anon_sym_LPAREN] = ACTIONS(611),
    [aux_sym_where_condition_token1] = ACTIONS(5233),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5256),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(5256),
    [aux_sym_basic_type_token21] = ACTIONS(5256),
    [aux_sym_basic_type_token22] = ACTIONS(5259),
    [aux_sym_basic_type_token48] = ACTIONS(5256),
    [aux_sym_basic_type_token53] = ACTIONS(5233),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5233),
    [aux_sym_separator_action_token1] = ACTIONS(5233),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5233),
    [aux_sym_type_declaration_token1] = ACTIONS(5233),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(613),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [anon_sym_not] = ACTIONS(613),
    [anon_sym_NOT] = ACTIONS(613),
    [anon_sym_Not] = ACTIONS(613),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5256),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5256),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [sym_datetime_literal] = ACTIONS(611),
    [sym_date_literal] = ACTIONS(613),
    [sym_time_literal] = ACTIONS(613),
    [sym_biginteger_literal] = ACTIONS(611),
    [anon_sym_else] = ACTIONS(613),
    [anon_sym_ELSE] = ACTIONS(613),
    [anon_sym_Else] = ACTIONS(613),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(5233),
    [sym_page_keyword] = ACTIONS(5256),
    [anon_sym_codeunit] = ACTIONS(5262),
    [anon_sym_CODEUNIT] = ACTIONS(5262),
    [anon_sym_Codeunit] = ACTIONS(5262),
    [anon_sym_CodeUnit] = ACTIONS(5262),
    [anon_sym_COdeunit] = ACTIONS(5262),
    [anon_sym_codeUnit] = ACTIONS(5262),
    [sym_report_keyword] = ACTIONS(5256),
    [sym_query_keyword] = ACTIONS(5256),
    [anon_sym_xmlport] = ACTIONS(5265),
    [anon_sym_XMLPORT] = ACTIONS(5265),
    [anon_sym_Xmlport] = ACTIONS(5265),
    [anon_sym_XMLport] = ACTIONS(5265),
    [anon_sym_XMLPort] = ACTIONS(5265),
    [anon_sym_XmlPort] = ACTIONS(5265),
    [anon_sym_enum] = ACTIONS(5268),
    [anon_sym_ENUM] = ACTIONS(5268),
    [anon_sym_Enum] = ACTIONS(5268),
    [anon_sym_eNUM] = ACTIONS(5268),
    [anon_sym_eNum] = ACTIONS(5268),
    [anon_sym_ENum] = ACTIONS(5268),
    [sym_local_keyword] = ACTIONS(5227),
    [sym_internal_keyword] = ACTIONS(5227),
    [sym_protected_keyword] = ACTIONS(5227),
    [sym_key_keyword] = ACTIONS(5233),
    [sym_dataset_keyword] = ACTIONS(5233),
    [sym_quoted_identifier] = ACTIONS(5271),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5271),
    [sym_verbatim_string] = ACTIONS(611),
    [sym_integer] = ACTIONS(5247),
    [sym_continue_as_identifier] = ACTIONS(611),
    [sym_preproc_open] = ACTIONS(611),
  },
  [STATE(2251)] = {
    [sym__body_element] = STATE(4922),
    [sym_empty_statement] = STATE(4922),
    [sym_property] = STATE(4922),
    [sym_permissions_property] = STATE(4922),
    [sym_table_relation_property] = STATE(4922),
    [sym_fields_section] = STATE(4922),
    [sym_keys_section] = STATE(4922),
    [sym_fieldgroups_section] = STATE(4922),
    [sym_enum_value_declaration] = STATE(4922),
    [sym_labels_section] = STATE(4922),
    [sym_layout_section] = STATE(4922),
    [sym__layout_element] = STATE(6481),
    [sym_area_section] = STATE(6481),
    [sym_group_section] = STATE(6481),
    [sym_repeater_section] = STATE(6481),
    [sym_cuegroup_section] = STATE(6481),
    [sym_fixed_section] = STATE(6481),
    [sym_grid_section] = STATE(6481),
    [sym_page_field] = STATE(6481),
    [sym_part_section] = STATE(6481),
    [sym_systempart_section] = STATE(6481),
    [sym_usercontrol_section] = STATE(6481),
    [sym_preproc_split_field] = STATE(6481),
    [sym_label_section] = STATE(6481),
    [sym_addfirst_modification] = STATE(6481),
    [sym_addlast_modification] = STATE(6481),
    [sym_addafter_modification] = STATE(6481),
    [sym_addbefore_modification] = STATE(6481),
    [sym_modify_modification] = STATE(5402),
    [sym_movefirst_modification] = STATE(6481),
    [sym_movelast_modification] = STATE(6481),
    [sym_moveafter_modification] = STATE(6481),
    [sym_movebefore_modification] = STATE(6481),
    [sym_actions_section] = STATE(4922),
    [sym_views_section] = STATE(4922),
    [sym_dataset_section] = STATE(4922),
    [sym_requestpage_section] = STATE(4922),
    [sym_rendering_section] = STATE(4922),
    [sym_elements_section] = STATE(4922),
    [sym_schema_section] = STATE(4922),
    [sym_assembly_declaration] = STATE(4922),
    [sym_event_declaration] = STATE(4922),
    [sym_procedure] = STATE(4922),
    [sym_preproc_split_procedure] = STATE(4922),
    [sym_preproc_split_procedure_preamble] = STATE(4922),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4922),
    [sym_var_section] = STATE(4922),
    [sym_attribute_item] = STATE(4922),
    [sym_preproc_conditional] = STATE(4922),
    [sym_preproc_if] = STATE(2080),
    [sym_preproc_endif] = STATE(5413),
    [sym_preproc_conditional_layout] = STATE(6481),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4922),
    [aux_sym_layout_section_repeat1] = STATE(6481),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4604),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2252)] = {
    [aux_sym_option_member_list_repeat2] = STATE(2252),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_EQ] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(5274),
    [anon_sym_DASH] = ACTIONS(836),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [sym_decimal] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(838),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(838),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [anon_sym_not] = ACTIONS(836),
    [anon_sym_NOT] = ACTIONS(836),
    [anon_sym_Not] = ACTIONS(836),
    [anon_sym_POUNDelif] = ACTIONS(838),
    [anon_sym_POUNDELIF] = ACTIONS(838),
    [anon_sym_POUNDElif] = ACTIONS(838),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [anon_sym_POUNDendif] = ACTIONS(838),
    [anon_sym_POUNDENDIF] = ACTIONS(838),
    [anon_sym_POUNDEndif] = ACTIONS(838),
    [anon_sym_POUNDendif2] = ACTIONS(838),
    [anon_sym_POUNDENDIF2] = ACTIONS(838),
    [anon_sym_POUNDEndif2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(838),
    [aux_sym__expression_token1] = ACTIONS(838),
    [aux_sym__expression_token2] = ACTIONS(838),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_div] = ACTIONS(836),
    [anon_sym_DIV] = ACTIONS(836),
    [anon_sym_Div] = ACTIONS(836),
    [anon_sym_mod] = ACTIONS(836),
    [anon_sym_MOD] = ACTIONS(836),
    [anon_sym_Mod] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_LT_GT] = ACTIONS(838),
    [anon_sym_and] = ACTIONS(836),
    [anon_sym_AND] = ACTIONS(836),
    [anon_sym_And] = ACTIONS(836),
    [anon_sym_or] = ACTIONS(836),
    [anon_sym_OR] = ACTIONS(836),
    [anon_sym_Or] = ACTIONS(836),
    [anon_sym_xor] = ACTIONS(836),
    [anon_sym_XOR] = ACTIONS(836),
    [anon_sym_Xor] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(838),
    [sym_datetime_literal] = ACTIONS(838),
    [sym_date_literal] = ACTIONS(836),
    [sym_time_literal] = ACTIONS(836),
    [sym_biginteger_literal] = ACTIONS(838),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_IN] = ACTIONS(836),
    [anon_sym_In] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_verbatim_string] = ACTIONS(838),
    [sym_integer] = ACTIONS(836),
    [sym_continue_as_identifier] = ACTIONS(838),
    [sym_preproc_close] = ACTIONS(838),
  },
  [STATE(2253)] = {
    [sym__body_element] = STATE(4908),
    [sym_empty_statement] = STATE(4908),
    [sym_property] = STATE(4908),
    [sym_permissions_property] = STATE(4908),
    [sym_table_relation_property] = STATE(4908),
    [sym_fields_section] = STATE(4908),
    [sym_keys_section] = STATE(4908),
    [sym_fieldgroups_section] = STATE(4908),
    [sym_enum_value_declaration] = STATE(4908),
    [sym_labels_section] = STATE(4908),
    [sym_layout_section] = STATE(4908),
    [sym__layout_element] = STATE(6511),
    [sym_area_section] = STATE(6511),
    [sym_group_section] = STATE(6511),
    [sym_repeater_section] = STATE(6511),
    [sym_cuegroup_section] = STATE(6511),
    [sym_fixed_section] = STATE(6511),
    [sym_grid_section] = STATE(6511),
    [sym_page_field] = STATE(6511),
    [sym_part_section] = STATE(6511),
    [sym_systempart_section] = STATE(6511),
    [sym_usercontrol_section] = STATE(6511),
    [sym_preproc_split_field] = STATE(6511),
    [sym_label_section] = STATE(6511),
    [sym_addfirst_modification] = STATE(6511),
    [sym_addlast_modification] = STATE(6511),
    [sym_addafter_modification] = STATE(6511),
    [sym_addbefore_modification] = STATE(6511),
    [sym_modify_modification] = STATE(5402),
    [sym_movefirst_modification] = STATE(6511),
    [sym_movelast_modification] = STATE(6511),
    [sym_moveafter_modification] = STATE(6511),
    [sym_movebefore_modification] = STATE(6511),
    [sym_actions_section] = STATE(4908),
    [sym_views_section] = STATE(4908),
    [sym_dataset_section] = STATE(4908),
    [sym_requestpage_section] = STATE(4908),
    [sym_rendering_section] = STATE(4908),
    [sym_elements_section] = STATE(4908),
    [sym_schema_section] = STATE(4908),
    [sym_assembly_declaration] = STATE(4908),
    [sym_event_declaration] = STATE(4908),
    [sym_procedure] = STATE(4908),
    [sym_preproc_split_procedure] = STATE(4908),
    [sym_preproc_split_procedure_preamble] = STATE(4908),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4908),
    [sym_var_section] = STATE(4908),
    [sym_attribute_item] = STATE(4908),
    [sym_preproc_conditional] = STATE(4908),
    [sym_preproc_if] = STATE(2080),
    [sym_preproc_endif] = STATE(5354),
    [sym_preproc_conditional_layout] = STATE(6511),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4908),
    [aux_sym_layout_section_repeat1] = STATE(6511),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4604),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2254)] = {
    [sym__body_element] = STATE(2102),
    [sym_empty_statement] = STATE(2102),
    [sym_property] = STATE(2102),
    [sym_permissions_property] = STATE(2102),
    [sym_table_relation_property] = STATE(2102),
    [sym_fields_section] = STATE(2102),
    [sym_keys_section] = STATE(2102),
    [sym_fieldgroups_section] = STATE(2102),
    [sym_enum_value_declaration] = STATE(2102),
    [sym_labels_section] = STATE(2102),
    [sym_layout_section] = STATE(2102),
    [sym__layout_element] = STATE(2102),
    [sym_area_section] = STATE(2102),
    [sym_group_section] = STATE(2102),
    [sym_repeater_section] = STATE(2102),
    [sym_cuegroup_section] = STATE(2102),
    [sym_fixed_section] = STATE(2102),
    [sym_grid_section] = STATE(2102),
    [sym_page_field] = STATE(2102),
    [sym_part_section] = STATE(2102),
    [sym_systempart_section] = STATE(2102),
    [sym_usercontrol_section] = STATE(2102),
    [sym_preproc_split_field] = STATE(2102),
    [sym_label_section] = STATE(2102),
    [sym_addfirst_modification] = STATE(2102),
    [sym_addlast_modification] = STATE(2102),
    [sym_addafter_modification] = STATE(2102),
    [sym_addbefore_modification] = STATE(2102),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2102),
    [sym_movelast_modification] = STATE(2102),
    [sym_moveafter_modification] = STATE(2102),
    [sym_movebefore_modification] = STATE(2102),
    [sym_actions_section] = STATE(2102),
    [sym_views_section] = STATE(2102),
    [sym_dataset_section] = STATE(2102),
    [sym_requestpage_section] = STATE(2102),
    [sym_rendering_section] = STATE(2102),
    [sym_elements_section] = STATE(2102),
    [sym_schema_section] = STATE(2102),
    [sym_assembly_declaration] = STATE(2102),
    [sym_event_declaration] = STATE(2102),
    [sym_procedure] = STATE(2102),
    [sym_preproc_split_procedure] = STATE(2102),
    [sym_preproc_split_procedure_preamble] = STATE(2102),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2102),
    [sym_var_section] = STATE(2102),
    [sym_attribute_item] = STATE(2102),
    [sym_preproc_conditional] = STATE(2102),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_endif] = STATE(8015),
    [sym_preproc_conditional_layout] = STATE(2102),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2102),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2255)] = {
    [sym__body_element] = STATE(2256),
    [sym_empty_statement] = STATE(2256),
    [sym_property] = STATE(2256),
    [sym_permissions_property] = STATE(2256),
    [sym_table_relation_property] = STATE(2256),
    [sym_fields_section] = STATE(2256),
    [sym_keys_section] = STATE(2256),
    [sym_fieldgroups_section] = STATE(2256),
    [sym_enum_value_declaration] = STATE(2256),
    [sym_labels_section] = STATE(2256),
    [sym_layout_section] = STATE(2256),
    [sym__layout_element] = STATE(2256),
    [sym_area_section] = STATE(2256),
    [sym_group_section] = STATE(2256),
    [sym_repeater_section] = STATE(2256),
    [sym_cuegroup_section] = STATE(2256),
    [sym_fixed_section] = STATE(2256),
    [sym_grid_section] = STATE(2256),
    [sym_page_field] = STATE(2256),
    [sym_part_section] = STATE(2256),
    [sym_systempart_section] = STATE(2256),
    [sym_usercontrol_section] = STATE(2256),
    [sym_preproc_split_field] = STATE(2256),
    [sym_label_section] = STATE(2256),
    [sym_addfirst_modification] = STATE(2256),
    [sym_addlast_modification] = STATE(2256),
    [sym_addafter_modification] = STATE(2256),
    [sym_addbefore_modification] = STATE(2256),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2256),
    [sym_movelast_modification] = STATE(2256),
    [sym_moveafter_modification] = STATE(2256),
    [sym_movebefore_modification] = STATE(2256),
    [sym_actions_section] = STATE(2256),
    [sym_views_section] = STATE(2256),
    [sym_dataset_section] = STATE(2256),
    [sym_requestpage_section] = STATE(2256),
    [sym_rendering_section] = STATE(2256),
    [sym_elements_section] = STATE(2256),
    [sym_schema_section] = STATE(2256),
    [sym_assembly_declaration] = STATE(2256),
    [sym_event_declaration] = STATE(2256),
    [sym_procedure] = STATE(2256),
    [sym_preproc_split_procedure] = STATE(2256),
    [sym_preproc_split_procedure_preamble] = STATE(2256),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2256),
    [sym_var_section] = STATE(2256),
    [sym_attribute_item] = STATE(2256),
    [sym_preproc_conditional] = STATE(2256),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_endif] = STATE(8015),
    [sym_preproc_conditional_layout] = STATE(2256),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2256),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2256)] = {
    [sym__body_element] = STATE(2102),
    [sym_empty_statement] = STATE(2102),
    [sym_property] = STATE(2102),
    [sym_permissions_property] = STATE(2102),
    [sym_table_relation_property] = STATE(2102),
    [sym_fields_section] = STATE(2102),
    [sym_keys_section] = STATE(2102),
    [sym_fieldgroups_section] = STATE(2102),
    [sym_enum_value_declaration] = STATE(2102),
    [sym_labels_section] = STATE(2102),
    [sym_layout_section] = STATE(2102),
    [sym__layout_element] = STATE(2102),
    [sym_area_section] = STATE(2102),
    [sym_group_section] = STATE(2102),
    [sym_repeater_section] = STATE(2102),
    [sym_cuegroup_section] = STATE(2102),
    [sym_fixed_section] = STATE(2102),
    [sym_grid_section] = STATE(2102),
    [sym_page_field] = STATE(2102),
    [sym_part_section] = STATE(2102),
    [sym_systempart_section] = STATE(2102),
    [sym_usercontrol_section] = STATE(2102),
    [sym_preproc_split_field] = STATE(2102),
    [sym_label_section] = STATE(2102),
    [sym_addfirst_modification] = STATE(2102),
    [sym_addlast_modification] = STATE(2102),
    [sym_addafter_modification] = STATE(2102),
    [sym_addbefore_modification] = STATE(2102),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2102),
    [sym_movelast_modification] = STATE(2102),
    [sym_moveafter_modification] = STATE(2102),
    [sym_movebefore_modification] = STATE(2102),
    [sym_actions_section] = STATE(2102),
    [sym_views_section] = STATE(2102),
    [sym_dataset_section] = STATE(2102),
    [sym_requestpage_section] = STATE(2102),
    [sym_rendering_section] = STATE(2102),
    [sym_elements_section] = STATE(2102),
    [sym_schema_section] = STATE(2102),
    [sym_assembly_declaration] = STATE(2102),
    [sym_event_declaration] = STATE(2102),
    [sym_procedure] = STATE(2102),
    [sym_preproc_split_procedure] = STATE(2102),
    [sym_preproc_split_procedure_preamble] = STATE(2102),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2102),
    [sym_var_section] = STATE(2102),
    [sym_attribute_item] = STATE(2102),
    [sym_preproc_conditional] = STATE(2102),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_endif] = STATE(7998),
    [sym_preproc_conditional_layout] = STATE(2102),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2102),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2257)] = {
    [sym__body_element] = STATE(2259),
    [sym_empty_statement] = STATE(2259),
    [sym_property] = STATE(2259),
    [sym_permissions_property] = STATE(2259),
    [sym_table_relation_property] = STATE(2259),
    [sym_fields_section] = STATE(2259),
    [sym_keys_section] = STATE(2259),
    [sym_fieldgroups_section] = STATE(2259),
    [sym_enum_value_declaration] = STATE(2259),
    [sym_labels_section] = STATE(2259),
    [sym_layout_section] = STATE(2259),
    [sym__layout_element] = STATE(2259),
    [sym_area_section] = STATE(2259),
    [sym_group_section] = STATE(2259),
    [sym_repeater_section] = STATE(2259),
    [sym_cuegroup_section] = STATE(2259),
    [sym_fixed_section] = STATE(2259),
    [sym_grid_section] = STATE(2259),
    [sym_page_field] = STATE(2259),
    [sym_part_section] = STATE(2259),
    [sym_systempart_section] = STATE(2259),
    [sym_usercontrol_section] = STATE(2259),
    [sym_preproc_split_field] = STATE(2259),
    [sym_label_section] = STATE(2259),
    [sym_addfirst_modification] = STATE(2259),
    [sym_addlast_modification] = STATE(2259),
    [sym_addafter_modification] = STATE(2259),
    [sym_addbefore_modification] = STATE(2259),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2259),
    [sym_movelast_modification] = STATE(2259),
    [sym_moveafter_modification] = STATE(2259),
    [sym_movebefore_modification] = STATE(2259),
    [sym_actions_section] = STATE(2259),
    [sym_views_section] = STATE(2259),
    [sym_dataset_section] = STATE(2259),
    [sym_requestpage_section] = STATE(2259),
    [sym_rendering_section] = STATE(2259),
    [sym_elements_section] = STATE(2259),
    [sym_schema_section] = STATE(2259),
    [sym_assembly_declaration] = STATE(2259),
    [sym_event_declaration] = STATE(2259),
    [sym_procedure] = STATE(2259),
    [sym_preproc_split_procedure] = STATE(2259),
    [sym_preproc_split_procedure_preamble] = STATE(2259),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2259),
    [sym_var_section] = STATE(2259),
    [sym_attribute_item] = STATE(2259),
    [sym_preproc_conditional] = STATE(2259),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_endif] = STATE(7998),
    [sym_preproc_conditional_layout] = STATE(2259),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2259),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2258)] = {
    [ts_builtin_sym_end] = ACTIONS(5277),
    [anon_sym_LBRACE] = ACTIONS(5277),
    [anon_sym_RBRACE] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5277),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5277),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5277),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token6] = ACTIONS(5277),
    [aux_sym_addafter_modification_token1] = ACTIONS(5277),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5277),
    [aux_sym_modify_modification_token1] = ACTIONS(5277),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5277),
    [aux_sym_movelast_modification_token1] = ACTIONS(5277),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5277),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5277),
    [aux_sym_add_dataset_modification_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [anon_sym_tableextension] = ACTIONS(5277),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5277),
    [anon_sym_Tableextension] = ACTIONS(5277),
    [anon_sym_TableExtension] = ACTIONS(5277),
    [anon_sym_tableExtension] = ACTIONS(5277),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_pageextension] = ACTIONS(5277),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5277),
    [anon_sym_Pageextension] = ACTIONS(5277),
    [anon_sym_PageExtension] = ACTIONS(5277),
    [anon_sym_pageExtension] = ACTIONS(5277),
    [anon_sym_codeunit] = ACTIONS(5277),
    [anon_sym_CODEUNIT] = ACTIONS(5277),
    [anon_sym_Codeunit] = ACTIONS(5277),
    [anon_sym_CodeUnit] = ACTIONS(5277),
    [anon_sym_COdeunit] = ACTIONS(5277),
    [anon_sym_codeUnit] = ACTIONS(5277),
    [sym_report_keyword] = ACTIONS(5279),
    [anon_sym_reportextension] = ACTIONS(5277),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5277),
    [anon_sym_Reportextension] = ACTIONS(5277),
    [anon_sym_ReportExtension] = ACTIONS(5277),
    [anon_sym_reportExtension] = ACTIONS(5277),
    [sym_query_keyword] = ACTIONS(5277),
    [anon_sym_xmlport] = ACTIONS(5277),
    [anon_sym_XMLPORT] = ACTIONS(5277),
    [anon_sym_Xmlport] = ACTIONS(5277),
    [anon_sym_XMLport] = ACTIONS(5277),
    [anon_sym_XMLPort] = ACTIONS(5277),
    [anon_sym_XmlPort] = ACTIONS(5277),
    [anon_sym_enum] = ACTIONS(5279),
    [anon_sym_ENUM] = ACTIONS(5279),
    [anon_sym_Enum] = ACTIONS(5279),
    [anon_sym_eNUM] = ACTIONS(5277),
    [anon_sym_eNum] = ACTIONS(5277),
    [anon_sym_ENum] = ACTIONS(5277),
    [anon_sym_enumextension] = ACTIONS(5277),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5277),
    [anon_sym_Enumextension] = ACTIONS(5277),
    [anon_sym_EnumExtension] = ACTIONS(5277),
    [anon_sym_enumExtension] = ACTIONS(5277),
    [sym_interface_keyword] = ACTIONS(5277),
    [anon_sym_controladdin] = ACTIONS(5277),
    [anon_sym_CONTROLADDIN] = ACTIONS(5277),
    [anon_sym_Controladdin] = ACTIONS(5277),
    [anon_sym_ControlAddIn] = ACTIONS(5277),
    [anon_sym_ControlAddin] = ACTIONS(5277),
    [anon_sym_controlAddIn] = ACTIONS(5277),
    [anon_sym_controlAddin] = ACTIONS(5277),
    [anon_sym_dotnet] = ACTIONS(5277),
    [anon_sym_DOTNET] = ACTIONS(5277),
    [anon_sym_Dotnet] = ACTIONS(5277),
    [anon_sym_DotNet] = ACTIONS(5277),
    [anon_sym_dotNet] = ACTIONS(5277),
    [sym_profile_keyword] = ACTIONS(5279),
    [anon_sym_profileextension] = ACTIONS(5277),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5277),
    [anon_sym_Profileextension] = ACTIONS(5277),
    [anon_sym_ProfileExtension] = ACTIONS(5277),
    [anon_sym_profileExtension] = ACTIONS(5277),
    [anon_sym_permissionset] = ACTIONS(5279),
    [anon_sym_PERMISSIONSET] = ACTIONS(5279),
    [anon_sym_Permissionset] = ACTIONS(5279),
    [anon_sym_PermissionSet] = ACTIONS(5279),
    [anon_sym_permissionSet] = ACTIONS(5279),
    [anon_sym_permissionsetextension] = ACTIONS(5277),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5277),
    [anon_sym_Permissionsetextension] = ACTIONS(5277),
    [anon_sym_PermissionSetExtension] = ACTIONS(5277),
    [anon_sym_permissionSetExtension] = ACTIONS(5277),
    [sym_entitlement_keyword] = ACTIONS(5277),
    [anon_sym_pagecustomization] = ACTIONS(5277),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5277),
    [anon_sym_Pagecustomization] = ACTIONS(5277),
    [anon_sym_PageCustomization] = ACTIONS(5277),
    [anon_sym_pageCustomization] = ACTIONS(5277),
    [sym_using_keyword] = ACTIONS(5277),
    [sym_key_keyword] = ACTIONS(5277),
    [sym_area_keyword] = ACTIONS(5277),
    [sym_group_keyword] = ACTIONS(5277),
    [sym_repeater_keyword] = ACTIONS(5277),
    [sym_cuegroup_keyword] = ACTIONS(5277),
    [sym_fixed_keyword] = ACTIONS(5277),
    [sym_grid_keyword] = ACTIONS(5277),
    [sym_part_keyword] = ACTIONS(5277),
    [sym_systempart_keyword] = ACTIONS(5277),
    [sym_usercontrol_keyword] = ACTIONS(5277),
    [sym_dataitem_keyword] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5277),
  },
  [STATE(2259)] = {
    [sym__body_element] = STATE(2102),
    [sym_empty_statement] = STATE(2102),
    [sym_property] = STATE(2102),
    [sym_permissions_property] = STATE(2102),
    [sym_table_relation_property] = STATE(2102),
    [sym_fields_section] = STATE(2102),
    [sym_keys_section] = STATE(2102),
    [sym_fieldgroups_section] = STATE(2102),
    [sym_enum_value_declaration] = STATE(2102),
    [sym_labels_section] = STATE(2102),
    [sym_layout_section] = STATE(2102),
    [sym__layout_element] = STATE(2102),
    [sym_area_section] = STATE(2102),
    [sym_group_section] = STATE(2102),
    [sym_repeater_section] = STATE(2102),
    [sym_cuegroup_section] = STATE(2102),
    [sym_fixed_section] = STATE(2102),
    [sym_grid_section] = STATE(2102),
    [sym_page_field] = STATE(2102),
    [sym_part_section] = STATE(2102),
    [sym_systempart_section] = STATE(2102),
    [sym_usercontrol_section] = STATE(2102),
    [sym_preproc_split_field] = STATE(2102),
    [sym_label_section] = STATE(2102),
    [sym_addfirst_modification] = STATE(2102),
    [sym_addlast_modification] = STATE(2102),
    [sym_addafter_modification] = STATE(2102),
    [sym_addbefore_modification] = STATE(2102),
    [sym_modify_modification] = STATE(5410),
    [sym_movefirst_modification] = STATE(2102),
    [sym_movelast_modification] = STATE(2102),
    [sym_moveafter_modification] = STATE(2102),
    [sym_movebefore_modification] = STATE(2102),
    [sym_actions_section] = STATE(2102),
    [sym_views_section] = STATE(2102),
    [sym_dataset_section] = STATE(2102),
    [sym_requestpage_section] = STATE(2102),
    [sym_rendering_section] = STATE(2102),
    [sym_elements_section] = STATE(2102),
    [sym_schema_section] = STATE(2102),
    [sym_assembly_declaration] = STATE(2102),
    [sym_event_declaration] = STATE(2102),
    [sym_procedure] = STATE(2102),
    [sym_preproc_split_procedure] = STATE(2102),
    [sym_preproc_split_procedure_preamble] = STATE(2102),
    [sym_procedure_modifier] = STATE(17730),
    [sym_trigger_declaration] = STATE(2102),
    [sym_var_section] = STATE(2102),
    [sym_attribute_item] = STATE(2102),
    [sym_preproc_conditional] = STATE(2102),
    [sym_preproc_if] = STATE(2075),
    [sym_preproc_endif] = STATE(7989),
    [sym_preproc_conditional_layout] = STATE(2102),
    [aux_sym_preproc_conditional_layout_mixed_repeat1] = STATE(2102),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_where_condition_token1] = ACTIONS(4560),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4194),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token6] = ACTIONS(4198),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(4202),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4204),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4208),
    [aux_sym_movelast_modification_token1] = ACTIONS(4210),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4212),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4214),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4562),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(4248),
    [sym_group_keyword] = ACTIONS(4250),
    [sym_repeater_keyword] = ACTIONS(4252),
    [sym_cuegroup_keyword] = ACTIONS(4254),
    [sym_fixed_keyword] = ACTIONS(4256),
    [sym_grid_keyword] = ACTIONS(4258),
    [sym_part_keyword] = ACTIONS(4260),
    [sym_systempart_keyword] = ACTIONS(4262),
    [sym_usercontrol_keyword] = ACTIONS(4264),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4280),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2260)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3726),
    [anon_sym_SEMI] = ACTIONS(3728),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3728),
    [anon_sym_COMMA] = ACTIONS(3728),
    [anon_sym_COLON] = ACTIONS(3726),
    [anon_sym_DASH] = ACTIONS(3726),
    [aux_sym_boolean_token1] = ACTIONS(3726),
    [aux_sym_boolean_token2] = ACTIONS(3726),
    [sym_decimal] = ACTIONS(3726),
    [anon_sym_LPAREN] = ACTIONS(3728),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3726),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3726),
    [aux_sym_basic_type_token21] = ACTIONS(3726),
    [aux_sym_basic_type_token22] = ACTIONS(3726),
    [aux_sym_basic_type_token48] = ACTIONS(3726),
    [anon_sym_POUNDif] = ACTIONS(3728),
    [anon_sym_POUNDIF] = ACTIONS(3728),
    [anon_sym_POUNDIf] = ACTIONS(3728),
    [anon_sym_not] = ACTIONS(3726),
    [anon_sym_NOT] = ACTIONS(3726),
    [anon_sym_Not] = ACTIONS(3726),
    [anon_sym_POUNDelif] = ACTIONS(3728),
    [anon_sym_POUNDELIF] = ACTIONS(3728),
    [anon_sym_POUNDElif] = ACTIONS(3728),
    [anon_sym_POUNDelse] = ACTIONS(3728),
    [anon_sym_POUNDELSE] = ACTIONS(3728),
    [anon_sym_POUNDElse] = ACTIONS(3728),
    [anon_sym_POUNDelse2] = ACTIONS(3728),
    [anon_sym_POUNDELSE2] = ACTIONS(3728),
    [anon_sym_POUNDElse2] = ACTIONS(3728),
    [anon_sym_POUNDendif] = ACTIONS(3728),
    [anon_sym_POUNDENDIF] = ACTIONS(3728),
    [anon_sym_POUNDEndif] = ACTIONS(3728),
    [anon_sym_POUNDendif2] = ACTIONS(3728),
    [anon_sym_POUNDENDIF2] = ACTIONS(3728),
    [anon_sym_POUNDEndif2] = ACTIONS(3728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3728),
    [aux_sym__expression_token1] = ACTIONS(3728),
    [aux_sym__expression_token2] = ACTIONS(3728),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3726),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(3726),
    [anon_sym_GT_EQ] = ACTIONS(3728),
    [anon_sym_LT_EQ] = ACTIONS(3728),
    [anon_sym_GT] = ACTIONS(3726),
    [anon_sym_LT] = ACTIONS(3726),
    [anon_sym_LT_GT] = ACTIONS(3728),
    [anon_sym_and] = ACTIONS(3726),
    [anon_sym_AND] = ACTIONS(3726),
    [anon_sym_And] = ACTIONS(3726),
    [anon_sym_or] = ACTIONS(3726),
    [anon_sym_OR] = ACTIONS(3726),
    [anon_sym_Or] = ACTIONS(3726),
    [anon_sym_xor] = ACTIONS(3726),
    [anon_sym_XOR] = ACTIONS(3726),
    [anon_sym_Xor] = ACTIONS(3726),
    [anon_sym_QMARK] = ACTIONS(3728),
    [sym_datetime_literal] = ACTIONS(3728),
    [sym_date_literal] = ACTIONS(3726),
    [sym_time_literal] = ACTIONS(3726),
    [sym_biginteger_literal] = ACTIONS(3728),
    [anon_sym_else] = ACTIONS(3726),
    [anon_sym_ELSE] = ACTIONS(3726),
    [anon_sym_Else] = ACTIONS(3726),
    [anon_sym_in] = ACTIONS(3726),
    [anon_sym_IN] = ACTIONS(3726),
    [anon_sym_In] = ACTIONS(3726),
    [sym_page_keyword] = ACTIONS(3726),
    [anon_sym_codeunit] = ACTIONS(3726),
    [anon_sym_CODEUNIT] = ACTIONS(3726),
    [anon_sym_Codeunit] = ACTIONS(3726),
    [anon_sym_CodeUnit] = ACTIONS(3726),
    [anon_sym_COdeunit] = ACTIONS(3726),
    [anon_sym_codeUnit] = ACTIONS(3726),
    [sym_report_keyword] = ACTIONS(3726),
    [sym_query_keyword] = ACTIONS(3726),
    [anon_sym_xmlport] = ACTIONS(3726),
    [anon_sym_XMLPORT] = ACTIONS(3726),
    [anon_sym_Xmlport] = ACTIONS(3726),
    [anon_sym_XMLport] = ACTIONS(3726),
    [anon_sym_XMLPort] = ACTIONS(3726),
    [anon_sym_XmlPort] = ACTIONS(3726),
    [anon_sym_enum] = ACTIONS(3726),
    [anon_sym_ENUM] = ACTIONS(3726),
    [anon_sym_Enum] = ACTIONS(3726),
    [anon_sym_eNUM] = ACTIONS(3726),
    [anon_sym_eNum] = ACTIONS(3726),
    [anon_sym_ENum] = ACTIONS(3726),
    [sym_quoted_identifier] = ACTIONS(3728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3728),
    [sym_verbatim_string] = ACTIONS(3728),
    [sym_integer] = ACTIONS(3726),
    [sym_continue_as_identifier] = ACTIONS(3728),
    [sym_preproc_open] = ACTIONS(3728),
    [sym_preproc_close] = ACTIONS(3728),
  },
  [STATE(2261)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12773),
    [sym_else_table_relation_fragment] = STATE(12773),
    [sym_table_relation_expression] = STATE(12773),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym_preproc_conditional_permissions] = STATE(9178),
    [sym_tabledata_permission] = STATE(8680),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2092),
    [sym_preproc_endif] = STATE(8700),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7141),
    [sym_xmlport_keyword] = STATE(7141),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [aux_sym_preproc_conditional_permissions_repeat1] = STATE(9178),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_COMMA] = ACTIONS(5303),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4373),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4375),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(3977),
    [anon_sym_POUNDIF] = ACTIONS(3977),
    [anon_sym_POUNDIf] = ACTIONS(3977),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4556),
    [anon_sym_POUNDENDIF] = ACTIONS(4556),
    [anon_sym_POUNDEndif] = ACTIONS(4556),
    [anon_sym_POUNDendif2] = ACTIONS(4556),
    [anon_sym_POUNDENDIF2] = ACTIONS(4556),
    [anon_sym_POUNDEndif2] = ACTIONS(4556),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4389),
    [sym_page_keyword] = ACTIONS(4391),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(4391),
    [sym_query_keyword] = ACTIONS(4391),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(3977),
    [sym_preproc_close] = ACTIONS(4556),
  },
  [STATE(2262)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_COMMA] = ACTIONS(3679),
    [anon_sym_COLON] = ACTIONS(3677),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelif] = ACTIONS(3679),
    [anon_sym_POUNDELIF] = ACTIONS(3679),
    [anon_sym_POUNDElif] = ACTIONS(3679),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [anon_sym_POUNDendif] = ACTIONS(3679),
    [anon_sym_POUNDENDIF] = ACTIONS(3679),
    [anon_sym_POUNDEndif] = ACTIONS(3679),
    [anon_sym_POUNDendif2] = ACTIONS(3679),
    [anon_sym_POUNDENDIF2] = ACTIONS(3679),
    [anon_sym_POUNDEndif2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
    [sym_preproc_close] = ACTIONS(3679),
  },
  [STATE(2263)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3639),
    [anon_sym_SEMI] = ACTIONS(3641),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3641),
    [anon_sym_COMMA] = ACTIONS(3641),
    [anon_sym_COLON] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3639),
    [aux_sym_boolean_token1] = ACTIONS(3639),
    [aux_sym_boolean_token2] = ACTIONS(3639),
    [sym_decimal] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3641),
    [anon_sym_DOT_DOT] = ACTIONS(3641),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3639),
    [anon_sym_STAR] = ACTIONS(3639),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3639),
    [aux_sym_basic_type_token21] = ACTIONS(3639),
    [aux_sym_basic_type_token22] = ACTIONS(3639),
    [aux_sym_basic_type_token48] = ACTIONS(3639),
    [anon_sym_POUNDif] = ACTIONS(3641),
    [anon_sym_POUNDIF] = ACTIONS(3641),
    [anon_sym_POUNDIf] = ACTIONS(3641),
    [anon_sym_not] = ACTIONS(3639),
    [anon_sym_NOT] = ACTIONS(3639),
    [anon_sym_Not] = ACTIONS(3639),
    [anon_sym_POUNDelif] = ACTIONS(3641),
    [anon_sym_POUNDELIF] = ACTIONS(3641),
    [anon_sym_POUNDElif] = ACTIONS(3641),
    [anon_sym_POUNDelse] = ACTIONS(3641),
    [anon_sym_POUNDELSE] = ACTIONS(3641),
    [anon_sym_POUNDElse] = ACTIONS(3641),
    [anon_sym_POUNDelse2] = ACTIONS(3641),
    [anon_sym_POUNDELSE2] = ACTIONS(3641),
    [anon_sym_POUNDElse2] = ACTIONS(3641),
    [anon_sym_POUNDendif] = ACTIONS(3641),
    [anon_sym_POUNDENDIF] = ACTIONS(3641),
    [anon_sym_POUNDEndif] = ACTIONS(3641),
    [anon_sym_POUNDendif2] = ACTIONS(3641),
    [anon_sym_POUNDENDIF2] = ACTIONS(3641),
    [anon_sym_POUNDEndif2] = ACTIONS(3641),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3641),
    [aux_sym__expression_token1] = ACTIONS(3641),
    [aux_sym__expression_token2] = ACTIONS(3641),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3639),
    [anon_sym_SLASH] = ACTIONS(3639),
    [anon_sym_div] = ACTIONS(3639),
    [anon_sym_DIV] = ACTIONS(3639),
    [anon_sym_Div] = ACTIONS(3639),
    [anon_sym_mod] = ACTIONS(3639),
    [anon_sym_MOD] = ACTIONS(3639),
    [anon_sym_Mod] = ACTIONS(3639),
    [anon_sym_PLUS] = ACTIONS(3639),
    [anon_sym_GT_EQ] = ACTIONS(3641),
    [anon_sym_LT_EQ] = ACTIONS(3641),
    [anon_sym_GT] = ACTIONS(3639),
    [anon_sym_LT] = ACTIONS(3639),
    [anon_sym_LT_GT] = ACTIONS(3641),
    [anon_sym_and] = ACTIONS(3639),
    [anon_sym_AND] = ACTIONS(3639),
    [anon_sym_And] = ACTIONS(3639),
    [anon_sym_or] = ACTIONS(3639),
    [anon_sym_OR] = ACTIONS(3639),
    [anon_sym_Or] = ACTIONS(3639),
    [anon_sym_xor] = ACTIONS(3639),
    [anon_sym_XOR] = ACTIONS(3639),
    [anon_sym_Xor] = ACTIONS(3639),
    [anon_sym_QMARK] = ACTIONS(3641),
    [sym_datetime_literal] = ACTIONS(3641),
    [sym_date_literal] = ACTIONS(3639),
    [sym_time_literal] = ACTIONS(3639),
    [sym_biginteger_literal] = ACTIONS(3641),
    [anon_sym_else] = ACTIONS(3639),
    [anon_sym_ELSE] = ACTIONS(3639),
    [anon_sym_Else] = ACTIONS(3639),
    [anon_sym_in] = ACTIONS(3639),
    [anon_sym_IN] = ACTIONS(3639),
    [anon_sym_In] = ACTIONS(3639),
    [sym_page_keyword] = ACTIONS(3639),
    [anon_sym_codeunit] = ACTIONS(3639),
    [anon_sym_CODEUNIT] = ACTIONS(3639),
    [anon_sym_Codeunit] = ACTIONS(3639),
    [anon_sym_CodeUnit] = ACTIONS(3639),
    [anon_sym_COdeunit] = ACTIONS(3639),
    [anon_sym_codeUnit] = ACTIONS(3639),
    [sym_report_keyword] = ACTIONS(3639),
    [sym_query_keyword] = ACTIONS(3639),
    [anon_sym_xmlport] = ACTIONS(3639),
    [anon_sym_XMLPORT] = ACTIONS(3639),
    [anon_sym_Xmlport] = ACTIONS(3639),
    [anon_sym_XMLport] = ACTIONS(3639),
    [anon_sym_XMLPort] = ACTIONS(3639),
    [anon_sym_XmlPort] = ACTIONS(3639),
    [anon_sym_enum] = ACTIONS(3639),
    [anon_sym_ENUM] = ACTIONS(3639),
    [anon_sym_Enum] = ACTIONS(3639),
    [anon_sym_eNUM] = ACTIONS(3639),
    [anon_sym_eNum] = ACTIONS(3639),
    [anon_sym_ENum] = ACTIONS(3639),
    [sym_quoted_identifier] = ACTIONS(3641),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3641),
    [sym_verbatim_string] = ACTIONS(3641),
    [sym_integer] = ACTIONS(3639),
    [sym_continue_as_identifier] = ACTIONS(3641),
    [sym_preproc_open] = ACTIONS(3641),
    [sym_preproc_close] = ACTIONS(3641),
  },
  [STATE(2264)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2265)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3576),
    [anon_sym_SEMI] = ACTIONS(3578),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3578),
    [anon_sym_COLON] = ACTIONS(3576),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3576),
    [aux_sym_boolean_token2] = ACTIONS(3576),
    [sym_decimal] = ACTIONS(3576),
    [anon_sym_LPAREN] = ACTIONS(3578),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3576),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3576),
    [aux_sym_basic_type_token21] = ACTIONS(3576),
    [aux_sym_basic_type_token22] = ACTIONS(3576),
    [aux_sym_basic_type_token48] = ACTIONS(3576),
    [anon_sym_POUNDif] = ACTIONS(3578),
    [anon_sym_POUNDIF] = ACTIONS(3578),
    [anon_sym_POUNDIf] = ACTIONS(3578),
    [anon_sym_not] = ACTIONS(3576),
    [anon_sym_NOT] = ACTIONS(3576),
    [anon_sym_Not] = ACTIONS(3576),
    [anon_sym_POUNDelif] = ACTIONS(3578),
    [anon_sym_POUNDELIF] = ACTIONS(3578),
    [anon_sym_POUNDElif] = ACTIONS(3578),
    [anon_sym_POUNDelse] = ACTIONS(3578),
    [anon_sym_POUNDELSE] = ACTIONS(3578),
    [anon_sym_POUNDElse] = ACTIONS(3578),
    [anon_sym_POUNDelse2] = ACTIONS(3578),
    [anon_sym_POUNDELSE2] = ACTIONS(3578),
    [anon_sym_POUNDElse2] = ACTIONS(3578),
    [anon_sym_POUNDendif] = ACTIONS(3578),
    [anon_sym_POUNDENDIF] = ACTIONS(3578),
    [anon_sym_POUNDEndif] = ACTIONS(3578),
    [anon_sym_POUNDendif2] = ACTIONS(3578),
    [anon_sym_POUNDENDIF2] = ACTIONS(3578),
    [anon_sym_POUNDEndif2] = ACTIONS(3578),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5307),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3576),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3576),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(5321),
    [anon_sym_OR] = ACTIONS(5323),
    [anon_sym_Or] = ACTIONS(5325),
    [anon_sym_xor] = ACTIONS(5327),
    [anon_sym_XOR] = ACTIONS(5329),
    [anon_sym_Xor] = ACTIONS(5331),
    [anon_sym_QMARK] = ACTIONS(5333),
    [sym_datetime_literal] = ACTIONS(3578),
    [sym_date_literal] = ACTIONS(3576),
    [sym_time_literal] = ACTIONS(3576),
    [sym_biginteger_literal] = ACTIONS(3578),
    [anon_sym_else] = ACTIONS(3576),
    [anon_sym_ELSE] = ACTIONS(3576),
    [anon_sym_Else] = ACTIONS(3576),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3576),
    [anon_sym_codeunit] = ACTIONS(3576),
    [anon_sym_CODEUNIT] = ACTIONS(3576),
    [anon_sym_Codeunit] = ACTIONS(3576),
    [anon_sym_CodeUnit] = ACTIONS(3576),
    [anon_sym_COdeunit] = ACTIONS(3576),
    [anon_sym_codeUnit] = ACTIONS(3576),
    [sym_report_keyword] = ACTIONS(3576),
    [sym_query_keyword] = ACTIONS(3576),
    [anon_sym_xmlport] = ACTIONS(3576),
    [anon_sym_XMLPORT] = ACTIONS(3576),
    [anon_sym_Xmlport] = ACTIONS(3576),
    [anon_sym_XMLport] = ACTIONS(3576),
    [anon_sym_XMLPort] = ACTIONS(3576),
    [anon_sym_XmlPort] = ACTIONS(3576),
    [anon_sym_enum] = ACTIONS(3576),
    [anon_sym_ENUM] = ACTIONS(3576),
    [anon_sym_Enum] = ACTIONS(3576),
    [anon_sym_eNUM] = ACTIONS(3576),
    [anon_sym_eNum] = ACTIONS(3576),
    [anon_sym_ENum] = ACTIONS(3576),
    [sym_quoted_identifier] = ACTIONS(3578),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3578),
    [sym_verbatim_string] = ACTIONS(3578),
    [sym_integer] = ACTIONS(3576),
    [sym_continue_as_identifier] = ACTIONS(3578),
    [sym_preproc_open] = ACTIONS(3578),
    [sym_preproc_close] = ACTIONS(3578),
  },
  [STATE(2266)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2267)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2268)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2269)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2270)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2271)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2272)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2273)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_COMMA] = ACTIONS(3679),
    [anon_sym_COLON] = ACTIONS(3677),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelif] = ACTIONS(3679),
    [anon_sym_POUNDELIF] = ACTIONS(3679),
    [anon_sym_POUNDElif] = ACTIONS(3679),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [anon_sym_POUNDendif] = ACTIONS(3679),
    [anon_sym_POUNDENDIF] = ACTIONS(3679),
    [anon_sym_POUNDEndif] = ACTIONS(3679),
    [anon_sym_POUNDendif2] = ACTIONS(3679),
    [anon_sym_POUNDENDIF2] = ACTIONS(3679),
    [anon_sym_POUNDEndif2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
    [sym_preproc_close] = ACTIONS(3679),
  },
  [STATE(2274)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2275)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2276)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2286),
    [sym_identifier] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(5335),
    [anon_sym_EQ] = ACTIONS(3695),
    [anon_sym_COMMA] = ACTIONS(3695),
    [anon_sym_COLON] = ACTIONS(3693),
    [anon_sym_DASH] = ACTIONS(3693),
    [aux_sym_boolean_token1] = ACTIONS(3693),
    [aux_sym_boolean_token2] = ACTIONS(3693),
    [sym_decimal] = ACTIONS(3693),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_DOT_DOT] = ACTIONS(3695),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [aux_sym_record_type_token1] = ACTIONS(3693),
    [aux_sym_basic_type_token21] = ACTIONS(3693),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_basic_type_token48] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_not] = ACTIONS(3693),
    [anon_sym_NOT] = ACTIONS(3693),
    [anon_sym_Not] = ACTIONS(3693),
    [anon_sym_POUNDelif] = ACTIONS(3695),
    [anon_sym_POUNDELIF] = ACTIONS(3695),
    [anon_sym_POUNDElif] = ACTIONS(3695),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [anon_sym_POUNDendif] = ACTIONS(3695),
    [anon_sym_POUNDENDIF] = ACTIONS(3695),
    [anon_sym_POUNDEndif] = ACTIONS(3695),
    [anon_sym_POUNDendif2] = ACTIONS(3695),
    [anon_sym_POUNDENDIF2] = ACTIONS(3695),
    [anon_sym_POUNDEndif2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3695),
    [aux_sym__expression_token1] = ACTIONS(3695),
    [aux_sym__expression_token2] = ACTIONS(3695),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3693),
    [anon_sym_SLASH] = ACTIONS(3693),
    [anon_sym_div] = ACTIONS(3693),
    [anon_sym_DIV] = ACTIONS(3693),
    [anon_sym_Div] = ACTIONS(3693),
    [anon_sym_mod] = ACTIONS(3693),
    [anon_sym_MOD] = ACTIONS(3693),
    [anon_sym_Mod] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(3693),
    [anon_sym_GT_EQ] = ACTIONS(3695),
    [anon_sym_LT_EQ] = ACTIONS(3695),
    [anon_sym_GT] = ACTIONS(3693),
    [anon_sym_LT] = ACTIONS(3693),
    [anon_sym_LT_GT] = ACTIONS(3695),
    [anon_sym_and] = ACTIONS(3693),
    [anon_sym_AND] = ACTIONS(3693),
    [anon_sym_And] = ACTIONS(3693),
    [anon_sym_or] = ACTIONS(3693),
    [anon_sym_OR] = ACTIONS(3693),
    [anon_sym_Or] = ACTIONS(3693),
    [anon_sym_xor] = ACTIONS(3693),
    [anon_sym_XOR] = ACTIONS(3693),
    [anon_sym_Xor] = ACTIONS(3693),
    [anon_sym_QMARK] = ACTIONS(3695),
    [sym_datetime_literal] = ACTIONS(3695),
    [sym_date_literal] = ACTIONS(3693),
    [sym_time_literal] = ACTIONS(3693),
    [sym_biginteger_literal] = ACTIONS(3695),
    [anon_sym_else] = ACTIONS(3693),
    [anon_sym_ELSE] = ACTIONS(3693),
    [anon_sym_Else] = ACTIONS(3693),
    [anon_sym_in] = ACTIONS(3693),
    [anon_sym_IN] = ACTIONS(3693),
    [anon_sym_In] = ACTIONS(3693),
    [sym_page_keyword] = ACTIONS(3693),
    [anon_sym_codeunit] = ACTIONS(3693),
    [anon_sym_CODEUNIT] = ACTIONS(3693),
    [anon_sym_Codeunit] = ACTIONS(3693),
    [anon_sym_CodeUnit] = ACTIONS(3693),
    [anon_sym_COdeunit] = ACTIONS(3693),
    [anon_sym_codeUnit] = ACTIONS(3693),
    [sym_report_keyword] = ACTIONS(3693),
    [sym_query_keyword] = ACTIONS(3693),
    [anon_sym_xmlport] = ACTIONS(3693),
    [anon_sym_XMLPORT] = ACTIONS(3693),
    [anon_sym_Xmlport] = ACTIONS(3693),
    [anon_sym_XMLport] = ACTIONS(3693),
    [anon_sym_XMLPort] = ACTIONS(3693),
    [anon_sym_XmlPort] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_ENUM] = ACTIONS(3693),
    [anon_sym_Enum] = ACTIONS(3693),
    [anon_sym_eNUM] = ACTIONS(3693),
    [anon_sym_eNum] = ACTIONS(3693),
    [anon_sym_ENum] = ACTIONS(3693),
    [sym_temporary_keyword] = ACTIONS(3693),
    [sym_quoted_identifier] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3695),
    [sym_verbatim_string] = ACTIONS(3695),
    [sym_integer] = ACTIONS(3693),
    [sym_continue_as_identifier] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
    [sym_preproc_close] = ACTIONS(3695),
  },
  [STATE(2277)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2278)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2279)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2280)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2281)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2282)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2283)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3647),
    [anon_sym_SEMI] = ACTIONS(3649),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3649),
    [anon_sym_COMMA] = ACTIONS(3649),
    [anon_sym_COLON] = ACTIONS(3647),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3647),
    [aux_sym_boolean_token2] = ACTIONS(3647),
    [sym_decimal] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3649),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3647),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3647),
    [aux_sym_basic_type_token21] = ACTIONS(3647),
    [aux_sym_basic_type_token22] = ACTIONS(3647),
    [aux_sym_basic_type_token48] = ACTIONS(3647),
    [anon_sym_POUNDif] = ACTIONS(3649),
    [anon_sym_POUNDIF] = ACTIONS(3649),
    [anon_sym_POUNDIf] = ACTIONS(3649),
    [anon_sym_not] = ACTIONS(3647),
    [anon_sym_NOT] = ACTIONS(3647),
    [anon_sym_Not] = ACTIONS(3647),
    [anon_sym_POUNDelif] = ACTIONS(3649),
    [anon_sym_POUNDELIF] = ACTIONS(3649),
    [anon_sym_POUNDElif] = ACTIONS(3649),
    [anon_sym_POUNDelse] = ACTIONS(3649),
    [anon_sym_POUNDELSE] = ACTIONS(3649),
    [anon_sym_POUNDElse] = ACTIONS(3649),
    [anon_sym_POUNDelse2] = ACTIONS(3649),
    [anon_sym_POUNDELSE2] = ACTIONS(3649),
    [anon_sym_POUNDElse2] = ACTIONS(3649),
    [anon_sym_POUNDendif] = ACTIONS(3649),
    [anon_sym_POUNDENDIF] = ACTIONS(3649),
    [anon_sym_POUNDEndif] = ACTIONS(3649),
    [anon_sym_POUNDendif2] = ACTIONS(3649),
    [anon_sym_POUNDENDIF2] = ACTIONS(3649),
    [anon_sym_POUNDEndif2] = ACTIONS(3649),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3649),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3647),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3647),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3649),
    [anon_sym_LT_EQ] = ACTIONS(3649),
    [anon_sym_GT] = ACTIONS(3647),
    [anon_sym_LT] = ACTIONS(3647),
    [anon_sym_LT_GT] = ACTIONS(3649),
    [anon_sym_and] = ACTIONS(3647),
    [anon_sym_AND] = ACTIONS(3647),
    [anon_sym_And] = ACTIONS(3647),
    [anon_sym_or] = ACTIONS(3647),
    [anon_sym_OR] = ACTIONS(3647),
    [anon_sym_Or] = ACTIONS(3647),
    [anon_sym_xor] = ACTIONS(3647),
    [anon_sym_XOR] = ACTIONS(3647),
    [anon_sym_Xor] = ACTIONS(3647),
    [anon_sym_QMARK] = ACTIONS(3649),
    [sym_datetime_literal] = ACTIONS(3649),
    [sym_date_literal] = ACTIONS(3647),
    [sym_time_literal] = ACTIONS(3647),
    [sym_biginteger_literal] = ACTIONS(3649),
    [anon_sym_else] = ACTIONS(3647),
    [anon_sym_ELSE] = ACTIONS(3647),
    [anon_sym_Else] = ACTIONS(3647),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3647),
    [anon_sym_codeunit] = ACTIONS(3647),
    [anon_sym_CODEUNIT] = ACTIONS(3647),
    [anon_sym_Codeunit] = ACTIONS(3647),
    [anon_sym_CodeUnit] = ACTIONS(3647),
    [anon_sym_COdeunit] = ACTIONS(3647),
    [anon_sym_codeUnit] = ACTIONS(3647),
    [sym_report_keyword] = ACTIONS(3647),
    [sym_query_keyword] = ACTIONS(3647),
    [anon_sym_xmlport] = ACTIONS(3647),
    [anon_sym_XMLPORT] = ACTIONS(3647),
    [anon_sym_Xmlport] = ACTIONS(3647),
    [anon_sym_XMLport] = ACTIONS(3647),
    [anon_sym_XMLPort] = ACTIONS(3647),
    [anon_sym_XmlPort] = ACTIONS(3647),
    [anon_sym_enum] = ACTIONS(3647),
    [anon_sym_ENUM] = ACTIONS(3647),
    [anon_sym_Enum] = ACTIONS(3647),
    [anon_sym_eNUM] = ACTIONS(3647),
    [anon_sym_eNum] = ACTIONS(3647),
    [anon_sym_ENum] = ACTIONS(3647),
    [sym_quoted_identifier] = ACTIONS(3649),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3649),
    [sym_verbatim_string] = ACTIONS(3649),
    [sym_integer] = ACTIONS(3647),
    [sym_continue_as_identifier] = ACTIONS(3649),
    [sym_preproc_open] = ACTIONS(3649),
    [sym_preproc_close] = ACTIONS(3649),
  },
  [STATE(2284)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_COMMA] = ACTIONS(3564),
    [anon_sym_COLON] = ACTIONS(3562),
    [anon_sym_DASH] = ACTIONS(3562),
    [aux_sym_boolean_token1] = ACTIONS(3562),
    [aux_sym_boolean_token2] = ACTIONS(3562),
    [sym_decimal] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_record_type_token1] = ACTIONS(3562),
    [aux_sym_basic_type_token21] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token48] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_not] = ACTIONS(3562),
    [anon_sym_NOT] = ACTIONS(3562),
    [anon_sym_Not] = ACTIONS(3562),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3562),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [sym_datetime_literal] = ACTIONS(3564),
    [sym_date_literal] = ACTIONS(3562),
    [sym_time_literal] = ACTIONS(3562),
    [sym_biginteger_literal] = ACTIONS(3564),
    [anon_sym_else] = ACTIONS(3562),
    [anon_sym_ELSE] = ACTIONS(3562),
    [anon_sym_Else] = ACTIONS(3562),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_page_keyword] = ACTIONS(3562),
    [anon_sym_codeunit] = ACTIONS(3562),
    [anon_sym_CODEUNIT] = ACTIONS(3562),
    [anon_sym_Codeunit] = ACTIONS(3562),
    [anon_sym_CodeUnit] = ACTIONS(3562),
    [anon_sym_COdeunit] = ACTIONS(3562),
    [anon_sym_codeUnit] = ACTIONS(3562),
    [sym_report_keyword] = ACTIONS(3562),
    [sym_query_keyword] = ACTIONS(3562),
    [anon_sym_xmlport] = ACTIONS(3562),
    [anon_sym_XMLPORT] = ACTIONS(3562),
    [anon_sym_Xmlport] = ACTIONS(3562),
    [anon_sym_XMLport] = ACTIONS(3562),
    [anon_sym_XMLPort] = ACTIONS(3562),
    [anon_sym_XmlPort] = ACTIONS(3562),
    [anon_sym_enum] = ACTIONS(3562),
    [anon_sym_ENUM] = ACTIONS(3562),
    [anon_sym_Enum] = ACTIONS(3562),
    [anon_sym_eNUM] = ACTIONS(3562),
    [anon_sym_eNum] = ACTIONS(3562),
    [anon_sym_ENum] = ACTIONS(3562),
    [sym_temporary_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3564),
    [sym_verbatim_string] = ACTIONS(3564),
    [sym_integer] = ACTIONS(3562),
    [sym_continue_as_identifier] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
  },
  [STATE(2285)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3673),
    [anon_sym_SEMI] = ACTIONS(3675),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3675),
    [anon_sym_COLON] = ACTIONS(3673),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3673),
    [aux_sym_boolean_token2] = ACTIONS(3673),
    [sym_decimal] = ACTIONS(3673),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3673),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3673),
    [aux_sym_basic_type_token21] = ACTIONS(3673),
    [aux_sym_basic_type_token22] = ACTIONS(3673),
    [aux_sym_basic_type_token48] = ACTIONS(3673),
    [anon_sym_POUNDif] = ACTIONS(3675),
    [anon_sym_POUNDIF] = ACTIONS(3675),
    [anon_sym_POUNDIf] = ACTIONS(3675),
    [anon_sym_not] = ACTIONS(3673),
    [anon_sym_NOT] = ACTIONS(3673),
    [anon_sym_Not] = ACTIONS(3673),
    [anon_sym_POUNDelif] = ACTIONS(3675),
    [anon_sym_POUNDELIF] = ACTIONS(3675),
    [anon_sym_POUNDElif] = ACTIONS(3675),
    [anon_sym_POUNDelse] = ACTIONS(3675),
    [anon_sym_POUNDELSE] = ACTIONS(3675),
    [anon_sym_POUNDElse] = ACTIONS(3675),
    [anon_sym_POUNDelse2] = ACTIONS(3675),
    [anon_sym_POUNDELSE2] = ACTIONS(3675),
    [anon_sym_POUNDElse2] = ACTIONS(3675),
    [anon_sym_POUNDendif] = ACTIONS(3675),
    [anon_sym_POUNDENDIF] = ACTIONS(3675),
    [anon_sym_POUNDEndif] = ACTIONS(3675),
    [anon_sym_POUNDendif2] = ACTIONS(3675),
    [anon_sym_POUNDENDIF2] = ACTIONS(3675),
    [anon_sym_POUNDEndif2] = ACTIONS(3675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3675),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3673),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(5321),
    [anon_sym_OR] = ACTIONS(5323),
    [anon_sym_Or] = ACTIONS(5325),
    [anon_sym_xor] = ACTIONS(5327),
    [anon_sym_XOR] = ACTIONS(5329),
    [anon_sym_Xor] = ACTIONS(5331),
    [anon_sym_QMARK] = ACTIONS(5333),
    [sym_datetime_literal] = ACTIONS(3675),
    [sym_date_literal] = ACTIONS(3673),
    [sym_time_literal] = ACTIONS(3673),
    [sym_biginteger_literal] = ACTIONS(3675),
    [anon_sym_else] = ACTIONS(3673),
    [anon_sym_ELSE] = ACTIONS(3673),
    [anon_sym_Else] = ACTIONS(3673),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3673),
    [anon_sym_codeunit] = ACTIONS(3673),
    [anon_sym_CODEUNIT] = ACTIONS(3673),
    [anon_sym_Codeunit] = ACTIONS(3673),
    [anon_sym_CodeUnit] = ACTIONS(3673),
    [anon_sym_COdeunit] = ACTIONS(3673),
    [anon_sym_codeUnit] = ACTIONS(3673),
    [sym_report_keyword] = ACTIONS(3673),
    [sym_query_keyword] = ACTIONS(3673),
    [anon_sym_xmlport] = ACTIONS(3673),
    [anon_sym_XMLPORT] = ACTIONS(3673),
    [anon_sym_Xmlport] = ACTIONS(3673),
    [anon_sym_XMLport] = ACTIONS(3673),
    [anon_sym_XMLPort] = ACTIONS(3673),
    [anon_sym_XmlPort] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_ENUM] = ACTIONS(3673),
    [anon_sym_Enum] = ACTIONS(3673),
    [anon_sym_eNUM] = ACTIONS(3673),
    [anon_sym_eNum] = ACTIONS(3673),
    [anon_sym_ENum] = ACTIONS(3673),
    [sym_quoted_identifier] = ACTIONS(3675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3675),
    [sym_verbatim_string] = ACTIONS(3675),
    [sym_integer] = ACTIONS(3673),
    [sym_continue_as_identifier] = ACTIONS(3675),
    [sym_preproc_open] = ACTIONS(3675),
    [sym_preproc_close] = ACTIONS(3675),
  },
  [STATE(2286)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2287),
    [sym_identifier] = ACTIONS(3699),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(5335),
    [anon_sym_EQ] = ACTIONS(3701),
    [anon_sym_COMMA] = ACTIONS(3701),
    [anon_sym_COLON] = ACTIONS(3699),
    [anon_sym_DASH] = ACTIONS(3699),
    [aux_sym_boolean_token1] = ACTIONS(3699),
    [aux_sym_boolean_token2] = ACTIONS(3699),
    [sym_decimal] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_DOT_DOT] = ACTIONS(3701),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3699),
    [anon_sym_STAR] = ACTIONS(3699),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [aux_sym_record_type_token1] = ACTIONS(3699),
    [aux_sym_basic_type_token21] = ACTIONS(3699),
    [aux_sym_basic_type_token22] = ACTIONS(3699),
    [aux_sym_basic_type_token48] = ACTIONS(3699),
    [anon_sym_POUNDif] = ACTIONS(3701),
    [anon_sym_POUNDIF] = ACTIONS(3701),
    [anon_sym_POUNDIf] = ACTIONS(3701),
    [anon_sym_not] = ACTIONS(3699),
    [anon_sym_NOT] = ACTIONS(3699),
    [anon_sym_Not] = ACTIONS(3699),
    [anon_sym_POUNDelif] = ACTIONS(3701),
    [anon_sym_POUNDELIF] = ACTIONS(3701),
    [anon_sym_POUNDElif] = ACTIONS(3701),
    [anon_sym_POUNDelse] = ACTIONS(3701),
    [anon_sym_POUNDELSE] = ACTIONS(3701),
    [anon_sym_POUNDElse] = ACTIONS(3701),
    [anon_sym_POUNDelse2] = ACTIONS(3701),
    [anon_sym_POUNDELSE2] = ACTIONS(3701),
    [anon_sym_POUNDElse2] = ACTIONS(3701),
    [anon_sym_POUNDendif] = ACTIONS(3701),
    [anon_sym_POUNDENDIF] = ACTIONS(3701),
    [anon_sym_POUNDEndif] = ACTIONS(3701),
    [anon_sym_POUNDendif2] = ACTIONS(3701),
    [anon_sym_POUNDENDIF2] = ACTIONS(3701),
    [anon_sym_POUNDEndif2] = ACTIONS(3701),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3701),
    [aux_sym__expression_token1] = ACTIONS(3701),
    [aux_sym__expression_token2] = ACTIONS(3701),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3699),
    [anon_sym_SLASH] = ACTIONS(3699),
    [anon_sym_div] = ACTIONS(3699),
    [anon_sym_DIV] = ACTIONS(3699),
    [anon_sym_Div] = ACTIONS(3699),
    [anon_sym_mod] = ACTIONS(3699),
    [anon_sym_MOD] = ACTIONS(3699),
    [anon_sym_Mod] = ACTIONS(3699),
    [anon_sym_PLUS] = ACTIONS(3699),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT] = ACTIONS(3699),
    [anon_sym_LT] = ACTIONS(3699),
    [anon_sym_LT_GT] = ACTIONS(3701),
    [anon_sym_and] = ACTIONS(3699),
    [anon_sym_AND] = ACTIONS(3699),
    [anon_sym_And] = ACTIONS(3699),
    [anon_sym_or] = ACTIONS(3699),
    [anon_sym_OR] = ACTIONS(3699),
    [anon_sym_Or] = ACTIONS(3699),
    [anon_sym_xor] = ACTIONS(3699),
    [anon_sym_XOR] = ACTIONS(3699),
    [anon_sym_Xor] = ACTIONS(3699),
    [anon_sym_QMARK] = ACTIONS(3701),
    [sym_datetime_literal] = ACTIONS(3701),
    [sym_date_literal] = ACTIONS(3699),
    [sym_time_literal] = ACTIONS(3699),
    [sym_biginteger_literal] = ACTIONS(3701),
    [anon_sym_else] = ACTIONS(3699),
    [anon_sym_ELSE] = ACTIONS(3699),
    [anon_sym_Else] = ACTIONS(3699),
    [anon_sym_in] = ACTIONS(3699),
    [anon_sym_IN] = ACTIONS(3699),
    [anon_sym_In] = ACTIONS(3699),
    [sym_page_keyword] = ACTIONS(3699),
    [anon_sym_codeunit] = ACTIONS(3699),
    [anon_sym_CODEUNIT] = ACTIONS(3699),
    [anon_sym_Codeunit] = ACTIONS(3699),
    [anon_sym_CodeUnit] = ACTIONS(3699),
    [anon_sym_COdeunit] = ACTIONS(3699),
    [anon_sym_codeUnit] = ACTIONS(3699),
    [sym_report_keyword] = ACTIONS(3699),
    [sym_query_keyword] = ACTIONS(3699),
    [anon_sym_xmlport] = ACTIONS(3699),
    [anon_sym_XMLPORT] = ACTIONS(3699),
    [anon_sym_Xmlport] = ACTIONS(3699),
    [anon_sym_XMLport] = ACTIONS(3699),
    [anon_sym_XMLPort] = ACTIONS(3699),
    [anon_sym_XmlPort] = ACTIONS(3699),
    [anon_sym_enum] = ACTIONS(3699),
    [anon_sym_ENUM] = ACTIONS(3699),
    [anon_sym_Enum] = ACTIONS(3699),
    [anon_sym_eNUM] = ACTIONS(3699),
    [anon_sym_eNum] = ACTIONS(3699),
    [anon_sym_ENum] = ACTIONS(3699),
    [sym_temporary_keyword] = ACTIONS(3699),
    [sym_quoted_identifier] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3701),
    [sym_verbatim_string] = ACTIONS(3701),
    [sym_integer] = ACTIONS(3699),
    [sym_continue_as_identifier] = ACTIONS(3701),
    [sym_preproc_open] = ACTIONS(3701),
    [sym_preproc_close] = ACTIONS(3701),
  },
  [STATE(2287)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2287),
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(5337),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_COMMA] = ACTIONS(3705),
    [anon_sym_COLON] = ACTIONS(3703),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelif] = ACTIONS(3705),
    [anon_sym_POUNDELIF] = ACTIONS(3705),
    [anon_sym_POUNDElif] = ACTIONS(3705),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [anon_sym_POUNDendif] = ACTIONS(3705),
    [anon_sym_POUNDENDIF] = ACTIONS(3705),
    [anon_sym_POUNDEndif] = ACTIONS(3705),
    [anon_sym_POUNDendif2] = ACTIONS(3705),
    [anon_sym_POUNDENDIF2] = ACTIONS(3705),
    [anon_sym_POUNDEndif2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3705),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
    [sym_preproc_close] = ACTIONS(3705),
  },
  [STATE(2288)] = {
    [sym_boolean] = STATE(2717),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_elif] = STATE(2653),
    [sym_preproc_else] = STATE(3391),
    [sym_preproc_endif] = STATE(3734),
    [sym_assignment_expression] = STATE(8840),
    [sym_case_branch] = STATE(2341),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3864),
    [sym_preproc_conditional_case_patterns] = STATE(3864),
    [sym__single_pattern] = STATE(4801),
    [sym_case_else_branch] = STATE(10786),
    [sym__expression] = STATE(8840),
    [sym_keyword_identifier] = STATE(2518),
    [sym_range_expression] = STATE(2717),
    [sym_multiplicative_expression] = STATE(2717),
    [sym_additive_expression] = STATE(2717),
    [sym_comparison_expression] = STATE(2717),
    [sym_logical_expression] = STATE(2717),
    [sym_ternary_expression] = STATE(8840),
    [sym_unary_expression] = STATE(2717),
    [sym_call_expression] = STATE(2648),
    [sym_member_expression] = STATE(2518),
    [sym_subscript_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2717),
    [sym_list_literal] = STATE(8840),
    [sym_qualified_enum_value] = STATE(2518),
    [sym_database_reference] = STATE(2717),
    [sym__literal_value] = STATE(2717),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2341),
    [aux_sym_preproc_conditional_case_repeat2] = STATE(10787),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3489),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(10788),
    [sym_identifier] = ACTIONS(5340),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(5342),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(5346),
    [sym_date_literal] = ACTIONS(5342),
    [sym_time_literal] = ACTIONS(5342),
    [sym_biginteger_literal] = ACTIONS(5346),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(5350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5346),
    [sym_verbatim_string] = ACTIONS(5346),
    [sym_integer] = ACTIONS(5342),
    [sym_continue_as_identifier] = ACTIONS(5352),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2289)] = {
    [sym_argument_list] = STATE(2317),
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(3683),
    [anon_sym_COLON] = ACTIONS(3681),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5354),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(5356),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelif] = ACTIONS(3683),
    [anon_sym_POUNDELIF] = ACTIONS(3683),
    [anon_sym_POUNDElif] = ACTIONS(3683),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [anon_sym_POUNDendif] = ACTIONS(3683),
    [anon_sym_POUNDENDIF] = ACTIONS(3683),
    [anon_sym_POUNDEndif] = ACTIONS(3683),
    [anon_sym_POUNDendif2] = ACTIONS(3683),
    [anon_sym_POUNDENDIF2] = ACTIONS(3683),
    [anon_sym_POUNDEndif2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
    [sym_preproc_close] = ACTIONS(3683),
  },
  [STATE(2290)] = {
    [sym_identifier] = ACTIONS(5358),
    [anon_sym_SEMI] = ACTIONS(5360),
    [anon_sym_DASH] = ACTIONS(5360),
    [aux_sym_boolean_token1] = ACTIONS(5358),
    [aux_sym_boolean_token2] = ACTIONS(5358),
    [sym_decimal] = ACTIONS(5358),
    [anon_sym_LPAREN] = ACTIONS(5360),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5358),
    [anon_sym_LBRACK] = ACTIONS(5360),
    [aux_sym_record_type_token1] = ACTIONS(5358),
    [aux_sym_basic_type_token21] = ACTIONS(5358),
    [aux_sym_basic_type_token22] = ACTIONS(5358),
    [aux_sym_basic_type_token48] = ACTIONS(5358),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5358),
    [anon_sym_POUNDif] = ACTIONS(5360),
    [anon_sym_POUNDIF] = ACTIONS(5360),
    [anon_sym_POUNDIf] = ACTIONS(5360),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5362),
    [anon_sym_PIPE_PIPE] = ACTIONS(5364),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5366),
    [anon_sym_AMP_AMP] = ACTIONS(5368),
    [anon_sym_not] = ACTIONS(5358),
    [anon_sym_NOT] = ACTIONS(5358),
    [anon_sym_Not] = ACTIONS(5358),
    [anon_sym_POUNDelif] = ACTIONS(5360),
    [anon_sym_POUNDELIF] = ACTIONS(5360),
    [anon_sym_POUNDElif] = ACTIONS(5360),
    [anon_sym_POUNDelse] = ACTIONS(5360),
    [anon_sym_POUNDELSE] = ACTIONS(5360),
    [anon_sym_POUNDElse] = ACTIONS(5360),
    [anon_sym_POUNDelse2] = ACTIONS(5360),
    [anon_sym_POUNDELSE2] = ACTIONS(5360),
    [anon_sym_POUNDElse2] = ACTIONS(5360),
    [anon_sym_POUNDendif] = ACTIONS(5360),
    [anon_sym_POUNDENDIF] = ACTIONS(5360),
    [anon_sym_POUNDEndif] = ACTIONS(5360),
    [anon_sym_POUNDendif2] = ACTIONS(5360),
    [anon_sym_POUNDENDIF2] = ACTIONS(5360),
    [anon_sym_POUNDEndif2] = ACTIONS(5360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5358),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5358),
    [anon_sym_PLUS] = ACTIONS(5360),
    [sym_datetime_literal] = ACTIONS(5360),
    [sym_date_literal] = ACTIONS(5358),
    [sym_time_literal] = ACTIONS(5358),
    [sym_biginteger_literal] = ACTIONS(5360),
    [anon_sym_if] = ACTIONS(5358),
    [anon_sym_IF] = ACTIONS(5358),
    [anon_sym_If] = ACTIONS(5358),
    [anon_sym_else] = ACTIONS(5358),
    [anon_sym_ELSE] = ACTIONS(5358),
    [anon_sym_Else] = ACTIONS(5358),
    [anon_sym_case] = ACTIONS(5358),
    [anon_sym_CASE] = ACTIONS(5358),
    [anon_sym_Case] = ACTIONS(5358),
    [anon_sym_for] = ACTIONS(5358),
    [anon_sym_FOR] = ACTIONS(5358),
    [anon_sym_For] = ACTIONS(5358),
    [anon_sym_foreach] = ACTIONS(5358),
    [anon_sym_FOREACH] = ACTIONS(5358),
    [anon_sym_Foreach] = ACTIONS(5358),
    [anon_sym_while] = ACTIONS(5358),
    [anon_sym_WHILE] = ACTIONS(5358),
    [anon_sym_While] = ACTIONS(5358),
    [anon_sym_repeat] = ACTIONS(5358),
    [anon_sym_REPEAT] = ACTIONS(5358),
    [anon_sym_Repeat] = ACTIONS(5358),
    [anon_sym_exit] = ACTIONS(5358),
    [anon_sym_EXIT] = ACTIONS(5358),
    [anon_sym_Exit] = ACTIONS(5358),
    [anon_sym_continue] = ACTIONS(5358),
    [anon_sym_CONTINUE] = ACTIONS(5358),
    [anon_sym_Continue] = ACTIONS(5358),
    [anon_sym_break] = ACTIONS(5358),
    [anon_sym_BREAK] = ACTIONS(5358),
    [anon_sym_Break] = ACTIONS(5358),
    [anon_sym_with] = ACTIONS(5358),
    [anon_sym_WITH] = ACTIONS(5358),
    [anon_sym_With] = ACTIONS(5358),
    [sym_asserterror_keyword] = ACTIONS(5360),
    [sym_page_keyword] = ACTIONS(5358),
    [anon_sym_codeunit] = ACTIONS(5358),
    [anon_sym_CODEUNIT] = ACTIONS(5358),
    [anon_sym_Codeunit] = ACTIONS(5358),
    [anon_sym_CodeUnit] = ACTIONS(5358),
    [anon_sym_COdeunit] = ACTIONS(5358),
    [anon_sym_codeUnit] = ACTIONS(5358),
    [sym_report_keyword] = ACTIONS(5358),
    [sym_query_keyword] = ACTIONS(5358),
    [anon_sym_xmlport] = ACTIONS(5358),
    [anon_sym_XMLPORT] = ACTIONS(5358),
    [anon_sym_Xmlport] = ACTIONS(5358),
    [anon_sym_XMLport] = ACTIONS(5358),
    [anon_sym_XMLPort] = ACTIONS(5358),
    [anon_sym_XmlPort] = ACTIONS(5358),
    [anon_sym_enum] = ACTIONS(5358),
    [anon_sym_ENUM] = ACTIONS(5358),
    [anon_sym_Enum] = ACTIONS(5358),
    [anon_sym_eNUM] = ACTIONS(5358),
    [anon_sym_eNum] = ACTIONS(5358),
    [anon_sym_ENum] = ACTIONS(5358),
    [sym_quoted_identifier] = ACTIONS(5360),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5360),
    [sym_verbatim_string] = ACTIONS(5360),
    [sym_integer] = ACTIONS(5358),
    [sym_continue_as_identifier] = ACTIONS(5360),
    [sym_preproc_open] = ACTIONS(5360),
    [sym_preproc_close] = ACTIONS(5360),
  },
  [STATE(2291)] = {
    [sym_identifier] = ACTIONS(5370),
    [anon_sym_SEMI] = ACTIONS(5372),
    [anon_sym_DASH] = ACTIONS(5372),
    [aux_sym_boolean_token1] = ACTIONS(5370),
    [aux_sym_boolean_token2] = ACTIONS(5370),
    [sym_decimal] = ACTIONS(5370),
    [anon_sym_LPAREN] = ACTIONS(5372),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5370),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [aux_sym_record_type_token1] = ACTIONS(5370),
    [aux_sym_basic_type_token21] = ACTIONS(5370),
    [aux_sym_basic_type_token22] = ACTIONS(5370),
    [aux_sym_basic_type_token48] = ACTIONS(5370),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5370),
    [anon_sym_POUNDif] = ACTIONS(5372),
    [anon_sym_POUNDIF] = ACTIONS(5372),
    [anon_sym_POUNDIf] = ACTIONS(5372),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5362),
    [anon_sym_PIPE_PIPE] = ACTIONS(5364),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5366),
    [anon_sym_AMP_AMP] = ACTIONS(5368),
    [anon_sym_not] = ACTIONS(5370),
    [anon_sym_NOT] = ACTIONS(5370),
    [anon_sym_Not] = ACTIONS(5370),
    [anon_sym_POUNDelif] = ACTIONS(5372),
    [anon_sym_POUNDELIF] = ACTIONS(5372),
    [anon_sym_POUNDElif] = ACTIONS(5372),
    [anon_sym_POUNDelse] = ACTIONS(5372),
    [anon_sym_POUNDELSE] = ACTIONS(5372),
    [anon_sym_POUNDElse] = ACTIONS(5372),
    [anon_sym_POUNDelse2] = ACTIONS(5372),
    [anon_sym_POUNDELSE2] = ACTIONS(5372),
    [anon_sym_POUNDElse2] = ACTIONS(5372),
    [anon_sym_POUNDendif] = ACTIONS(5372),
    [anon_sym_POUNDENDIF] = ACTIONS(5372),
    [anon_sym_POUNDEndif] = ACTIONS(5372),
    [anon_sym_POUNDendif2] = ACTIONS(5372),
    [anon_sym_POUNDENDIF2] = ACTIONS(5372),
    [anon_sym_POUNDEndif2] = ACTIONS(5372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5370),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5370),
    [anon_sym_PLUS] = ACTIONS(5372),
    [sym_datetime_literal] = ACTIONS(5372),
    [sym_date_literal] = ACTIONS(5370),
    [sym_time_literal] = ACTIONS(5370),
    [sym_biginteger_literal] = ACTIONS(5372),
    [anon_sym_if] = ACTIONS(5370),
    [anon_sym_IF] = ACTIONS(5370),
    [anon_sym_If] = ACTIONS(5370),
    [anon_sym_else] = ACTIONS(5370),
    [anon_sym_ELSE] = ACTIONS(5370),
    [anon_sym_Else] = ACTIONS(5370),
    [anon_sym_case] = ACTIONS(5370),
    [anon_sym_CASE] = ACTIONS(5370),
    [anon_sym_Case] = ACTIONS(5370),
    [anon_sym_for] = ACTIONS(5370),
    [anon_sym_FOR] = ACTIONS(5370),
    [anon_sym_For] = ACTIONS(5370),
    [anon_sym_foreach] = ACTIONS(5370),
    [anon_sym_FOREACH] = ACTIONS(5370),
    [anon_sym_Foreach] = ACTIONS(5370),
    [anon_sym_while] = ACTIONS(5370),
    [anon_sym_WHILE] = ACTIONS(5370),
    [anon_sym_While] = ACTIONS(5370),
    [anon_sym_repeat] = ACTIONS(5370),
    [anon_sym_REPEAT] = ACTIONS(5370),
    [anon_sym_Repeat] = ACTIONS(5370),
    [anon_sym_exit] = ACTIONS(5370),
    [anon_sym_EXIT] = ACTIONS(5370),
    [anon_sym_Exit] = ACTIONS(5370),
    [anon_sym_continue] = ACTIONS(5370),
    [anon_sym_CONTINUE] = ACTIONS(5370),
    [anon_sym_Continue] = ACTIONS(5370),
    [anon_sym_break] = ACTIONS(5370),
    [anon_sym_BREAK] = ACTIONS(5370),
    [anon_sym_Break] = ACTIONS(5370),
    [anon_sym_with] = ACTIONS(5370),
    [anon_sym_WITH] = ACTIONS(5370),
    [anon_sym_With] = ACTIONS(5370),
    [sym_asserterror_keyword] = ACTIONS(5372),
    [sym_page_keyword] = ACTIONS(5370),
    [anon_sym_codeunit] = ACTIONS(5370),
    [anon_sym_CODEUNIT] = ACTIONS(5370),
    [anon_sym_Codeunit] = ACTIONS(5370),
    [anon_sym_CodeUnit] = ACTIONS(5370),
    [anon_sym_COdeunit] = ACTIONS(5370),
    [anon_sym_codeUnit] = ACTIONS(5370),
    [sym_report_keyword] = ACTIONS(5370),
    [sym_query_keyword] = ACTIONS(5370),
    [anon_sym_xmlport] = ACTIONS(5370),
    [anon_sym_XMLPORT] = ACTIONS(5370),
    [anon_sym_Xmlport] = ACTIONS(5370),
    [anon_sym_XMLport] = ACTIONS(5370),
    [anon_sym_XMLPort] = ACTIONS(5370),
    [anon_sym_XmlPort] = ACTIONS(5370),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_ENUM] = ACTIONS(5370),
    [anon_sym_Enum] = ACTIONS(5370),
    [anon_sym_eNUM] = ACTIONS(5370),
    [anon_sym_eNum] = ACTIONS(5370),
    [anon_sym_ENum] = ACTIONS(5370),
    [sym_quoted_identifier] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5372),
    [sym_verbatim_string] = ACTIONS(5372),
    [sym_integer] = ACTIONS(5370),
    [sym_continue_as_identifier] = ACTIONS(5372),
    [sym_preproc_open] = ACTIONS(5372),
    [sym_preproc_close] = ACTIONS(5372),
  },
  [STATE(2292)] = {
    [sym_identifier] = ACTIONS(5374),
    [anon_sym_SEMI] = ACTIONS(5376),
    [anon_sym_DASH] = ACTIONS(5376),
    [aux_sym_boolean_token1] = ACTIONS(5374),
    [aux_sym_boolean_token2] = ACTIONS(5374),
    [sym_decimal] = ACTIONS(5374),
    [anon_sym_LPAREN] = ACTIONS(5376),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5374),
    [anon_sym_LBRACK] = ACTIONS(5376),
    [aux_sym_record_type_token1] = ACTIONS(5374),
    [aux_sym_basic_type_token21] = ACTIONS(5374),
    [aux_sym_basic_type_token22] = ACTIONS(5374),
    [aux_sym_basic_type_token48] = ACTIONS(5374),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5374),
    [anon_sym_POUNDif] = ACTIONS(5376),
    [anon_sym_POUNDIF] = ACTIONS(5376),
    [anon_sym_POUNDIf] = ACTIONS(5376),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5374),
    [anon_sym_PIPE_PIPE] = ACTIONS(5376),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5374),
    [anon_sym_AMP_AMP] = ACTIONS(5376),
    [anon_sym_not] = ACTIONS(5374),
    [anon_sym_NOT] = ACTIONS(5374),
    [anon_sym_Not] = ACTIONS(5374),
    [anon_sym_POUNDelif] = ACTIONS(5376),
    [anon_sym_POUNDELIF] = ACTIONS(5376),
    [anon_sym_POUNDElif] = ACTIONS(5376),
    [anon_sym_POUNDelse] = ACTIONS(5376),
    [anon_sym_POUNDELSE] = ACTIONS(5376),
    [anon_sym_POUNDElse] = ACTIONS(5376),
    [anon_sym_POUNDelse2] = ACTIONS(5376),
    [anon_sym_POUNDELSE2] = ACTIONS(5376),
    [anon_sym_POUNDElse2] = ACTIONS(5376),
    [anon_sym_POUNDendif] = ACTIONS(5376),
    [anon_sym_POUNDENDIF] = ACTIONS(5376),
    [anon_sym_POUNDEndif] = ACTIONS(5376),
    [anon_sym_POUNDendif2] = ACTIONS(5376),
    [anon_sym_POUNDENDIF2] = ACTIONS(5376),
    [anon_sym_POUNDEndif2] = ACTIONS(5376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5374),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5374),
    [anon_sym_PLUS] = ACTIONS(5376),
    [sym_datetime_literal] = ACTIONS(5376),
    [sym_date_literal] = ACTIONS(5374),
    [sym_time_literal] = ACTIONS(5374),
    [sym_biginteger_literal] = ACTIONS(5376),
    [anon_sym_if] = ACTIONS(5374),
    [anon_sym_IF] = ACTIONS(5374),
    [anon_sym_If] = ACTIONS(5374),
    [anon_sym_else] = ACTIONS(5374),
    [anon_sym_ELSE] = ACTIONS(5374),
    [anon_sym_Else] = ACTIONS(5374),
    [anon_sym_case] = ACTIONS(5374),
    [anon_sym_CASE] = ACTIONS(5374),
    [anon_sym_Case] = ACTIONS(5374),
    [anon_sym_for] = ACTIONS(5374),
    [anon_sym_FOR] = ACTIONS(5374),
    [anon_sym_For] = ACTIONS(5374),
    [anon_sym_foreach] = ACTIONS(5374),
    [anon_sym_FOREACH] = ACTIONS(5374),
    [anon_sym_Foreach] = ACTIONS(5374),
    [anon_sym_while] = ACTIONS(5374),
    [anon_sym_WHILE] = ACTIONS(5374),
    [anon_sym_While] = ACTIONS(5374),
    [anon_sym_repeat] = ACTIONS(5374),
    [anon_sym_REPEAT] = ACTIONS(5374),
    [anon_sym_Repeat] = ACTIONS(5374),
    [anon_sym_exit] = ACTIONS(5374),
    [anon_sym_EXIT] = ACTIONS(5374),
    [anon_sym_Exit] = ACTIONS(5374),
    [anon_sym_continue] = ACTIONS(5374),
    [anon_sym_CONTINUE] = ACTIONS(5374),
    [anon_sym_Continue] = ACTIONS(5374),
    [anon_sym_break] = ACTIONS(5374),
    [anon_sym_BREAK] = ACTIONS(5374),
    [anon_sym_Break] = ACTIONS(5374),
    [anon_sym_with] = ACTIONS(5374),
    [anon_sym_WITH] = ACTIONS(5374),
    [anon_sym_With] = ACTIONS(5374),
    [sym_asserterror_keyword] = ACTIONS(5376),
    [sym_page_keyword] = ACTIONS(5374),
    [anon_sym_codeunit] = ACTIONS(5374),
    [anon_sym_CODEUNIT] = ACTIONS(5374),
    [anon_sym_Codeunit] = ACTIONS(5374),
    [anon_sym_CodeUnit] = ACTIONS(5374),
    [anon_sym_COdeunit] = ACTIONS(5374),
    [anon_sym_codeUnit] = ACTIONS(5374),
    [sym_report_keyword] = ACTIONS(5374),
    [sym_query_keyword] = ACTIONS(5374),
    [anon_sym_xmlport] = ACTIONS(5374),
    [anon_sym_XMLPORT] = ACTIONS(5374),
    [anon_sym_Xmlport] = ACTIONS(5374),
    [anon_sym_XMLport] = ACTIONS(5374),
    [anon_sym_XMLPort] = ACTIONS(5374),
    [anon_sym_XmlPort] = ACTIONS(5374),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_ENUM] = ACTIONS(5374),
    [anon_sym_Enum] = ACTIONS(5374),
    [anon_sym_eNUM] = ACTIONS(5374),
    [anon_sym_eNum] = ACTIONS(5374),
    [anon_sym_ENum] = ACTIONS(5374),
    [sym_quoted_identifier] = ACTIONS(5376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5376),
    [sym_verbatim_string] = ACTIONS(5376),
    [sym_integer] = ACTIONS(5374),
    [sym_continue_as_identifier] = ACTIONS(5376),
    [sym_preproc_open] = ACTIONS(5376),
    [sym_preproc_close] = ACTIONS(5376),
  },
  [STATE(2293)] = {
    [sym_identifier] = ACTIONS(5378),
    [anon_sym_SEMI] = ACTIONS(5380),
    [anon_sym_DASH] = ACTIONS(5380),
    [aux_sym_boolean_token1] = ACTIONS(5378),
    [aux_sym_boolean_token2] = ACTIONS(5378),
    [sym_decimal] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5378),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [aux_sym_record_type_token1] = ACTIONS(5378),
    [aux_sym_basic_type_token21] = ACTIONS(5378),
    [aux_sym_basic_type_token22] = ACTIONS(5378),
    [aux_sym_basic_type_token48] = ACTIONS(5378),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5378),
    [anon_sym_POUNDif] = ACTIONS(5380),
    [anon_sym_POUNDIF] = ACTIONS(5380),
    [anon_sym_POUNDIf] = ACTIONS(5380),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5380),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5366),
    [anon_sym_AMP_AMP] = ACTIONS(5368),
    [anon_sym_not] = ACTIONS(5378),
    [anon_sym_NOT] = ACTIONS(5378),
    [anon_sym_Not] = ACTIONS(5378),
    [anon_sym_POUNDelif] = ACTIONS(5380),
    [anon_sym_POUNDELIF] = ACTIONS(5380),
    [anon_sym_POUNDElif] = ACTIONS(5380),
    [anon_sym_POUNDelse] = ACTIONS(5380),
    [anon_sym_POUNDELSE] = ACTIONS(5380),
    [anon_sym_POUNDElse] = ACTIONS(5380),
    [anon_sym_POUNDelse2] = ACTIONS(5380),
    [anon_sym_POUNDELSE2] = ACTIONS(5380),
    [anon_sym_POUNDElse2] = ACTIONS(5380),
    [anon_sym_POUNDendif] = ACTIONS(5380),
    [anon_sym_POUNDENDIF] = ACTIONS(5380),
    [anon_sym_POUNDEndif] = ACTIONS(5380),
    [anon_sym_POUNDendif2] = ACTIONS(5380),
    [anon_sym_POUNDENDIF2] = ACTIONS(5380),
    [anon_sym_POUNDEndif2] = ACTIONS(5380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [sym_datetime_literal] = ACTIONS(5380),
    [sym_date_literal] = ACTIONS(5378),
    [sym_time_literal] = ACTIONS(5378),
    [sym_biginteger_literal] = ACTIONS(5380),
    [anon_sym_if] = ACTIONS(5378),
    [anon_sym_IF] = ACTIONS(5378),
    [anon_sym_If] = ACTIONS(5378),
    [anon_sym_else] = ACTIONS(5378),
    [anon_sym_ELSE] = ACTIONS(5378),
    [anon_sym_Else] = ACTIONS(5378),
    [anon_sym_case] = ACTIONS(5378),
    [anon_sym_CASE] = ACTIONS(5378),
    [anon_sym_Case] = ACTIONS(5378),
    [anon_sym_for] = ACTIONS(5378),
    [anon_sym_FOR] = ACTIONS(5378),
    [anon_sym_For] = ACTIONS(5378),
    [anon_sym_foreach] = ACTIONS(5378),
    [anon_sym_FOREACH] = ACTIONS(5378),
    [anon_sym_Foreach] = ACTIONS(5378),
    [anon_sym_while] = ACTIONS(5378),
    [anon_sym_WHILE] = ACTIONS(5378),
    [anon_sym_While] = ACTIONS(5378),
    [anon_sym_repeat] = ACTIONS(5378),
    [anon_sym_REPEAT] = ACTIONS(5378),
    [anon_sym_Repeat] = ACTIONS(5378),
    [anon_sym_exit] = ACTIONS(5378),
    [anon_sym_EXIT] = ACTIONS(5378),
    [anon_sym_Exit] = ACTIONS(5378),
    [anon_sym_continue] = ACTIONS(5378),
    [anon_sym_CONTINUE] = ACTIONS(5378),
    [anon_sym_Continue] = ACTIONS(5378),
    [anon_sym_break] = ACTIONS(5378),
    [anon_sym_BREAK] = ACTIONS(5378),
    [anon_sym_Break] = ACTIONS(5378),
    [anon_sym_with] = ACTIONS(5378),
    [anon_sym_WITH] = ACTIONS(5378),
    [anon_sym_With] = ACTIONS(5378),
    [sym_asserterror_keyword] = ACTIONS(5380),
    [sym_page_keyword] = ACTIONS(5378),
    [anon_sym_codeunit] = ACTIONS(5378),
    [anon_sym_CODEUNIT] = ACTIONS(5378),
    [anon_sym_Codeunit] = ACTIONS(5378),
    [anon_sym_CodeUnit] = ACTIONS(5378),
    [anon_sym_COdeunit] = ACTIONS(5378),
    [anon_sym_codeUnit] = ACTIONS(5378),
    [sym_report_keyword] = ACTIONS(5378),
    [sym_query_keyword] = ACTIONS(5378),
    [anon_sym_xmlport] = ACTIONS(5378),
    [anon_sym_XMLPORT] = ACTIONS(5378),
    [anon_sym_Xmlport] = ACTIONS(5378),
    [anon_sym_XMLport] = ACTIONS(5378),
    [anon_sym_XMLPort] = ACTIONS(5378),
    [anon_sym_XmlPort] = ACTIONS(5378),
    [anon_sym_enum] = ACTIONS(5378),
    [anon_sym_ENUM] = ACTIONS(5378),
    [anon_sym_Enum] = ACTIONS(5378),
    [anon_sym_eNUM] = ACTIONS(5378),
    [anon_sym_eNum] = ACTIONS(5378),
    [anon_sym_ENum] = ACTIONS(5378),
    [sym_quoted_identifier] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5380),
    [sym_verbatim_string] = ACTIONS(5380),
    [sym_integer] = ACTIONS(5378),
    [sym_continue_as_identifier] = ACTIONS(5380),
    [sym_preproc_open] = ACTIONS(5380),
    [sym_preproc_close] = ACTIONS(5380),
  },
  [STATE(2294)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2295)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2304),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(3689),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelif] = ACTIONS(3691),
    [anon_sym_POUNDELIF] = ACTIONS(3691),
    [anon_sym_POUNDElif] = ACTIONS(3691),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [anon_sym_POUNDendif] = ACTIONS(3691),
    [anon_sym_POUNDENDIF] = ACTIONS(3691),
    [anon_sym_POUNDEndif] = ACTIONS(3691),
    [anon_sym_POUNDendif2] = ACTIONS(3691),
    [anon_sym_POUNDENDIF2] = ACTIONS(3691),
    [anon_sym_POUNDEndif2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3691),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
    [sym_preproc_close] = ACTIONS(3691),
  },
  [STATE(2296)] = {
    [sym_identifier] = ACTIONS(3768),
    [anon_sym_SEMI] = ACTIONS(3770),
    [anon_sym_DOT] = ACTIONS(3768),
    [anon_sym_EQ] = ACTIONS(3770),
    [anon_sym_COMMA] = ACTIONS(3770),
    [anon_sym_COLON] = ACTIONS(3768),
    [anon_sym_DASH] = ACTIONS(3768),
    [aux_sym_boolean_token1] = ACTIONS(3768),
    [aux_sym_boolean_token2] = ACTIONS(3768),
    [sym_decimal] = ACTIONS(3768),
    [anon_sym_LPAREN] = ACTIONS(3770),
    [anon_sym_DOT_DOT] = ACTIONS(3770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3768),
    [anon_sym_STAR] = ACTIONS(3768),
    [anon_sym_LBRACK] = ACTIONS(3770),
    [aux_sym_record_type_token1] = ACTIONS(3768),
    [aux_sym_basic_type_token21] = ACTIONS(3768),
    [aux_sym_basic_type_token22] = ACTIONS(3768),
    [aux_sym_basic_type_token48] = ACTIONS(3768),
    [anon_sym_COLON_COLON] = ACTIONS(3770),
    [anon_sym_POUNDif] = ACTIONS(3770),
    [anon_sym_POUNDIF] = ACTIONS(3770),
    [anon_sym_POUNDIf] = ACTIONS(3770),
    [anon_sym_not] = ACTIONS(3768),
    [anon_sym_NOT] = ACTIONS(3768),
    [anon_sym_Not] = ACTIONS(3768),
    [anon_sym_POUNDelif] = ACTIONS(3770),
    [anon_sym_POUNDELIF] = ACTIONS(3770),
    [anon_sym_POUNDElif] = ACTIONS(3770),
    [anon_sym_POUNDelse] = ACTIONS(3770),
    [anon_sym_POUNDELSE] = ACTIONS(3770),
    [anon_sym_POUNDElse] = ACTIONS(3770),
    [anon_sym_POUNDelse2] = ACTIONS(3770),
    [anon_sym_POUNDELSE2] = ACTIONS(3770),
    [anon_sym_POUNDElse2] = ACTIONS(3770),
    [anon_sym_POUNDendif] = ACTIONS(3770),
    [anon_sym_POUNDENDIF] = ACTIONS(3770),
    [anon_sym_POUNDEndif] = ACTIONS(3770),
    [anon_sym_POUNDendif2] = ACTIONS(3770),
    [anon_sym_POUNDENDIF2] = ACTIONS(3770),
    [anon_sym_POUNDEndif2] = ACTIONS(3770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3770),
    [aux_sym__expression_token1] = ACTIONS(3770),
    [aux_sym__expression_token2] = ACTIONS(3770),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3768),
    [anon_sym_SLASH] = ACTIONS(3768),
    [anon_sym_div] = ACTIONS(3768),
    [anon_sym_DIV] = ACTIONS(3768),
    [anon_sym_Div] = ACTIONS(3768),
    [anon_sym_mod] = ACTIONS(3768),
    [anon_sym_MOD] = ACTIONS(3768),
    [anon_sym_Mod] = ACTIONS(3768),
    [anon_sym_PLUS] = ACTIONS(3768),
    [anon_sym_GT_EQ] = ACTIONS(3770),
    [anon_sym_LT_EQ] = ACTIONS(3770),
    [anon_sym_GT] = ACTIONS(3768),
    [anon_sym_LT] = ACTIONS(3768),
    [anon_sym_LT_GT] = ACTIONS(3770),
    [anon_sym_and] = ACTIONS(3768),
    [anon_sym_AND] = ACTIONS(3768),
    [anon_sym_And] = ACTIONS(3768),
    [anon_sym_or] = ACTIONS(3768),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3768),
    [anon_sym_xor] = ACTIONS(3768),
    [anon_sym_XOR] = ACTIONS(3768),
    [anon_sym_Xor] = ACTIONS(3768),
    [anon_sym_QMARK] = ACTIONS(3770),
    [sym_datetime_literal] = ACTIONS(3770),
    [sym_date_literal] = ACTIONS(3768),
    [sym_time_literal] = ACTIONS(3768),
    [sym_biginteger_literal] = ACTIONS(3770),
    [anon_sym_else] = ACTIONS(3768),
    [anon_sym_ELSE] = ACTIONS(3768),
    [anon_sym_Else] = ACTIONS(3768),
    [anon_sym_in] = ACTIONS(3768),
    [anon_sym_IN] = ACTIONS(3768),
    [anon_sym_In] = ACTIONS(3768),
    [sym_page_keyword] = ACTIONS(3768),
    [anon_sym_codeunit] = ACTIONS(3768),
    [anon_sym_CODEUNIT] = ACTIONS(3768),
    [anon_sym_Codeunit] = ACTIONS(3768),
    [anon_sym_CodeUnit] = ACTIONS(3768),
    [anon_sym_COdeunit] = ACTIONS(3768),
    [anon_sym_codeUnit] = ACTIONS(3768),
    [sym_report_keyword] = ACTIONS(3768),
    [sym_query_keyword] = ACTIONS(3768),
    [anon_sym_xmlport] = ACTIONS(3768),
    [anon_sym_XMLPORT] = ACTIONS(3768),
    [anon_sym_Xmlport] = ACTIONS(3768),
    [anon_sym_XMLport] = ACTIONS(3768),
    [anon_sym_XMLPort] = ACTIONS(3768),
    [anon_sym_XmlPort] = ACTIONS(3768),
    [anon_sym_enum] = ACTIONS(3768),
    [anon_sym_ENUM] = ACTIONS(3768),
    [anon_sym_Enum] = ACTIONS(3768),
    [anon_sym_eNUM] = ACTIONS(3768),
    [anon_sym_eNum] = ACTIONS(3768),
    [anon_sym_ENum] = ACTIONS(3768),
    [sym_quoted_identifier] = ACTIONS(3770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3770),
    [sym_verbatim_string] = ACTIONS(3770),
    [sym_integer] = ACTIONS(3768),
    [sym_continue_as_identifier] = ACTIONS(3770),
    [sym_preproc_open] = ACTIONS(3770),
    [sym_preproc_close] = ACTIONS(3770),
  },
  [STATE(2297)] = {
    [sym_identifier] = ACTIONS(3772),
    [anon_sym_SEMI] = ACTIONS(3774),
    [anon_sym_DOT] = ACTIONS(3772),
    [anon_sym_EQ] = ACTIONS(3774),
    [anon_sym_COMMA] = ACTIONS(3774),
    [anon_sym_COLON] = ACTIONS(3772),
    [anon_sym_DASH] = ACTIONS(3772),
    [aux_sym_boolean_token1] = ACTIONS(3772),
    [aux_sym_boolean_token2] = ACTIONS(3772),
    [sym_decimal] = ACTIONS(3772),
    [anon_sym_LPAREN] = ACTIONS(3774),
    [anon_sym_DOT_DOT] = ACTIONS(3774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(3772),
    [anon_sym_LBRACK] = ACTIONS(3774),
    [aux_sym_record_type_token1] = ACTIONS(3772),
    [aux_sym_basic_type_token21] = ACTIONS(3772),
    [aux_sym_basic_type_token22] = ACTIONS(3772),
    [aux_sym_basic_type_token48] = ACTIONS(3772),
    [anon_sym_COLON_COLON] = ACTIONS(3774),
    [anon_sym_POUNDif] = ACTIONS(3774),
    [anon_sym_POUNDIF] = ACTIONS(3774),
    [anon_sym_POUNDIf] = ACTIONS(3774),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_NOT] = ACTIONS(3772),
    [anon_sym_Not] = ACTIONS(3772),
    [anon_sym_POUNDelif] = ACTIONS(3774),
    [anon_sym_POUNDELIF] = ACTIONS(3774),
    [anon_sym_POUNDElif] = ACTIONS(3774),
    [anon_sym_POUNDelse] = ACTIONS(3774),
    [anon_sym_POUNDELSE] = ACTIONS(3774),
    [anon_sym_POUNDElse] = ACTIONS(3774),
    [anon_sym_POUNDelse2] = ACTIONS(3774),
    [anon_sym_POUNDELSE2] = ACTIONS(3774),
    [anon_sym_POUNDElse2] = ACTIONS(3774),
    [anon_sym_POUNDendif] = ACTIONS(3774),
    [anon_sym_POUNDENDIF] = ACTIONS(3774),
    [anon_sym_POUNDEndif] = ACTIONS(3774),
    [anon_sym_POUNDendif2] = ACTIONS(3774),
    [anon_sym_POUNDENDIF2] = ACTIONS(3774),
    [anon_sym_POUNDEndif2] = ACTIONS(3774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3774),
    [aux_sym__expression_token1] = ACTIONS(3774),
    [aux_sym__expression_token2] = ACTIONS(3774),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3772),
    [anon_sym_SLASH] = ACTIONS(3772),
    [anon_sym_div] = ACTIONS(3772),
    [anon_sym_DIV] = ACTIONS(3772),
    [anon_sym_Div] = ACTIONS(3772),
    [anon_sym_mod] = ACTIONS(3772),
    [anon_sym_MOD] = ACTIONS(3772),
    [anon_sym_Mod] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_GT_EQ] = ACTIONS(3774),
    [anon_sym_LT_EQ] = ACTIONS(3774),
    [anon_sym_GT] = ACTIONS(3772),
    [anon_sym_LT] = ACTIONS(3772),
    [anon_sym_LT_GT] = ACTIONS(3774),
    [anon_sym_and] = ACTIONS(3772),
    [anon_sym_AND] = ACTIONS(3772),
    [anon_sym_And] = ACTIONS(3772),
    [anon_sym_or] = ACTIONS(3772),
    [anon_sym_OR] = ACTIONS(3772),
    [anon_sym_Or] = ACTIONS(3772),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3772),
    [anon_sym_Xor] = ACTIONS(3772),
    [anon_sym_QMARK] = ACTIONS(3774),
    [sym_datetime_literal] = ACTIONS(3774),
    [sym_date_literal] = ACTIONS(3772),
    [sym_time_literal] = ACTIONS(3772),
    [sym_biginteger_literal] = ACTIONS(3774),
    [anon_sym_else] = ACTIONS(3772),
    [anon_sym_ELSE] = ACTIONS(3772),
    [anon_sym_Else] = ACTIONS(3772),
    [anon_sym_in] = ACTIONS(3772),
    [anon_sym_IN] = ACTIONS(3772),
    [anon_sym_In] = ACTIONS(3772),
    [sym_page_keyword] = ACTIONS(3772),
    [anon_sym_codeunit] = ACTIONS(3772),
    [anon_sym_CODEUNIT] = ACTIONS(3772),
    [anon_sym_Codeunit] = ACTIONS(3772),
    [anon_sym_CodeUnit] = ACTIONS(3772),
    [anon_sym_COdeunit] = ACTIONS(3772),
    [anon_sym_codeUnit] = ACTIONS(3772),
    [sym_report_keyword] = ACTIONS(3772),
    [sym_query_keyword] = ACTIONS(3772),
    [anon_sym_xmlport] = ACTIONS(3772),
    [anon_sym_XMLPORT] = ACTIONS(3772),
    [anon_sym_Xmlport] = ACTIONS(3772),
    [anon_sym_XMLport] = ACTIONS(3772),
    [anon_sym_XMLPort] = ACTIONS(3772),
    [anon_sym_XmlPort] = ACTIONS(3772),
    [anon_sym_enum] = ACTIONS(3772),
    [anon_sym_ENUM] = ACTIONS(3772),
    [anon_sym_Enum] = ACTIONS(3772),
    [anon_sym_eNUM] = ACTIONS(3772),
    [anon_sym_eNum] = ACTIONS(3772),
    [anon_sym_ENum] = ACTIONS(3772),
    [sym_quoted_identifier] = ACTIONS(3774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3774),
    [sym_verbatim_string] = ACTIONS(3774),
    [sym_integer] = ACTIONS(3772),
    [sym_continue_as_identifier] = ACTIONS(3774),
    [sym_preproc_open] = ACTIONS(3774),
    [sym_preproc_close] = ACTIONS(3774),
  },
  [STATE(2298)] = {
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(3703),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_COMMA] = ACTIONS(3705),
    [anon_sym_COLON] = ACTIONS(3703),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelif] = ACTIONS(3705),
    [anon_sym_POUNDELIF] = ACTIONS(3705),
    [anon_sym_POUNDElif] = ACTIONS(3705),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [anon_sym_POUNDendif] = ACTIONS(3705),
    [anon_sym_POUNDENDIF] = ACTIONS(3705),
    [anon_sym_POUNDEndif] = ACTIONS(3705),
    [anon_sym_POUNDendif2] = ACTIONS(3705),
    [anon_sym_POUNDENDIF2] = ACTIONS(3705),
    [anon_sym_POUNDEndif2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3705),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
    [sym_preproc_close] = ACTIONS(3705),
  },
  [STATE(2299)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_COLON] = ACTIONS(3663),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(5384),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(2300)] = {
    [sym_identifier] = ACTIONS(3776),
    [anon_sym_SEMI] = ACTIONS(3778),
    [anon_sym_DOT] = ACTIONS(3776),
    [anon_sym_EQ] = ACTIONS(3778),
    [anon_sym_COMMA] = ACTIONS(3778),
    [anon_sym_COLON] = ACTIONS(3776),
    [anon_sym_DASH] = ACTIONS(3776),
    [aux_sym_boolean_token1] = ACTIONS(3776),
    [aux_sym_boolean_token2] = ACTIONS(3776),
    [sym_decimal] = ACTIONS(3776),
    [anon_sym_LPAREN] = ACTIONS(3778),
    [anon_sym_DOT_DOT] = ACTIONS(3778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3776),
    [anon_sym_STAR] = ACTIONS(3776),
    [anon_sym_LBRACK] = ACTIONS(3778),
    [aux_sym_record_type_token1] = ACTIONS(3776),
    [aux_sym_basic_type_token21] = ACTIONS(3776),
    [aux_sym_basic_type_token22] = ACTIONS(3776),
    [aux_sym_basic_type_token48] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_POUNDif] = ACTIONS(3778),
    [anon_sym_POUNDIF] = ACTIONS(3778),
    [anon_sym_POUNDIf] = ACTIONS(3778),
    [anon_sym_not] = ACTIONS(3776),
    [anon_sym_NOT] = ACTIONS(3776),
    [anon_sym_Not] = ACTIONS(3776),
    [anon_sym_POUNDelif] = ACTIONS(3778),
    [anon_sym_POUNDELIF] = ACTIONS(3778),
    [anon_sym_POUNDElif] = ACTIONS(3778),
    [anon_sym_POUNDelse] = ACTIONS(3778),
    [anon_sym_POUNDELSE] = ACTIONS(3778),
    [anon_sym_POUNDElse] = ACTIONS(3778),
    [anon_sym_POUNDelse2] = ACTIONS(3778),
    [anon_sym_POUNDELSE2] = ACTIONS(3778),
    [anon_sym_POUNDElse2] = ACTIONS(3778),
    [anon_sym_POUNDendif] = ACTIONS(3778),
    [anon_sym_POUNDENDIF] = ACTIONS(3778),
    [anon_sym_POUNDEndif] = ACTIONS(3778),
    [anon_sym_POUNDendif2] = ACTIONS(3778),
    [anon_sym_POUNDENDIF2] = ACTIONS(3778),
    [anon_sym_POUNDEndif2] = ACTIONS(3778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3778),
    [aux_sym__expression_token1] = ACTIONS(3778),
    [aux_sym__expression_token2] = ACTIONS(3778),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3776),
    [anon_sym_SLASH] = ACTIONS(3776),
    [anon_sym_div] = ACTIONS(3776),
    [anon_sym_DIV] = ACTIONS(3776),
    [anon_sym_Div] = ACTIONS(3776),
    [anon_sym_mod] = ACTIONS(3776),
    [anon_sym_MOD] = ACTIONS(3776),
    [anon_sym_Mod] = ACTIONS(3776),
    [anon_sym_PLUS] = ACTIONS(3776),
    [anon_sym_GT_EQ] = ACTIONS(3778),
    [anon_sym_LT_EQ] = ACTIONS(3778),
    [anon_sym_GT] = ACTIONS(3776),
    [anon_sym_LT] = ACTIONS(3776),
    [anon_sym_LT_GT] = ACTIONS(3778),
    [anon_sym_and] = ACTIONS(3776),
    [anon_sym_AND] = ACTIONS(3776),
    [anon_sym_And] = ACTIONS(3776),
    [anon_sym_or] = ACTIONS(3776),
    [anon_sym_OR] = ACTIONS(3776),
    [anon_sym_Or] = ACTIONS(3776),
    [anon_sym_xor] = ACTIONS(3776),
    [anon_sym_XOR] = ACTIONS(3776),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(3778),
    [sym_date_literal] = ACTIONS(3776),
    [sym_time_literal] = ACTIONS(3776),
    [sym_biginteger_literal] = ACTIONS(3778),
    [anon_sym_else] = ACTIONS(3776),
    [anon_sym_ELSE] = ACTIONS(3776),
    [anon_sym_Else] = ACTIONS(3776),
    [anon_sym_in] = ACTIONS(3776),
    [anon_sym_IN] = ACTIONS(3776),
    [anon_sym_In] = ACTIONS(3776),
    [sym_page_keyword] = ACTIONS(3776),
    [anon_sym_codeunit] = ACTIONS(3776),
    [anon_sym_CODEUNIT] = ACTIONS(3776),
    [anon_sym_Codeunit] = ACTIONS(3776),
    [anon_sym_CodeUnit] = ACTIONS(3776),
    [anon_sym_COdeunit] = ACTIONS(3776),
    [anon_sym_codeUnit] = ACTIONS(3776),
    [sym_report_keyword] = ACTIONS(3776),
    [sym_query_keyword] = ACTIONS(3776),
    [anon_sym_xmlport] = ACTIONS(3776),
    [anon_sym_XMLPORT] = ACTIONS(3776),
    [anon_sym_Xmlport] = ACTIONS(3776),
    [anon_sym_XMLport] = ACTIONS(3776),
    [anon_sym_XMLPort] = ACTIONS(3776),
    [anon_sym_XmlPort] = ACTIONS(3776),
    [anon_sym_enum] = ACTIONS(3776),
    [anon_sym_ENUM] = ACTIONS(3776),
    [anon_sym_Enum] = ACTIONS(3776),
    [anon_sym_eNUM] = ACTIONS(3776),
    [anon_sym_eNum] = ACTIONS(3776),
    [anon_sym_ENum] = ACTIONS(3776),
    [sym_quoted_identifier] = ACTIONS(3778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3778),
    [sym_verbatim_string] = ACTIONS(3778),
    [sym_integer] = ACTIONS(3776),
    [sym_continue_as_identifier] = ACTIONS(3778),
    [sym_preproc_open] = ACTIONS(3778),
    [sym_preproc_close] = ACTIONS(3778),
  },
  [STATE(2301)] = {
    [sym_identifier] = ACTIONS(3760),
    [anon_sym_SEMI] = ACTIONS(3762),
    [anon_sym_DOT] = ACTIONS(3760),
    [anon_sym_EQ] = ACTIONS(3762),
    [anon_sym_COMMA] = ACTIONS(3762),
    [anon_sym_COLON] = ACTIONS(3760),
    [anon_sym_DASH] = ACTIONS(3760),
    [aux_sym_boolean_token1] = ACTIONS(3760),
    [aux_sym_boolean_token2] = ACTIONS(3760),
    [sym_decimal] = ACTIONS(3760),
    [anon_sym_LPAREN] = ACTIONS(3762),
    [anon_sym_DOT_DOT] = ACTIONS(3762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3760),
    [anon_sym_STAR] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3762),
    [aux_sym_record_type_token1] = ACTIONS(3760),
    [aux_sym_basic_type_token21] = ACTIONS(3760),
    [aux_sym_basic_type_token22] = ACTIONS(3760),
    [aux_sym_basic_type_token48] = ACTIONS(3760),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(3762),
    [anon_sym_POUNDIF] = ACTIONS(3762),
    [anon_sym_POUNDIf] = ACTIONS(3762),
    [anon_sym_not] = ACTIONS(3760),
    [anon_sym_NOT] = ACTIONS(3760),
    [anon_sym_Not] = ACTIONS(3760),
    [anon_sym_POUNDelif] = ACTIONS(3762),
    [anon_sym_POUNDELIF] = ACTIONS(3762),
    [anon_sym_POUNDElif] = ACTIONS(3762),
    [anon_sym_POUNDelse] = ACTIONS(3762),
    [anon_sym_POUNDELSE] = ACTIONS(3762),
    [anon_sym_POUNDElse] = ACTIONS(3762),
    [anon_sym_POUNDelse2] = ACTIONS(3762),
    [anon_sym_POUNDELSE2] = ACTIONS(3762),
    [anon_sym_POUNDElse2] = ACTIONS(3762),
    [anon_sym_POUNDendif] = ACTIONS(3762),
    [anon_sym_POUNDENDIF] = ACTIONS(3762),
    [anon_sym_POUNDEndif] = ACTIONS(3762),
    [anon_sym_POUNDendif2] = ACTIONS(3762),
    [anon_sym_POUNDENDIF2] = ACTIONS(3762),
    [anon_sym_POUNDEndif2] = ACTIONS(3762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3762),
    [aux_sym__expression_token1] = ACTIONS(3762),
    [aux_sym__expression_token2] = ACTIONS(3762),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3760),
    [anon_sym_SLASH] = ACTIONS(3760),
    [anon_sym_div] = ACTIONS(3760),
    [anon_sym_DIV] = ACTIONS(3760),
    [anon_sym_Div] = ACTIONS(3760),
    [anon_sym_mod] = ACTIONS(3760),
    [anon_sym_MOD] = ACTIONS(3760),
    [anon_sym_Mod] = ACTIONS(3760),
    [anon_sym_PLUS] = ACTIONS(3760),
    [anon_sym_GT_EQ] = ACTIONS(3762),
    [anon_sym_LT_EQ] = ACTIONS(3762),
    [anon_sym_GT] = ACTIONS(3760),
    [anon_sym_LT] = ACTIONS(3760),
    [anon_sym_LT_GT] = ACTIONS(3762),
    [anon_sym_and] = ACTIONS(3760),
    [anon_sym_AND] = ACTIONS(3760),
    [anon_sym_And] = ACTIONS(3760),
    [anon_sym_or] = ACTIONS(3760),
    [anon_sym_OR] = ACTIONS(3760),
    [anon_sym_Or] = ACTIONS(3760),
    [anon_sym_xor] = ACTIONS(3760),
    [anon_sym_XOR] = ACTIONS(3760),
    [anon_sym_Xor] = ACTIONS(3760),
    [anon_sym_QMARK] = ACTIONS(3762),
    [sym_datetime_literal] = ACTIONS(3762),
    [sym_date_literal] = ACTIONS(3760),
    [sym_time_literal] = ACTIONS(3760),
    [sym_biginteger_literal] = ACTIONS(3762),
    [anon_sym_else] = ACTIONS(3760),
    [anon_sym_ELSE] = ACTIONS(3760),
    [anon_sym_Else] = ACTIONS(3760),
    [anon_sym_in] = ACTIONS(3760),
    [anon_sym_IN] = ACTIONS(3760),
    [anon_sym_In] = ACTIONS(3760),
    [sym_page_keyword] = ACTIONS(3760),
    [anon_sym_codeunit] = ACTIONS(3760),
    [anon_sym_CODEUNIT] = ACTIONS(3760),
    [anon_sym_Codeunit] = ACTIONS(3760),
    [anon_sym_CodeUnit] = ACTIONS(3760),
    [anon_sym_COdeunit] = ACTIONS(3760),
    [anon_sym_codeUnit] = ACTIONS(3760),
    [sym_report_keyword] = ACTIONS(3760),
    [sym_query_keyword] = ACTIONS(3760),
    [anon_sym_xmlport] = ACTIONS(3760),
    [anon_sym_XMLPORT] = ACTIONS(3760),
    [anon_sym_Xmlport] = ACTIONS(3760),
    [anon_sym_XMLport] = ACTIONS(3760),
    [anon_sym_XMLPort] = ACTIONS(3760),
    [anon_sym_XmlPort] = ACTIONS(3760),
    [anon_sym_enum] = ACTIONS(3760),
    [anon_sym_ENUM] = ACTIONS(3760),
    [anon_sym_Enum] = ACTIONS(3760),
    [anon_sym_eNUM] = ACTIONS(3760),
    [anon_sym_eNum] = ACTIONS(3760),
    [anon_sym_ENum] = ACTIONS(3760),
    [sym_quoted_identifier] = ACTIONS(3762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3762),
    [sym_verbatim_string] = ACTIONS(3762),
    [sym_integer] = ACTIONS(3760),
    [sym_continue_as_identifier] = ACTIONS(3762),
    [sym_preproc_open] = ACTIONS(3762),
    [sym_preproc_close] = ACTIONS(3762),
  },
  [STATE(2302)] = {
    [sym_where_clause] = STATE(4933),
    [sym_argument_list] = STATE(7165),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(5390),
    [aux_sym_where_condition_token1] = ACTIONS(5392),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5386),
    [anon_sym_STAR] = ACTIONS(3681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5386),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5386),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [aux_sym_basic_type_token6] = ACTIONS(5392),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5386),
    [aux_sym_addafter_modification_token1] = ACTIONS(5386),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5386),
    [aux_sym_modify_modification_token1] = ACTIONS(5386),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5386),
    [aux_sym_movelast_modification_token1] = ACTIONS(5386),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5386),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5386),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5392),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5386),
    [anon_sym_POUNDIF] = ACTIONS(5386),
    [anon_sym_POUNDIf] = ACTIONS(5386),
    [anon_sym_POUNDelif] = ACTIONS(5386),
    [anon_sym_POUNDELIF] = ACTIONS(5386),
    [anon_sym_POUNDElif] = ACTIONS(5386),
    [anon_sym_POUNDelse] = ACTIONS(5386),
    [anon_sym_POUNDELSE] = ACTIONS(5386),
    [anon_sym_POUNDElse] = ACTIONS(5386),
    [anon_sym_POUNDelse2] = ACTIONS(5386),
    [anon_sym_POUNDELSE2] = ACTIONS(5386),
    [anon_sym_POUNDElse2] = ACTIONS(5386),
    [anon_sym_POUNDendif] = ACTIONS(5386),
    [anon_sym_POUNDENDIF] = ACTIONS(5386),
    [anon_sym_POUNDEndif] = ACTIONS(5386),
    [anon_sym_POUNDendif2] = ACTIONS(5386),
    [anon_sym_POUNDENDIF2] = ACTIONS(5386),
    [anon_sym_POUNDEndif2] = ACTIONS(5386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5386),
    [sym_trigger_keyword] = ACTIONS(5386),
    [sym_var_keyword] = ACTIONS(5386),
    [sym_local_keyword] = ACTIONS(5386),
    [sym_internal_keyword] = ACTIONS(5386),
    [sym_protected_keyword] = ACTIONS(5386),
    [sym_event_keyword] = ACTIONS(5386),
    [sym_fields_keyword] = ACTIONS(5386),
    [sym_keys_keyword] = ACTIONS(5386),
    [sym_fieldgroups_keyword] = ACTIONS(5386),
    [sym_actions_keyword] = ACTIONS(5386),
    [sym_layout_keyword] = ACTIONS(5386),
    [sym_area_keyword] = ACTIONS(5386),
    [sym_group_keyword] = ACTIONS(5386),
    [sym_repeater_keyword] = ACTIONS(5386),
    [sym_cuegroup_keyword] = ACTIONS(5386),
    [sym_fixed_keyword] = ACTIONS(5386),
    [sym_grid_keyword] = ACTIONS(5386),
    [sym_part_keyword] = ACTIONS(5386),
    [sym_systempart_keyword] = ACTIONS(5386),
    [sym_usercontrol_keyword] = ACTIONS(5386),
    [sym_dataset_keyword] = ACTIONS(5386),
    [sym_elements_keyword] = ACTIONS(5386),
    [sym_dataitem_keyword] = ACTIONS(5386),
    [sym_column_keyword] = ACTIONS(5386),
    [sym_filter_keyword] = ACTIONS(5386),
    [sym_labels_keyword] = ACTIONS(5386),
    [sym_rendering_keyword] = ACTIONS(5386),
    [sym_requestpage_keyword] = ACTIONS(5386),
    [sym_schema_keyword] = ACTIONS(5386),
    [sym_views_keyword] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5386),
    [sym_preproc_open] = ACTIONS(5386),
    [sym_preproc_close] = ACTIONS(5386),
  },
  [STATE(2303)] = {
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(3683),
    [anon_sym_COLON] = ACTIONS(3681),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(5356),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelif] = ACTIONS(3683),
    [anon_sym_POUNDELIF] = ACTIONS(3683),
    [anon_sym_POUNDElif] = ACTIONS(3683),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [anon_sym_POUNDendif] = ACTIONS(3683),
    [anon_sym_POUNDENDIF] = ACTIONS(3683),
    [anon_sym_POUNDEndif] = ACTIONS(3683),
    [anon_sym_POUNDendif2] = ACTIONS(3683),
    [anon_sym_POUNDENDIF2] = ACTIONS(3683),
    [anon_sym_POUNDEndif2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
    [sym_preproc_close] = ACTIONS(3683),
  },
  [STATE(2304)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2304),
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(5396),
    [anon_sym_COLON] = ACTIONS(3632),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelif] = ACTIONS(3634),
    [anon_sym_POUNDELIF] = ACTIONS(3634),
    [anon_sym_POUNDElif] = ACTIONS(3634),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [anon_sym_POUNDendif] = ACTIONS(3634),
    [anon_sym_POUNDENDIF] = ACTIONS(3634),
    [anon_sym_POUNDEndif] = ACTIONS(3634),
    [anon_sym_POUNDendif2] = ACTIONS(3634),
    [anon_sym_POUNDENDIF2] = ACTIONS(3634),
    [anon_sym_POUNDEndif2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3634),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
    [sym_preproc_close] = ACTIONS(3634),
  },
  [STATE(2305)] = {
    [sym_identifier] = ACTIONS(3651),
    [anon_sym_SEMI] = ACTIONS(3653),
    [anon_sym_DOT] = ACTIONS(3651),
    [anon_sym_EQ] = ACTIONS(3653),
    [anon_sym_COMMA] = ACTIONS(3653),
    [anon_sym_COLON] = ACTIONS(3651),
    [anon_sym_DASH] = ACTIONS(3651),
    [aux_sym_boolean_token1] = ACTIONS(3651),
    [aux_sym_boolean_token2] = ACTIONS(3651),
    [sym_decimal] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3653),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3651),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_LBRACK] = ACTIONS(3653),
    [aux_sym_record_type_token1] = ACTIONS(3651),
    [aux_sym_basic_type_token21] = ACTIONS(3651),
    [aux_sym_basic_type_token22] = ACTIONS(3651),
    [aux_sym_basic_type_token48] = ACTIONS(3651),
    [anon_sym_COLON_COLON] = ACTIONS(3653),
    [anon_sym_POUNDif] = ACTIONS(3653),
    [anon_sym_POUNDIF] = ACTIONS(3653),
    [anon_sym_POUNDIf] = ACTIONS(3653),
    [anon_sym_not] = ACTIONS(3651),
    [anon_sym_NOT] = ACTIONS(3651),
    [anon_sym_Not] = ACTIONS(3651),
    [anon_sym_POUNDelif] = ACTIONS(3653),
    [anon_sym_POUNDELIF] = ACTIONS(3653),
    [anon_sym_POUNDElif] = ACTIONS(3653),
    [anon_sym_POUNDelse] = ACTIONS(3653),
    [anon_sym_POUNDELSE] = ACTIONS(3653),
    [anon_sym_POUNDElse] = ACTIONS(3653),
    [anon_sym_POUNDelse2] = ACTIONS(3653),
    [anon_sym_POUNDELSE2] = ACTIONS(3653),
    [anon_sym_POUNDElse2] = ACTIONS(3653),
    [anon_sym_POUNDendif] = ACTIONS(3653),
    [anon_sym_POUNDENDIF] = ACTIONS(3653),
    [anon_sym_POUNDEndif] = ACTIONS(3653),
    [anon_sym_POUNDendif2] = ACTIONS(3653),
    [anon_sym_POUNDENDIF2] = ACTIONS(3653),
    [anon_sym_POUNDEndif2] = ACTIONS(3653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3653),
    [aux_sym__expression_token1] = ACTIONS(3653),
    [aux_sym__expression_token2] = ACTIONS(3653),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3651),
    [anon_sym_SLASH] = ACTIONS(3651),
    [anon_sym_div] = ACTIONS(3651),
    [anon_sym_DIV] = ACTIONS(3651),
    [anon_sym_Div] = ACTIONS(3651),
    [anon_sym_mod] = ACTIONS(3651),
    [anon_sym_MOD] = ACTIONS(3651),
    [anon_sym_Mod] = ACTIONS(3651),
    [anon_sym_PLUS] = ACTIONS(3651),
    [anon_sym_GT_EQ] = ACTIONS(3653),
    [anon_sym_LT_EQ] = ACTIONS(3653),
    [anon_sym_GT] = ACTIONS(3651),
    [anon_sym_LT] = ACTIONS(3651),
    [anon_sym_LT_GT] = ACTIONS(3653),
    [anon_sym_and] = ACTIONS(3651),
    [anon_sym_AND] = ACTIONS(3651),
    [anon_sym_And] = ACTIONS(3651),
    [anon_sym_or] = ACTIONS(3651),
    [anon_sym_OR] = ACTIONS(3651),
    [anon_sym_Or] = ACTIONS(3651),
    [anon_sym_xor] = ACTIONS(3651),
    [anon_sym_XOR] = ACTIONS(3651),
    [anon_sym_Xor] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [sym_datetime_literal] = ACTIONS(3653),
    [sym_date_literal] = ACTIONS(3651),
    [sym_time_literal] = ACTIONS(3651),
    [sym_biginteger_literal] = ACTIONS(3653),
    [anon_sym_else] = ACTIONS(3651),
    [anon_sym_ELSE] = ACTIONS(3651),
    [anon_sym_Else] = ACTIONS(3651),
    [anon_sym_in] = ACTIONS(3651),
    [anon_sym_IN] = ACTIONS(3651),
    [anon_sym_In] = ACTIONS(3651),
    [sym_page_keyword] = ACTIONS(3651),
    [anon_sym_codeunit] = ACTIONS(3651),
    [anon_sym_CODEUNIT] = ACTIONS(3651),
    [anon_sym_Codeunit] = ACTIONS(3651),
    [anon_sym_CodeUnit] = ACTIONS(3651),
    [anon_sym_COdeunit] = ACTIONS(3651),
    [anon_sym_codeUnit] = ACTIONS(3651),
    [sym_report_keyword] = ACTIONS(3651),
    [sym_query_keyword] = ACTIONS(3651),
    [anon_sym_xmlport] = ACTIONS(3651),
    [anon_sym_XMLPORT] = ACTIONS(3651),
    [anon_sym_Xmlport] = ACTIONS(3651),
    [anon_sym_XMLport] = ACTIONS(3651),
    [anon_sym_XMLPort] = ACTIONS(3651),
    [anon_sym_XmlPort] = ACTIONS(3651),
    [anon_sym_enum] = ACTIONS(3651),
    [anon_sym_ENUM] = ACTIONS(3651),
    [anon_sym_Enum] = ACTIONS(3651),
    [anon_sym_eNUM] = ACTIONS(3651),
    [anon_sym_eNum] = ACTIONS(3651),
    [anon_sym_ENum] = ACTIONS(3651),
    [sym_quoted_identifier] = ACTIONS(3653),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3653),
    [sym_verbatim_string] = ACTIONS(3653),
    [sym_integer] = ACTIONS(3651),
    [sym_continue_as_identifier] = ACTIONS(3653),
    [sym_preproc_open] = ACTIONS(3653),
    [sym_preproc_close] = ACTIONS(3653),
  },
  [STATE(2306)] = {
    [sym_identifier] = ACTIONS(3655),
    [anon_sym_SEMI] = ACTIONS(3657),
    [anon_sym_DOT] = ACTIONS(3655),
    [anon_sym_EQ] = ACTIONS(3657),
    [anon_sym_COMMA] = ACTIONS(3657),
    [anon_sym_COLON] = ACTIONS(3655),
    [anon_sym_DASH] = ACTIONS(3655),
    [aux_sym_boolean_token1] = ACTIONS(3655),
    [aux_sym_boolean_token2] = ACTIONS(3655),
    [sym_decimal] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3657),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3655),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [aux_sym_record_type_token1] = ACTIONS(3655),
    [aux_sym_basic_type_token21] = ACTIONS(3655),
    [aux_sym_basic_type_token22] = ACTIONS(3655),
    [aux_sym_basic_type_token48] = ACTIONS(3655),
    [anon_sym_COLON_COLON] = ACTIONS(3657),
    [anon_sym_POUNDif] = ACTIONS(3657),
    [anon_sym_POUNDIF] = ACTIONS(3657),
    [anon_sym_POUNDIf] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3655),
    [anon_sym_NOT] = ACTIONS(3655),
    [anon_sym_Not] = ACTIONS(3655),
    [anon_sym_POUNDelif] = ACTIONS(3657),
    [anon_sym_POUNDELIF] = ACTIONS(3657),
    [anon_sym_POUNDElif] = ACTIONS(3657),
    [anon_sym_POUNDelse] = ACTIONS(3657),
    [anon_sym_POUNDELSE] = ACTIONS(3657),
    [anon_sym_POUNDElse] = ACTIONS(3657),
    [anon_sym_POUNDelse2] = ACTIONS(3657),
    [anon_sym_POUNDELSE2] = ACTIONS(3657),
    [anon_sym_POUNDElse2] = ACTIONS(3657),
    [anon_sym_POUNDendif] = ACTIONS(3657),
    [anon_sym_POUNDENDIF] = ACTIONS(3657),
    [anon_sym_POUNDEndif] = ACTIONS(3657),
    [anon_sym_POUNDendif2] = ACTIONS(3657),
    [anon_sym_POUNDENDIF2] = ACTIONS(3657),
    [anon_sym_POUNDEndif2] = ACTIONS(3657),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3657),
    [aux_sym__expression_token1] = ACTIONS(3657),
    [aux_sym__expression_token2] = ACTIONS(3657),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3655),
    [anon_sym_SLASH] = ACTIONS(3655),
    [anon_sym_div] = ACTIONS(3655),
    [anon_sym_DIV] = ACTIONS(3655),
    [anon_sym_Div] = ACTIONS(3655),
    [anon_sym_mod] = ACTIONS(3655),
    [anon_sym_MOD] = ACTIONS(3655),
    [anon_sym_Mod] = ACTIONS(3655),
    [anon_sym_PLUS] = ACTIONS(3655),
    [anon_sym_GT_EQ] = ACTIONS(3657),
    [anon_sym_LT_EQ] = ACTIONS(3657),
    [anon_sym_GT] = ACTIONS(3655),
    [anon_sym_LT] = ACTIONS(3655),
    [anon_sym_LT_GT] = ACTIONS(3657),
    [anon_sym_and] = ACTIONS(3655),
    [anon_sym_AND] = ACTIONS(3655),
    [anon_sym_And] = ACTIONS(3655),
    [anon_sym_or] = ACTIONS(3655),
    [anon_sym_OR] = ACTIONS(3655),
    [anon_sym_Or] = ACTIONS(3655),
    [anon_sym_xor] = ACTIONS(3655),
    [anon_sym_XOR] = ACTIONS(3655),
    [anon_sym_Xor] = ACTIONS(3655),
    [anon_sym_QMARK] = ACTIONS(3657),
    [sym_datetime_literal] = ACTIONS(3657),
    [sym_date_literal] = ACTIONS(3655),
    [sym_time_literal] = ACTIONS(3655),
    [sym_biginteger_literal] = ACTIONS(3657),
    [anon_sym_else] = ACTIONS(3655),
    [anon_sym_ELSE] = ACTIONS(3655),
    [anon_sym_Else] = ACTIONS(3655),
    [anon_sym_in] = ACTIONS(3655),
    [anon_sym_IN] = ACTIONS(3655),
    [anon_sym_In] = ACTIONS(3655),
    [sym_page_keyword] = ACTIONS(3655),
    [anon_sym_codeunit] = ACTIONS(3655),
    [anon_sym_CODEUNIT] = ACTIONS(3655),
    [anon_sym_Codeunit] = ACTIONS(3655),
    [anon_sym_CodeUnit] = ACTIONS(3655),
    [anon_sym_COdeunit] = ACTIONS(3655),
    [anon_sym_codeUnit] = ACTIONS(3655),
    [sym_report_keyword] = ACTIONS(3655),
    [sym_query_keyword] = ACTIONS(3655),
    [anon_sym_xmlport] = ACTIONS(3655),
    [anon_sym_XMLPORT] = ACTIONS(3655),
    [anon_sym_Xmlport] = ACTIONS(3655),
    [anon_sym_XMLport] = ACTIONS(3655),
    [anon_sym_XMLPort] = ACTIONS(3655),
    [anon_sym_XmlPort] = ACTIONS(3655),
    [anon_sym_enum] = ACTIONS(3655),
    [anon_sym_ENUM] = ACTIONS(3655),
    [anon_sym_Enum] = ACTIONS(3655),
    [anon_sym_eNUM] = ACTIONS(3655),
    [anon_sym_eNum] = ACTIONS(3655),
    [anon_sym_ENum] = ACTIONS(3655),
    [sym_quoted_identifier] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3657),
    [sym_verbatim_string] = ACTIONS(3657),
    [sym_integer] = ACTIONS(3655),
    [sym_continue_as_identifier] = ACTIONS(3657),
    [sym_preproc_open] = ACTIONS(3657),
    [sym_preproc_close] = ACTIONS(3657),
  },
  [STATE(2307)] = {
    [sym_identifier] = ACTIONS(3659),
    [anon_sym_SEMI] = ACTIONS(3661),
    [anon_sym_DOT] = ACTIONS(3659),
    [anon_sym_EQ] = ACTIONS(3661),
    [anon_sym_COMMA] = ACTIONS(3661),
    [anon_sym_COLON] = ACTIONS(3659),
    [anon_sym_DASH] = ACTIONS(3659),
    [aux_sym_boolean_token1] = ACTIONS(3659),
    [aux_sym_boolean_token2] = ACTIONS(3659),
    [sym_decimal] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3661),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3661),
    [aux_sym_record_type_token1] = ACTIONS(3659),
    [aux_sym_basic_type_token21] = ACTIONS(3659),
    [aux_sym_basic_type_token22] = ACTIONS(3659),
    [aux_sym_basic_type_token48] = ACTIONS(3659),
    [anon_sym_COLON_COLON] = ACTIONS(3661),
    [anon_sym_POUNDif] = ACTIONS(3661),
    [anon_sym_POUNDIF] = ACTIONS(3661),
    [anon_sym_POUNDIf] = ACTIONS(3661),
    [anon_sym_not] = ACTIONS(3659),
    [anon_sym_NOT] = ACTIONS(3659),
    [anon_sym_Not] = ACTIONS(3659),
    [anon_sym_POUNDelif] = ACTIONS(3661),
    [anon_sym_POUNDELIF] = ACTIONS(3661),
    [anon_sym_POUNDElif] = ACTIONS(3661),
    [anon_sym_POUNDelse] = ACTIONS(3661),
    [anon_sym_POUNDELSE] = ACTIONS(3661),
    [anon_sym_POUNDElse] = ACTIONS(3661),
    [anon_sym_POUNDelse2] = ACTIONS(3661),
    [anon_sym_POUNDELSE2] = ACTIONS(3661),
    [anon_sym_POUNDElse2] = ACTIONS(3661),
    [anon_sym_POUNDendif] = ACTIONS(3661),
    [anon_sym_POUNDENDIF] = ACTIONS(3661),
    [anon_sym_POUNDEndif] = ACTIONS(3661),
    [anon_sym_POUNDendif2] = ACTIONS(3661),
    [anon_sym_POUNDENDIF2] = ACTIONS(3661),
    [anon_sym_POUNDEndif2] = ACTIONS(3661),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3661),
    [aux_sym__expression_token1] = ACTIONS(3661),
    [aux_sym__expression_token2] = ACTIONS(3661),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3659),
    [anon_sym_SLASH] = ACTIONS(3659),
    [anon_sym_div] = ACTIONS(3659),
    [anon_sym_DIV] = ACTIONS(3659),
    [anon_sym_Div] = ACTIONS(3659),
    [anon_sym_mod] = ACTIONS(3659),
    [anon_sym_MOD] = ACTIONS(3659),
    [anon_sym_Mod] = ACTIONS(3659),
    [anon_sym_PLUS] = ACTIONS(3659),
    [anon_sym_GT_EQ] = ACTIONS(3661),
    [anon_sym_LT_EQ] = ACTIONS(3661),
    [anon_sym_GT] = ACTIONS(3659),
    [anon_sym_LT] = ACTIONS(3659),
    [anon_sym_LT_GT] = ACTIONS(3661),
    [anon_sym_and] = ACTIONS(3659),
    [anon_sym_AND] = ACTIONS(3659),
    [anon_sym_And] = ACTIONS(3659),
    [anon_sym_or] = ACTIONS(3659),
    [anon_sym_OR] = ACTIONS(3659),
    [anon_sym_Or] = ACTIONS(3659),
    [anon_sym_xor] = ACTIONS(3659),
    [anon_sym_XOR] = ACTIONS(3659),
    [anon_sym_Xor] = ACTIONS(3659),
    [anon_sym_QMARK] = ACTIONS(3661),
    [sym_datetime_literal] = ACTIONS(3661),
    [sym_date_literal] = ACTIONS(3659),
    [sym_time_literal] = ACTIONS(3659),
    [sym_biginteger_literal] = ACTIONS(3661),
    [anon_sym_else] = ACTIONS(3659),
    [anon_sym_ELSE] = ACTIONS(3659),
    [anon_sym_Else] = ACTIONS(3659),
    [anon_sym_in] = ACTIONS(3659),
    [anon_sym_IN] = ACTIONS(3659),
    [anon_sym_In] = ACTIONS(3659),
    [sym_page_keyword] = ACTIONS(3659),
    [anon_sym_codeunit] = ACTIONS(3659),
    [anon_sym_CODEUNIT] = ACTIONS(3659),
    [anon_sym_Codeunit] = ACTIONS(3659),
    [anon_sym_CodeUnit] = ACTIONS(3659),
    [anon_sym_COdeunit] = ACTIONS(3659),
    [anon_sym_codeUnit] = ACTIONS(3659),
    [sym_report_keyword] = ACTIONS(3659),
    [sym_query_keyword] = ACTIONS(3659),
    [anon_sym_xmlport] = ACTIONS(3659),
    [anon_sym_XMLPORT] = ACTIONS(3659),
    [anon_sym_Xmlport] = ACTIONS(3659),
    [anon_sym_XMLport] = ACTIONS(3659),
    [anon_sym_XMLPort] = ACTIONS(3659),
    [anon_sym_XmlPort] = ACTIONS(3659),
    [anon_sym_enum] = ACTIONS(3659),
    [anon_sym_ENUM] = ACTIONS(3659),
    [anon_sym_Enum] = ACTIONS(3659),
    [anon_sym_eNUM] = ACTIONS(3659),
    [anon_sym_eNum] = ACTIONS(3659),
    [anon_sym_ENum] = ACTIONS(3659),
    [sym_quoted_identifier] = ACTIONS(3661),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3661),
    [sym_verbatim_string] = ACTIONS(3661),
    [sym_integer] = ACTIONS(3659),
    [sym_continue_as_identifier] = ACTIONS(3661),
    [sym_preproc_open] = ACTIONS(3661),
    [sym_preproc_close] = ACTIONS(3661),
  },
  [STATE(2308)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_COLON] = ACTIONS(3663),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(2309)] = {
    [sym_identifier] = ACTIONS(3756),
    [anon_sym_SEMI] = ACTIONS(3758),
    [anon_sym_DOT] = ACTIONS(3756),
    [anon_sym_EQ] = ACTIONS(3758),
    [anon_sym_COMMA] = ACTIONS(3758),
    [anon_sym_COLON] = ACTIONS(3756),
    [anon_sym_DASH] = ACTIONS(3756),
    [aux_sym_boolean_token1] = ACTIONS(3756),
    [aux_sym_boolean_token2] = ACTIONS(3756),
    [sym_decimal] = ACTIONS(3756),
    [anon_sym_LPAREN] = ACTIONS(3758),
    [anon_sym_DOT_DOT] = ACTIONS(3758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3756),
    [anon_sym_LBRACK] = ACTIONS(3758),
    [aux_sym_record_type_token1] = ACTIONS(3756),
    [aux_sym_basic_type_token21] = ACTIONS(3756),
    [aux_sym_basic_type_token22] = ACTIONS(3756),
    [aux_sym_basic_type_token48] = ACTIONS(3756),
    [anon_sym_COLON_COLON] = ACTIONS(3758),
    [anon_sym_POUNDif] = ACTIONS(3758),
    [anon_sym_POUNDIF] = ACTIONS(3758),
    [anon_sym_POUNDIf] = ACTIONS(3758),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_NOT] = ACTIONS(3756),
    [anon_sym_Not] = ACTIONS(3756),
    [anon_sym_POUNDelif] = ACTIONS(3758),
    [anon_sym_POUNDELIF] = ACTIONS(3758),
    [anon_sym_POUNDElif] = ACTIONS(3758),
    [anon_sym_POUNDelse] = ACTIONS(3758),
    [anon_sym_POUNDELSE] = ACTIONS(3758),
    [anon_sym_POUNDElse] = ACTIONS(3758),
    [anon_sym_POUNDelse2] = ACTIONS(3758),
    [anon_sym_POUNDELSE2] = ACTIONS(3758),
    [anon_sym_POUNDElse2] = ACTIONS(3758),
    [anon_sym_POUNDendif] = ACTIONS(3758),
    [anon_sym_POUNDENDIF] = ACTIONS(3758),
    [anon_sym_POUNDEndif] = ACTIONS(3758),
    [anon_sym_POUNDendif2] = ACTIONS(3758),
    [anon_sym_POUNDENDIF2] = ACTIONS(3758),
    [anon_sym_POUNDEndif2] = ACTIONS(3758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3758),
    [aux_sym__expression_token1] = ACTIONS(3758),
    [aux_sym__expression_token2] = ACTIONS(3758),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3756),
    [anon_sym_SLASH] = ACTIONS(3756),
    [anon_sym_div] = ACTIONS(3756),
    [anon_sym_DIV] = ACTIONS(3756),
    [anon_sym_Div] = ACTIONS(3756),
    [anon_sym_mod] = ACTIONS(3756),
    [anon_sym_MOD] = ACTIONS(3756),
    [anon_sym_Mod] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_GT_EQ] = ACTIONS(3758),
    [anon_sym_LT_EQ] = ACTIONS(3758),
    [anon_sym_GT] = ACTIONS(3756),
    [anon_sym_LT] = ACTIONS(3756),
    [anon_sym_LT_GT] = ACTIONS(3758),
    [anon_sym_and] = ACTIONS(3756),
    [anon_sym_AND] = ACTIONS(3756),
    [anon_sym_And] = ACTIONS(3756),
    [anon_sym_or] = ACTIONS(3756),
    [anon_sym_OR] = ACTIONS(3756),
    [anon_sym_Or] = ACTIONS(3756),
    [anon_sym_xor] = ACTIONS(3756),
    [anon_sym_XOR] = ACTIONS(3756),
    [anon_sym_Xor] = ACTIONS(3756),
    [anon_sym_QMARK] = ACTIONS(3758),
    [sym_datetime_literal] = ACTIONS(3758),
    [sym_date_literal] = ACTIONS(3756),
    [sym_time_literal] = ACTIONS(3756),
    [sym_biginteger_literal] = ACTIONS(3758),
    [anon_sym_else] = ACTIONS(3756),
    [anon_sym_ELSE] = ACTIONS(3756),
    [anon_sym_Else] = ACTIONS(3756),
    [anon_sym_in] = ACTIONS(3756),
    [anon_sym_IN] = ACTIONS(3756),
    [anon_sym_In] = ACTIONS(3756),
    [sym_page_keyword] = ACTIONS(3756),
    [anon_sym_codeunit] = ACTIONS(3756),
    [anon_sym_CODEUNIT] = ACTIONS(3756),
    [anon_sym_Codeunit] = ACTIONS(3756),
    [anon_sym_CodeUnit] = ACTIONS(3756),
    [anon_sym_COdeunit] = ACTIONS(3756),
    [anon_sym_codeUnit] = ACTIONS(3756),
    [sym_report_keyword] = ACTIONS(3756),
    [sym_query_keyword] = ACTIONS(3756),
    [anon_sym_xmlport] = ACTIONS(3756),
    [anon_sym_XMLPORT] = ACTIONS(3756),
    [anon_sym_Xmlport] = ACTIONS(3756),
    [anon_sym_XMLport] = ACTIONS(3756),
    [anon_sym_XMLPort] = ACTIONS(3756),
    [anon_sym_XmlPort] = ACTIONS(3756),
    [anon_sym_enum] = ACTIONS(3756),
    [anon_sym_ENUM] = ACTIONS(3756),
    [anon_sym_Enum] = ACTIONS(3756),
    [anon_sym_eNUM] = ACTIONS(3756),
    [anon_sym_eNum] = ACTIONS(3756),
    [anon_sym_ENum] = ACTIONS(3756),
    [sym_quoted_identifier] = ACTIONS(3758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3758),
    [sym_verbatim_string] = ACTIONS(3758),
    [sym_integer] = ACTIONS(3756),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_open] = ACTIONS(3758),
    [sym_preproc_close] = ACTIONS(3758),
  },
  [STATE(2310)] = {
    [sym_identifier] = ACTIONS(5399),
    [anon_sym_SEMI] = ACTIONS(5401),
    [anon_sym_DASH] = ACTIONS(5401),
    [aux_sym_boolean_token1] = ACTIONS(5399),
    [aux_sym_boolean_token2] = ACTIONS(5399),
    [sym_decimal] = ACTIONS(5399),
    [anon_sym_LPAREN] = ACTIONS(5401),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5399),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [aux_sym_record_type_token1] = ACTIONS(5399),
    [aux_sym_basic_type_token21] = ACTIONS(5399),
    [aux_sym_basic_type_token22] = ACTIONS(5399),
    [aux_sym_basic_type_token48] = ACTIONS(5399),
    [anon_sym_POUNDif] = ACTIONS(5401),
    [anon_sym_POUNDIF] = ACTIONS(5401),
    [anon_sym_POUNDIf] = ACTIONS(5401),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5362),
    [anon_sym_PIPE_PIPE] = ACTIONS(5364),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5366),
    [anon_sym_AMP_AMP] = ACTIONS(5368),
    [anon_sym_not] = ACTIONS(5399),
    [anon_sym_NOT] = ACTIONS(5399),
    [anon_sym_Not] = ACTIONS(5399),
    [anon_sym_POUNDelif] = ACTIONS(5401),
    [anon_sym_POUNDELIF] = ACTIONS(5401),
    [anon_sym_POUNDElif] = ACTIONS(5401),
    [anon_sym_POUNDelse] = ACTIONS(5401),
    [anon_sym_POUNDELSE] = ACTIONS(5401),
    [anon_sym_POUNDElse] = ACTIONS(5401),
    [anon_sym_POUNDelse2] = ACTIONS(5401),
    [anon_sym_POUNDELSE2] = ACTIONS(5401),
    [anon_sym_POUNDElse2] = ACTIONS(5401),
    [anon_sym_POUNDendif] = ACTIONS(5401),
    [anon_sym_POUNDENDIF] = ACTIONS(5401),
    [anon_sym_POUNDEndif] = ACTIONS(5401),
    [anon_sym_POUNDendif2] = ACTIONS(5401),
    [anon_sym_POUNDENDIF2] = ACTIONS(5401),
    [anon_sym_POUNDEndif2] = ACTIONS(5401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5399),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5399),
    [anon_sym_PLUS] = ACTIONS(5401),
    [sym_datetime_literal] = ACTIONS(5401),
    [sym_date_literal] = ACTIONS(5399),
    [sym_time_literal] = ACTIONS(5399),
    [sym_biginteger_literal] = ACTIONS(5401),
    [anon_sym_if] = ACTIONS(5399),
    [anon_sym_IF] = ACTIONS(5399),
    [anon_sym_If] = ACTIONS(5399),
    [anon_sym_else] = ACTIONS(5399),
    [anon_sym_ELSE] = ACTIONS(5399),
    [anon_sym_Else] = ACTIONS(5399),
    [anon_sym_case] = ACTIONS(5399),
    [anon_sym_CASE] = ACTIONS(5399),
    [anon_sym_Case] = ACTIONS(5399),
    [anon_sym_for] = ACTIONS(5399),
    [anon_sym_FOR] = ACTIONS(5399),
    [anon_sym_For] = ACTIONS(5399),
    [anon_sym_foreach] = ACTIONS(5399),
    [anon_sym_FOREACH] = ACTIONS(5399),
    [anon_sym_Foreach] = ACTIONS(5399),
    [anon_sym_while] = ACTIONS(5399),
    [anon_sym_WHILE] = ACTIONS(5399),
    [anon_sym_While] = ACTIONS(5399),
    [anon_sym_repeat] = ACTIONS(5399),
    [anon_sym_REPEAT] = ACTIONS(5399),
    [anon_sym_Repeat] = ACTIONS(5399),
    [anon_sym_exit] = ACTIONS(5399),
    [anon_sym_EXIT] = ACTIONS(5399),
    [anon_sym_Exit] = ACTIONS(5399),
    [anon_sym_continue] = ACTIONS(5399),
    [anon_sym_CONTINUE] = ACTIONS(5399),
    [anon_sym_Continue] = ACTIONS(5399),
    [anon_sym_break] = ACTIONS(5399),
    [anon_sym_BREAK] = ACTIONS(5399),
    [anon_sym_Break] = ACTIONS(5399),
    [anon_sym_with] = ACTIONS(5399),
    [anon_sym_WITH] = ACTIONS(5399),
    [anon_sym_With] = ACTIONS(5399),
    [sym_asserterror_keyword] = ACTIONS(5401),
    [sym_page_keyword] = ACTIONS(5399),
    [anon_sym_codeunit] = ACTIONS(5399),
    [anon_sym_CODEUNIT] = ACTIONS(5399),
    [anon_sym_Codeunit] = ACTIONS(5399),
    [anon_sym_CodeUnit] = ACTIONS(5399),
    [anon_sym_COdeunit] = ACTIONS(5399),
    [anon_sym_codeUnit] = ACTIONS(5399),
    [sym_report_keyword] = ACTIONS(5399),
    [sym_query_keyword] = ACTIONS(5399),
    [anon_sym_xmlport] = ACTIONS(5399),
    [anon_sym_XMLPORT] = ACTIONS(5399),
    [anon_sym_Xmlport] = ACTIONS(5399),
    [anon_sym_XMLport] = ACTIONS(5399),
    [anon_sym_XMLPort] = ACTIONS(5399),
    [anon_sym_XmlPort] = ACTIONS(5399),
    [anon_sym_enum] = ACTIONS(5399),
    [anon_sym_ENUM] = ACTIONS(5399),
    [anon_sym_Enum] = ACTIONS(5399),
    [anon_sym_eNUM] = ACTIONS(5399),
    [anon_sym_eNum] = ACTIONS(5399),
    [anon_sym_ENum] = ACTIONS(5399),
    [sym_quoted_identifier] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5401),
    [sym_verbatim_string] = ACTIONS(5401),
    [sym_integer] = ACTIONS(5399),
    [sym_continue_as_identifier] = ACTIONS(5401),
    [sym_preproc_open] = ACTIONS(5401),
    [sym_preproc_close] = ACTIONS(5401),
  },
  [STATE(2311)] = {
    [sym_identifier] = ACTIONS(3764),
    [anon_sym_SEMI] = ACTIONS(3766),
    [anon_sym_DOT] = ACTIONS(3764),
    [anon_sym_EQ] = ACTIONS(3766),
    [anon_sym_COMMA] = ACTIONS(3766),
    [anon_sym_COLON] = ACTIONS(3764),
    [anon_sym_DASH] = ACTIONS(3764),
    [aux_sym_boolean_token1] = ACTIONS(3764),
    [aux_sym_boolean_token2] = ACTIONS(3764),
    [sym_decimal] = ACTIONS(3764),
    [anon_sym_LPAREN] = ACTIONS(3766),
    [anon_sym_DOT_DOT] = ACTIONS(3766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3764),
    [anon_sym_STAR] = ACTIONS(3764),
    [anon_sym_LBRACK] = ACTIONS(3766),
    [aux_sym_record_type_token1] = ACTIONS(3764),
    [aux_sym_basic_type_token21] = ACTIONS(3764),
    [aux_sym_basic_type_token22] = ACTIONS(3764),
    [aux_sym_basic_type_token48] = ACTIONS(3764),
    [anon_sym_COLON_COLON] = ACTIONS(3766),
    [anon_sym_POUNDif] = ACTIONS(3766),
    [anon_sym_POUNDIF] = ACTIONS(3766),
    [anon_sym_POUNDIf] = ACTIONS(3766),
    [anon_sym_not] = ACTIONS(3764),
    [anon_sym_NOT] = ACTIONS(3764),
    [anon_sym_Not] = ACTIONS(3764),
    [anon_sym_POUNDelif] = ACTIONS(3766),
    [anon_sym_POUNDELIF] = ACTIONS(3766),
    [anon_sym_POUNDElif] = ACTIONS(3766),
    [anon_sym_POUNDelse] = ACTIONS(3766),
    [anon_sym_POUNDELSE] = ACTIONS(3766),
    [anon_sym_POUNDElse] = ACTIONS(3766),
    [anon_sym_POUNDelse2] = ACTIONS(3766),
    [anon_sym_POUNDELSE2] = ACTIONS(3766),
    [anon_sym_POUNDElse2] = ACTIONS(3766),
    [anon_sym_POUNDendif] = ACTIONS(3766),
    [anon_sym_POUNDENDIF] = ACTIONS(3766),
    [anon_sym_POUNDEndif] = ACTIONS(3766),
    [anon_sym_POUNDendif2] = ACTIONS(3766),
    [anon_sym_POUNDENDIF2] = ACTIONS(3766),
    [anon_sym_POUNDEndif2] = ACTIONS(3766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3766),
    [aux_sym__expression_token1] = ACTIONS(3766),
    [aux_sym__expression_token2] = ACTIONS(3766),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3764),
    [anon_sym_SLASH] = ACTIONS(3764),
    [anon_sym_div] = ACTIONS(3764),
    [anon_sym_DIV] = ACTIONS(3764),
    [anon_sym_Div] = ACTIONS(3764),
    [anon_sym_mod] = ACTIONS(3764),
    [anon_sym_MOD] = ACTIONS(3764),
    [anon_sym_Mod] = ACTIONS(3764),
    [anon_sym_PLUS] = ACTIONS(3764),
    [anon_sym_GT_EQ] = ACTIONS(3766),
    [anon_sym_LT_EQ] = ACTIONS(3766),
    [anon_sym_GT] = ACTIONS(3764),
    [anon_sym_LT] = ACTIONS(3764),
    [anon_sym_LT_GT] = ACTIONS(3766),
    [anon_sym_and] = ACTIONS(3764),
    [anon_sym_AND] = ACTIONS(3764),
    [anon_sym_And] = ACTIONS(3764),
    [anon_sym_or] = ACTIONS(3764),
    [anon_sym_OR] = ACTIONS(3764),
    [anon_sym_Or] = ACTIONS(3764),
    [anon_sym_xor] = ACTIONS(3764),
    [anon_sym_XOR] = ACTIONS(3764),
    [anon_sym_Xor] = ACTIONS(3764),
    [anon_sym_QMARK] = ACTIONS(3766),
    [sym_datetime_literal] = ACTIONS(3766),
    [sym_date_literal] = ACTIONS(3764),
    [sym_time_literal] = ACTIONS(3764),
    [sym_biginteger_literal] = ACTIONS(3766),
    [anon_sym_else] = ACTIONS(3764),
    [anon_sym_ELSE] = ACTIONS(3764),
    [anon_sym_Else] = ACTIONS(3764),
    [anon_sym_in] = ACTIONS(3764),
    [anon_sym_IN] = ACTIONS(3764),
    [anon_sym_In] = ACTIONS(3764),
    [sym_page_keyword] = ACTIONS(3764),
    [anon_sym_codeunit] = ACTIONS(3764),
    [anon_sym_CODEUNIT] = ACTIONS(3764),
    [anon_sym_Codeunit] = ACTIONS(3764),
    [anon_sym_CodeUnit] = ACTIONS(3764),
    [anon_sym_COdeunit] = ACTIONS(3764),
    [anon_sym_codeUnit] = ACTIONS(3764),
    [sym_report_keyword] = ACTIONS(3764),
    [sym_query_keyword] = ACTIONS(3764),
    [anon_sym_xmlport] = ACTIONS(3764),
    [anon_sym_XMLPORT] = ACTIONS(3764),
    [anon_sym_Xmlport] = ACTIONS(3764),
    [anon_sym_XMLport] = ACTIONS(3764),
    [anon_sym_XMLPort] = ACTIONS(3764),
    [anon_sym_XmlPort] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3764),
    [anon_sym_ENUM] = ACTIONS(3764),
    [anon_sym_Enum] = ACTIONS(3764),
    [anon_sym_eNUM] = ACTIONS(3764),
    [anon_sym_eNum] = ACTIONS(3764),
    [anon_sym_ENum] = ACTIONS(3764),
    [sym_quoted_identifier] = ACTIONS(3766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3766),
    [sym_verbatim_string] = ACTIONS(3766),
    [sym_integer] = ACTIONS(3764),
    [sym_continue_as_identifier] = ACTIONS(3766),
    [sym_preproc_open] = ACTIONS(3766),
    [sym_preproc_close] = ACTIONS(3766),
  },
  [STATE(2312)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2295),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(602),
    [aux_sym_boolean_token1] = ACTIONS(602),
    [aux_sym_boolean_token2] = ACTIONS(602),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(602),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(602),
    [aux_sym_basic_type_token21] = ACTIONS(602),
    [aux_sym_basic_type_token22] = ACTIONS(602),
    [aux_sym_basic_type_token48] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(602),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_page_keyword] = ACTIONS(602),
    [anon_sym_codeunit] = ACTIONS(602),
    [anon_sym_CODEUNIT] = ACTIONS(602),
    [anon_sym_Codeunit] = ACTIONS(602),
    [anon_sym_CodeUnit] = ACTIONS(602),
    [anon_sym_COdeunit] = ACTIONS(602),
    [anon_sym_codeUnit] = ACTIONS(602),
    [sym_report_keyword] = ACTIONS(602),
    [sym_query_keyword] = ACTIONS(602),
    [anon_sym_xmlport] = ACTIONS(602),
    [anon_sym_XMLPORT] = ACTIONS(602),
    [anon_sym_Xmlport] = ACTIONS(602),
    [anon_sym_XMLport] = ACTIONS(602),
    [anon_sym_XMLPort] = ACTIONS(602),
    [anon_sym_XmlPort] = ACTIONS(602),
    [anon_sym_enum] = ACTIONS(602),
    [anon_sym_ENUM] = ACTIONS(602),
    [anon_sym_Enum] = ACTIONS(602),
    [anon_sym_eNUM] = ACTIONS(602),
    [anon_sym_eNum] = ACTIONS(602),
    [anon_sym_ENum] = ACTIONS(602),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(600),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(602),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
  },
  [STATE(2313)] = {
    [sym_identifier] = ACTIONS(3784),
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_COMMA] = ACTIONS(3786),
    [anon_sym_COLON] = ACTIONS(3784),
    [anon_sym_DASH] = ACTIONS(3784),
    [aux_sym_boolean_token1] = ACTIONS(3784),
    [aux_sym_boolean_token2] = ACTIONS(3784),
    [sym_decimal] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3784),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_record_type_token1] = ACTIONS(3784),
    [aux_sym_basic_type_token21] = ACTIONS(3784),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_basic_type_token48] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_not] = ACTIONS(3784),
    [anon_sym_NOT] = ACTIONS(3784),
    [anon_sym_Not] = ACTIONS(3784),
    [anon_sym_POUNDelif] = ACTIONS(3786),
    [anon_sym_POUNDELIF] = ACTIONS(3786),
    [anon_sym_POUNDElif] = ACTIONS(3786),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [anon_sym_POUNDendif] = ACTIONS(3786),
    [anon_sym_POUNDENDIF] = ACTIONS(3786),
    [anon_sym_POUNDEndif] = ACTIONS(3786),
    [anon_sym_POUNDendif2] = ACTIONS(3786),
    [anon_sym_POUNDENDIF2] = ACTIONS(3786),
    [anon_sym_POUNDEndif2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3784),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3784),
    [anon_sym_DIV] = ACTIONS(3784),
    [anon_sym_Div] = ACTIONS(3784),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3784),
    [anon_sym_AND] = ACTIONS(3784),
    [anon_sym_And] = ACTIONS(3784),
    [anon_sym_or] = ACTIONS(3784),
    [anon_sym_OR] = ACTIONS(3784),
    [anon_sym_Or] = ACTIONS(3784),
    [anon_sym_xor] = ACTIONS(3784),
    [anon_sym_XOR] = ACTIONS(3784),
    [anon_sym_Xor] = ACTIONS(3784),
    [anon_sym_QMARK] = ACTIONS(3786),
    [sym_datetime_literal] = ACTIONS(3786),
    [sym_date_literal] = ACTIONS(3784),
    [sym_time_literal] = ACTIONS(3784),
    [sym_biginteger_literal] = ACTIONS(3786),
    [anon_sym_else] = ACTIONS(3784),
    [anon_sym_ELSE] = ACTIONS(3784),
    [anon_sym_Else] = ACTIONS(3784),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_page_keyword] = ACTIONS(3784),
    [anon_sym_codeunit] = ACTIONS(3784),
    [anon_sym_CODEUNIT] = ACTIONS(3784),
    [anon_sym_Codeunit] = ACTIONS(3784),
    [anon_sym_CodeUnit] = ACTIONS(3784),
    [anon_sym_COdeunit] = ACTIONS(3784),
    [anon_sym_codeUnit] = ACTIONS(3784),
    [sym_report_keyword] = ACTIONS(3784),
    [sym_query_keyword] = ACTIONS(3784),
    [anon_sym_xmlport] = ACTIONS(3784),
    [anon_sym_XMLPORT] = ACTIONS(3784),
    [anon_sym_Xmlport] = ACTIONS(3784),
    [anon_sym_XMLport] = ACTIONS(3784),
    [anon_sym_XMLPort] = ACTIONS(3784),
    [anon_sym_XmlPort] = ACTIONS(3784),
    [anon_sym_enum] = ACTIONS(3784),
    [anon_sym_ENUM] = ACTIONS(3784),
    [anon_sym_Enum] = ACTIONS(3784),
    [anon_sym_eNUM] = ACTIONS(3784),
    [anon_sym_eNum] = ACTIONS(3784),
    [anon_sym_ENum] = ACTIONS(3784),
    [sym_quoted_identifier] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3786),
    [sym_verbatim_string] = ACTIONS(3786),
    [sym_integer] = ACTIONS(3784),
    [sym_continue_as_identifier] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
    [sym_preproc_close] = ACTIONS(3786),
  },
  [STATE(2314)] = {
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_SEMI] = ACTIONS(3748),
    [anon_sym_DOT] = ACTIONS(3746),
    [anon_sym_EQ] = ACTIONS(3748),
    [anon_sym_COMMA] = ACTIONS(3748),
    [anon_sym_COLON] = ACTIONS(3746),
    [anon_sym_DASH] = ACTIONS(3746),
    [aux_sym_boolean_token1] = ACTIONS(3746),
    [aux_sym_boolean_token2] = ACTIONS(3746),
    [sym_decimal] = ACTIONS(3746),
    [anon_sym_LPAREN] = ACTIONS(3748),
    [anon_sym_DOT_DOT] = ACTIONS(3748),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3746),
    [anon_sym_STAR] = ACTIONS(3746),
    [anon_sym_LBRACK] = ACTIONS(3748),
    [aux_sym_record_type_token1] = ACTIONS(3746),
    [aux_sym_basic_type_token21] = ACTIONS(3746),
    [aux_sym_basic_type_token22] = ACTIONS(3746),
    [aux_sym_basic_type_token48] = ACTIONS(3746),
    [anon_sym_POUNDif] = ACTIONS(3748),
    [anon_sym_POUNDIF] = ACTIONS(3748),
    [anon_sym_POUNDIf] = ACTIONS(3748),
    [anon_sym_not] = ACTIONS(3746),
    [anon_sym_NOT] = ACTIONS(3746),
    [anon_sym_Not] = ACTIONS(3746),
    [anon_sym_POUNDelif] = ACTIONS(3748),
    [anon_sym_POUNDELIF] = ACTIONS(3748),
    [anon_sym_POUNDElif] = ACTIONS(3748),
    [anon_sym_POUNDelse] = ACTIONS(3748),
    [anon_sym_POUNDELSE] = ACTIONS(3748),
    [anon_sym_POUNDElse] = ACTIONS(3748),
    [anon_sym_POUNDelse2] = ACTIONS(3748),
    [anon_sym_POUNDELSE2] = ACTIONS(3748),
    [anon_sym_POUNDElse2] = ACTIONS(3748),
    [anon_sym_POUNDendif] = ACTIONS(3748),
    [anon_sym_POUNDENDIF] = ACTIONS(3748),
    [anon_sym_POUNDEndif] = ACTIONS(3748),
    [anon_sym_POUNDendif2] = ACTIONS(3748),
    [anon_sym_POUNDENDIF2] = ACTIONS(3748),
    [anon_sym_POUNDEndif2] = ACTIONS(3748),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3748),
    [aux_sym__expression_token1] = ACTIONS(3748),
    [aux_sym__expression_token2] = ACTIONS(3748),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3746),
    [anon_sym_SLASH] = ACTIONS(3746),
    [anon_sym_div] = ACTIONS(3746),
    [anon_sym_DIV] = ACTIONS(3746),
    [anon_sym_Div] = ACTIONS(3746),
    [anon_sym_mod] = ACTIONS(3746),
    [anon_sym_MOD] = ACTIONS(3746),
    [anon_sym_Mod] = ACTIONS(3746),
    [anon_sym_PLUS] = ACTIONS(3746),
    [anon_sym_GT_EQ] = ACTIONS(3748),
    [anon_sym_LT_EQ] = ACTIONS(3748),
    [anon_sym_GT] = ACTIONS(3746),
    [anon_sym_LT] = ACTIONS(3746),
    [anon_sym_LT_GT] = ACTIONS(3748),
    [anon_sym_and] = ACTIONS(3746),
    [anon_sym_AND] = ACTIONS(3746),
    [anon_sym_And] = ACTIONS(3746),
    [anon_sym_or] = ACTIONS(3746),
    [anon_sym_OR] = ACTIONS(3746),
    [anon_sym_Or] = ACTIONS(3746),
    [anon_sym_xor] = ACTIONS(3746),
    [anon_sym_XOR] = ACTIONS(3746),
    [anon_sym_Xor] = ACTIONS(3746),
    [anon_sym_QMARK] = ACTIONS(3748),
    [sym_datetime_literal] = ACTIONS(3748),
    [sym_date_literal] = ACTIONS(3746),
    [sym_time_literal] = ACTIONS(3746),
    [sym_biginteger_literal] = ACTIONS(3748),
    [anon_sym_else] = ACTIONS(3746),
    [anon_sym_ELSE] = ACTIONS(3746),
    [anon_sym_Else] = ACTIONS(3746),
    [anon_sym_in] = ACTIONS(3746),
    [anon_sym_IN] = ACTIONS(3746),
    [anon_sym_In] = ACTIONS(3746),
    [sym_page_keyword] = ACTIONS(3746),
    [anon_sym_codeunit] = ACTIONS(3746),
    [anon_sym_CODEUNIT] = ACTIONS(3746),
    [anon_sym_Codeunit] = ACTIONS(3746),
    [anon_sym_CodeUnit] = ACTIONS(3746),
    [anon_sym_COdeunit] = ACTIONS(3746),
    [anon_sym_codeUnit] = ACTIONS(3746),
    [sym_report_keyword] = ACTIONS(3746),
    [sym_query_keyword] = ACTIONS(3746),
    [anon_sym_xmlport] = ACTIONS(3746),
    [anon_sym_XMLPORT] = ACTIONS(3746),
    [anon_sym_Xmlport] = ACTIONS(3746),
    [anon_sym_XMLport] = ACTIONS(3746),
    [anon_sym_XMLPort] = ACTIONS(3746),
    [anon_sym_XmlPort] = ACTIONS(3746),
    [anon_sym_enum] = ACTIONS(3746),
    [anon_sym_ENUM] = ACTIONS(3746),
    [anon_sym_Enum] = ACTIONS(3746),
    [anon_sym_eNUM] = ACTIONS(3746),
    [anon_sym_eNum] = ACTIONS(3746),
    [anon_sym_ENum] = ACTIONS(3746),
    [sym_temporary_keyword] = ACTIONS(5403),
    [sym_quoted_identifier] = ACTIONS(3748),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3748),
    [sym_verbatim_string] = ACTIONS(3748),
    [sym_integer] = ACTIONS(3746),
    [sym_continue_as_identifier] = ACTIONS(3748),
    [sym_preproc_open] = ACTIONS(3748),
    [sym_preproc_close] = ACTIONS(3748),
  },
  [STATE(2315)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2304),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_SEMI] = ACTIONS(3669),
    [anon_sym_DOT] = ACTIONS(3667),
    [anon_sym_EQ] = ACTIONS(3669),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(3667),
    [anon_sym_DASH] = ACTIONS(3667),
    [aux_sym_boolean_token1] = ACTIONS(3667),
    [aux_sym_boolean_token2] = ACTIONS(3667),
    [sym_decimal] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3669),
    [anon_sym_DOT_DOT] = ACTIONS(3669),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3667),
    [anon_sym_STAR] = ACTIONS(3667),
    [anon_sym_LBRACK] = ACTIONS(3669),
    [aux_sym_record_type_token1] = ACTIONS(3667),
    [aux_sym_basic_type_token21] = ACTIONS(3667),
    [aux_sym_basic_type_token22] = ACTIONS(3667),
    [aux_sym_basic_type_token48] = ACTIONS(3667),
    [anon_sym_POUNDif] = ACTIONS(3669),
    [anon_sym_POUNDIF] = ACTIONS(3669),
    [anon_sym_POUNDIf] = ACTIONS(3669),
    [anon_sym_not] = ACTIONS(3667),
    [anon_sym_NOT] = ACTIONS(3667),
    [anon_sym_Not] = ACTIONS(3667),
    [anon_sym_POUNDelif] = ACTIONS(3669),
    [anon_sym_POUNDELIF] = ACTIONS(3669),
    [anon_sym_POUNDElif] = ACTIONS(3669),
    [anon_sym_POUNDelse] = ACTIONS(3669),
    [anon_sym_POUNDELSE] = ACTIONS(3669),
    [anon_sym_POUNDElse] = ACTIONS(3669),
    [anon_sym_POUNDelse2] = ACTIONS(3669),
    [anon_sym_POUNDELSE2] = ACTIONS(3669),
    [anon_sym_POUNDElse2] = ACTIONS(3669),
    [anon_sym_POUNDendif] = ACTIONS(3669),
    [anon_sym_POUNDENDIF] = ACTIONS(3669),
    [anon_sym_POUNDEndif] = ACTIONS(3669),
    [anon_sym_POUNDendif2] = ACTIONS(3669),
    [anon_sym_POUNDENDIF2] = ACTIONS(3669),
    [anon_sym_POUNDEndif2] = ACTIONS(3669),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3669),
    [aux_sym__expression_token1] = ACTIONS(3669),
    [aux_sym__expression_token2] = ACTIONS(3669),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3667),
    [anon_sym_SLASH] = ACTIONS(3667),
    [anon_sym_div] = ACTIONS(3667),
    [anon_sym_DIV] = ACTIONS(3667),
    [anon_sym_Div] = ACTIONS(3667),
    [anon_sym_mod] = ACTIONS(3667),
    [anon_sym_MOD] = ACTIONS(3667),
    [anon_sym_Mod] = ACTIONS(3667),
    [anon_sym_PLUS] = ACTIONS(3667),
    [anon_sym_GT_EQ] = ACTIONS(3669),
    [anon_sym_LT_EQ] = ACTIONS(3669),
    [anon_sym_GT] = ACTIONS(3667),
    [anon_sym_LT] = ACTIONS(3667),
    [anon_sym_LT_GT] = ACTIONS(3669),
    [anon_sym_and] = ACTIONS(3667),
    [anon_sym_AND] = ACTIONS(3667),
    [anon_sym_And] = ACTIONS(3667),
    [anon_sym_or] = ACTIONS(3667),
    [anon_sym_OR] = ACTIONS(3667),
    [anon_sym_Or] = ACTIONS(3667),
    [anon_sym_xor] = ACTIONS(3667),
    [anon_sym_XOR] = ACTIONS(3667),
    [anon_sym_Xor] = ACTIONS(3667),
    [anon_sym_QMARK] = ACTIONS(3669),
    [sym_datetime_literal] = ACTIONS(3669),
    [sym_date_literal] = ACTIONS(3667),
    [sym_time_literal] = ACTIONS(3667),
    [sym_biginteger_literal] = ACTIONS(3669),
    [anon_sym_else] = ACTIONS(3667),
    [anon_sym_ELSE] = ACTIONS(3667),
    [anon_sym_Else] = ACTIONS(3667),
    [anon_sym_in] = ACTIONS(3667),
    [anon_sym_IN] = ACTIONS(3667),
    [anon_sym_In] = ACTIONS(3667),
    [sym_page_keyword] = ACTIONS(3667),
    [anon_sym_codeunit] = ACTIONS(3667),
    [anon_sym_CODEUNIT] = ACTIONS(3667),
    [anon_sym_Codeunit] = ACTIONS(3667),
    [anon_sym_CodeUnit] = ACTIONS(3667),
    [anon_sym_COdeunit] = ACTIONS(3667),
    [anon_sym_codeUnit] = ACTIONS(3667),
    [sym_report_keyword] = ACTIONS(3667),
    [sym_query_keyword] = ACTIONS(3667),
    [anon_sym_xmlport] = ACTIONS(3667),
    [anon_sym_XMLPORT] = ACTIONS(3667),
    [anon_sym_Xmlport] = ACTIONS(3667),
    [anon_sym_XMLport] = ACTIONS(3667),
    [anon_sym_XMLPort] = ACTIONS(3667),
    [anon_sym_XmlPort] = ACTIONS(3667),
    [anon_sym_enum] = ACTIONS(3667),
    [anon_sym_ENUM] = ACTIONS(3667),
    [anon_sym_Enum] = ACTIONS(3667),
    [anon_sym_eNUM] = ACTIONS(3667),
    [anon_sym_eNum] = ACTIONS(3667),
    [anon_sym_ENum] = ACTIONS(3667),
    [sym_quoted_identifier] = ACTIONS(3669),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3669),
    [sym_verbatim_string] = ACTIONS(3669),
    [sym_integer] = ACTIONS(3667),
    [sym_continue_as_identifier] = ACTIONS(3669),
    [sym_preproc_open] = ACTIONS(3669),
    [sym_preproc_close] = ACTIONS(3669),
  },
  [STATE(2316)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2315),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(3689),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelif] = ACTIONS(3691),
    [anon_sym_POUNDELIF] = ACTIONS(3691),
    [anon_sym_POUNDElif] = ACTIONS(3691),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [anon_sym_POUNDendif] = ACTIONS(3691),
    [anon_sym_POUNDENDIF] = ACTIONS(3691),
    [anon_sym_POUNDEndif] = ACTIONS(3691),
    [anon_sym_POUNDendif2] = ACTIONS(3691),
    [anon_sym_POUNDENDIF2] = ACTIONS(3691),
    [anon_sym_POUNDEndif2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3691),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
    [sym_preproc_close] = ACTIONS(3691),
  },
  [STATE(2317)] = {
    [sym_identifier] = ACTIONS(3790),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_DOT] = ACTIONS(3790),
    [anon_sym_EQ] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3792),
    [anon_sym_COLON] = ACTIONS(3790),
    [anon_sym_DASH] = ACTIONS(3790),
    [aux_sym_boolean_token1] = ACTIONS(3790),
    [aux_sym_boolean_token2] = ACTIONS(3790),
    [sym_decimal] = ACTIONS(3790),
    [anon_sym_LPAREN] = ACTIONS(3792),
    [anon_sym_DOT_DOT] = ACTIONS(3792),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3790),
    [anon_sym_STAR] = ACTIONS(3790),
    [anon_sym_LBRACK] = ACTIONS(3792),
    [aux_sym_record_type_token1] = ACTIONS(3790),
    [aux_sym_basic_type_token21] = ACTIONS(3790),
    [aux_sym_basic_type_token22] = ACTIONS(3790),
    [aux_sym_basic_type_token48] = ACTIONS(3790),
    [anon_sym_COLON_COLON] = ACTIONS(3792),
    [anon_sym_POUNDif] = ACTIONS(3792),
    [anon_sym_POUNDIF] = ACTIONS(3792),
    [anon_sym_POUNDIf] = ACTIONS(3792),
    [anon_sym_not] = ACTIONS(3790),
    [anon_sym_NOT] = ACTIONS(3790),
    [anon_sym_Not] = ACTIONS(3790),
    [anon_sym_POUNDelif] = ACTIONS(3792),
    [anon_sym_POUNDELIF] = ACTIONS(3792),
    [anon_sym_POUNDElif] = ACTIONS(3792),
    [anon_sym_POUNDelse] = ACTIONS(3792),
    [anon_sym_POUNDELSE] = ACTIONS(3792),
    [anon_sym_POUNDElse] = ACTIONS(3792),
    [anon_sym_POUNDelse2] = ACTIONS(3792),
    [anon_sym_POUNDELSE2] = ACTIONS(3792),
    [anon_sym_POUNDElse2] = ACTIONS(3792),
    [anon_sym_POUNDendif] = ACTIONS(3792),
    [anon_sym_POUNDENDIF] = ACTIONS(3792),
    [anon_sym_POUNDEndif] = ACTIONS(3792),
    [anon_sym_POUNDendif2] = ACTIONS(3792),
    [anon_sym_POUNDENDIF2] = ACTIONS(3792),
    [anon_sym_POUNDEndif2] = ACTIONS(3792),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3792),
    [aux_sym__expression_token1] = ACTIONS(3792),
    [aux_sym__expression_token2] = ACTIONS(3792),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3790),
    [anon_sym_SLASH] = ACTIONS(3790),
    [anon_sym_div] = ACTIONS(3790),
    [anon_sym_DIV] = ACTIONS(3790),
    [anon_sym_Div] = ACTIONS(3790),
    [anon_sym_mod] = ACTIONS(3790),
    [anon_sym_MOD] = ACTIONS(3790),
    [anon_sym_Mod] = ACTIONS(3790),
    [anon_sym_PLUS] = ACTIONS(3790),
    [anon_sym_GT_EQ] = ACTIONS(3792),
    [anon_sym_LT_EQ] = ACTIONS(3792),
    [anon_sym_GT] = ACTIONS(3790),
    [anon_sym_LT] = ACTIONS(3790),
    [anon_sym_LT_GT] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3790),
    [anon_sym_AND] = ACTIONS(3790),
    [anon_sym_And] = ACTIONS(3790),
    [anon_sym_or] = ACTIONS(3790),
    [anon_sym_OR] = ACTIONS(3790),
    [anon_sym_Or] = ACTIONS(3790),
    [anon_sym_xor] = ACTIONS(3790),
    [anon_sym_XOR] = ACTIONS(3790),
    [anon_sym_Xor] = ACTIONS(3790),
    [anon_sym_QMARK] = ACTIONS(3792),
    [sym_datetime_literal] = ACTIONS(3792),
    [sym_date_literal] = ACTIONS(3790),
    [sym_time_literal] = ACTIONS(3790),
    [sym_biginteger_literal] = ACTIONS(3792),
    [anon_sym_else] = ACTIONS(3790),
    [anon_sym_ELSE] = ACTIONS(3790),
    [anon_sym_Else] = ACTIONS(3790),
    [anon_sym_in] = ACTIONS(3790),
    [anon_sym_IN] = ACTIONS(3790),
    [anon_sym_In] = ACTIONS(3790),
    [sym_page_keyword] = ACTIONS(3790),
    [anon_sym_codeunit] = ACTIONS(3790),
    [anon_sym_CODEUNIT] = ACTIONS(3790),
    [anon_sym_Codeunit] = ACTIONS(3790),
    [anon_sym_CodeUnit] = ACTIONS(3790),
    [anon_sym_COdeunit] = ACTIONS(3790),
    [anon_sym_codeUnit] = ACTIONS(3790),
    [sym_report_keyword] = ACTIONS(3790),
    [sym_query_keyword] = ACTIONS(3790),
    [anon_sym_xmlport] = ACTIONS(3790),
    [anon_sym_XMLPORT] = ACTIONS(3790),
    [anon_sym_Xmlport] = ACTIONS(3790),
    [anon_sym_XMLport] = ACTIONS(3790),
    [anon_sym_XMLPort] = ACTIONS(3790),
    [anon_sym_XmlPort] = ACTIONS(3790),
    [anon_sym_enum] = ACTIONS(3790),
    [anon_sym_ENUM] = ACTIONS(3790),
    [anon_sym_Enum] = ACTIONS(3790),
    [anon_sym_eNUM] = ACTIONS(3790),
    [anon_sym_eNum] = ACTIONS(3790),
    [anon_sym_ENum] = ACTIONS(3790),
    [sym_quoted_identifier] = ACTIONS(3792),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3792),
    [sym_verbatim_string] = ACTIONS(3792),
    [sym_integer] = ACTIONS(3790),
    [sym_continue_as_identifier] = ACTIONS(3792),
    [sym_preproc_open] = ACTIONS(3792),
    [sym_preproc_close] = ACTIONS(3792),
  },
  [STATE(2318)] = {
    [sym_identifier] = ACTIONS(3909),
    [anon_sym_SEMI] = ACTIONS(3911),
    [anon_sym_DOT] = ACTIONS(3909),
    [anon_sym_EQ] = ACTIONS(3911),
    [anon_sym_COMMA] = ACTIONS(3911),
    [anon_sym_COLON] = ACTIONS(3909),
    [anon_sym_DASH] = ACTIONS(3909),
    [aux_sym_boolean_token1] = ACTIONS(3909),
    [aux_sym_boolean_token2] = ACTIONS(3909),
    [sym_decimal] = ACTIONS(3909),
    [anon_sym_LPAREN] = ACTIONS(3911),
    [anon_sym_DOT_DOT] = ACTIONS(3911),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3909),
    [anon_sym_STAR] = ACTIONS(3909),
    [anon_sym_LBRACK] = ACTIONS(3911),
    [aux_sym_record_type_token1] = ACTIONS(3909),
    [aux_sym_basic_type_token21] = ACTIONS(3909),
    [aux_sym_basic_type_token22] = ACTIONS(3909),
    [aux_sym_basic_type_token48] = ACTIONS(3909),
    [anon_sym_POUNDif] = ACTIONS(3911),
    [anon_sym_POUNDIF] = ACTIONS(3911),
    [anon_sym_POUNDIf] = ACTIONS(3911),
    [anon_sym_not] = ACTIONS(3909),
    [anon_sym_NOT] = ACTIONS(3909),
    [anon_sym_Not] = ACTIONS(3909),
    [anon_sym_POUNDelif] = ACTIONS(3911),
    [anon_sym_POUNDELIF] = ACTIONS(3911),
    [anon_sym_POUNDElif] = ACTIONS(3911),
    [anon_sym_POUNDelse] = ACTIONS(3911),
    [anon_sym_POUNDELSE] = ACTIONS(3911),
    [anon_sym_POUNDElse] = ACTIONS(3911),
    [anon_sym_POUNDelse2] = ACTIONS(3911),
    [anon_sym_POUNDELSE2] = ACTIONS(3911),
    [anon_sym_POUNDElse2] = ACTIONS(3911),
    [anon_sym_POUNDendif] = ACTIONS(3911),
    [anon_sym_POUNDENDIF] = ACTIONS(3911),
    [anon_sym_POUNDEndif] = ACTIONS(3911),
    [anon_sym_POUNDendif2] = ACTIONS(3911),
    [anon_sym_POUNDENDIF2] = ACTIONS(3911),
    [anon_sym_POUNDEndif2] = ACTIONS(3911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3911),
    [aux_sym__expression_token1] = ACTIONS(3911),
    [aux_sym__expression_token2] = ACTIONS(3911),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3909),
    [anon_sym_SLASH] = ACTIONS(3909),
    [anon_sym_div] = ACTIONS(3909),
    [anon_sym_DIV] = ACTIONS(3909),
    [anon_sym_Div] = ACTIONS(3909),
    [anon_sym_mod] = ACTIONS(3909),
    [anon_sym_MOD] = ACTIONS(3909),
    [anon_sym_Mod] = ACTIONS(3909),
    [anon_sym_PLUS] = ACTIONS(3909),
    [anon_sym_GT_EQ] = ACTIONS(3911),
    [anon_sym_LT_EQ] = ACTIONS(3911),
    [anon_sym_GT] = ACTIONS(3909),
    [anon_sym_LT] = ACTIONS(3909),
    [anon_sym_LT_GT] = ACTIONS(3911),
    [anon_sym_and] = ACTIONS(3909),
    [anon_sym_AND] = ACTIONS(3909),
    [anon_sym_And] = ACTIONS(3909),
    [anon_sym_or] = ACTIONS(3909),
    [anon_sym_OR] = ACTIONS(3909),
    [anon_sym_Or] = ACTIONS(3909),
    [anon_sym_xor] = ACTIONS(3909),
    [anon_sym_XOR] = ACTIONS(3909),
    [anon_sym_Xor] = ACTIONS(3909),
    [anon_sym_QMARK] = ACTIONS(3911),
    [sym_datetime_literal] = ACTIONS(3911),
    [sym_date_literal] = ACTIONS(3909),
    [sym_time_literal] = ACTIONS(3909),
    [sym_biginteger_literal] = ACTIONS(3911),
    [anon_sym_else] = ACTIONS(3909),
    [anon_sym_ELSE] = ACTIONS(3909),
    [anon_sym_Else] = ACTIONS(3909),
    [anon_sym_in] = ACTIONS(3909),
    [anon_sym_IN] = ACTIONS(3909),
    [anon_sym_In] = ACTIONS(3909),
    [sym_page_keyword] = ACTIONS(3909),
    [anon_sym_codeunit] = ACTIONS(3909),
    [anon_sym_CODEUNIT] = ACTIONS(3909),
    [anon_sym_Codeunit] = ACTIONS(3909),
    [anon_sym_CodeUnit] = ACTIONS(3909),
    [anon_sym_COdeunit] = ACTIONS(3909),
    [anon_sym_codeUnit] = ACTIONS(3909),
    [sym_report_keyword] = ACTIONS(3909),
    [sym_query_keyword] = ACTIONS(3909),
    [anon_sym_xmlport] = ACTIONS(3909),
    [anon_sym_XMLPORT] = ACTIONS(3909),
    [anon_sym_Xmlport] = ACTIONS(3909),
    [anon_sym_XMLport] = ACTIONS(3909),
    [anon_sym_XMLPort] = ACTIONS(3909),
    [anon_sym_XmlPort] = ACTIONS(3909),
    [anon_sym_enum] = ACTIONS(3909),
    [anon_sym_ENUM] = ACTIONS(3909),
    [anon_sym_Enum] = ACTIONS(3909),
    [anon_sym_eNUM] = ACTIONS(3909),
    [anon_sym_eNum] = ACTIONS(3909),
    [anon_sym_ENum] = ACTIONS(3909),
    [sym_quoted_identifier] = ACTIONS(3911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3911),
    [sym_verbatim_string] = ACTIONS(3911),
    [sym_integer] = ACTIONS(3909),
    [sym_continue_as_identifier] = ACTIONS(3911),
    [sym_preproc_open] = ACTIONS(3911),
    [sym_preproc_close] = ACTIONS(3911),
  },
  [STATE(2319)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_COLON] = ACTIONS(3873),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(2320)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3734),
    [anon_sym_SEMI] = ACTIONS(3736),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3734),
    [aux_sym_boolean_token2] = ACTIONS(3734),
    [sym_decimal] = ACTIONS(3734),
    [anon_sym_LPAREN] = ACTIONS(3736),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3734),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3734),
    [aux_sym_basic_type_token21] = ACTIONS(3734),
    [aux_sym_basic_type_token22] = ACTIONS(3734),
    [aux_sym_basic_type_token48] = ACTIONS(3734),
    [anon_sym_POUNDif] = ACTIONS(3736),
    [anon_sym_POUNDIF] = ACTIONS(3736),
    [anon_sym_POUNDIf] = ACTIONS(3736),
    [anon_sym_not] = ACTIONS(3734),
    [anon_sym_NOT] = ACTIONS(3734),
    [anon_sym_Not] = ACTIONS(3734),
    [anon_sym_POUNDelif] = ACTIONS(3736),
    [anon_sym_POUNDELIF] = ACTIONS(3736),
    [anon_sym_POUNDElif] = ACTIONS(3736),
    [anon_sym_POUNDelse] = ACTIONS(3736),
    [anon_sym_POUNDELSE] = ACTIONS(3736),
    [anon_sym_POUNDElse] = ACTIONS(3736),
    [anon_sym_POUNDelse2] = ACTIONS(3736),
    [anon_sym_POUNDELSE2] = ACTIONS(3736),
    [anon_sym_POUNDElse2] = ACTIONS(3736),
    [anon_sym_POUNDendif] = ACTIONS(3736),
    [anon_sym_POUNDENDIF] = ACTIONS(3736),
    [anon_sym_POUNDEndif] = ACTIONS(3736),
    [anon_sym_POUNDendif2] = ACTIONS(3736),
    [anon_sym_POUNDENDIF2] = ACTIONS(3736),
    [anon_sym_POUNDEndif2] = ACTIONS(3736),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5307),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3734),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3734),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(5321),
    [anon_sym_OR] = ACTIONS(5323),
    [anon_sym_Or] = ACTIONS(5325),
    [anon_sym_xor] = ACTIONS(5327),
    [anon_sym_XOR] = ACTIONS(5329),
    [anon_sym_Xor] = ACTIONS(5331),
    [anon_sym_QMARK] = ACTIONS(5333),
    [sym_datetime_literal] = ACTIONS(3736),
    [sym_date_literal] = ACTIONS(3734),
    [sym_time_literal] = ACTIONS(3734),
    [sym_biginteger_literal] = ACTIONS(3736),
    [anon_sym_else] = ACTIONS(3734),
    [anon_sym_ELSE] = ACTIONS(3734),
    [anon_sym_Else] = ACTIONS(3734),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3734),
    [anon_sym_codeunit] = ACTIONS(3734),
    [anon_sym_CODEUNIT] = ACTIONS(3734),
    [anon_sym_Codeunit] = ACTIONS(3734),
    [anon_sym_CodeUnit] = ACTIONS(3734),
    [anon_sym_COdeunit] = ACTIONS(3734),
    [anon_sym_codeUnit] = ACTIONS(3734),
    [sym_report_keyword] = ACTIONS(3734),
    [sym_query_keyword] = ACTIONS(3734),
    [anon_sym_xmlport] = ACTIONS(3734),
    [anon_sym_XMLPORT] = ACTIONS(3734),
    [anon_sym_Xmlport] = ACTIONS(3734),
    [anon_sym_XMLport] = ACTIONS(3734),
    [anon_sym_XMLPort] = ACTIONS(3734),
    [anon_sym_XmlPort] = ACTIONS(3734),
    [anon_sym_enum] = ACTIONS(3734),
    [anon_sym_ENUM] = ACTIONS(3734),
    [anon_sym_Enum] = ACTIONS(3734),
    [anon_sym_eNUM] = ACTIONS(3734),
    [anon_sym_eNum] = ACTIONS(3734),
    [anon_sym_ENum] = ACTIONS(3734),
    [sym_quoted_identifier] = ACTIONS(3736),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3736),
    [sym_verbatim_string] = ACTIONS(3736),
    [sym_integer] = ACTIONS(3734),
    [sym_continue_as_identifier] = ACTIONS(3736),
    [sym_preproc_open] = ACTIONS(3736),
    [sym_preproc_close] = ACTIONS(3736),
  },
  [STATE(2321)] = {
    [sym_identifier] = ACTIONS(3941),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_DOT] = ACTIONS(3941),
    [anon_sym_EQ] = ACTIONS(3943),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_COLON] = ACTIONS(3941),
    [anon_sym_DASH] = ACTIONS(3941),
    [aux_sym_boolean_token1] = ACTIONS(3941),
    [aux_sym_boolean_token2] = ACTIONS(3941),
    [sym_decimal] = ACTIONS(3941),
    [anon_sym_LPAREN] = ACTIONS(3943),
    [anon_sym_DOT_DOT] = ACTIONS(3943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3941),
    [anon_sym_STAR] = ACTIONS(3941),
    [anon_sym_LBRACK] = ACTIONS(3943),
    [aux_sym_record_type_token1] = ACTIONS(3941),
    [aux_sym_basic_type_token21] = ACTIONS(3941),
    [aux_sym_basic_type_token22] = ACTIONS(3941),
    [aux_sym_basic_type_token48] = ACTIONS(3941),
    [anon_sym_POUNDif] = ACTIONS(3943),
    [anon_sym_POUNDIF] = ACTIONS(3943),
    [anon_sym_POUNDIf] = ACTIONS(3943),
    [anon_sym_not] = ACTIONS(3941),
    [anon_sym_NOT] = ACTIONS(3941),
    [anon_sym_Not] = ACTIONS(3941),
    [anon_sym_POUNDelif] = ACTIONS(3943),
    [anon_sym_POUNDELIF] = ACTIONS(3943),
    [anon_sym_POUNDElif] = ACTIONS(3943),
    [anon_sym_POUNDelse] = ACTIONS(3943),
    [anon_sym_POUNDELSE] = ACTIONS(3943),
    [anon_sym_POUNDElse] = ACTIONS(3943),
    [anon_sym_POUNDelse2] = ACTIONS(3943),
    [anon_sym_POUNDELSE2] = ACTIONS(3943),
    [anon_sym_POUNDElse2] = ACTIONS(3943),
    [anon_sym_POUNDendif] = ACTIONS(3943),
    [anon_sym_POUNDENDIF] = ACTIONS(3943),
    [anon_sym_POUNDEndif] = ACTIONS(3943),
    [anon_sym_POUNDendif2] = ACTIONS(3943),
    [anon_sym_POUNDENDIF2] = ACTIONS(3943),
    [anon_sym_POUNDEndif2] = ACTIONS(3943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3943),
    [aux_sym__expression_token1] = ACTIONS(3943),
    [aux_sym__expression_token2] = ACTIONS(3943),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3941),
    [anon_sym_SLASH] = ACTIONS(3941),
    [anon_sym_div] = ACTIONS(3941),
    [anon_sym_DIV] = ACTIONS(3941),
    [anon_sym_Div] = ACTIONS(3941),
    [anon_sym_mod] = ACTIONS(3941),
    [anon_sym_MOD] = ACTIONS(3941),
    [anon_sym_Mod] = ACTIONS(3941),
    [anon_sym_PLUS] = ACTIONS(3941),
    [anon_sym_GT_EQ] = ACTIONS(3943),
    [anon_sym_LT_EQ] = ACTIONS(3943),
    [anon_sym_GT] = ACTIONS(3941),
    [anon_sym_LT] = ACTIONS(3941),
    [anon_sym_LT_GT] = ACTIONS(3943),
    [anon_sym_and] = ACTIONS(3941),
    [anon_sym_AND] = ACTIONS(3941),
    [anon_sym_And] = ACTIONS(3941),
    [anon_sym_or] = ACTIONS(3941),
    [anon_sym_OR] = ACTIONS(3941),
    [anon_sym_Or] = ACTIONS(3941),
    [anon_sym_xor] = ACTIONS(3941),
    [anon_sym_XOR] = ACTIONS(3941),
    [anon_sym_Xor] = ACTIONS(3941),
    [anon_sym_QMARK] = ACTIONS(3943),
    [sym_datetime_literal] = ACTIONS(3943),
    [sym_date_literal] = ACTIONS(3941),
    [sym_time_literal] = ACTIONS(3941),
    [sym_biginteger_literal] = ACTIONS(3943),
    [anon_sym_else] = ACTIONS(3941),
    [anon_sym_ELSE] = ACTIONS(3941),
    [anon_sym_Else] = ACTIONS(3941),
    [anon_sym_in] = ACTIONS(3941),
    [anon_sym_IN] = ACTIONS(3941),
    [anon_sym_In] = ACTIONS(3941),
    [sym_page_keyword] = ACTIONS(3941),
    [anon_sym_codeunit] = ACTIONS(3941),
    [anon_sym_CODEUNIT] = ACTIONS(3941),
    [anon_sym_Codeunit] = ACTIONS(3941),
    [anon_sym_CodeUnit] = ACTIONS(3941),
    [anon_sym_COdeunit] = ACTIONS(3941),
    [anon_sym_codeUnit] = ACTIONS(3941),
    [sym_report_keyword] = ACTIONS(3941),
    [sym_query_keyword] = ACTIONS(3941),
    [anon_sym_xmlport] = ACTIONS(3941),
    [anon_sym_XMLPORT] = ACTIONS(3941),
    [anon_sym_Xmlport] = ACTIONS(3941),
    [anon_sym_XMLport] = ACTIONS(3941),
    [anon_sym_XMLPort] = ACTIONS(3941),
    [anon_sym_XmlPort] = ACTIONS(3941),
    [anon_sym_enum] = ACTIONS(3941),
    [anon_sym_ENUM] = ACTIONS(3941),
    [anon_sym_Enum] = ACTIONS(3941),
    [anon_sym_eNUM] = ACTIONS(3941),
    [anon_sym_eNum] = ACTIONS(3941),
    [anon_sym_ENum] = ACTIONS(3941),
    [sym_quoted_identifier] = ACTIONS(3943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3943),
    [sym_verbatim_string] = ACTIONS(3943),
    [sym_integer] = ACTIONS(3941),
    [sym_continue_as_identifier] = ACTIONS(3943),
    [sym_preproc_open] = ACTIONS(3943),
    [sym_preproc_close] = ACTIONS(3943),
  },
  [STATE(2322)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_COLON] = ACTIONS(3873),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(2323)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_COLON] = ACTIONS(3663),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(2324)] = {
    [sym_identifier] = ACTIONS(3885),
    [anon_sym_SEMI] = ACTIONS(3887),
    [anon_sym_DOT] = ACTIONS(3885),
    [anon_sym_EQ] = ACTIONS(3887),
    [anon_sym_COMMA] = ACTIONS(3887),
    [anon_sym_COLON] = ACTIONS(3885),
    [anon_sym_DASH] = ACTIONS(3885),
    [aux_sym_boolean_token1] = ACTIONS(3885),
    [aux_sym_boolean_token2] = ACTIONS(3885),
    [sym_decimal] = ACTIONS(3885),
    [anon_sym_LPAREN] = ACTIONS(3887),
    [anon_sym_DOT_DOT] = ACTIONS(3887),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3885),
    [anon_sym_STAR] = ACTIONS(3885),
    [anon_sym_LBRACK] = ACTIONS(3887),
    [aux_sym_record_type_token1] = ACTIONS(3885),
    [aux_sym_basic_type_token21] = ACTIONS(3885),
    [aux_sym_basic_type_token22] = ACTIONS(3885),
    [aux_sym_basic_type_token48] = ACTIONS(3885),
    [anon_sym_POUNDif] = ACTIONS(3887),
    [anon_sym_POUNDIF] = ACTIONS(3887),
    [anon_sym_POUNDIf] = ACTIONS(3887),
    [anon_sym_not] = ACTIONS(3885),
    [anon_sym_NOT] = ACTIONS(3885),
    [anon_sym_Not] = ACTIONS(3885),
    [anon_sym_POUNDelif] = ACTIONS(3887),
    [anon_sym_POUNDELIF] = ACTIONS(3887),
    [anon_sym_POUNDElif] = ACTIONS(3887),
    [anon_sym_POUNDelse] = ACTIONS(3887),
    [anon_sym_POUNDELSE] = ACTIONS(3887),
    [anon_sym_POUNDElse] = ACTIONS(3887),
    [anon_sym_POUNDelse2] = ACTIONS(3887),
    [anon_sym_POUNDELSE2] = ACTIONS(3887),
    [anon_sym_POUNDElse2] = ACTIONS(3887),
    [anon_sym_POUNDendif] = ACTIONS(3887),
    [anon_sym_POUNDENDIF] = ACTIONS(3887),
    [anon_sym_POUNDEndif] = ACTIONS(3887),
    [anon_sym_POUNDendif2] = ACTIONS(3887),
    [anon_sym_POUNDENDIF2] = ACTIONS(3887),
    [anon_sym_POUNDEndif2] = ACTIONS(3887),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3887),
    [aux_sym__expression_token1] = ACTIONS(3887),
    [aux_sym__expression_token2] = ACTIONS(3887),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3885),
    [anon_sym_SLASH] = ACTIONS(3885),
    [anon_sym_div] = ACTIONS(3885),
    [anon_sym_DIV] = ACTIONS(3885),
    [anon_sym_Div] = ACTIONS(3885),
    [anon_sym_mod] = ACTIONS(3885),
    [anon_sym_MOD] = ACTIONS(3885),
    [anon_sym_Mod] = ACTIONS(3885),
    [anon_sym_PLUS] = ACTIONS(3885),
    [anon_sym_GT_EQ] = ACTIONS(3887),
    [anon_sym_LT_EQ] = ACTIONS(3887),
    [anon_sym_GT] = ACTIONS(3885),
    [anon_sym_LT] = ACTIONS(3885),
    [anon_sym_LT_GT] = ACTIONS(3887),
    [anon_sym_and] = ACTIONS(3885),
    [anon_sym_AND] = ACTIONS(3885),
    [anon_sym_And] = ACTIONS(3885),
    [anon_sym_or] = ACTIONS(3885),
    [anon_sym_OR] = ACTIONS(3885),
    [anon_sym_Or] = ACTIONS(3885),
    [anon_sym_xor] = ACTIONS(3885),
    [anon_sym_XOR] = ACTIONS(3885),
    [anon_sym_Xor] = ACTIONS(3885),
    [anon_sym_QMARK] = ACTIONS(3887),
    [sym_datetime_literal] = ACTIONS(3887),
    [sym_date_literal] = ACTIONS(3885),
    [sym_time_literal] = ACTIONS(3885),
    [sym_biginteger_literal] = ACTIONS(3887),
    [anon_sym_else] = ACTIONS(3885),
    [anon_sym_ELSE] = ACTIONS(3885),
    [anon_sym_Else] = ACTIONS(3885),
    [anon_sym_in] = ACTIONS(3885),
    [anon_sym_IN] = ACTIONS(3885),
    [anon_sym_In] = ACTIONS(3885),
    [sym_page_keyword] = ACTIONS(3885),
    [anon_sym_codeunit] = ACTIONS(3885),
    [anon_sym_CODEUNIT] = ACTIONS(3885),
    [anon_sym_Codeunit] = ACTIONS(3885),
    [anon_sym_CodeUnit] = ACTIONS(3885),
    [anon_sym_COdeunit] = ACTIONS(3885),
    [anon_sym_codeUnit] = ACTIONS(3885),
    [sym_report_keyword] = ACTIONS(3885),
    [sym_query_keyword] = ACTIONS(3885),
    [anon_sym_xmlport] = ACTIONS(3885),
    [anon_sym_XMLPORT] = ACTIONS(3885),
    [anon_sym_Xmlport] = ACTIONS(3885),
    [anon_sym_XMLport] = ACTIONS(3885),
    [anon_sym_XMLPort] = ACTIONS(3885),
    [anon_sym_XmlPort] = ACTIONS(3885),
    [anon_sym_enum] = ACTIONS(3885),
    [anon_sym_ENUM] = ACTIONS(3885),
    [anon_sym_Enum] = ACTIONS(3885),
    [anon_sym_eNUM] = ACTIONS(3885),
    [anon_sym_eNum] = ACTIONS(3885),
    [anon_sym_ENum] = ACTIONS(3885),
    [sym_quoted_identifier] = ACTIONS(3887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3887),
    [sym_verbatim_string] = ACTIONS(3887),
    [sym_integer] = ACTIONS(3885),
    [sym_continue_as_identifier] = ACTIONS(3887),
    [sym_preproc_open] = ACTIONS(3887),
    [sym_preproc_close] = ACTIONS(3887),
  },
  [STATE(2325)] = {
    [sym_identifier] = ACTIONS(3945),
    [anon_sym_SEMI] = ACTIONS(3947),
    [anon_sym_DOT] = ACTIONS(3945),
    [anon_sym_EQ] = ACTIONS(3947),
    [anon_sym_COMMA] = ACTIONS(3947),
    [anon_sym_COLON] = ACTIONS(3945),
    [anon_sym_DASH] = ACTIONS(3945),
    [aux_sym_boolean_token1] = ACTIONS(3945),
    [aux_sym_boolean_token2] = ACTIONS(3945),
    [sym_decimal] = ACTIONS(3945),
    [anon_sym_LPAREN] = ACTIONS(3947),
    [anon_sym_DOT_DOT] = ACTIONS(3947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3945),
    [anon_sym_STAR] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(3947),
    [aux_sym_record_type_token1] = ACTIONS(3945),
    [aux_sym_basic_type_token21] = ACTIONS(3945),
    [aux_sym_basic_type_token22] = ACTIONS(3945),
    [aux_sym_basic_type_token48] = ACTIONS(3945),
    [anon_sym_POUNDif] = ACTIONS(3947),
    [anon_sym_POUNDIF] = ACTIONS(3947),
    [anon_sym_POUNDIf] = ACTIONS(3947),
    [anon_sym_not] = ACTIONS(3945),
    [anon_sym_NOT] = ACTIONS(3945),
    [anon_sym_Not] = ACTIONS(3945),
    [anon_sym_POUNDelif] = ACTIONS(3947),
    [anon_sym_POUNDELIF] = ACTIONS(3947),
    [anon_sym_POUNDElif] = ACTIONS(3947),
    [anon_sym_POUNDelse] = ACTIONS(3947),
    [anon_sym_POUNDELSE] = ACTIONS(3947),
    [anon_sym_POUNDElse] = ACTIONS(3947),
    [anon_sym_POUNDelse2] = ACTIONS(3947),
    [anon_sym_POUNDELSE2] = ACTIONS(3947),
    [anon_sym_POUNDElse2] = ACTIONS(3947),
    [anon_sym_POUNDendif] = ACTIONS(3947),
    [anon_sym_POUNDENDIF] = ACTIONS(3947),
    [anon_sym_POUNDEndif] = ACTIONS(3947),
    [anon_sym_POUNDendif2] = ACTIONS(3947),
    [anon_sym_POUNDENDIF2] = ACTIONS(3947),
    [anon_sym_POUNDEndif2] = ACTIONS(3947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3947),
    [aux_sym__expression_token1] = ACTIONS(3947),
    [aux_sym__expression_token2] = ACTIONS(3947),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3945),
    [anon_sym_SLASH] = ACTIONS(3945),
    [anon_sym_div] = ACTIONS(3945),
    [anon_sym_DIV] = ACTIONS(3945),
    [anon_sym_Div] = ACTIONS(3945),
    [anon_sym_mod] = ACTIONS(3945),
    [anon_sym_MOD] = ACTIONS(3945),
    [anon_sym_Mod] = ACTIONS(3945),
    [anon_sym_PLUS] = ACTIONS(3945),
    [anon_sym_GT_EQ] = ACTIONS(3947),
    [anon_sym_LT_EQ] = ACTIONS(3947),
    [anon_sym_GT] = ACTIONS(3945),
    [anon_sym_LT] = ACTIONS(3945),
    [anon_sym_LT_GT] = ACTIONS(3947),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_AND] = ACTIONS(3945),
    [anon_sym_And] = ACTIONS(3945),
    [anon_sym_or] = ACTIONS(3945),
    [anon_sym_OR] = ACTIONS(3945),
    [anon_sym_Or] = ACTIONS(3945),
    [anon_sym_xor] = ACTIONS(3945),
    [anon_sym_XOR] = ACTIONS(3945),
    [anon_sym_Xor] = ACTIONS(3945),
    [anon_sym_QMARK] = ACTIONS(3947),
    [sym_datetime_literal] = ACTIONS(3947),
    [sym_date_literal] = ACTIONS(3945),
    [sym_time_literal] = ACTIONS(3945),
    [sym_biginteger_literal] = ACTIONS(3947),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_ELSE] = ACTIONS(3945),
    [anon_sym_Else] = ACTIONS(3945),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_IN] = ACTIONS(3945),
    [anon_sym_In] = ACTIONS(3945),
    [sym_page_keyword] = ACTIONS(3945),
    [anon_sym_codeunit] = ACTIONS(3945),
    [anon_sym_CODEUNIT] = ACTIONS(3945),
    [anon_sym_Codeunit] = ACTIONS(3945),
    [anon_sym_CodeUnit] = ACTIONS(3945),
    [anon_sym_COdeunit] = ACTIONS(3945),
    [anon_sym_codeUnit] = ACTIONS(3945),
    [sym_report_keyword] = ACTIONS(3945),
    [sym_query_keyword] = ACTIONS(3945),
    [anon_sym_xmlport] = ACTIONS(3945),
    [anon_sym_XMLPORT] = ACTIONS(3945),
    [anon_sym_Xmlport] = ACTIONS(3945),
    [anon_sym_XMLport] = ACTIONS(3945),
    [anon_sym_XMLPort] = ACTIONS(3945),
    [anon_sym_XmlPort] = ACTIONS(3945),
    [anon_sym_enum] = ACTIONS(3945),
    [anon_sym_ENUM] = ACTIONS(3945),
    [anon_sym_Enum] = ACTIONS(3945),
    [anon_sym_eNUM] = ACTIONS(3945),
    [anon_sym_eNum] = ACTIONS(3945),
    [anon_sym_ENum] = ACTIONS(3945),
    [sym_quoted_identifier] = ACTIONS(3947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3947),
    [sym_verbatim_string] = ACTIONS(3947),
    [sym_integer] = ACTIONS(3945),
    [sym_continue_as_identifier] = ACTIONS(3947),
    [sym_preproc_open] = ACTIONS(3947),
    [sym_preproc_close] = ACTIONS(3947),
  },
  [STATE(2326)] = {
    [sym_identifier] = ACTIONS(3738),
    [anon_sym_SEMI] = ACTIONS(3740),
    [anon_sym_DOT] = ACTIONS(3738),
    [anon_sym_EQ] = ACTIONS(3740),
    [anon_sym_COMMA] = ACTIONS(3740),
    [anon_sym_COLON] = ACTIONS(3738),
    [anon_sym_DASH] = ACTIONS(3738),
    [aux_sym_boolean_token1] = ACTIONS(3738),
    [aux_sym_boolean_token2] = ACTIONS(3738),
    [sym_decimal] = ACTIONS(3738),
    [anon_sym_LPAREN] = ACTIONS(3740),
    [anon_sym_DOT_DOT] = ACTIONS(3740),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3738),
    [anon_sym_STAR] = ACTIONS(3738),
    [anon_sym_LBRACK] = ACTIONS(3740),
    [aux_sym_record_type_token1] = ACTIONS(3738),
    [aux_sym_basic_type_token21] = ACTIONS(3738),
    [aux_sym_basic_type_token22] = ACTIONS(3738),
    [aux_sym_basic_type_token48] = ACTIONS(3738),
    [anon_sym_POUNDif] = ACTIONS(3740),
    [anon_sym_POUNDIF] = ACTIONS(3740),
    [anon_sym_POUNDIf] = ACTIONS(3740),
    [anon_sym_not] = ACTIONS(3738),
    [anon_sym_NOT] = ACTIONS(3738),
    [anon_sym_Not] = ACTIONS(3738),
    [anon_sym_POUNDelif] = ACTIONS(3740),
    [anon_sym_POUNDELIF] = ACTIONS(3740),
    [anon_sym_POUNDElif] = ACTIONS(3740),
    [anon_sym_POUNDelse] = ACTIONS(3740),
    [anon_sym_POUNDELSE] = ACTIONS(3740),
    [anon_sym_POUNDElse] = ACTIONS(3740),
    [anon_sym_POUNDelse2] = ACTIONS(3740),
    [anon_sym_POUNDELSE2] = ACTIONS(3740),
    [anon_sym_POUNDElse2] = ACTIONS(3740),
    [anon_sym_POUNDendif] = ACTIONS(3740),
    [anon_sym_POUNDENDIF] = ACTIONS(3740),
    [anon_sym_POUNDEndif] = ACTIONS(3740),
    [anon_sym_POUNDendif2] = ACTIONS(3740),
    [anon_sym_POUNDENDIF2] = ACTIONS(3740),
    [anon_sym_POUNDEndif2] = ACTIONS(3740),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3740),
    [aux_sym__expression_token1] = ACTIONS(3740),
    [aux_sym__expression_token2] = ACTIONS(3740),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3738),
    [anon_sym_SLASH] = ACTIONS(3738),
    [anon_sym_div] = ACTIONS(3738),
    [anon_sym_DIV] = ACTIONS(3738),
    [anon_sym_Div] = ACTIONS(3738),
    [anon_sym_mod] = ACTIONS(3738),
    [anon_sym_MOD] = ACTIONS(3738),
    [anon_sym_Mod] = ACTIONS(3738),
    [anon_sym_PLUS] = ACTIONS(3738),
    [anon_sym_GT_EQ] = ACTIONS(3740),
    [anon_sym_LT_EQ] = ACTIONS(3740),
    [anon_sym_GT] = ACTIONS(3738),
    [anon_sym_LT] = ACTIONS(3738),
    [anon_sym_LT_GT] = ACTIONS(3740),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3738),
    [anon_sym_And] = ACTIONS(3738),
    [anon_sym_or] = ACTIONS(3738),
    [anon_sym_OR] = ACTIONS(3738),
    [anon_sym_Or] = ACTIONS(3738),
    [anon_sym_xor] = ACTIONS(3738),
    [anon_sym_XOR] = ACTIONS(3738),
    [anon_sym_Xor] = ACTIONS(3738),
    [anon_sym_QMARK] = ACTIONS(3740),
    [sym_datetime_literal] = ACTIONS(3740),
    [sym_date_literal] = ACTIONS(3738),
    [sym_time_literal] = ACTIONS(3738),
    [sym_biginteger_literal] = ACTIONS(3740),
    [anon_sym_else] = ACTIONS(3738),
    [anon_sym_ELSE] = ACTIONS(3738),
    [anon_sym_Else] = ACTIONS(3738),
    [anon_sym_in] = ACTIONS(3738),
    [anon_sym_IN] = ACTIONS(3738),
    [anon_sym_In] = ACTIONS(3738),
    [sym_page_keyword] = ACTIONS(3738),
    [anon_sym_codeunit] = ACTIONS(3738),
    [anon_sym_CODEUNIT] = ACTIONS(3738),
    [anon_sym_Codeunit] = ACTIONS(3738),
    [anon_sym_CodeUnit] = ACTIONS(3738),
    [anon_sym_COdeunit] = ACTIONS(3738),
    [anon_sym_codeUnit] = ACTIONS(3738),
    [sym_report_keyword] = ACTIONS(3738),
    [sym_query_keyword] = ACTIONS(3738),
    [anon_sym_xmlport] = ACTIONS(3738),
    [anon_sym_XMLPORT] = ACTIONS(3738),
    [anon_sym_Xmlport] = ACTIONS(3738),
    [anon_sym_XMLport] = ACTIONS(3738),
    [anon_sym_XMLPort] = ACTIONS(3738),
    [anon_sym_XmlPort] = ACTIONS(3738),
    [anon_sym_enum] = ACTIONS(3738),
    [anon_sym_ENUM] = ACTIONS(3738),
    [anon_sym_Enum] = ACTIONS(3738),
    [anon_sym_eNUM] = ACTIONS(3738),
    [anon_sym_eNum] = ACTIONS(3738),
    [anon_sym_ENum] = ACTIONS(3738),
    [sym_quoted_identifier] = ACTIONS(3740),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3740),
    [sym_verbatim_string] = ACTIONS(3740),
    [sym_integer] = ACTIONS(3738),
    [sym_continue_as_identifier] = ACTIONS(3740),
    [sym_preproc_open] = ACTIONS(3740),
    [sym_preproc_close] = ACTIONS(3740),
  },
  [STATE(2327)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_COLON] = ACTIONS(3873),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(2328)] = {
    [sym_identifier] = ACTIONS(3937),
    [anon_sym_SEMI] = ACTIONS(3939),
    [anon_sym_DOT] = ACTIONS(3937),
    [anon_sym_EQ] = ACTIONS(3939),
    [anon_sym_COMMA] = ACTIONS(3939),
    [anon_sym_COLON] = ACTIONS(3937),
    [anon_sym_DASH] = ACTIONS(3937),
    [aux_sym_boolean_token1] = ACTIONS(3937),
    [aux_sym_boolean_token2] = ACTIONS(3937),
    [sym_decimal] = ACTIONS(3937),
    [anon_sym_LPAREN] = ACTIONS(3939),
    [anon_sym_DOT_DOT] = ACTIONS(3939),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3937),
    [anon_sym_STAR] = ACTIONS(3937),
    [anon_sym_LBRACK] = ACTIONS(3939),
    [aux_sym_record_type_token1] = ACTIONS(3937),
    [aux_sym_basic_type_token21] = ACTIONS(3937),
    [aux_sym_basic_type_token22] = ACTIONS(3937),
    [aux_sym_basic_type_token48] = ACTIONS(3937),
    [anon_sym_POUNDif] = ACTIONS(3939),
    [anon_sym_POUNDIF] = ACTIONS(3939),
    [anon_sym_POUNDIf] = ACTIONS(3939),
    [anon_sym_not] = ACTIONS(3937),
    [anon_sym_NOT] = ACTIONS(3937),
    [anon_sym_Not] = ACTIONS(3937),
    [anon_sym_POUNDelif] = ACTIONS(3939),
    [anon_sym_POUNDELIF] = ACTIONS(3939),
    [anon_sym_POUNDElif] = ACTIONS(3939),
    [anon_sym_POUNDelse] = ACTIONS(3939),
    [anon_sym_POUNDELSE] = ACTIONS(3939),
    [anon_sym_POUNDElse] = ACTIONS(3939),
    [anon_sym_POUNDelse2] = ACTIONS(3939),
    [anon_sym_POUNDELSE2] = ACTIONS(3939),
    [anon_sym_POUNDElse2] = ACTIONS(3939),
    [anon_sym_POUNDendif] = ACTIONS(3939),
    [anon_sym_POUNDENDIF] = ACTIONS(3939),
    [anon_sym_POUNDEndif] = ACTIONS(3939),
    [anon_sym_POUNDendif2] = ACTIONS(3939),
    [anon_sym_POUNDENDIF2] = ACTIONS(3939),
    [anon_sym_POUNDEndif2] = ACTIONS(3939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3939),
    [aux_sym__expression_token1] = ACTIONS(3939),
    [aux_sym__expression_token2] = ACTIONS(3939),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3937),
    [anon_sym_SLASH] = ACTIONS(3937),
    [anon_sym_div] = ACTIONS(3937),
    [anon_sym_DIV] = ACTIONS(3937),
    [anon_sym_Div] = ACTIONS(3937),
    [anon_sym_mod] = ACTIONS(3937),
    [anon_sym_MOD] = ACTIONS(3937),
    [anon_sym_Mod] = ACTIONS(3937),
    [anon_sym_PLUS] = ACTIONS(3937),
    [anon_sym_GT_EQ] = ACTIONS(3939),
    [anon_sym_LT_EQ] = ACTIONS(3939),
    [anon_sym_GT] = ACTIONS(3937),
    [anon_sym_LT] = ACTIONS(3937),
    [anon_sym_LT_GT] = ACTIONS(3939),
    [anon_sym_and] = ACTIONS(3937),
    [anon_sym_AND] = ACTIONS(3937),
    [anon_sym_And] = ACTIONS(3937),
    [anon_sym_or] = ACTIONS(3937),
    [anon_sym_OR] = ACTIONS(3937),
    [anon_sym_Or] = ACTIONS(3937),
    [anon_sym_xor] = ACTIONS(3937),
    [anon_sym_XOR] = ACTIONS(3937),
    [anon_sym_Xor] = ACTIONS(3937),
    [anon_sym_QMARK] = ACTIONS(3939),
    [sym_datetime_literal] = ACTIONS(3939),
    [sym_date_literal] = ACTIONS(3937),
    [sym_time_literal] = ACTIONS(3937),
    [sym_biginteger_literal] = ACTIONS(3939),
    [anon_sym_else] = ACTIONS(3937),
    [anon_sym_ELSE] = ACTIONS(3937),
    [anon_sym_Else] = ACTIONS(3937),
    [anon_sym_in] = ACTIONS(3937),
    [anon_sym_IN] = ACTIONS(3937),
    [anon_sym_In] = ACTIONS(3937),
    [sym_page_keyword] = ACTIONS(3937),
    [anon_sym_codeunit] = ACTIONS(3937),
    [anon_sym_CODEUNIT] = ACTIONS(3937),
    [anon_sym_Codeunit] = ACTIONS(3937),
    [anon_sym_CodeUnit] = ACTIONS(3937),
    [anon_sym_COdeunit] = ACTIONS(3937),
    [anon_sym_codeUnit] = ACTIONS(3937),
    [sym_report_keyword] = ACTIONS(3937),
    [sym_query_keyword] = ACTIONS(3937),
    [anon_sym_xmlport] = ACTIONS(3937),
    [anon_sym_XMLPORT] = ACTIONS(3937),
    [anon_sym_Xmlport] = ACTIONS(3937),
    [anon_sym_XMLport] = ACTIONS(3937),
    [anon_sym_XMLPort] = ACTIONS(3937),
    [anon_sym_XmlPort] = ACTIONS(3937),
    [anon_sym_enum] = ACTIONS(3937),
    [anon_sym_ENUM] = ACTIONS(3937),
    [anon_sym_Enum] = ACTIONS(3937),
    [anon_sym_eNUM] = ACTIONS(3937),
    [anon_sym_eNum] = ACTIONS(3937),
    [anon_sym_ENum] = ACTIONS(3937),
    [sym_quoted_identifier] = ACTIONS(3939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3939),
    [sym_verbatim_string] = ACTIONS(3939),
    [sym_integer] = ACTIONS(3937),
    [sym_continue_as_identifier] = ACTIONS(3939),
    [sym_preproc_open] = ACTIONS(3939),
    [sym_preproc_close] = ACTIONS(3939),
  },
  [STATE(2329)] = {
    [sym_identifier] = ACTIONS(3877),
    [anon_sym_SEMI] = ACTIONS(3879),
    [anon_sym_DOT] = ACTIONS(3877),
    [anon_sym_EQ] = ACTIONS(3879),
    [anon_sym_COMMA] = ACTIONS(3879),
    [anon_sym_COLON] = ACTIONS(3877),
    [anon_sym_DASH] = ACTIONS(3877),
    [aux_sym_boolean_token1] = ACTIONS(3877),
    [aux_sym_boolean_token2] = ACTIONS(3877),
    [sym_decimal] = ACTIONS(3877),
    [anon_sym_LPAREN] = ACTIONS(3879),
    [anon_sym_DOT_DOT] = ACTIONS(3879),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3877),
    [anon_sym_STAR] = ACTIONS(3877),
    [anon_sym_LBRACK] = ACTIONS(3879),
    [aux_sym_record_type_token1] = ACTIONS(3877),
    [aux_sym_basic_type_token21] = ACTIONS(3877),
    [aux_sym_basic_type_token22] = ACTIONS(3877),
    [aux_sym_basic_type_token48] = ACTIONS(3877),
    [anon_sym_POUNDif] = ACTIONS(3879),
    [anon_sym_POUNDIF] = ACTIONS(3879),
    [anon_sym_POUNDIf] = ACTIONS(3879),
    [anon_sym_not] = ACTIONS(3877),
    [anon_sym_NOT] = ACTIONS(3877),
    [anon_sym_Not] = ACTIONS(3877),
    [anon_sym_POUNDelif] = ACTIONS(3879),
    [anon_sym_POUNDELIF] = ACTIONS(3879),
    [anon_sym_POUNDElif] = ACTIONS(3879),
    [anon_sym_POUNDelse] = ACTIONS(3879),
    [anon_sym_POUNDELSE] = ACTIONS(3879),
    [anon_sym_POUNDElse] = ACTIONS(3879),
    [anon_sym_POUNDelse2] = ACTIONS(3879),
    [anon_sym_POUNDELSE2] = ACTIONS(3879),
    [anon_sym_POUNDElse2] = ACTIONS(3879),
    [anon_sym_POUNDendif] = ACTIONS(3879),
    [anon_sym_POUNDENDIF] = ACTIONS(3879),
    [anon_sym_POUNDEndif] = ACTIONS(3879),
    [anon_sym_POUNDendif2] = ACTIONS(3879),
    [anon_sym_POUNDENDIF2] = ACTIONS(3879),
    [anon_sym_POUNDEndif2] = ACTIONS(3879),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3879),
    [aux_sym__expression_token1] = ACTIONS(3879),
    [aux_sym__expression_token2] = ACTIONS(3879),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3877),
    [anon_sym_SLASH] = ACTIONS(3877),
    [anon_sym_div] = ACTIONS(3877),
    [anon_sym_DIV] = ACTIONS(3877),
    [anon_sym_Div] = ACTIONS(3877),
    [anon_sym_mod] = ACTIONS(3877),
    [anon_sym_MOD] = ACTIONS(3877),
    [anon_sym_Mod] = ACTIONS(3877),
    [anon_sym_PLUS] = ACTIONS(3877),
    [anon_sym_GT_EQ] = ACTIONS(3879),
    [anon_sym_LT_EQ] = ACTIONS(3879),
    [anon_sym_GT] = ACTIONS(3877),
    [anon_sym_LT] = ACTIONS(3877),
    [anon_sym_LT_GT] = ACTIONS(3879),
    [anon_sym_and] = ACTIONS(3877),
    [anon_sym_AND] = ACTIONS(3877),
    [anon_sym_And] = ACTIONS(3877),
    [anon_sym_or] = ACTIONS(3877),
    [anon_sym_OR] = ACTIONS(3877),
    [anon_sym_Or] = ACTIONS(3877),
    [anon_sym_xor] = ACTIONS(3877),
    [anon_sym_XOR] = ACTIONS(3877),
    [anon_sym_Xor] = ACTIONS(3877),
    [anon_sym_QMARK] = ACTIONS(3879),
    [sym_datetime_literal] = ACTIONS(3879),
    [sym_date_literal] = ACTIONS(3877),
    [sym_time_literal] = ACTIONS(3877),
    [sym_biginteger_literal] = ACTIONS(3879),
    [anon_sym_else] = ACTIONS(3877),
    [anon_sym_ELSE] = ACTIONS(3877),
    [anon_sym_Else] = ACTIONS(3877),
    [anon_sym_in] = ACTIONS(3877),
    [anon_sym_IN] = ACTIONS(3877),
    [anon_sym_In] = ACTIONS(3877),
    [sym_page_keyword] = ACTIONS(3877),
    [anon_sym_codeunit] = ACTIONS(3877),
    [anon_sym_CODEUNIT] = ACTIONS(3877),
    [anon_sym_Codeunit] = ACTIONS(3877),
    [anon_sym_CodeUnit] = ACTIONS(3877),
    [anon_sym_COdeunit] = ACTIONS(3877),
    [anon_sym_codeUnit] = ACTIONS(3877),
    [sym_report_keyword] = ACTIONS(3877),
    [sym_query_keyword] = ACTIONS(3877),
    [anon_sym_xmlport] = ACTIONS(3877),
    [anon_sym_XMLPORT] = ACTIONS(3877),
    [anon_sym_Xmlport] = ACTIONS(3877),
    [anon_sym_XMLport] = ACTIONS(3877),
    [anon_sym_XMLPort] = ACTIONS(3877),
    [anon_sym_XmlPort] = ACTIONS(3877),
    [anon_sym_enum] = ACTIONS(3877),
    [anon_sym_ENUM] = ACTIONS(3877),
    [anon_sym_Enum] = ACTIONS(3877),
    [anon_sym_eNUM] = ACTIONS(3877),
    [anon_sym_eNum] = ACTIONS(3877),
    [anon_sym_ENum] = ACTIONS(3877),
    [sym_quoted_identifier] = ACTIONS(3879),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3879),
    [sym_verbatim_string] = ACTIONS(3879),
    [sym_integer] = ACTIONS(3877),
    [sym_continue_as_identifier] = ACTIONS(3879),
    [sym_preproc_open] = ACTIONS(3879),
    [sym_preproc_close] = ACTIONS(3879),
  },
  [STATE(2330)] = {
    [sym_identifier] = ACTIONS(3752),
    [anon_sym_SEMI] = ACTIONS(3754),
    [anon_sym_DOT] = ACTIONS(3752),
    [anon_sym_EQ] = ACTIONS(3754),
    [anon_sym_COMMA] = ACTIONS(3754),
    [anon_sym_COLON] = ACTIONS(3752),
    [anon_sym_DASH] = ACTIONS(3752),
    [aux_sym_boolean_token1] = ACTIONS(3752),
    [aux_sym_boolean_token2] = ACTIONS(3752),
    [sym_decimal] = ACTIONS(3752),
    [anon_sym_LPAREN] = ACTIONS(3754),
    [anon_sym_DOT_DOT] = ACTIONS(3754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3752),
    [anon_sym_STAR] = ACTIONS(3752),
    [anon_sym_LBRACK] = ACTIONS(3754),
    [aux_sym_record_type_token1] = ACTIONS(3752),
    [aux_sym_basic_type_token21] = ACTIONS(3752),
    [aux_sym_basic_type_token22] = ACTIONS(3752),
    [aux_sym_basic_type_token48] = ACTIONS(3752),
    [anon_sym_POUNDif] = ACTIONS(3754),
    [anon_sym_POUNDIF] = ACTIONS(3754),
    [anon_sym_POUNDIf] = ACTIONS(3754),
    [anon_sym_not] = ACTIONS(3752),
    [anon_sym_NOT] = ACTIONS(3752),
    [anon_sym_Not] = ACTIONS(3752),
    [anon_sym_POUNDelif] = ACTIONS(3754),
    [anon_sym_POUNDELIF] = ACTIONS(3754),
    [anon_sym_POUNDElif] = ACTIONS(3754),
    [anon_sym_POUNDelse] = ACTIONS(3754),
    [anon_sym_POUNDELSE] = ACTIONS(3754),
    [anon_sym_POUNDElse] = ACTIONS(3754),
    [anon_sym_POUNDelse2] = ACTIONS(3754),
    [anon_sym_POUNDELSE2] = ACTIONS(3754),
    [anon_sym_POUNDElse2] = ACTIONS(3754),
    [anon_sym_POUNDendif] = ACTIONS(3754),
    [anon_sym_POUNDENDIF] = ACTIONS(3754),
    [anon_sym_POUNDEndif] = ACTIONS(3754),
    [anon_sym_POUNDendif2] = ACTIONS(3754),
    [anon_sym_POUNDENDIF2] = ACTIONS(3754),
    [anon_sym_POUNDEndif2] = ACTIONS(3754),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3754),
    [aux_sym__expression_token1] = ACTIONS(3754),
    [aux_sym__expression_token2] = ACTIONS(3754),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3752),
    [anon_sym_SLASH] = ACTIONS(3752),
    [anon_sym_div] = ACTIONS(3752),
    [anon_sym_DIV] = ACTIONS(3752),
    [anon_sym_Div] = ACTIONS(3752),
    [anon_sym_mod] = ACTIONS(3752),
    [anon_sym_MOD] = ACTIONS(3752),
    [anon_sym_Mod] = ACTIONS(3752),
    [anon_sym_PLUS] = ACTIONS(3752),
    [anon_sym_GT_EQ] = ACTIONS(3754),
    [anon_sym_LT_EQ] = ACTIONS(3754),
    [anon_sym_GT] = ACTIONS(3752),
    [anon_sym_LT] = ACTIONS(3752),
    [anon_sym_LT_GT] = ACTIONS(3754),
    [anon_sym_and] = ACTIONS(3752),
    [anon_sym_AND] = ACTIONS(3752),
    [anon_sym_And] = ACTIONS(3752),
    [anon_sym_or] = ACTIONS(3752),
    [anon_sym_OR] = ACTIONS(3752),
    [anon_sym_Or] = ACTIONS(3752),
    [anon_sym_xor] = ACTIONS(3752),
    [anon_sym_XOR] = ACTIONS(3752),
    [anon_sym_Xor] = ACTIONS(3752),
    [anon_sym_QMARK] = ACTIONS(3754),
    [sym_datetime_literal] = ACTIONS(3754),
    [sym_date_literal] = ACTIONS(3752),
    [sym_time_literal] = ACTIONS(3752),
    [sym_biginteger_literal] = ACTIONS(3754),
    [anon_sym_else] = ACTIONS(3752),
    [anon_sym_ELSE] = ACTIONS(3752),
    [anon_sym_Else] = ACTIONS(3752),
    [anon_sym_in] = ACTIONS(3752),
    [anon_sym_IN] = ACTIONS(3752),
    [anon_sym_In] = ACTIONS(3752),
    [sym_page_keyword] = ACTIONS(3752),
    [anon_sym_codeunit] = ACTIONS(3752),
    [anon_sym_CODEUNIT] = ACTIONS(3752),
    [anon_sym_Codeunit] = ACTIONS(3752),
    [anon_sym_CodeUnit] = ACTIONS(3752),
    [anon_sym_COdeunit] = ACTIONS(3752),
    [anon_sym_codeUnit] = ACTIONS(3752),
    [sym_report_keyword] = ACTIONS(3752),
    [sym_query_keyword] = ACTIONS(3752),
    [anon_sym_xmlport] = ACTIONS(3752),
    [anon_sym_XMLPORT] = ACTIONS(3752),
    [anon_sym_Xmlport] = ACTIONS(3752),
    [anon_sym_XMLport] = ACTIONS(3752),
    [anon_sym_XMLPort] = ACTIONS(3752),
    [anon_sym_XmlPort] = ACTIONS(3752),
    [anon_sym_enum] = ACTIONS(3752),
    [anon_sym_ENUM] = ACTIONS(3752),
    [anon_sym_Enum] = ACTIONS(3752),
    [anon_sym_eNUM] = ACTIONS(3752),
    [anon_sym_eNum] = ACTIONS(3752),
    [anon_sym_ENum] = ACTIONS(3752),
    [sym_quoted_identifier] = ACTIONS(3754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3754),
    [sym_verbatim_string] = ACTIONS(3754),
    [sym_integer] = ACTIONS(3752),
    [sym_continue_as_identifier] = ACTIONS(3754),
    [sym_preproc_open] = ACTIONS(3754),
    [sym_preproc_close] = ACTIONS(3754),
  },
  [STATE(2331)] = {
    [sym_argument_list] = STATE(7165),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [aux_sym_where_condition_token1] = ACTIONS(5410),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5405),
    [anon_sym_STAR] = ACTIONS(3681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5405),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5405),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_basic_type_token6] = ACTIONS(5410),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5405),
    [aux_sym_addafter_modification_token1] = ACTIONS(5405),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5405),
    [aux_sym_modify_modification_token1] = ACTIONS(5405),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5405),
    [aux_sym_movelast_modification_token1] = ACTIONS(5405),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5405),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [anon_sym_POUNDelif] = ACTIONS(5405),
    [anon_sym_POUNDELIF] = ACTIONS(5405),
    [anon_sym_POUNDElif] = ACTIONS(5405),
    [anon_sym_POUNDelse] = ACTIONS(5405),
    [anon_sym_POUNDELSE] = ACTIONS(5405),
    [anon_sym_POUNDElse] = ACTIONS(5405),
    [anon_sym_POUNDelse2] = ACTIONS(5405),
    [anon_sym_POUNDELSE2] = ACTIONS(5405),
    [anon_sym_POUNDElse2] = ACTIONS(5405),
    [anon_sym_POUNDendif] = ACTIONS(5405),
    [anon_sym_POUNDENDIF] = ACTIONS(5405),
    [anon_sym_POUNDEndif] = ACTIONS(5405),
    [anon_sym_POUNDendif2] = ACTIONS(5405),
    [anon_sym_POUNDENDIF2] = ACTIONS(5405),
    [anon_sym_POUNDEndif2] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5405),
    [sym_trigger_keyword] = ACTIONS(5405),
    [sym_var_keyword] = ACTIONS(5405),
    [sym_local_keyword] = ACTIONS(5405),
    [sym_internal_keyword] = ACTIONS(5405),
    [sym_protected_keyword] = ACTIONS(5405),
    [sym_event_keyword] = ACTIONS(5405),
    [sym_fields_keyword] = ACTIONS(5405),
    [sym_keys_keyword] = ACTIONS(5405),
    [sym_fieldgroups_keyword] = ACTIONS(5405),
    [sym_actions_keyword] = ACTIONS(5405),
    [sym_layout_keyword] = ACTIONS(5405),
    [sym_area_keyword] = ACTIONS(5405),
    [sym_group_keyword] = ACTIONS(5405),
    [sym_repeater_keyword] = ACTIONS(5405),
    [sym_cuegroup_keyword] = ACTIONS(5405),
    [sym_fixed_keyword] = ACTIONS(5405),
    [sym_grid_keyword] = ACTIONS(5405),
    [sym_part_keyword] = ACTIONS(5405),
    [sym_systempart_keyword] = ACTIONS(5405),
    [sym_usercontrol_keyword] = ACTIONS(5405),
    [sym_dataset_keyword] = ACTIONS(5405),
    [sym_elements_keyword] = ACTIONS(5405),
    [sym_dataitem_keyword] = ACTIONS(5405),
    [sym_column_keyword] = ACTIONS(5405),
    [sym_filter_keyword] = ACTIONS(5405),
    [sym_labels_keyword] = ACTIONS(5405),
    [sym_rendering_keyword] = ACTIONS(5405),
    [sym_requestpage_keyword] = ACTIONS(5405),
    [sym_schema_keyword] = ACTIONS(5405),
    [sym_views_keyword] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
    [sym_preproc_close] = ACTIONS(5405),
  },
  [STATE(2332)] = {
    [sym_identifier] = ACTIONS(3925),
    [anon_sym_SEMI] = ACTIONS(3927),
    [anon_sym_DOT] = ACTIONS(3925),
    [anon_sym_EQ] = ACTIONS(3927),
    [anon_sym_COMMA] = ACTIONS(3927),
    [anon_sym_COLON] = ACTIONS(3925),
    [anon_sym_DASH] = ACTIONS(3925),
    [aux_sym_boolean_token1] = ACTIONS(3925),
    [aux_sym_boolean_token2] = ACTIONS(3925),
    [sym_decimal] = ACTIONS(3925),
    [anon_sym_LPAREN] = ACTIONS(3927),
    [anon_sym_DOT_DOT] = ACTIONS(3927),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3925),
    [anon_sym_STAR] = ACTIONS(3925),
    [anon_sym_LBRACK] = ACTIONS(5415),
    [aux_sym_record_type_token1] = ACTIONS(3925),
    [aux_sym_basic_type_token21] = ACTIONS(3925),
    [aux_sym_basic_type_token22] = ACTIONS(3925),
    [aux_sym_basic_type_token48] = ACTIONS(3925),
    [anon_sym_POUNDif] = ACTIONS(3927),
    [anon_sym_POUNDIF] = ACTIONS(3927),
    [anon_sym_POUNDIf] = ACTIONS(3927),
    [anon_sym_not] = ACTIONS(3925),
    [anon_sym_NOT] = ACTIONS(3925),
    [anon_sym_Not] = ACTIONS(3925),
    [anon_sym_POUNDelif] = ACTIONS(3927),
    [anon_sym_POUNDELIF] = ACTIONS(3927),
    [anon_sym_POUNDElif] = ACTIONS(3927),
    [anon_sym_POUNDelse] = ACTIONS(3927),
    [anon_sym_POUNDELSE] = ACTIONS(3927),
    [anon_sym_POUNDElse] = ACTIONS(3927),
    [anon_sym_POUNDelse2] = ACTIONS(3927),
    [anon_sym_POUNDELSE2] = ACTIONS(3927),
    [anon_sym_POUNDElse2] = ACTIONS(3927),
    [anon_sym_POUNDendif] = ACTIONS(3927),
    [anon_sym_POUNDENDIF] = ACTIONS(3927),
    [anon_sym_POUNDEndif] = ACTIONS(3927),
    [anon_sym_POUNDendif2] = ACTIONS(3927),
    [anon_sym_POUNDENDIF2] = ACTIONS(3927),
    [anon_sym_POUNDEndif2] = ACTIONS(3927),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3927),
    [aux_sym__expression_token1] = ACTIONS(3927),
    [aux_sym__expression_token2] = ACTIONS(3927),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3925),
    [anon_sym_SLASH] = ACTIONS(3925),
    [anon_sym_div] = ACTIONS(3925),
    [anon_sym_DIV] = ACTIONS(3925),
    [anon_sym_Div] = ACTIONS(3925),
    [anon_sym_mod] = ACTIONS(3925),
    [anon_sym_MOD] = ACTIONS(3925),
    [anon_sym_Mod] = ACTIONS(3925),
    [anon_sym_PLUS] = ACTIONS(3925),
    [anon_sym_GT_EQ] = ACTIONS(3927),
    [anon_sym_LT_EQ] = ACTIONS(3927),
    [anon_sym_GT] = ACTIONS(3925),
    [anon_sym_LT] = ACTIONS(3925),
    [anon_sym_LT_GT] = ACTIONS(3927),
    [anon_sym_and] = ACTIONS(3925),
    [anon_sym_AND] = ACTIONS(3925),
    [anon_sym_And] = ACTIONS(3925),
    [anon_sym_or] = ACTIONS(3925),
    [anon_sym_OR] = ACTIONS(3925),
    [anon_sym_Or] = ACTIONS(3925),
    [anon_sym_xor] = ACTIONS(3925),
    [anon_sym_XOR] = ACTIONS(3925),
    [anon_sym_Xor] = ACTIONS(3925),
    [anon_sym_QMARK] = ACTIONS(3927),
    [sym_datetime_literal] = ACTIONS(3927),
    [sym_date_literal] = ACTIONS(3925),
    [sym_time_literal] = ACTIONS(3925),
    [sym_biginteger_literal] = ACTIONS(3927),
    [anon_sym_else] = ACTIONS(3925),
    [anon_sym_ELSE] = ACTIONS(3925),
    [anon_sym_Else] = ACTIONS(3925),
    [anon_sym_in] = ACTIONS(3925),
    [anon_sym_IN] = ACTIONS(3925),
    [anon_sym_In] = ACTIONS(3925),
    [sym_page_keyword] = ACTIONS(3925),
    [anon_sym_codeunit] = ACTIONS(3925),
    [anon_sym_CODEUNIT] = ACTIONS(3925),
    [anon_sym_Codeunit] = ACTIONS(3925),
    [anon_sym_CodeUnit] = ACTIONS(3925),
    [anon_sym_COdeunit] = ACTIONS(3925),
    [anon_sym_codeUnit] = ACTIONS(3925),
    [sym_report_keyword] = ACTIONS(3925),
    [sym_query_keyword] = ACTIONS(3925),
    [anon_sym_xmlport] = ACTIONS(3925),
    [anon_sym_XMLPORT] = ACTIONS(3925),
    [anon_sym_Xmlport] = ACTIONS(3925),
    [anon_sym_XMLport] = ACTIONS(3925),
    [anon_sym_XMLPort] = ACTIONS(3925),
    [anon_sym_XmlPort] = ACTIONS(3925),
    [anon_sym_enum] = ACTIONS(3925),
    [anon_sym_ENUM] = ACTIONS(3925),
    [anon_sym_Enum] = ACTIONS(3925),
    [anon_sym_eNUM] = ACTIONS(3925),
    [anon_sym_eNum] = ACTIONS(3925),
    [anon_sym_ENum] = ACTIONS(3925),
    [sym_quoted_identifier] = ACTIONS(3927),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3927),
    [sym_verbatim_string] = ACTIONS(3927),
    [sym_integer] = ACTIONS(3925),
    [sym_continue_as_identifier] = ACTIONS(3927),
    [sym_preproc_open] = ACTIONS(3927),
    [sym_preproc_close] = ACTIONS(3927),
  },
  [STATE(2333)] = {
    [sym_identifier] = ACTIONS(3931),
    [anon_sym_SEMI] = ACTIONS(3933),
    [anon_sym_DOT] = ACTIONS(3931),
    [anon_sym_EQ] = ACTIONS(3933),
    [anon_sym_COMMA] = ACTIONS(3933),
    [anon_sym_COLON] = ACTIONS(3931),
    [anon_sym_DASH] = ACTIONS(3931),
    [aux_sym_boolean_token1] = ACTIONS(3931),
    [aux_sym_boolean_token2] = ACTIONS(3931),
    [sym_decimal] = ACTIONS(3931),
    [anon_sym_LPAREN] = ACTIONS(3933),
    [anon_sym_DOT_DOT] = ACTIONS(3933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3931),
    [anon_sym_STAR] = ACTIONS(3931),
    [anon_sym_LBRACK] = ACTIONS(5417),
    [aux_sym_record_type_token1] = ACTIONS(3931),
    [aux_sym_basic_type_token21] = ACTIONS(3931),
    [aux_sym_basic_type_token22] = ACTIONS(3931),
    [aux_sym_basic_type_token48] = ACTIONS(3931),
    [anon_sym_POUNDif] = ACTIONS(3933),
    [anon_sym_POUNDIF] = ACTIONS(3933),
    [anon_sym_POUNDIf] = ACTIONS(3933),
    [anon_sym_not] = ACTIONS(3931),
    [anon_sym_NOT] = ACTIONS(3931),
    [anon_sym_Not] = ACTIONS(3931),
    [anon_sym_POUNDelif] = ACTIONS(3933),
    [anon_sym_POUNDELIF] = ACTIONS(3933),
    [anon_sym_POUNDElif] = ACTIONS(3933),
    [anon_sym_POUNDelse] = ACTIONS(3933),
    [anon_sym_POUNDELSE] = ACTIONS(3933),
    [anon_sym_POUNDElse] = ACTIONS(3933),
    [anon_sym_POUNDelse2] = ACTIONS(3933),
    [anon_sym_POUNDELSE2] = ACTIONS(3933),
    [anon_sym_POUNDElse2] = ACTIONS(3933),
    [anon_sym_POUNDendif] = ACTIONS(3933),
    [anon_sym_POUNDENDIF] = ACTIONS(3933),
    [anon_sym_POUNDEndif] = ACTIONS(3933),
    [anon_sym_POUNDendif2] = ACTIONS(3933),
    [anon_sym_POUNDENDIF2] = ACTIONS(3933),
    [anon_sym_POUNDEndif2] = ACTIONS(3933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3933),
    [aux_sym__expression_token1] = ACTIONS(3933),
    [aux_sym__expression_token2] = ACTIONS(3933),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3931),
    [anon_sym_SLASH] = ACTIONS(3931),
    [anon_sym_div] = ACTIONS(3931),
    [anon_sym_DIV] = ACTIONS(3931),
    [anon_sym_Div] = ACTIONS(3931),
    [anon_sym_mod] = ACTIONS(3931),
    [anon_sym_MOD] = ACTIONS(3931),
    [anon_sym_Mod] = ACTIONS(3931),
    [anon_sym_PLUS] = ACTIONS(3931),
    [anon_sym_GT_EQ] = ACTIONS(3933),
    [anon_sym_LT_EQ] = ACTIONS(3933),
    [anon_sym_GT] = ACTIONS(3931),
    [anon_sym_LT] = ACTIONS(3931),
    [anon_sym_LT_GT] = ACTIONS(3933),
    [anon_sym_and] = ACTIONS(3931),
    [anon_sym_AND] = ACTIONS(3931),
    [anon_sym_And] = ACTIONS(3931),
    [anon_sym_or] = ACTIONS(3931),
    [anon_sym_OR] = ACTIONS(3931),
    [anon_sym_Or] = ACTIONS(3931),
    [anon_sym_xor] = ACTIONS(3931),
    [anon_sym_XOR] = ACTIONS(3931),
    [anon_sym_Xor] = ACTIONS(3931),
    [anon_sym_QMARK] = ACTIONS(3933),
    [sym_datetime_literal] = ACTIONS(3933),
    [sym_date_literal] = ACTIONS(3931),
    [sym_time_literal] = ACTIONS(3931),
    [sym_biginteger_literal] = ACTIONS(3933),
    [anon_sym_else] = ACTIONS(3931),
    [anon_sym_ELSE] = ACTIONS(3931),
    [anon_sym_Else] = ACTIONS(3931),
    [anon_sym_in] = ACTIONS(3931),
    [anon_sym_IN] = ACTIONS(3931),
    [anon_sym_In] = ACTIONS(3931),
    [sym_page_keyword] = ACTIONS(3931),
    [anon_sym_codeunit] = ACTIONS(3931),
    [anon_sym_CODEUNIT] = ACTIONS(3931),
    [anon_sym_Codeunit] = ACTIONS(3931),
    [anon_sym_CodeUnit] = ACTIONS(3931),
    [anon_sym_COdeunit] = ACTIONS(3931),
    [anon_sym_codeUnit] = ACTIONS(3931),
    [sym_report_keyword] = ACTIONS(3931),
    [sym_query_keyword] = ACTIONS(3931),
    [anon_sym_xmlport] = ACTIONS(3931),
    [anon_sym_XMLPORT] = ACTIONS(3931),
    [anon_sym_Xmlport] = ACTIONS(3931),
    [anon_sym_XMLport] = ACTIONS(3931),
    [anon_sym_XMLPort] = ACTIONS(3931),
    [anon_sym_XmlPort] = ACTIONS(3931),
    [anon_sym_enum] = ACTIONS(3931),
    [anon_sym_ENUM] = ACTIONS(3931),
    [anon_sym_Enum] = ACTIONS(3931),
    [anon_sym_eNUM] = ACTIONS(3931),
    [anon_sym_eNum] = ACTIONS(3931),
    [anon_sym_ENum] = ACTIONS(3931),
    [sym_quoted_identifier] = ACTIONS(3933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3933),
    [sym_verbatim_string] = ACTIONS(3933),
    [sym_integer] = ACTIONS(3931),
    [sym_continue_as_identifier] = ACTIONS(3933),
    [sym_preproc_open] = ACTIONS(3933),
    [sym_preproc_close] = ACTIONS(3933),
  },
  [STATE(2334)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3730),
    [anon_sym_SEMI] = ACTIONS(3732),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3730),
    [aux_sym_boolean_token2] = ACTIONS(3730),
    [sym_decimal] = ACTIONS(3730),
    [anon_sym_LPAREN] = ACTIONS(3732),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3730),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3730),
    [aux_sym_basic_type_token21] = ACTIONS(3730),
    [aux_sym_basic_type_token22] = ACTIONS(3730),
    [aux_sym_basic_type_token48] = ACTIONS(3730),
    [anon_sym_POUNDif] = ACTIONS(3732),
    [anon_sym_POUNDIF] = ACTIONS(3732),
    [anon_sym_POUNDIf] = ACTIONS(3732),
    [anon_sym_not] = ACTIONS(3730),
    [anon_sym_NOT] = ACTIONS(3730),
    [anon_sym_Not] = ACTIONS(3730),
    [anon_sym_POUNDelif] = ACTIONS(3732),
    [anon_sym_POUNDELIF] = ACTIONS(3732),
    [anon_sym_POUNDElif] = ACTIONS(3732),
    [anon_sym_POUNDelse] = ACTIONS(3732),
    [anon_sym_POUNDELSE] = ACTIONS(3732),
    [anon_sym_POUNDElse] = ACTIONS(3732),
    [anon_sym_POUNDelse2] = ACTIONS(3732),
    [anon_sym_POUNDELSE2] = ACTIONS(3732),
    [anon_sym_POUNDElse2] = ACTIONS(3732),
    [anon_sym_POUNDendif] = ACTIONS(3732),
    [anon_sym_POUNDENDIF] = ACTIONS(3732),
    [anon_sym_POUNDEndif] = ACTIONS(3732),
    [anon_sym_POUNDendif2] = ACTIONS(3732),
    [anon_sym_POUNDENDIF2] = ACTIONS(3732),
    [anon_sym_POUNDEndif2] = ACTIONS(3732),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5307),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3730),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3730),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(5321),
    [anon_sym_OR] = ACTIONS(5323),
    [anon_sym_Or] = ACTIONS(5325),
    [anon_sym_xor] = ACTIONS(5327),
    [anon_sym_XOR] = ACTIONS(5329),
    [anon_sym_Xor] = ACTIONS(5331),
    [anon_sym_QMARK] = ACTIONS(5333),
    [sym_datetime_literal] = ACTIONS(3732),
    [sym_date_literal] = ACTIONS(3730),
    [sym_time_literal] = ACTIONS(3730),
    [sym_biginteger_literal] = ACTIONS(3732),
    [anon_sym_else] = ACTIONS(3730),
    [anon_sym_ELSE] = ACTIONS(3730),
    [anon_sym_Else] = ACTIONS(3730),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3730),
    [anon_sym_codeunit] = ACTIONS(3730),
    [anon_sym_CODEUNIT] = ACTIONS(3730),
    [anon_sym_Codeunit] = ACTIONS(3730),
    [anon_sym_CodeUnit] = ACTIONS(3730),
    [anon_sym_COdeunit] = ACTIONS(3730),
    [anon_sym_codeUnit] = ACTIONS(3730),
    [sym_report_keyword] = ACTIONS(3730),
    [sym_query_keyword] = ACTIONS(3730),
    [anon_sym_xmlport] = ACTIONS(3730),
    [anon_sym_XMLPORT] = ACTIONS(3730),
    [anon_sym_Xmlport] = ACTIONS(3730),
    [anon_sym_XMLport] = ACTIONS(3730),
    [anon_sym_XMLPort] = ACTIONS(3730),
    [anon_sym_XmlPort] = ACTIONS(3730),
    [anon_sym_enum] = ACTIONS(3730),
    [anon_sym_ENUM] = ACTIONS(3730),
    [anon_sym_Enum] = ACTIONS(3730),
    [anon_sym_eNUM] = ACTIONS(3730),
    [anon_sym_eNum] = ACTIONS(3730),
    [anon_sym_ENum] = ACTIONS(3730),
    [sym_quoted_identifier] = ACTIONS(3732),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3732),
    [sym_verbatim_string] = ACTIONS(3732),
    [sym_integer] = ACTIONS(3730),
    [sym_continue_as_identifier] = ACTIONS(3732),
    [sym_preproc_open] = ACTIONS(3732),
    [sym_preproc_close] = ACTIONS(3732),
  },
  [STATE(2335)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_COLON] = ACTIONS(3865),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(2336)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_COLON] = ACTIONS(3865),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(2337)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_COLON] = ACTIONS(3869),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(2338)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_COLON] = ACTIONS(3869),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(2339)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_COLON] = ACTIONS(3869),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(2340)] = {
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(3634),
    [anon_sym_COLON] = ACTIONS(3632),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelif] = ACTIONS(3634),
    [anon_sym_POUNDELIF] = ACTIONS(3634),
    [anon_sym_POUNDElif] = ACTIONS(3634),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [anon_sym_POUNDendif] = ACTIONS(3634),
    [anon_sym_POUNDENDIF] = ACTIONS(3634),
    [anon_sym_POUNDEndif] = ACTIONS(3634),
    [anon_sym_POUNDendif2] = ACTIONS(3634),
    [anon_sym_POUNDENDIF2] = ACTIONS(3634),
    [anon_sym_POUNDEndif2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3634),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
    [sym_preproc_close] = ACTIONS(3634),
  },
  [STATE(2341)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_elif] = STATE(2718),
    [sym_preproc_else] = STATE(3409),
    [sym_preproc_endif] = STATE(6548),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(2726),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3893),
    [sym_preproc_conditional_case_patterns] = STATE(3893),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(10679),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2726),
    [aux_sym_preproc_conditional_case_repeat2] = STATE(10665),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDelif] = ACTIONS(77),
    [anon_sym_POUNDELIF] = ACTIONS(77),
    [anon_sym_POUNDElif] = ACTIONS(77),
    [anon_sym_POUNDelse] = ACTIONS(79),
    [anon_sym_POUNDELSE] = ACTIONS(79),
    [anon_sym_POUNDElse] = ACTIONS(79),
    [anon_sym_POUNDelse2] = ACTIONS(79),
    [anon_sym_POUNDELSE2] = ACTIONS(79),
    [anon_sym_POUNDElse2] = ACTIONS(79),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(2342)] = {
    [sym_identifier] = ACTIONS(3742),
    [anon_sym_SEMI] = ACTIONS(3744),
    [anon_sym_DOT] = ACTIONS(3742),
    [anon_sym_EQ] = ACTIONS(3744),
    [anon_sym_COMMA] = ACTIONS(3744),
    [anon_sym_COLON] = ACTIONS(3742),
    [anon_sym_DASH] = ACTIONS(3742),
    [aux_sym_boolean_token1] = ACTIONS(3742),
    [aux_sym_boolean_token2] = ACTIONS(3742),
    [sym_decimal] = ACTIONS(3742),
    [anon_sym_LPAREN] = ACTIONS(3744),
    [anon_sym_DOT_DOT] = ACTIONS(3744),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3742),
    [anon_sym_STAR] = ACTIONS(3742),
    [anon_sym_LBRACK] = ACTIONS(3744),
    [aux_sym_record_type_token1] = ACTIONS(3742),
    [aux_sym_basic_type_token21] = ACTIONS(3742),
    [aux_sym_basic_type_token22] = ACTIONS(3742),
    [aux_sym_basic_type_token48] = ACTIONS(3742),
    [anon_sym_POUNDif] = ACTIONS(3744),
    [anon_sym_POUNDIF] = ACTIONS(3744),
    [anon_sym_POUNDIf] = ACTIONS(3744),
    [anon_sym_not] = ACTIONS(3742),
    [anon_sym_NOT] = ACTIONS(3742),
    [anon_sym_Not] = ACTIONS(3742),
    [anon_sym_POUNDelif] = ACTIONS(3744),
    [anon_sym_POUNDELIF] = ACTIONS(3744),
    [anon_sym_POUNDElif] = ACTIONS(3744),
    [anon_sym_POUNDelse] = ACTIONS(3744),
    [anon_sym_POUNDELSE] = ACTIONS(3744),
    [anon_sym_POUNDElse] = ACTIONS(3744),
    [anon_sym_POUNDelse2] = ACTIONS(3744),
    [anon_sym_POUNDELSE2] = ACTIONS(3744),
    [anon_sym_POUNDElse2] = ACTIONS(3744),
    [anon_sym_POUNDendif] = ACTIONS(3744),
    [anon_sym_POUNDENDIF] = ACTIONS(3744),
    [anon_sym_POUNDEndif] = ACTIONS(3744),
    [anon_sym_POUNDendif2] = ACTIONS(3744),
    [anon_sym_POUNDENDIF2] = ACTIONS(3744),
    [anon_sym_POUNDEndif2] = ACTIONS(3744),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3744),
    [aux_sym__expression_token1] = ACTIONS(3744),
    [aux_sym__expression_token2] = ACTIONS(3744),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3742),
    [anon_sym_SLASH] = ACTIONS(3742),
    [anon_sym_div] = ACTIONS(3742),
    [anon_sym_DIV] = ACTIONS(3742),
    [anon_sym_Div] = ACTIONS(3742),
    [anon_sym_mod] = ACTIONS(3742),
    [anon_sym_MOD] = ACTIONS(3742),
    [anon_sym_Mod] = ACTIONS(3742),
    [anon_sym_PLUS] = ACTIONS(3742),
    [anon_sym_GT_EQ] = ACTIONS(3744),
    [anon_sym_LT_EQ] = ACTIONS(3744),
    [anon_sym_GT] = ACTIONS(3742),
    [anon_sym_LT] = ACTIONS(3742),
    [anon_sym_LT_GT] = ACTIONS(3744),
    [anon_sym_and] = ACTIONS(3742),
    [anon_sym_AND] = ACTIONS(3742),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3742),
    [anon_sym_OR] = ACTIONS(3742),
    [anon_sym_Or] = ACTIONS(3742),
    [anon_sym_xor] = ACTIONS(3742),
    [anon_sym_XOR] = ACTIONS(3742),
    [anon_sym_Xor] = ACTIONS(3742),
    [anon_sym_QMARK] = ACTIONS(3744),
    [sym_datetime_literal] = ACTIONS(3744),
    [sym_date_literal] = ACTIONS(3742),
    [sym_time_literal] = ACTIONS(3742),
    [sym_biginteger_literal] = ACTIONS(3744),
    [anon_sym_else] = ACTIONS(3742),
    [anon_sym_ELSE] = ACTIONS(3742),
    [anon_sym_Else] = ACTIONS(3742),
    [anon_sym_in] = ACTIONS(3742),
    [anon_sym_IN] = ACTIONS(3742),
    [anon_sym_In] = ACTIONS(3742),
    [sym_page_keyword] = ACTIONS(3742),
    [anon_sym_codeunit] = ACTIONS(3742),
    [anon_sym_CODEUNIT] = ACTIONS(3742),
    [anon_sym_Codeunit] = ACTIONS(3742),
    [anon_sym_CodeUnit] = ACTIONS(3742),
    [anon_sym_COdeunit] = ACTIONS(3742),
    [anon_sym_codeUnit] = ACTIONS(3742),
    [sym_report_keyword] = ACTIONS(3742),
    [sym_query_keyword] = ACTIONS(3742),
    [anon_sym_xmlport] = ACTIONS(3742),
    [anon_sym_XMLPORT] = ACTIONS(3742),
    [anon_sym_Xmlport] = ACTIONS(3742),
    [anon_sym_XMLport] = ACTIONS(3742),
    [anon_sym_XMLPort] = ACTIONS(3742),
    [anon_sym_XmlPort] = ACTIONS(3742),
    [anon_sym_enum] = ACTIONS(3742),
    [anon_sym_ENUM] = ACTIONS(3742),
    [anon_sym_Enum] = ACTIONS(3742),
    [anon_sym_eNUM] = ACTIONS(3742),
    [anon_sym_eNum] = ACTIONS(3742),
    [anon_sym_ENum] = ACTIONS(3742),
    [sym_quoted_identifier] = ACTIONS(3744),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3744),
    [sym_verbatim_string] = ACTIONS(3744),
    [sym_integer] = ACTIONS(3742),
    [sym_continue_as_identifier] = ACTIONS(3744),
    [sym_preproc_open] = ACTIONS(3744),
    [sym_preproc_close] = ACTIONS(3744),
  },
  [STATE(2343)] = {
    [sym_identifier] = ACTIONS(3921),
    [anon_sym_SEMI] = ACTIONS(3923),
    [anon_sym_DOT] = ACTIONS(3921),
    [anon_sym_EQ] = ACTIONS(3923),
    [anon_sym_COMMA] = ACTIONS(3923),
    [anon_sym_COLON] = ACTIONS(3921),
    [anon_sym_DASH] = ACTIONS(3921),
    [aux_sym_boolean_token1] = ACTIONS(3921),
    [aux_sym_boolean_token2] = ACTIONS(3921),
    [sym_decimal] = ACTIONS(3921),
    [anon_sym_LPAREN] = ACTIONS(3923),
    [anon_sym_DOT_DOT] = ACTIONS(3923),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3921),
    [anon_sym_STAR] = ACTIONS(3921),
    [anon_sym_LBRACK] = ACTIONS(3923),
    [aux_sym_record_type_token1] = ACTIONS(3921),
    [aux_sym_basic_type_token21] = ACTIONS(3921),
    [aux_sym_basic_type_token22] = ACTIONS(3921),
    [aux_sym_basic_type_token48] = ACTIONS(3921),
    [anon_sym_POUNDif] = ACTIONS(3923),
    [anon_sym_POUNDIF] = ACTIONS(3923),
    [anon_sym_POUNDIf] = ACTIONS(3923),
    [anon_sym_not] = ACTIONS(3921),
    [anon_sym_NOT] = ACTIONS(3921),
    [anon_sym_Not] = ACTIONS(3921),
    [anon_sym_POUNDelif] = ACTIONS(3923),
    [anon_sym_POUNDELIF] = ACTIONS(3923),
    [anon_sym_POUNDElif] = ACTIONS(3923),
    [anon_sym_POUNDelse] = ACTIONS(3923),
    [anon_sym_POUNDELSE] = ACTIONS(3923),
    [anon_sym_POUNDElse] = ACTIONS(3923),
    [anon_sym_POUNDelse2] = ACTIONS(3923),
    [anon_sym_POUNDELSE2] = ACTIONS(3923),
    [anon_sym_POUNDElse2] = ACTIONS(3923),
    [anon_sym_POUNDendif] = ACTIONS(3923),
    [anon_sym_POUNDENDIF] = ACTIONS(3923),
    [anon_sym_POUNDEndif] = ACTIONS(3923),
    [anon_sym_POUNDendif2] = ACTIONS(3923),
    [anon_sym_POUNDENDIF2] = ACTIONS(3923),
    [anon_sym_POUNDEndif2] = ACTIONS(3923),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3923),
    [aux_sym__expression_token1] = ACTIONS(3923),
    [aux_sym__expression_token2] = ACTIONS(3923),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3921),
    [anon_sym_SLASH] = ACTIONS(3921),
    [anon_sym_div] = ACTIONS(3921),
    [anon_sym_DIV] = ACTIONS(3921),
    [anon_sym_Div] = ACTIONS(3921),
    [anon_sym_mod] = ACTIONS(3921),
    [anon_sym_MOD] = ACTIONS(3921),
    [anon_sym_Mod] = ACTIONS(3921),
    [anon_sym_PLUS] = ACTIONS(3921),
    [anon_sym_GT_EQ] = ACTIONS(3923),
    [anon_sym_LT_EQ] = ACTIONS(3923),
    [anon_sym_GT] = ACTIONS(3921),
    [anon_sym_LT] = ACTIONS(3921),
    [anon_sym_LT_GT] = ACTIONS(3923),
    [anon_sym_and] = ACTIONS(3921),
    [anon_sym_AND] = ACTIONS(3921),
    [anon_sym_And] = ACTIONS(3921),
    [anon_sym_or] = ACTIONS(3921),
    [anon_sym_OR] = ACTIONS(3921),
    [anon_sym_Or] = ACTIONS(3921),
    [anon_sym_xor] = ACTIONS(3921),
    [anon_sym_XOR] = ACTIONS(3921),
    [anon_sym_Xor] = ACTIONS(3921),
    [anon_sym_QMARK] = ACTIONS(3923),
    [sym_datetime_literal] = ACTIONS(3923),
    [sym_date_literal] = ACTIONS(3921),
    [sym_time_literal] = ACTIONS(3921),
    [sym_biginteger_literal] = ACTIONS(3923),
    [anon_sym_else] = ACTIONS(3921),
    [anon_sym_ELSE] = ACTIONS(3921),
    [anon_sym_Else] = ACTIONS(3921),
    [anon_sym_in] = ACTIONS(3921),
    [anon_sym_IN] = ACTIONS(3921),
    [anon_sym_In] = ACTIONS(3921),
    [sym_page_keyword] = ACTIONS(3921),
    [anon_sym_codeunit] = ACTIONS(3921),
    [anon_sym_CODEUNIT] = ACTIONS(3921),
    [anon_sym_Codeunit] = ACTIONS(3921),
    [anon_sym_CodeUnit] = ACTIONS(3921),
    [anon_sym_COdeunit] = ACTIONS(3921),
    [anon_sym_codeUnit] = ACTIONS(3921),
    [sym_report_keyword] = ACTIONS(3921),
    [sym_query_keyword] = ACTIONS(3921),
    [anon_sym_xmlport] = ACTIONS(3921),
    [anon_sym_XMLPORT] = ACTIONS(3921),
    [anon_sym_Xmlport] = ACTIONS(3921),
    [anon_sym_XMLport] = ACTIONS(3921),
    [anon_sym_XMLPort] = ACTIONS(3921),
    [anon_sym_XmlPort] = ACTIONS(3921),
    [anon_sym_enum] = ACTIONS(3921),
    [anon_sym_ENUM] = ACTIONS(3921),
    [anon_sym_Enum] = ACTIONS(3921),
    [anon_sym_eNUM] = ACTIONS(3921),
    [anon_sym_eNum] = ACTIONS(3921),
    [anon_sym_ENum] = ACTIONS(3921),
    [sym_quoted_identifier] = ACTIONS(3923),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3923),
    [sym_verbatim_string] = ACTIONS(3923),
    [sym_integer] = ACTIONS(3921),
    [sym_continue_as_identifier] = ACTIONS(3923),
    [sym_preproc_open] = ACTIONS(3923),
    [sym_preproc_close] = ACTIONS(3923),
  },
  [STATE(2344)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3710),
    [anon_sym_SEMI] = ACTIONS(3712),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3710),
    [aux_sym_boolean_token2] = ACTIONS(3710),
    [sym_decimal] = ACTIONS(3710),
    [anon_sym_LPAREN] = ACTIONS(3712),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3710),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3710),
    [aux_sym_basic_type_token21] = ACTIONS(3710),
    [aux_sym_basic_type_token22] = ACTIONS(3710),
    [aux_sym_basic_type_token48] = ACTIONS(3710),
    [anon_sym_POUNDif] = ACTIONS(3712),
    [anon_sym_POUNDIF] = ACTIONS(3712),
    [anon_sym_POUNDIf] = ACTIONS(3712),
    [anon_sym_not] = ACTIONS(3710),
    [anon_sym_NOT] = ACTIONS(3710),
    [anon_sym_Not] = ACTIONS(3710),
    [anon_sym_POUNDelif] = ACTIONS(3712),
    [anon_sym_POUNDELIF] = ACTIONS(3712),
    [anon_sym_POUNDElif] = ACTIONS(3712),
    [anon_sym_POUNDelse] = ACTIONS(3712),
    [anon_sym_POUNDELSE] = ACTIONS(3712),
    [anon_sym_POUNDElse] = ACTIONS(3712),
    [anon_sym_POUNDelse2] = ACTIONS(3712),
    [anon_sym_POUNDELSE2] = ACTIONS(3712),
    [anon_sym_POUNDElse2] = ACTIONS(3712),
    [anon_sym_POUNDendif] = ACTIONS(3712),
    [anon_sym_POUNDENDIF] = ACTIONS(3712),
    [anon_sym_POUNDEndif] = ACTIONS(3712),
    [anon_sym_POUNDendif2] = ACTIONS(3712),
    [anon_sym_POUNDENDIF2] = ACTIONS(3712),
    [anon_sym_POUNDEndif2] = ACTIONS(3712),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5429),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3710),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3710),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(5321),
    [anon_sym_OR] = ACTIONS(5323),
    [anon_sym_Or] = ACTIONS(5325),
    [anon_sym_xor] = ACTIONS(5327),
    [anon_sym_XOR] = ACTIONS(5329),
    [anon_sym_Xor] = ACTIONS(5331),
    [anon_sym_QMARK] = ACTIONS(5333),
    [sym_datetime_literal] = ACTIONS(3712),
    [sym_date_literal] = ACTIONS(3710),
    [sym_time_literal] = ACTIONS(3710),
    [sym_biginteger_literal] = ACTIONS(3712),
    [anon_sym_else] = ACTIONS(3710),
    [anon_sym_ELSE] = ACTIONS(3710),
    [anon_sym_Else] = ACTIONS(3710),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3710),
    [anon_sym_codeunit] = ACTIONS(3710),
    [anon_sym_CODEUNIT] = ACTIONS(3710),
    [anon_sym_Codeunit] = ACTIONS(3710),
    [anon_sym_CodeUnit] = ACTIONS(3710),
    [anon_sym_COdeunit] = ACTIONS(3710),
    [anon_sym_codeUnit] = ACTIONS(3710),
    [sym_report_keyword] = ACTIONS(3710),
    [sym_query_keyword] = ACTIONS(3710),
    [anon_sym_xmlport] = ACTIONS(3710),
    [anon_sym_XMLPORT] = ACTIONS(3710),
    [anon_sym_Xmlport] = ACTIONS(3710),
    [anon_sym_XMLport] = ACTIONS(3710),
    [anon_sym_XMLPort] = ACTIONS(3710),
    [anon_sym_XmlPort] = ACTIONS(3710),
    [anon_sym_enum] = ACTIONS(3710),
    [anon_sym_ENUM] = ACTIONS(3710),
    [anon_sym_Enum] = ACTIONS(3710),
    [anon_sym_eNUM] = ACTIONS(3710),
    [anon_sym_eNum] = ACTIONS(3710),
    [anon_sym_ENum] = ACTIONS(3710),
    [sym_quoted_identifier] = ACTIONS(3712),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3712),
    [sym_verbatim_string] = ACTIONS(3712),
    [sym_integer] = ACTIONS(3710),
    [sym_continue_as_identifier] = ACTIONS(3712),
    [sym_preproc_open] = ACTIONS(3712),
    [sym_preproc_close] = ACTIONS(3712),
  },
  [STATE(2345)] = {
    [sym_identifier] = ACTIONS(3881),
    [anon_sym_SEMI] = ACTIONS(3883),
    [anon_sym_DOT] = ACTIONS(3881),
    [anon_sym_EQ] = ACTIONS(3883),
    [anon_sym_COMMA] = ACTIONS(3883),
    [anon_sym_COLON] = ACTIONS(3881),
    [anon_sym_DASH] = ACTIONS(3881),
    [aux_sym_boolean_token1] = ACTIONS(3881),
    [aux_sym_boolean_token2] = ACTIONS(3881),
    [sym_decimal] = ACTIONS(3881),
    [anon_sym_LPAREN] = ACTIONS(3883),
    [anon_sym_DOT_DOT] = ACTIONS(3883),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3881),
    [anon_sym_STAR] = ACTIONS(3881),
    [anon_sym_LBRACK] = ACTIONS(3883),
    [aux_sym_record_type_token1] = ACTIONS(3881),
    [aux_sym_basic_type_token21] = ACTIONS(3881),
    [aux_sym_basic_type_token22] = ACTIONS(3881),
    [aux_sym_basic_type_token48] = ACTIONS(3881),
    [anon_sym_POUNDif] = ACTIONS(3883),
    [anon_sym_POUNDIF] = ACTIONS(3883),
    [anon_sym_POUNDIf] = ACTIONS(3883),
    [anon_sym_not] = ACTIONS(3881),
    [anon_sym_NOT] = ACTIONS(3881),
    [anon_sym_Not] = ACTIONS(3881),
    [anon_sym_POUNDelif] = ACTIONS(3883),
    [anon_sym_POUNDELIF] = ACTIONS(3883),
    [anon_sym_POUNDElif] = ACTIONS(3883),
    [anon_sym_POUNDelse] = ACTIONS(3883),
    [anon_sym_POUNDELSE] = ACTIONS(3883),
    [anon_sym_POUNDElse] = ACTIONS(3883),
    [anon_sym_POUNDelse2] = ACTIONS(3883),
    [anon_sym_POUNDELSE2] = ACTIONS(3883),
    [anon_sym_POUNDElse2] = ACTIONS(3883),
    [anon_sym_POUNDendif] = ACTIONS(3883),
    [anon_sym_POUNDENDIF] = ACTIONS(3883),
    [anon_sym_POUNDEndif] = ACTIONS(3883),
    [anon_sym_POUNDendif2] = ACTIONS(3883),
    [anon_sym_POUNDENDIF2] = ACTIONS(3883),
    [anon_sym_POUNDEndif2] = ACTIONS(3883),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3883),
    [aux_sym__expression_token1] = ACTIONS(3883),
    [aux_sym__expression_token2] = ACTIONS(3883),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3881),
    [anon_sym_SLASH] = ACTIONS(3881),
    [anon_sym_div] = ACTIONS(3881),
    [anon_sym_DIV] = ACTIONS(3881),
    [anon_sym_Div] = ACTIONS(3881),
    [anon_sym_mod] = ACTIONS(3881),
    [anon_sym_MOD] = ACTIONS(3881),
    [anon_sym_Mod] = ACTIONS(3881),
    [anon_sym_PLUS] = ACTIONS(3881),
    [anon_sym_GT_EQ] = ACTIONS(3883),
    [anon_sym_LT_EQ] = ACTIONS(3883),
    [anon_sym_GT] = ACTIONS(3881),
    [anon_sym_LT] = ACTIONS(3881),
    [anon_sym_LT_GT] = ACTIONS(3883),
    [anon_sym_and] = ACTIONS(3881),
    [anon_sym_AND] = ACTIONS(3881),
    [anon_sym_And] = ACTIONS(3881),
    [anon_sym_or] = ACTIONS(3881),
    [anon_sym_OR] = ACTIONS(3881),
    [anon_sym_Or] = ACTIONS(3881),
    [anon_sym_xor] = ACTIONS(3881),
    [anon_sym_XOR] = ACTIONS(3881),
    [anon_sym_Xor] = ACTIONS(3881),
    [anon_sym_QMARK] = ACTIONS(3883),
    [sym_datetime_literal] = ACTIONS(3883),
    [sym_date_literal] = ACTIONS(3881),
    [sym_time_literal] = ACTIONS(3881),
    [sym_biginteger_literal] = ACTIONS(3883),
    [anon_sym_else] = ACTIONS(3881),
    [anon_sym_ELSE] = ACTIONS(3881),
    [anon_sym_Else] = ACTIONS(3881),
    [anon_sym_in] = ACTIONS(3881),
    [anon_sym_IN] = ACTIONS(3881),
    [anon_sym_In] = ACTIONS(3881),
    [sym_page_keyword] = ACTIONS(3881),
    [anon_sym_codeunit] = ACTIONS(3881),
    [anon_sym_CODEUNIT] = ACTIONS(3881),
    [anon_sym_Codeunit] = ACTIONS(3881),
    [anon_sym_CodeUnit] = ACTIONS(3881),
    [anon_sym_COdeunit] = ACTIONS(3881),
    [anon_sym_codeUnit] = ACTIONS(3881),
    [sym_report_keyword] = ACTIONS(3881),
    [sym_query_keyword] = ACTIONS(3881),
    [anon_sym_xmlport] = ACTIONS(3881),
    [anon_sym_XMLPORT] = ACTIONS(3881),
    [anon_sym_Xmlport] = ACTIONS(3881),
    [anon_sym_XMLport] = ACTIONS(3881),
    [anon_sym_XMLPort] = ACTIONS(3881),
    [anon_sym_XmlPort] = ACTIONS(3881),
    [anon_sym_enum] = ACTIONS(3881),
    [anon_sym_ENUM] = ACTIONS(3881),
    [anon_sym_Enum] = ACTIONS(3881),
    [anon_sym_eNUM] = ACTIONS(3881),
    [anon_sym_eNum] = ACTIONS(3881),
    [anon_sym_ENum] = ACTIONS(3881),
    [sym_quoted_identifier] = ACTIONS(3883),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3883),
    [sym_verbatim_string] = ACTIONS(3883),
    [sym_integer] = ACTIONS(3881),
    [sym_continue_as_identifier] = ACTIONS(3883),
    [sym_preproc_open] = ACTIONS(3883),
    [sym_preproc_close] = ACTIONS(3883),
  },
  [STATE(2346)] = {
    [sym_identifier] = ACTIONS(3889),
    [anon_sym_SEMI] = ACTIONS(3891),
    [anon_sym_DOT] = ACTIONS(3889),
    [anon_sym_EQ] = ACTIONS(3891),
    [anon_sym_COMMA] = ACTIONS(3891),
    [anon_sym_COLON] = ACTIONS(3889),
    [anon_sym_DASH] = ACTIONS(3889),
    [aux_sym_boolean_token1] = ACTIONS(3889),
    [aux_sym_boolean_token2] = ACTIONS(3889),
    [sym_decimal] = ACTIONS(3889),
    [anon_sym_LPAREN] = ACTIONS(3891),
    [anon_sym_DOT_DOT] = ACTIONS(3891),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3889),
    [anon_sym_STAR] = ACTIONS(3889),
    [anon_sym_LBRACK] = ACTIONS(3891),
    [aux_sym_record_type_token1] = ACTIONS(3889),
    [aux_sym_basic_type_token21] = ACTIONS(3889),
    [aux_sym_basic_type_token22] = ACTIONS(3889),
    [aux_sym_basic_type_token48] = ACTIONS(3889),
    [anon_sym_POUNDif] = ACTIONS(3891),
    [anon_sym_POUNDIF] = ACTIONS(3891),
    [anon_sym_POUNDIf] = ACTIONS(3891),
    [anon_sym_not] = ACTIONS(3889),
    [anon_sym_NOT] = ACTIONS(3889),
    [anon_sym_Not] = ACTIONS(3889),
    [anon_sym_POUNDelif] = ACTIONS(3891),
    [anon_sym_POUNDELIF] = ACTIONS(3891),
    [anon_sym_POUNDElif] = ACTIONS(3891),
    [anon_sym_POUNDelse] = ACTIONS(3891),
    [anon_sym_POUNDELSE] = ACTIONS(3891),
    [anon_sym_POUNDElse] = ACTIONS(3891),
    [anon_sym_POUNDelse2] = ACTIONS(3891),
    [anon_sym_POUNDELSE2] = ACTIONS(3891),
    [anon_sym_POUNDElse2] = ACTIONS(3891),
    [anon_sym_POUNDendif] = ACTIONS(3891),
    [anon_sym_POUNDENDIF] = ACTIONS(3891),
    [anon_sym_POUNDEndif] = ACTIONS(3891),
    [anon_sym_POUNDendif2] = ACTIONS(3891),
    [anon_sym_POUNDENDIF2] = ACTIONS(3891),
    [anon_sym_POUNDEndif2] = ACTIONS(3891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3891),
    [aux_sym__expression_token1] = ACTIONS(3891),
    [aux_sym__expression_token2] = ACTIONS(3891),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3889),
    [anon_sym_SLASH] = ACTIONS(3889),
    [anon_sym_div] = ACTIONS(3889),
    [anon_sym_DIV] = ACTIONS(3889),
    [anon_sym_Div] = ACTIONS(3889),
    [anon_sym_mod] = ACTIONS(3889),
    [anon_sym_MOD] = ACTIONS(3889),
    [anon_sym_Mod] = ACTIONS(3889),
    [anon_sym_PLUS] = ACTIONS(3889),
    [anon_sym_GT_EQ] = ACTIONS(3891),
    [anon_sym_LT_EQ] = ACTIONS(3891),
    [anon_sym_GT] = ACTIONS(3889),
    [anon_sym_LT] = ACTIONS(3889),
    [anon_sym_LT_GT] = ACTIONS(3891),
    [anon_sym_and] = ACTIONS(3889),
    [anon_sym_AND] = ACTIONS(3889),
    [anon_sym_And] = ACTIONS(3889),
    [anon_sym_or] = ACTIONS(3889),
    [anon_sym_OR] = ACTIONS(3889),
    [anon_sym_Or] = ACTIONS(3889),
    [anon_sym_xor] = ACTIONS(3889),
    [anon_sym_XOR] = ACTIONS(3889),
    [anon_sym_Xor] = ACTIONS(3889),
    [anon_sym_QMARK] = ACTIONS(3891),
    [sym_datetime_literal] = ACTIONS(3891),
    [sym_date_literal] = ACTIONS(3889),
    [sym_time_literal] = ACTIONS(3889),
    [sym_biginteger_literal] = ACTIONS(3891),
    [anon_sym_else] = ACTIONS(3889),
    [anon_sym_ELSE] = ACTIONS(3889),
    [anon_sym_Else] = ACTIONS(3889),
    [anon_sym_in] = ACTIONS(3889),
    [anon_sym_IN] = ACTIONS(3889),
    [anon_sym_In] = ACTIONS(3889),
    [sym_page_keyword] = ACTIONS(3889),
    [anon_sym_codeunit] = ACTIONS(3889),
    [anon_sym_CODEUNIT] = ACTIONS(3889),
    [anon_sym_Codeunit] = ACTIONS(3889),
    [anon_sym_CodeUnit] = ACTIONS(3889),
    [anon_sym_COdeunit] = ACTIONS(3889),
    [anon_sym_codeUnit] = ACTIONS(3889),
    [sym_report_keyword] = ACTIONS(3889),
    [sym_query_keyword] = ACTIONS(3889),
    [anon_sym_xmlport] = ACTIONS(3889),
    [anon_sym_XMLPORT] = ACTIONS(3889),
    [anon_sym_Xmlport] = ACTIONS(3889),
    [anon_sym_XMLport] = ACTIONS(3889),
    [anon_sym_XMLPort] = ACTIONS(3889),
    [anon_sym_XmlPort] = ACTIONS(3889),
    [anon_sym_enum] = ACTIONS(3889),
    [anon_sym_ENUM] = ACTIONS(3889),
    [anon_sym_Enum] = ACTIONS(3889),
    [anon_sym_eNUM] = ACTIONS(3889),
    [anon_sym_eNum] = ACTIONS(3889),
    [anon_sym_ENum] = ACTIONS(3889),
    [sym_quoted_identifier] = ACTIONS(3891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3891),
    [sym_verbatim_string] = ACTIONS(3891),
    [sym_integer] = ACTIONS(3889),
    [sym_continue_as_identifier] = ACTIONS(3891),
    [sym_preproc_open] = ACTIONS(3891),
    [sym_preproc_close] = ACTIONS(3891),
  },
  [STATE(2347)] = {
    [sym_identifier] = ACTIONS(3893),
    [anon_sym_SEMI] = ACTIONS(3895),
    [anon_sym_DOT] = ACTIONS(3893),
    [anon_sym_EQ] = ACTIONS(3895),
    [anon_sym_COMMA] = ACTIONS(3895),
    [anon_sym_COLON] = ACTIONS(3893),
    [anon_sym_DASH] = ACTIONS(3893),
    [aux_sym_boolean_token1] = ACTIONS(3893),
    [aux_sym_boolean_token2] = ACTIONS(3893),
    [sym_decimal] = ACTIONS(3893),
    [anon_sym_LPAREN] = ACTIONS(3895),
    [anon_sym_DOT_DOT] = ACTIONS(3895),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3893),
    [anon_sym_STAR] = ACTIONS(3893),
    [anon_sym_LBRACK] = ACTIONS(3895),
    [aux_sym_record_type_token1] = ACTIONS(3893),
    [aux_sym_basic_type_token21] = ACTIONS(3893),
    [aux_sym_basic_type_token22] = ACTIONS(3893),
    [aux_sym_basic_type_token48] = ACTIONS(3893),
    [anon_sym_POUNDif] = ACTIONS(3895),
    [anon_sym_POUNDIF] = ACTIONS(3895),
    [anon_sym_POUNDIf] = ACTIONS(3895),
    [anon_sym_not] = ACTIONS(3893),
    [anon_sym_NOT] = ACTIONS(3893),
    [anon_sym_Not] = ACTIONS(3893),
    [anon_sym_POUNDelif] = ACTIONS(3895),
    [anon_sym_POUNDELIF] = ACTIONS(3895),
    [anon_sym_POUNDElif] = ACTIONS(3895),
    [anon_sym_POUNDelse] = ACTIONS(3895),
    [anon_sym_POUNDELSE] = ACTIONS(3895),
    [anon_sym_POUNDElse] = ACTIONS(3895),
    [anon_sym_POUNDelse2] = ACTIONS(3895),
    [anon_sym_POUNDELSE2] = ACTIONS(3895),
    [anon_sym_POUNDElse2] = ACTIONS(3895),
    [anon_sym_POUNDendif] = ACTIONS(3895),
    [anon_sym_POUNDENDIF] = ACTIONS(3895),
    [anon_sym_POUNDEndif] = ACTIONS(3895),
    [anon_sym_POUNDendif2] = ACTIONS(3895),
    [anon_sym_POUNDENDIF2] = ACTIONS(3895),
    [anon_sym_POUNDEndif2] = ACTIONS(3895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3895),
    [aux_sym__expression_token1] = ACTIONS(3895),
    [aux_sym__expression_token2] = ACTIONS(3895),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3893),
    [anon_sym_SLASH] = ACTIONS(3893),
    [anon_sym_div] = ACTIONS(3893),
    [anon_sym_DIV] = ACTIONS(3893),
    [anon_sym_Div] = ACTIONS(3893),
    [anon_sym_mod] = ACTIONS(3893),
    [anon_sym_MOD] = ACTIONS(3893),
    [anon_sym_Mod] = ACTIONS(3893),
    [anon_sym_PLUS] = ACTIONS(3893),
    [anon_sym_GT_EQ] = ACTIONS(3895),
    [anon_sym_LT_EQ] = ACTIONS(3895),
    [anon_sym_GT] = ACTIONS(3893),
    [anon_sym_LT] = ACTIONS(3893),
    [anon_sym_LT_GT] = ACTIONS(3895),
    [anon_sym_and] = ACTIONS(3893),
    [anon_sym_AND] = ACTIONS(3893),
    [anon_sym_And] = ACTIONS(3893),
    [anon_sym_or] = ACTIONS(3893),
    [anon_sym_OR] = ACTIONS(3893),
    [anon_sym_Or] = ACTIONS(3893),
    [anon_sym_xor] = ACTIONS(3893),
    [anon_sym_XOR] = ACTIONS(3893),
    [anon_sym_Xor] = ACTIONS(3893),
    [anon_sym_QMARK] = ACTIONS(3895),
    [sym_datetime_literal] = ACTIONS(3895),
    [sym_date_literal] = ACTIONS(3893),
    [sym_time_literal] = ACTIONS(3893),
    [sym_biginteger_literal] = ACTIONS(3895),
    [anon_sym_else] = ACTIONS(3893),
    [anon_sym_ELSE] = ACTIONS(3893),
    [anon_sym_Else] = ACTIONS(3893),
    [anon_sym_in] = ACTIONS(3893),
    [anon_sym_IN] = ACTIONS(3893),
    [anon_sym_In] = ACTIONS(3893),
    [sym_page_keyword] = ACTIONS(3893),
    [anon_sym_codeunit] = ACTIONS(3893),
    [anon_sym_CODEUNIT] = ACTIONS(3893),
    [anon_sym_Codeunit] = ACTIONS(3893),
    [anon_sym_CodeUnit] = ACTIONS(3893),
    [anon_sym_COdeunit] = ACTIONS(3893),
    [anon_sym_codeUnit] = ACTIONS(3893),
    [sym_report_keyword] = ACTIONS(3893),
    [sym_query_keyword] = ACTIONS(3893),
    [anon_sym_xmlport] = ACTIONS(3893),
    [anon_sym_XMLPORT] = ACTIONS(3893),
    [anon_sym_Xmlport] = ACTIONS(3893),
    [anon_sym_XMLport] = ACTIONS(3893),
    [anon_sym_XMLPort] = ACTIONS(3893),
    [anon_sym_XmlPort] = ACTIONS(3893),
    [anon_sym_enum] = ACTIONS(3893),
    [anon_sym_ENUM] = ACTIONS(3893),
    [anon_sym_Enum] = ACTIONS(3893),
    [anon_sym_eNUM] = ACTIONS(3893),
    [anon_sym_eNum] = ACTIONS(3893),
    [anon_sym_ENum] = ACTIONS(3893),
    [sym_quoted_identifier] = ACTIONS(3895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3895),
    [sym_verbatim_string] = ACTIONS(3895),
    [sym_integer] = ACTIONS(3893),
    [sym_continue_as_identifier] = ACTIONS(3895),
    [sym_preproc_open] = ACTIONS(3895),
    [sym_preproc_close] = ACTIONS(3895),
  },
  [STATE(2348)] = {
    [sym_identifier] = ACTIONS(3897),
    [anon_sym_SEMI] = ACTIONS(3899),
    [anon_sym_DOT] = ACTIONS(3897),
    [anon_sym_EQ] = ACTIONS(3899),
    [anon_sym_COMMA] = ACTIONS(3899),
    [anon_sym_COLON] = ACTIONS(3897),
    [anon_sym_DASH] = ACTIONS(3897),
    [aux_sym_boolean_token1] = ACTIONS(3897),
    [aux_sym_boolean_token2] = ACTIONS(3897),
    [sym_decimal] = ACTIONS(3897),
    [anon_sym_LPAREN] = ACTIONS(3899),
    [anon_sym_DOT_DOT] = ACTIONS(3899),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3897),
    [anon_sym_STAR] = ACTIONS(3897),
    [anon_sym_LBRACK] = ACTIONS(3899),
    [aux_sym_record_type_token1] = ACTIONS(3897),
    [aux_sym_basic_type_token21] = ACTIONS(3897),
    [aux_sym_basic_type_token22] = ACTIONS(3897),
    [aux_sym_basic_type_token48] = ACTIONS(3897),
    [anon_sym_POUNDif] = ACTIONS(3899),
    [anon_sym_POUNDIF] = ACTIONS(3899),
    [anon_sym_POUNDIf] = ACTIONS(3899),
    [anon_sym_not] = ACTIONS(3897),
    [anon_sym_NOT] = ACTIONS(3897),
    [anon_sym_Not] = ACTIONS(3897),
    [anon_sym_POUNDelif] = ACTIONS(3899),
    [anon_sym_POUNDELIF] = ACTIONS(3899),
    [anon_sym_POUNDElif] = ACTIONS(3899),
    [anon_sym_POUNDelse] = ACTIONS(3899),
    [anon_sym_POUNDELSE] = ACTIONS(3899),
    [anon_sym_POUNDElse] = ACTIONS(3899),
    [anon_sym_POUNDelse2] = ACTIONS(3899),
    [anon_sym_POUNDELSE2] = ACTIONS(3899),
    [anon_sym_POUNDElse2] = ACTIONS(3899),
    [anon_sym_POUNDendif] = ACTIONS(3899),
    [anon_sym_POUNDENDIF] = ACTIONS(3899),
    [anon_sym_POUNDEndif] = ACTIONS(3899),
    [anon_sym_POUNDendif2] = ACTIONS(3899),
    [anon_sym_POUNDENDIF2] = ACTIONS(3899),
    [anon_sym_POUNDEndif2] = ACTIONS(3899),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3899),
    [aux_sym__expression_token1] = ACTIONS(3899),
    [aux_sym__expression_token2] = ACTIONS(3899),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3897),
    [anon_sym_SLASH] = ACTIONS(3897),
    [anon_sym_div] = ACTIONS(3897),
    [anon_sym_DIV] = ACTIONS(3897),
    [anon_sym_Div] = ACTIONS(3897),
    [anon_sym_mod] = ACTIONS(3897),
    [anon_sym_MOD] = ACTIONS(3897),
    [anon_sym_Mod] = ACTIONS(3897),
    [anon_sym_PLUS] = ACTIONS(3897),
    [anon_sym_GT_EQ] = ACTIONS(3899),
    [anon_sym_LT_EQ] = ACTIONS(3899),
    [anon_sym_GT] = ACTIONS(3897),
    [anon_sym_LT] = ACTIONS(3897),
    [anon_sym_LT_GT] = ACTIONS(3899),
    [anon_sym_and] = ACTIONS(3897),
    [anon_sym_AND] = ACTIONS(3897),
    [anon_sym_And] = ACTIONS(3897),
    [anon_sym_or] = ACTIONS(3897),
    [anon_sym_OR] = ACTIONS(3897),
    [anon_sym_Or] = ACTIONS(3897),
    [anon_sym_xor] = ACTIONS(3897),
    [anon_sym_XOR] = ACTIONS(3897),
    [anon_sym_Xor] = ACTIONS(3897),
    [anon_sym_QMARK] = ACTIONS(3899),
    [sym_datetime_literal] = ACTIONS(3899),
    [sym_date_literal] = ACTIONS(3897),
    [sym_time_literal] = ACTIONS(3897),
    [sym_biginteger_literal] = ACTIONS(3899),
    [anon_sym_else] = ACTIONS(3897),
    [anon_sym_ELSE] = ACTIONS(3897),
    [anon_sym_Else] = ACTIONS(3897),
    [anon_sym_in] = ACTIONS(3897),
    [anon_sym_IN] = ACTIONS(3897),
    [anon_sym_In] = ACTIONS(3897),
    [sym_page_keyword] = ACTIONS(3897),
    [anon_sym_codeunit] = ACTIONS(3897),
    [anon_sym_CODEUNIT] = ACTIONS(3897),
    [anon_sym_Codeunit] = ACTIONS(3897),
    [anon_sym_CodeUnit] = ACTIONS(3897),
    [anon_sym_COdeunit] = ACTIONS(3897),
    [anon_sym_codeUnit] = ACTIONS(3897),
    [sym_report_keyword] = ACTIONS(3897),
    [sym_query_keyword] = ACTIONS(3897),
    [anon_sym_xmlport] = ACTIONS(3897),
    [anon_sym_XMLPORT] = ACTIONS(3897),
    [anon_sym_Xmlport] = ACTIONS(3897),
    [anon_sym_XMLport] = ACTIONS(3897),
    [anon_sym_XMLPort] = ACTIONS(3897),
    [anon_sym_XmlPort] = ACTIONS(3897),
    [anon_sym_enum] = ACTIONS(3897),
    [anon_sym_ENUM] = ACTIONS(3897),
    [anon_sym_Enum] = ACTIONS(3897),
    [anon_sym_eNUM] = ACTIONS(3897),
    [anon_sym_eNum] = ACTIONS(3897),
    [anon_sym_ENum] = ACTIONS(3897),
    [sym_quoted_identifier] = ACTIONS(3899),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3899),
    [sym_verbatim_string] = ACTIONS(3899),
    [sym_integer] = ACTIONS(3897),
    [sym_continue_as_identifier] = ACTIONS(3899),
    [sym_preproc_open] = ACTIONS(3899),
    [sym_preproc_close] = ACTIONS(3899),
  },
  [STATE(2349)] = {
    [sym_identifier] = ACTIONS(3901),
    [anon_sym_SEMI] = ACTIONS(3903),
    [anon_sym_DOT] = ACTIONS(3901),
    [anon_sym_EQ] = ACTIONS(3903),
    [anon_sym_COMMA] = ACTIONS(3903),
    [anon_sym_COLON] = ACTIONS(3901),
    [anon_sym_DASH] = ACTIONS(3901),
    [aux_sym_boolean_token1] = ACTIONS(3901),
    [aux_sym_boolean_token2] = ACTIONS(3901),
    [sym_decimal] = ACTIONS(3901),
    [anon_sym_LPAREN] = ACTIONS(3903),
    [anon_sym_DOT_DOT] = ACTIONS(3903),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3901),
    [anon_sym_STAR] = ACTIONS(3901),
    [anon_sym_LBRACK] = ACTIONS(3903),
    [aux_sym_record_type_token1] = ACTIONS(3901),
    [aux_sym_basic_type_token21] = ACTIONS(3901),
    [aux_sym_basic_type_token22] = ACTIONS(3901),
    [aux_sym_basic_type_token48] = ACTIONS(3901),
    [anon_sym_POUNDif] = ACTIONS(3903),
    [anon_sym_POUNDIF] = ACTIONS(3903),
    [anon_sym_POUNDIf] = ACTIONS(3903),
    [anon_sym_not] = ACTIONS(3901),
    [anon_sym_NOT] = ACTIONS(3901),
    [anon_sym_Not] = ACTIONS(3901),
    [anon_sym_POUNDelif] = ACTIONS(3903),
    [anon_sym_POUNDELIF] = ACTIONS(3903),
    [anon_sym_POUNDElif] = ACTIONS(3903),
    [anon_sym_POUNDelse] = ACTIONS(3903),
    [anon_sym_POUNDELSE] = ACTIONS(3903),
    [anon_sym_POUNDElse] = ACTIONS(3903),
    [anon_sym_POUNDelse2] = ACTIONS(3903),
    [anon_sym_POUNDELSE2] = ACTIONS(3903),
    [anon_sym_POUNDElse2] = ACTIONS(3903),
    [anon_sym_POUNDendif] = ACTIONS(3903),
    [anon_sym_POUNDENDIF] = ACTIONS(3903),
    [anon_sym_POUNDEndif] = ACTIONS(3903),
    [anon_sym_POUNDendif2] = ACTIONS(3903),
    [anon_sym_POUNDENDIF2] = ACTIONS(3903),
    [anon_sym_POUNDEndif2] = ACTIONS(3903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3903),
    [aux_sym__expression_token1] = ACTIONS(3903),
    [aux_sym__expression_token2] = ACTIONS(3903),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3901),
    [anon_sym_SLASH] = ACTIONS(3901),
    [anon_sym_div] = ACTIONS(3901),
    [anon_sym_DIV] = ACTIONS(3901),
    [anon_sym_Div] = ACTIONS(3901),
    [anon_sym_mod] = ACTIONS(3901),
    [anon_sym_MOD] = ACTIONS(3901),
    [anon_sym_Mod] = ACTIONS(3901),
    [anon_sym_PLUS] = ACTIONS(3901),
    [anon_sym_GT_EQ] = ACTIONS(3903),
    [anon_sym_LT_EQ] = ACTIONS(3903),
    [anon_sym_GT] = ACTIONS(3901),
    [anon_sym_LT] = ACTIONS(3901),
    [anon_sym_LT_GT] = ACTIONS(3903),
    [anon_sym_and] = ACTIONS(3901),
    [anon_sym_AND] = ACTIONS(3901),
    [anon_sym_And] = ACTIONS(3901),
    [anon_sym_or] = ACTIONS(3901),
    [anon_sym_OR] = ACTIONS(3901),
    [anon_sym_Or] = ACTIONS(3901),
    [anon_sym_xor] = ACTIONS(3901),
    [anon_sym_XOR] = ACTIONS(3901),
    [anon_sym_Xor] = ACTIONS(3901),
    [anon_sym_QMARK] = ACTIONS(3903),
    [sym_datetime_literal] = ACTIONS(3903),
    [sym_date_literal] = ACTIONS(3901),
    [sym_time_literal] = ACTIONS(3901),
    [sym_biginteger_literal] = ACTIONS(3903),
    [anon_sym_else] = ACTIONS(3901),
    [anon_sym_ELSE] = ACTIONS(3901),
    [anon_sym_Else] = ACTIONS(3901),
    [anon_sym_in] = ACTIONS(3901),
    [anon_sym_IN] = ACTIONS(3901),
    [anon_sym_In] = ACTIONS(3901),
    [sym_page_keyword] = ACTIONS(3901),
    [anon_sym_codeunit] = ACTIONS(3901),
    [anon_sym_CODEUNIT] = ACTIONS(3901),
    [anon_sym_Codeunit] = ACTIONS(3901),
    [anon_sym_CodeUnit] = ACTIONS(3901),
    [anon_sym_COdeunit] = ACTIONS(3901),
    [anon_sym_codeUnit] = ACTIONS(3901),
    [sym_report_keyword] = ACTIONS(3901),
    [sym_query_keyword] = ACTIONS(3901),
    [anon_sym_xmlport] = ACTIONS(3901),
    [anon_sym_XMLPORT] = ACTIONS(3901),
    [anon_sym_Xmlport] = ACTIONS(3901),
    [anon_sym_XMLport] = ACTIONS(3901),
    [anon_sym_XMLPort] = ACTIONS(3901),
    [anon_sym_XmlPort] = ACTIONS(3901),
    [anon_sym_enum] = ACTIONS(3901),
    [anon_sym_ENUM] = ACTIONS(3901),
    [anon_sym_Enum] = ACTIONS(3901),
    [anon_sym_eNUM] = ACTIONS(3901),
    [anon_sym_eNum] = ACTIONS(3901),
    [anon_sym_ENum] = ACTIONS(3901),
    [sym_quoted_identifier] = ACTIONS(3903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3903),
    [sym_verbatim_string] = ACTIONS(3903),
    [sym_integer] = ACTIONS(3901),
    [sym_continue_as_identifier] = ACTIONS(3903),
    [sym_preproc_open] = ACTIONS(3903),
    [sym_preproc_close] = ACTIONS(3903),
  },
  [STATE(2350)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3720),
    [anon_sym_SEMI] = ACTIONS(3723),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(5305),
    [aux_sym_boolean_token1] = ACTIONS(3720),
    [aux_sym_boolean_token2] = ACTIONS(3720),
    [sym_decimal] = ACTIONS(3720),
    [anon_sym_LPAREN] = ACTIONS(3723),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3720),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(5287),
    [aux_sym_record_type_token1] = ACTIONS(3720),
    [aux_sym_basic_type_token21] = ACTIONS(3720),
    [aux_sym_basic_type_token22] = ACTIONS(3720),
    [aux_sym_basic_type_token48] = ACTIONS(3720),
    [anon_sym_POUNDif] = ACTIONS(3723),
    [anon_sym_POUNDIF] = ACTIONS(3723),
    [anon_sym_POUNDIf] = ACTIONS(3723),
    [anon_sym_not] = ACTIONS(3720),
    [anon_sym_NOT] = ACTIONS(3720),
    [anon_sym_Not] = ACTIONS(3720),
    [anon_sym_POUNDelif] = ACTIONS(3723),
    [anon_sym_POUNDELIF] = ACTIONS(3723),
    [anon_sym_POUNDElif] = ACTIONS(3723),
    [anon_sym_POUNDelse] = ACTIONS(3723),
    [anon_sym_POUNDELSE] = ACTIONS(3723),
    [anon_sym_POUNDElse] = ACTIONS(3723),
    [anon_sym_POUNDelse2] = ACTIONS(3723),
    [anon_sym_POUNDELSE2] = ACTIONS(3723),
    [anon_sym_POUNDElse2] = ACTIONS(3723),
    [anon_sym_POUNDendif] = ACTIONS(3723),
    [anon_sym_POUNDENDIF] = ACTIONS(3723),
    [anon_sym_POUNDEndif] = ACTIONS(3723),
    [anon_sym_POUNDendif2] = ACTIONS(3723),
    [anon_sym_POUNDENDIF2] = ACTIONS(3723),
    [anon_sym_POUNDEndif2] = ACTIONS(3723),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5307),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3720),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(5313),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(5321),
    [anon_sym_OR] = ACTIONS(5323),
    [anon_sym_Or] = ACTIONS(5325),
    [anon_sym_xor] = ACTIONS(5327),
    [anon_sym_XOR] = ACTIONS(5329),
    [anon_sym_Xor] = ACTIONS(5331),
    [anon_sym_QMARK] = ACTIONS(5333),
    [sym_datetime_literal] = ACTIONS(3723),
    [sym_date_literal] = ACTIONS(3720),
    [sym_time_literal] = ACTIONS(3720),
    [sym_biginteger_literal] = ACTIONS(3723),
    [anon_sym_else] = ACTIONS(3720),
    [anon_sym_ELSE] = ACTIONS(3720),
    [anon_sym_Else] = ACTIONS(3720),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3720),
    [anon_sym_codeunit] = ACTIONS(3720),
    [anon_sym_CODEUNIT] = ACTIONS(3720),
    [anon_sym_Codeunit] = ACTIONS(3720),
    [anon_sym_CodeUnit] = ACTIONS(3720),
    [anon_sym_COdeunit] = ACTIONS(3720),
    [anon_sym_codeUnit] = ACTIONS(3720),
    [sym_report_keyword] = ACTIONS(3720),
    [sym_query_keyword] = ACTIONS(3720),
    [anon_sym_xmlport] = ACTIONS(3720),
    [anon_sym_XMLPORT] = ACTIONS(3720),
    [anon_sym_Xmlport] = ACTIONS(3720),
    [anon_sym_XMLport] = ACTIONS(3720),
    [anon_sym_XMLPort] = ACTIONS(3720),
    [anon_sym_XmlPort] = ACTIONS(3720),
    [anon_sym_enum] = ACTIONS(3720),
    [anon_sym_ENUM] = ACTIONS(3720),
    [anon_sym_Enum] = ACTIONS(3720),
    [anon_sym_eNUM] = ACTIONS(3720),
    [anon_sym_eNum] = ACTIONS(3720),
    [anon_sym_ENum] = ACTIONS(3720),
    [sym_quoted_identifier] = ACTIONS(3723),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3723),
    [sym_verbatim_string] = ACTIONS(3723),
    [sym_integer] = ACTIONS(3720),
    [sym_continue_as_identifier] = ACTIONS(3723),
    [sym_preproc_open] = ACTIONS(3723),
    [sym_preproc_close] = ACTIONS(3723),
  },
  [STATE(2351)] = {
    [sym_identifier] = ACTIONS(3905),
    [anon_sym_SEMI] = ACTIONS(3907),
    [anon_sym_DOT] = ACTIONS(3905),
    [anon_sym_EQ] = ACTIONS(3907),
    [anon_sym_COMMA] = ACTIONS(3907),
    [anon_sym_COLON] = ACTIONS(3905),
    [anon_sym_DASH] = ACTIONS(3905),
    [aux_sym_boolean_token1] = ACTIONS(3905),
    [aux_sym_boolean_token2] = ACTIONS(3905),
    [sym_decimal] = ACTIONS(3905),
    [anon_sym_LPAREN] = ACTIONS(3907),
    [anon_sym_DOT_DOT] = ACTIONS(3907),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3905),
    [anon_sym_STAR] = ACTIONS(3905),
    [anon_sym_LBRACK] = ACTIONS(3907),
    [aux_sym_record_type_token1] = ACTIONS(3905),
    [aux_sym_basic_type_token21] = ACTIONS(3905),
    [aux_sym_basic_type_token22] = ACTIONS(3905),
    [aux_sym_basic_type_token48] = ACTIONS(3905),
    [anon_sym_POUNDif] = ACTIONS(3907),
    [anon_sym_POUNDIF] = ACTIONS(3907),
    [anon_sym_POUNDIf] = ACTIONS(3907),
    [anon_sym_not] = ACTIONS(3905),
    [anon_sym_NOT] = ACTIONS(3905),
    [anon_sym_Not] = ACTIONS(3905),
    [anon_sym_POUNDelif] = ACTIONS(3907),
    [anon_sym_POUNDELIF] = ACTIONS(3907),
    [anon_sym_POUNDElif] = ACTIONS(3907),
    [anon_sym_POUNDelse] = ACTIONS(3907),
    [anon_sym_POUNDELSE] = ACTIONS(3907),
    [anon_sym_POUNDElse] = ACTIONS(3907),
    [anon_sym_POUNDelse2] = ACTIONS(3907),
    [anon_sym_POUNDELSE2] = ACTIONS(3907),
    [anon_sym_POUNDElse2] = ACTIONS(3907),
    [anon_sym_POUNDendif] = ACTIONS(3907),
    [anon_sym_POUNDENDIF] = ACTIONS(3907),
    [anon_sym_POUNDEndif] = ACTIONS(3907),
    [anon_sym_POUNDendif2] = ACTIONS(3907),
    [anon_sym_POUNDENDIF2] = ACTIONS(3907),
    [anon_sym_POUNDEndif2] = ACTIONS(3907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3907),
    [aux_sym__expression_token1] = ACTIONS(3907),
    [aux_sym__expression_token2] = ACTIONS(3907),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3905),
    [anon_sym_SLASH] = ACTIONS(3905),
    [anon_sym_div] = ACTIONS(3905),
    [anon_sym_DIV] = ACTIONS(3905),
    [anon_sym_Div] = ACTIONS(3905),
    [anon_sym_mod] = ACTIONS(3905),
    [anon_sym_MOD] = ACTIONS(3905),
    [anon_sym_Mod] = ACTIONS(3905),
    [anon_sym_PLUS] = ACTIONS(3905),
    [anon_sym_GT_EQ] = ACTIONS(3907),
    [anon_sym_LT_EQ] = ACTIONS(3907),
    [anon_sym_GT] = ACTIONS(3905),
    [anon_sym_LT] = ACTIONS(3905),
    [anon_sym_LT_GT] = ACTIONS(3907),
    [anon_sym_and] = ACTIONS(3905),
    [anon_sym_AND] = ACTIONS(3905),
    [anon_sym_And] = ACTIONS(3905),
    [anon_sym_or] = ACTIONS(3905),
    [anon_sym_OR] = ACTIONS(3905),
    [anon_sym_Or] = ACTIONS(3905),
    [anon_sym_xor] = ACTIONS(3905),
    [anon_sym_XOR] = ACTIONS(3905),
    [anon_sym_Xor] = ACTIONS(3905),
    [anon_sym_QMARK] = ACTIONS(3907),
    [sym_datetime_literal] = ACTIONS(3907),
    [sym_date_literal] = ACTIONS(3905),
    [sym_time_literal] = ACTIONS(3905),
    [sym_biginteger_literal] = ACTIONS(3907),
    [anon_sym_else] = ACTIONS(3905),
    [anon_sym_ELSE] = ACTIONS(3905),
    [anon_sym_Else] = ACTIONS(3905),
    [anon_sym_in] = ACTIONS(3905),
    [anon_sym_IN] = ACTIONS(3905),
    [anon_sym_In] = ACTIONS(3905),
    [sym_page_keyword] = ACTIONS(3905),
    [anon_sym_codeunit] = ACTIONS(3905),
    [anon_sym_CODEUNIT] = ACTIONS(3905),
    [anon_sym_Codeunit] = ACTIONS(3905),
    [anon_sym_CodeUnit] = ACTIONS(3905),
    [anon_sym_COdeunit] = ACTIONS(3905),
    [anon_sym_codeUnit] = ACTIONS(3905),
    [sym_report_keyword] = ACTIONS(3905),
    [sym_query_keyword] = ACTIONS(3905),
    [anon_sym_xmlport] = ACTIONS(3905),
    [anon_sym_XMLPORT] = ACTIONS(3905),
    [anon_sym_Xmlport] = ACTIONS(3905),
    [anon_sym_XMLport] = ACTIONS(3905),
    [anon_sym_XMLPort] = ACTIONS(3905),
    [anon_sym_XmlPort] = ACTIONS(3905),
    [anon_sym_enum] = ACTIONS(3905),
    [anon_sym_ENUM] = ACTIONS(3905),
    [anon_sym_Enum] = ACTIONS(3905),
    [anon_sym_eNUM] = ACTIONS(3905),
    [anon_sym_eNum] = ACTIONS(3905),
    [anon_sym_ENum] = ACTIONS(3905),
    [sym_quoted_identifier] = ACTIONS(3907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3907),
    [sym_verbatim_string] = ACTIONS(3907),
    [sym_integer] = ACTIONS(3905),
    [sym_continue_as_identifier] = ACTIONS(3907),
    [sym_preproc_open] = ACTIONS(3907),
    [sym_preproc_close] = ACTIONS(3907),
  },
  [STATE(2352)] = {
    [sym_identifier] = ACTIONS(3913),
    [anon_sym_SEMI] = ACTIONS(3915),
    [anon_sym_DOT] = ACTIONS(3913),
    [anon_sym_EQ] = ACTIONS(3915),
    [anon_sym_COMMA] = ACTIONS(3915),
    [anon_sym_COLON] = ACTIONS(3913),
    [anon_sym_DASH] = ACTIONS(3913),
    [aux_sym_boolean_token1] = ACTIONS(3913),
    [aux_sym_boolean_token2] = ACTIONS(3913),
    [sym_decimal] = ACTIONS(3913),
    [anon_sym_LPAREN] = ACTIONS(3915),
    [anon_sym_DOT_DOT] = ACTIONS(3915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3913),
    [anon_sym_STAR] = ACTIONS(3913),
    [anon_sym_LBRACK] = ACTIONS(3915),
    [aux_sym_record_type_token1] = ACTIONS(3913),
    [aux_sym_basic_type_token21] = ACTIONS(3913),
    [aux_sym_basic_type_token22] = ACTIONS(3913),
    [aux_sym_basic_type_token48] = ACTIONS(3913),
    [anon_sym_POUNDif] = ACTIONS(3915),
    [anon_sym_POUNDIF] = ACTIONS(3915),
    [anon_sym_POUNDIf] = ACTIONS(3915),
    [anon_sym_not] = ACTIONS(3913),
    [anon_sym_NOT] = ACTIONS(3913),
    [anon_sym_Not] = ACTIONS(3913),
    [anon_sym_POUNDelif] = ACTIONS(3915),
    [anon_sym_POUNDELIF] = ACTIONS(3915),
    [anon_sym_POUNDElif] = ACTIONS(3915),
    [anon_sym_POUNDelse] = ACTIONS(3915),
    [anon_sym_POUNDELSE] = ACTIONS(3915),
    [anon_sym_POUNDElse] = ACTIONS(3915),
    [anon_sym_POUNDelse2] = ACTIONS(3915),
    [anon_sym_POUNDELSE2] = ACTIONS(3915),
    [anon_sym_POUNDElse2] = ACTIONS(3915),
    [anon_sym_POUNDendif] = ACTIONS(3915),
    [anon_sym_POUNDENDIF] = ACTIONS(3915),
    [anon_sym_POUNDEndif] = ACTIONS(3915),
    [anon_sym_POUNDendif2] = ACTIONS(3915),
    [anon_sym_POUNDENDIF2] = ACTIONS(3915),
    [anon_sym_POUNDEndif2] = ACTIONS(3915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3915),
    [aux_sym__expression_token1] = ACTIONS(3915),
    [aux_sym__expression_token2] = ACTIONS(3915),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3913),
    [anon_sym_SLASH] = ACTIONS(3913),
    [anon_sym_div] = ACTIONS(3913),
    [anon_sym_DIV] = ACTIONS(3913),
    [anon_sym_Div] = ACTIONS(3913),
    [anon_sym_mod] = ACTIONS(3913),
    [anon_sym_MOD] = ACTIONS(3913),
    [anon_sym_Mod] = ACTIONS(3913),
    [anon_sym_PLUS] = ACTIONS(3913),
    [anon_sym_GT_EQ] = ACTIONS(3915),
    [anon_sym_LT_EQ] = ACTIONS(3915),
    [anon_sym_GT] = ACTIONS(3913),
    [anon_sym_LT] = ACTIONS(3913),
    [anon_sym_LT_GT] = ACTIONS(3915),
    [anon_sym_and] = ACTIONS(3913),
    [anon_sym_AND] = ACTIONS(3913),
    [anon_sym_And] = ACTIONS(3913),
    [anon_sym_or] = ACTIONS(3913),
    [anon_sym_OR] = ACTIONS(3913),
    [anon_sym_Or] = ACTIONS(3913),
    [anon_sym_xor] = ACTIONS(3913),
    [anon_sym_XOR] = ACTIONS(3913),
    [anon_sym_Xor] = ACTIONS(3913),
    [anon_sym_QMARK] = ACTIONS(3915),
    [sym_datetime_literal] = ACTIONS(3915),
    [sym_date_literal] = ACTIONS(3913),
    [sym_time_literal] = ACTIONS(3913),
    [sym_biginteger_literal] = ACTIONS(3915),
    [anon_sym_else] = ACTIONS(3913),
    [anon_sym_ELSE] = ACTIONS(3913),
    [anon_sym_Else] = ACTIONS(3913),
    [anon_sym_in] = ACTIONS(3913),
    [anon_sym_IN] = ACTIONS(3913),
    [anon_sym_In] = ACTIONS(3913),
    [sym_page_keyword] = ACTIONS(3913),
    [anon_sym_codeunit] = ACTIONS(3913),
    [anon_sym_CODEUNIT] = ACTIONS(3913),
    [anon_sym_Codeunit] = ACTIONS(3913),
    [anon_sym_CodeUnit] = ACTIONS(3913),
    [anon_sym_COdeunit] = ACTIONS(3913),
    [anon_sym_codeUnit] = ACTIONS(3913),
    [sym_report_keyword] = ACTIONS(3913),
    [sym_query_keyword] = ACTIONS(3913),
    [anon_sym_xmlport] = ACTIONS(3913),
    [anon_sym_XMLPORT] = ACTIONS(3913),
    [anon_sym_Xmlport] = ACTIONS(3913),
    [anon_sym_XMLport] = ACTIONS(3913),
    [anon_sym_XMLPort] = ACTIONS(3913),
    [anon_sym_XmlPort] = ACTIONS(3913),
    [anon_sym_enum] = ACTIONS(3913),
    [anon_sym_ENUM] = ACTIONS(3913),
    [anon_sym_Enum] = ACTIONS(3913),
    [anon_sym_eNUM] = ACTIONS(3913),
    [anon_sym_eNum] = ACTIONS(3913),
    [anon_sym_ENum] = ACTIONS(3913),
    [sym_quoted_identifier] = ACTIONS(3915),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3915),
    [sym_verbatim_string] = ACTIONS(3915),
    [sym_integer] = ACTIONS(3913),
    [sym_continue_as_identifier] = ACTIONS(3915),
    [sym_preproc_open] = ACTIONS(3915),
    [sym_preproc_close] = ACTIONS(3915),
  },
  [STATE(2353)] = {
    [sym_identifier] = ACTIONS(3917),
    [anon_sym_SEMI] = ACTIONS(3919),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_EQ] = ACTIONS(3919),
    [anon_sym_COMMA] = ACTIONS(3919),
    [anon_sym_COLON] = ACTIONS(3917),
    [anon_sym_DASH] = ACTIONS(3917),
    [aux_sym_boolean_token1] = ACTIONS(3917),
    [aux_sym_boolean_token2] = ACTIONS(3917),
    [sym_decimal] = ACTIONS(3917),
    [anon_sym_LPAREN] = ACTIONS(3919),
    [anon_sym_DOT_DOT] = ACTIONS(3919),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3919),
    [aux_sym_record_type_token1] = ACTIONS(3917),
    [aux_sym_basic_type_token21] = ACTIONS(3917),
    [aux_sym_basic_type_token22] = ACTIONS(3917),
    [aux_sym_basic_type_token48] = ACTIONS(3917),
    [anon_sym_POUNDif] = ACTIONS(3919),
    [anon_sym_POUNDIF] = ACTIONS(3919),
    [anon_sym_POUNDIf] = ACTIONS(3919),
    [anon_sym_not] = ACTIONS(3917),
    [anon_sym_NOT] = ACTIONS(3917),
    [anon_sym_Not] = ACTIONS(3917),
    [anon_sym_POUNDelif] = ACTIONS(3919),
    [anon_sym_POUNDELIF] = ACTIONS(3919),
    [anon_sym_POUNDElif] = ACTIONS(3919),
    [anon_sym_POUNDelse] = ACTIONS(3919),
    [anon_sym_POUNDELSE] = ACTIONS(3919),
    [anon_sym_POUNDElse] = ACTIONS(3919),
    [anon_sym_POUNDelse2] = ACTIONS(3919),
    [anon_sym_POUNDELSE2] = ACTIONS(3919),
    [anon_sym_POUNDElse2] = ACTIONS(3919),
    [anon_sym_POUNDendif] = ACTIONS(3919),
    [anon_sym_POUNDENDIF] = ACTIONS(3919),
    [anon_sym_POUNDEndif] = ACTIONS(3919),
    [anon_sym_POUNDendif2] = ACTIONS(3919),
    [anon_sym_POUNDENDIF2] = ACTIONS(3919),
    [anon_sym_POUNDEndif2] = ACTIONS(3919),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3919),
    [aux_sym__expression_token1] = ACTIONS(3919),
    [aux_sym__expression_token2] = ACTIONS(3919),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_div] = ACTIONS(3917),
    [anon_sym_DIV] = ACTIONS(3917),
    [anon_sym_Div] = ACTIONS(3917),
    [anon_sym_mod] = ACTIONS(3917),
    [anon_sym_MOD] = ACTIONS(3917),
    [anon_sym_Mod] = ACTIONS(3917),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3919),
    [anon_sym_LT_EQ] = ACTIONS(3919),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_LT_GT] = ACTIONS(3919),
    [anon_sym_and] = ACTIONS(3917),
    [anon_sym_AND] = ACTIONS(3917),
    [anon_sym_And] = ACTIONS(3917),
    [anon_sym_or] = ACTIONS(3917),
    [anon_sym_OR] = ACTIONS(3917),
    [anon_sym_Or] = ACTIONS(3917),
    [anon_sym_xor] = ACTIONS(3917),
    [anon_sym_XOR] = ACTIONS(3917),
    [anon_sym_Xor] = ACTIONS(3917),
    [anon_sym_QMARK] = ACTIONS(3919),
    [sym_datetime_literal] = ACTIONS(3919),
    [sym_date_literal] = ACTIONS(3917),
    [sym_time_literal] = ACTIONS(3917),
    [sym_biginteger_literal] = ACTIONS(3919),
    [anon_sym_else] = ACTIONS(3917),
    [anon_sym_ELSE] = ACTIONS(3917),
    [anon_sym_Else] = ACTIONS(3917),
    [anon_sym_in] = ACTIONS(3917),
    [anon_sym_IN] = ACTIONS(3917),
    [anon_sym_In] = ACTIONS(3917),
    [sym_page_keyword] = ACTIONS(3917),
    [anon_sym_codeunit] = ACTIONS(3917),
    [anon_sym_CODEUNIT] = ACTIONS(3917),
    [anon_sym_Codeunit] = ACTIONS(3917),
    [anon_sym_CodeUnit] = ACTIONS(3917),
    [anon_sym_COdeunit] = ACTIONS(3917),
    [anon_sym_codeUnit] = ACTIONS(3917),
    [sym_report_keyword] = ACTIONS(3917),
    [sym_query_keyword] = ACTIONS(3917),
    [anon_sym_xmlport] = ACTIONS(3917),
    [anon_sym_XMLPORT] = ACTIONS(3917),
    [anon_sym_Xmlport] = ACTIONS(3917),
    [anon_sym_XMLport] = ACTIONS(3917),
    [anon_sym_XMLPort] = ACTIONS(3917),
    [anon_sym_XmlPort] = ACTIONS(3917),
    [anon_sym_enum] = ACTIONS(3917),
    [anon_sym_ENUM] = ACTIONS(3917),
    [anon_sym_Enum] = ACTIONS(3917),
    [anon_sym_eNUM] = ACTIONS(3917),
    [anon_sym_eNum] = ACTIONS(3917),
    [anon_sym_ENum] = ACTIONS(3917),
    [sym_quoted_identifier] = ACTIONS(3919),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3919),
    [sym_verbatim_string] = ACTIONS(3919),
    [sym_integer] = ACTIONS(3917),
    [sym_continue_as_identifier] = ACTIONS(3919),
    [sym_preproc_open] = ACTIONS(3919),
    [sym_preproc_close] = ACTIONS(3919),
  },
  [STATE(2354)] = {
    [sym_comparison_operator] = STATE(4640),
    [sym_in_keyword] = STATE(16536),
    [sym_identifier] = ACTIONS(3716),
    [anon_sym_SEMI] = ACTIONS(3718),
    [anon_sym_DOT] = ACTIONS(5281),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3716),
    [aux_sym_boolean_token1] = ACTIONS(3716),
    [aux_sym_boolean_token2] = ACTIONS(3716),
    [sym_decimal] = ACTIONS(3716),
    [anon_sym_LPAREN] = ACTIONS(3718),
    [anon_sym_DOT_DOT] = ACTIONS(5283),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3716),
    [anon_sym_STAR] = ACTIONS(5285),
    [anon_sym_LBRACK] = ACTIONS(3718),
    [aux_sym_record_type_token1] = ACTIONS(3716),
    [aux_sym_basic_type_token21] = ACTIONS(3716),
    [aux_sym_basic_type_token22] = ACTIONS(3716),
    [aux_sym_basic_type_token48] = ACTIONS(3716),
    [anon_sym_POUNDif] = ACTIONS(3718),
    [anon_sym_POUNDIF] = ACTIONS(3718),
    [anon_sym_POUNDIf] = ACTIONS(3718),
    [anon_sym_not] = ACTIONS(3716),
    [anon_sym_NOT] = ACTIONS(3716),
    [anon_sym_Not] = ACTIONS(3716),
    [anon_sym_POUNDelif] = ACTIONS(3718),
    [anon_sym_POUNDELIF] = ACTIONS(3718),
    [anon_sym_POUNDElif] = ACTIONS(3718),
    [anon_sym_POUNDelse] = ACTIONS(3718),
    [anon_sym_POUNDELSE] = ACTIONS(3718),
    [anon_sym_POUNDElse] = ACTIONS(3718),
    [anon_sym_POUNDelse2] = ACTIONS(3718),
    [anon_sym_POUNDELSE2] = ACTIONS(3718),
    [anon_sym_POUNDElse2] = ACTIONS(3718),
    [anon_sym_POUNDendif] = ACTIONS(3718),
    [anon_sym_POUNDENDIF] = ACTIONS(3718),
    [anon_sym_POUNDEndif] = ACTIONS(3718),
    [anon_sym_POUNDendif2] = ACTIONS(3718),
    [anon_sym_POUNDENDIF2] = ACTIONS(3718),
    [anon_sym_POUNDEndif2] = ACTIONS(3718),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(5307),
    [aux_sym__expression_token1] = ACTIONS(5309),
    [aux_sym__expression_token2] = ACTIONS(5311),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3716),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3716),
    [anon_sym_SLASH] = ACTIONS(5289),
    [anon_sym_div] = ACTIONS(5291),
    [anon_sym_DIV] = ACTIONS(5293),
    [anon_sym_Div] = ACTIONS(5295),
    [anon_sym_mod] = ACTIONS(5297),
    [anon_sym_MOD] = ACTIONS(5299),
    [anon_sym_Mod] = ACTIONS(5301),
    [anon_sym_PLUS] = ACTIONS(3716),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_AND] = ACTIONS(5317),
    [anon_sym_And] = ACTIONS(5319),
    [anon_sym_or] = ACTIONS(5321),
    [anon_sym_OR] = ACTIONS(5323),
    [anon_sym_Or] = ACTIONS(5325),
    [anon_sym_xor] = ACTIONS(5327),
    [anon_sym_XOR] = ACTIONS(5329),
    [anon_sym_Xor] = ACTIONS(5331),
    [anon_sym_QMARK] = ACTIONS(5333),
    [sym_datetime_literal] = ACTIONS(3718),
    [sym_date_literal] = ACTIONS(3716),
    [sym_time_literal] = ACTIONS(3716),
    [sym_biginteger_literal] = ACTIONS(3718),
    [anon_sym_else] = ACTIONS(3716),
    [anon_sym_ELSE] = ACTIONS(3716),
    [anon_sym_Else] = ACTIONS(3716),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3716),
    [anon_sym_codeunit] = ACTIONS(3716),
    [anon_sym_CODEUNIT] = ACTIONS(3716),
    [anon_sym_Codeunit] = ACTIONS(3716),
    [anon_sym_CodeUnit] = ACTIONS(3716),
    [anon_sym_COdeunit] = ACTIONS(3716),
    [anon_sym_codeUnit] = ACTIONS(3716),
    [sym_report_keyword] = ACTIONS(3716),
    [sym_query_keyword] = ACTIONS(3716),
    [anon_sym_xmlport] = ACTIONS(3716),
    [anon_sym_XMLPORT] = ACTIONS(3716),
    [anon_sym_Xmlport] = ACTIONS(3716),
    [anon_sym_XMLport] = ACTIONS(3716),
    [anon_sym_XMLPort] = ACTIONS(3716),
    [anon_sym_XmlPort] = ACTIONS(3716),
    [anon_sym_enum] = ACTIONS(3716),
    [anon_sym_ENUM] = ACTIONS(3716),
    [anon_sym_Enum] = ACTIONS(3716),
    [anon_sym_eNUM] = ACTIONS(3716),
    [anon_sym_eNum] = ACTIONS(3716),
    [anon_sym_ENum] = ACTIONS(3716),
    [sym_quoted_identifier] = ACTIONS(3718),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3718),
    [sym_verbatim_string] = ACTIONS(3718),
    [sym_integer] = ACTIONS(3716),
    [sym_continue_as_identifier] = ACTIONS(3718),
    [sym_preproc_open] = ACTIONS(3718),
    [sym_preproc_close] = ACTIONS(3718),
  },
  [STATE(2355)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_COLON] = ACTIONS(3865),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(2356)] = {
    [sym_else_keyword] = STATE(645),
    [sym_identifier] = ACTIONS(5431),
    [anon_sym_SEMI] = ACTIONS(5433),
    [anon_sym_DASH] = ACTIONS(5433),
    [aux_sym_boolean_token1] = ACTIONS(5431),
    [aux_sym_boolean_token2] = ACTIONS(5431),
    [sym_decimal] = ACTIONS(5431),
    [anon_sym_LPAREN] = ACTIONS(5433),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5431),
    [anon_sym_LBRACK] = ACTIONS(5433),
    [aux_sym_record_type_token1] = ACTIONS(5431),
    [aux_sym_basic_type_token21] = ACTIONS(5431),
    [aux_sym_basic_type_token22] = ACTIONS(5431),
    [aux_sym_basic_type_token48] = ACTIONS(5431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5431),
    [anon_sym_POUNDif] = ACTIONS(5433),
    [anon_sym_POUNDIF] = ACTIONS(5433),
    [anon_sym_POUNDIf] = ACTIONS(5433),
    [anon_sym_not] = ACTIONS(5431),
    [anon_sym_NOT] = ACTIONS(5431),
    [anon_sym_Not] = ACTIONS(5431),
    [anon_sym_POUNDelif] = ACTIONS(5433),
    [anon_sym_POUNDELIF] = ACTIONS(5433),
    [anon_sym_POUNDElif] = ACTIONS(5433),
    [anon_sym_POUNDelse] = ACTIONS(5433),
    [anon_sym_POUNDELSE] = ACTIONS(5433),
    [anon_sym_POUNDElse] = ACTIONS(5433),
    [anon_sym_POUNDelse2] = ACTIONS(5433),
    [anon_sym_POUNDELSE2] = ACTIONS(5433),
    [anon_sym_POUNDElse2] = ACTIONS(5433),
    [anon_sym_POUNDendif] = ACTIONS(5433),
    [anon_sym_POUNDENDIF] = ACTIONS(5433),
    [anon_sym_POUNDEndif] = ACTIONS(5433),
    [anon_sym_POUNDendif2] = ACTIONS(5433),
    [anon_sym_POUNDENDIF2] = ACTIONS(5433),
    [anon_sym_POUNDEndif2] = ACTIONS(5433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5431),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5431),
    [anon_sym_PLUS] = ACTIONS(5433),
    [sym_datetime_literal] = ACTIONS(5433),
    [sym_date_literal] = ACTIONS(5431),
    [sym_time_literal] = ACTIONS(5431),
    [sym_biginteger_literal] = ACTIONS(5433),
    [anon_sym_if] = ACTIONS(5431),
    [anon_sym_IF] = ACTIONS(5431),
    [anon_sym_If] = ACTIONS(5431),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5431),
    [anon_sym_CASE] = ACTIONS(5431),
    [anon_sym_Case] = ACTIONS(5431),
    [anon_sym_for] = ACTIONS(5431),
    [anon_sym_FOR] = ACTIONS(5431),
    [anon_sym_For] = ACTIONS(5431),
    [anon_sym_foreach] = ACTIONS(5431),
    [anon_sym_FOREACH] = ACTIONS(5431),
    [anon_sym_Foreach] = ACTIONS(5431),
    [anon_sym_while] = ACTIONS(5431),
    [anon_sym_WHILE] = ACTIONS(5431),
    [anon_sym_While] = ACTIONS(5431),
    [anon_sym_repeat] = ACTIONS(5431),
    [anon_sym_REPEAT] = ACTIONS(5431),
    [anon_sym_Repeat] = ACTIONS(5431),
    [anon_sym_exit] = ACTIONS(5431),
    [anon_sym_EXIT] = ACTIONS(5431),
    [anon_sym_Exit] = ACTIONS(5431),
    [anon_sym_continue] = ACTIONS(5431),
    [anon_sym_CONTINUE] = ACTIONS(5431),
    [anon_sym_Continue] = ACTIONS(5431),
    [anon_sym_break] = ACTIONS(5431),
    [anon_sym_BREAK] = ACTIONS(5431),
    [anon_sym_Break] = ACTIONS(5431),
    [anon_sym_with] = ACTIONS(5431),
    [anon_sym_WITH] = ACTIONS(5431),
    [anon_sym_With] = ACTIONS(5431),
    [sym_asserterror_keyword] = ACTIONS(5433),
    [sym_page_keyword] = ACTIONS(5431),
    [anon_sym_codeunit] = ACTIONS(5431),
    [anon_sym_CODEUNIT] = ACTIONS(5431),
    [anon_sym_Codeunit] = ACTIONS(5431),
    [anon_sym_CodeUnit] = ACTIONS(5431),
    [anon_sym_COdeunit] = ACTIONS(5431),
    [anon_sym_codeUnit] = ACTIONS(5431),
    [sym_report_keyword] = ACTIONS(5431),
    [sym_query_keyword] = ACTIONS(5431),
    [anon_sym_xmlport] = ACTIONS(5431),
    [anon_sym_XMLPORT] = ACTIONS(5431),
    [anon_sym_Xmlport] = ACTIONS(5431),
    [anon_sym_XMLport] = ACTIONS(5431),
    [anon_sym_XMLPort] = ACTIONS(5431),
    [anon_sym_XmlPort] = ACTIONS(5431),
    [anon_sym_enum] = ACTIONS(5431),
    [anon_sym_ENUM] = ACTIONS(5431),
    [anon_sym_Enum] = ACTIONS(5431),
    [anon_sym_eNUM] = ACTIONS(5431),
    [anon_sym_eNum] = ACTIONS(5431),
    [anon_sym_ENum] = ACTIONS(5431),
    [sym_quoted_identifier] = ACTIONS(5433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5433),
    [sym_verbatim_string] = ACTIONS(5433),
    [sym_integer] = ACTIONS(5431),
    [sym_continue_as_identifier] = ACTIONS(5433),
    [sym_preproc_open] = ACTIONS(5433),
    [sym_preproc_close] = ACTIONS(5433),
  },
  [STATE(2357)] = {
    [sym_else_keyword] = STATE(652),
    [sym_identifier] = ACTIONS(5437),
    [anon_sym_SEMI] = ACTIONS(5439),
    [anon_sym_DASH] = ACTIONS(5439),
    [aux_sym_boolean_token1] = ACTIONS(5437),
    [aux_sym_boolean_token2] = ACTIONS(5437),
    [sym_decimal] = ACTIONS(5437),
    [anon_sym_LPAREN] = ACTIONS(5439),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5437),
    [anon_sym_LBRACK] = ACTIONS(5439),
    [aux_sym_record_type_token1] = ACTIONS(5437),
    [aux_sym_basic_type_token21] = ACTIONS(5437),
    [aux_sym_basic_type_token22] = ACTIONS(5437),
    [aux_sym_basic_type_token48] = ACTIONS(5437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5437),
    [anon_sym_POUNDif] = ACTIONS(5439),
    [anon_sym_POUNDIF] = ACTIONS(5439),
    [anon_sym_POUNDIf] = ACTIONS(5439),
    [anon_sym_not] = ACTIONS(5437),
    [anon_sym_NOT] = ACTIONS(5437),
    [anon_sym_Not] = ACTIONS(5437),
    [anon_sym_POUNDelif] = ACTIONS(5439),
    [anon_sym_POUNDELIF] = ACTIONS(5439),
    [anon_sym_POUNDElif] = ACTIONS(5439),
    [anon_sym_POUNDelse] = ACTIONS(5439),
    [anon_sym_POUNDELSE] = ACTIONS(5439),
    [anon_sym_POUNDElse] = ACTIONS(5439),
    [anon_sym_POUNDelse2] = ACTIONS(5439),
    [anon_sym_POUNDELSE2] = ACTIONS(5439),
    [anon_sym_POUNDElse2] = ACTIONS(5439),
    [anon_sym_POUNDendif] = ACTIONS(5439),
    [anon_sym_POUNDENDIF] = ACTIONS(5439),
    [anon_sym_POUNDEndif] = ACTIONS(5439),
    [anon_sym_POUNDendif2] = ACTIONS(5439),
    [anon_sym_POUNDENDIF2] = ACTIONS(5439),
    [anon_sym_POUNDEndif2] = ACTIONS(5439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5437),
    [anon_sym_PLUS] = ACTIONS(5439),
    [sym_datetime_literal] = ACTIONS(5439),
    [sym_date_literal] = ACTIONS(5437),
    [sym_time_literal] = ACTIONS(5437),
    [sym_biginteger_literal] = ACTIONS(5439),
    [anon_sym_if] = ACTIONS(5437),
    [anon_sym_IF] = ACTIONS(5437),
    [anon_sym_If] = ACTIONS(5437),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5437),
    [anon_sym_CASE] = ACTIONS(5437),
    [anon_sym_Case] = ACTIONS(5437),
    [anon_sym_for] = ACTIONS(5437),
    [anon_sym_FOR] = ACTIONS(5437),
    [anon_sym_For] = ACTIONS(5437),
    [anon_sym_foreach] = ACTIONS(5437),
    [anon_sym_FOREACH] = ACTIONS(5437),
    [anon_sym_Foreach] = ACTIONS(5437),
    [anon_sym_while] = ACTIONS(5437),
    [anon_sym_WHILE] = ACTIONS(5437),
    [anon_sym_While] = ACTIONS(5437),
    [anon_sym_repeat] = ACTIONS(5437),
    [anon_sym_REPEAT] = ACTIONS(5437),
    [anon_sym_Repeat] = ACTIONS(5437),
    [anon_sym_exit] = ACTIONS(5437),
    [anon_sym_EXIT] = ACTIONS(5437),
    [anon_sym_Exit] = ACTIONS(5437),
    [anon_sym_continue] = ACTIONS(5437),
    [anon_sym_CONTINUE] = ACTIONS(5437),
    [anon_sym_Continue] = ACTIONS(5437),
    [anon_sym_break] = ACTIONS(5437),
    [anon_sym_BREAK] = ACTIONS(5437),
    [anon_sym_Break] = ACTIONS(5437),
    [anon_sym_with] = ACTIONS(5437),
    [anon_sym_WITH] = ACTIONS(5437),
    [anon_sym_With] = ACTIONS(5437),
    [sym_asserterror_keyword] = ACTIONS(5439),
    [sym_page_keyword] = ACTIONS(5437),
    [anon_sym_codeunit] = ACTIONS(5437),
    [anon_sym_CODEUNIT] = ACTIONS(5437),
    [anon_sym_Codeunit] = ACTIONS(5437),
    [anon_sym_CodeUnit] = ACTIONS(5437),
    [anon_sym_COdeunit] = ACTIONS(5437),
    [anon_sym_codeUnit] = ACTIONS(5437),
    [sym_report_keyword] = ACTIONS(5437),
    [sym_query_keyword] = ACTIONS(5437),
    [anon_sym_xmlport] = ACTIONS(5437),
    [anon_sym_XMLPORT] = ACTIONS(5437),
    [anon_sym_Xmlport] = ACTIONS(5437),
    [anon_sym_XMLport] = ACTIONS(5437),
    [anon_sym_XMLPort] = ACTIONS(5437),
    [anon_sym_XmlPort] = ACTIONS(5437),
    [anon_sym_enum] = ACTIONS(5437),
    [anon_sym_ENUM] = ACTIONS(5437),
    [anon_sym_Enum] = ACTIONS(5437),
    [anon_sym_eNUM] = ACTIONS(5437),
    [anon_sym_eNum] = ACTIONS(5437),
    [anon_sym_ENum] = ACTIONS(5437),
    [sym_quoted_identifier] = ACTIONS(5439),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5439),
    [sym_verbatim_string] = ACTIONS(5439),
    [sym_integer] = ACTIONS(5437),
    [sym_continue_as_identifier] = ACTIONS(5439),
    [sym_preproc_open] = ACTIONS(5439),
    [sym_preproc_close] = ACTIONS(5439),
  },
  [STATE(2358)] = {
    [sym_else_keyword] = STATE(644),
    [sym_identifier] = ACTIONS(5441),
    [anon_sym_SEMI] = ACTIONS(5443),
    [anon_sym_DASH] = ACTIONS(5443),
    [aux_sym_boolean_token1] = ACTIONS(5441),
    [aux_sym_boolean_token2] = ACTIONS(5441),
    [sym_decimal] = ACTIONS(5441),
    [anon_sym_LPAREN] = ACTIONS(5443),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5441),
    [anon_sym_LBRACK] = ACTIONS(5443),
    [aux_sym_record_type_token1] = ACTIONS(5441),
    [aux_sym_basic_type_token21] = ACTIONS(5441),
    [aux_sym_basic_type_token22] = ACTIONS(5441),
    [aux_sym_basic_type_token48] = ACTIONS(5441),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5441),
    [anon_sym_POUNDif] = ACTIONS(5443),
    [anon_sym_POUNDIF] = ACTIONS(5443),
    [anon_sym_POUNDIf] = ACTIONS(5443),
    [anon_sym_not] = ACTIONS(5441),
    [anon_sym_NOT] = ACTIONS(5441),
    [anon_sym_Not] = ACTIONS(5441),
    [anon_sym_POUNDelif] = ACTIONS(5443),
    [anon_sym_POUNDELIF] = ACTIONS(5443),
    [anon_sym_POUNDElif] = ACTIONS(5443),
    [anon_sym_POUNDelse] = ACTIONS(5443),
    [anon_sym_POUNDELSE] = ACTIONS(5443),
    [anon_sym_POUNDElse] = ACTIONS(5443),
    [anon_sym_POUNDelse2] = ACTIONS(5443),
    [anon_sym_POUNDELSE2] = ACTIONS(5443),
    [anon_sym_POUNDElse2] = ACTIONS(5443),
    [anon_sym_POUNDendif] = ACTIONS(5443),
    [anon_sym_POUNDENDIF] = ACTIONS(5443),
    [anon_sym_POUNDEndif] = ACTIONS(5443),
    [anon_sym_POUNDendif2] = ACTIONS(5443),
    [anon_sym_POUNDENDIF2] = ACTIONS(5443),
    [anon_sym_POUNDEndif2] = ACTIONS(5443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5441),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5441),
    [anon_sym_PLUS] = ACTIONS(5443),
    [sym_datetime_literal] = ACTIONS(5443),
    [sym_date_literal] = ACTIONS(5441),
    [sym_time_literal] = ACTIONS(5441),
    [sym_biginteger_literal] = ACTIONS(5443),
    [anon_sym_if] = ACTIONS(5441),
    [anon_sym_IF] = ACTIONS(5441),
    [anon_sym_If] = ACTIONS(5441),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5441),
    [anon_sym_CASE] = ACTIONS(5441),
    [anon_sym_Case] = ACTIONS(5441),
    [anon_sym_for] = ACTIONS(5441),
    [anon_sym_FOR] = ACTIONS(5441),
    [anon_sym_For] = ACTIONS(5441),
    [anon_sym_foreach] = ACTIONS(5441),
    [anon_sym_FOREACH] = ACTIONS(5441),
    [anon_sym_Foreach] = ACTIONS(5441),
    [anon_sym_while] = ACTIONS(5441),
    [anon_sym_WHILE] = ACTIONS(5441),
    [anon_sym_While] = ACTIONS(5441),
    [anon_sym_repeat] = ACTIONS(5441),
    [anon_sym_REPEAT] = ACTIONS(5441),
    [anon_sym_Repeat] = ACTIONS(5441),
    [anon_sym_exit] = ACTIONS(5441),
    [anon_sym_EXIT] = ACTIONS(5441),
    [anon_sym_Exit] = ACTIONS(5441),
    [anon_sym_continue] = ACTIONS(5441),
    [anon_sym_CONTINUE] = ACTIONS(5441),
    [anon_sym_Continue] = ACTIONS(5441),
    [anon_sym_break] = ACTIONS(5441),
    [anon_sym_BREAK] = ACTIONS(5441),
    [anon_sym_Break] = ACTIONS(5441),
    [anon_sym_with] = ACTIONS(5441),
    [anon_sym_WITH] = ACTIONS(5441),
    [anon_sym_With] = ACTIONS(5441),
    [sym_asserterror_keyword] = ACTIONS(5443),
    [sym_page_keyword] = ACTIONS(5441),
    [anon_sym_codeunit] = ACTIONS(5441),
    [anon_sym_CODEUNIT] = ACTIONS(5441),
    [anon_sym_Codeunit] = ACTIONS(5441),
    [anon_sym_CodeUnit] = ACTIONS(5441),
    [anon_sym_COdeunit] = ACTIONS(5441),
    [anon_sym_codeUnit] = ACTIONS(5441),
    [sym_report_keyword] = ACTIONS(5441),
    [sym_query_keyword] = ACTIONS(5441),
    [anon_sym_xmlport] = ACTIONS(5441),
    [anon_sym_XMLPORT] = ACTIONS(5441),
    [anon_sym_Xmlport] = ACTIONS(5441),
    [anon_sym_XMLport] = ACTIONS(5441),
    [anon_sym_XMLPort] = ACTIONS(5441),
    [anon_sym_XmlPort] = ACTIONS(5441),
    [anon_sym_enum] = ACTIONS(5441),
    [anon_sym_ENUM] = ACTIONS(5441),
    [anon_sym_Enum] = ACTIONS(5441),
    [anon_sym_eNUM] = ACTIONS(5441),
    [anon_sym_eNum] = ACTIONS(5441),
    [anon_sym_ENum] = ACTIONS(5441),
    [sym_quoted_identifier] = ACTIONS(5443),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5443),
    [sym_verbatim_string] = ACTIONS(5443),
    [sym_integer] = ACTIONS(5441),
    [sym_continue_as_identifier] = ACTIONS(5443),
    [sym_preproc_open] = ACTIONS(5443),
    [sym_preproc_close] = ACTIONS(5443),
  },
  [STATE(2359)] = {
    [sym_identifier] = ACTIONS(5445),
    [anon_sym_SEMI] = ACTIONS(5447),
    [anon_sym_DASH] = ACTIONS(5447),
    [aux_sym_boolean_token1] = ACTIONS(5445),
    [aux_sym_boolean_token2] = ACTIONS(5445),
    [sym_decimal] = ACTIONS(5445),
    [anon_sym_LPAREN] = ACTIONS(5445),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5445),
    [anon_sym_LBRACK] = ACTIONS(5447),
    [aux_sym_record_type_token1] = ACTIONS(5445),
    [aux_sym_basic_type_token21] = ACTIONS(5445),
    [aux_sym_basic_type_token22] = ACTIONS(5445),
    [aux_sym_basic_type_token48] = ACTIONS(5445),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5445),
    [anon_sym_POUNDif] = ACTIONS(5447),
    [anon_sym_POUNDIF] = ACTIONS(5447),
    [anon_sym_POUNDIf] = ACTIONS(5447),
    [anon_sym_not] = ACTIONS(5445),
    [anon_sym_NOT] = ACTIONS(5445),
    [anon_sym_Not] = ACTIONS(5445),
    [anon_sym_POUNDelif] = ACTIONS(5447),
    [anon_sym_POUNDELIF] = ACTIONS(5447),
    [anon_sym_POUNDElif] = ACTIONS(5447),
    [anon_sym_POUNDelse] = ACTIONS(5447),
    [anon_sym_POUNDELSE] = ACTIONS(5447),
    [anon_sym_POUNDElse] = ACTIONS(5447),
    [anon_sym_POUNDelse2] = ACTIONS(5447),
    [anon_sym_POUNDELSE2] = ACTIONS(5447),
    [anon_sym_POUNDElse2] = ACTIONS(5447),
    [anon_sym_POUNDendif] = ACTIONS(5447),
    [anon_sym_POUNDENDIF] = ACTIONS(5447),
    [anon_sym_POUNDEndif] = ACTIONS(5447),
    [anon_sym_POUNDendif2] = ACTIONS(5447),
    [anon_sym_POUNDENDIF2] = ACTIONS(5447),
    [anon_sym_POUNDEndif2] = ACTIONS(5447),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(5447),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5445),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5445),
    [anon_sym_PLUS] = ACTIONS(5447),
    [sym_datetime_literal] = ACTIONS(5447),
    [sym_date_literal] = ACTIONS(5445),
    [sym_time_literal] = ACTIONS(5445),
    [sym_biginteger_literal] = ACTIONS(5447),
    [anon_sym_if] = ACTIONS(5445),
    [anon_sym_IF] = ACTIONS(5445),
    [anon_sym_If] = ACTIONS(5445),
    [anon_sym_else] = ACTIONS(5445),
    [anon_sym_ELSE] = ACTIONS(5445),
    [anon_sym_Else] = ACTIONS(5445),
    [anon_sym_case] = ACTIONS(5445),
    [anon_sym_CASE] = ACTIONS(5445),
    [anon_sym_Case] = ACTIONS(5445),
    [anon_sym_for] = ACTIONS(5445),
    [anon_sym_FOR] = ACTIONS(5445),
    [anon_sym_For] = ACTIONS(5445),
    [anon_sym_foreach] = ACTIONS(5445),
    [anon_sym_FOREACH] = ACTIONS(5445),
    [anon_sym_Foreach] = ACTIONS(5445),
    [anon_sym_while] = ACTIONS(5445),
    [anon_sym_WHILE] = ACTIONS(5445),
    [anon_sym_While] = ACTIONS(5445),
    [anon_sym_repeat] = ACTIONS(5445),
    [anon_sym_REPEAT] = ACTIONS(5445),
    [anon_sym_Repeat] = ACTIONS(5445),
    [anon_sym_exit] = ACTIONS(5445),
    [anon_sym_EXIT] = ACTIONS(5445),
    [anon_sym_Exit] = ACTIONS(5445),
    [anon_sym_continue] = ACTIONS(5445),
    [anon_sym_CONTINUE] = ACTIONS(5445),
    [anon_sym_Continue] = ACTIONS(5445),
    [anon_sym_break] = ACTIONS(5445),
    [anon_sym_BREAK] = ACTIONS(5445),
    [anon_sym_Break] = ACTIONS(5445),
    [anon_sym_with] = ACTIONS(5445),
    [anon_sym_WITH] = ACTIONS(5445),
    [anon_sym_With] = ACTIONS(5445),
    [sym_asserterror_keyword] = ACTIONS(5447),
    [sym_page_keyword] = ACTIONS(5445),
    [anon_sym_codeunit] = ACTIONS(5445),
    [anon_sym_CODEUNIT] = ACTIONS(5445),
    [anon_sym_Codeunit] = ACTIONS(5445),
    [anon_sym_CodeUnit] = ACTIONS(5445),
    [anon_sym_COdeunit] = ACTIONS(5445),
    [anon_sym_codeUnit] = ACTIONS(5445),
    [sym_report_keyword] = ACTIONS(5445),
    [sym_query_keyword] = ACTIONS(5445),
    [anon_sym_xmlport] = ACTIONS(5445),
    [anon_sym_XMLPORT] = ACTIONS(5445),
    [anon_sym_Xmlport] = ACTIONS(5445),
    [anon_sym_XMLport] = ACTIONS(5445),
    [anon_sym_XMLPort] = ACTIONS(5445),
    [anon_sym_XmlPort] = ACTIONS(5445),
    [anon_sym_enum] = ACTIONS(5445),
    [anon_sym_ENUM] = ACTIONS(5445),
    [anon_sym_Enum] = ACTIONS(5445),
    [anon_sym_eNUM] = ACTIONS(5445),
    [anon_sym_eNum] = ACTIONS(5445),
    [anon_sym_ENum] = ACTIONS(5445),
    [sym_quoted_identifier] = ACTIONS(5447),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5447),
    [sym_verbatim_string] = ACTIONS(5447),
    [sym_integer] = ACTIONS(5445),
    [sym_continue_as_identifier] = ACTIONS(5447),
    [sym_preproc_open] = ACTIONS(5447),
    [sym_preproc_close] = ACTIONS(5447),
  },
  [STATE(2360)] = {
    [sym_else_keyword] = STATE(637),
    [sym_identifier] = ACTIONS(5449),
    [anon_sym_SEMI] = ACTIONS(5451),
    [anon_sym_DASH] = ACTIONS(5451),
    [aux_sym_boolean_token1] = ACTIONS(5449),
    [aux_sym_boolean_token2] = ACTIONS(5449),
    [sym_decimal] = ACTIONS(5449),
    [anon_sym_LPAREN] = ACTIONS(5451),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5449),
    [anon_sym_LBRACK] = ACTIONS(5451),
    [aux_sym_record_type_token1] = ACTIONS(5449),
    [aux_sym_basic_type_token21] = ACTIONS(5449),
    [aux_sym_basic_type_token22] = ACTIONS(5449),
    [aux_sym_basic_type_token48] = ACTIONS(5449),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5449),
    [anon_sym_POUNDif] = ACTIONS(5451),
    [anon_sym_POUNDIF] = ACTIONS(5451),
    [anon_sym_POUNDIf] = ACTIONS(5451),
    [anon_sym_not] = ACTIONS(5449),
    [anon_sym_NOT] = ACTIONS(5449),
    [anon_sym_Not] = ACTIONS(5449),
    [anon_sym_POUNDelif] = ACTIONS(5451),
    [anon_sym_POUNDELIF] = ACTIONS(5451),
    [anon_sym_POUNDElif] = ACTIONS(5451),
    [anon_sym_POUNDelse] = ACTIONS(5451),
    [anon_sym_POUNDELSE] = ACTIONS(5451),
    [anon_sym_POUNDElse] = ACTIONS(5451),
    [anon_sym_POUNDelse2] = ACTIONS(5451),
    [anon_sym_POUNDELSE2] = ACTIONS(5451),
    [anon_sym_POUNDElse2] = ACTIONS(5451),
    [anon_sym_POUNDendif] = ACTIONS(5451),
    [anon_sym_POUNDENDIF] = ACTIONS(5451),
    [anon_sym_POUNDEndif] = ACTIONS(5451),
    [anon_sym_POUNDendif2] = ACTIONS(5451),
    [anon_sym_POUNDENDIF2] = ACTIONS(5451),
    [anon_sym_POUNDEndif2] = ACTIONS(5451),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5449),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5449),
    [anon_sym_PLUS] = ACTIONS(5451),
    [sym_datetime_literal] = ACTIONS(5451),
    [sym_date_literal] = ACTIONS(5449),
    [sym_time_literal] = ACTIONS(5449),
    [sym_biginteger_literal] = ACTIONS(5451),
    [anon_sym_if] = ACTIONS(5449),
    [anon_sym_IF] = ACTIONS(5449),
    [anon_sym_If] = ACTIONS(5449),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5449),
    [anon_sym_CASE] = ACTIONS(5449),
    [anon_sym_Case] = ACTIONS(5449),
    [anon_sym_for] = ACTIONS(5449),
    [anon_sym_FOR] = ACTIONS(5449),
    [anon_sym_For] = ACTIONS(5449),
    [anon_sym_foreach] = ACTIONS(5449),
    [anon_sym_FOREACH] = ACTIONS(5449),
    [anon_sym_Foreach] = ACTIONS(5449),
    [anon_sym_while] = ACTIONS(5449),
    [anon_sym_WHILE] = ACTIONS(5449),
    [anon_sym_While] = ACTIONS(5449),
    [anon_sym_repeat] = ACTIONS(5449),
    [anon_sym_REPEAT] = ACTIONS(5449),
    [anon_sym_Repeat] = ACTIONS(5449),
    [anon_sym_exit] = ACTIONS(5449),
    [anon_sym_EXIT] = ACTIONS(5449),
    [anon_sym_Exit] = ACTIONS(5449),
    [anon_sym_continue] = ACTIONS(5449),
    [anon_sym_CONTINUE] = ACTIONS(5449),
    [anon_sym_Continue] = ACTIONS(5449),
    [anon_sym_break] = ACTIONS(5449),
    [anon_sym_BREAK] = ACTIONS(5449),
    [anon_sym_Break] = ACTIONS(5449),
    [anon_sym_with] = ACTIONS(5449),
    [anon_sym_WITH] = ACTIONS(5449),
    [anon_sym_With] = ACTIONS(5449),
    [sym_asserterror_keyword] = ACTIONS(5451),
    [sym_page_keyword] = ACTIONS(5449),
    [anon_sym_codeunit] = ACTIONS(5449),
    [anon_sym_CODEUNIT] = ACTIONS(5449),
    [anon_sym_Codeunit] = ACTIONS(5449),
    [anon_sym_CodeUnit] = ACTIONS(5449),
    [anon_sym_COdeunit] = ACTIONS(5449),
    [anon_sym_codeUnit] = ACTIONS(5449),
    [sym_report_keyword] = ACTIONS(5449),
    [sym_query_keyword] = ACTIONS(5449),
    [anon_sym_xmlport] = ACTIONS(5449),
    [anon_sym_XMLPORT] = ACTIONS(5449),
    [anon_sym_Xmlport] = ACTIONS(5449),
    [anon_sym_XMLport] = ACTIONS(5449),
    [anon_sym_XMLPort] = ACTIONS(5449),
    [anon_sym_XmlPort] = ACTIONS(5449),
    [anon_sym_enum] = ACTIONS(5449),
    [anon_sym_ENUM] = ACTIONS(5449),
    [anon_sym_Enum] = ACTIONS(5449),
    [anon_sym_eNUM] = ACTIONS(5449),
    [anon_sym_eNum] = ACTIONS(5449),
    [anon_sym_ENum] = ACTIONS(5449),
    [sym_quoted_identifier] = ACTIONS(5451),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5451),
    [sym_verbatim_string] = ACTIONS(5451),
    [sym_integer] = ACTIONS(5449),
    [sym_continue_as_identifier] = ACTIONS(5451),
    [sym_preproc_open] = ACTIONS(5451),
    [sym_preproc_close] = ACTIONS(5451),
  },
  [STATE(2361)] = {
    [sym_else_keyword] = STATE(674),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelif] = ACTIONS(5455),
    [anon_sym_POUNDELIF] = ACTIONS(5455),
    [anon_sym_POUNDElif] = ACTIONS(5455),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [anon_sym_POUNDendif] = ACTIONS(5455),
    [anon_sym_POUNDENDIF] = ACTIONS(5455),
    [anon_sym_POUNDEndif] = ACTIONS(5455),
    [anon_sym_POUNDendif2] = ACTIONS(5455),
    [anon_sym_POUNDENDIF2] = ACTIONS(5455),
    [anon_sym_POUNDEndif2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_preproc_close] = ACTIONS(5455),
  },
  [STATE(2362)] = {
    [sym_identifier] = ACTIONS(5378),
    [anon_sym_SEMI] = ACTIONS(5380),
    [anon_sym_DASH] = ACTIONS(5380),
    [aux_sym_boolean_token1] = ACTIONS(5378),
    [aux_sym_boolean_token2] = ACTIONS(5378),
    [sym_decimal] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5378),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [aux_sym_record_type_token1] = ACTIONS(5378),
    [aux_sym_basic_type_token21] = ACTIONS(5378),
    [aux_sym_basic_type_token22] = ACTIONS(5378),
    [aux_sym_basic_type_token48] = ACTIONS(5378),
    [anon_sym_POUNDif] = ACTIONS(5380),
    [anon_sym_POUNDIF] = ACTIONS(5380),
    [anon_sym_POUNDIf] = ACTIONS(5380),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5380),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5457),
    [anon_sym_AMP_AMP] = ACTIONS(5459),
    [anon_sym_not] = ACTIONS(5378),
    [anon_sym_NOT] = ACTIONS(5378),
    [anon_sym_Not] = ACTIONS(5378),
    [anon_sym_POUNDelif] = ACTIONS(5380),
    [anon_sym_POUNDELIF] = ACTIONS(5380),
    [anon_sym_POUNDElif] = ACTIONS(5380),
    [anon_sym_POUNDelse] = ACTIONS(5380),
    [anon_sym_POUNDELSE] = ACTIONS(5380),
    [anon_sym_POUNDElse] = ACTIONS(5380),
    [anon_sym_POUNDelse2] = ACTIONS(5380),
    [anon_sym_POUNDELSE2] = ACTIONS(5380),
    [anon_sym_POUNDElse2] = ACTIONS(5380),
    [anon_sym_POUNDendif] = ACTIONS(5380),
    [anon_sym_POUNDENDIF] = ACTIONS(5380),
    [anon_sym_POUNDEndif] = ACTIONS(5380),
    [anon_sym_POUNDendif2] = ACTIONS(5380),
    [anon_sym_POUNDENDIF2] = ACTIONS(5380),
    [anon_sym_POUNDEndif2] = ACTIONS(5380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [sym_datetime_literal] = ACTIONS(5380),
    [sym_date_literal] = ACTIONS(5378),
    [sym_time_literal] = ACTIONS(5378),
    [sym_biginteger_literal] = ACTIONS(5380),
    [anon_sym_if] = ACTIONS(5378),
    [anon_sym_IF] = ACTIONS(5378),
    [anon_sym_If] = ACTIONS(5378),
    [anon_sym_case] = ACTIONS(5378),
    [anon_sym_CASE] = ACTIONS(5378),
    [anon_sym_Case] = ACTIONS(5378),
    [anon_sym_for] = ACTIONS(5378),
    [anon_sym_FOR] = ACTIONS(5378),
    [anon_sym_For] = ACTIONS(5378),
    [anon_sym_foreach] = ACTIONS(5378),
    [anon_sym_FOREACH] = ACTIONS(5378),
    [anon_sym_Foreach] = ACTIONS(5378),
    [anon_sym_while] = ACTIONS(5378),
    [anon_sym_WHILE] = ACTIONS(5378),
    [anon_sym_While] = ACTIONS(5378),
    [anon_sym_repeat] = ACTIONS(5378),
    [anon_sym_REPEAT] = ACTIONS(5378),
    [anon_sym_Repeat] = ACTIONS(5378),
    [anon_sym_exit] = ACTIONS(5378),
    [anon_sym_EXIT] = ACTIONS(5378),
    [anon_sym_Exit] = ACTIONS(5378),
    [anon_sym_continue] = ACTIONS(5378),
    [anon_sym_CONTINUE] = ACTIONS(5378),
    [anon_sym_Continue] = ACTIONS(5378),
    [anon_sym_break] = ACTIONS(5378),
    [anon_sym_BREAK] = ACTIONS(5378),
    [anon_sym_Break] = ACTIONS(5378),
    [anon_sym_with] = ACTIONS(5378),
    [anon_sym_WITH] = ACTIONS(5378),
    [anon_sym_With] = ACTIONS(5378),
    [sym_asserterror_keyword] = ACTIONS(5380),
    [sym_page_keyword] = ACTIONS(5378),
    [anon_sym_codeunit] = ACTIONS(5378),
    [anon_sym_CODEUNIT] = ACTIONS(5378),
    [anon_sym_Codeunit] = ACTIONS(5378),
    [anon_sym_CodeUnit] = ACTIONS(5378),
    [anon_sym_COdeunit] = ACTIONS(5378),
    [anon_sym_codeUnit] = ACTIONS(5378),
    [sym_report_keyword] = ACTIONS(5378),
    [sym_query_keyword] = ACTIONS(5378),
    [anon_sym_xmlport] = ACTIONS(5378),
    [anon_sym_XMLPORT] = ACTIONS(5378),
    [anon_sym_Xmlport] = ACTIONS(5378),
    [anon_sym_XMLport] = ACTIONS(5378),
    [anon_sym_XMLPort] = ACTIONS(5378),
    [anon_sym_XmlPort] = ACTIONS(5378),
    [anon_sym_enum] = ACTIONS(5378),
    [anon_sym_ENUM] = ACTIONS(5378),
    [anon_sym_Enum] = ACTIONS(5378),
    [anon_sym_eNUM] = ACTIONS(5378),
    [anon_sym_eNum] = ACTIONS(5378),
    [anon_sym_ENum] = ACTIONS(5378),
    [sym_quoted_identifier] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5380),
    [sym_verbatim_string] = ACTIONS(5380),
    [sym_integer] = ACTIONS(5378),
    [sym_continue_as_identifier] = ACTIONS(5380),
    [sym_preproc_open] = ACTIONS(5380),
    [sym_preproc_close] = ACTIONS(5380),
    [sym_preproc_split_end] = ACTIONS(5380),
  },
  [STATE(2363)] = {
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3562),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3564),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3564),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_basic_type_token6] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3564),
    [aux_sym_addafter_modification_token1] = ACTIONS(3564),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3564),
    [aux_sym_modify_modification_token1] = ACTIONS(3564),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3564),
    [aux_sym_movelast_modification_token1] = ACTIONS(3564),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3564),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3564),
    [anon_sym_DIV] = ACTIONS(3564),
    [anon_sym_Div] = ACTIONS(3564),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3564),
    [anon_sym_AND] = ACTIONS(3564),
    [anon_sym_And] = ACTIONS(3564),
    [anon_sym_or] = ACTIONS(3564),
    [anon_sym_OR] = ACTIONS(3564),
    [anon_sym_Or] = ACTIONS(3564),
    [anon_sym_xor] = ACTIONS(3564),
    [anon_sym_XOR] = ACTIONS(3564),
    [anon_sym_Xor] = ACTIONS(3564),
    [anon_sym_QMARK] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_procedure_keyword] = ACTIONS(3564),
    [sym_trigger_keyword] = ACTIONS(3564),
    [sym_var_keyword] = ACTIONS(3564),
    [sym_local_keyword] = ACTIONS(3564),
    [sym_internal_keyword] = ACTIONS(3564),
    [sym_protected_keyword] = ACTIONS(3564),
    [sym_event_keyword] = ACTIONS(3564),
    [sym_fields_keyword] = ACTIONS(3564),
    [sym_keys_keyword] = ACTIONS(3564),
    [sym_fieldgroups_keyword] = ACTIONS(3564),
    [sym_actions_keyword] = ACTIONS(3564),
    [sym_layout_keyword] = ACTIONS(3564),
    [sym_area_keyword] = ACTIONS(3564),
    [sym_group_keyword] = ACTIONS(3564),
    [sym_repeater_keyword] = ACTIONS(3564),
    [sym_cuegroup_keyword] = ACTIONS(3564),
    [sym_fixed_keyword] = ACTIONS(3564),
    [sym_grid_keyword] = ACTIONS(3564),
    [sym_part_keyword] = ACTIONS(3564),
    [sym_systempart_keyword] = ACTIONS(3564),
    [sym_usercontrol_keyword] = ACTIONS(3564),
    [sym_dataset_keyword] = ACTIONS(3564),
    [sym_elements_keyword] = ACTIONS(3564),
    [sym_dataitem_keyword] = ACTIONS(3564),
    [sym_column_keyword] = ACTIONS(3564),
    [sym_filter_keyword] = ACTIONS(3564),
    [sym_labels_keyword] = ACTIONS(3564),
    [sym_rendering_keyword] = ACTIONS(3564),
    [sym_requestpage_keyword] = ACTIONS(3564),
    [sym_schema_keyword] = ACTIONS(3564),
    [sym_views_keyword] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
  },
  [STATE(2364)] = {
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3663),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3564),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3564),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_basic_type_token6] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3564),
    [aux_sym_addafter_modification_token1] = ACTIONS(3564),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3564),
    [aux_sym_modify_modification_token1] = ACTIONS(3564),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3564),
    [aux_sym_movelast_modification_token1] = ACTIONS(3564),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3564),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3665),
    [anon_sym_DIV] = ACTIONS(3665),
    [anon_sym_Div] = ACTIONS(3665),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3665),
    [anon_sym_AND] = ACTIONS(3665),
    [anon_sym_And] = ACTIONS(3665),
    [anon_sym_or] = ACTIONS(3665),
    [anon_sym_OR] = ACTIONS(3665),
    [anon_sym_Or] = ACTIONS(3665),
    [anon_sym_xor] = ACTIONS(3665),
    [anon_sym_XOR] = ACTIONS(3665),
    [anon_sym_Xor] = ACTIONS(3665),
    [anon_sym_QMARK] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_procedure_keyword] = ACTIONS(3564),
    [sym_trigger_keyword] = ACTIONS(3564),
    [sym_var_keyword] = ACTIONS(3564),
    [sym_local_keyword] = ACTIONS(3564),
    [sym_internal_keyword] = ACTIONS(3564),
    [sym_protected_keyword] = ACTIONS(3564),
    [sym_event_keyword] = ACTIONS(3564),
    [sym_fields_keyword] = ACTIONS(3564),
    [sym_keys_keyword] = ACTIONS(3564),
    [sym_fieldgroups_keyword] = ACTIONS(3564),
    [sym_actions_keyword] = ACTIONS(3564),
    [sym_layout_keyword] = ACTIONS(3564),
    [sym_area_keyword] = ACTIONS(3564),
    [sym_group_keyword] = ACTIONS(3564),
    [sym_repeater_keyword] = ACTIONS(3564),
    [sym_cuegroup_keyword] = ACTIONS(3564),
    [sym_fixed_keyword] = ACTIONS(3564),
    [sym_grid_keyword] = ACTIONS(3564),
    [sym_part_keyword] = ACTIONS(3564),
    [sym_systempart_keyword] = ACTIONS(3564),
    [sym_usercontrol_keyword] = ACTIONS(3564),
    [sym_dataset_keyword] = ACTIONS(3564),
    [sym_elements_keyword] = ACTIONS(3564),
    [sym_dataitem_keyword] = ACTIONS(3564),
    [sym_column_keyword] = ACTIONS(3564),
    [sym_filter_keyword] = ACTIONS(3564),
    [sym_labels_keyword] = ACTIONS(3564),
    [sym_rendering_keyword] = ACTIONS(3564),
    [sym_requestpage_keyword] = ACTIONS(3564),
    [sym_schema_keyword] = ACTIONS(3564),
    [sym_views_keyword] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
  },
  [STATE(2365)] = {
    [sym_identifier] = ACTIONS(5461),
    [anon_sym_SEMI] = ACTIONS(5463),
    [anon_sym_DASH] = ACTIONS(5463),
    [aux_sym_boolean_token1] = ACTIONS(5461),
    [aux_sym_boolean_token2] = ACTIONS(5461),
    [sym_decimal] = ACTIONS(5461),
    [anon_sym_LPAREN] = ACTIONS(5461),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5461),
    [anon_sym_LBRACK] = ACTIONS(5463),
    [aux_sym_record_type_token1] = ACTIONS(5461),
    [aux_sym_basic_type_token21] = ACTIONS(5461),
    [aux_sym_basic_type_token22] = ACTIONS(5461),
    [aux_sym_basic_type_token48] = ACTIONS(5461),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5461),
    [anon_sym_POUNDif] = ACTIONS(5463),
    [anon_sym_POUNDIF] = ACTIONS(5463),
    [anon_sym_POUNDIf] = ACTIONS(5463),
    [anon_sym_not] = ACTIONS(5461),
    [anon_sym_NOT] = ACTIONS(5461),
    [anon_sym_Not] = ACTIONS(5461),
    [anon_sym_POUNDelif] = ACTIONS(5463),
    [anon_sym_POUNDELIF] = ACTIONS(5463),
    [anon_sym_POUNDElif] = ACTIONS(5463),
    [anon_sym_POUNDelse] = ACTIONS(5463),
    [anon_sym_POUNDELSE] = ACTIONS(5463),
    [anon_sym_POUNDElse] = ACTIONS(5463),
    [anon_sym_POUNDelse2] = ACTIONS(5463),
    [anon_sym_POUNDELSE2] = ACTIONS(5463),
    [anon_sym_POUNDElse2] = ACTIONS(5463),
    [anon_sym_POUNDendif] = ACTIONS(5463),
    [anon_sym_POUNDENDIF] = ACTIONS(5463),
    [anon_sym_POUNDEndif] = ACTIONS(5463),
    [anon_sym_POUNDendif2] = ACTIONS(5463),
    [anon_sym_POUNDENDIF2] = ACTIONS(5463),
    [anon_sym_POUNDEndif2] = ACTIONS(5463),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(5465),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5461),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5461),
    [anon_sym_PLUS] = ACTIONS(5463),
    [sym_datetime_literal] = ACTIONS(5463),
    [sym_date_literal] = ACTIONS(5461),
    [sym_time_literal] = ACTIONS(5461),
    [sym_biginteger_literal] = ACTIONS(5463),
    [anon_sym_if] = ACTIONS(5461),
    [anon_sym_IF] = ACTIONS(5461),
    [anon_sym_If] = ACTIONS(5461),
    [anon_sym_else] = ACTIONS(5461),
    [anon_sym_ELSE] = ACTIONS(5461),
    [anon_sym_Else] = ACTIONS(5461),
    [anon_sym_case] = ACTIONS(5461),
    [anon_sym_CASE] = ACTIONS(5461),
    [anon_sym_Case] = ACTIONS(5461),
    [anon_sym_for] = ACTIONS(5461),
    [anon_sym_FOR] = ACTIONS(5461),
    [anon_sym_For] = ACTIONS(5461),
    [anon_sym_foreach] = ACTIONS(5461),
    [anon_sym_FOREACH] = ACTIONS(5461),
    [anon_sym_Foreach] = ACTIONS(5461),
    [anon_sym_while] = ACTIONS(5461),
    [anon_sym_WHILE] = ACTIONS(5461),
    [anon_sym_While] = ACTIONS(5461),
    [anon_sym_repeat] = ACTIONS(5461),
    [anon_sym_REPEAT] = ACTIONS(5461),
    [anon_sym_Repeat] = ACTIONS(5461),
    [anon_sym_exit] = ACTIONS(5461),
    [anon_sym_EXIT] = ACTIONS(5461),
    [anon_sym_Exit] = ACTIONS(5461),
    [anon_sym_continue] = ACTIONS(5461),
    [anon_sym_CONTINUE] = ACTIONS(5461),
    [anon_sym_Continue] = ACTIONS(5461),
    [anon_sym_break] = ACTIONS(5461),
    [anon_sym_BREAK] = ACTIONS(5461),
    [anon_sym_Break] = ACTIONS(5461),
    [anon_sym_with] = ACTIONS(5461),
    [anon_sym_WITH] = ACTIONS(5461),
    [anon_sym_With] = ACTIONS(5461),
    [sym_asserterror_keyword] = ACTIONS(5463),
    [sym_page_keyword] = ACTIONS(5461),
    [anon_sym_codeunit] = ACTIONS(5461),
    [anon_sym_CODEUNIT] = ACTIONS(5461),
    [anon_sym_Codeunit] = ACTIONS(5461),
    [anon_sym_CodeUnit] = ACTIONS(5461),
    [anon_sym_COdeunit] = ACTIONS(5461),
    [anon_sym_codeUnit] = ACTIONS(5461),
    [sym_report_keyword] = ACTIONS(5461),
    [sym_query_keyword] = ACTIONS(5461),
    [anon_sym_xmlport] = ACTIONS(5461),
    [anon_sym_XMLPORT] = ACTIONS(5461),
    [anon_sym_Xmlport] = ACTIONS(5461),
    [anon_sym_XMLport] = ACTIONS(5461),
    [anon_sym_XMLPort] = ACTIONS(5461),
    [anon_sym_XmlPort] = ACTIONS(5461),
    [anon_sym_enum] = ACTIONS(5461),
    [anon_sym_ENUM] = ACTIONS(5461),
    [anon_sym_Enum] = ACTIONS(5461),
    [anon_sym_eNUM] = ACTIONS(5461),
    [anon_sym_eNum] = ACTIONS(5461),
    [anon_sym_ENum] = ACTIONS(5461),
    [sym_quoted_identifier] = ACTIONS(5463),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5463),
    [sym_verbatim_string] = ACTIONS(5463),
    [sym_integer] = ACTIONS(5461),
    [sym_continue_as_identifier] = ACTIONS(5463),
    [sym_preproc_open] = ACTIONS(5463),
    [sym_preproc_close] = ACTIONS(5463),
  },
  [STATE(2366)] = {
    [sym_else_keyword] = STATE(111),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelif] = ACTIONS(5455),
    [anon_sym_POUNDELIF] = ACTIONS(5455),
    [anon_sym_POUNDElif] = ACTIONS(5455),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [anon_sym_POUNDendif] = ACTIONS(5455),
    [anon_sym_POUNDENDIF] = ACTIONS(5455),
    [anon_sym_POUNDEndif] = ACTIONS(5455),
    [anon_sym_POUNDendif2] = ACTIONS(5455),
    [anon_sym_POUNDENDIF2] = ACTIONS(5455),
    [anon_sym_POUNDEndif2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_preproc_close] = ACTIONS(5455),
  },
  [STATE(2367)] = {
    [sym_else_keyword] = STATE(636),
    [sym_identifier] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5471),
    [anon_sym_DASH] = ACTIONS(5471),
    [aux_sym_boolean_token1] = ACTIONS(5469),
    [aux_sym_boolean_token2] = ACTIONS(5469),
    [sym_decimal] = ACTIONS(5469),
    [anon_sym_LPAREN] = ACTIONS(5471),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5469),
    [anon_sym_LBRACK] = ACTIONS(5471),
    [aux_sym_record_type_token1] = ACTIONS(5469),
    [aux_sym_basic_type_token21] = ACTIONS(5469),
    [aux_sym_basic_type_token22] = ACTIONS(5469),
    [aux_sym_basic_type_token48] = ACTIONS(5469),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5469),
    [anon_sym_POUNDif] = ACTIONS(5471),
    [anon_sym_POUNDIF] = ACTIONS(5471),
    [anon_sym_POUNDIf] = ACTIONS(5471),
    [anon_sym_not] = ACTIONS(5469),
    [anon_sym_NOT] = ACTIONS(5469),
    [anon_sym_Not] = ACTIONS(5469),
    [anon_sym_POUNDelif] = ACTIONS(5471),
    [anon_sym_POUNDELIF] = ACTIONS(5471),
    [anon_sym_POUNDElif] = ACTIONS(5471),
    [anon_sym_POUNDelse] = ACTIONS(5471),
    [anon_sym_POUNDELSE] = ACTIONS(5471),
    [anon_sym_POUNDElse] = ACTIONS(5471),
    [anon_sym_POUNDelse2] = ACTIONS(5471),
    [anon_sym_POUNDELSE2] = ACTIONS(5471),
    [anon_sym_POUNDElse2] = ACTIONS(5471),
    [anon_sym_POUNDendif] = ACTIONS(5471),
    [anon_sym_POUNDENDIF] = ACTIONS(5471),
    [anon_sym_POUNDEndif] = ACTIONS(5471),
    [anon_sym_POUNDendif2] = ACTIONS(5471),
    [anon_sym_POUNDENDIF2] = ACTIONS(5471),
    [anon_sym_POUNDEndif2] = ACTIONS(5471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5469),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5469),
    [anon_sym_PLUS] = ACTIONS(5471),
    [sym_datetime_literal] = ACTIONS(5471),
    [sym_date_literal] = ACTIONS(5469),
    [sym_time_literal] = ACTIONS(5469),
    [sym_biginteger_literal] = ACTIONS(5471),
    [anon_sym_if] = ACTIONS(5469),
    [anon_sym_IF] = ACTIONS(5469),
    [anon_sym_If] = ACTIONS(5469),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5469),
    [anon_sym_CASE] = ACTIONS(5469),
    [anon_sym_Case] = ACTIONS(5469),
    [anon_sym_for] = ACTIONS(5469),
    [anon_sym_FOR] = ACTIONS(5469),
    [anon_sym_For] = ACTIONS(5469),
    [anon_sym_foreach] = ACTIONS(5469),
    [anon_sym_FOREACH] = ACTIONS(5469),
    [anon_sym_Foreach] = ACTIONS(5469),
    [anon_sym_while] = ACTIONS(5469),
    [anon_sym_WHILE] = ACTIONS(5469),
    [anon_sym_While] = ACTIONS(5469),
    [anon_sym_repeat] = ACTIONS(5469),
    [anon_sym_REPEAT] = ACTIONS(5469),
    [anon_sym_Repeat] = ACTIONS(5469),
    [anon_sym_exit] = ACTIONS(5469),
    [anon_sym_EXIT] = ACTIONS(5469),
    [anon_sym_Exit] = ACTIONS(5469),
    [anon_sym_continue] = ACTIONS(5469),
    [anon_sym_CONTINUE] = ACTIONS(5469),
    [anon_sym_Continue] = ACTIONS(5469),
    [anon_sym_break] = ACTIONS(5469),
    [anon_sym_BREAK] = ACTIONS(5469),
    [anon_sym_Break] = ACTIONS(5469),
    [anon_sym_with] = ACTIONS(5469),
    [anon_sym_WITH] = ACTIONS(5469),
    [anon_sym_With] = ACTIONS(5469),
    [sym_asserterror_keyword] = ACTIONS(5471),
    [sym_page_keyword] = ACTIONS(5469),
    [anon_sym_codeunit] = ACTIONS(5469),
    [anon_sym_CODEUNIT] = ACTIONS(5469),
    [anon_sym_Codeunit] = ACTIONS(5469),
    [anon_sym_CodeUnit] = ACTIONS(5469),
    [anon_sym_COdeunit] = ACTIONS(5469),
    [anon_sym_codeUnit] = ACTIONS(5469),
    [sym_report_keyword] = ACTIONS(5469),
    [sym_query_keyword] = ACTIONS(5469),
    [anon_sym_xmlport] = ACTIONS(5469),
    [anon_sym_XMLPORT] = ACTIONS(5469),
    [anon_sym_Xmlport] = ACTIONS(5469),
    [anon_sym_XMLport] = ACTIONS(5469),
    [anon_sym_XMLPort] = ACTIONS(5469),
    [anon_sym_XmlPort] = ACTIONS(5469),
    [anon_sym_enum] = ACTIONS(5469),
    [anon_sym_ENUM] = ACTIONS(5469),
    [anon_sym_Enum] = ACTIONS(5469),
    [anon_sym_eNUM] = ACTIONS(5469),
    [anon_sym_eNum] = ACTIONS(5469),
    [anon_sym_ENum] = ACTIONS(5469),
    [sym_quoted_identifier] = ACTIONS(5471),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5471),
    [sym_verbatim_string] = ACTIONS(5471),
    [sym_integer] = ACTIONS(5469),
    [sym_continue_as_identifier] = ACTIONS(5471),
    [sym_preproc_open] = ACTIONS(5471),
    [sym_preproc_close] = ACTIONS(5471),
  },
  [STATE(2368)] = {
    [sym_identifier] = ACTIONS(5358),
    [anon_sym_SEMI] = ACTIONS(5360),
    [anon_sym_DASH] = ACTIONS(5360),
    [aux_sym_boolean_token1] = ACTIONS(5358),
    [aux_sym_boolean_token2] = ACTIONS(5358),
    [sym_decimal] = ACTIONS(5358),
    [anon_sym_LPAREN] = ACTIONS(5360),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5358),
    [anon_sym_LBRACK] = ACTIONS(5360),
    [aux_sym_record_type_token1] = ACTIONS(5358),
    [aux_sym_basic_type_token21] = ACTIONS(5358),
    [aux_sym_basic_type_token22] = ACTIONS(5358),
    [aux_sym_basic_type_token48] = ACTIONS(5358),
    [anon_sym_POUNDif] = ACTIONS(5360),
    [anon_sym_POUNDIF] = ACTIONS(5360),
    [anon_sym_POUNDIf] = ACTIONS(5360),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5473),
    [anon_sym_PIPE_PIPE] = ACTIONS(5475),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5457),
    [anon_sym_AMP_AMP] = ACTIONS(5459),
    [anon_sym_not] = ACTIONS(5358),
    [anon_sym_NOT] = ACTIONS(5358),
    [anon_sym_Not] = ACTIONS(5358),
    [anon_sym_POUNDelif] = ACTIONS(5360),
    [anon_sym_POUNDELIF] = ACTIONS(5360),
    [anon_sym_POUNDElif] = ACTIONS(5360),
    [anon_sym_POUNDelse] = ACTIONS(5360),
    [anon_sym_POUNDELSE] = ACTIONS(5360),
    [anon_sym_POUNDElse] = ACTIONS(5360),
    [anon_sym_POUNDelse2] = ACTIONS(5360),
    [anon_sym_POUNDELSE2] = ACTIONS(5360),
    [anon_sym_POUNDElse2] = ACTIONS(5360),
    [anon_sym_POUNDendif] = ACTIONS(5360),
    [anon_sym_POUNDENDIF] = ACTIONS(5360),
    [anon_sym_POUNDEndif] = ACTIONS(5360),
    [anon_sym_POUNDendif2] = ACTIONS(5360),
    [anon_sym_POUNDENDIF2] = ACTIONS(5360),
    [anon_sym_POUNDEndif2] = ACTIONS(5360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5358),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5358),
    [anon_sym_PLUS] = ACTIONS(5360),
    [sym_datetime_literal] = ACTIONS(5360),
    [sym_date_literal] = ACTIONS(5358),
    [sym_time_literal] = ACTIONS(5358),
    [sym_biginteger_literal] = ACTIONS(5360),
    [anon_sym_if] = ACTIONS(5358),
    [anon_sym_IF] = ACTIONS(5358),
    [anon_sym_If] = ACTIONS(5358),
    [anon_sym_case] = ACTIONS(5358),
    [anon_sym_CASE] = ACTIONS(5358),
    [anon_sym_Case] = ACTIONS(5358),
    [anon_sym_for] = ACTIONS(5358),
    [anon_sym_FOR] = ACTIONS(5358),
    [anon_sym_For] = ACTIONS(5358),
    [anon_sym_foreach] = ACTIONS(5358),
    [anon_sym_FOREACH] = ACTIONS(5358),
    [anon_sym_Foreach] = ACTIONS(5358),
    [anon_sym_while] = ACTIONS(5358),
    [anon_sym_WHILE] = ACTIONS(5358),
    [anon_sym_While] = ACTIONS(5358),
    [anon_sym_repeat] = ACTIONS(5358),
    [anon_sym_REPEAT] = ACTIONS(5358),
    [anon_sym_Repeat] = ACTIONS(5358),
    [anon_sym_exit] = ACTIONS(5358),
    [anon_sym_EXIT] = ACTIONS(5358),
    [anon_sym_Exit] = ACTIONS(5358),
    [anon_sym_continue] = ACTIONS(5358),
    [anon_sym_CONTINUE] = ACTIONS(5358),
    [anon_sym_Continue] = ACTIONS(5358),
    [anon_sym_break] = ACTIONS(5358),
    [anon_sym_BREAK] = ACTIONS(5358),
    [anon_sym_Break] = ACTIONS(5358),
    [anon_sym_with] = ACTIONS(5358),
    [anon_sym_WITH] = ACTIONS(5358),
    [anon_sym_With] = ACTIONS(5358),
    [sym_asserterror_keyword] = ACTIONS(5360),
    [sym_page_keyword] = ACTIONS(5358),
    [anon_sym_codeunit] = ACTIONS(5358),
    [anon_sym_CODEUNIT] = ACTIONS(5358),
    [anon_sym_Codeunit] = ACTIONS(5358),
    [anon_sym_CodeUnit] = ACTIONS(5358),
    [anon_sym_COdeunit] = ACTIONS(5358),
    [anon_sym_codeUnit] = ACTIONS(5358),
    [sym_report_keyword] = ACTIONS(5358),
    [sym_query_keyword] = ACTIONS(5358),
    [anon_sym_xmlport] = ACTIONS(5358),
    [anon_sym_XMLPORT] = ACTIONS(5358),
    [anon_sym_Xmlport] = ACTIONS(5358),
    [anon_sym_XMLport] = ACTIONS(5358),
    [anon_sym_XMLPort] = ACTIONS(5358),
    [anon_sym_XmlPort] = ACTIONS(5358),
    [anon_sym_enum] = ACTIONS(5358),
    [anon_sym_ENUM] = ACTIONS(5358),
    [anon_sym_Enum] = ACTIONS(5358),
    [anon_sym_eNUM] = ACTIONS(5358),
    [anon_sym_eNum] = ACTIONS(5358),
    [anon_sym_ENum] = ACTIONS(5358),
    [sym_quoted_identifier] = ACTIONS(5360),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5360),
    [sym_verbatim_string] = ACTIONS(5360),
    [sym_integer] = ACTIONS(5358),
    [sym_continue_as_identifier] = ACTIONS(5360),
    [sym_preproc_open] = ACTIONS(5360),
    [sym_preproc_close] = ACTIONS(5360),
    [sym_preproc_split_end] = ACTIONS(5360),
  },
  [STATE(2369)] = {
    [sym_identifier] = ACTIONS(5370),
    [anon_sym_SEMI] = ACTIONS(5372),
    [anon_sym_DASH] = ACTIONS(5372),
    [aux_sym_boolean_token1] = ACTIONS(5370),
    [aux_sym_boolean_token2] = ACTIONS(5370),
    [sym_decimal] = ACTIONS(5370),
    [anon_sym_LPAREN] = ACTIONS(5372),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5370),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [aux_sym_record_type_token1] = ACTIONS(5370),
    [aux_sym_basic_type_token21] = ACTIONS(5370),
    [aux_sym_basic_type_token22] = ACTIONS(5370),
    [aux_sym_basic_type_token48] = ACTIONS(5370),
    [anon_sym_POUNDif] = ACTIONS(5372),
    [anon_sym_POUNDIF] = ACTIONS(5372),
    [anon_sym_POUNDIf] = ACTIONS(5372),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5473),
    [anon_sym_PIPE_PIPE] = ACTIONS(5475),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5457),
    [anon_sym_AMP_AMP] = ACTIONS(5459),
    [anon_sym_not] = ACTIONS(5370),
    [anon_sym_NOT] = ACTIONS(5370),
    [anon_sym_Not] = ACTIONS(5370),
    [anon_sym_POUNDelif] = ACTIONS(5372),
    [anon_sym_POUNDELIF] = ACTIONS(5372),
    [anon_sym_POUNDElif] = ACTIONS(5372),
    [anon_sym_POUNDelse] = ACTIONS(5372),
    [anon_sym_POUNDELSE] = ACTIONS(5372),
    [anon_sym_POUNDElse] = ACTIONS(5372),
    [anon_sym_POUNDelse2] = ACTIONS(5372),
    [anon_sym_POUNDELSE2] = ACTIONS(5372),
    [anon_sym_POUNDElse2] = ACTIONS(5372),
    [anon_sym_POUNDendif] = ACTIONS(5372),
    [anon_sym_POUNDENDIF] = ACTIONS(5372),
    [anon_sym_POUNDEndif] = ACTIONS(5372),
    [anon_sym_POUNDendif2] = ACTIONS(5372),
    [anon_sym_POUNDENDIF2] = ACTIONS(5372),
    [anon_sym_POUNDEndif2] = ACTIONS(5372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5370),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5370),
    [anon_sym_PLUS] = ACTIONS(5372),
    [sym_datetime_literal] = ACTIONS(5372),
    [sym_date_literal] = ACTIONS(5370),
    [sym_time_literal] = ACTIONS(5370),
    [sym_biginteger_literal] = ACTIONS(5372),
    [anon_sym_if] = ACTIONS(5370),
    [anon_sym_IF] = ACTIONS(5370),
    [anon_sym_If] = ACTIONS(5370),
    [anon_sym_case] = ACTIONS(5370),
    [anon_sym_CASE] = ACTIONS(5370),
    [anon_sym_Case] = ACTIONS(5370),
    [anon_sym_for] = ACTIONS(5370),
    [anon_sym_FOR] = ACTIONS(5370),
    [anon_sym_For] = ACTIONS(5370),
    [anon_sym_foreach] = ACTIONS(5370),
    [anon_sym_FOREACH] = ACTIONS(5370),
    [anon_sym_Foreach] = ACTIONS(5370),
    [anon_sym_while] = ACTIONS(5370),
    [anon_sym_WHILE] = ACTIONS(5370),
    [anon_sym_While] = ACTIONS(5370),
    [anon_sym_repeat] = ACTIONS(5370),
    [anon_sym_REPEAT] = ACTIONS(5370),
    [anon_sym_Repeat] = ACTIONS(5370),
    [anon_sym_exit] = ACTIONS(5370),
    [anon_sym_EXIT] = ACTIONS(5370),
    [anon_sym_Exit] = ACTIONS(5370),
    [anon_sym_continue] = ACTIONS(5370),
    [anon_sym_CONTINUE] = ACTIONS(5370),
    [anon_sym_Continue] = ACTIONS(5370),
    [anon_sym_break] = ACTIONS(5370),
    [anon_sym_BREAK] = ACTIONS(5370),
    [anon_sym_Break] = ACTIONS(5370),
    [anon_sym_with] = ACTIONS(5370),
    [anon_sym_WITH] = ACTIONS(5370),
    [anon_sym_With] = ACTIONS(5370),
    [sym_asserterror_keyword] = ACTIONS(5372),
    [sym_page_keyword] = ACTIONS(5370),
    [anon_sym_codeunit] = ACTIONS(5370),
    [anon_sym_CODEUNIT] = ACTIONS(5370),
    [anon_sym_Codeunit] = ACTIONS(5370),
    [anon_sym_CodeUnit] = ACTIONS(5370),
    [anon_sym_COdeunit] = ACTIONS(5370),
    [anon_sym_codeUnit] = ACTIONS(5370),
    [sym_report_keyword] = ACTIONS(5370),
    [sym_query_keyword] = ACTIONS(5370),
    [anon_sym_xmlport] = ACTIONS(5370),
    [anon_sym_XMLPORT] = ACTIONS(5370),
    [anon_sym_Xmlport] = ACTIONS(5370),
    [anon_sym_XMLport] = ACTIONS(5370),
    [anon_sym_XMLPort] = ACTIONS(5370),
    [anon_sym_XmlPort] = ACTIONS(5370),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_ENUM] = ACTIONS(5370),
    [anon_sym_Enum] = ACTIONS(5370),
    [anon_sym_eNUM] = ACTIONS(5370),
    [anon_sym_eNum] = ACTIONS(5370),
    [anon_sym_ENum] = ACTIONS(5370),
    [sym_quoted_identifier] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5372),
    [sym_verbatim_string] = ACTIONS(5372),
    [sym_integer] = ACTIONS(5370),
    [sym_continue_as_identifier] = ACTIONS(5372),
    [sym_preproc_open] = ACTIONS(5372),
    [sym_preproc_close] = ACTIONS(5372),
    [sym_preproc_split_end] = ACTIONS(5372),
  },
  [STATE(2370)] = {
    [sym_else_keyword] = STATE(643),
    [sym_identifier] = ACTIONS(5477),
    [anon_sym_SEMI] = ACTIONS(5479),
    [anon_sym_DASH] = ACTIONS(5479),
    [aux_sym_boolean_token1] = ACTIONS(5477),
    [aux_sym_boolean_token2] = ACTIONS(5477),
    [sym_decimal] = ACTIONS(5477),
    [anon_sym_LPAREN] = ACTIONS(5479),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5477),
    [anon_sym_LBRACK] = ACTIONS(5479),
    [aux_sym_record_type_token1] = ACTIONS(5477),
    [aux_sym_basic_type_token21] = ACTIONS(5477),
    [aux_sym_basic_type_token22] = ACTIONS(5477),
    [aux_sym_basic_type_token48] = ACTIONS(5477),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5477),
    [anon_sym_POUNDif] = ACTIONS(5479),
    [anon_sym_POUNDIF] = ACTIONS(5479),
    [anon_sym_POUNDIf] = ACTIONS(5479),
    [anon_sym_not] = ACTIONS(5477),
    [anon_sym_NOT] = ACTIONS(5477),
    [anon_sym_Not] = ACTIONS(5477),
    [anon_sym_POUNDelif] = ACTIONS(5479),
    [anon_sym_POUNDELIF] = ACTIONS(5479),
    [anon_sym_POUNDElif] = ACTIONS(5479),
    [anon_sym_POUNDelse] = ACTIONS(5479),
    [anon_sym_POUNDELSE] = ACTIONS(5479),
    [anon_sym_POUNDElse] = ACTIONS(5479),
    [anon_sym_POUNDelse2] = ACTIONS(5479),
    [anon_sym_POUNDELSE2] = ACTIONS(5479),
    [anon_sym_POUNDElse2] = ACTIONS(5479),
    [anon_sym_POUNDendif] = ACTIONS(5479),
    [anon_sym_POUNDENDIF] = ACTIONS(5479),
    [anon_sym_POUNDEndif] = ACTIONS(5479),
    [anon_sym_POUNDendif2] = ACTIONS(5479),
    [anon_sym_POUNDENDIF2] = ACTIONS(5479),
    [anon_sym_POUNDEndif2] = ACTIONS(5479),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5477),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5477),
    [anon_sym_PLUS] = ACTIONS(5479),
    [sym_datetime_literal] = ACTIONS(5479),
    [sym_date_literal] = ACTIONS(5477),
    [sym_time_literal] = ACTIONS(5477),
    [sym_biginteger_literal] = ACTIONS(5479),
    [anon_sym_if] = ACTIONS(5477),
    [anon_sym_IF] = ACTIONS(5477),
    [anon_sym_If] = ACTIONS(5477),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5477),
    [anon_sym_CASE] = ACTIONS(5477),
    [anon_sym_Case] = ACTIONS(5477),
    [anon_sym_for] = ACTIONS(5477),
    [anon_sym_FOR] = ACTIONS(5477),
    [anon_sym_For] = ACTIONS(5477),
    [anon_sym_foreach] = ACTIONS(5477),
    [anon_sym_FOREACH] = ACTIONS(5477),
    [anon_sym_Foreach] = ACTIONS(5477),
    [anon_sym_while] = ACTIONS(5477),
    [anon_sym_WHILE] = ACTIONS(5477),
    [anon_sym_While] = ACTIONS(5477),
    [anon_sym_repeat] = ACTIONS(5477),
    [anon_sym_REPEAT] = ACTIONS(5477),
    [anon_sym_Repeat] = ACTIONS(5477),
    [anon_sym_exit] = ACTIONS(5477),
    [anon_sym_EXIT] = ACTIONS(5477),
    [anon_sym_Exit] = ACTIONS(5477),
    [anon_sym_continue] = ACTIONS(5477),
    [anon_sym_CONTINUE] = ACTIONS(5477),
    [anon_sym_Continue] = ACTIONS(5477),
    [anon_sym_break] = ACTIONS(5477),
    [anon_sym_BREAK] = ACTIONS(5477),
    [anon_sym_Break] = ACTIONS(5477),
    [anon_sym_with] = ACTIONS(5477),
    [anon_sym_WITH] = ACTIONS(5477),
    [anon_sym_With] = ACTIONS(5477),
    [sym_asserterror_keyword] = ACTIONS(5479),
    [sym_page_keyword] = ACTIONS(5477),
    [anon_sym_codeunit] = ACTIONS(5477),
    [anon_sym_CODEUNIT] = ACTIONS(5477),
    [anon_sym_Codeunit] = ACTIONS(5477),
    [anon_sym_CodeUnit] = ACTIONS(5477),
    [anon_sym_COdeunit] = ACTIONS(5477),
    [anon_sym_codeUnit] = ACTIONS(5477),
    [sym_report_keyword] = ACTIONS(5477),
    [sym_query_keyword] = ACTIONS(5477),
    [anon_sym_xmlport] = ACTIONS(5477),
    [anon_sym_XMLPORT] = ACTIONS(5477),
    [anon_sym_Xmlport] = ACTIONS(5477),
    [anon_sym_XMLport] = ACTIONS(5477),
    [anon_sym_XMLPort] = ACTIONS(5477),
    [anon_sym_XmlPort] = ACTIONS(5477),
    [anon_sym_enum] = ACTIONS(5477),
    [anon_sym_ENUM] = ACTIONS(5477),
    [anon_sym_Enum] = ACTIONS(5477),
    [anon_sym_eNUM] = ACTIONS(5477),
    [anon_sym_eNum] = ACTIONS(5477),
    [anon_sym_ENum] = ACTIONS(5477),
    [sym_quoted_identifier] = ACTIONS(5479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5479),
    [sym_verbatim_string] = ACTIONS(5479),
    [sym_integer] = ACTIONS(5477),
    [sym_continue_as_identifier] = ACTIONS(5479),
    [sym_preproc_open] = ACTIONS(5479),
    [sym_preproc_close] = ACTIONS(5479),
  },
  [STATE(2371)] = {
    [sym_else_keyword] = STATE(646),
    [sym_identifier] = ACTIONS(5481),
    [anon_sym_SEMI] = ACTIONS(5483),
    [anon_sym_DASH] = ACTIONS(5483),
    [aux_sym_boolean_token1] = ACTIONS(5481),
    [aux_sym_boolean_token2] = ACTIONS(5481),
    [sym_decimal] = ACTIONS(5481),
    [anon_sym_LPAREN] = ACTIONS(5483),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5481),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [aux_sym_record_type_token1] = ACTIONS(5481),
    [aux_sym_basic_type_token21] = ACTIONS(5481),
    [aux_sym_basic_type_token22] = ACTIONS(5481),
    [aux_sym_basic_type_token48] = ACTIONS(5481),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5481),
    [anon_sym_POUNDif] = ACTIONS(5483),
    [anon_sym_POUNDIF] = ACTIONS(5483),
    [anon_sym_POUNDIf] = ACTIONS(5483),
    [anon_sym_not] = ACTIONS(5481),
    [anon_sym_NOT] = ACTIONS(5481),
    [anon_sym_Not] = ACTIONS(5481),
    [anon_sym_POUNDelif] = ACTIONS(5483),
    [anon_sym_POUNDELIF] = ACTIONS(5483),
    [anon_sym_POUNDElif] = ACTIONS(5483),
    [anon_sym_POUNDelse] = ACTIONS(5483),
    [anon_sym_POUNDELSE] = ACTIONS(5483),
    [anon_sym_POUNDElse] = ACTIONS(5483),
    [anon_sym_POUNDelse2] = ACTIONS(5483),
    [anon_sym_POUNDELSE2] = ACTIONS(5483),
    [anon_sym_POUNDElse2] = ACTIONS(5483),
    [anon_sym_POUNDendif] = ACTIONS(5483),
    [anon_sym_POUNDENDIF] = ACTIONS(5483),
    [anon_sym_POUNDEndif] = ACTIONS(5483),
    [anon_sym_POUNDendif2] = ACTIONS(5483),
    [anon_sym_POUNDENDIF2] = ACTIONS(5483),
    [anon_sym_POUNDEndif2] = ACTIONS(5483),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5481),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5481),
    [anon_sym_PLUS] = ACTIONS(5483),
    [sym_datetime_literal] = ACTIONS(5483),
    [sym_date_literal] = ACTIONS(5481),
    [sym_time_literal] = ACTIONS(5481),
    [sym_biginteger_literal] = ACTIONS(5483),
    [anon_sym_if] = ACTIONS(5481),
    [anon_sym_IF] = ACTIONS(5481),
    [anon_sym_If] = ACTIONS(5481),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5481),
    [anon_sym_CASE] = ACTIONS(5481),
    [anon_sym_Case] = ACTIONS(5481),
    [anon_sym_for] = ACTIONS(5481),
    [anon_sym_FOR] = ACTIONS(5481),
    [anon_sym_For] = ACTIONS(5481),
    [anon_sym_foreach] = ACTIONS(5481),
    [anon_sym_FOREACH] = ACTIONS(5481),
    [anon_sym_Foreach] = ACTIONS(5481),
    [anon_sym_while] = ACTIONS(5481),
    [anon_sym_WHILE] = ACTIONS(5481),
    [anon_sym_While] = ACTIONS(5481),
    [anon_sym_repeat] = ACTIONS(5481),
    [anon_sym_REPEAT] = ACTIONS(5481),
    [anon_sym_Repeat] = ACTIONS(5481),
    [anon_sym_exit] = ACTIONS(5481),
    [anon_sym_EXIT] = ACTIONS(5481),
    [anon_sym_Exit] = ACTIONS(5481),
    [anon_sym_continue] = ACTIONS(5481),
    [anon_sym_CONTINUE] = ACTIONS(5481),
    [anon_sym_Continue] = ACTIONS(5481),
    [anon_sym_break] = ACTIONS(5481),
    [anon_sym_BREAK] = ACTIONS(5481),
    [anon_sym_Break] = ACTIONS(5481),
    [anon_sym_with] = ACTIONS(5481),
    [anon_sym_WITH] = ACTIONS(5481),
    [anon_sym_With] = ACTIONS(5481),
    [sym_asserterror_keyword] = ACTIONS(5483),
    [sym_page_keyword] = ACTIONS(5481),
    [anon_sym_codeunit] = ACTIONS(5481),
    [anon_sym_CODEUNIT] = ACTIONS(5481),
    [anon_sym_Codeunit] = ACTIONS(5481),
    [anon_sym_CodeUnit] = ACTIONS(5481),
    [anon_sym_COdeunit] = ACTIONS(5481),
    [anon_sym_codeUnit] = ACTIONS(5481),
    [sym_report_keyword] = ACTIONS(5481),
    [sym_query_keyword] = ACTIONS(5481),
    [anon_sym_xmlport] = ACTIONS(5481),
    [anon_sym_XMLPORT] = ACTIONS(5481),
    [anon_sym_Xmlport] = ACTIONS(5481),
    [anon_sym_XMLport] = ACTIONS(5481),
    [anon_sym_XMLPort] = ACTIONS(5481),
    [anon_sym_XmlPort] = ACTIONS(5481),
    [anon_sym_enum] = ACTIONS(5481),
    [anon_sym_ENUM] = ACTIONS(5481),
    [anon_sym_Enum] = ACTIONS(5481),
    [anon_sym_eNUM] = ACTIONS(5481),
    [anon_sym_eNum] = ACTIONS(5481),
    [anon_sym_ENum] = ACTIONS(5481),
    [sym_quoted_identifier] = ACTIONS(5483),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5483),
    [sym_verbatim_string] = ACTIONS(5483),
    [sym_integer] = ACTIONS(5481),
    [sym_continue_as_identifier] = ACTIONS(5483),
    [sym_preproc_open] = ACTIONS(5483),
    [sym_preproc_close] = ACTIONS(5483),
  },
  [STATE(2372)] = {
    [sym_identifier] = ACTIONS(5374),
    [anon_sym_SEMI] = ACTIONS(5376),
    [anon_sym_DASH] = ACTIONS(5376),
    [aux_sym_boolean_token1] = ACTIONS(5374),
    [aux_sym_boolean_token2] = ACTIONS(5374),
    [sym_decimal] = ACTIONS(5374),
    [anon_sym_LPAREN] = ACTIONS(5376),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5374),
    [anon_sym_LBRACK] = ACTIONS(5376),
    [aux_sym_record_type_token1] = ACTIONS(5374),
    [aux_sym_basic_type_token21] = ACTIONS(5374),
    [aux_sym_basic_type_token22] = ACTIONS(5374),
    [aux_sym_basic_type_token48] = ACTIONS(5374),
    [anon_sym_POUNDif] = ACTIONS(5376),
    [anon_sym_POUNDIF] = ACTIONS(5376),
    [anon_sym_POUNDIf] = ACTIONS(5376),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5374),
    [anon_sym_PIPE_PIPE] = ACTIONS(5376),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5374),
    [anon_sym_AMP_AMP] = ACTIONS(5376),
    [anon_sym_not] = ACTIONS(5374),
    [anon_sym_NOT] = ACTIONS(5374),
    [anon_sym_Not] = ACTIONS(5374),
    [anon_sym_POUNDelif] = ACTIONS(5376),
    [anon_sym_POUNDELIF] = ACTIONS(5376),
    [anon_sym_POUNDElif] = ACTIONS(5376),
    [anon_sym_POUNDelse] = ACTIONS(5376),
    [anon_sym_POUNDELSE] = ACTIONS(5376),
    [anon_sym_POUNDElse] = ACTIONS(5376),
    [anon_sym_POUNDelse2] = ACTIONS(5376),
    [anon_sym_POUNDELSE2] = ACTIONS(5376),
    [anon_sym_POUNDElse2] = ACTIONS(5376),
    [anon_sym_POUNDendif] = ACTIONS(5376),
    [anon_sym_POUNDENDIF] = ACTIONS(5376),
    [anon_sym_POUNDEndif] = ACTIONS(5376),
    [anon_sym_POUNDendif2] = ACTIONS(5376),
    [anon_sym_POUNDENDIF2] = ACTIONS(5376),
    [anon_sym_POUNDEndif2] = ACTIONS(5376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5374),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5374),
    [anon_sym_PLUS] = ACTIONS(5376),
    [sym_datetime_literal] = ACTIONS(5376),
    [sym_date_literal] = ACTIONS(5374),
    [sym_time_literal] = ACTIONS(5374),
    [sym_biginteger_literal] = ACTIONS(5376),
    [anon_sym_if] = ACTIONS(5374),
    [anon_sym_IF] = ACTIONS(5374),
    [anon_sym_If] = ACTIONS(5374),
    [anon_sym_case] = ACTIONS(5374),
    [anon_sym_CASE] = ACTIONS(5374),
    [anon_sym_Case] = ACTIONS(5374),
    [anon_sym_for] = ACTIONS(5374),
    [anon_sym_FOR] = ACTIONS(5374),
    [anon_sym_For] = ACTIONS(5374),
    [anon_sym_foreach] = ACTIONS(5374),
    [anon_sym_FOREACH] = ACTIONS(5374),
    [anon_sym_Foreach] = ACTIONS(5374),
    [anon_sym_while] = ACTIONS(5374),
    [anon_sym_WHILE] = ACTIONS(5374),
    [anon_sym_While] = ACTIONS(5374),
    [anon_sym_repeat] = ACTIONS(5374),
    [anon_sym_REPEAT] = ACTIONS(5374),
    [anon_sym_Repeat] = ACTIONS(5374),
    [anon_sym_exit] = ACTIONS(5374),
    [anon_sym_EXIT] = ACTIONS(5374),
    [anon_sym_Exit] = ACTIONS(5374),
    [anon_sym_continue] = ACTIONS(5374),
    [anon_sym_CONTINUE] = ACTIONS(5374),
    [anon_sym_Continue] = ACTIONS(5374),
    [anon_sym_break] = ACTIONS(5374),
    [anon_sym_BREAK] = ACTIONS(5374),
    [anon_sym_Break] = ACTIONS(5374),
    [anon_sym_with] = ACTIONS(5374),
    [anon_sym_WITH] = ACTIONS(5374),
    [anon_sym_With] = ACTIONS(5374),
    [sym_asserterror_keyword] = ACTIONS(5376),
    [sym_page_keyword] = ACTIONS(5374),
    [anon_sym_codeunit] = ACTIONS(5374),
    [anon_sym_CODEUNIT] = ACTIONS(5374),
    [anon_sym_Codeunit] = ACTIONS(5374),
    [anon_sym_CodeUnit] = ACTIONS(5374),
    [anon_sym_COdeunit] = ACTIONS(5374),
    [anon_sym_codeUnit] = ACTIONS(5374),
    [sym_report_keyword] = ACTIONS(5374),
    [sym_query_keyword] = ACTIONS(5374),
    [anon_sym_xmlport] = ACTIONS(5374),
    [anon_sym_XMLPORT] = ACTIONS(5374),
    [anon_sym_Xmlport] = ACTIONS(5374),
    [anon_sym_XMLport] = ACTIONS(5374),
    [anon_sym_XMLPort] = ACTIONS(5374),
    [anon_sym_XmlPort] = ACTIONS(5374),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_ENUM] = ACTIONS(5374),
    [anon_sym_Enum] = ACTIONS(5374),
    [anon_sym_eNUM] = ACTIONS(5374),
    [anon_sym_eNum] = ACTIONS(5374),
    [anon_sym_ENum] = ACTIONS(5374),
    [sym_quoted_identifier] = ACTIONS(5376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5376),
    [sym_verbatim_string] = ACTIONS(5376),
    [sym_integer] = ACTIONS(5374),
    [sym_continue_as_identifier] = ACTIONS(5376),
    [sym_preproc_open] = ACTIONS(5376),
    [sym_preproc_close] = ACTIONS(5376),
    [sym_preproc_split_end] = ACTIONS(5376),
  },
  [STATE(2373)] = {
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [aux_sym_where_clause_token1] = ACTIONS(3786),
    [aux_sym_where_condition_token1] = ACTIONS(3784),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3786),
    [anon_sym_STAR] = ACTIONS(3784),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3786),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3786),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_basic_type_token6] = ACTIONS(3784),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3786),
    [aux_sym_addafter_modification_token1] = ACTIONS(3786),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3786),
    [aux_sym_modify_modification_token1] = ACTIONS(3786),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3786),
    [aux_sym_movelast_modification_token1] = ACTIONS(3786),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3786),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3786),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_POUNDelif] = ACTIONS(3786),
    [anon_sym_POUNDELIF] = ACTIONS(3786),
    [anon_sym_POUNDElif] = ACTIONS(3786),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [anon_sym_POUNDendif] = ACTIONS(3786),
    [anon_sym_POUNDENDIF] = ACTIONS(3786),
    [anon_sym_POUNDEndif] = ACTIONS(3786),
    [anon_sym_POUNDendif2] = ACTIONS(3786),
    [anon_sym_POUNDENDIF2] = ACTIONS(3786),
    [anon_sym_POUNDEndif2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3786),
    [anon_sym_DIV] = ACTIONS(3786),
    [anon_sym_Div] = ACTIONS(3786),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3786),
    [anon_sym_AND] = ACTIONS(3786),
    [anon_sym_And] = ACTIONS(3786),
    [anon_sym_or] = ACTIONS(3786),
    [anon_sym_OR] = ACTIONS(3786),
    [anon_sym_Or] = ACTIONS(3786),
    [anon_sym_xor] = ACTIONS(3786),
    [anon_sym_XOR] = ACTIONS(3786),
    [anon_sym_Xor] = ACTIONS(3786),
    [anon_sym_QMARK] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_procedure_keyword] = ACTIONS(3786),
    [sym_trigger_keyword] = ACTIONS(3786),
    [sym_var_keyword] = ACTIONS(3786),
    [sym_local_keyword] = ACTIONS(3786),
    [sym_internal_keyword] = ACTIONS(3786),
    [sym_protected_keyword] = ACTIONS(3786),
    [sym_event_keyword] = ACTIONS(3786),
    [sym_fields_keyword] = ACTIONS(3786),
    [sym_keys_keyword] = ACTIONS(3786),
    [sym_fieldgroups_keyword] = ACTIONS(3786),
    [sym_actions_keyword] = ACTIONS(3786),
    [sym_layout_keyword] = ACTIONS(3786),
    [sym_area_keyword] = ACTIONS(3786),
    [sym_group_keyword] = ACTIONS(3786),
    [sym_repeater_keyword] = ACTIONS(3786),
    [sym_cuegroup_keyword] = ACTIONS(3786),
    [sym_fixed_keyword] = ACTIONS(3786),
    [sym_grid_keyword] = ACTIONS(3786),
    [sym_part_keyword] = ACTIONS(3786),
    [sym_systempart_keyword] = ACTIONS(3786),
    [sym_usercontrol_keyword] = ACTIONS(3786),
    [sym_dataset_keyword] = ACTIONS(3786),
    [sym_elements_keyword] = ACTIONS(3786),
    [sym_dataitem_keyword] = ACTIONS(3786),
    [sym_column_keyword] = ACTIONS(3786),
    [sym_filter_keyword] = ACTIONS(3786),
    [sym_labels_keyword] = ACTIONS(3786),
    [sym_rendering_keyword] = ACTIONS(3786),
    [sym_requestpage_keyword] = ACTIONS(3786),
    [sym_schema_keyword] = ACTIONS(3786),
    [sym_views_keyword] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
    [sym_preproc_close] = ACTIONS(3786),
  },
  [STATE(2374)] = {
    [sym_else_keyword] = STATE(673),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelif] = ACTIONS(5487),
    [anon_sym_POUNDELIF] = ACTIONS(5487),
    [anon_sym_POUNDElif] = ACTIONS(5487),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [anon_sym_POUNDendif] = ACTIONS(5487),
    [anon_sym_POUNDENDIF] = ACTIONS(5487),
    [anon_sym_POUNDEndif] = ACTIONS(5487),
    [anon_sym_POUNDendif2] = ACTIONS(5487),
    [anon_sym_POUNDENDIF2] = ACTIONS(5487),
    [anon_sym_POUNDEndif2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_preproc_close] = ACTIONS(5487),
  },
  [STATE(2375)] = {
    [sym_else_keyword] = STATE(651),
    [sym_identifier] = ACTIONS(5489),
    [anon_sym_SEMI] = ACTIONS(5491),
    [anon_sym_DASH] = ACTIONS(5491),
    [aux_sym_boolean_token1] = ACTIONS(5489),
    [aux_sym_boolean_token2] = ACTIONS(5489),
    [sym_decimal] = ACTIONS(5489),
    [anon_sym_LPAREN] = ACTIONS(5491),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5489),
    [anon_sym_LBRACK] = ACTIONS(5491),
    [aux_sym_record_type_token1] = ACTIONS(5489),
    [aux_sym_basic_type_token21] = ACTIONS(5489),
    [aux_sym_basic_type_token22] = ACTIONS(5489),
    [aux_sym_basic_type_token48] = ACTIONS(5489),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5489),
    [anon_sym_POUNDif] = ACTIONS(5491),
    [anon_sym_POUNDIF] = ACTIONS(5491),
    [anon_sym_POUNDIf] = ACTIONS(5491),
    [anon_sym_not] = ACTIONS(5489),
    [anon_sym_NOT] = ACTIONS(5489),
    [anon_sym_Not] = ACTIONS(5489),
    [anon_sym_POUNDelif] = ACTIONS(5491),
    [anon_sym_POUNDELIF] = ACTIONS(5491),
    [anon_sym_POUNDElif] = ACTIONS(5491),
    [anon_sym_POUNDelse] = ACTIONS(5491),
    [anon_sym_POUNDELSE] = ACTIONS(5491),
    [anon_sym_POUNDElse] = ACTIONS(5491),
    [anon_sym_POUNDelse2] = ACTIONS(5491),
    [anon_sym_POUNDELSE2] = ACTIONS(5491),
    [anon_sym_POUNDElse2] = ACTIONS(5491),
    [anon_sym_POUNDendif] = ACTIONS(5491),
    [anon_sym_POUNDENDIF] = ACTIONS(5491),
    [anon_sym_POUNDEndif] = ACTIONS(5491),
    [anon_sym_POUNDendif2] = ACTIONS(5491),
    [anon_sym_POUNDENDIF2] = ACTIONS(5491),
    [anon_sym_POUNDEndif2] = ACTIONS(5491),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5489),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5489),
    [anon_sym_PLUS] = ACTIONS(5491),
    [sym_datetime_literal] = ACTIONS(5491),
    [sym_date_literal] = ACTIONS(5489),
    [sym_time_literal] = ACTIONS(5489),
    [sym_biginteger_literal] = ACTIONS(5491),
    [anon_sym_if] = ACTIONS(5489),
    [anon_sym_IF] = ACTIONS(5489),
    [anon_sym_If] = ACTIONS(5489),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5489),
    [anon_sym_CASE] = ACTIONS(5489),
    [anon_sym_Case] = ACTIONS(5489),
    [anon_sym_for] = ACTIONS(5489),
    [anon_sym_FOR] = ACTIONS(5489),
    [anon_sym_For] = ACTIONS(5489),
    [anon_sym_foreach] = ACTIONS(5489),
    [anon_sym_FOREACH] = ACTIONS(5489),
    [anon_sym_Foreach] = ACTIONS(5489),
    [anon_sym_while] = ACTIONS(5489),
    [anon_sym_WHILE] = ACTIONS(5489),
    [anon_sym_While] = ACTIONS(5489),
    [anon_sym_repeat] = ACTIONS(5489),
    [anon_sym_REPEAT] = ACTIONS(5489),
    [anon_sym_Repeat] = ACTIONS(5489),
    [anon_sym_exit] = ACTIONS(5489),
    [anon_sym_EXIT] = ACTIONS(5489),
    [anon_sym_Exit] = ACTIONS(5489),
    [anon_sym_continue] = ACTIONS(5489),
    [anon_sym_CONTINUE] = ACTIONS(5489),
    [anon_sym_Continue] = ACTIONS(5489),
    [anon_sym_break] = ACTIONS(5489),
    [anon_sym_BREAK] = ACTIONS(5489),
    [anon_sym_Break] = ACTIONS(5489),
    [anon_sym_with] = ACTIONS(5489),
    [anon_sym_WITH] = ACTIONS(5489),
    [anon_sym_With] = ACTIONS(5489),
    [sym_asserterror_keyword] = ACTIONS(5491),
    [sym_page_keyword] = ACTIONS(5489),
    [anon_sym_codeunit] = ACTIONS(5489),
    [anon_sym_CODEUNIT] = ACTIONS(5489),
    [anon_sym_Codeunit] = ACTIONS(5489),
    [anon_sym_CodeUnit] = ACTIONS(5489),
    [anon_sym_COdeunit] = ACTIONS(5489),
    [anon_sym_codeUnit] = ACTIONS(5489),
    [sym_report_keyword] = ACTIONS(5489),
    [sym_query_keyword] = ACTIONS(5489),
    [anon_sym_xmlport] = ACTIONS(5489),
    [anon_sym_XMLPORT] = ACTIONS(5489),
    [anon_sym_Xmlport] = ACTIONS(5489),
    [anon_sym_XMLport] = ACTIONS(5489),
    [anon_sym_XMLPort] = ACTIONS(5489),
    [anon_sym_XmlPort] = ACTIONS(5489),
    [anon_sym_enum] = ACTIONS(5489),
    [anon_sym_ENUM] = ACTIONS(5489),
    [anon_sym_Enum] = ACTIONS(5489),
    [anon_sym_eNUM] = ACTIONS(5489),
    [anon_sym_eNum] = ACTIONS(5489),
    [anon_sym_ENum] = ACTIONS(5489),
    [sym_quoted_identifier] = ACTIONS(5491),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5491),
    [sym_verbatim_string] = ACTIONS(5491),
    [sym_integer] = ACTIONS(5489),
    [sym_continue_as_identifier] = ACTIONS(5491),
    [sym_preproc_open] = ACTIONS(5491),
    [sym_preproc_close] = ACTIONS(5491),
  },
  [STATE(2376)] = {
    [sym_else_keyword] = STATE(128),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelif] = ACTIONS(5487),
    [anon_sym_POUNDELIF] = ACTIONS(5487),
    [anon_sym_POUNDElif] = ACTIONS(5487),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [anon_sym_POUNDendif] = ACTIONS(5487),
    [anon_sym_POUNDENDIF] = ACTIONS(5487),
    [anon_sym_POUNDEndif] = ACTIONS(5487),
    [anon_sym_POUNDendif2] = ACTIONS(5487),
    [anon_sym_POUNDENDIF2] = ACTIONS(5487),
    [anon_sym_POUNDEndif2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_preproc_close] = ACTIONS(5487),
  },
  [STATE(2377)] = {
    [sym_identifier] = ACTIONS(5493),
    [anon_sym_SEMI] = ACTIONS(5495),
    [anon_sym_DASH] = ACTIONS(5495),
    [aux_sym_boolean_token1] = ACTIONS(5493),
    [aux_sym_boolean_token2] = ACTIONS(5493),
    [sym_decimal] = ACTIONS(5493),
    [anon_sym_LPAREN] = ACTIONS(5495),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5493),
    [anon_sym_LBRACK] = ACTIONS(5495),
    [aux_sym_record_type_token1] = ACTIONS(5493),
    [aux_sym_basic_type_token21] = ACTIONS(5493),
    [aux_sym_basic_type_token22] = ACTIONS(5493),
    [aux_sym_basic_type_token48] = ACTIONS(5493),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5493),
    [anon_sym_POUNDif] = ACTIONS(5495),
    [anon_sym_POUNDIF] = ACTIONS(5495),
    [anon_sym_POUNDIf] = ACTIONS(5495),
    [anon_sym_not] = ACTIONS(5493),
    [anon_sym_NOT] = ACTIONS(5493),
    [anon_sym_Not] = ACTIONS(5493),
    [anon_sym_POUNDelif] = ACTIONS(5495),
    [anon_sym_POUNDELIF] = ACTIONS(5495),
    [anon_sym_POUNDElif] = ACTIONS(5495),
    [anon_sym_POUNDelse] = ACTIONS(5495),
    [anon_sym_POUNDELSE] = ACTIONS(5495),
    [anon_sym_POUNDElse] = ACTIONS(5495),
    [anon_sym_POUNDelse2] = ACTIONS(5495),
    [anon_sym_POUNDELSE2] = ACTIONS(5495),
    [anon_sym_POUNDElse2] = ACTIONS(5495),
    [anon_sym_POUNDendif] = ACTIONS(5495),
    [anon_sym_POUNDENDIF] = ACTIONS(5495),
    [anon_sym_POUNDEndif] = ACTIONS(5495),
    [anon_sym_POUNDendif2] = ACTIONS(5495),
    [anon_sym_POUNDENDIF2] = ACTIONS(5495),
    [anon_sym_POUNDEndif2] = ACTIONS(5495),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5493),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5493),
    [anon_sym_PLUS] = ACTIONS(5495),
    [sym_datetime_literal] = ACTIONS(5495),
    [sym_date_literal] = ACTIONS(5493),
    [sym_time_literal] = ACTIONS(5493),
    [sym_biginteger_literal] = ACTIONS(5495),
    [anon_sym_if] = ACTIONS(5493),
    [anon_sym_IF] = ACTIONS(5493),
    [anon_sym_If] = ACTIONS(5493),
    [anon_sym_else] = ACTIONS(5493),
    [anon_sym_ELSE] = ACTIONS(5493),
    [anon_sym_Else] = ACTIONS(5493),
    [anon_sym_case] = ACTIONS(5493),
    [anon_sym_CASE] = ACTIONS(5493),
    [anon_sym_Case] = ACTIONS(5493),
    [anon_sym_for] = ACTIONS(5493),
    [anon_sym_FOR] = ACTIONS(5493),
    [anon_sym_For] = ACTIONS(5493),
    [anon_sym_foreach] = ACTIONS(5493),
    [anon_sym_FOREACH] = ACTIONS(5493),
    [anon_sym_Foreach] = ACTIONS(5493),
    [anon_sym_while] = ACTIONS(5493),
    [anon_sym_WHILE] = ACTIONS(5493),
    [anon_sym_While] = ACTIONS(5493),
    [anon_sym_repeat] = ACTIONS(5493),
    [anon_sym_REPEAT] = ACTIONS(5493),
    [anon_sym_Repeat] = ACTIONS(5493),
    [anon_sym_exit] = ACTIONS(5493),
    [anon_sym_EXIT] = ACTIONS(5493),
    [anon_sym_Exit] = ACTIONS(5493),
    [anon_sym_continue] = ACTIONS(5493),
    [anon_sym_CONTINUE] = ACTIONS(5493),
    [anon_sym_Continue] = ACTIONS(5493),
    [anon_sym_break] = ACTIONS(5493),
    [anon_sym_BREAK] = ACTIONS(5493),
    [anon_sym_Break] = ACTIONS(5493),
    [anon_sym_with] = ACTIONS(5493),
    [anon_sym_WITH] = ACTIONS(5493),
    [anon_sym_With] = ACTIONS(5493),
    [sym_asserterror_keyword] = ACTIONS(5495),
    [sym_page_keyword] = ACTIONS(5493),
    [anon_sym_codeunit] = ACTIONS(5493),
    [anon_sym_CODEUNIT] = ACTIONS(5493),
    [anon_sym_Codeunit] = ACTIONS(5493),
    [anon_sym_CodeUnit] = ACTIONS(5493),
    [anon_sym_COdeunit] = ACTIONS(5493),
    [anon_sym_codeUnit] = ACTIONS(5493),
    [sym_report_keyword] = ACTIONS(5493),
    [sym_query_keyword] = ACTIONS(5493),
    [anon_sym_xmlport] = ACTIONS(5493),
    [anon_sym_XMLPORT] = ACTIONS(5493),
    [anon_sym_Xmlport] = ACTIONS(5493),
    [anon_sym_XMLport] = ACTIONS(5493),
    [anon_sym_XMLPort] = ACTIONS(5493),
    [anon_sym_XmlPort] = ACTIONS(5493),
    [anon_sym_enum] = ACTIONS(5493),
    [anon_sym_ENUM] = ACTIONS(5493),
    [anon_sym_Enum] = ACTIONS(5493),
    [anon_sym_eNUM] = ACTIONS(5493),
    [anon_sym_eNum] = ACTIONS(5493),
    [anon_sym_ENum] = ACTIONS(5493),
    [sym_quoted_identifier] = ACTIONS(5495),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5495),
    [sym_verbatim_string] = ACTIONS(5495),
    [sym_integer] = ACTIONS(5493),
    [sym_continue_as_identifier] = ACTIONS(5495),
    [sym_preproc_open] = ACTIONS(5495),
    [sym_preproc_close] = ACTIONS(5495),
  },
  [STATE(2378)] = {
    [sym_identifier] = ACTIONS(5497),
    [anon_sym_SEMI] = ACTIONS(5499),
    [anon_sym_DASH] = ACTIONS(5501),
    [aux_sym_boolean_token1] = ACTIONS(5497),
    [aux_sym_boolean_token2] = ACTIONS(5497),
    [sym_decimal] = ACTIONS(5497),
    [anon_sym_LPAREN] = ACTIONS(5501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5497),
    [anon_sym_LBRACK] = ACTIONS(5501),
    [aux_sym_record_type_token1] = ACTIONS(5497),
    [aux_sym_basic_type_token21] = ACTIONS(5497),
    [aux_sym_basic_type_token22] = ACTIONS(5497),
    [aux_sym_basic_type_token48] = ACTIONS(5497),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5497),
    [anon_sym_POUNDif] = ACTIONS(5501),
    [anon_sym_POUNDIF] = ACTIONS(5501),
    [anon_sym_POUNDIf] = ACTIONS(5501),
    [anon_sym_not] = ACTIONS(5497),
    [anon_sym_NOT] = ACTIONS(5497),
    [anon_sym_Not] = ACTIONS(5497),
    [anon_sym_POUNDelif] = ACTIONS(5501),
    [anon_sym_POUNDELIF] = ACTIONS(5501),
    [anon_sym_POUNDElif] = ACTIONS(5501),
    [anon_sym_POUNDelse] = ACTIONS(5501),
    [anon_sym_POUNDELSE] = ACTIONS(5501),
    [anon_sym_POUNDElse] = ACTIONS(5501),
    [anon_sym_POUNDelse2] = ACTIONS(5501),
    [anon_sym_POUNDELSE2] = ACTIONS(5501),
    [anon_sym_POUNDElse2] = ACTIONS(5501),
    [anon_sym_POUNDendif] = ACTIONS(5501),
    [anon_sym_POUNDENDIF] = ACTIONS(5501),
    [anon_sym_POUNDEndif] = ACTIONS(5501),
    [anon_sym_POUNDendif2] = ACTIONS(5501),
    [anon_sym_POUNDENDIF2] = ACTIONS(5501),
    [anon_sym_POUNDEndif2] = ACTIONS(5501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5497),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5497),
    [anon_sym_PLUS] = ACTIONS(5501),
    [sym_datetime_literal] = ACTIONS(5501),
    [sym_date_literal] = ACTIONS(5497),
    [sym_time_literal] = ACTIONS(5497),
    [sym_biginteger_literal] = ACTIONS(5501),
    [anon_sym_if] = ACTIONS(5497),
    [anon_sym_IF] = ACTIONS(5497),
    [anon_sym_If] = ACTIONS(5497),
    [anon_sym_else] = ACTIONS(5497),
    [anon_sym_ELSE] = ACTIONS(5497),
    [anon_sym_Else] = ACTIONS(5497),
    [anon_sym_case] = ACTIONS(5497),
    [anon_sym_CASE] = ACTIONS(5497),
    [anon_sym_Case] = ACTIONS(5497),
    [anon_sym_for] = ACTIONS(5497),
    [anon_sym_FOR] = ACTIONS(5497),
    [anon_sym_For] = ACTIONS(5497),
    [anon_sym_foreach] = ACTIONS(5497),
    [anon_sym_FOREACH] = ACTIONS(5497),
    [anon_sym_Foreach] = ACTIONS(5497),
    [anon_sym_while] = ACTIONS(5497),
    [anon_sym_WHILE] = ACTIONS(5497),
    [anon_sym_While] = ACTIONS(5497),
    [anon_sym_repeat] = ACTIONS(5497),
    [anon_sym_REPEAT] = ACTIONS(5497),
    [anon_sym_Repeat] = ACTIONS(5497),
    [anon_sym_exit] = ACTIONS(5497),
    [anon_sym_EXIT] = ACTIONS(5497),
    [anon_sym_Exit] = ACTIONS(5497),
    [anon_sym_continue] = ACTIONS(5497),
    [anon_sym_CONTINUE] = ACTIONS(5497),
    [anon_sym_Continue] = ACTIONS(5497),
    [anon_sym_break] = ACTIONS(5497),
    [anon_sym_BREAK] = ACTIONS(5497),
    [anon_sym_Break] = ACTIONS(5497),
    [anon_sym_with] = ACTIONS(5497),
    [anon_sym_WITH] = ACTIONS(5497),
    [anon_sym_With] = ACTIONS(5497),
    [sym_asserterror_keyword] = ACTIONS(5501),
    [sym_page_keyword] = ACTIONS(5497),
    [anon_sym_codeunit] = ACTIONS(5497),
    [anon_sym_CODEUNIT] = ACTIONS(5497),
    [anon_sym_Codeunit] = ACTIONS(5497),
    [anon_sym_CodeUnit] = ACTIONS(5497),
    [anon_sym_COdeunit] = ACTIONS(5497),
    [anon_sym_codeUnit] = ACTIONS(5497),
    [sym_report_keyword] = ACTIONS(5497),
    [sym_query_keyword] = ACTIONS(5497),
    [anon_sym_xmlport] = ACTIONS(5497),
    [anon_sym_XMLPORT] = ACTIONS(5497),
    [anon_sym_Xmlport] = ACTIONS(5497),
    [anon_sym_XMLport] = ACTIONS(5497),
    [anon_sym_XMLPort] = ACTIONS(5497),
    [anon_sym_XmlPort] = ACTIONS(5497),
    [anon_sym_enum] = ACTIONS(5497),
    [anon_sym_ENUM] = ACTIONS(5497),
    [anon_sym_Enum] = ACTIONS(5497),
    [anon_sym_eNUM] = ACTIONS(5497),
    [anon_sym_eNum] = ACTIONS(5497),
    [anon_sym_ENum] = ACTIONS(5497),
    [sym_quoted_identifier] = ACTIONS(5501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5501),
    [sym_verbatim_string] = ACTIONS(5501),
    [sym_integer] = ACTIONS(5497),
    [sym_continue_as_identifier] = ACTIONS(5501),
    [sym_preproc_open] = ACTIONS(5501),
    [sym_preproc_close] = ACTIONS(5501),
  },
  [STATE(2379)] = {
    [sym_identifier] = ACTIONS(5497),
    [anon_sym_SEMI] = ACTIONS(5503),
    [anon_sym_DASH] = ACTIONS(5501),
    [aux_sym_boolean_token1] = ACTIONS(5497),
    [aux_sym_boolean_token2] = ACTIONS(5497),
    [sym_decimal] = ACTIONS(5497),
    [anon_sym_LPAREN] = ACTIONS(5501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5497),
    [anon_sym_LBRACK] = ACTIONS(5501),
    [aux_sym_record_type_token1] = ACTIONS(5497),
    [aux_sym_basic_type_token21] = ACTIONS(5497),
    [aux_sym_basic_type_token22] = ACTIONS(5497),
    [aux_sym_basic_type_token48] = ACTIONS(5497),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5497),
    [anon_sym_POUNDif] = ACTIONS(5501),
    [anon_sym_POUNDIF] = ACTIONS(5501),
    [anon_sym_POUNDIf] = ACTIONS(5501),
    [anon_sym_not] = ACTIONS(5497),
    [anon_sym_NOT] = ACTIONS(5497),
    [anon_sym_Not] = ACTIONS(5497),
    [anon_sym_POUNDelif] = ACTIONS(5501),
    [anon_sym_POUNDELIF] = ACTIONS(5501),
    [anon_sym_POUNDElif] = ACTIONS(5501),
    [anon_sym_POUNDelse] = ACTIONS(5501),
    [anon_sym_POUNDELSE] = ACTIONS(5501),
    [anon_sym_POUNDElse] = ACTIONS(5501),
    [anon_sym_POUNDelse2] = ACTIONS(5501),
    [anon_sym_POUNDELSE2] = ACTIONS(5501),
    [anon_sym_POUNDElse2] = ACTIONS(5501),
    [anon_sym_POUNDendif] = ACTIONS(5501),
    [anon_sym_POUNDENDIF] = ACTIONS(5501),
    [anon_sym_POUNDEndif] = ACTIONS(5501),
    [anon_sym_POUNDendif2] = ACTIONS(5501),
    [anon_sym_POUNDENDIF2] = ACTIONS(5501),
    [anon_sym_POUNDEndif2] = ACTIONS(5501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5497),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5497),
    [anon_sym_PLUS] = ACTIONS(5501),
    [sym_datetime_literal] = ACTIONS(5501),
    [sym_date_literal] = ACTIONS(5497),
    [sym_time_literal] = ACTIONS(5497),
    [sym_biginteger_literal] = ACTIONS(5501),
    [anon_sym_if] = ACTIONS(5497),
    [anon_sym_IF] = ACTIONS(5497),
    [anon_sym_If] = ACTIONS(5497),
    [anon_sym_else] = ACTIONS(5497),
    [anon_sym_ELSE] = ACTIONS(5497),
    [anon_sym_Else] = ACTIONS(5497),
    [anon_sym_case] = ACTIONS(5497),
    [anon_sym_CASE] = ACTIONS(5497),
    [anon_sym_Case] = ACTIONS(5497),
    [anon_sym_for] = ACTIONS(5497),
    [anon_sym_FOR] = ACTIONS(5497),
    [anon_sym_For] = ACTIONS(5497),
    [anon_sym_foreach] = ACTIONS(5497),
    [anon_sym_FOREACH] = ACTIONS(5497),
    [anon_sym_Foreach] = ACTIONS(5497),
    [anon_sym_while] = ACTIONS(5497),
    [anon_sym_WHILE] = ACTIONS(5497),
    [anon_sym_While] = ACTIONS(5497),
    [anon_sym_repeat] = ACTIONS(5497),
    [anon_sym_REPEAT] = ACTIONS(5497),
    [anon_sym_Repeat] = ACTIONS(5497),
    [anon_sym_exit] = ACTIONS(5497),
    [anon_sym_EXIT] = ACTIONS(5497),
    [anon_sym_Exit] = ACTIONS(5497),
    [anon_sym_continue] = ACTIONS(5497),
    [anon_sym_CONTINUE] = ACTIONS(5497),
    [anon_sym_Continue] = ACTIONS(5497),
    [anon_sym_break] = ACTIONS(5497),
    [anon_sym_BREAK] = ACTIONS(5497),
    [anon_sym_Break] = ACTIONS(5497),
    [anon_sym_with] = ACTIONS(5497),
    [anon_sym_WITH] = ACTIONS(5497),
    [anon_sym_With] = ACTIONS(5497),
    [sym_asserterror_keyword] = ACTIONS(5501),
    [sym_page_keyword] = ACTIONS(5497),
    [anon_sym_codeunit] = ACTIONS(5497),
    [anon_sym_CODEUNIT] = ACTIONS(5497),
    [anon_sym_Codeunit] = ACTIONS(5497),
    [anon_sym_CodeUnit] = ACTIONS(5497),
    [anon_sym_COdeunit] = ACTIONS(5497),
    [anon_sym_codeUnit] = ACTIONS(5497),
    [sym_report_keyword] = ACTIONS(5497),
    [sym_query_keyword] = ACTIONS(5497),
    [anon_sym_xmlport] = ACTIONS(5497),
    [anon_sym_XMLPORT] = ACTIONS(5497),
    [anon_sym_Xmlport] = ACTIONS(5497),
    [anon_sym_XMLport] = ACTIONS(5497),
    [anon_sym_XMLPort] = ACTIONS(5497),
    [anon_sym_XmlPort] = ACTIONS(5497),
    [anon_sym_enum] = ACTIONS(5497),
    [anon_sym_ENUM] = ACTIONS(5497),
    [anon_sym_Enum] = ACTIONS(5497),
    [anon_sym_eNUM] = ACTIONS(5497),
    [anon_sym_eNum] = ACTIONS(5497),
    [anon_sym_ENum] = ACTIONS(5497),
    [sym_quoted_identifier] = ACTIONS(5501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5501),
    [sym_verbatim_string] = ACTIONS(5501),
    [sym_integer] = ACTIONS(5497),
    [sym_continue_as_identifier] = ACTIONS(5501),
    [sym_preproc_open] = ACTIONS(5501),
    [sym_preproc_close] = ACTIONS(5501),
  },
  [STATE(2380)] = {
    [sym_identifier] = ACTIONS(5505),
    [anon_sym_SEMI] = ACTIONS(5507),
    [anon_sym_DASH] = ACTIONS(5507),
    [aux_sym_boolean_token1] = ACTIONS(5505),
    [aux_sym_boolean_token2] = ACTIONS(5505),
    [sym_decimal] = ACTIONS(5505),
    [anon_sym_LPAREN] = ACTIONS(5507),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5505),
    [anon_sym_LBRACK] = ACTIONS(5507),
    [aux_sym_record_type_token1] = ACTIONS(5505),
    [aux_sym_basic_type_token21] = ACTIONS(5505),
    [aux_sym_basic_type_token22] = ACTIONS(5505),
    [aux_sym_basic_type_token48] = ACTIONS(5505),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5505),
    [anon_sym_POUNDif] = ACTIONS(5507),
    [anon_sym_POUNDIF] = ACTIONS(5507),
    [anon_sym_POUNDIf] = ACTIONS(5507),
    [anon_sym_not] = ACTIONS(5505),
    [anon_sym_NOT] = ACTIONS(5505),
    [anon_sym_Not] = ACTIONS(5505),
    [anon_sym_POUNDelif] = ACTIONS(5507),
    [anon_sym_POUNDELIF] = ACTIONS(5507),
    [anon_sym_POUNDElif] = ACTIONS(5507),
    [anon_sym_POUNDelse] = ACTIONS(5507),
    [anon_sym_POUNDELSE] = ACTIONS(5507),
    [anon_sym_POUNDElse] = ACTIONS(5507),
    [anon_sym_POUNDelse2] = ACTIONS(5507),
    [anon_sym_POUNDELSE2] = ACTIONS(5507),
    [anon_sym_POUNDElse2] = ACTIONS(5507),
    [anon_sym_POUNDendif] = ACTIONS(5507),
    [anon_sym_POUNDENDIF] = ACTIONS(5507),
    [anon_sym_POUNDEndif] = ACTIONS(5507),
    [anon_sym_POUNDendif2] = ACTIONS(5507),
    [anon_sym_POUNDENDIF2] = ACTIONS(5507),
    [anon_sym_POUNDEndif2] = ACTIONS(5507),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5505),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5505),
    [anon_sym_PLUS] = ACTIONS(5507),
    [sym_datetime_literal] = ACTIONS(5507),
    [sym_date_literal] = ACTIONS(5505),
    [sym_time_literal] = ACTIONS(5505),
    [sym_biginteger_literal] = ACTIONS(5507),
    [anon_sym_if] = ACTIONS(5505),
    [anon_sym_IF] = ACTIONS(5505),
    [anon_sym_If] = ACTIONS(5505),
    [anon_sym_else] = ACTIONS(5505),
    [anon_sym_ELSE] = ACTIONS(5505),
    [anon_sym_Else] = ACTIONS(5505),
    [anon_sym_case] = ACTIONS(5505),
    [anon_sym_CASE] = ACTIONS(5505),
    [anon_sym_Case] = ACTIONS(5505),
    [anon_sym_for] = ACTIONS(5505),
    [anon_sym_FOR] = ACTIONS(5505),
    [anon_sym_For] = ACTIONS(5505),
    [anon_sym_foreach] = ACTIONS(5505),
    [anon_sym_FOREACH] = ACTIONS(5505),
    [anon_sym_Foreach] = ACTIONS(5505),
    [anon_sym_while] = ACTIONS(5505),
    [anon_sym_WHILE] = ACTIONS(5505),
    [anon_sym_While] = ACTIONS(5505),
    [anon_sym_repeat] = ACTIONS(5505),
    [anon_sym_REPEAT] = ACTIONS(5505),
    [anon_sym_Repeat] = ACTIONS(5505),
    [anon_sym_exit] = ACTIONS(5505),
    [anon_sym_EXIT] = ACTIONS(5505),
    [anon_sym_Exit] = ACTIONS(5505),
    [anon_sym_continue] = ACTIONS(5505),
    [anon_sym_CONTINUE] = ACTIONS(5505),
    [anon_sym_Continue] = ACTIONS(5505),
    [anon_sym_break] = ACTIONS(5505),
    [anon_sym_BREAK] = ACTIONS(5505),
    [anon_sym_Break] = ACTIONS(5505),
    [anon_sym_with] = ACTIONS(5505),
    [anon_sym_WITH] = ACTIONS(5505),
    [anon_sym_With] = ACTIONS(5505),
    [sym_asserterror_keyword] = ACTIONS(5507),
    [sym_page_keyword] = ACTIONS(5505),
    [anon_sym_codeunit] = ACTIONS(5505),
    [anon_sym_CODEUNIT] = ACTIONS(5505),
    [anon_sym_Codeunit] = ACTIONS(5505),
    [anon_sym_CodeUnit] = ACTIONS(5505),
    [anon_sym_COdeunit] = ACTIONS(5505),
    [anon_sym_codeUnit] = ACTIONS(5505),
    [sym_report_keyword] = ACTIONS(5505),
    [sym_query_keyword] = ACTIONS(5505),
    [anon_sym_xmlport] = ACTIONS(5505),
    [anon_sym_XMLPORT] = ACTIONS(5505),
    [anon_sym_Xmlport] = ACTIONS(5505),
    [anon_sym_XMLport] = ACTIONS(5505),
    [anon_sym_XMLPort] = ACTIONS(5505),
    [anon_sym_XmlPort] = ACTIONS(5505),
    [anon_sym_enum] = ACTIONS(5505),
    [anon_sym_ENUM] = ACTIONS(5505),
    [anon_sym_Enum] = ACTIONS(5505),
    [anon_sym_eNUM] = ACTIONS(5505),
    [anon_sym_eNum] = ACTIONS(5505),
    [anon_sym_ENum] = ACTIONS(5505),
    [sym_quoted_identifier] = ACTIONS(5507),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5507),
    [sym_verbatim_string] = ACTIONS(5507),
    [sym_integer] = ACTIONS(5505),
    [sym_continue_as_identifier] = ACTIONS(5507),
    [sym_preproc_open] = ACTIONS(5507),
    [sym_preproc_close] = ACTIONS(5507),
  },
  [STATE(2381)] = {
    [sym_identifier] = ACTIONS(5509),
    [anon_sym_SEMI] = ACTIONS(5511),
    [anon_sym_DASH] = ACTIONS(5511),
    [aux_sym_boolean_token1] = ACTIONS(5509),
    [aux_sym_boolean_token2] = ACTIONS(5509),
    [sym_decimal] = ACTIONS(5509),
    [anon_sym_LPAREN] = ACTIONS(5511),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5509),
    [anon_sym_LBRACK] = ACTIONS(5511),
    [aux_sym_record_type_token1] = ACTIONS(5509),
    [aux_sym_basic_type_token21] = ACTIONS(5509),
    [aux_sym_basic_type_token22] = ACTIONS(5509),
    [aux_sym_basic_type_token48] = ACTIONS(5509),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5509),
    [anon_sym_POUNDif] = ACTIONS(5511),
    [anon_sym_POUNDIF] = ACTIONS(5511),
    [anon_sym_POUNDIf] = ACTIONS(5511),
    [anon_sym_not] = ACTIONS(5509),
    [anon_sym_NOT] = ACTIONS(5509),
    [anon_sym_Not] = ACTIONS(5509),
    [anon_sym_POUNDelif] = ACTIONS(5511),
    [anon_sym_POUNDELIF] = ACTIONS(5511),
    [anon_sym_POUNDElif] = ACTIONS(5511),
    [anon_sym_POUNDelse] = ACTIONS(5511),
    [anon_sym_POUNDELSE] = ACTIONS(5511),
    [anon_sym_POUNDElse] = ACTIONS(5511),
    [anon_sym_POUNDelse2] = ACTIONS(5511),
    [anon_sym_POUNDELSE2] = ACTIONS(5511),
    [anon_sym_POUNDElse2] = ACTIONS(5511),
    [anon_sym_POUNDendif] = ACTIONS(5511),
    [anon_sym_POUNDENDIF] = ACTIONS(5511),
    [anon_sym_POUNDEndif] = ACTIONS(5511),
    [anon_sym_POUNDendif2] = ACTIONS(5511),
    [anon_sym_POUNDENDIF2] = ACTIONS(5511),
    [anon_sym_POUNDEndif2] = ACTIONS(5511),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5509),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5509),
    [anon_sym_PLUS] = ACTIONS(5511),
    [sym_datetime_literal] = ACTIONS(5511),
    [sym_date_literal] = ACTIONS(5509),
    [sym_time_literal] = ACTIONS(5509),
    [sym_biginteger_literal] = ACTIONS(5511),
    [anon_sym_if] = ACTIONS(5509),
    [anon_sym_IF] = ACTIONS(5509),
    [anon_sym_If] = ACTIONS(5509),
    [anon_sym_else] = ACTIONS(5509),
    [anon_sym_ELSE] = ACTIONS(5509),
    [anon_sym_Else] = ACTIONS(5509),
    [anon_sym_case] = ACTIONS(5509),
    [anon_sym_CASE] = ACTIONS(5509),
    [anon_sym_Case] = ACTIONS(5509),
    [anon_sym_for] = ACTIONS(5509),
    [anon_sym_FOR] = ACTIONS(5509),
    [anon_sym_For] = ACTIONS(5509),
    [anon_sym_foreach] = ACTIONS(5509),
    [anon_sym_FOREACH] = ACTIONS(5509),
    [anon_sym_Foreach] = ACTIONS(5509),
    [anon_sym_while] = ACTIONS(5509),
    [anon_sym_WHILE] = ACTIONS(5509),
    [anon_sym_While] = ACTIONS(5509),
    [anon_sym_repeat] = ACTIONS(5509),
    [anon_sym_REPEAT] = ACTIONS(5509),
    [anon_sym_Repeat] = ACTIONS(5509),
    [anon_sym_exit] = ACTIONS(5509),
    [anon_sym_EXIT] = ACTIONS(5509),
    [anon_sym_Exit] = ACTIONS(5509),
    [anon_sym_continue] = ACTIONS(5509),
    [anon_sym_CONTINUE] = ACTIONS(5509),
    [anon_sym_Continue] = ACTIONS(5509),
    [anon_sym_break] = ACTIONS(5509),
    [anon_sym_BREAK] = ACTIONS(5509),
    [anon_sym_Break] = ACTIONS(5509),
    [anon_sym_with] = ACTIONS(5509),
    [anon_sym_WITH] = ACTIONS(5509),
    [anon_sym_With] = ACTIONS(5509),
    [sym_asserterror_keyword] = ACTIONS(5511),
    [sym_page_keyword] = ACTIONS(5509),
    [anon_sym_codeunit] = ACTIONS(5509),
    [anon_sym_CODEUNIT] = ACTIONS(5509),
    [anon_sym_Codeunit] = ACTIONS(5509),
    [anon_sym_CodeUnit] = ACTIONS(5509),
    [anon_sym_COdeunit] = ACTIONS(5509),
    [anon_sym_codeUnit] = ACTIONS(5509),
    [sym_report_keyword] = ACTIONS(5509),
    [sym_query_keyword] = ACTIONS(5509),
    [anon_sym_xmlport] = ACTIONS(5509),
    [anon_sym_XMLPORT] = ACTIONS(5509),
    [anon_sym_Xmlport] = ACTIONS(5509),
    [anon_sym_XMLport] = ACTIONS(5509),
    [anon_sym_XMLPort] = ACTIONS(5509),
    [anon_sym_XmlPort] = ACTIONS(5509),
    [anon_sym_enum] = ACTIONS(5509),
    [anon_sym_ENUM] = ACTIONS(5509),
    [anon_sym_Enum] = ACTIONS(5509),
    [anon_sym_eNUM] = ACTIONS(5509),
    [anon_sym_eNum] = ACTIONS(5509),
    [anon_sym_ENum] = ACTIONS(5509),
    [sym_quoted_identifier] = ACTIONS(5511),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5511),
    [sym_verbatim_string] = ACTIONS(5511),
    [sym_integer] = ACTIONS(5509),
    [sym_continue_as_identifier] = ACTIONS(5511),
    [sym_preproc_open] = ACTIONS(5511),
    [sym_preproc_close] = ACTIONS(5511),
  },
  [STATE(2382)] = {
    [sym_identifier] = ACTIONS(5513),
    [anon_sym_SEMI] = ACTIONS(5515),
    [anon_sym_DASH] = ACTIONS(5515),
    [aux_sym_boolean_token1] = ACTIONS(5513),
    [aux_sym_boolean_token2] = ACTIONS(5513),
    [sym_decimal] = ACTIONS(5513),
    [anon_sym_LPAREN] = ACTIONS(5515),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5513),
    [anon_sym_LBRACK] = ACTIONS(5515),
    [aux_sym_record_type_token1] = ACTIONS(5513),
    [aux_sym_basic_type_token21] = ACTIONS(5513),
    [aux_sym_basic_type_token22] = ACTIONS(5513),
    [aux_sym_basic_type_token48] = ACTIONS(5513),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5513),
    [anon_sym_POUNDif] = ACTIONS(5515),
    [anon_sym_POUNDIF] = ACTIONS(5515),
    [anon_sym_POUNDIf] = ACTIONS(5515),
    [anon_sym_not] = ACTIONS(5513),
    [anon_sym_NOT] = ACTIONS(5513),
    [anon_sym_Not] = ACTIONS(5513),
    [anon_sym_POUNDelif] = ACTIONS(5515),
    [anon_sym_POUNDELIF] = ACTIONS(5515),
    [anon_sym_POUNDElif] = ACTIONS(5515),
    [anon_sym_POUNDelse] = ACTIONS(5515),
    [anon_sym_POUNDELSE] = ACTIONS(5515),
    [anon_sym_POUNDElse] = ACTIONS(5515),
    [anon_sym_POUNDelse2] = ACTIONS(5515),
    [anon_sym_POUNDELSE2] = ACTIONS(5515),
    [anon_sym_POUNDElse2] = ACTIONS(5515),
    [anon_sym_POUNDendif] = ACTIONS(5515),
    [anon_sym_POUNDENDIF] = ACTIONS(5515),
    [anon_sym_POUNDEndif] = ACTIONS(5515),
    [anon_sym_POUNDendif2] = ACTIONS(5515),
    [anon_sym_POUNDENDIF2] = ACTIONS(5515),
    [anon_sym_POUNDEndif2] = ACTIONS(5515),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5513),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5513),
    [anon_sym_PLUS] = ACTIONS(5515),
    [sym_datetime_literal] = ACTIONS(5515),
    [sym_date_literal] = ACTIONS(5513),
    [sym_time_literal] = ACTIONS(5513),
    [sym_biginteger_literal] = ACTIONS(5515),
    [anon_sym_if] = ACTIONS(5513),
    [anon_sym_IF] = ACTIONS(5513),
    [anon_sym_If] = ACTIONS(5513),
    [anon_sym_else] = ACTIONS(5513),
    [anon_sym_ELSE] = ACTIONS(5513),
    [anon_sym_Else] = ACTIONS(5513),
    [anon_sym_case] = ACTIONS(5513),
    [anon_sym_CASE] = ACTIONS(5513),
    [anon_sym_Case] = ACTIONS(5513),
    [anon_sym_for] = ACTIONS(5513),
    [anon_sym_FOR] = ACTIONS(5513),
    [anon_sym_For] = ACTIONS(5513),
    [anon_sym_foreach] = ACTIONS(5513),
    [anon_sym_FOREACH] = ACTIONS(5513),
    [anon_sym_Foreach] = ACTIONS(5513),
    [anon_sym_while] = ACTIONS(5513),
    [anon_sym_WHILE] = ACTIONS(5513),
    [anon_sym_While] = ACTIONS(5513),
    [anon_sym_repeat] = ACTIONS(5513),
    [anon_sym_REPEAT] = ACTIONS(5513),
    [anon_sym_Repeat] = ACTIONS(5513),
    [anon_sym_exit] = ACTIONS(5513),
    [anon_sym_EXIT] = ACTIONS(5513),
    [anon_sym_Exit] = ACTIONS(5513),
    [anon_sym_continue] = ACTIONS(5513),
    [anon_sym_CONTINUE] = ACTIONS(5513),
    [anon_sym_Continue] = ACTIONS(5513),
    [anon_sym_break] = ACTIONS(5513),
    [anon_sym_BREAK] = ACTIONS(5513),
    [anon_sym_Break] = ACTIONS(5513),
    [anon_sym_with] = ACTIONS(5513),
    [anon_sym_WITH] = ACTIONS(5513),
    [anon_sym_With] = ACTIONS(5513),
    [sym_asserterror_keyword] = ACTIONS(5515),
    [sym_page_keyword] = ACTIONS(5513),
    [anon_sym_codeunit] = ACTIONS(5513),
    [anon_sym_CODEUNIT] = ACTIONS(5513),
    [anon_sym_Codeunit] = ACTIONS(5513),
    [anon_sym_CodeUnit] = ACTIONS(5513),
    [anon_sym_COdeunit] = ACTIONS(5513),
    [anon_sym_codeUnit] = ACTIONS(5513),
    [sym_report_keyword] = ACTIONS(5513),
    [sym_query_keyword] = ACTIONS(5513),
    [anon_sym_xmlport] = ACTIONS(5513),
    [anon_sym_XMLPORT] = ACTIONS(5513),
    [anon_sym_Xmlport] = ACTIONS(5513),
    [anon_sym_XMLport] = ACTIONS(5513),
    [anon_sym_XMLPort] = ACTIONS(5513),
    [anon_sym_XmlPort] = ACTIONS(5513),
    [anon_sym_enum] = ACTIONS(5513),
    [anon_sym_ENUM] = ACTIONS(5513),
    [anon_sym_Enum] = ACTIONS(5513),
    [anon_sym_eNUM] = ACTIONS(5513),
    [anon_sym_eNum] = ACTIONS(5513),
    [anon_sym_ENum] = ACTIONS(5513),
    [sym_quoted_identifier] = ACTIONS(5515),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5515),
    [sym_verbatim_string] = ACTIONS(5515),
    [sym_integer] = ACTIONS(5513),
    [sym_continue_as_identifier] = ACTIONS(5515),
    [sym_preproc_open] = ACTIONS(5515),
    [sym_preproc_close] = ACTIONS(5515),
  },
  [STATE(2383)] = {
    [sym_identifier] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym_DASH] = ACTIONS(5519),
    [aux_sym_boolean_token1] = ACTIONS(5517),
    [aux_sym_boolean_token2] = ACTIONS(5517),
    [sym_decimal] = ACTIONS(5517),
    [anon_sym_LPAREN] = ACTIONS(5519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5519),
    [aux_sym_record_type_token1] = ACTIONS(5517),
    [aux_sym_basic_type_token21] = ACTIONS(5517),
    [aux_sym_basic_type_token22] = ACTIONS(5517),
    [aux_sym_basic_type_token48] = ACTIONS(5517),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5517),
    [anon_sym_POUNDif] = ACTIONS(5519),
    [anon_sym_POUNDIF] = ACTIONS(5519),
    [anon_sym_POUNDIf] = ACTIONS(5519),
    [anon_sym_not] = ACTIONS(5517),
    [anon_sym_NOT] = ACTIONS(5517),
    [anon_sym_Not] = ACTIONS(5517),
    [anon_sym_POUNDelif] = ACTIONS(5519),
    [anon_sym_POUNDELIF] = ACTIONS(5519),
    [anon_sym_POUNDElif] = ACTIONS(5519),
    [anon_sym_POUNDelse] = ACTIONS(5519),
    [anon_sym_POUNDELSE] = ACTIONS(5519),
    [anon_sym_POUNDElse] = ACTIONS(5519),
    [anon_sym_POUNDelse2] = ACTIONS(5519),
    [anon_sym_POUNDELSE2] = ACTIONS(5519),
    [anon_sym_POUNDElse2] = ACTIONS(5519),
    [anon_sym_POUNDendif] = ACTIONS(5519),
    [anon_sym_POUNDENDIF] = ACTIONS(5519),
    [anon_sym_POUNDEndif] = ACTIONS(5519),
    [anon_sym_POUNDendif2] = ACTIONS(5519),
    [anon_sym_POUNDENDIF2] = ACTIONS(5519),
    [anon_sym_POUNDEndif2] = ACTIONS(5519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5517),
    [anon_sym_PLUS] = ACTIONS(5519),
    [sym_datetime_literal] = ACTIONS(5519),
    [sym_date_literal] = ACTIONS(5517),
    [sym_time_literal] = ACTIONS(5517),
    [sym_biginteger_literal] = ACTIONS(5519),
    [anon_sym_if] = ACTIONS(5517),
    [anon_sym_IF] = ACTIONS(5517),
    [anon_sym_If] = ACTIONS(5517),
    [anon_sym_else] = ACTIONS(5517),
    [anon_sym_ELSE] = ACTIONS(5517),
    [anon_sym_Else] = ACTIONS(5517),
    [anon_sym_case] = ACTIONS(5517),
    [anon_sym_CASE] = ACTIONS(5517),
    [anon_sym_Case] = ACTIONS(5517),
    [anon_sym_for] = ACTIONS(5517),
    [anon_sym_FOR] = ACTIONS(5517),
    [anon_sym_For] = ACTIONS(5517),
    [anon_sym_foreach] = ACTIONS(5517),
    [anon_sym_FOREACH] = ACTIONS(5517),
    [anon_sym_Foreach] = ACTIONS(5517),
    [anon_sym_while] = ACTIONS(5517),
    [anon_sym_WHILE] = ACTIONS(5517),
    [anon_sym_While] = ACTIONS(5517),
    [anon_sym_repeat] = ACTIONS(5517),
    [anon_sym_REPEAT] = ACTIONS(5517),
    [anon_sym_Repeat] = ACTIONS(5517),
    [anon_sym_exit] = ACTIONS(5517),
    [anon_sym_EXIT] = ACTIONS(5517),
    [anon_sym_Exit] = ACTIONS(5517),
    [anon_sym_continue] = ACTIONS(5517),
    [anon_sym_CONTINUE] = ACTIONS(5517),
    [anon_sym_Continue] = ACTIONS(5517),
    [anon_sym_break] = ACTIONS(5517),
    [anon_sym_BREAK] = ACTIONS(5517),
    [anon_sym_Break] = ACTIONS(5517),
    [anon_sym_with] = ACTIONS(5517),
    [anon_sym_WITH] = ACTIONS(5517),
    [anon_sym_With] = ACTIONS(5517),
    [sym_asserterror_keyword] = ACTIONS(5519),
    [sym_page_keyword] = ACTIONS(5517),
    [anon_sym_codeunit] = ACTIONS(5517),
    [anon_sym_CODEUNIT] = ACTIONS(5517),
    [anon_sym_Codeunit] = ACTIONS(5517),
    [anon_sym_CodeUnit] = ACTIONS(5517),
    [anon_sym_COdeunit] = ACTIONS(5517),
    [anon_sym_codeUnit] = ACTIONS(5517),
    [sym_report_keyword] = ACTIONS(5517),
    [sym_query_keyword] = ACTIONS(5517),
    [anon_sym_xmlport] = ACTIONS(5517),
    [anon_sym_XMLPORT] = ACTIONS(5517),
    [anon_sym_Xmlport] = ACTIONS(5517),
    [anon_sym_XMLport] = ACTIONS(5517),
    [anon_sym_XMLPort] = ACTIONS(5517),
    [anon_sym_XmlPort] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_ENUM] = ACTIONS(5517),
    [anon_sym_Enum] = ACTIONS(5517),
    [anon_sym_eNUM] = ACTIONS(5517),
    [anon_sym_eNum] = ACTIONS(5517),
    [anon_sym_ENum] = ACTIONS(5517),
    [sym_quoted_identifier] = ACTIONS(5519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5519),
    [sym_verbatim_string] = ACTIONS(5519),
    [sym_integer] = ACTIONS(5517),
    [sym_continue_as_identifier] = ACTIONS(5519),
    [sym_preproc_open] = ACTIONS(5519),
    [sym_preproc_close] = ACTIONS(5519),
  },
  [STATE(2384)] = {
    [sym_identifier] = ACTIONS(5521),
    [anon_sym_SEMI] = ACTIONS(5523),
    [anon_sym_DASH] = ACTIONS(5523),
    [aux_sym_boolean_token1] = ACTIONS(5521),
    [aux_sym_boolean_token2] = ACTIONS(5521),
    [sym_decimal] = ACTIONS(5521),
    [anon_sym_LPAREN] = ACTIONS(5523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5521),
    [anon_sym_LBRACK] = ACTIONS(5523),
    [aux_sym_record_type_token1] = ACTIONS(5521),
    [aux_sym_basic_type_token21] = ACTIONS(5521),
    [aux_sym_basic_type_token22] = ACTIONS(5521),
    [aux_sym_basic_type_token48] = ACTIONS(5521),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5521),
    [anon_sym_POUNDif] = ACTIONS(5523),
    [anon_sym_POUNDIF] = ACTIONS(5523),
    [anon_sym_POUNDIf] = ACTIONS(5523),
    [anon_sym_not] = ACTIONS(5521),
    [anon_sym_NOT] = ACTIONS(5521),
    [anon_sym_Not] = ACTIONS(5521),
    [anon_sym_POUNDelif] = ACTIONS(5523),
    [anon_sym_POUNDELIF] = ACTIONS(5523),
    [anon_sym_POUNDElif] = ACTIONS(5523),
    [anon_sym_POUNDelse] = ACTIONS(5523),
    [anon_sym_POUNDELSE] = ACTIONS(5523),
    [anon_sym_POUNDElse] = ACTIONS(5523),
    [anon_sym_POUNDelse2] = ACTIONS(5523),
    [anon_sym_POUNDELSE2] = ACTIONS(5523),
    [anon_sym_POUNDElse2] = ACTIONS(5523),
    [anon_sym_POUNDendif] = ACTIONS(5523),
    [anon_sym_POUNDENDIF] = ACTIONS(5523),
    [anon_sym_POUNDEndif] = ACTIONS(5523),
    [anon_sym_POUNDendif2] = ACTIONS(5523),
    [anon_sym_POUNDENDIF2] = ACTIONS(5523),
    [anon_sym_POUNDEndif2] = ACTIONS(5523),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5521),
    [anon_sym_PLUS] = ACTIONS(5523),
    [sym_datetime_literal] = ACTIONS(5523),
    [sym_date_literal] = ACTIONS(5521),
    [sym_time_literal] = ACTIONS(5521),
    [sym_biginteger_literal] = ACTIONS(5523),
    [anon_sym_if] = ACTIONS(5521),
    [anon_sym_IF] = ACTIONS(5521),
    [anon_sym_If] = ACTIONS(5521),
    [anon_sym_else] = ACTIONS(5521),
    [anon_sym_ELSE] = ACTIONS(5521),
    [anon_sym_Else] = ACTIONS(5521),
    [anon_sym_case] = ACTIONS(5521),
    [anon_sym_CASE] = ACTIONS(5521),
    [anon_sym_Case] = ACTIONS(5521),
    [anon_sym_for] = ACTIONS(5521),
    [anon_sym_FOR] = ACTIONS(5521),
    [anon_sym_For] = ACTIONS(5521),
    [anon_sym_foreach] = ACTIONS(5521),
    [anon_sym_FOREACH] = ACTIONS(5521),
    [anon_sym_Foreach] = ACTIONS(5521),
    [anon_sym_while] = ACTIONS(5521),
    [anon_sym_WHILE] = ACTIONS(5521),
    [anon_sym_While] = ACTIONS(5521),
    [anon_sym_repeat] = ACTIONS(5521),
    [anon_sym_REPEAT] = ACTIONS(5521),
    [anon_sym_Repeat] = ACTIONS(5521),
    [anon_sym_exit] = ACTIONS(5521),
    [anon_sym_EXIT] = ACTIONS(5521),
    [anon_sym_Exit] = ACTIONS(5521),
    [anon_sym_continue] = ACTIONS(5521),
    [anon_sym_CONTINUE] = ACTIONS(5521),
    [anon_sym_Continue] = ACTIONS(5521),
    [anon_sym_break] = ACTIONS(5521),
    [anon_sym_BREAK] = ACTIONS(5521),
    [anon_sym_Break] = ACTIONS(5521),
    [anon_sym_with] = ACTIONS(5521),
    [anon_sym_WITH] = ACTIONS(5521),
    [anon_sym_With] = ACTIONS(5521),
    [sym_asserterror_keyword] = ACTIONS(5523),
    [sym_page_keyword] = ACTIONS(5521),
    [anon_sym_codeunit] = ACTIONS(5521),
    [anon_sym_CODEUNIT] = ACTIONS(5521),
    [anon_sym_Codeunit] = ACTIONS(5521),
    [anon_sym_CodeUnit] = ACTIONS(5521),
    [anon_sym_COdeunit] = ACTIONS(5521),
    [anon_sym_codeUnit] = ACTIONS(5521),
    [sym_report_keyword] = ACTIONS(5521),
    [sym_query_keyword] = ACTIONS(5521),
    [anon_sym_xmlport] = ACTIONS(5521),
    [anon_sym_XMLPORT] = ACTIONS(5521),
    [anon_sym_Xmlport] = ACTIONS(5521),
    [anon_sym_XMLport] = ACTIONS(5521),
    [anon_sym_XMLPort] = ACTIONS(5521),
    [anon_sym_XmlPort] = ACTIONS(5521),
    [anon_sym_enum] = ACTIONS(5521),
    [anon_sym_ENUM] = ACTIONS(5521),
    [anon_sym_Enum] = ACTIONS(5521),
    [anon_sym_eNUM] = ACTIONS(5521),
    [anon_sym_eNum] = ACTIONS(5521),
    [anon_sym_ENum] = ACTIONS(5521),
    [sym_quoted_identifier] = ACTIONS(5523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5523),
    [sym_verbatim_string] = ACTIONS(5523),
    [sym_integer] = ACTIONS(5521),
    [sym_continue_as_identifier] = ACTIONS(5523),
    [sym_preproc_open] = ACTIONS(5523),
    [sym_preproc_close] = ACTIONS(5523),
  },
  [STATE(2385)] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5527),
    [aux_sym_boolean_token1] = ACTIONS(5525),
    [aux_sym_boolean_token2] = ACTIONS(5525),
    [sym_decimal] = ACTIONS(5525),
    [anon_sym_LPAREN] = ACTIONS(5527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [aux_sym_record_type_token1] = ACTIONS(5525),
    [aux_sym_basic_type_token21] = ACTIONS(5525),
    [aux_sym_basic_type_token22] = ACTIONS(5525),
    [aux_sym_basic_type_token48] = ACTIONS(5525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5525),
    [anon_sym_POUNDif] = ACTIONS(5527),
    [anon_sym_POUNDIF] = ACTIONS(5527),
    [anon_sym_POUNDIf] = ACTIONS(5527),
    [anon_sym_not] = ACTIONS(5525),
    [anon_sym_NOT] = ACTIONS(5525),
    [anon_sym_Not] = ACTIONS(5525),
    [anon_sym_POUNDelif] = ACTIONS(5527),
    [anon_sym_POUNDELIF] = ACTIONS(5527),
    [anon_sym_POUNDElif] = ACTIONS(5527),
    [anon_sym_POUNDelse] = ACTIONS(5527),
    [anon_sym_POUNDELSE] = ACTIONS(5527),
    [anon_sym_POUNDElse] = ACTIONS(5527),
    [anon_sym_POUNDelse2] = ACTIONS(5527),
    [anon_sym_POUNDELSE2] = ACTIONS(5527),
    [anon_sym_POUNDElse2] = ACTIONS(5527),
    [anon_sym_POUNDendif] = ACTIONS(5527),
    [anon_sym_POUNDENDIF] = ACTIONS(5527),
    [anon_sym_POUNDEndif] = ACTIONS(5527),
    [anon_sym_POUNDendif2] = ACTIONS(5527),
    [anon_sym_POUNDENDIF2] = ACTIONS(5527),
    [anon_sym_POUNDEndif2] = ACTIONS(5527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5527),
    [sym_datetime_literal] = ACTIONS(5527),
    [sym_date_literal] = ACTIONS(5525),
    [sym_time_literal] = ACTIONS(5525),
    [sym_biginteger_literal] = ACTIONS(5527),
    [anon_sym_if] = ACTIONS(5525),
    [anon_sym_IF] = ACTIONS(5525),
    [anon_sym_If] = ACTIONS(5525),
    [anon_sym_else] = ACTIONS(5525),
    [anon_sym_ELSE] = ACTIONS(5525),
    [anon_sym_Else] = ACTIONS(5525),
    [anon_sym_case] = ACTIONS(5525),
    [anon_sym_CASE] = ACTIONS(5525),
    [anon_sym_Case] = ACTIONS(5525),
    [anon_sym_for] = ACTIONS(5525),
    [anon_sym_FOR] = ACTIONS(5525),
    [anon_sym_For] = ACTIONS(5525),
    [anon_sym_foreach] = ACTIONS(5525),
    [anon_sym_FOREACH] = ACTIONS(5525),
    [anon_sym_Foreach] = ACTIONS(5525),
    [anon_sym_while] = ACTIONS(5525),
    [anon_sym_WHILE] = ACTIONS(5525),
    [anon_sym_While] = ACTIONS(5525),
    [anon_sym_repeat] = ACTIONS(5525),
    [anon_sym_REPEAT] = ACTIONS(5525),
    [anon_sym_Repeat] = ACTIONS(5525),
    [anon_sym_exit] = ACTIONS(5525),
    [anon_sym_EXIT] = ACTIONS(5525),
    [anon_sym_Exit] = ACTIONS(5525),
    [anon_sym_continue] = ACTIONS(5525),
    [anon_sym_CONTINUE] = ACTIONS(5525),
    [anon_sym_Continue] = ACTIONS(5525),
    [anon_sym_break] = ACTIONS(5525),
    [anon_sym_BREAK] = ACTIONS(5525),
    [anon_sym_Break] = ACTIONS(5525),
    [anon_sym_with] = ACTIONS(5525),
    [anon_sym_WITH] = ACTIONS(5525),
    [anon_sym_With] = ACTIONS(5525),
    [sym_asserterror_keyword] = ACTIONS(5527),
    [sym_page_keyword] = ACTIONS(5525),
    [anon_sym_codeunit] = ACTIONS(5525),
    [anon_sym_CODEUNIT] = ACTIONS(5525),
    [anon_sym_Codeunit] = ACTIONS(5525),
    [anon_sym_CodeUnit] = ACTIONS(5525),
    [anon_sym_COdeunit] = ACTIONS(5525),
    [anon_sym_codeUnit] = ACTIONS(5525),
    [sym_report_keyword] = ACTIONS(5525),
    [sym_query_keyword] = ACTIONS(5525),
    [anon_sym_xmlport] = ACTIONS(5525),
    [anon_sym_XMLPORT] = ACTIONS(5525),
    [anon_sym_Xmlport] = ACTIONS(5525),
    [anon_sym_XMLport] = ACTIONS(5525),
    [anon_sym_XMLPort] = ACTIONS(5525),
    [anon_sym_XmlPort] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_ENUM] = ACTIONS(5525),
    [anon_sym_Enum] = ACTIONS(5525),
    [anon_sym_eNUM] = ACTIONS(5525),
    [anon_sym_eNum] = ACTIONS(5525),
    [anon_sym_ENum] = ACTIONS(5525),
    [sym_quoted_identifier] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5527),
    [sym_verbatim_string] = ACTIONS(5527),
    [sym_integer] = ACTIONS(5525),
    [sym_continue_as_identifier] = ACTIONS(5527),
    [sym_preproc_open] = ACTIONS(5527),
    [sym_preproc_close] = ACTIONS(5527),
  },
  [STATE(2386)] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5527),
    [aux_sym_boolean_token1] = ACTIONS(5525),
    [aux_sym_boolean_token2] = ACTIONS(5525),
    [sym_decimal] = ACTIONS(5525),
    [anon_sym_LPAREN] = ACTIONS(5527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [aux_sym_record_type_token1] = ACTIONS(5525),
    [aux_sym_basic_type_token21] = ACTIONS(5525),
    [aux_sym_basic_type_token22] = ACTIONS(5525),
    [aux_sym_basic_type_token48] = ACTIONS(5525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5525),
    [anon_sym_POUNDif] = ACTIONS(5527),
    [anon_sym_POUNDIF] = ACTIONS(5527),
    [anon_sym_POUNDIf] = ACTIONS(5527),
    [anon_sym_not] = ACTIONS(5525),
    [anon_sym_NOT] = ACTIONS(5525),
    [anon_sym_Not] = ACTIONS(5525),
    [anon_sym_POUNDelif] = ACTIONS(5527),
    [anon_sym_POUNDELIF] = ACTIONS(5527),
    [anon_sym_POUNDElif] = ACTIONS(5527),
    [anon_sym_POUNDelse] = ACTIONS(5527),
    [anon_sym_POUNDELSE] = ACTIONS(5527),
    [anon_sym_POUNDElse] = ACTIONS(5527),
    [anon_sym_POUNDelse2] = ACTIONS(5527),
    [anon_sym_POUNDELSE2] = ACTIONS(5527),
    [anon_sym_POUNDElse2] = ACTIONS(5527),
    [anon_sym_POUNDendif] = ACTIONS(5527),
    [anon_sym_POUNDENDIF] = ACTIONS(5527),
    [anon_sym_POUNDEndif] = ACTIONS(5527),
    [anon_sym_POUNDendif2] = ACTIONS(5527),
    [anon_sym_POUNDENDIF2] = ACTIONS(5527),
    [anon_sym_POUNDEndif2] = ACTIONS(5527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5527),
    [sym_datetime_literal] = ACTIONS(5527),
    [sym_date_literal] = ACTIONS(5525),
    [sym_time_literal] = ACTIONS(5525),
    [sym_biginteger_literal] = ACTIONS(5527),
    [anon_sym_if] = ACTIONS(5525),
    [anon_sym_IF] = ACTIONS(5525),
    [anon_sym_If] = ACTIONS(5525),
    [anon_sym_else] = ACTIONS(5525),
    [anon_sym_ELSE] = ACTIONS(5525),
    [anon_sym_Else] = ACTIONS(5525),
    [anon_sym_case] = ACTIONS(5525),
    [anon_sym_CASE] = ACTIONS(5525),
    [anon_sym_Case] = ACTIONS(5525),
    [anon_sym_for] = ACTIONS(5525),
    [anon_sym_FOR] = ACTIONS(5525),
    [anon_sym_For] = ACTIONS(5525),
    [anon_sym_foreach] = ACTIONS(5525),
    [anon_sym_FOREACH] = ACTIONS(5525),
    [anon_sym_Foreach] = ACTIONS(5525),
    [anon_sym_while] = ACTIONS(5525),
    [anon_sym_WHILE] = ACTIONS(5525),
    [anon_sym_While] = ACTIONS(5525),
    [anon_sym_repeat] = ACTIONS(5525),
    [anon_sym_REPEAT] = ACTIONS(5525),
    [anon_sym_Repeat] = ACTIONS(5525),
    [anon_sym_exit] = ACTIONS(5525),
    [anon_sym_EXIT] = ACTIONS(5525),
    [anon_sym_Exit] = ACTIONS(5525),
    [anon_sym_continue] = ACTIONS(5525),
    [anon_sym_CONTINUE] = ACTIONS(5525),
    [anon_sym_Continue] = ACTIONS(5525),
    [anon_sym_break] = ACTIONS(5525),
    [anon_sym_BREAK] = ACTIONS(5525),
    [anon_sym_Break] = ACTIONS(5525),
    [anon_sym_with] = ACTIONS(5525),
    [anon_sym_WITH] = ACTIONS(5525),
    [anon_sym_With] = ACTIONS(5525),
    [sym_asserterror_keyword] = ACTIONS(5527),
    [sym_page_keyword] = ACTIONS(5525),
    [anon_sym_codeunit] = ACTIONS(5525),
    [anon_sym_CODEUNIT] = ACTIONS(5525),
    [anon_sym_Codeunit] = ACTIONS(5525),
    [anon_sym_CodeUnit] = ACTIONS(5525),
    [anon_sym_COdeunit] = ACTIONS(5525),
    [anon_sym_codeUnit] = ACTIONS(5525),
    [sym_report_keyword] = ACTIONS(5525),
    [sym_query_keyword] = ACTIONS(5525),
    [anon_sym_xmlport] = ACTIONS(5525),
    [anon_sym_XMLPORT] = ACTIONS(5525),
    [anon_sym_Xmlport] = ACTIONS(5525),
    [anon_sym_XMLport] = ACTIONS(5525),
    [anon_sym_XMLPort] = ACTIONS(5525),
    [anon_sym_XmlPort] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_ENUM] = ACTIONS(5525),
    [anon_sym_Enum] = ACTIONS(5525),
    [anon_sym_eNUM] = ACTIONS(5525),
    [anon_sym_eNum] = ACTIONS(5525),
    [anon_sym_ENum] = ACTIONS(5525),
    [sym_quoted_identifier] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5527),
    [sym_verbatim_string] = ACTIONS(5527),
    [sym_integer] = ACTIONS(5525),
    [sym_continue_as_identifier] = ACTIONS(5527),
    [sym_preproc_open] = ACTIONS(5527),
    [sym_preproc_close] = ACTIONS(5527),
  },
  [STATE(2387)] = {
    [sym_identifier] = ACTIONS(5529),
    [anon_sym_SEMI] = ACTIONS(5531),
    [anon_sym_DASH] = ACTIONS(5531),
    [aux_sym_boolean_token1] = ACTIONS(5529),
    [aux_sym_boolean_token2] = ACTIONS(5529),
    [sym_decimal] = ACTIONS(5529),
    [anon_sym_LPAREN] = ACTIONS(5531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5529),
    [anon_sym_LBRACK] = ACTIONS(5531),
    [aux_sym_record_type_token1] = ACTIONS(5529),
    [aux_sym_basic_type_token21] = ACTIONS(5529),
    [aux_sym_basic_type_token22] = ACTIONS(5529),
    [aux_sym_basic_type_token48] = ACTIONS(5529),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5529),
    [anon_sym_POUNDif] = ACTIONS(5531),
    [anon_sym_POUNDIF] = ACTIONS(5531),
    [anon_sym_POUNDIf] = ACTIONS(5531),
    [anon_sym_not] = ACTIONS(5529),
    [anon_sym_NOT] = ACTIONS(5529),
    [anon_sym_Not] = ACTIONS(5529),
    [anon_sym_POUNDelif] = ACTIONS(5531),
    [anon_sym_POUNDELIF] = ACTIONS(5531),
    [anon_sym_POUNDElif] = ACTIONS(5531),
    [anon_sym_POUNDelse] = ACTIONS(5531),
    [anon_sym_POUNDELSE] = ACTIONS(5531),
    [anon_sym_POUNDElse] = ACTIONS(5531),
    [anon_sym_POUNDelse2] = ACTIONS(5531),
    [anon_sym_POUNDELSE2] = ACTIONS(5531),
    [anon_sym_POUNDElse2] = ACTIONS(5531),
    [anon_sym_POUNDendif] = ACTIONS(5531),
    [anon_sym_POUNDENDIF] = ACTIONS(5531),
    [anon_sym_POUNDEndif] = ACTIONS(5531),
    [anon_sym_POUNDendif2] = ACTIONS(5531),
    [anon_sym_POUNDENDIF2] = ACTIONS(5531),
    [anon_sym_POUNDEndif2] = ACTIONS(5531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5529),
    [anon_sym_PLUS] = ACTIONS(5531),
    [sym_datetime_literal] = ACTIONS(5531),
    [sym_date_literal] = ACTIONS(5529),
    [sym_time_literal] = ACTIONS(5529),
    [sym_biginteger_literal] = ACTIONS(5531),
    [anon_sym_if] = ACTIONS(5529),
    [anon_sym_IF] = ACTIONS(5529),
    [anon_sym_If] = ACTIONS(5529),
    [anon_sym_else] = ACTIONS(5529),
    [anon_sym_ELSE] = ACTIONS(5529),
    [anon_sym_Else] = ACTIONS(5529),
    [anon_sym_case] = ACTIONS(5529),
    [anon_sym_CASE] = ACTIONS(5529),
    [anon_sym_Case] = ACTIONS(5529),
    [anon_sym_for] = ACTIONS(5529),
    [anon_sym_FOR] = ACTIONS(5529),
    [anon_sym_For] = ACTIONS(5529),
    [anon_sym_foreach] = ACTIONS(5529),
    [anon_sym_FOREACH] = ACTIONS(5529),
    [anon_sym_Foreach] = ACTIONS(5529),
    [anon_sym_while] = ACTIONS(5529),
    [anon_sym_WHILE] = ACTIONS(5529),
    [anon_sym_While] = ACTIONS(5529),
    [anon_sym_repeat] = ACTIONS(5529),
    [anon_sym_REPEAT] = ACTIONS(5529),
    [anon_sym_Repeat] = ACTIONS(5529),
    [anon_sym_exit] = ACTIONS(5529),
    [anon_sym_EXIT] = ACTIONS(5529),
    [anon_sym_Exit] = ACTIONS(5529),
    [anon_sym_continue] = ACTIONS(5529),
    [anon_sym_CONTINUE] = ACTIONS(5529),
    [anon_sym_Continue] = ACTIONS(5529),
    [anon_sym_break] = ACTIONS(5529),
    [anon_sym_BREAK] = ACTIONS(5529),
    [anon_sym_Break] = ACTIONS(5529),
    [anon_sym_with] = ACTIONS(5529),
    [anon_sym_WITH] = ACTIONS(5529),
    [anon_sym_With] = ACTIONS(5529),
    [sym_asserterror_keyword] = ACTIONS(5531),
    [sym_page_keyword] = ACTIONS(5529),
    [anon_sym_codeunit] = ACTIONS(5529),
    [anon_sym_CODEUNIT] = ACTIONS(5529),
    [anon_sym_Codeunit] = ACTIONS(5529),
    [anon_sym_CodeUnit] = ACTIONS(5529),
    [anon_sym_COdeunit] = ACTIONS(5529),
    [anon_sym_codeUnit] = ACTIONS(5529),
    [sym_report_keyword] = ACTIONS(5529),
    [sym_query_keyword] = ACTIONS(5529),
    [anon_sym_xmlport] = ACTIONS(5529),
    [anon_sym_XMLPORT] = ACTIONS(5529),
    [anon_sym_Xmlport] = ACTIONS(5529),
    [anon_sym_XMLport] = ACTIONS(5529),
    [anon_sym_XMLPort] = ACTIONS(5529),
    [anon_sym_XmlPort] = ACTIONS(5529),
    [anon_sym_enum] = ACTIONS(5529),
    [anon_sym_ENUM] = ACTIONS(5529),
    [anon_sym_Enum] = ACTIONS(5529),
    [anon_sym_eNUM] = ACTIONS(5529),
    [anon_sym_eNum] = ACTIONS(5529),
    [anon_sym_ENum] = ACTIONS(5529),
    [sym_quoted_identifier] = ACTIONS(5531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5531),
    [sym_verbatim_string] = ACTIONS(5531),
    [sym_integer] = ACTIONS(5529),
    [sym_continue_as_identifier] = ACTIONS(5531),
    [sym_preproc_open] = ACTIONS(5531),
    [sym_preproc_close] = ACTIONS(5531),
  },
  [STATE(2388)] = {
    [sym_identifier] = ACTIONS(5533),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym_DASH] = ACTIONS(5535),
    [aux_sym_boolean_token1] = ACTIONS(5533),
    [aux_sym_boolean_token2] = ACTIONS(5533),
    [sym_decimal] = ACTIONS(5533),
    [anon_sym_LPAREN] = ACTIONS(5535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5533),
    [anon_sym_LBRACK] = ACTIONS(5535),
    [aux_sym_record_type_token1] = ACTIONS(5533),
    [aux_sym_basic_type_token21] = ACTIONS(5533),
    [aux_sym_basic_type_token22] = ACTIONS(5533),
    [aux_sym_basic_type_token48] = ACTIONS(5533),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5533),
    [anon_sym_POUNDif] = ACTIONS(5535),
    [anon_sym_POUNDIF] = ACTIONS(5535),
    [anon_sym_POUNDIf] = ACTIONS(5535),
    [anon_sym_not] = ACTIONS(5533),
    [anon_sym_NOT] = ACTIONS(5533),
    [anon_sym_Not] = ACTIONS(5533),
    [anon_sym_POUNDelif] = ACTIONS(5535),
    [anon_sym_POUNDELIF] = ACTIONS(5535),
    [anon_sym_POUNDElif] = ACTIONS(5535),
    [anon_sym_POUNDelse] = ACTIONS(5535),
    [anon_sym_POUNDELSE] = ACTIONS(5535),
    [anon_sym_POUNDElse] = ACTIONS(5535),
    [anon_sym_POUNDelse2] = ACTIONS(5535),
    [anon_sym_POUNDELSE2] = ACTIONS(5535),
    [anon_sym_POUNDElse2] = ACTIONS(5535),
    [anon_sym_POUNDendif] = ACTIONS(5535),
    [anon_sym_POUNDENDIF] = ACTIONS(5535),
    [anon_sym_POUNDEndif] = ACTIONS(5535),
    [anon_sym_POUNDendif2] = ACTIONS(5535),
    [anon_sym_POUNDENDIF2] = ACTIONS(5535),
    [anon_sym_POUNDEndif2] = ACTIONS(5535),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5533),
    [anon_sym_PLUS] = ACTIONS(5535),
    [sym_datetime_literal] = ACTIONS(5535),
    [sym_date_literal] = ACTIONS(5533),
    [sym_time_literal] = ACTIONS(5533),
    [sym_biginteger_literal] = ACTIONS(5535),
    [anon_sym_if] = ACTIONS(5533),
    [anon_sym_IF] = ACTIONS(5533),
    [anon_sym_If] = ACTIONS(5533),
    [anon_sym_else] = ACTIONS(5533),
    [anon_sym_ELSE] = ACTIONS(5533),
    [anon_sym_Else] = ACTIONS(5533),
    [anon_sym_case] = ACTIONS(5533),
    [anon_sym_CASE] = ACTIONS(5533),
    [anon_sym_Case] = ACTIONS(5533),
    [anon_sym_for] = ACTIONS(5533),
    [anon_sym_FOR] = ACTIONS(5533),
    [anon_sym_For] = ACTIONS(5533),
    [anon_sym_foreach] = ACTIONS(5533),
    [anon_sym_FOREACH] = ACTIONS(5533),
    [anon_sym_Foreach] = ACTIONS(5533),
    [anon_sym_while] = ACTIONS(5533),
    [anon_sym_WHILE] = ACTIONS(5533),
    [anon_sym_While] = ACTIONS(5533),
    [anon_sym_repeat] = ACTIONS(5533),
    [anon_sym_REPEAT] = ACTIONS(5533),
    [anon_sym_Repeat] = ACTIONS(5533),
    [anon_sym_exit] = ACTIONS(5533),
    [anon_sym_EXIT] = ACTIONS(5533),
    [anon_sym_Exit] = ACTIONS(5533),
    [anon_sym_continue] = ACTIONS(5533),
    [anon_sym_CONTINUE] = ACTIONS(5533),
    [anon_sym_Continue] = ACTIONS(5533),
    [anon_sym_break] = ACTIONS(5533),
    [anon_sym_BREAK] = ACTIONS(5533),
    [anon_sym_Break] = ACTIONS(5533),
    [anon_sym_with] = ACTIONS(5533),
    [anon_sym_WITH] = ACTIONS(5533),
    [anon_sym_With] = ACTIONS(5533),
    [sym_asserterror_keyword] = ACTIONS(5535),
    [sym_page_keyword] = ACTIONS(5533),
    [anon_sym_codeunit] = ACTIONS(5533),
    [anon_sym_CODEUNIT] = ACTIONS(5533),
    [anon_sym_Codeunit] = ACTIONS(5533),
    [anon_sym_CodeUnit] = ACTIONS(5533),
    [anon_sym_COdeunit] = ACTIONS(5533),
    [anon_sym_codeUnit] = ACTIONS(5533),
    [sym_report_keyword] = ACTIONS(5533),
    [sym_query_keyword] = ACTIONS(5533),
    [anon_sym_xmlport] = ACTIONS(5533),
    [anon_sym_XMLPORT] = ACTIONS(5533),
    [anon_sym_Xmlport] = ACTIONS(5533),
    [anon_sym_XMLport] = ACTIONS(5533),
    [anon_sym_XMLPort] = ACTIONS(5533),
    [anon_sym_XmlPort] = ACTIONS(5533),
    [anon_sym_enum] = ACTIONS(5533),
    [anon_sym_ENUM] = ACTIONS(5533),
    [anon_sym_Enum] = ACTIONS(5533),
    [anon_sym_eNUM] = ACTIONS(5533),
    [anon_sym_eNum] = ACTIONS(5533),
    [anon_sym_ENum] = ACTIONS(5533),
    [sym_quoted_identifier] = ACTIONS(5535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5535),
    [sym_verbatim_string] = ACTIONS(5535),
    [sym_integer] = ACTIONS(5533),
    [sym_continue_as_identifier] = ACTIONS(5535),
    [sym_preproc_open] = ACTIONS(5535),
    [sym_preproc_close] = ACTIONS(5535),
  },
  [STATE(2389)] = {
    [sym_identifier] = ACTIONS(5537),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym_DASH] = ACTIONS(5539),
    [aux_sym_boolean_token1] = ACTIONS(5537),
    [aux_sym_boolean_token2] = ACTIONS(5537),
    [sym_decimal] = ACTIONS(5537),
    [anon_sym_LPAREN] = ACTIONS(5539),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5537),
    [anon_sym_LBRACK] = ACTIONS(5539),
    [aux_sym_record_type_token1] = ACTIONS(5537),
    [aux_sym_basic_type_token21] = ACTIONS(5537),
    [aux_sym_basic_type_token22] = ACTIONS(5537),
    [aux_sym_basic_type_token48] = ACTIONS(5537),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5537),
    [anon_sym_POUNDif] = ACTIONS(5539),
    [anon_sym_POUNDIF] = ACTIONS(5539),
    [anon_sym_POUNDIf] = ACTIONS(5539),
    [anon_sym_not] = ACTIONS(5537),
    [anon_sym_NOT] = ACTIONS(5537),
    [anon_sym_Not] = ACTIONS(5537),
    [anon_sym_POUNDelif] = ACTIONS(5539),
    [anon_sym_POUNDELIF] = ACTIONS(5539),
    [anon_sym_POUNDElif] = ACTIONS(5539),
    [anon_sym_POUNDelse] = ACTIONS(5539),
    [anon_sym_POUNDELSE] = ACTIONS(5539),
    [anon_sym_POUNDElse] = ACTIONS(5539),
    [anon_sym_POUNDelse2] = ACTIONS(5539),
    [anon_sym_POUNDELSE2] = ACTIONS(5539),
    [anon_sym_POUNDElse2] = ACTIONS(5539),
    [anon_sym_POUNDendif] = ACTIONS(5539),
    [anon_sym_POUNDENDIF] = ACTIONS(5539),
    [anon_sym_POUNDEndif] = ACTIONS(5539),
    [anon_sym_POUNDendif2] = ACTIONS(5539),
    [anon_sym_POUNDENDIF2] = ACTIONS(5539),
    [anon_sym_POUNDEndif2] = ACTIONS(5539),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5537),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5537),
    [anon_sym_PLUS] = ACTIONS(5539),
    [sym_datetime_literal] = ACTIONS(5539),
    [sym_date_literal] = ACTIONS(5537),
    [sym_time_literal] = ACTIONS(5537),
    [sym_biginteger_literal] = ACTIONS(5539),
    [anon_sym_if] = ACTIONS(5537),
    [anon_sym_IF] = ACTIONS(5537),
    [anon_sym_If] = ACTIONS(5537),
    [anon_sym_else] = ACTIONS(5537),
    [anon_sym_ELSE] = ACTIONS(5537),
    [anon_sym_Else] = ACTIONS(5537),
    [anon_sym_case] = ACTIONS(5537),
    [anon_sym_CASE] = ACTIONS(5537),
    [anon_sym_Case] = ACTIONS(5537),
    [anon_sym_for] = ACTIONS(5537),
    [anon_sym_FOR] = ACTIONS(5537),
    [anon_sym_For] = ACTIONS(5537),
    [anon_sym_foreach] = ACTIONS(5537),
    [anon_sym_FOREACH] = ACTIONS(5537),
    [anon_sym_Foreach] = ACTIONS(5537),
    [anon_sym_while] = ACTIONS(5537),
    [anon_sym_WHILE] = ACTIONS(5537),
    [anon_sym_While] = ACTIONS(5537),
    [anon_sym_repeat] = ACTIONS(5537),
    [anon_sym_REPEAT] = ACTIONS(5537),
    [anon_sym_Repeat] = ACTIONS(5537),
    [anon_sym_exit] = ACTIONS(5537),
    [anon_sym_EXIT] = ACTIONS(5537),
    [anon_sym_Exit] = ACTIONS(5537),
    [anon_sym_continue] = ACTIONS(5537),
    [anon_sym_CONTINUE] = ACTIONS(5537),
    [anon_sym_Continue] = ACTIONS(5537),
    [anon_sym_break] = ACTIONS(5537),
    [anon_sym_BREAK] = ACTIONS(5537),
    [anon_sym_Break] = ACTIONS(5537),
    [anon_sym_with] = ACTIONS(5537),
    [anon_sym_WITH] = ACTIONS(5537),
    [anon_sym_With] = ACTIONS(5537),
    [sym_asserterror_keyword] = ACTIONS(5539),
    [sym_page_keyword] = ACTIONS(5537),
    [anon_sym_codeunit] = ACTIONS(5537),
    [anon_sym_CODEUNIT] = ACTIONS(5537),
    [anon_sym_Codeunit] = ACTIONS(5537),
    [anon_sym_CodeUnit] = ACTIONS(5537),
    [anon_sym_COdeunit] = ACTIONS(5537),
    [anon_sym_codeUnit] = ACTIONS(5537),
    [sym_report_keyword] = ACTIONS(5537),
    [sym_query_keyword] = ACTIONS(5537),
    [anon_sym_xmlport] = ACTIONS(5537),
    [anon_sym_XMLPORT] = ACTIONS(5537),
    [anon_sym_Xmlport] = ACTIONS(5537),
    [anon_sym_XMLport] = ACTIONS(5537),
    [anon_sym_XMLPort] = ACTIONS(5537),
    [anon_sym_XmlPort] = ACTIONS(5537),
    [anon_sym_enum] = ACTIONS(5537),
    [anon_sym_ENUM] = ACTIONS(5537),
    [anon_sym_Enum] = ACTIONS(5537),
    [anon_sym_eNUM] = ACTIONS(5537),
    [anon_sym_eNum] = ACTIONS(5537),
    [anon_sym_ENum] = ACTIONS(5537),
    [sym_quoted_identifier] = ACTIONS(5539),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5539),
    [sym_verbatim_string] = ACTIONS(5539),
    [sym_integer] = ACTIONS(5537),
    [sym_continue_as_identifier] = ACTIONS(5539),
    [sym_preproc_open] = ACTIONS(5539),
    [sym_preproc_close] = ACTIONS(5539),
  },
  [STATE(2390)] = {
    [sym_identifier] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym_DASH] = ACTIONS(5543),
    [aux_sym_boolean_token1] = ACTIONS(5541),
    [aux_sym_boolean_token2] = ACTIONS(5541),
    [sym_decimal] = ACTIONS(5541),
    [anon_sym_LPAREN] = ACTIONS(5543),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5543),
    [aux_sym_record_type_token1] = ACTIONS(5541),
    [aux_sym_basic_type_token21] = ACTIONS(5541),
    [aux_sym_basic_type_token22] = ACTIONS(5541),
    [aux_sym_basic_type_token48] = ACTIONS(5541),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5541),
    [anon_sym_POUNDif] = ACTIONS(5543),
    [anon_sym_POUNDIF] = ACTIONS(5543),
    [anon_sym_POUNDIf] = ACTIONS(5543),
    [anon_sym_not] = ACTIONS(5541),
    [anon_sym_NOT] = ACTIONS(5541),
    [anon_sym_Not] = ACTIONS(5541),
    [anon_sym_POUNDelif] = ACTIONS(5543),
    [anon_sym_POUNDELIF] = ACTIONS(5543),
    [anon_sym_POUNDElif] = ACTIONS(5543),
    [anon_sym_POUNDelse] = ACTIONS(5543),
    [anon_sym_POUNDELSE] = ACTIONS(5543),
    [anon_sym_POUNDElse] = ACTIONS(5543),
    [anon_sym_POUNDelse2] = ACTIONS(5543),
    [anon_sym_POUNDELSE2] = ACTIONS(5543),
    [anon_sym_POUNDElse2] = ACTIONS(5543),
    [anon_sym_POUNDendif] = ACTIONS(5543),
    [anon_sym_POUNDENDIF] = ACTIONS(5543),
    [anon_sym_POUNDEndif] = ACTIONS(5543),
    [anon_sym_POUNDendif2] = ACTIONS(5543),
    [anon_sym_POUNDENDIF2] = ACTIONS(5543),
    [anon_sym_POUNDEndif2] = ACTIONS(5543),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5541),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5541),
    [anon_sym_PLUS] = ACTIONS(5543),
    [sym_datetime_literal] = ACTIONS(5543),
    [sym_date_literal] = ACTIONS(5541),
    [sym_time_literal] = ACTIONS(5541),
    [sym_biginteger_literal] = ACTIONS(5543),
    [anon_sym_if] = ACTIONS(5541),
    [anon_sym_IF] = ACTIONS(5541),
    [anon_sym_If] = ACTIONS(5541),
    [anon_sym_else] = ACTIONS(5541),
    [anon_sym_ELSE] = ACTIONS(5541),
    [anon_sym_Else] = ACTIONS(5541),
    [anon_sym_case] = ACTIONS(5541),
    [anon_sym_CASE] = ACTIONS(5541),
    [anon_sym_Case] = ACTIONS(5541),
    [anon_sym_for] = ACTIONS(5541),
    [anon_sym_FOR] = ACTIONS(5541),
    [anon_sym_For] = ACTIONS(5541),
    [anon_sym_foreach] = ACTIONS(5541),
    [anon_sym_FOREACH] = ACTIONS(5541),
    [anon_sym_Foreach] = ACTIONS(5541),
    [anon_sym_while] = ACTIONS(5541),
    [anon_sym_WHILE] = ACTIONS(5541),
    [anon_sym_While] = ACTIONS(5541),
    [anon_sym_repeat] = ACTIONS(5541),
    [anon_sym_REPEAT] = ACTIONS(5541),
    [anon_sym_Repeat] = ACTIONS(5541),
    [anon_sym_exit] = ACTIONS(5541),
    [anon_sym_EXIT] = ACTIONS(5541),
    [anon_sym_Exit] = ACTIONS(5541),
    [anon_sym_continue] = ACTIONS(5541),
    [anon_sym_CONTINUE] = ACTIONS(5541),
    [anon_sym_Continue] = ACTIONS(5541),
    [anon_sym_break] = ACTIONS(5541),
    [anon_sym_BREAK] = ACTIONS(5541),
    [anon_sym_Break] = ACTIONS(5541),
    [anon_sym_with] = ACTIONS(5541),
    [anon_sym_WITH] = ACTIONS(5541),
    [anon_sym_With] = ACTIONS(5541),
    [sym_asserterror_keyword] = ACTIONS(5543),
    [sym_page_keyword] = ACTIONS(5541),
    [anon_sym_codeunit] = ACTIONS(5541),
    [anon_sym_CODEUNIT] = ACTIONS(5541),
    [anon_sym_Codeunit] = ACTIONS(5541),
    [anon_sym_CodeUnit] = ACTIONS(5541),
    [anon_sym_COdeunit] = ACTIONS(5541),
    [anon_sym_codeUnit] = ACTIONS(5541),
    [sym_report_keyword] = ACTIONS(5541),
    [sym_query_keyword] = ACTIONS(5541),
    [anon_sym_xmlport] = ACTIONS(5541),
    [anon_sym_XMLPORT] = ACTIONS(5541),
    [anon_sym_Xmlport] = ACTIONS(5541),
    [anon_sym_XMLport] = ACTIONS(5541),
    [anon_sym_XMLPort] = ACTIONS(5541),
    [anon_sym_XmlPort] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_ENUM] = ACTIONS(5541),
    [anon_sym_Enum] = ACTIONS(5541),
    [anon_sym_eNUM] = ACTIONS(5541),
    [anon_sym_eNum] = ACTIONS(5541),
    [anon_sym_ENum] = ACTIONS(5541),
    [sym_quoted_identifier] = ACTIONS(5543),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5543),
    [sym_verbatim_string] = ACTIONS(5543),
    [sym_integer] = ACTIONS(5541),
    [sym_continue_as_identifier] = ACTIONS(5543),
    [sym_preproc_open] = ACTIONS(5543),
    [sym_preproc_close] = ACTIONS(5543),
  },
  [STATE(2391)] = {
    [sym_identifier] = ACTIONS(5545),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym_DASH] = ACTIONS(5547),
    [aux_sym_boolean_token1] = ACTIONS(5545),
    [aux_sym_boolean_token2] = ACTIONS(5545),
    [sym_decimal] = ACTIONS(5545),
    [anon_sym_LPAREN] = ACTIONS(5547),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5547),
    [aux_sym_record_type_token1] = ACTIONS(5545),
    [aux_sym_basic_type_token21] = ACTIONS(5545),
    [aux_sym_basic_type_token22] = ACTIONS(5545),
    [aux_sym_basic_type_token48] = ACTIONS(5545),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5545),
    [anon_sym_POUNDif] = ACTIONS(5547),
    [anon_sym_POUNDIF] = ACTIONS(5547),
    [anon_sym_POUNDIf] = ACTIONS(5547),
    [anon_sym_not] = ACTIONS(5545),
    [anon_sym_NOT] = ACTIONS(5545),
    [anon_sym_Not] = ACTIONS(5545),
    [anon_sym_POUNDelif] = ACTIONS(5547),
    [anon_sym_POUNDELIF] = ACTIONS(5547),
    [anon_sym_POUNDElif] = ACTIONS(5547),
    [anon_sym_POUNDelse] = ACTIONS(5547),
    [anon_sym_POUNDELSE] = ACTIONS(5547),
    [anon_sym_POUNDElse] = ACTIONS(5547),
    [anon_sym_POUNDelse2] = ACTIONS(5547),
    [anon_sym_POUNDELSE2] = ACTIONS(5547),
    [anon_sym_POUNDElse2] = ACTIONS(5547),
    [anon_sym_POUNDendif] = ACTIONS(5547),
    [anon_sym_POUNDENDIF] = ACTIONS(5547),
    [anon_sym_POUNDEndif] = ACTIONS(5547),
    [anon_sym_POUNDendif2] = ACTIONS(5547),
    [anon_sym_POUNDENDIF2] = ACTIONS(5547),
    [anon_sym_POUNDEndif2] = ACTIONS(5547),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5545),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5545),
    [anon_sym_PLUS] = ACTIONS(5547),
    [sym_datetime_literal] = ACTIONS(5547),
    [sym_date_literal] = ACTIONS(5545),
    [sym_time_literal] = ACTIONS(5545),
    [sym_biginteger_literal] = ACTIONS(5547),
    [anon_sym_if] = ACTIONS(5545),
    [anon_sym_IF] = ACTIONS(5545),
    [anon_sym_If] = ACTIONS(5545),
    [anon_sym_else] = ACTIONS(5545),
    [anon_sym_ELSE] = ACTIONS(5545),
    [anon_sym_Else] = ACTIONS(5545),
    [anon_sym_case] = ACTIONS(5545),
    [anon_sym_CASE] = ACTIONS(5545),
    [anon_sym_Case] = ACTIONS(5545),
    [anon_sym_for] = ACTIONS(5545),
    [anon_sym_FOR] = ACTIONS(5545),
    [anon_sym_For] = ACTIONS(5545),
    [anon_sym_foreach] = ACTIONS(5545),
    [anon_sym_FOREACH] = ACTIONS(5545),
    [anon_sym_Foreach] = ACTIONS(5545),
    [anon_sym_while] = ACTIONS(5545),
    [anon_sym_WHILE] = ACTIONS(5545),
    [anon_sym_While] = ACTIONS(5545),
    [anon_sym_repeat] = ACTIONS(5545),
    [anon_sym_REPEAT] = ACTIONS(5545),
    [anon_sym_Repeat] = ACTIONS(5545),
    [anon_sym_exit] = ACTIONS(5545),
    [anon_sym_EXIT] = ACTIONS(5545),
    [anon_sym_Exit] = ACTIONS(5545),
    [anon_sym_continue] = ACTIONS(5545),
    [anon_sym_CONTINUE] = ACTIONS(5545),
    [anon_sym_Continue] = ACTIONS(5545),
    [anon_sym_break] = ACTIONS(5545),
    [anon_sym_BREAK] = ACTIONS(5545),
    [anon_sym_Break] = ACTIONS(5545),
    [anon_sym_with] = ACTIONS(5545),
    [anon_sym_WITH] = ACTIONS(5545),
    [anon_sym_With] = ACTIONS(5545),
    [sym_asserterror_keyword] = ACTIONS(5547),
    [sym_page_keyword] = ACTIONS(5545),
    [anon_sym_codeunit] = ACTIONS(5545),
    [anon_sym_CODEUNIT] = ACTIONS(5545),
    [anon_sym_Codeunit] = ACTIONS(5545),
    [anon_sym_CodeUnit] = ACTIONS(5545),
    [anon_sym_COdeunit] = ACTIONS(5545),
    [anon_sym_codeUnit] = ACTIONS(5545),
    [sym_report_keyword] = ACTIONS(5545),
    [sym_query_keyword] = ACTIONS(5545),
    [anon_sym_xmlport] = ACTIONS(5545),
    [anon_sym_XMLPORT] = ACTIONS(5545),
    [anon_sym_Xmlport] = ACTIONS(5545),
    [anon_sym_XMLport] = ACTIONS(5545),
    [anon_sym_XMLPort] = ACTIONS(5545),
    [anon_sym_XmlPort] = ACTIONS(5545),
    [anon_sym_enum] = ACTIONS(5545),
    [anon_sym_ENUM] = ACTIONS(5545),
    [anon_sym_Enum] = ACTIONS(5545),
    [anon_sym_eNUM] = ACTIONS(5545),
    [anon_sym_eNum] = ACTIONS(5545),
    [anon_sym_ENum] = ACTIONS(5545),
    [sym_quoted_identifier] = ACTIONS(5547),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5547),
    [sym_verbatim_string] = ACTIONS(5547),
    [sym_integer] = ACTIONS(5545),
    [sym_continue_as_identifier] = ACTIONS(5547),
    [sym_preproc_open] = ACTIONS(5547),
    [sym_preproc_close] = ACTIONS(5547),
  },
  [STATE(2392)] = {
    [sym_identifier] = ACTIONS(5549),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym_DASH] = ACTIONS(5551),
    [aux_sym_boolean_token1] = ACTIONS(5549),
    [aux_sym_boolean_token2] = ACTIONS(5549),
    [sym_decimal] = ACTIONS(5549),
    [anon_sym_LPAREN] = ACTIONS(5551),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5549),
    [anon_sym_LBRACK] = ACTIONS(5551),
    [aux_sym_record_type_token1] = ACTIONS(5549),
    [aux_sym_basic_type_token21] = ACTIONS(5549),
    [aux_sym_basic_type_token22] = ACTIONS(5549),
    [aux_sym_basic_type_token48] = ACTIONS(5549),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5549),
    [anon_sym_POUNDif] = ACTIONS(5551),
    [anon_sym_POUNDIF] = ACTIONS(5551),
    [anon_sym_POUNDIf] = ACTIONS(5551),
    [anon_sym_not] = ACTIONS(5549),
    [anon_sym_NOT] = ACTIONS(5549),
    [anon_sym_Not] = ACTIONS(5549),
    [anon_sym_POUNDelif] = ACTIONS(5551),
    [anon_sym_POUNDELIF] = ACTIONS(5551),
    [anon_sym_POUNDElif] = ACTIONS(5551),
    [anon_sym_POUNDelse] = ACTIONS(5551),
    [anon_sym_POUNDELSE] = ACTIONS(5551),
    [anon_sym_POUNDElse] = ACTIONS(5551),
    [anon_sym_POUNDelse2] = ACTIONS(5551),
    [anon_sym_POUNDELSE2] = ACTIONS(5551),
    [anon_sym_POUNDElse2] = ACTIONS(5551),
    [anon_sym_POUNDendif] = ACTIONS(5551),
    [anon_sym_POUNDENDIF] = ACTIONS(5551),
    [anon_sym_POUNDEndif] = ACTIONS(5551),
    [anon_sym_POUNDendif2] = ACTIONS(5551),
    [anon_sym_POUNDENDIF2] = ACTIONS(5551),
    [anon_sym_POUNDEndif2] = ACTIONS(5551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5549),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5549),
    [anon_sym_PLUS] = ACTIONS(5551),
    [sym_datetime_literal] = ACTIONS(5551),
    [sym_date_literal] = ACTIONS(5549),
    [sym_time_literal] = ACTIONS(5549),
    [sym_biginteger_literal] = ACTIONS(5551),
    [anon_sym_if] = ACTIONS(5549),
    [anon_sym_IF] = ACTIONS(5549),
    [anon_sym_If] = ACTIONS(5549),
    [anon_sym_else] = ACTIONS(5549),
    [anon_sym_ELSE] = ACTIONS(5549),
    [anon_sym_Else] = ACTIONS(5549),
    [anon_sym_case] = ACTIONS(5549),
    [anon_sym_CASE] = ACTIONS(5549),
    [anon_sym_Case] = ACTIONS(5549),
    [anon_sym_for] = ACTIONS(5549),
    [anon_sym_FOR] = ACTIONS(5549),
    [anon_sym_For] = ACTIONS(5549),
    [anon_sym_foreach] = ACTIONS(5549),
    [anon_sym_FOREACH] = ACTIONS(5549),
    [anon_sym_Foreach] = ACTIONS(5549),
    [anon_sym_while] = ACTIONS(5549),
    [anon_sym_WHILE] = ACTIONS(5549),
    [anon_sym_While] = ACTIONS(5549),
    [anon_sym_repeat] = ACTIONS(5549),
    [anon_sym_REPEAT] = ACTIONS(5549),
    [anon_sym_Repeat] = ACTIONS(5549),
    [anon_sym_exit] = ACTIONS(5549),
    [anon_sym_EXIT] = ACTIONS(5549),
    [anon_sym_Exit] = ACTIONS(5549),
    [anon_sym_continue] = ACTIONS(5549),
    [anon_sym_CONTINUE] = ACTIONS(5549),
    [anon_sym_Continue] = ACTIONS(5549),
    [anon_sym_break] = ACTIONS(5549),
    [anon_sym_BREAK] = ACTIONS(5549),
    [anon_sym_Break] = ACTIONS(5549),
    [anon_sym_with] = ACTIONS(5549),
    [anon_sym_WITH] = ACTIONS(5549),
    [anon_sym_With] = ACTIONS(5549),
    [sym_asserterror_keyword] = ACTIONS(5551),
    [sym_page_keyword] = ACTIONS(5549),
    [anon_sym_codeunit] = ACTIONS(5549),
    [anon_sym_CODEUNIT] = ACTIONS(5549),
    [anon_sym_Codeunit] = ACTIONS(5549),
    [anon_sym_CodeUnit] = ACTIONS(5549),
    [anon_sym_COdeunit] = ACTIONS(5549),
    [anon_sym_codeUnit] = ACTIONS(5549),
    [sym_report_keyword] = ACTIONS(5549),
    [sym_query_keyword] = ACTIONS(5549),
    [anon_sym_xmlport] = ACTIONS(5549),
    [anon_sym_XMLPORT] = ACTIONS(5549),
    [anon_sym_Xmlport] = ACTIONS(5549),
    [anon_sym_XMLport] = ACTIONS(5549),
    [anon_sym_XMLPort] = ACTIONS(5549),
    [anon_sym_XmlPort] = ACTIONS(5549),
    [anon_sym_enum] = ACTIONS(5549),
    [anon_sym_ENUM] = ACTIONS(5549),
    [anon_sym_Enum] = ACTIONS(5549),
    [anon_sym_eNUM] = ACTIONS(5549),
    [anon_sym_eNum] = ACTIONS(5549),
    [anon_sym_ENum] = ACTIONS(5549),
    [sym_quoted_identifier] = ACTIONS(5551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5551),
    [sym_verbatim_string] = ACTIONS(5551),
    [sym_integer] = ACTIONS(5549),
    [sym_continue_as_identifier] = ACTIONS(5551),
    [sym_preproc_open] = ACTIONS(5551),
    [sym_preproc_close] = ACTIONS(5551),
  },
  [STATE(2393)] = {
    [sym_identifier] = ACTIONS(5553),
    [anon_sym_SEMI] = ACTIONS(5555),
    [anon_sym_DASH] = ACTIONS(5555),
    [aux_sym_boolean_token1] = ACTIONS(5553),
    [aux_sym_boolean_token2] = ACTIONS(5553),
    [sym_decimal] = ACTIONS(5553),
    [anon_sym_LPAREN] = ACTIONS(5555),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5553),
    [anon_sym_LBRACK] = ACTIONS(5555),
    [aux_sym_record_type_token1] = ACTIONS(5553),
    [aux_sym_basic_type_token21] = ACTIONS(5553),
    [aux_sym_basic_type_token22] = ACTIONS(5553),
    [aux_sym_basic_type_token48] = ACTIONS(5553),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5553),
    [anon_sym_POUNDif] = ACTIONS(5555),
    [anon_sym_POUNDIF] = ACTIONS(5555),
    [anon_sym_POUNDIf] = ACTIONS(5555),
    [anon_sym_not] = ACTIONS(5553),
    [anon_sym_NOT] = ACTIONS(5553),
    [anon_sym_Not] = ACTIONS(5553),
    [anon_sym_POUNDelif] = ACTIONS(5555),
    [anon_sym_POUNDELIF] = ACTIONS(5555),
    [anon_sym_POUNDElif] = ACTIONS(5555),
    [anon_sym_POUNDelse] = ACTIONS(5555),
    [anon_sym_POUNDELSE] = ACTIONS(5555),
    [anon_sym_POUNDElse] = ACTIONS(5555),
    [anon_sym_POUNDelse2] = ACTIONS(5555),
    [anon_sym_POUNDELSE2] = ACTIONS(5555),
    [anon_sym_POUNDElse2] = ACTIONS(5555),
    [anon_sym_POUNDendif] = ACTIONS(5555),
    [anon_sym_POUNDENDIF] = ACTIONS(5555),
    [anon_sym_POUNDEndif] = ACTIONS(5555),
    [anon_sym_POUNDendif2] = ACTIONS(5555),
    [anon_sym_POUNDENDIF2] = ACTIONS(5555),
    [anon_sym_POUNDEndif2] = ACTIONS(5555),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5553),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5553),
    [anon_sym_PLUS] = ACTIONS(5555),
    [sym_datetime_literal] = ACTIONS(5555),
    [sym_date_literal] = ACTIONS(5553),
    [sym_time_literal] = ACTIONS(5553),
    [sym_biginteger_literal] = ACTIONS(5555),
    [anon_sym_if] = ACTIONS(5553),
    [anon_sym_IF] = ACTIONS(5553),
    [anon_sym_If] = ACTIONS(5553),
    [anon_sym_else] = ACTIONS(5553),
    [anon_sym_ELSE] = ACTIONS(5553),
    [anon_sym_Else] = ACTIONS(5553),
    [anon_sym_case] = ACTIONS(5553),
    [anon_sym_CASE] = ACTIONS(5553),
    [anon_sym_Case] = ACTIONS(5553),
    [anon_sym_for] = ACTIONS(5553),
    [anon_sym_FOR] = ACTIONS(5553),
    [anon_sym_For] = ACTIONS(5553),
    [anon_sym_foreach] = ACTIONS(5553),
    [anon_sym_FOREACH] = ACTIONS(5553),
    [anon_sym_Foreach] = ACTIONS(5553),
    [anon_sym_while] = ACTIONS(5553),
    [anon_sym_WHILE] = ACTIONS(5553),
    [anon_sym_While] = ACTIONS(5553),
    [anon_sym_repeat] = ACTIONS(5553),
    [anon_sym_REPEAT] = ACTIONS(5553),
    [anon_sym_Repeat] = ACTIONS(5553),
    [anon_sym_exit] = ACTIONS(5553),
    [anon_sym_EXIT] = ACTIONS(5553),
    [anon_sym_Exit] = ACTIONS(5553),
    [anon_sym_continue] = ACTIONS(5553),
    [anon_sym_CONTINUE] = ACTIONS(5553),
    [anon_sym_Continue] = ACTIONS(5553),
    [anon_sym_break] = ACTIONS(5553),
    [anon_sym_BREAK] = ACTIONS(5553),
    [anon_sym_Break] = ACTIONS(5553),
    [anon_sym_with] = ACTIONS(5553),
    [anon_sym_WITH] = ACTIONS(5553),
    [anon_sym_With] = ACTIONS(5553),
    [sym_asserterror_keyword] = ACTIONS(5555),
    [sym_page_keyword] = ACTIONS(5553),
    [anon_sym_codeunit] = ACTIONS(5553),
    [anon_sym_CODEUNIT] = ACTIONS(5553),
    [anon_sym_Codeunit] = ACTIONS(5553),
    [anon_sym_CodeUnit] = ACTIONS(5553),
    [anon_sym_COdeunit] = ACTIONS(5553),
    [anon_sym_codeUnit] = ACTIONS(5553),
    [sym_report_keyword] = ACTIONS(5553),
    [sym_query_keyword] = ACTIONS(5553),
    [anon_sym_xmlport] = ACTIONS(5553),
    [anon_sym_XMLPORT] = ACTIONS(5553),
    [anon_sym_Xmlport] = ACTIONS(5553),
    [anon_sym_XMLport] = ACTIONS(5553),
    [anon_sym_XMLPort] = ACTIONS(5553),
    [anon_sym_XmlPort] = ACTIONS(5553),
    [anon_sym_enum] = ACTIONS(5553),
    [anon_sym_ENUM] = ACTIONS(5553),
    [anon_sym_Enum] = ACTIONS(5553),
    [anon_sym_eNUM] = ACTIONS(5553),
    [anon_sym_eNum] = ACTIONS(5553),
    [anon_sym_ENum] = ACTIONS(5553),
    [sym_quoted_identifier] = ACTIONS(5555),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5555),
    [sym_verbatim_string] = ACTIONS(5555),
    [sym_integer] = ACTIONS(5553),
    [sym_continue_as_identifier] = ACTIONS(5555),
    [sym_preproc_open] = ACTIONS(5555),
    [sym_preproc_close] = ACTIONS(5555),
  },
  [STATE(2394)] = {
    [sym_identifier] = ACTIONS(5557),
    [anon_sym_SEMI] = ACTIONS(5559),
    [anon_sym_DASH] = ACTIONS(5559),
    [aux_sym_boolean_token1] = ACTIONS(5557),
    [aux_sym_boolean_token2] = ACTIONS(5557),
    [sym_decimal] = ACTIONS(5557),
    [anon_sym_LPAREN] = ACTIONS(5559),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5557),
    [anon_sym_LBRACK] = ACTIONS(5559),
    [aux_sym_record_type_token1] = ACTIONS(5557),
    [aux_sym_basic_type_token21] = ACTIONS(5557),
    [aux_sym_basic_type_token22] = ACTIONS(5557),
    [aux_sym_basic_type_token48] = ACTIONS(5557),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5557),
    [anon_sym_POUNDif] = ACTIONS(5559),
    [anon_sym_POUNDIF] = ACTIONS(5559),
    [anon_sym_POUNDIf] = ACTIONS(5559),
    [anon_sym_not] = ACTIONS(5557),
    [anon_sym_NOT] = ACTIONS(5557),
    [anon_sym_Not] = ACTIONS(5557),
    [anon_sym_POUNDelif] = ACTIONS(5559),
    [anon_sym_POUNDELIF] = ACTIONS(5559),
    [anon_sym_POUNDElif] = ACTIONS(5559),
    [anon_sym_POUNDelse] = ACTIONS(5559),
    [anon_sym_POUNDELSE] = ACTIONS(5559),
    [anon_sym_POUNDElse] = ACTIONS(5559),
    [anon_sym_POUNDelse2] = ACTIONS(5559),
    [anon_sym_POUNDELSE2] = ACTIONS(5559),
    [anon_sym_POUNDElse2] = ACTIONS(5559),
    [anon_sym_POUNDendif] = ACTIONS(5559),
    [anon_sym_POUNDENDIF] = ACTIONS(5559),
    [anon_sym_POUNDEndif] = ACTIONS(5559),
    [anon_sym_POUNDendif2] = ACTIONS(5559),
    [anon_sym_POUNDENDIF2] = ACTIONS(5559),
    [anon_sym_POUNDEndif2] = ACTIONS(5559),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5557),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5557),
    [anon_sym_PLUS] = ACTIONS(5559),
    [sym_datetime_literal] = ACTIONS(5559),
    [sym_date_literal] = ACTIONS(5557),
    [sym_time_literal] = ACTIONS(5557),
    [sym_biginteger_literal] = ACTIONS(5559),
    [anon_sym_if] = ACTIONS(5557),
    [anon_sym_IF] = ACTIONS(5557),
    [anon_sym_If] = ACTIONS(5557),
    [anon_sym_else] = ACTIONS(5557),
    [anon_sym_ELSE] = ACTIONS(5557),
    [anon_sym_Else] = ACTIONS(5557),
    [anon_sym_case] = ACTIONS(5557),
    [anon_sym_CASE] = ACTIONS(5557),
    [anon_sym_Case] = ACTIONS(5557),
    [anon_sym_for] = ACTIONS(5557),
    [anon_sym_FOR] = ACTIONS(5557),
    [anon_sym_For] = ACTIONS(5557),
    [anon_sym_foreach] = ACTIONS(5557),
    [anon_sym_FOREACH] = ACTIONS(5557),
    [anon_sym_Foreach] = ACTIONS(5557),
    [anon_sym_while] = ACTIONS(5557),
    [anon_sym_WHILE] = ACTIONS(5557),
    [anon_sym_While] = ACTIONS(5557),
    [anon_sym_repeat] = ACTIONS(5557),
    [anon_sym_REPEAT] = ACTIONS(5557),
    [anon_sym_Repeat] = ACTIONS(5557),
    [anon_sym_exit] = ACTIONS(5557),
    [anon_sym_EXIT] = ACTIONS(5557),
    [anon_sym_Exit] = ACTIONS(5557),
    [anon_sym_continue] = ACTIONS(5557),
    [anon_sym_CONTINUE] = ACTIONS(5557),
    [anon_sym_Continue] = ACTIONS(5557),
    [anon_sym_break] = ACTIONS(5557),
    [anon_sym_BREAK] = ACTIONS(5557),
    [anon_sym_Break] = ACTIONS(5557),
    [anon_sym_with] = ACTIONS(5557),
    [anon_sym_WITH] = ACTIONS(5557),
    [anon_sym_With] = ACTIONS(5557),
    [sym_asserterror_keyword] = ACTIONS(5559),
    [sym_page_keyword] = ACTIONS(5557),
    [anon_sym_codeunit] = ACTIONS(5557),
    [anon_sym_CODEUNIT] = ACTIONS(5557),
    [anon_sym_Codeunit] = ACTIONS(5557),
    [anon_sym_CodeUnit] = ACTIONS(5557),
    [anon_sym_COdeunit] = ACTIONS(5557),
    [anon_sym_codeUnit] = ACTIONS(5557),
    [sym_report_keyword] = ACTIONS(5557),
    [sym_query_keyword] = ACTIONS(5557),
    [anon_sym_xmlport] = ACTIONS(5557),
    [anon_sym_XMLPORT] = ACTIONS(5557),
    [anon_sym_Xmlport] = ACTIONS(5557),
    [anon_sym_XMLport] = ACTIONS(5557),
    [anon_sym_XMLPort] = ACTIONS(5557),
    [anon_sym_XmlPort] = ACTIONS(5557),
    [anon_sym_enum] = ACTIONS(5557),
    [anon_sym_ENUM] = ACTIONS(5557),
    [anon_sym_Enum] = ACTIONS(5557),
    [anon_sym_eNUM] = ACTIONS(5557),
    [anon_sym_eNum] = ACTIONS(5557),
    [anon_sym_ENum] = ACTIONS(5557),
    [sym_quoted_identifier] = ACTIONS(5559),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5559),
    [sym_verbatim_string] = ACTIONS(5559),
    [sym_integer] = ACTIONS(5557),
    [sym_continue_as_identifier] = ACTIONS(5559),
    [sym_preproc_open] = ACTIONS(5559),
    [sym_preproc_close] = ACTIONS(5559),
  },
  [STATE(2395)] = {
    [sym_identifier] = ACTIONS(5561),
    [anon_sym_SEMI] = ACTIONS(5563),
    [anon_sym_DASH] = ACTIONS(5563),
    [aux_sym_boolean_token1] = ACTIONS(5561),
    [aux_sym_boolean_token2] = ACTIONS(5561),
    [sym_decimal] = ACTIONS(5561),
    [anon_sym_LPAREN] = ACTIONS(5563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5561),
    [anon_sym_LBRACK] = ACTIONS(5563),
    [aux_sym_record_type_token1] = ACTIONS(5561),
    [aux_sym_basic_type_token21] = ACTIONS(5561),
    [aux_sym_basic_type_token22] = ACTIONS(5561),
    [aux_sym_basic_type_token48] = ACTIONS(5561),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5561),
    [anon_sym_POUNDif] = ACTIONS(5563),
    [anon_sym_POUNDIF] = ACTIONS(5563),
    [anon_sym_POUNDIf] = ACTIONS(5563),
    [anon_sym_not] = ACTIONS(5561),
    [anon_sym_NOT] = ACTIONS(5561),
    [anon_sym_Not] = ACTIONS(5561),
    [anon_sym_POUNDelif] = ACTIONS(5563),
    [anon_sym_POUNDELIF] = ACTIONS(5563),
    [anon_sym_POUNDElif] = ACTIONS(5563),
    [anon_sym_POUNDelse] = ACTIONS(5563),
    [anon_sym_POUNDELSE] = ACTIONS(5563),
    [anon_sym_POUNDElse] = ACTIONS(5563),
    [anon_sym_POUNDelse2] = ACTIONS(5563),
    [anon_sym_POUNDELSE2] = ACTIONS(5563),
    [anon_sym_POUNDElse2] = ACTIONS(5563),
    [anon_sym_POUNDendif] = ACTIONS(5563),
    [anon_sym_POUNDENDIF] = ACTIONS(5563),
    [anon_sym_POUNDEndif] = ACTIONS(5563),
    [anon_sym_POUNDendif2] = ACTIONS(5563),
    [anon_sym_POUNDENDIF2] = ACTIONS(5563),
    [anon_sym_POUNDEndif2] = ACTIONS(5563),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5561),
    [anon_sym_PLUS] = ACTIONS(5563),
    [sym_datetime_literal] = ACTIONS(5563),
    [sym_date_literal] = ACTIONS(5561),
    [sym_time_literal] = ACTIONS(5561),
    [sym_biginteger_literal] = ACTIONS(5563),
    [anon_sym_if] = ACTIONS(5561),
    [anon_sym_IF] = ACTIONS(5561),
    [anon_sym_If] = ACTIONS(5561),
    [anon_sym_else] = ACTIONS(5561),
    [anon_sym_ELSE] = ACTIONS(5561),
    [anon_sym_Else] = ACTIONS(5561),
    [anon_sym_case] = ACTIONS(5561),
    [anon_sym_CASE] = ACTIONS(5561),
    [anon_sym_Case] = ACTIONS(5561),
    [anon_sym_for] = ACTIONS(5561),
    [anon_sym_FOR] = ACTIONS(5561),
    [anon_sym_For] = ACTIONS(5561),
    [anon_sym_foreach] = ACTIONS(5561),
    [anon_sym_FOREACH] = ACTIONS(5561),
    [anon_sym_Foreach] = ACTIONS(5561),
    [anon_sym_while] = ACTIONS(5561),
    [anon_sym_WHILE] = ACTIONS(5561),
    [anon_sym_While] = ACTIONS(5561),
    [anon_sym_repeat] = ACTIONS(5561),
    [anon_sym_REPEAT] = ACTIONS(5561),
    [anon_sym_Repeat] = ACTIONS(5561),
    [anon_sym_exit] = ACTIONS(5561),
    [anon_sym_EXIT] = ACTIONS(5561),
    [anon_sym_Exit] = ACTIONS(5561),
    [anon_sym_continue] = ACTIONS(5561),
    [anon_sym_CONTINUE] = ACTIONS(5561),
    [anon_sym_Continue] = ACTIONS(5561),
    [anon_sym_break] = ACTIONS(5561),
    [anon_sym_BREAK] = ACTIONS(5561),
    [anon_sym_Break] = ACTIONS(5561),
    [anon_sym_with] = ACTIONS(5561),
    [anon_sym_WITH] = ACTIONS(5561),
    [anon_sym_With] = ACTIONS(5561),
    [sym_asserterror_keyword] = ACTIONS(5563),
    [sym_page_keyword] = ACTIONS(5561),
    [anon_sym_codeunit] = ACTIONS(5561),
    [anon_sym_CODEUNIT] = ACTIONS(5561),
    [anon_sym_Codeunit] = ACTIONS(5561),
    [anon_sym_CodeUnit] = ACTIONS(5561),
    [anon_sym_COdeunit] = ACTIONS(5561),
    [anon_sym_codeUnit] = ACTIONS(5561),
    [sym_report_keyword] = ACTIONS(5561),
    [sym_query_keyword] = ACTIONS(5561),
    [anon_sym_xmlport] = ACTIONS(5561),
    [anon_sym_XMLPORT] = ACTIONS(5561),
    [anon_sym_Xmlport] = ACTIONS(5561),
    [anon_sym_XMLport] = ACTIONS(5561),
    [anon_sym_XMLPort] = ACTIONS(5561),
    [anon_sym_XmlPort] = ACTIONS(5561),
    [anon_sym_enum] = ACTIONS(5561),
    [anon_sym_ENUM] = ACTIONS(5561),
    [anon_sym_Enum] = ACTIONS(5561),
    [anon_sym_eNUM] = ACTIONS(5561),
    [anon_sym_eNum] = ACTIONS(5561),
    [anon_sym_ENum] = ACTIONS(5561),
    [sym_quoted_identifier] = ACTIONS(5563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5563),
    [sym_verbatim_string] = ACTIONS(5563),
    [sym_integer] = ACTIONS(5561),
    [sym_continue_as_identifier] = ACTIONS(5563),
    [sym_preproc_open] = ACTIONS(5563),
    [sym_preproc_close] = ACTIONS(5563),
  },
  [STATE(2396)] = {
    [sym_identifier] = ACTIONS(5565),
    [anon_sym_SEMI] = ACTIONS(5567),
    [anon_sym_DASH] = ACTIONS(5567),
    [aux_sym_boolean_token1] = ACTIONS(5565),
    [aux_sym_boolean_token2] = ACTIONS(5565),
    [sym_decimal] = ACTIONS(5565),
    [anon_sym_LPAREN] = ACTIONS(5567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5565),
    [anon_sym_LBRACK] = ACTIONS(5567),
    [aux_sym_record_type_token1] = ACTIONS(5565),
    [aux_sym_basic_type_token21] = ACTIONS(5565),
    [aux_sym_basic_type_token22] = ACTIONS(5565),
    [aux_sym_basic_type_token48] = ACTIONS(5565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5565),
    [anon_sym_POUNDif] = ACTIONS(5567),
    [anon_sym_POUNDIF] = ACTIONS(5567),
    [anon_sym_POUNDIf] = ACTIONS(5567),
    [anon_sym_not] = ACTIONS(5565),
    [anon_sym_NOT] = ACTIONS(5565),
    [anon_sym_Not] = ACTIONS(5565),
    [anon_sym_POUNDelif] = ACTIONS(5567),
    [anon_sym_POUNDELIF] = ACTIONS(5567),
    [anon_sym_POUNDElif] = ACTIONS(5567),
    [anon_sym_POUNDelse] = ACTIONS(5567),
    [anon_sym_POUNDELSE] = ACTIONS(5567),
    [anon_sym_POUNDElse] = ACTIONS(5567),
    [anon_sym_POUNDelse2] = ACTIONS(5567),
    [anon_sym_POUNDELSE2] = ACTIONS(5567),
    [anon_sym_POUNDElse2] = ACTIONS(5567),
    [anon_sym_POUNDendif] = ACTIONS(5567),
    [anon_sym_POUNDENDIF] = ACTIONS(5567),
    [anon_sym_POUNDEndif] = ACTIONS(5567),
    [anon_sym_POUNDendif2] = ACTIONS(5567),
    [anon_sym_POUNDENDIF2] = ACTIONS(5567),
    [anon_sym_POUNDEndif2] = ACTIONS(5567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5565),
    [anon_sym_PLUS] = ACTIONS(5567),
    [sym_datetime_literal] = ACTIONS(5567),
    [sym_date_literal] = ACTIONS(5565),
    [sym_time_literal] = ACTIONS(5565),
    [sym_biginteger_literal] = ACTIONS(5567),
    [anon_sym_if] = ACTIONS(5565),
    [anon_sym_IF] = ACTIONS(5565),
    [anon_sym_If] = ACTIONS(5565),
    [anon_sym_else] = ACTIONS(5565),
    [anon_sym_ELSE] = ACTIONS(5565),
    [anon_sym_Else] = ACTIONS(5565),
    [anon_sym_case] = ACTIONS(5565),
    [anon_sym_CASE] = ACTIONS(5565),
    [anon_sym_Case] = ACTIONS(5565),
    [anon_sym_for] = ACTIONS(5565),
    [anon_sym_FOR] = ACTIONS(5565),
    [anon_sym_For] = ACTIONS(5565),
    [anon_sym_foreach] = ACTIONS(5565),
    [anon_sym_FOREACH] = ACTIONS(5565),
    [anon_sym_Foreach] = ACTIONS(5565),
    [anon_sym_while] = ACTIONS(5565),
    [anon_sym_WHILE] = ACTIONS(5565),
    [anon_sym_While] = ACTIONS(5565),
    [anon_sym_repeat] = ACTIONS(5565),
    [anon_sym_REPEAT] = ACTIONS(5565),
    [anon_sym_Repeat] = ACTIONS(5565),
    [anon_sym_exit] = ACTIONS(5565),
    [anon_sym_EXIT] = ACTIONS(5565),
    [anon_sym_Exit] = ACTIONS(5565),
    [anon_sym_continue] = ACTIONS(5565),
    [anon_sym_CONTINUE] = ACTIONS(5565),
    [anon_sym_Continue] = ACTIONS(5565),
    [anon_sym_break] = ACTIONS(5565),
    [anon_sym_BREAK] = ACTIONS(5565),
    [anon_sym_Break] = ACTIONS(5565),
    [anon_sym_with] = ACTIONS(5565),
    [anon_sym_WITH] = ACTIONS(5565),
    [anon_sym_With] = ACTIONS(5565),
    [sym_asserterror_keyword] = ACTIONS(5567),
    [sym_page_keyword] = ACTIONS(5565),
    [anon_sym_codeunit] = ACTIONS(5565),
    [anon_sym_CODEUNIT] = ACTIONS(5565),
    [anon_sym_Codeunit] = ACTIONS(5565),
    [anon_sym_CodeUnit] = ACTIONS(5565),
    [anon_sym_COdeunit] = ACTIONS(5565),
    [anon_sym_codeUnit] = ACTIONS(5565),
    [sym_report_keyword] = ACTIONS(5565),
    [sym_query_keyword] = ACTIONS(5565),
    [anon_sym_xmlport] = ACTIONS(5565),
    [anon_sym_XMLPORT] = ACTIONS(5565),
    [anon_sym_Xmlport] = ACTIONS(5565),
    [anon_sym_XMLport] = ACTIONS(5565),
    [anon_sym_XMLPort] = ACTIONS(5565),
    [anon_sym_XmlPort] = ACTIONS(5565),
    [anon_sym_enum] = ACTIONS(5565),
    [anon_sym_ENUM] = ACTIONS(5565),
    [anon_sym_Enum] = ACTIONS(5565),
    [anon_sym_eNUM] = ACTIONS(5565),
    [anon_sym_eNum] = ACTIONS(5565),
    [anon_sym_ENum] = ACTIONS(5565),
    [sym_quoted_identifier] = ACTIONS(5567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5567),
    [sym_verbatim_string] = ACTIONS(5567),
    [sym_integer] = ACTIONS(5565),
    [sym_continue_as_identifier] = ACTIONS(5567),
    [sym_preproc_open] = ACTIONS(5567),
    [sym_preproc_close] = ACTIONS(5567),
  },
  [STATE(2397)] = {
    [sym_identifier] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym_DASH] = ACTIONS(5571),
    [aux_sym_boolean_token1] = ACTIONS(5569),
    [aux_sym_boolean_token2] = ACTIONS(5569),
    [sym_decimal] = ACTIONS(5569),
    [anon_sym_LPAREN] = ACTIONS(5571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5571),
    [aux_sym_record_type_token1] = ACTIONS(5569),
    [aux_sym_basic_type_token21] = ACTIONS(5569),
    [aux_sym_basic_type_token22] = ACTIONS(5569),
    [aux_sym_basic_type_token48] = ACTIONS(5569),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5569),
    [anon_sym_POUNDif] = ACTIONS(5571),
    [anon_sym_POUNDIF] = ACTIONS(5571),
    [anon_sym_POUNDIf] = ACTIONS(5571),
    [anon_sym_not] = ACTIONS(5569),
    [anon_sym_NOT] = ACTIONS(5569),
    [anon_sym_Not] = ACTIONS(5569),
    [anon_sym_POUNDelif] = ACTIONS(5571),
    [anon_sym_POUNDELIF] = ACTIONS(5571),
    [anon_sym_POUNDElif] = ACTIONS(5571),
    [anon_sym_POUNDelse] = ACTIONS(5571),
    [anon_sym_POUNDELSE] = ACTIONS(5571),
    [anon_sym_POUNDElse] = ACTIONS(5571),
    [anon_sym_POUNDelse2] = ACTIONS(5571),
    [anon_sym_POUNDELSE2] = ACTIONS(5571),
    [anon_sym_POUNDElse2] = ACTIONS(5571),
    [anon_sym_POUNDendif] = ACTIONS(5571),
    [anon_sym_POUNDENDIF] = ACTIONS(5571),
    [anon_sym_POUNDEndif] = ACTIONS(5571),
    [anon_sym_POUNDendif2] = ACTIONS(5571),
    [anon_sym_POUNDENDIF2] = ACTIONS(5571),
    [anon_sym_POUNDEndif2] = ACTIONS(5571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5569),
    [anon_sym_PLUS] = ACTIONS(5571),
    [sym_datetime_literal] = ACTIONS(5571),
    [sym_date_literal] = ACTIONS(5569),
    [sym_time_literal] = ACTIONS(5569),
    [sym_biginteger_literal] = ACTIONS(5571),
    [anon_sym_if] = ACTIONS(5569),
    [anon_sym_IF] = ACTIONS(5569),
    [anon_sym_If] = ACTIONS(5569),
    [anon_sym_else] = ACTIONS(5569),
    [anon_sym_ELSE] = ACTIONS(5569),
    [anon_sym_Else] = ACTIONS(5569),
    [anon_sym_case] = ACTIONS(5569),
    [anon_sym_CASE] = ACTIONS(5569),
    [anon_sym_Case] = ACTIONS(5569),
    [anon_sym_for] = ACTIONS(5569),
    [anon_sym_FOR] = ACTIONS(5569),
    [anon_sym_For] = ACTIONS(5569),
    [anon_sym_foreach] = ACTIONS(5569),
    [anon_sym_FOREACH] = ACTIONS(5569),
    [anon_sym_Foreach] = ACTIONS(5569),
    [anon_sym_while] = ACTIONS(5569),
    [anon_sym_WHILE] = ACTIONS(5569),
    [anon_sym_While] = ACTIONS(5569),
    [anon_sym_repeat] = ACTIONS(5569),
    [anon_sym_REPEAT] = ACTIONS(5569),
    [anon_sym_Repeat] = ACTIONS(5569),
    [anon_sym_exit] = ACTIONS(5569),
    [anon_sym_EXIT] = ACTIONS(5569),
    [anon_sym_Exit] = ACTIONS(5569),
    [anon_sym_continue] = ACTIONS(5569),
    [anon_sym_CONTINUE] = ACTIONS(5569),
    [anon_sym_Continue] = ACTIONS(5569),
    [anon_sym_break] = ACTIONS(5569),
    [anon_sym_BREAK] = ACTIONS(5569),
    [anon_sym_Break] = ACTIONS(5569),
    [anon_sym_with] = ACTIONS(5569),
    [anon_sym_WITH] = ACTIONS(5569),
    [anon_sym_With] = ACTIONS(5569),
    [sym_asserterror_keyword] = ACTIONS(5571),
    [sym_page_keyword] = ACTIONS(5569),
    [anon_sym_codeunit] = ACTIONS(5569),
    [anon_sym_CODEUNIT] = ACTIONS(5569),
    [anon_sym_Codeunit] = ACTIONS(5569),
    [anon_sym_CodeUnit] = ACTIONS(5569),
    [anon_sym_COdeunit] = ACTIONS(5569),
    [anon_sym_codeUnit] = ACTIONS(5569),
    [sym_report_keyword] = ACTIONS(5569),
    [sym_query_keyword] = ACTIONS(5569),
    [anon_sym_xmlport] = ACTIONS(5569),
    [anon_sym_XMLPORT] = ACTIONS(5569),
    [anon_sym_Xmlport] = ACTIONS(5569),
    [anon_sym_XMLport] = ACTIONS(5569),
    [anon_sym_XMLPort] = ACTIONS(5569),
    [anon_sym_XmlPort] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_ENUM] = ACTIONS(5569),
    [anon_sym_Enum] = ACTIONS(5569),
    [anon_sym_eNUM] = ACTIONS(5569),
    [anon_sym_eNum] = ACTIONS(5569),
    [anon_sym_ENum] = ACTIONS(5569),
    [sym_quoted_identifier] = ACTIONS(5571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5571),
    [sym_verbatim_string] = ACTIONS(5571),
    [sym_integer] = ACTIONS(5569),
    [sym_continue_as_identifier] = ACTIONS(5571),
    [sym_preproc_open] = ACTIONS(5571),
    [sym_preproc_close] = ACTIONS(5571),
  },
  [STATE(2398)] = {
    [sym_identifier] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym_DASH] = ACTIONS(5575),
    [aux_sym_boolean_token1] = ACTIONS(5573),
    [aux_sym_boolean_token2] = ACTIONS(5573),
    [sym_decimal] = ACTIONS(5573),
    [anon_sym_LPAREN] = ACTIONS(5575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5575),
    [aux_sym_record_type_token1] = ACTIONS(5573),
    [aux_sym_basic_type_token21] = ACTIONS(5573),
    [aux_sym_basic_type_token22] = ACTIONS(5573),
    [aux_sym_basic_type_token48] = ACTIONS(5573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5573),
    [anon_sym_POUNDif] = ACTIONS(5575),
    [anon_sym_POUNDIF] = ACTIONS(5575),
    [anon_sym_POUNDIf] = ACTIONS(5575),
    [anon_sym_not] = ACTIONS(5573),
    [anon_sym_NOT] = ACTIONS(5573),
    [anon_sym_Not] = ACTIONS(5573),
    [anon_sym_POUNDelif] = ACTIONS(5575),
    [anon_sym_POUNDELIF] = ACTIONS(5575),
    [anon_sym_POUNDElif] = ACTIONS(5575),
    [anon_sym_POUNDelse] = ACTIONS(5575),
    [anon_sym_POUNDELSE] = ACTIONS(5575),
    [anon_sym_POUNDElse] = ACTIONS(5575),
    [anon_sym_POUNDelse2] = ACTIONS(5575),
    [anon_sym_POUNDELSE2] = ACTIONS(5575),
    [anon_sym_POUNDElse2] = ACTIONS(5575),
    [anon_sym_POUNDendif] = ACTIONS(5575),
    [anon_sym_POUNDENDIF] = ACTIONS(5575),
    [anon_sym_POUNDEndif] = ACTIONS(5575),
    [anon_sym_POUNDendif2] = ACTIONS(5575),
    [anon_sym_POUNDENDIF2] = ACTIONS(5575),
    [anon_sym_POUNDEndif2] = ACTIONS(5575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5573),
    [anon_sym_PLUS] = ACTIONS(5575),
    [sym_datetime_literal] = ACTIONS(5575),
    [sym_date_literal] = ACTIONS(5573),
    [sym_time_literal] = ACTIONS(5573),
    [sym_biginteger_literal] = ACTIONS(5575),
    [anon_sym_if] = ACTIONS(5573),
    [anon_sym_IF] = ACTIONS(5573),
    [anon_sym_If] = ACTIONS(5573),
    [anon_sym_else] = ACTIONS(5573),
    [anon_sym_ELSE] = ACTIONS(5573),
    [anon_sym_Else] = ACTIONS(5573),
    [anon_sym_case] = ACTIONS(5573),
    [anon_sym_CASE] = ACTIONS(5573),
    [anon_sym_Case] = ACTIONS(5573),
    [anon_sym_for] = ACTIONS(5573),
    [anon_sym_FOR] = ACTIONS(5573),
    [anon_sym_For] = ACTIONS(5573),
    [anon_sym_foreach] = ACTIONS(5573),
    [anon_sym_FOREACH] = ACTIONS(5573),
    [anon_sym_Foreach] = ACTIONS(5573),
    [anon_sym_while] = ACTIONS(5573),
    [anon_sym_WHILE] = ACTIONS(5573),
    [anon_sym_While] = ACTIONS(5573),
    [anon_sym_repeat] = ACTIONS(5573),
    [anon_sym_REPEAT] = ACTIONS(5573),
    [anon_sym_Repeat] = ACTIONS(5573),
    [anon_sym_exit] = ACTIONS(5573),
    [anon_sym_EXIT] = ACTIONS(5573),
    [anon_sym_Exit] = ACTIONS(5573),
    [anon_sym_continue] = ACTIONS(5573),
    [anon_sym_CONTINUE] = ACTIONS(5573),
    [anon_sym_Continue] = ACTIONS(5573),
    [anon_sym_break] = ACTIONS(5573),
    [anon_sym_BREAK] = ACTIONS(5573),
    [anon_sym_Break] = ACTIONS(5573),
    [anon_sym_with] = ACTIONS(5573),
    [anon_sym_WITH] = ACTIONS(5573),
    [anon_sym_With] = ACTIONS(5573),
    [sym_asserterror_keyword] = ACTIONS(5575),
    [sym_page_keyword] = ACTIONS(5573),
    [anon_sym_codeunit] = ACTIONS(5573),
    [anon_sym_CODEUNIT] = ACTIONS(5573),
    [anon_sym_Codeunit] = ACTIONS(5573),
    [anon_sym_CodeUnit] = ACTIONS(5573),
    [anon_sym_COdeunit] = ACTIONS(5573),
    [anon_sym_codeUnit] = ACTIONS(5573),
    [sym_report_keyword] = ACTIONS(5573),
    [sym_query_keyword] = ACTIONS(5573),
    [anon_sym_xmlport] = ACTIONS(5573),
    [anon_sym_XMLPORT] = ACTIONS(5573),
    [anon_sym_Xmlport] = ACTIONS(5573),
    [anon_sym_XMLport] = ACTIONS(5573),
    [anon_sym_XMLPort] = ACTIONS(5573),
    [anon_sym_XmlPort] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_ENUM] = ACTIONS(5573),
    [anon_sym_Enum] = ACTIONS(5573),
    [anon_sym_eNUM] = ACTIONS(5573),
    [anon_sym_eNum] = ACTIONS(5573),
    [anon_sym_ENum] = ACTIONS(5573),
    [sym_quoted_identifier] = ACTIONS(5575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5575),
    [sym_verbatim_string] = ACTIONS(5575),
    [sym_integer] = ACTIONS(5573),
    [sym_continue_as_identifier] = ACTIONS(5575),
    [sym_preproc_open] = ACTIONS(5575),
    [sym_preproc_close] = ACTIONS(5575),
  },
  [STATE(2399)] = {
    [sym_identifier] = ACTIONS(5577),
    [anon_sym_SEMI] = ACTIONS(5579),
    [anon_sym_DASH] = ACTIONS(5579),
    [aux_sym_boolean_token1] = ACTIONS(5577),
    [aux_sym_boolean_token2] = ACTIONS(5577),
    [sym_decimal] = ACTIONS(5577),
    [anon_sym_LPAREN] = ACTIONS(5579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5577),
    [anon_sym_LBRACK] = ACTIONS(5579),
    [aux_sym_record_type_token1] = ACTIONS(5577),
    [aux_sym_basic_type_token21] = ACTIONS(5577),
    [aux_sym_basic_type_token22] = ACTIONS(5577),
    [aux_sym_basic_type_token48] = ACTIONS(5577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5577),
    [anon_sym_POUNDif] = ACTIONS(5579),
    [anon_sym_POUNDIF] = ACTIONS(5579),
    [anon_sym_POUNDIf] = ACTIONS(5579),
    [anon_sym_not] = ACTIONS(5577),
    [anon_sym_NOT] = ACTIONS(5577),
    [anon_sym_Not] = ACTIONS(5577),
    [anon_sym_POUNDelif] = ACTIONS(5579),
    [anon_sym_POUNDELIF] = ACTIONS(5579),
    [anon_sym_POUNDElif] = ACTIONS(5579),
    [anon_sym_POUNDelse] = ACTIONS(5579),
    [anon_sym_POUNDELSE] = ACTIONS(5579),
    [anon_sym_POUNDElse] = ACTIONS(5579),
    [anon_sym_POUNDelse2] = ACTIONS(5579),
    [anon_sym_POUNDELSE2] = ACTIONS(5579),
    [anon_sym_POUNDElse2] = ACTIONS(5579),
    [anon_sym_POUNDendif] = ACTIONS(5579),
    [anon_sym_POUNDENDIF] = ACTIONS(5579),
    [anon_sym_POUNDEndif] = ACTIONS(5579),
    [anon_sym_POUNDendif2] = ACTIONS(5579),
    [anon_sym_POUNDENDIF2] = ACTIONS(5579),
    [anon_sym_POUNDEndif2] = ACTIONS(5579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5577),
    [anon_sym_PLUS] = ACTIONS(5579),
    [sym_datetime_literal] = ACTIONS(5579),
    [sym_date_literal] = ACTIONS(5577),
    [sym_time_literal] = ACTIONS(5577),
    [sym_biginteger_literal] = ACTIONS(5579),
    [anon_sym_if] = ACTIONS(5577),
    [anon_sym_IF] = ACTIONS(5577),
    [anon_sym_If] = ACTIONS(5577),
    [anon_sym_else] = ACTIONS(5577),
    [anon_sym_ELSE] = ACTIONS(5577),
    [anon_sym_Else] = ACTIONS(5577),
    [anon_sym_case] = ACTIONS(5577),
    [anon_sym_CASE] = ACTIONS(5577),
    [anon_sym_Case] = ACTIONS(5577),
    [anon_sym_for] = ACTIONS(5577),
    [anon_sym_FOR] = ACTIONS(5577),
    [anon_sym_For] = ACTIONS(5577),
    [anon_sym_foreach] = ACTIONS(5577),
    [anon_sym_FOREACH] = ACTIONS(5577),
    [anon_sym_Foreach] = ACTIONS(5577),
    [anon_sym_while] = ACTIONS(5577),
    [anon_sym_WHILE] = ACTIONS(5577),
    [anon_sym_While] = ACTIONS(5577),
    [anon_sym_repeat] = ACTIONS(5577),
    [anon_sym_REPEAT] = ACTIONS(5577),
    [anon_sym_Repeat] = ACTIONS(5577),
    [anon_sym_exit] = ACTIONS(5577),
    [anon_sym_EXIT] = ACTIONS(5577),
    [anon_sym_Exit] = ACTIONS(5577),
    [anon_sym_continue] = ACTIONS(5577),
    [anon_sym_CONTINUE] = ACTIONS(5577),
    [anon_sym_Continue] = ACTIONS(5577),
    [anon_sym_break] = ACTIONS(5577),
    [anon_sym_BREAK] = ACTIONS(5577),
    [anon_sym_Break] = ACTIONS(5577),
    [anon_sym_with] = ACTIONS(5577),
    [anon_sym_WITH] = ACTIONS(5577),
    [anon_sym_With] = ACTIONS(5577),
    [sym_asserterror_keyword] = ACTIONS(5579),
    [sym_page_keyword] = ACTIONS(5577),
    [anon_sym_codeunit] = ACTIONS(5577),
    [anon_sym_CODEUNIT] = ACTIONS(5577),
    [anon_sym_Codeunit] = ACTIONS(5577),
    [anon_sym_CodeUnit] = ACTIONS(5577),
    [anon_sym_COdeunit] = ACTIONS(5577),
    [anon_sym_codeUnit] = ACTIONS(5577),
    [sym_report_keyword] = ACTIONS(5577),
    [sym_query_keyword] = ACTIONS(5577),
    [anon_sym_xmlport] = ACTIONS(5577),
    [anon_sym_XMLPORT] = ACTIONS(5577),
    [anon_sym_Xmlport] = ACTIONS(5577),
    [anon_sym_XMLport] = ACTIONS(5577),
    [anon_sym_XMLPort] = ACTIONS(5577),
    [anon_sym_XmlPort] = ACTIONS(5577),
    [anon_sym_enum] = ACTIONS(5577),
    [anon_sym_ENUM] = ACTIONS(5577),
    [anon_sym_Enum] = ACTIONS(5577),
    [anon_sym_eNUM] = ACTIONS(5577),
    [anon_sym_eNum] = ACTIONS(5577),
    [anon_sym_ENum] = ACTIONS(5577),
    [sym_quoted_identifier] = ACTIONS(5579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5579),
    [sym_verbatim_string] = ACTIONS(5579),
    [sym_integer] = ACTIONS(5577),
    [sym_continue_as_identifier] = ACTIONS(5579),
    [sym_preproc_open] = ACTIONS(5579),
    [sym_preproc_close] = ACTIONS(5579),
  },
  [STATE(2400)] = {
    [sym_identifier] = ACTIONS(5581),
    [anon_sym_SEMI] = ACTIONS(5583),
    [anon_sym_DASH] = ACTIONS(5583),
    [aux_sym_boolean_token1] = ACTIONS(5581),
    [aux_sym_boolean_token2] = ACTIONS(5581),
    [sym_decimal] = ACTIONS(5581),
    [anon_sym_LPAREN] = ACTIONS(5583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5581),
    [anon_sym_LBRACK] = ACTIONS(5583),
    [aux_sym_record_type_token1] = ACTIONS(5581),
    [aux_sym_basic_type_token21] = ACTIONS(5581),
    [aux_sym_basic_type_token22] = ACTIONS(5581),
    [aux_sym_basic_type_token48] = ACTIONS(5581),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5581),
    [anon_sym_POUNDif] = ACTIONS(5583),
    [anon_sym_POUNDIF] = ACTIONS(5583),
    [anon_sym_POUNDIf] = ACTIONS(5583),
    [anon_sym_not] = ACTIONS(5581),
    [anon_sym_NOT] = ACTIONS(5581),
    [anon_sym_Not] = ACTIONS(5581),
    [anon_sym_POUNDelif] = ACTIONS(5583),
    [anon_sym_POUNDELIF] = ACTIONS(5583),
    [anon_sym_POUNDElif] = ACTIONS(5583),
    [anon_sym_POUNDelse] = ACTIONS(5583),
    [anon_sym_POUNDELSE] = ACTIONS(5583),
    [anon_sym_POUNDElse] = ACTIONS(5583),
    [anon_sym_POUNDelse2] = ACTIONS(5583),
    [anon_sym_POUNDELSE2] = ACTIONS(5583),
    [anon_sym_POUNDElse2] = ACTIONS(5583),
    [anon_sym_POUNDendif] = ACTIONS(5583),
    [anon_sym_POUNDENDIF] = ACTIONS(5583),
    [anon_sym_POUNDEndif] = ACTIONS(5583),
    [anon_sym_POUNDendif2] = ACTIONS(5583),
    [anon_sym_POUNDENDIF2] = ACTIONS(5583),
    [anon_sym_POUNDEndif2] = ACTIONS(5583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5581),
    [anon_sym_PLUS] = ACTIONS(5583),
    [sym_datetime_literal] = ACTIONS(5583),
    [sym_date_literal] = ACTIONS(5581),
    [sym_time_literal] = ACTIONS(5581),
    [sym_biginteger_literal] = ACTIONS(5583),
    [anon_sym_if] = ACTIONS(5581),
    [anon_sym_IF] = ACTIONS(5581),
    [anon_sym_If] = ACTIONS(5581),
    [anon_sym_else] = ACTIONS(5581),
    [anon_sym_ELSE] = ACTIONS(5581),
    [anon_sym_Else] = ACTIONS(5581),
    [anon_sym_case] = ACTIONS(5581),
    [anon_sym_CASE] = ACTIONS(5581),
    [anon_sym_Case] = ACTIONS(5581),
    [anon_sym_for] = ACTIONS(5581),
    [anon_sym_FOR] = ACTIONS(5581),
    [anon_sym_For] = ACTIONS(5581),
    [anon_sym_foreach] = ACTIONS(5581),
    [anon_sym_FOREACH] = ACTIONS(5581),
    [anon_sym_Foreach] = ACTIONS(5581),
    [anon_sym_while] = ACTIONS(5581),
    [anon_sym_WHILE] = ACTIONS(5581),
    [anon_sym_While] = ACTIONS(5581),
    [anon_sym_repeat] = ACTIONS(5581),
    [anon_sym_REPEAT] = ACTIONS(5581),
    [anon_sym_Repeat] = ACTIONS(5581),
    [anon_sym_exit] = ACTIONS(5581),
    [anon_sym_EXIT] = ACTIONS(5581),
    [anon_sym_Exit] = ACTIONS(5581),
    [anon_sym_continue] = ACTIONS(5581),
    [anon_sym_CONTINUE] = ACTIONS(5581),
    [anon_sym_Continue] = ACTIONS(5581),
    [anon_sym_break] = ACTIONS(5581),
    [anon_sym_BREAK] = ACTIONS(5581),
    [anon_sym_Break] = ACTIONS(5581),
    [anon_sym_with] = ACTIONS(5581),
    [anon_sym_WITH] = ACTIONS(5581),
    [anon_sym_With] = ACTIONS(5581),
    [sym_asserterror_keyword] = ACTIONS(5583),
    [sym_page_keyword] = ACTIONS(5581),
    [anon_sym_codeunit] = ACTIONS(5581),
    [anon_sym_CODEUNIT] = ACTIONS(5581),
    [anon_sym_Codeunit] = ACTIONS(5581),
    [anon_sym_CodeUnit] = ACTIONS(5581),
    [anon_sym_COdeunit] = ACTIONS(5581),
    [anon_sym_codeUnit] = ACTIONS(5581),
    [sym_report_keyword] = ACTIONS(5581),
    [sym_query_keyword] = ACTIONS(5581),
    [anon_sym_xmlport] = ACTIONS(5581),
    [anon_sym_XMLPORT] = ACTIONS(5581),
    [anon_sym_Xmlport] = ACTIONS(5581),
    [anon_sym_XMLport] = ACTIONS(5581),
    [anon_sym_XMLPort] = ACTIONS(5581),
    [anon_sym_XmlPort] = ACTIONS(5581),
    [anon_sym_enum] = ACTIONS(5581),
    [anon_sym_ENUM] = ACTIONS(5581),
    [anon_sym_Enum] = ACTIONS(5581),
    [anon_sym_eNUM] = ACTIONS(5581),
    [anon_sym_eNum] = ACTIONS(5581),
    [anon_sym_ENum] = ACTIONS(5581),
    [sym_quoted_identifier] = ACTIONS(5583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5583),
    [sym_verbatim_string] = ACTIONS(5583),
    [sym_integer] = ACTIONS(5581),
    [sym_continue_as_identifier] = ACTIONS(5583),
    [sym_preproc_open] = ACTIONS(5583),
    [sym_preproc_close] = ACTIONS(5583),
  },
  [STATE(2401)] = {
    [sym_identifier] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym_DASH] = ACTIONS(5587),
    [aux_sym_boolean_token1] = ACTIONS(5585),
    [aux_sym_boolean_token2] = ACTIONS(5585),
    [sym_decimal] = ACTIONS(5585),
    [anon_sym_LPAREN] = ACTIONS(5587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5587),
    [aux_sym_record_type_token1] = ACTIONS(5585),
    [aux_sym_basic_type_token21] = ACTIONS(5585),
    [aux_sym_basic_type_token22] = ACTIONS(5585),
    [aux_sym_basic_type_token48] = ACTIONS(5585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5585),
    [anon_sym_POUNDif] = ACTIONS(5587),
    [anon_sym_POUNDIF] = ACTIONS(5587),
    [anon_sym_POUNDIf] = ACTIONS(5587),
    [anon_sym_not] = ACTIONS(5585),
    [anon_sym_NOT] = ACTIONS(5585),
    [anon_sym_Not] = ACTIONS(5585),
    [anon_sym_POUNDelif] = ACTIONS(5587),
    [anon_sym_POUNDELIF] = ACTIONS(5587),
    [anon_sym_POUNDElif] = ACTIONS(5587),
    [anon_sym_POUNDelse] = ACTIONS(5587),
    [anon_sym_POUNDELSE] = ACTIONS(5587),
    [anon_sym_POUNDElse] = ACTIONS(5587),
    [anon_sym_POUNDelse2] = ACTIONS(5587),
    [anon_sym_POUNDELSE2] = ACTIONS(5587),
    [anon_sym_POUNDElse2] = ACTIONS(5587),
    [anon_sym_POUNDendif] = ACTIONS(5587),
    [anon_sym_POUNDENDIF] = ACTIONS(5587),
    [anon_sym_POUNDEndif] = ACTIONS(5587),
    [anon_sym_POUNDendif2] = ACTIONS(5587),
    [anon_sym_POUNDENDIF2] = ACTIONS(5587),
    [anon_sym_POUNDEndif2] = ACTIONS(5587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5585),
    [anon_sym_PLUS] = ACTIONS(5587),
    [sym_datetime_literal] = ACTIONS(5587),
    [sym_date_literal] = ACTIONS(5585),
    [sym_time_literal] = ACTIONS(5585),
    [sym_biginteger_literal] = ACTIONS(5587),
    [anon_sym_if] = ACTIONS(5585),
    [anon_sym_IF] = ACTIONS(5585),
    [anon_sym_If] = ACTIONS(5585),
    [anon_sym_else] = ACTIONS(5585),
    [anon_sym_ELSE] = ACTIONS(5585),
    [anon_sym_Else] = ACTIONS(5585),
    [anon_sym_case] = ACTIONS(5585),
    [anon_sym_CASE] = ACTIONS(5585),
    [anon_sym_Case] = ACTIONS(5585),
    [anon_sym_for] = ACTIONS(5585),
    [anon_sym_FOR] = ACTIONS(5585),
    [anon_sym_For] = ACTIONS(5585),
    [anon_sym_foreach] = ACTIONS(5585),
    [anon_sym_FOREACH] = ACTIONS(5585),
    [anon_sym_Foreach] = ACTIONS(5585),
    [anon_sym_while] = ACTIONS(5585),
    [anon_sym_WHILE] = ACTIONS(5585),
    [anon_sym_While] = ACTIONS(5585),
    [anon_sym_repeat] = ACTIONS(5585),
    [anon_sym_REPEAT] = ACTIONS(5585),
    [anon_sym_Repeat] = ACTIONS(5585),
    [anon_sym_exit] = ACTIONS(5585),
    [anon_sym_EXIT] = ACTIONS(5585),
    [anon_sym_Exit] = ACTIONS(5585),
    [anon_sym_continue] = ACTIONS(5585),
    [anon_sym_CONTINUE] = ACTIONS(5585),
    [anon_sym_Continue] = ACTIONS(5585),
    [anon_sym_break] = ACTIONS(5585),
    [anon_sym_BREAK] = ACTIONS(5585),
    [anon_sym_Break] = ACTIONS(5585),
    [anon_sym_with] = ACTIONS(5585),
    [anon_sym_WITH] = ACTIONS(5585),
    [anon_sym_With] = ACTIONS(5585),
    [sym_asserterror_keyword] = ACTIONS(5587),
    [sym_page_keyword] = ACTIONS(5585),
    [anon_sym_codeunit] = ACTIONS(5585),
    [anon_sym_CODEUNIT] = ACTIONS(5585),
    [anon_sym_Codeunit] = ACTIONS(5585),
    [anon_sym_CodeUnit] = ACTIONS(5585),
    [anon_sym_COdeunit] = ACTIONS(5585),
    [anon_sym_codeUnit] = ACTIONS(5585),
    [sym_report_keyword] = ACTIONS(5585),
    [sym_query_keyword] = ACTIONS(5585),
    [anon_sym_xmlport] = ACTIONS(5585),
    [anon_sym_XMLPORT] = ACTIONS(5585),
    [anon_sym_Xmlport] = ACTIONS(5585),
    [anon_sym_XMLport] = ACTIONS(5585),
    [anon_sym_XMLPort] = ACTIONS(5585),
    [anon_sym_XmlPort] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_ENUM] = ACTIONS(5585),
    [anon_sym_Enum] = ACTIONS(5585),
    [anon_sym_eNUM] = ACTIONS(5585),
    [anon_sym_eNum] = ACTIONS(5585),
    [anon_sym_ENum] = ACTIONS(5585),
    [sym_quoted_identifier] = ACTIONS(5587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5587),
    [sym_verbatim_string] = ACTIONS(5587),
    [sym_integer] = ACTIONS(5585),
    [sym_continue_as_identifier] = ACTIONS(5587),
    [sym_preproc_open] = ACTIONS(5587),
    [sym_preproc_close] = ACTIONS(5587),
  },
  [STATE(2402)] = {
    [sym_identifier] = ACTIONS(5589),
    [anon_sym_SEMI] = ACTIONS(5591),
    [anon_sym_DASH] = ACTIONS(5591),
    [aux_sym_boolean_token1] = ACTIONS(5589),
    [aux_sym_boolean_token2] = ACTIONS(5589),
    [sym_decimal] = ACTIONS(5589),
    [anon_sym_LPAREN] = ACTIONS(5591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5589),
    [anon_sym_LBRACK] = ACTIONS(5591),
    [aux_sym_record_type_token1] = ACTIONS(5589),
    [aux_sym_basic_type_token21] = ACTIONS(5589),
    [aux_sym_basic_type_token22] = ACTIONS(5589),
    [aux_sym_basic_type_token48] = ACTIONS(5589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5589),
    [anon_sym_POUNDif] = ACTIONS(5591),
    [anon_sym_POUNDIF] = ACTIONS(5591),
    [anon_sym_POUNDIf] = ACTIONS(5591),
    [anon_sym_not] = ACTIONS(5589),
    [anon_sym_NOT] = ACTIONS(5589),
    [anon_sym_Not] = ACTIONS(5589),
    [anon_sym_POUNDelif] = ACTIONS(5591),
    [anon_sym_POUNDELIF] = ACTIONS(5591),
    [anon_sym_POUNDElif] = ACTIONS(5591),
    [anon_sym_POUNDelse] = ACTIONS(5591),
    [anon_sym_POUNDELSE] = ACTIONS(5591),
    [anon_sym_POUNDElse] = ACTIONS(5591),
    [anon_sym_POUNDelse2] = ACTIONS(5591),
    [anon_sym_POUNDELSE2] = ACTIONS(5591),
    [anon_sym_POUNDElse2] = ACTIONS(5591),
    [anon_sym_POUNDendif] = ACTIONS(5591),
    [anon_sym_POUNDENDIF] = ACTIONS(5591),
    [anon_sym_POUNDEndif] = ACTIONS(5591),
    [anon_sym_POUNDendif2] = ACTIONS(5591),
    [anon_sym_POUNDENDIF2] = ACTIONS(5591),
    [anon_sym_POUNDEndif2] = ACTIONS(5591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5589),
    [anon_sym_PLUS] = ACTIONS(5591),
    [sym_datetime_literal] = ACTIONS(5591),
    [sym_date_literal] = ACTIONS(5589),
    [sym_time_literal] = ACTIONS(5589),
    [sym_biginteger_literal] = ACTIONS(5591),
    [anon_sym_if] = ACTIONS(5589),
    [anon_sym_IF] = ACTIONS(5589),
    [anon_sym_If] = ACTIONS(5589),
    [anon_sym_else] = ACTIONS(5589),
    [anon_sym_ELSE] = ACTIONS(5589),
    [anon_sym_Else] = ACTIONS(5589),
    [anon_sym_case] = ACTIONS(5589),
    [anon_sym_CASE] = ACTIONS(5589),
    [anon_sym_Case] = ACTIONS(5589),
    [anon_sym_for] = ACTIONS(5589),
    [anon_sym_FOR] = ACTIONS(5589),
    [anon_sym_For] = ACTIONS(5589),
    [anon_sym_foreach] = ACTIONS(5589),
    [anon_sym_FOREACH] = ACTIONS(5589),
    [anon_sym_Foreach] = ACTIONS(5589),
    [anon_sym_while] = ACTIONS(5589),
    [anon_sym_WHILE] = ACTIONS(5589),
    [anon_sym_While] = ACTIONS(5589),
    [anon_sym_repeat] = ACTIONS(5589),
    [anon_sym_REPEAT] = ACTIONS(5589),
    [anon_sym_Repeat] = ACTIONS(5589),
    [anon_sym_exit] = ACTIONS(5589),
    [anon_sym_EXIT] = ACTIONS(5589),
    [anon_sym_Exit] = ACTIONS(5589),
    [anon_sym_continue] = ACTIONS(5589),
    [anon_sym_CONTINUE] = ACTIONS(5589),
    [anon_sym_Continue] = ACTIONS(5589),
    [anon_sym_break] = ACTIONS(5589),
    [anon_sym_BREAK] = ACTIONS(5589),
    [anon_sym_Break] = ACTIONS(5589),
    [anon_sym_with] = ACTIONS(5589),
    [anon_sym_WITH] = ACTIONS(5589),
    [anon_sym_With] = ACTIONS(5589),
    [sym_asserterror_keyword] = ACTIONS(5591),
    [sym_page_keyword] = ACTIONS(5589),
    [anon_sym_codeunit] = ACTIONS(5589),
    [anon_sym_CODEUNIT] = ACTIONS(5589),
    [anon_sym_Codeunit] = ACTIONS(5589),
    [anon_sym_CodeUnit] = ACTIONS(5589),
    [anon_sym_COdeunit] = ACTIONS(5589),
    [anon_sym_codeUnit] = ACTIONS(5589),
    [sym_report_keyword] = ACTIONS(5589),
    [sym_query_keyword] = ACTIONS(5589),
    [anon_sym_xmlport] = ACTIONS(5589),
    [anon_sym_XMLPORT] = ACTIONS(5589),
    [anon_sym_Xmlport] = ACTIONS(5589),
    [anon_sym_XMLport] = ACTIONS(5589),
    [anon_sym_XMLPort] = ACTIONS(5589),
    [anon_sym_XmlPort] = ACTIONS(5589),
    [anon_sym_enum] = ACTIONS(5589),
    [anon_sym_ENUM] = ACTIONS(5589),
    [anon_sym_Enum] = ACTIONS(5589),
    [anon_sym_eNUM] = ACTIONS(5589),
    [anon_sym_eNum] = ACTIONS(5589),
    [anon_sym_ENum] = ACTIONS(5589),
    [sym_quoted_identifier] = ACTIONS(5591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5591),
    [sym_verbatim_string] = ACTIONS(5591),
    [sym_integer] = ACTIONS(5589),
    [sym_continue_as_identifier] = ACTIONS(5591),
    [sym_preproc_open] = ACTIONS(5591),
    [sym_preproc_close] = ACTIONS(5591),
  },
  [STATE(2403)] = {
    [sym_identifier] = ACTIONS(5593),
    [anon_sym_SEMI] = ACTIONS(5595),
    [anon_sym_DASH] = ACTIONS(5595),
    [aux_sym_boolean_token1] = ACTIONS(5593),
    [aux_sym_boolean_token2] = ACTIONS(5593),
    [sym_decimal] = ACTIONS(5593),
    [anon_sym_LPAREN] = ACTIONS(5595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5593),
    [anon_sym_LBRACK] = ACTIONS(5595),
    [aux_sym_record_type_token1] = ACTIONS(5593),
    [aux_sym_basic_type_token21] = ACTIONS(5593),
    [aux_sym_basic_type_token22] = ACTIONS(5593),
    [aux_sym_basic_type_token48] = ACTIONS(5593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5593),
    [anon_sym_POUNDif] = ACTIONS(5595),
    [anon_sym_POUNDIF] = ACTIONS(5595),
    [anon_sym_POUNDIf] = ACTIONS(5595),
    [anon_sym_not] = ACTIONS(5593),
    [anon_sym_NOT] = ACTIONS(5593),
    [anon_sym_Not] = ACTIONS(5593),
    [anon_sym_POUNDelif] = ACTIONS(5595),
    [anon_sym_POUNDELIF] = ACTIONS(5595),
    [anon_sym_POUNDElif] = ACTIONS(5595),
    [anon_sym_POUNDelse] = ACTIONS(5595),
    [anon_sym_POUNDELSE] = ACTIONS(5595),
    [anon_sym_POUNDElse] = ACTIONS(5595),
    [anon_sym_POUNDelse2] = ACTIONS(5595),
    [anon_sym_POUNDELSE2] = ACTIONS(5595),
    [anon_sym_POUNDElse2] = ACTIONS(5595),
    [anon_sym_POUNDendif] = ACTIONS(5595),
    [anon_sym_POUNDENDIF] = ACTIONS(5595),
    [anon_sym_POUNDEndif] = ACTIONS(5595),
    [anon_sym_POUNDendif2] = ACTIONS(5595),
    [anon_sym_POUNDENDIF2] = ACTIONS(5595),
    [anon_sym_POUNDEndif2] = ACTIONS(5595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5593),
    [anon_sym_PLUS] = ACTIONS(5595),
    [sym_datetime_literal] = ACTIONS(5595),
    [sym_date_literal] = ACTIONS(5593),
    [sym_time_literal] = ACTIONS(5593),
    [sym_biginteger_literal] = ACTIONS(5595),
    [anon_sym_if] = ACTIONS(5593),
    [anon_sym_IF] = ACTIONS(5593),
    [anon_sym_If] = ACTIONS(5593),
    [anon_sym_else] = ACTIONS(5593),
    [anon_sym_ELSE] = ACTIONS(5593),
    [anon_sym_Else] = ACTIONS(5593),
    [anon_sym_case] = ACTIONS(5593),
    [anon_sym_CASE] = ACTIONS(5593),
    [anon_sym_Case] = ACTIONS(5593),
    [anon_sym_for] = ACTIONS(5593),
    [anon_sym_FOR] = ACTIONS(5593),
    [anon_sym_For] = ACTIONS(5593),
    [anon_sym_foreach] = ACTIONS(5593),
    [anon_sym_FOREACH] = ACTIONS(5593),
    [anon_sym_Foreach] = ACTIONS(5593),
    [anon_sym_while] = ACTIONS(5593),
    [anon_sym_WHILE] = ACTIONS(5593),
    [anon_sym_While] = ACTIONS(5593),
    [anon_sym_repeat] = ACTIONS(5593),
    [anon_sym_REPEAT] = ACTIONS(5593),
    [anon_sym_Repeat] = ACTIONS(5593),
    [anon_sym_exit] = ACTIONS(5593),
    [anon_sym_EXIT] = ACTIONS(5593),
    [anon_sym_Exit] = ACTIONS(5593),
    [anon_sym_continue] = ACTIONS(5593),
    [anon_sym_CONTINUE] = ACTIONS(5593),
    [anon_sym_Continue] = ACTIONS(5593),
    [anon_sym_break] = ACTIONS(5593),
    [anon_sym_BREAK] = ACTIONS(5593),
    [anon_sym_Break] = ACTIONS(5593),
    [anon_sym_with] = ACTIONS(5593),
    [anon_sym_WITH] = ACTIONS(5593),
    [anon_sym_With] = ACTIONS(5593),
    [sym_asserterror_keyword] = ACTIONS(5595),
    [sym_page_keyword] = ACTIONS(5593),
    [anon_sym_codeunit] = ACTIONS(5593),
    [anon_sym_CODEUNIT] = ACTIONS(5593),
    [anon_sym_Codeunit] = ACTIONS(5593),
    [anon_sym_CodeUnit] = ACTIONS(5593),
    [anon_sym_COdeunit] = ACTIONS(5593),
    [anon_sym_codeUnit] = ACTIONS(5593),
    [sym_report_keyword] = ACTIONS(5593),
    [sym_query_keyword] = ACTIONS(5593),
    [anon_sym_xmlport] = ACTIONS(5593),
    [anon_sym_XMLPORT] = ACTIONS(5593),
    [anon_sym_Xmlport] = ACTIONS(5593),
    [anon_sym_XMLport] = ACTIONS(5593),
    [anon_sym_XMLPort] = ACTIONS(5593),
    [anon_sym_XmlPort] = ACTIONS(5593),
    [anon_sym_enum] = ACTIONS(5593),
    [anon_sym_ENUM] = ACTIONS(5593),
    [anon_sym_Enum] = ACTIONS(5593),
    [anon_sym_eNUM] = ACTIONS(5593),
    [anon_sym_eNum] = ACTIONS(5593),
    [anon_sym_ENum] = ACTIONS(5593),
    [sym_quoted_identifier] = ACTIONS(5595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5595),
    [sym_verbatim_string] = ACTIONS(5595),
    [sym_integer] = ACTIONS(5593),
    [sym_continue_as_identifier] = ACTIONS(5595),
    [sym_preproc_open] = ACTIONS(5595),
    [sym_preproc_close] = ACTIONS(5595),
  },
  [STATE(2404)] = {
    [sym_identifier] = ACTIONS(5597),
    [anon_sym_SEMI] = ACTIONS(5599),
    [anon_sym_DASH] = ACTIONS(5599),
    [aux_sym_boolean_token1] = ACTIONS(5597),
    [aux_sym_boolean_token2] = ACTIONS(5597),
    [sym_decimal] = ACTIONS(5597),
    [anon_sym_LPAREN] = ACTIONS(5599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5597),
    [anon_sym_LBRACK] = ACTIONS(5599),
    [aux_sym_record_type_token1] = ACTIONS(5597),
    [aux_sym_basic_type_token21] = ACTIONS(5597),
    [aux_sym_basic_type_token22] = ACTIONS(5597),
    [aux_sym_basic_type_token48] = ACTIONS(5597),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5597),
    [anon_sym_POUNDif] = ACTIONS(5599),
    [anon_sym_POUNDIF] = ACTIONS(5599),
    [anon_sym_POUNDIf] = ACTIONS(5599),
    [anon_sym_not] = ACTIONS(5597),
    [anon_sym_NOT] = ACTIONS(5597),
    [anon_sym_Not] = ACTIONS(5597),
    [anon_sym_POUNDelif] = ACTIONS(5599),
    [anon_sym_POUNDELIF] = ACTIONS(5599),
    [anon_sym_POUNDElif] = ACTIONS(5599),
    [anon_sym_POUNDelse] = ACTIONS(5599),
    [anon_sym_POUNDELSE] = ACTIONS(5599),
    [anon_sym_POUNDElse] = ACTIONS(5599),
    [anon_sym_POUNDelse2] = ACTIONS(5599),
    [anon_sym_POUNDELSE2] = ACTIONS(5599),
    [anon_sym_POUNDElse2] = ACTIONS(5599),
    [anon_sym_POUNDendif] = ACTIONS(5599),
    [anon_sym_POUNDENDIF] = ACTIONS(5599),
    [anon_sym_POUNDEndif] = ACTIONS(5599),
    [anon_sym_POUNDendif2] = ACTIONS(5599),
    [anon_sym_POUNDENDIF2] = ACTIONS(5599),
    [anon_sym_POUNDEndif2] = ACTIONS(5599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5597),
    [anon_sym_PLUS] = ACTIONS(5599),
    [sym_datetime_literal] = ACTIONS(5599),
    [sym_date_literal] = ACTIONS(5597),
    [sym_time_literal] = ACTIONS(5597),
    [sym_biginteger_literal] = ACTIONS(5599),
    [anon_sym_if] = ACTIONS(5597),
    [anon_sym_IF] = ACTIONS(5597),
    [anon_sym_If] = ACTIONS(5597),
    [anon_sym_else] = ACTIONS(5597),
    [anon_sym_ELSE] = ACTIONS(5597),
    [anon_sym_Else] = ACTIONS(5597),
    [anon_sym_case] = ACTIONS(5597),
    [anon_sym_CASE] = ACTIONS(5597),
    [anon_sym_Case] = ACTIONS(5597),
    [anon_sym_for] = ACTIONS(5597),
    [anon_sym_FOR] = ACTIONS(5597),
    [anon_sym_For] = ACTIONS(5597),
    [anon_sym_foreach] = ACTIONS(5597),
    [anon_sym_FOREACH] = ACTIONS(5597),
    [anon_sym_Foreach] = ACTIONS(5597),
    [anon_sym_while] = ACTIONS(5597),
    [anon_sym_WHILE] = ACTIONS(5597),
    [anon_sym_While] = ACTIONS(5597),
    [anon_sym_repeat] = ACTIONS(5597),
    [anon_sym_REPEAT] = ACTIONS(5597),
    [anon_sym_Repeat] = ACTIONS(5597),
    [anon_sym_exit] = ACTIONS(5597),
    [anon_sym_EXIT] = ACTIONS(5597),
    [anon_sym_Exit] = ACTIONS(5597),
    [anon_sym_continue] = ACTIONS(5597),
    [anon_sym_CONTINUE] = ACTIONS(5597),
    [anon_sym_Continue] = ACTIONS(5597),
    [anon_sym_break] = ACTIONS(5597),
    [anon_sym_BREAK] = ACTIONS(5597),
    [anon_sym_Break] = ACTIONS(5597),
    [anon_sym_with] = ACTIONS(5597),
    [anon_sym_WITH] = ACTIONS(5597),
    [anon_sym_With] = ACTIONS(5597),
    [sym_asserterror_keyword] = ACTIONS(5599),
    [sym_page_keyword] = ACTIONS(5597),
    [anon_sym_codeunit] = ACTIONS(5597),
    [anon_sym_CODEUNIT] = ACTIONS(5597),
    [anon_sym_Codeunit] = ACTIONS(5597),
    [anon_sym_CodeUnit] = ACTIONS(5597),
    [anon_sym_COdeunit] = ACTIONS(5597),
    [anon_sym_codeUnit] = ACTIONS(5597),
    [sym_report_keyword] = ACTIONS(5597),
    [sym_query_keyword] = ACTIONS(5597),
    [anon_sym_xmlport] = ACTIONS(5597),
    [anon_sym_XMLPORT] = ACTIONS(5597),
    [anon_sym_Xmlport] = ACTIONS(5597),
    [anon_sym_XMLport] = ACTIONS(5597),
    [anon_sym_XMLPort] = ACTIONS(5597),
    [anon_sym_XmlPort] = ACTIONS(5597),
    [anon_sym_enum] = ACTIONS(5597),
    [anon_sym_ENUM] = ACTIONS(5597),
    [anon_sym_Enum] = ACTIONS(5597),
    [anon_sym_eNUM] = ACTIONS(5597),
    [anon_sym_eNum] = ACTIONS(5597),
    [anon_sym_ENum] = ACTIONS(5597),
    [sym_quoted_identifier] = ACTIONS(5599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5599),
    [sym_verbatim_string] = ACTIONS(5599),
    [sym_integer] = ACTIONS(5597),
    [sym_continue_as_identifier] = ACTIONS(5599),
    [sym_preproc_open] = ACTIONS(5599),
    [sym_preproc_close] = ACTIONS(5599),
  },
  [STATE(2405)] = {
    [sym_identifier] = ACTIONS(5601),
    [anon_sym_SEMI] = ACTIONS(5603),
    [anon_sym_DASH] = ACTIONS(5603),
    [aux_sym_boolean_token1] = ACTIONS(5601),
    [aux_sym_boolean_token2] = ACTIONS(5601),
    [sym_decimal] = ACTIONS(5601),
    [anon_sym_LPAREN] = ACTIONS(5603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5601),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [aux_sym_record_type_token1] = ACTIONS(5601),
    [aux_sym_basic_type_token21] = ACTIONS(5601),
    [aux_sym_basic_type_token22] = ACTIONS(5601),
    [aux_sym_basic_type_token48] = ACTIONS(5601),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5601),
    [anon_sym_POUNDif] = ACTIONS(5603),
    [anon_sym_POUNDIF] = ACTIONS(5603),
    [anon_sym_POUNDIf] = ACTIONS(5603),
    [anon_sym_not] = ACTIONS(5601),
    [anon_sym_NOT] = ACTIONS(5601),
    [anon_sym_Not] = ACTIONS(5601),
    [anon_sym_POUNDelif] = ACTIONS(5603),
    [anon_sym_POUNDELIF] = ACTIONS(5603),
    [anon_sym_POUNDElif] = ACTIONS(5603),
    [anon_sym_POUNDelse] = ACTIONS(5603),
    [anon_sym_POUNDELSE] = ACTIONS(5603),
    [anon_sym_POUNDElse] = ACTIONS(5603),
    [anon_sym_POUNDelse2] = ACTIONS(5603),
    [anon_sym_POUNDELSE2] = ACTIONS(5603),
    [anon_sym_POUNDElse2] = ACTIONS(5603),
    [anon_sym_POUNDendif] = ACTIONS(5603),
    [anon_sym_POUNDENDIF] = ACTIONS(5603),
    [anon_sym_POUNDEndif] = ACTIONS(5603),
    [anon_sym_POUNDendif2] = ACTIONS(5603),
    [anon_sym_POUNDENDIF2] = ACTIONS(5603),
    [anon_sym_POUNDEndif2] = ACTIONS(5603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5601),
    [anon_sym_PLUS] = ACTIONS(5603),
    [sym_datetime_literal] = ACTIONS(5603),
    [sym_date_literal] = ACTIONS(5601),
    [sym_time_literal] = ACTIONS(5601),
    [sym_biginteger_literal] = ACTIONS(5603),
    [anon_sym_if] = ACTIONS(5601),
    [anon_sym_IF] = ACTIONS(5601),
    [anon_sym_If] = ACTIONS(5601),
    [anon_sym_else] = ACTIONS(5601),
    [anon_sym_ELSE] = ACTIONS(5601),
    [anon_sym_Else] = ACTIONS(5601),
    [anon_sym_case] = ACTIONS(5601),
    [anon_sym_CASE] = ACTIONS(5601),
    [anon_sym_Case] = ACTIONS(5601),
    [anon_sym_for] = ACTIONS(5601),
    [anon_sym_FOR] = ACTIONS(5601),
    [anon_sym_For] = ACTIONS(5601),
    [anon_sym_foreach] = ACTIONS(5601),
    [anon_sym_FOREACH] = ACTIONS(5601),
    [anon_sym_Foreach] = ACTIONS(5601),
    [anon_sym_while] = ACTIONS(5601),
    [anon_sym_WHILE] = ACTIONS(5601),
    [anon_sym_While] = ACTIONS(5601),
    [anon_sym_repeat] = ACTIONS(5601),
    [anon_sym_REPEAT] = ACTIONS(5601),
    [anon_sym_Repeat] = ACTIONS(5601),
    [anon_sym_exit] = ACTIONS(5601),
    [anon_sym_EXIT] = ACTIONS(5601),
    [anon_sym_Exit] = ACTIONS(5601),
    [anon_sym_continue] = ACTIONS(5601),
    [anon_sym_CONTINUE] = ACTIONS(5601),
    [anon_sym_Continue] = ACTIONS(5601),
    [anon_sym_break] = ACTIONS(5601),
    [anon_sym_BREAK] = ACTIONS(5601),
    [anon_sym_Break] = ACTIONS(5601),
    [anon_sym_with] = ACTIONS(5601),
    [anon_sym_WITH] = ACTIONS(5601),
    [anon_sym_With] = ACTIONS(5601),
    [sym_asserterror_keyword] = ACTIONS(5603),
    [sym_page_keyword] = ACTIONS(5601),
    [anon_sym_codeunit] = ACTIONS(5601),
    [anon_sym_CODEUNIT] = ACTIONS(5601),
    [anon_sym_Codeunit] = ACTIONS(5601),
    [anon_sym_CodeUnit] = ACTIONS(5601),
    [anon_sym_COdeunit] = ACTIONS(5601),
    [anon_sym_codeUnit] = ACTIONS(5601),
    [sym_report_keyword] = ACTIONS(5601),
    [sym_query_keyword] = ACTIONS(5601),
    [anon_sym_xmlport] = ACTIONS(5601),
    [anon_sym_XMLPORT] = ACTIONS(5601),
    [anon_sym_Xmlport] = ACTIONS(5601),
    [anon_sym_XMLport] = ACTIONS(5601),
    [anon_sym_XMLPort] = ACTIONS(5601),
    [anon_sym_XmlPort] = ACTIONS(5601),
    [anon_sym_enum] = ACTIONS(5601),
    [anon_sym_ENUM] = ACTIONS(5601),
    [anon_sym_Enum] = ACTIONS(5601),
    [anon_sym_eNUM] = ACTIONS(5601),
    [anon_sym_eNum] = ACTIONS(5601),
    [anon_sym_ENum] = ACTIONS(5601),
    [sym_quoted_identifier] = ACTIONS(5603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5603),
    [sym_verbatim_string] = ACTIONS(5603),
    [sym_integer] = ACTIONS(5601),
    [sym_continue_as_identifier] = ACTIONS(5603),
    [sym_preproc_open] = ACTIONS(5603),
    [sym_preproc_close] = ACTIONS(5603),
  },
  [STATE(2406)] = {
    [sym_identifier] = ACTIONS(5605),
    [anon_sym_SEMI] = ACTIONS(5607),
    [anon_sym_DASH] = ACTIONS(5607),
    [aux_sym_boolean_token1] = ACTIONS(5605),
    [aux_sym_boolean_token2] = ACTIONS(5605),
    [sym_decimal] = ACTIONS(5605),
    [anon_sym_LPAREN] = ACTIONS(5607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5605),
    [anon_sym_LBRACK] = ACTIONS(5607),
    [aux_sym_record_type_token1] = ACTIONS(5605),
    [aux_sym_basic_type_token21] = ACTIONS(5605),
    [aux_sym_basic_type_token22] = ACTIONS(5605),
    [aux_sym_basic_type_token48] = ACTIONS(5605),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5605),
    [anon_sym_POUNDif] = ACTIONS(5607),
    [anon_sym_POUNDIF] = ACTIONS(5607),
    [anon_sym_POUNDIf] = ACTIONS(5607),
    [anon_sym_not] = ACTIONS(5605),
    [anon_sym_NOT] = ACTIONS(5605),
    [anon_sym_Not] = ACTIONS(5605),
    [anon_sym_POUNDelif] = ACTIONS(5607),
    [anon_sym_POUNDELIF] = ACTIONS(5607),
    [anon_sym_POUNDElif] = ACTIONS(5607),
    [anon_sym_POUNDelse] = ACTIONS(5607),
    [anon_sym_POUNDELSE] = ACTIONS(5607),
    [anon_sym_POUNDElse] = ACTIONS(5607),
    [anon_sym_POUNDelse2] = ACTIONS(5607),
    [anon_sym_POUNDELSE2] = ACTIONS(5607),
    [anon_sym_POUNDElse2] = ACTIONS(5607),
    [anon_sym_POUNDendif] = ACTIONS(5607),
    [anon_sym_POUNDENDIF] = ACTIONS(5607),
    [anon_sym_POUNDEndif] = ACTIONS(5607),
    [anon_sym_POUNDendif2] = ACTIONS(5607),
    [anon_sym_POUNDENDIF2] = ACTIONS(5607),
    [anon_sym_POUNDEndif2] = ACTIONS(5607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5605),
    [anon_sym_PLUS] = ACTIONS(5607),
    [sym_datetime_literal] = ACTIONS(5607),
    [sym_date_literal] = ACTIONS(5605),
    [sym_time_literal] = ACTIONS(5605),
    [sym_biginteger_literal] = ACTIONS(5607),
    [anon_sym_if] = ACTIONS(5605),
    [anon_sym_IF] = ACTIONS(5605),
    [anon_sym_If] = ACTIONS(5605),
    [anon_sym_else] = ACTIONS(5605),
    [anon_sym_ELSE] = ACTIONS(5605),
    [anon_sym_Else] = ACTIONS(5605),
    [anon_sym_case] = ACTIONS(5605),
    [anon_sym_CASE] = ACTIONS(5605),
    [anon_sym_Case] = ACTIONS(5605),
    [anon_sym_for] = ACTIONS(5605),
    [anon_sym_FOR] = ACTIONS(5605),
    [anon_sym_For] = ACTIONS(5605),
    [anon_sym_foreach] = ACTIONS(5605),
    [anon_sym_FOREACH] = ACTIONS(5605),
    [anon_sym_Foreach] = ACTIONS(5605),
    [anon_sym_while] = ACTIONS(5605),
    [anon_sym_WHILE] = ACTIONS(5605),
    [anon_sym_While] = ACTIONS(5605),
    [anon_sym_repeat] = ACTIONS(5605),
    [anon_sym_REPEAT] = ACTIONS(5605),
    [anon_sym_Repeat] = ACTIONS(5605),
    [anon_sym_exit] = ACTIONS(5605),
    [anon_sym_EXIT] = ACTIONS(5605),
    [anon_sym_Exit] = ACTIONS(5605),
    [anon_sym_continue] = ACTIONS(5605),
    [anon_sym_CONTINUE] = ACTIONS(5605),
    [anon_sym_Continue] = ACTIONS(5605),
    [anon_sym_break] = ACTIONS(5605),
    [anon_sym_BREAK] = ACTIONS(5605),
    [anon_sym_Break] = ACTIONS(5605),
    [anon_sym_with] = ACTIONS(5605),
    [anon_sym_WITH] = ACTIONS(5605),
    [anon_sym_With] = ACTIONS(5605),
    [sym_asserterror_keyword] = ACTIONS(5607),
    [sym_page_keyword] = ACTIONS(5605),
    [anon_sym_codeunit] = ACTIONS(5605),
    [anon_sym_CODEUNIT] = ACTIONS(5605),
    [anon_sym_Codeunit] = ACTIONS(5605),
    [anon_sym_CodeUnit] = ACTIONS(5605),
    [anon_sym_COdeunit] = ACTIONS(5605),
    [anon_sym_codeUnit] = ACTIONS(5605),
    [sym_report_keyword] = ACTIONS(5605),
    [sym_query_keyword] = ACTIONS(5605),
    [anon_sym_xmlport] = ACTIONS(5605),
    [anon_sym_XMLPORT] = ACTIONS(5605),
    [anon_sym_Xmlport] = ACTIONS(5605),
    [anon_sym_XMLport] = ACTIONS(5605),
    [anon_sym_XMLPort] = ACTIONS(5605),
    [anon_sym_XmlPort] = ACTIONS(5605),
    [anon_sym_enum] = ACTIONS(5605),
    [anon_sym_ENUM] = ACTIONS(5605),
    [anon_sym_Enum] = ACTIONS(5605),
    [anon_sym_eNUM] = ACTIONS(5605),
    [anon_sym_eNum] = ACTIONS(5605),
    [anon_sym_ENum] = ACTIONS(5605),
    [sym_quoted_identifier] = ACTIONS(5607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5607),
    [sym_verbatim_string] = ACTIONS(5607),
    [sym_integer] = ACTIONS(5605),
    [sym_continue_as_identifier] = ACTIONS(5607),
    [sym_preproc_open] = ACTIONS(5607),
    [sym_preproc_close] = ACTIONS(5607),
  },
  [STATE(2407)] = {
    [sym_identifier] = ACTIONS(5609),
    [anon_sym_SEMI] = ACTIONS(5611),
    [anon_sym_DASH] = ACTIONS(5611),
    [aux_sym_boolean_token1] = ACTIONS(5609),
    [aux_sym_boolean_token2] = ACTIONS(5609),
    [sym_decimal] = ACTIONS(5609),
    [anon_sym_LPAREN] = ACTIONS(5611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5609),
    [anon_sym_LBRACK] = ACTIONS(5611),
    [aux_sym_record_type_token1] = ACTIONS(5609),
    [aux_sym_basic_type_token21] = ACTIONS(5609),
    [aux_sym_basic_type_token22] = ACTIONS(5609),
    [aux_sym_basic_type_token48] = ACTIONS(5609),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5609),
    [anon_sym_POUNDif] = ACTIONS(5611),
    [anon_sym_POUNDIF] = ACTIONS(5611),
    [anon_sym_POUNDIf] = ACTIONS(5611),
    [anon_sym_not] = ACTIONS(5609),
    [anon_sym_NOT] = ACTIONS(5609),
    [anon_sym_Not] = ACTIONS(5609),
    [anon_sym_POUNDelif] = ACTIONS(5611),
    [anon_sym_POUNDELIF] = ACTIONS(5611),
    [anon_sym_POUNDElif] = ACTIONS(5611),
    [anon_sym_POUNDelse] = ACTIONS(5611),
    [anon_sym_POUNDELSE] = ACTIONS(5611),
    [anon_sym_POUNDElse] = ACTIONS(5611),
    [anon_sym_POUNDelse2] = ACTIONS(5611),
    [anon_sym_POUNDELSE2] = ACTIONS(5611),
    [anon_sym_POUNDElse2] = ACTIONS(5611),
    [anon_sym_POUNDendif] = ACTIONS(5611),
    [anon_sym_POUNDENDIF] = ACTIONS(5611),
    [anon_sym_POUNDEndif] = ACTIONS(5611),
    [anon_sym_POUNDendif2] = ACTIONS(5611),
    [anon_sym_POUNDENDIF2] = ACTIONS(5611),
    [anon_sym_POUNDEndif2] = ACTIONS(5611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5609),
    [anon_sym_PLUS] = ACTIONS(5611),
    [sym_datetime_literal] = ACTIONS(5611),
    [sym_date_literal] = ACTIONS(5609),
    [sym_time_literal] = ACTIONS(5609),
    [sym_biginteger_literal] = ACTIONS(5611),
    [anon_sym_if] = ACTIONS(5609),
    [anon_sym_IF] = ACTIONS(5609),
    [anon_sym_If] = ACTIONS(5609),
    [anon_sym_else] = ACTIONS(5609),
    [anon_sym_ELSE] = ACTIONS(5609),
    [anon_sym_Else] = ACTIONS(5609),
    [anon_sym_case] = ACTIONS(5609),
    [anon_sym_CASE] = ACTIONS(5609),
    [anon_sym_Case] = ACTIONS(5609),
    [anon_sym_for] = ACTIONS(5609),
    [anon_sym_FOR] = ACTIONS(5609),
    [anon_sym_For] = ACTIONS(5609),
    [anon_sym_foreach] = ACTIONS(5609),
    [anon_sym_FOREACH] = ACTIONS(5609),
    [anon_sym_Foreach] = ACTIONS(5609),
    [anon_sym_while] = ACTIONS(5609),
    [anon_sym_WHILE] = ACTIONS(5609),
    [anon_sym_While] = ACTIONS(5609),
    [anon_sym_repeat] = ACTIONS(5609),
    [anon_sym_REPEAT] = ACTIONS(5609),
    [anon_sym_Repeat] = ACTIONS(5609),
    [anon_sym_exit] = ACTIONS(5609),
    [anon_sym_EXIT] = ACTIONS(5609),
    [anon_sym_Exit] = ACTIONS(5609),
    [anon_sym_continue] = ACTIONS(5609),
    [anon_sym_CONTINUE] = ACTIONS(5609),
    [anon_sym_Continue] = ACTIONS(5609),
    [anon_sym_break] = ACTIONS(5609),
    [anon_sym_BREAK] = ACTIONS(5609),
    [anon_sym_Break] = ACTIONS(5609),
    [anon_sym_with] = ACTIONS(5609),
    [anon_sym_WITH] = ACTIONS(5609),
    [anon_sym_With] = ACTIONS(5609),
    [sym_asserterror_keyword] = ACTIONS(5611),
    [sym_page_keyword] = ACTIONS(5609),
    [anon_sym_codeunit] = ACTIONS(5609),
    [anon_sym_CODEUNIT] = ACTIONS(5609),
    [anon_sym_Codeunit] = ACTIONS(5609),
    [anon_sym_CodeUnit] = ACTIONS(5609),
    [anon_sym_COdeunit] = ACTIONS(5609),
    [anon_sym_codeUnit] = ACTIONS(5609),
    [sym_report_keyword] = ACTIONS(5609),
    [sym_query_keyword] = ACTIONS(5609),
    [anon_sym_xmlport] = ACTIONS(5609),
    [anon_sym_XMLPORT] = ACTIONS(5609),
    [anon_sym_Xmlport] = ACTIONS(5609),
    [anon_sym_XMLport] = ACTIONS(5609),
    [anon_sym_XMLPort] = ACTIONS(5609),
    [anon_sym_XmlPort] = ACTIONS(5609),
    [anon_sym_enum] = ACTIONS(5609),
    [anon_sym_ENUM] = ACTIONS(5609),
    [anon_sym_Enum] = ACTIONS(5609),
    [anon_sym_eNUM] = ACTIONS(5609),
    [anon_sym_eNum] = ACTIONS(5609),
    [anon_sym_ENum] = ACTIONS(5609),
    [sym_quoted_identifier] = ACTIONS(5611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5611),
    [sym_verbatim_string] = ACTIONS(5611),
    [sym_integer] = ACTIONS(5609),
    [sym_continue_as_identifier] = ACTIONS(5611),
    [sym_preproc_open] = ACTIONS(5611),
    [sym_preproc_close] = ACTIONS(5611),
  },
  [STATE(2408)] = {
    [sym_identifier] = ACTIONS(5613),
    [anon_sym_SEMI] = ACTIONS(5615),
    [anon_sym_DASH] = ACTIONS(5615),
    [aux_sym_boolean_token1] = ACTIONS(5613),
    [aux_sym_boolean_token2] = ACTIONS(5613),
    [sym_decimal] = ACTIONS(5613),
    [anon_sym_LPAREN] = ACTIONS(5615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5613),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [aux_sym_record_type_token1] = ACTIONS(5613),
    [aux_sym_basic_type_token21] = ACTIONS(5613),
    [aux_sym_basic_type_token22] = ACTIONS(5613),
    [aux_sym_basic_type_token48] = ACTIONS(5613),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5613),
    [anon_sym_POUNDif] = ACTIONS(5615),
    [anon_sym_POUNDIF] = ACTIONS(5615),
    [anon_sym_POUNDIf] = ACTIONS(5615),
    [anon_sym_not] = ACTIONS(5613),
    [anon_sym_NOT] = ACTIONS(5613),
    [anon_sym_Not] = ACTIONS(5613),
    [anon_sym_POUNDelif] = ACTIONS(5615),
    [anon_sym_POUNDELIF] = ACTIONS(5615),
    [anon_sym_POUNDElif] = ACTIONS(5615),
    [anon_sym_POUNDelse] = ACTIONS(5615),
    [anon_sym_POUNDELSE] = ACTIONS(5615),
    [anon_sym_POUNDElse] = ACTIONS(5615),
    [anon_sym_POUNDelse2] = ACTIONS(5615),
    [anon_sym_POUNDELSE2] = ACTIONS(5615),
    [anon_sym_POUNDElse2] = ACTIONS(5615),
    [anon_sym_POUNDendif] = ACTIONS(5615),
    [anon_sym_POUNDENDIF] = ACTIONS(5615),
    [anon_sym_POUNDEndif] = ACTIONS(5615),
    [anon_sym_POUNDendif2] = ACTIONS(5615),
    [anon_sym_POUNDENDIF2] = ACTIONS(5615),
    [anon_sym_POUNDEndif2] = ACTIONS(5615),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5613),
    [anon_sym_PLUS] = ACTIONS(5615),
    [sym_datetime_literal] = ACTIONS(5615),
    [sym_date_literal] = ACTIONS(5613),
    [sym_time_literal] = ACTIONS(5613),
    [sym_biginteger_literal] = ACTIONS(5615),
    [anon_sym_if] = ACTIONS(5613),
    [anon_sym_IF] = ACTIONS(5613),
    [anon_sym_If] = ACTIONS(5613),
    [anon_sym_else] = ACTIONS(5613),
    [anon_sym_ELSE] = ACTIONS(5613),
    [anon_sym_Else] = ACTIONS(5613),
    [anon_sym_case] = ACTIONS(5613),
    [anon_sym_CASE] = ACTIONS(5613),
    [anon_sym_Case] = ACTIONS(5613),
    [anon_sym_for] = ACTIONS(5613),
    [anon_sym_FOR] = ACTIONS(5613),
    [anon_sym_For] = ACTIONS(5613),
    [anon_sym_foreach] = ACTIONS(5613),
    [anon_sym_FOREACH] = ACTIONS(5613),
    [anon_sym_Foreach] = ACTIONS(5613),
    [anon_sym_while] = ACTIONS(5613),
    [anon_sym_WHILE] = ACTIONS(5613),
    [anon_sym_While] = ACTIONS(5613),
    [anon_sym_repeat] = ACTIONS(5613),
    [anon_sym_REPEAT] = ACTIONS(5613),
    [anon_sym_Repeat] = ACTIONS(5613),
    [anon_sym_exit] = ACTIONS(5613),
    [anon_sym_EXIT] = ACTIONS(5613),
    [anon_sym_Exit] = ACTIONS(5613),
    [anon_sym_continue] = ACTIONS(5613),
    [anon_sym_CONTINUE] = ACTIONS(5613),
    [anon_sym_Continue] = ACTIONS(5613),
    [anon_sym_break] = ACTIONS(5613),
    [anon_sym_BREAK] = ACTIONS(5613),
    [anon_sym_Break] = ACTIONS(5613),
    [anon_sym_with] = ACTIONS(5613),
    [anon_sym_WITH] = ACTIONS(5613),
    [anon_sym_With] = ACTIONS(5613),
    [sym_asserterror_keyword] = ACTIONS(5615),
    [sym_page_keyword] = ACTIONS(5613),
    [anon_sym_codeunit] = ACTIONS(5613),
    [anon_sym_CODEUNIT] = ACTIONS(5613),
    [anon_sym_Codeunit] = ACTIONS(5613),
    [anon_sym_CodeUnit] = ACTIONS(5613),
    [anon_sym_COdeunit] = ACTIONS(5613),
    [anon_sym_codeUnit] = ACTIONS(5613),
    [sym_report_keyword] = ACTIONS(5613),
    [sym_query_keyword] = ACTIONS(5613),
    [anon_sym_xmlport] = ACTIONS(5613),
    [anon_sym_XMLPORT] = ACTIONS(5613),
    [anon_sym_Xmlport] = ACTIONS(5613),
    [anon_sym_XMLport] = ACTIONS(5613),
    [anon_sym_XMLPort] = ACTIONS(5613),
    [anon_sym_XmlPort] = ACTIONS(5613),
    [anon_sym_enum] = ACTIONS(5613),
    [anon_sym_ENUM] = ACTIONS(5613),
    [anon_sym_Enum] = ACTIONS(5613),
    [anon_sym_eNUM] = ACTIONS(5613),
    [anon_sym_eNum] = ACTIONS(5613),
    [anon_sym_ENum] = ACTIONS(5613),
    [sym_quoted_identifier] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5615),
    [sym_verbatim_string] = ACTIONS(5615),
    [sym_integer] = ACTIONS(5613),
    [sym_continue_as_identifier] = ACTIONS(5615),
    [sym_preproc_open] = ACTIONS(5615),
    [sym_preproc_close] = ACTIONS(5615),
  },
  [STATE(2409)] = {
    [sym_identifier] = ACTIONS(5617),
    [anon_sym_SEMI] = ACTIONS(5619),
    [anon_sym_DASH] = ACTIONS(5619),
    [aux_sym_boolean_token1] = ACTIONS(5617),
    [aux_sym_boolean_token2] = ACTIONS(5617),
    [sym_decimal] = ACTIONS(5617),
    [anon_sym_LPAREN] = ACTIONS(5619),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5617),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [aux_sym_record_type_token1] = ACTIONS(5617),
    [aux_sym_basic_type_token21] = ACTIONS(5617),
    [aux_sym_basic_type_token22] = ACTIONS(5617),
    [aux_sym_basic_type_token48] = ACTIONS(5617),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5617),
    [anon_sym_POUNDif] = ACTIONS(5619),
    [anon_sym_POUNDIF] = ACTIONS(5619),
    [anon_sym_POUNDIf] = ACTIONS(5619),
    [anon_sym_not] = ACTIONS(5617),
    [anon_sym_NOT] = ACTIONS(5617),
    [anon_sym_Not] = ACTIONS(5617),
    [anon_sym_POUNDelif] = ACTIONS(5619),
    [anon_sym_POUNDELIF] = ACTIONS(5619),
    [anon_sym_POUNDElif] = ACTIONS(5619),
    [anon_sym_POUNDelse] = ACTIONS(5619),
    [anon_sym_POUNDELSE] = ACTIONS(5619),
    [anon_sym_POUNDElse] = ACTIONS(5619),
    [anon_sym_POUNDelse2] = ACTIONS(5619),
    [anon_sym_POUNDELSE2] = ACTIONS(5619),
    [anon_sym_POUNDElse2] = ACTIONS(5619),
    [anon_sym_POUNDendif] = ACTIONS(5619),
    [anon_sym_POUNDENDIF] = ACTIONS(5619),
    [anon_sym_POUNDEndif] = ACTIONS(5619),
    [anon_sym_POUNDendif2] = ACTIONS(5619),
    [anon_sym_POUNDENDIF2] = ACTIONS(5619),
    [anon_sym_POUNDEndif2] = ACTIONS(5619),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5617),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5617),
    [anon_sym_PLUS] = ACTIONS(5619),
    [sym_datetime_literal] = ACTIONS(5619),
    [sym_date_literal] = ACTIONS(5617),
    [sym_time_literal] = ACTIONS(5617),
    [sym_biginteger_literal] = ACTIONS(5619),
    [anon_sym_if] = ACTIONS(5617),
    [anon_sym_IF] = ACTIONS(5617),
    [anon_sym_If] = ACTIONS(5617),
    [anon_sym_else] = ACTIONS(5617),
    [anon_sym_ELSE] = ACTIONS(5617),
    [anon_sym_Else] = ACTIONS(5617),
    [anon_sym_case] = ACTIONS(5617),
    [anon_sym_CASE] = ACTIONS(5617),
    [anon_sym_Case] = ACTIONS(5617),
    [anon_sym_for] = ACTIONS(5617),
    [anon_sym_FOR] = ACTIONS(5617),
    [anon_sym_For] = ACTIONS(5617),
    [anon_sym_foreach] = ACTIONS(5617),
    [anon_sym_FOREACH] = ACTIONS(5617),
    [anon_sym_Foreach] = ACTIONS(5617),
    [anon_sym_while] = ACTIONS(5617),
    [anon_sym_WHILE] = ACTIONS(5617),
    [anon_sym_While] = ACTIONS(5617),
    [anon_sym_repeat] = ACTIONS(5617),
    [anon_sym_REPEAT] = ACTIONS(5617),
    [anon_sym_Repeat] = ACTIONS(5617),
    [anon_sym_exit] = ACTIONS(5617),
    [anon_sym_EXIT] = ACTIONS(5617),
    [anon_sym_Exit] = ACTIONS(5617),
    [anon_sym_continue] = ACTIONS(5617),
    [anon_sym_CONTINUE] = ACTIONS(5617),
    [anon_sym_Continue] = ACTIONS(5617),
    [anon_sym_break] = ACTIONS(5617),
    [anon_sym_BREAK] = ACTIONS(5617),
    [anon_sym_Break] = ACTIONS(5617),
    [anon_sym_with] = ACTIONS(5617),
    [anon_sym_WITH] = ACTIONS(5617),
    [anon_sym_With] = ACTIONS(5617),
    [sym_asserterror_keyword] = ACTIONS(5619),
    [sym_page_keyword] = ACTIONS(5617),
    [anon_sym_codeunit] = ACTIONS(5617),
    [anon_sym_CODEUNIT] = ACTIONS(5617),
    [anon_sym_Codeunit] = ACTIONS(5617),
    [anon_sym_CodeUnit] = ACTIONS(5617),
    [anon_sym_COdeunit] = ACTIONS(5617),
    [anon_sym_codeUnit] = ACTIONS(5617),
    [sym_report_keyword] = ACTIONS(5617),
    [sym_query_keyword] = ACTIONS(5617),
    [anon_sym_xmlport] = ACTIONS(5617),
    [anon_sym_XMLPORT] = ACTIONS(5617),
    [anon_sym_Xmlport] = ACTIONS(5617),
    [anon_sym_XMLport] = ACTIONS(5617),
    [anon_sym_XMLPort] = ACTIONS(5617),
    [anon_sym_XmlPort] = ACTIONS(5617),
    [anon_sym_enum] = ACTIONS(5617),
    [anon_sym_ENUM] = ACTIONS(5617),
    [anon_sym_Enum] = ACTIONS(5617),
    [anon_sym_eNUM] = ACTIONS(5617),
    [anon_sym_eNum] = ACTIONS(5617),
    [anon_sym_ENum] = ACTIONS(5617),
    [sym_quoted_identifier] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5619),
    [sym_verbatim_string] = ACTIONS(5619),
    [sym_integer] = ACTIONS(5617),
    [sym_continue_as_identifier] = ACTIONS(5619),
    [sym_preproc_open] = ACTIONS(5619),
    [sym_preproc_close] = ACTIONS(5619),
  },
  [STATE(2410)] = {
    [sym_identifier] = ACTIONS(5621),
    [anon_sym_SEMI] = ACTIONS(5623),
    [anon_sym_DASH] = ACTIONS(5623),
    [aux_sym_boolean_token1] = ACTIONS(5621),
    [aux_sym_boolean_token2] = ACTIONS(5621),
    [sym_decimal] = ACTIONS(5621),
    [anon_sym_LPAREN] = ACTIONS(5623),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5621),
    [anon_sym_LBRACK] = ACTIONS(5623),
    [aux_sym_record_type_token1] = ACTIONS(5621),
    [aux_sym_basic_type_token21] = ACTIONS(5621),
    [aux_sym_basic_type_token22] = ACTIONS(5621),
    [aux_sym_basic_type_token48] = ACTIONS(5621),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5621),
    [anon_sym_POUNDif] = ACTIONS(5623),
    [anon_sym_POUNDIF] = ACTIONS(5623),
    [anon_sym_POUNDIf] = ACTIONS(5623),
    [anon_sym_not] = ACTIONS(5621),
    [anon_sym_NOT] = ACTIONS(5621),
    [anon_sym_Not] = ACTIONS(5621),
    [anon_sym_POUNDelif] = ACTIONS(5623),
    [anon_sym_POUNDELIF] = ACTIONS(5623),
    [anon_sym_POUNDElif] = ACTIONS(5623),
    [anon_sym_POUNDelse] = ACTIONS(5623),
    [anon_sym_POUNDELSE] = ACTIONS(5623),
    [anon_sym_POUNDElse] = ACTIONS(5623),
    [anon_sym_POUNDelse2] = ACTIONS(5623),
    [anon_sym_POUNDELSE2] = ACTIONS(5623),
    [anon_sym_POUNDElse2] = ACTIONS(5623),
    [anon_sym_POUNDendif] = ACTIONS(5623),
    [anon_sym_POUNDENDIF] = ACTIONS(5623),
    [anon_sym_POUNDEndif] = ACTIONS(5623),
    [anon_sym_POUNDendif2] = ACTIONS(5623),
    [anon_sym_POUNDENDIF2] = ACTIONS(5623),
    [anon_sym_POUNDEndif2] = ACTIONS(5623),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5621),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5621),
    [anon_sym_PLUS] = ACTIONS(5623),
    [sym_datetime_literal] = ACTIONS(5623),
    [sym_date_literal] = ACTIONS(5621),
    [sym_time_literal] = ACTIONS(5621),
    [sym_biginteger_literal] = ACTIONS(5623),
    [anon_sym_if] = ACTIONS(5621),
    [anon_sym_IF] = ACTIONS(5621),
    [anon_sym_If] = ACTIONS(5621),
    [anon_sym_else] = ACTIONS(5621),
    [anon_sym_ELSE] = ACTIONS(5621),
    [anon_sym_Else] = ACTIONS(5621),
    [anon_sym_case] = ACTIONS(5621),
    [anon_sym_CASE] = ACTIONS(5621),
    [anon_sym_Case] = ACTIONS(5621),
    [anon_sym_for] = ACTIONS(5621),
    [anon_sym_FOR] = ACTIONS(5621),
    [anon_sym_For] = ACTIONS(5621),
    [anon_sym_foreach] = ACTIONS(5621),
    [anon_sym_FOREACH] = ACTIONS(5621),
    [anon_sym_Foreach] = ACTIONS(5621),
    [anon_sym_while] = ACTIONS(5621),
    [anon_sym_WHILE] = ACTIONS(5621),
    [anon_sym_While] = ACTIONS(5621),
    [anon_sym_repeat] = ACTIONS(5621),
    [anon_sym_REPEAT] = ACTIONS(5621),
    [anon_sym_Repeat] = ACTIONS(5621),
    [anon_sym_exit] = ACTIONS(5621),
    [anon_sym_EXIT] = ACTIONS(5621),
    [anon_sym_Exit] = ACTIONS(5621),
    [anon_sym_continue] = ACTIONS(5621),
    [anon_sym_CONTINUE] = ACTIONS(5621),
    [anon_sym_Continue] = ACTIONS(5621),
    [anon_sym_break] = ACTIONS(5621),
    [anon_sym_BREAK] = ACTIONS(5621),
    [anon_sym_Break] = ACTIONS(5621),
    [anon_sym_with] = ACTIONS(5621),
    [anon_sym_WITH] = ACTIONS(5621),
    [anon_sym_With] = ACTIONS(5621),
    [sym_asserterror_keyword] = ACTIONS(5623),
    [sym_page_keyword] = ACTIONS(5621),
    [anon_sym_codeunit] = ACTIONS(5621),
    [anon_sym_CODEUNIT] = ACTIONS(5621),
    [anon_sym_Codeunit] = ACTIONS(5621),
    [anon_sym_CodeUnit] = ACTIONS(5621),
    [anon_sym_COdeunit] = ACTIONS(5621),
    [anon_sym_codeUnit] = ACTIONS(5621),
    [sym_report_keyword] = ACTIONS(5621),
    [sym_query_keyword] = ACTIONS(5621),
    [anon_sym_xmlport] = ACTIONS(5621),
    [anon_sym_XMLPORT] = ACTIONS(5621),
    [anon_sym_Xmlport] = ACTIONS(5621),
    [anon_sym_XMLport] = ACTIONS(5621),
    [anon_sym_XMLPort] = ACTIONS(5621),
    [anon_sym_XmlPort] = ACTIONS(5621),
    [anon_sym_enum] = ACTIONS(5621),
    [anon_sym_ENUM] = ACTIONS(5621),
    [anon_sym_Enum] = ACTIONS(5621),
    [anon_sym_eNUM] = ACTIONS(5621),
    [anon_sym_eNum] = ACTIONS(5621),
    [anon_sym_ENum] = ACTIONS(5621),
    [sym_quoted_identifier] = ACTIONS(5623),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5623),
    [sym_verbatim_string] = ACTIONS(5623),
    [sym_integer] = ACTIONS(5621),
    [sym_continue_as_identifier] = ACTIONS(5623),
    [sym_preproc_open] = ACTIONS(5623),
    [sym_preproc_close] = ACTIONS(5623),
  },
  [STATE(2411)] = {
    [sym_identifier] = ACTIONS(5625),
    [anon_sym_SEMI] = ACTIONS(5627),
    [anon_sym_DASH] = ACTIONS(5627),
    [aux_sym_boolean_token1] = ACTIONS(5625),
    [aux_sym_boolean_token2] = ACTIONS(5625),
    [sym_decimal] = ACTIONS(5625),
    [anon_sym_LPAREN] = ACTIONS(5627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5625),
    [anon_sym_LBRACK] = ACTIONS(5627),
    [aux_sym_record_type_token1] = ACTIONS(5625),
    [aux_sym_basic_type_token21] = ACTIONS(5625),
    [aux_sym_basic_type_token22] = ACTIONS(5625),
    [aux_sym_basic_type_token48] = ACTIONS(5625),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5625),
    [anon_sym_POUNDif] = ACTIONS(5627),
    [anon_sym_POUNDIF] = ACTIONS(5627),
    [anon_sym_POUNDIf] = ACTIONS(5627),
    [anon_sym_not] = ACTIONS(5625),
    [anon_sym_NOT] = ACTIONS(5625),
    [anon_sym_Not] = ACTIONS(5625),
    [anon_sym_POUNDelif] = ACTIONS(5627),
    [anon_sym_POUNDELIF] = ACTIONS(5627),
    [anon_sym_POUNDElif] = ACTIONS(5627),
    [anon_sym_POUNDelse] = ACTIONS(5627),
    [anon_sym_POUNDELSE] = ACTIONS(5627),
    [anon_sym_POUNDElse] = ACTIONS(5627),
    [anon_sym_POUNDelse2] = ACTIONS(5627),
    [anon_sym_POUNDELSE2] = ACTIONS(5627),
    [anon_sym_POUNDElse2] = ACTIONS(5627),
    [anon_sym_POUNDendif] = ACTIONS(5627),
    [anon_sym_POUNDENDIF] = ACTIONS(5627),
    [anon_sym_POUNDEndif] = ACTIONS(5627),
    [anon_sym_POUNDendif2] = ACTIONS(5627),
    [anon_sym_POUNDENDIF2] = ACTIONS(5627),
    [anon_sym_POUNDEndif2] = ACTIONS(5627),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5625),
    [anon_sym_PLUS] = ACTIONS(5627),
    [sym_datetime_literal] = ACTIONS(5627),
    [sym_date_literal] = ACTIONS(5625),
    [sym_time_literal] = ACTIONS(5625),
    [sym_biginteger_literal] = ACTIONS(5627),
    [anon_sym_if] = ACTIONS(5625),
    [anon_sym_IF] = ACTIONS(5625),
    [anon_sym_If] = ACTIONS(5625),
    [anon_sym_else] = ACTIONS(5625),
    [anon_sym_ELSE] = ACTIONS(5625),
    [anon_sym_Else] = ACTIONS(5625),
    [anon_sym_case] = ACTIONS(5625),
    [anon_sym_CASE] = ACTIONS(5625),
    [anon_sym_Case] = ACTIONS(5625),
    [anon_sym_for] = ACTIONS(5625),
    [anon_sym_FOR] = ACTIONS(5625),
    [anon_sym_For] = ACTIONS(5625),
    [anon_sym_foreach] = ACTIONS(5625),
    [anon_sym_FOREACH] = ACTIONS(5625),
    [anon_sym_Foreach] = ACTIONS(5625),
    [anon_sym_while] = ACTIONS(5625),
    [anon_sym_WHILE] = ACTIONS(5625),
    [anon_sym_While] = ACTIONS(5625),
    [anon_sym_repeat] = ACTIONS(5625),
    [anon_sym_REPEAT] = ACTIONS(5625),
    [anon_sym_Repeat] = ACTIONS(5625),
    [anon_sym_exit] = ACTIONS(5625),
    [anon_sym_EXIT] = ACTIONS(5625),
    [anon_sym_Exit] = ACTIONS(5625),
    [anon_sym_continue] = ACTIONS(5625),
    [anon_sym_CONTINUE] = ACTIONS(5625),
    [anon_sym_Continue] = ACTIONS(5625),
    [anon_sym_break] = ACTIONS(5625),
    [anon_sym_BREAK] = ACTIONS(5625),
    [anon_sym_Break] = ACTIONS(5625),
    [anon_sym_with] = ACTIONS(5625),
    [anon_sym_WITH] = ACTIONS(5625),
    [anon_sym_With] = ACTIONS(5625),
    [sym_asserterror_keyword] = ACTIONS(5627),
    [sym_page_keyword] = ACTIONS(5625),
    [anon_sym_codeunit] = ACTIONS(5625),
    [anon_sym_CODEUNIT] = ACTIONS(5625),
    [anon_sym_Codeunit] = ACTIONS(5625),
    [anon_sym_CodeUnit] = ACTIONS(5625),
    [anon_sym_COdeunit] = ACTIONS(5625),
    [anon_sym_codeUnit] = ACTIONS(5625),
    [sym_report_keyword] = ACTIONS(5625),
    [sym_query_keyword] = ACTIONS(5625),
    [anon_sym_xmlport] = ACTIONS(5625),
    [anon_sym_XMLPORT] = ACTIONS(5625),
    [anon_sym_Xmlport] = ACTIONS(5625),
    [anon_sym_XMLport] = ACTIONS(5625),
    [anon_sym_XMLPort] = ACTIONS(5625),
    [anon_sym_XmlPort] = ACTIONS(5625),
    [anon_sym_enum] = ACTIONS(5625),
    [anon_sym_ENUM] = ACTIONS(5625),
    [anon_sym_Enum] = ACTIONS(5625),
    [anon_sym_eNUM] = ACTIONS(5625),
    [anon_sym_eNum] = ACTIONS(5625),
    [anon_sym_ENum] = ACTIONS(5625),
    [sym_quoted_identifier] = ACTIONS(5627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5627),
    [sym_verbatim_string] = ACTIONS(5627),
    [sym_integer] = ACTIONS(5625),
    [sym_continue_as_identifier] = ACTIONS(5627),
    [sym_preproc_open] = ACTIONS(5627),
    [sym_preproc_close] = ACTIONS(5627),
  },
  [STATE(2412)] = {
    [sym_identifier] = ACTIONS(5629),
    [anon_sym_SEMI] = ACTIONS(5631),
    [anon_sym_DASH] = ACTIONS(5631),
    [aux_sym_boolean_token1] = ACTIONS(5629),
    [aux_sym_boolean_token2] = ACTIONS(5629),
    [sym_decimal] = ACTIONS(5629),
    [anon_sym_LPAREN] = ACTIONS(5631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5629),
    [anon_sym_LBRACK] = ACTIONS(5631),
    [aux_sym_record_type_token1] = ACTIONS(5629),
    [aux_sym_basic_type_token21] = ACTIONS(5629),
    [aux_sym_basic_type_token22] = ACTIONS(5629),
    [aux_sym_basic_type_token48] = ACTIONS(5629),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5629),
    [anon_sym_POUNDif] = ACTIONS(5631),
    [anon_sym_POUNDIF] = ACTIONS(5631),
    [anon_sym_POUNDIf] = ACTIONS(5631),
    [anon_sym_not] = ACTIONS(5629),
    [anon_sym_NOT] = ACTIONS(5629),
    [anon_sym_Not] = ACTIONS(5629),
    [anon_sym_POUNDelif] = ACTIONS(5631),
    [anon_sym_POUNDELIF] = ACTIONS(5631),
    [anon_sym_POUNDElif] = ACTIONS(5631),
    [anon_sym_POUNDelse] = ACTIONS(5631),
    [anon_sym_POUNDELSE] = ACTIONS(5631),
    [anon_sym_POUNDElse] = ACTIONS(5631),
    [anon_sym_POUNDelse2] = ACTIONS(5631),
    [anon_sym_POUNDELSE2] = ACTIONS(5631),
    [anon_sym_POUNDElse2] = ACTIONS(5631),
    [anon_sym_POUNDendif] = ACTIONS(5631),
    [anon_sym_POUNDENDIF] = ACTIONS(5631),
    [anon_sym_POUNDEndif] = ACTIONS(5631),
    [anon_sym_POUNDendif2] = ACTIONS(5631),
    [anon_sym_POUNDENDIF2] = ACTIONS(5631),
    [anon_sym_POUNDEndif2] = ACTIONS(5631),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5629),
    [anon_sym_PLUS] = ACTIONS(5631),
    [sym_datetime_literal] = ACTIONS(5631),
    [sym_date_literal] = ACTIONS(5629),
    [sym_time_literal] = ACTIONS(5629),
    [sym_biginteger_literal] = ACTIONS(5631),
    [anon_sym_if] = ACTIONS(5629),
    [anon_sym_IF] = ACTIONS(5629),
    [anon_sym_If] = ACTIONS(5629),
    [anon_sym_else] = ACTIONS(5629),
    [anon_sym_ELSE] = ACTIONS(5629),
    [anon_sym_Else] = ACTIONS(5629),
    [anon_sym_case] = ACTIONS(5629),
    [anon_sym_CASE] = ACTIONS(5629),
    [anon_sym_Case] = ACTIONS(5629),
    [anon_sym_for] = ACTIONS(5629),
    [anon_sym_FOR] = ACTIONS(5629),
    [anon_sym_For] = ACTIONS(5629),
    [anon_sym_foreach] = ACTIONS(5629),
    [anon_sym_FOREACH] = ACTIONS(5629),
    [anon_sym_Foreach] = ACTIONS(5629),
    [anon_sym_while] = ACTIONS(5629),
    [anon_sym_WHILE] = ACTIONS(5629),
    [anon_sym_While] = ACTIONS(5629),
    [anon_sym_repeat] = ACTIONS(5629),
    [anon_sym_REPEAT] = ACTIONS(5629),
    [anon_sym_Repeat] = ACTIONS(5629),
    [anon_sym_exit] = ACTIONS(5629),
    [anon_sym_EXIT] = ACTIONS(5629),
    [anon_sym_Exit] = ACTIONS(5629),
    [anon_sym_continue] = ACTIONS(5629),
    [anon_sym_CONTINUE] = ACTIONS(5629),
    [anon_sym_Continue] = ACTIONS(5629),
    [anon_sym_break] = ACTIONS(5629),
    [anon_sym_BREAK] = ACTIONS(5629),
    [anon_sym_Break] = ACTIONS(5629),
    [anon_sym_with] = ACTIONS(5629),
    [anon_sym_WITH] = ACTIONS(5629),
    [anon_sym_With] = ACTIONS(5629),
    [sym_asserterror_keyword] = ACTIONS(5631),
    [sym_page_keyword] = ACTIONS(5629),
    [anon_sym_codeunit] = ACTIONS(5629),
    [anon_sym_CODEUNIT] = ACTIONS(5629),
    [anon_sym_Codeunit] = ACTIONS(5629),
    [anon_sym_CodeUnit] = ACTIONS(5629),
    [anon_sym_COdeunit] = ACTIONS(5629),
    [anon_sym_codeUnit] = ACTIONS(5629),
    [sym_report_keyword] = ACTIONS(5629),
    [sym_query_keyword] = ACTIONS(5629),
    [anon_sym_xmlport] = ACTIONS(5629),
    [anon_sym_XMLPORT] = ACTIONS(5629),
    [anon_sym_Xmlport] = ACTIONS(5629),
    [anon_sym_XMLport] = ACTIONS(5629),
    [anon_sym_XMLPort] = ACTIONS(5629),
    [anon_sym_XmlPort] = ACTIONS(5629),
    [anon_sym_enum] = ACTIONS(5629),
    [anon_sym_ENUM] = ACTIONS(5629),
    [anon_sym_Enum] = ACTIONS(5629),
    [anon_sym_eNUM] = ACTIONS(5629),
    [anon_sym_eNum] = ACTIONS(5629),
    [anon_sym_ENum] = ACTIONS(5629),
    [sym_quoted_identifier] = ACTIONS(5631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5631),
    [sym_verbatim_string] = ACTIONS(5631),
    [sym_integer] = ACTIONS(5629),
    [sym_continue_as_identifier] = ACTIONS(5631),
    [sym_preproc_open] = ACTIONS(5631),
    [sym_preproc_close] = ACTIONS(5631),
  },
  [STATE(2413)] = {
    [sym_identifier] = ACTIONS(5633),
    [anon_sym_SEMI] = ACTIONS(5635),
    [anon_sym_DASH] = ACTIONS(5635),
    [aux_sym_boolean_token1] = ACTIONS(5633),
    [aux_sym_boolean_token2] = ACTIONS(5633),
    [sym_decimal] = ACTIONS(5633),
    [anon_sym_LPAREN] = ACTIONS(5635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5633),
    [anon_sym_LBRACK] = ACTIONS(5635),
    [aux_sym_record_type_token1] = ACTIONS(5633),
    [aux_sym_basic_type_token21] = ACTIONS(5633),
    [aux_sym_basic_type_token22] = ACTIONS(5633),
    [aux_sym_basic_type_token48] = ACTIONS(5633),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5633),
    [anon_sym_POUNDif] = ACTIONS(5635),
    [anon_sym_POUNDIF] = ACTIONS(5635),
    [anon_sym_POUNDIf] = ACTIONS(5635),
    [anon_sym_not] = ACTIONS(5633),
    [anon_sym_NOT] = ACTIONS(5633),
    [anon_sym_Not] = ACTIONS(5633),
    [anon_sym_POUNDelif] = ACTIONS(5635),
    [anon_sym_POUNDELIF] = ACTIONS(5635),
    [anon_sym_POUNDElif] = ACTIONS(5635),
    [anon_sym_POUNDelse] = ACTIONS(5635),
    [anon_sym_POUNDELSE] = ACTIONS(5635),
    [anon_sym_POUNDElse] = ACTIONS(5635),
    [anon_sym_POUNDelse2] = ACTIONS(5635),
    [anon_sym_POUNDELSE2] = ACTIONS(5635),
    [anon_sym_POUNDElse2] = ACTIONS(5635),
    [anon_sym_POUNDendif] = ACTIONS(5635),
    [anon_sym_POUNDENDIF] = ACTIONS(5635),
    [anon_sym_POUNDEndif] = ACTIONS(5635),
    [anon_sym_POUNDendif2] = ACTIONS(5635),
    [anon_sym_POUNDENDIF2] = ACTIONS(5635),
    [anon_sym_POUNDEndif2] = ACTIONS(5635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5633),
    [anon_sym_PLUS] = ACTIONS(5635),
    [sym_datetime_literal] = ACTIONS(5635),
    [sym_date_literal] = ACTIONS(5633),
    [sym_time_literal] = ACTIONS(5633),
    [sym_biginteger_literal] = ACTIONS(5635),
    [anon_sym_if] = ACTIONS(5633),
    [anon_sym_IF] = ACTIONS(5633),
    [anon_sym_If] = ACTIONS(5633),
    [anon_sym_else] = ACTIONS(5633),
    [anon_sym_ELSE] = ACTIONS(5633),
    [anon_sym_Else] = ACTIONS(5633),
    [anon_sym_case] = ACTIONS(5633),
    [anon_sym_CASE] = ACTIONS(5633),
    [anon_sym_Case] = ACTIONS(5633),
    [anon_sym_for] = ACTIONS(5633),
    [anon_sym_FOR] = ACTIONS(5633),
    [anon_sym_For] = ACTIONS(5633),
    [anon_sym_foreach] = ACTIONS(5633),
    [anon_sym_FOREACH] = ACTIONS(5633),
    [anon_sym_Foreach] = ACTIONS(5633),
    [anon_sym_while] = ACTIONS(5633),
    [anon_sym_WHILE] = ACTIONS(5633),
    [anon_sym_While] = ACTIONS(5633),
    [anon_sym_repeat] = ACTIONS(5633),
    [anon_sym_REPEAT] = ACTIONS(5633),
    [anon_sym_Repeat] = ACTIONS(5633),
    [anon_sym_exit] = ACTIONS(5633),
    [anon_sym_EXIT] = ACTIONS(5633),
    [anon_sym_Exit] = ACTIONS(5633),
    [anon_sym_continue] = ACTIONS(5633),
    [anon_sym_CONTINUE] = ACTIONS(5633),
    [anon_sym_Continue] = ACTIONS(5633),
    [anon_sym_break] = ACTIONS(5633),
    [anon_sym_BREAK] = ACTIONS(5633),
    [anon_sym_Break] = ACTIONS(5633),
    [anon_sym_with] = ACTIONS(5633),
    [anon_sym_WITH] = ACTIONS(5633),
    [anon_sym_With] = ACTIONS(5633),
    [sym_asserterror_keyword] = ACTIONS(5635),
    [sym_page_keyword] = ACTIONS(5633),
    [anon_sym_codeunit] = ACTIONS(5633),
    [anon_sym_CODEUNIT] = ACTIONS(5633),
    [anon_sym_Codeunit] = ACTIONS(5633),
    [anon_sym_CodeUnit] = ACTIONS(5633),
    [anon_sym_COdeunit] = ACTIONS(5633),
    [anon_sym_codeUnit] = ACTIONS(5633),
    [sym_report_keyword] = ACTIONS(5633),
    [sym_query_keyword] = ACTIONS(5633),
    [anon_sym_xmlport] = ACTIONS(5633),
    [anon_sym_XMLPORT] = ACTIONS(5633),
    [anon_sym_Xmlport] = ACTIONS(5633),
    [anon_sym_XMLport] = ACTIONS(5633),
    [anon_sym_XMLPort] = ACTIONS(5633),
    [anon_sym_XmlPort] = ACTIONS(5633),
    [anon_sym_enum] = ACTIONS(5633),
    [anon_sym_ENUM] = ACTIONS(5633),
    [anon_sym_Enum] = ACTIONS(5633),
    [anon_sym_eNUM] = ACTIONS(5633),
    [anon_sym_eNum] = ACTIONS(5633),
    [anon_sym_ENum] = ACTIONS(5633),
    [sym_quoted_identifier] = ACTIONS(5635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5635),
    [sym_verbatim_string] = ACTIONS(5635),
    [sym_integer] = ACTIONS(5633),
    [sym_continue_as_identifier] = ACTIONS(5635),
    [sym_preproc_open] = ACTIONS(5635),
    [sym_preproc_close] = ACTIONS(5635),
  },
  [STATE(2414)] = {
    [sym_identifier] = ACTIONS(5637),
    [anon_sym_SEMI] = ACTIONS(5639),
    [anon_sym_DASH] = ACTIONS(5639),
    [aux_sym_boolean_token1] = ACTIONS(5637),
    [aux_sym_boolean_token2] = ACTIONS(5637),
    [sym_decimal] = ACTIONS(5637),
    [anon_sym_LPAREN] = ACTIONS(5639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5637),
    [anon_sym_LBRACK] = ACTIONS(5639),
    [aux_sym_record_type_token1] = ACTIONS(5637),
    [aux_sym_basic_type_token21] = ACTIONS(5637),
    [aux_sym_basic_type_token22] = ACTIONS(5637),
    [aux_sym_basic_type_token48] = ACTIONS(5637),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5637),
    [anon_sym_POUNDif] = ACTIONS(5639),
    [anon_sym_POUNDIF] = ACTIONS(5639),
    [anon_sym_POUNDIf] = ACTIONS(5639),
    [anon_sym_not] = ACTIONS(5637),
    [anon_sym_NOT] = ACTIONS(5637),
    [anon_sym_Not] = ACTIONS(5637),
    [anon_sym_POUNDelif] = ACTIONS(5639),
    [anon_sym_POUNDELIF] = ACTIONS(5639),
    [anon_sym_POUNDElif] = ACTIONS(5639),
    [anon_sym_POUNDelse] = ACTIONS(5639),
    [anon_sym_POUNDELSE] = ACTIONS(5639),
    [anon_sym_POUNDElse] = ACTIONS(5639),
    [anon_sym_POUNDelse2] = ACTIONS(5639),
    [anon_sym_POUNDELSE2] = ACTIONS(5639),
    [anon_sym_POUNDElse2] = ACTIONS(5639),
    [anon_sym_POUNDendif] = ACTIONS(5639),
    [anon_sym_POUNDENDIF] = ACTIONS(5639),
    [anon_sym_POUNDEndif] = ACTIONS(5639),
    [anon_sym_POUNDendif2] = ACTIONS(5639),
    [anon_sym_POUNDENDIF2] = ACTIONS(5639),
    [anon_sym_POUNDEndif2] = ACTIONS(5639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5637),
    [anon_sym_PLUS] = ACTIONS(5639),
    [sym_datetime_literal] = ACTIONS(5639),
    [sym_date_literal] = ACTIONS(5637),
    [sym_time_literal] = ACTIONS(5637),
    [sym_biginteger_literal] = ACTIONS(5639),
    [anon_sym_if] = ACTIONS(5637),
    [anon_sym_IF] = ACTIONS(5637),
    [anon_sym_If] = ACTIONS(5637),
    [anon_sym_else] = ACTIONS(5637),
    [anon_sym_ELSE] = ACTIONS(5637),
    [anon_sym_Else] = ACTIONS(5637),
    [anon_sym_case] = ACTIONS(5637),
    [anon_sym_CASE] = ACTIONS(5637),
    [anon_sym_Case] = ACTIONS(5637),
    [anon_sym_for] = ACTIONS(5637),
    [anon_sym_FOR] = ACTIONS(5637),
    [anon_sym_For] = ACTIONS(5637),
    [anon_sym_foreach] = ACTIONS(5637),
    [anon_sym_FOREACH] = ACTIONS(5637),
    [anon_sym_Foreach] = ACTIONS(5637),
    [anon_sym_while] = ACTIONS(5637),
    [anon_sym_WHILE] = ACTIONS(5637),
    [anon_sym_While] = ACTIONS(5637),
    [anon_sym_repeat] = ACTIONS(5637),
    [anon_sym_REPEAT] = ACTIONS(5637),
    [anon_sym_Repeat] = ACTIONS(5637),
    [anon_sym_exit] = ACTIONS(5637),
    [anon_sym_EXIT] = ACTIONS(5637),
    [anon_sym_Exit] = ACTIONS(5637),
    [anon_sym_continue] = ACTIONS(5637),
    [anon_sym_CONTINUE] = ACTIONS(5637),
    [anon_sym_Continue] = ACTIONS(5637),
    [anon_sym_break] = ACTIONS(5637),
    [anon_sym_BREAK] = ACTIONS(5637),
    [anon_sym_Break] = ACTIONS(5637),
    [anon_sym_with] = ACTIONS(5637),
    [anon_sym_WITH] = ACTIONS(5637),
    [anon_sym_With] = ACTIONS(5637),
    [sym_asserterror_keyword] = ACTIONS(5639),
    [sym_page_keyword] = ACTIONS(5637),
    [anon_sym_codeunit] = ACTIONS(5637),
    [anon_sym_CODEUNIT] = ACTIONS(5637),
    [anon_sym_Codeunit] = ACTIONS(5637),
    [anon_sym_CodeUnit] = ACTIONS(5637),
    [anon_sym_COdeunit] = ACTIONS(5637),
    [anon_sym_codeUnit] = ACTIONS(5637),
    [sym_report_keyword] = ACTIONS(5637),
    [sym_query_keyword] = ACTIONS(5637),
    [anon_sym_xmlport] = ACTIONS(5637),
    [anon_sym_XMLPORT] = ACTIONS(5637),
    [anon_sym_Xmlport] = ACTIONS(5637),
    [anon_sym_XMLport] = ACTIONS(5637),
    [anon_sym_XMLPort] = ACTIONS(5637),
    [anon_sym_XmlPort] = ACTIONS(5637),
    [anon_sym_enum] = ACTIONS(5637),
    [anon_sym_ENUM] = ACTIONS(5637),
    [anon_sym_Enum] = ACTIONS(5637),
    [anon_sym_eNUM] = ACTIONS(5637),
    [anon_sym_eNum] = ACTIONS(5637),
    [anon_sym_ENum] = ACTIONS(5637),
    [sym_quoted_identifier] = ACTIONS(5639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5639),
    [sym_verbatim_string] = ACTIONS(5639),
    [sym_integer] = ACTIONS(5637),
    [sym_continue_as_identifier] = ACTIONS(5639),
    [sym_preproc_open] = ACTIONS(5639),
    [sym_preproc_close] = ACTIONS(5639),
  },
  [STATE(2415)] = {
    [sym_identifier] = ACTIONS(5641),
    [anon_sym_SEMI] = ACTIONS(5643),
    [anon_sym_DASH] = ACTIONS(5643),
    [aux_sym_boolean_token1] = ACTIONS(5641),
    [aux_sym_boolean_token2] = ACTIONS(5641),
    [sym_decimal] = ACTIONS(5641),
    [anon_sym_LPAREN] = ACTIONS(5643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5641),
    [anon_sym_LBRACK] = ACTIONS(5643),
    [aux_sym_record_type_token1] = ACTIONS(5641),
    [aux_sym_basic_type_token21] = ACTIONS(5641),
    [aux_sym_basic_type_token22] = ACTIONS(5641),
    [aux_sym_basic_type_token48] = ACTIONS(5641),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5641),
    [anon_sym_POUNDif] = ACTIONS(5643),
    [anon_sym_POUNDIF] = ACTIONS(5643),
    [anon_sym_POUNDIf] = ACTIONS(5643),
    [anon_sym_not] = ACTIONS(5641),
    [anon_sym_NOT] = ACTIONS(5641),
    [anon_sym_Not] = ACTIONS(5641),
    [anon_sym_POUNDelif] = ACTIONS(5643),
    [anon_sym_POUNDELIF] = ACTIONS(5643),
    [anon_sym_POUNDElif] = ACTIONS(5643),
    [anon_sym_POUNDelse] = ACTIONS(5643),
    [anon_sym_POUNDELSE] = ACTIONS(5643),
    [anon_sym_POUNDElse] = ACTIONS(5643),
    [anon_sym_POUNDelse2] = ACTIONS(5643),
    [anon_sym_POUNDELSE2] = ACTIONS(5643),
    [anon_sym_POUNDElse2] = ACTIONS(5643),
    [anon_sym_POUNDendif] = ACTIONS(5643),
    [anon_sym_POUNDENDIF] = ACTIONS(5643),
    [anon_sym_POUNDEndif] = ACTIONS(5643),
    [anon_sym_POUNDendif2] = ACTIONS(5643),
    [anon_sym_POUNDENDIF2] = ACTIONS(5643),
    [anon_sym_POUNDEndif2] = ACTIONS(5643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5641),
    [anon_sym_PLUS] = ACTIONS(5643),
    [sym_datetime_literal] = ACTIONS(5643),
    [sym_date_literal] = ACTIONS(5641),
    [sym_time_literal] = ACTIONS(5641),
    [sym_biginteger_literal] = ACTIONS(5643),
    [anon_sym_if] = ACTIONS(5641),
    [anon_sym_IF] = ACTIONS(5641),
    [anon_sym_If] = ACTIONS(5641),
    [anon_sym_else] = ACTIONS(5641),
    [anon_sym_ELSE] = ACTIONS(5641),
    [anon_sym_Else] = ACTIONS(5641),
    [anon_sym_case] = ACTIONS(5641),
    [anon_sym_CASE] = ACTIONS(5641),
    [anon_sym_Case] = ACTIONS(5641),
    [anon_sym_for] = ACTIONS(5641),
    [anon_sym_FOR] = ACTIONS(5641),
    [anon_sym_For] = ACTIONS(5641),
    [anon_sym_foreach] = ACTIONS(5641),
    [anon_sym_FOREACH] = ACTIONS(5641),
    [anon_sym_Foreach] = ACTIONS(5641),
    [anon_sym_while] = ACTIONS(5641),
    [anon_sym_WHILE] = ACTIONS(5641),
    [anon_sym_While] = ACTIONS(5641),
    [anon_sym_repeat] = ACTIONS(5641),
    [anon_sym_REPEAT] = ACTIONS(5641),
    [anon_sym_Repeat] = ACTIONS(5641),
    [anon_sym_exit] = ACTIONS(5641),
    [anon_sym_EXIT] = ACTIONS(5641),
    [anon_sym_Exit] = ACTIONS(5641),
    [anon_sym_continue] = ACTIONS(5641),
    [anon_sym_CONTINUE] = ACTIONS(5641),
    [anon_sym_Continue] = ACTIONS(5641),
    [anon_sym_break] = ACTIONS(5641),
    [anon_sym_BREAK] = ACTIONS(5641),
    [anon_sym_Break] = ACTIONS(5641),
    [anon_sym_with] = ACTIONS(5641),
    [anon_sym_WITH] = ACTIONS(5641),
    [anon_sym_With] = ACTIONS(5641),
    [sym_asserterror_keyword] = ACTIONS(5643),
    [sym_page_keyword] = ACTIONS(5641),
    [anon_sym_codeunit] = ACTIONS(5641),
    [anon_sym_CODEUNIT] = ACTIONS(5641),
    [anon_sym_Codeunit] = ACTIONS(5641),
    [anon_sym_CodeUnit] = ACTIONS(5641),
    [anon_sym_COdeunit] = ACTIONS(5641),
    [anon_sym_codeUnit] = ACTIONS(5641),
    [sym_report_keyword] = ACTIONS(5641),
    [sym_query_keyword] = ACTIONS(5641),
    [anon_sym_xmlport] = ACTIONS(5641),
    [anon_sym_XMLPORT] = ACTIONS(5641),
    [anon_sym_Xmlport] = ACTIONS(5641),
    [anon_sym_XMLport] = ACTIONS(5641),
    [anon_sym_XMLPort] = ACTIONS(5641),
    [anon_sym_XmlPort] = ACTIONS(5641),
    [anon_sym_enum] = ACTIONS(5641),
    [anon_sym_ENUM] = ACTIONS(5641),
    [anon_sym_Enum] = ACTIONS(5641),
    [anon_sym_eNUM] = ACTIONS(5641),
    [anon_sym_eNum] = ACTIONS(5641),
    [anon_sym_ENum] = ACTIONS(5641),
    [sym_quoted_identifier] = ACTIONS(5643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5643),
    [sym_verbatim_string] = ACTIONS(5643),
    [sym_integer] = ACTIONS(5641),
    [sym_continue_as_identifier] = ACTIONS(5643),
    [sym_preproc_open] = ACTIONS(5643),
    [sym_preproc_close] = ACTIONS(5643),
  },
  [STATE(2416)] = {
    [sym_identifier] = ACTIONS(5645),
    [anon_sym_SEMI] = ACTIONS(5647),
    [anon_sym_DASH] = ACTIONS(5647),
    [aux_sym_boolean_token1] = ACTIONS(5645),
    [aux_sym_boolean_token2] = ACTIONS(5645),
    [sym_decimal] = ACTIONS(5645),
    [anon_sym_LPAREN] = ACTIONS(5647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5645),
    [anon_sym_LBRACK] = ACTIONS(5647),
    [aux_sym_record_type_token1] = ACTIONS(5645),
    [aux_sym_basic_type_token21] = ACTIONS(5645),
    [aux_sym_basic_type_token22] = ACTIONS(5645),
    [aux_sym_basic_type_token48] = ACTIONS(5645),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5645),
    [anon_sym_POUNDif] = ACTIONS(5647),
    [anon_sym_POUNDIF] = ACTIONS(5647),
    [anon_sym_POUNDIf] = ACTIONS(5647),
    [anon_sym_not] = ACTIONS(5645),
    [anon_sym_NOT] = ACTIONS(5645),
    [anon_sym_Not] = ACTIONS(5645),
    [anon_sym_POUNDelif] = ACTIONS(5647),
    [anon_sym_POUNDELIF] = ACTIONS(5647),
    [anon_sym_POUNDElif] = ACTIONS(5647),
    [anon_sym_POUNDelse] = ACTIONS(5647),
    [anon_sym_POUNDELSE] = ACTIONS(5647),
    [anon_sym_POUNDElse] = ACTIONS(5647),
    [anon_sym_POUNDelse2] = ACTIONS(5647),
    [anon_sym_POUNDELSE2] = ACTIONS(5647),
    [anon_sym_POUNDElse2] = ACTIONS(5647),
    [anon_sym_POUNDendif] = ACTIONS(5647),
    [anon_sym_POUNDENDIF] = ACTIONS(5647),
    [anon_sym_POUNDEndif] = ACTIONS(5647),
    [anon_sym_POUNDendif2] = ACTIONS(5647),
    [anon_sym_POUNDENDIF2] = ACTIONS(5647),
    [anon_sym_POUNDEndif2] = ACTIONS(5647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5645),
    [anon_sym_PLUS] = ACTIONS(5647),
    [sym_datetime_literal] = ACTIONS(5647),
    [sym_date_literal] = ACTIONS(5645),
    [sym_time_literal] = ACTIONS(5645),
    [sym_biginteger_literal] = ACTIONS(5647),
    [anon_sym_if] = ACTIONS(5645),
    [anon_sym_IF] = ACTIONS(5645),
    [anon_sym_If] = ACTIONS(5645),
    [anon_sym_else] = ACTIONS(5645),
    [anon_sym_ELSE] = ACTIONS(5645),
    [anon_sym_Else] = ACTIONS(5645),
    [anon_sym_case] = ACTIONS(5645),
    [anon_sym_CASE] = ACTIONS(5645),
    [anon_sym_Case] = ACTIONS(5645),
    [anon_sym_for] = ACTIONS(5645),
    [anon_sym_FOR] = ACTIONS(5645),
    [anon_sym_For] = ACTIONS(5645),
    [anon_sym_foreach] = ACTIONS(5645),
    [anon_sym_FOREACH] = ACTIONS(5645),
    [anon_sym_Foreach] = ACTIONS(5645),
    [anon_sym_while] = ACTIONS(5645),
    [anon_sym_WHILE] = ACTIONS(5645),
    [anon_sym_While] = ACTIONS(5645),
    [anon_sym_repeat] = ACTIONS(5645),
    [anon_sym_REPEAT] = ACTIONS(5645),
    [anon_sym_Repeat] = ACTIONS(5645),
    [anon_sym_exit] = ACTIONS(5645),
    [anon_sym_EXIT] = ACTIONS(5645),
    [anon_sym_Exit] = ACTIONS(5645),
    [anon_sym_continue] = ACTIONS(5645),
    [anon_sym_CONTINUE] = ACTIONS(5645),
    [anon_sym_Continue] = ACTIONS(5645),
    [anon_sym_break] = ACTIONS(5645),
    [anon_sym_BREAK] = ACTIONS(5645),
    [anon_sym_Break] = ACTIONS(5645),
    [anon_sym_with] = ACTIONS(5645),
    [anon_sym_WITH] = ACTIONS(5645),
    [anon_sym_With] = ACTIONS(5645),
    [sym_asserterror_keyword] = ACTIONS(5647),
    [sym_page_keyword] = ACTIONS(5645),
    [anon_sym_codeunit] = ACTIONS(5645),
    [anon_sym_CODEUNIT] = ACTIONS(5645),
    [anon_sym_Codeunit] = ACTIONS(5645),
    [anon_sym_CodeUnit] = ACTIONS(5645),
    [anon_sym_COdeunit] = ACTIONS(5645),
    [anon_sym_codeUnit] = ACTIONS(5645),
    [sym_report_keyword] = ACTIONS(5645),
    [sym_query_keyword] = ACTIONS(5645),
    [anon_sym_xmlport] = ACTIONS(5645),
    [anon_sym_XMLPORT] = ACTIONS(5645),
    [anon_sym_Xmlport] = ACTIONS(5645),
    [anon_sym_XMLport] = ACTIONS(5645),
    [anon_sym_XMLPort] = ACTIONS(5645),
    [anon_sym_XmlPort] = ACTIONS(5645),
    [anon_sym_enum] = ACTIONS(5645),
    [anon_sym_ENUM] = ACTIONS(5645),
    [anon_sym_Enum] = ACTIONS(5645),
    [anon_sym_eNUM] = ACTIONS(5645),
    [anon_sym_eNum] = ACTIONS(5645),
    [anon_sym_ENum] = ACTIONS(5645),
    [sym_quoted_identifier] = ACTIONS(5647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5647),
    [sym_verbatim_string] = ACTIONS(5647),
    [sym_integer] = ACTIONS(5645),
    [sym_continue_as_identifier] = ACTIONS(5647),
    [sym_preproc_open] = ACTIONS(5647),
    [sym_preproc_close] = ACTIONS(5647),
  },
  [STATE(2417)] = {
    [sym_identifier] = ACTIONS(5649),
    [anon_sym_SEMI] = ACTIONS(5651),
    [anon_sym_DASH] = ACTIONS(5651),
    [aux_sym_boolean_token1] = ACTIONS(5649),
    [aux_sym_boolean_token2] = ACTIONS(5649),
    [sym_decimal] = ACTIONS(5649),
    [anon_sym_LPAREN] = ACTIONS(5651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5649),
    [anon_sym_LBRACK] = ACTIONS(5651),
    [aux_sym_record_type_token1] = ACTIONS(5649),
    [aux_sym_basic_type_token21] = ACTIONS(5649),
    [aux_sym_basic_type_token22] = ACTIONS(5649),
    [aux_sym_basic_type_token48] = ACTIONS(5649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5649),
    [anon_sym_POUNDif] = ACTIONS(5651),
    [anon_sym_POUNDIF] = ACTIONS(5651),
    [anon_sym_POUNDIf] = ACTIONS(5651),
    [anon_sym_not] = ACTIONS(5649),
    [anon_sym_NOT] = ACTIONS(5649),
    [anon_sym_Not] = ACTIONS(5649),
    [anon_sym_POUNDelif] = ACTIONS(5651),
    [anon_sym_POUNDELIF] = ACTIONS(5651),
    [anon_sym_POUNDElif] = ACTIONS(5651),
    [anon_sym_POUNDelse] = ACTIONS(5651),
    [anon_sym_POUNDELSE] = ACTIONS(5651),
    [anon_sym_POUNDElse] = ACTIONS(5651),
    [anon_sym_POUNDelse2] = ACTIONS(5651),
    [anon_sym_POUNDELSE2] = ACTIONS(5651),
    [anon_sym_POUNDElse2] = ACTIONS(5651),
    [anon_sym_POUNDendif] = ACTIONS(5651),
    [anon_sym_POUNDENDIF] = ACTIONS(5651),
    [anon_sym_POUNDEndif] = ACTIONS(5651),
    [anon_sym_POUNDendif2] = ACTIONS(5651),
    [anon_sym_POUNDENDIF2] = ACTIONS(5651),
    [anon_sym_POUNDEndif2] = ACTIONS(5651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5649),
    [anon_sym_PLUS] = ACTIONS(5651),
    [sym_datetime_literal] = ACTIONS(5651),
    [sym_date_literal] = ACTIONS(5649),
    [sym_time_literal] = ACTIONS(5649),
    [sym_biginteger_literal] = ACTIONS(5651),
    [anon_sym_if] = ACTIONS(5649),
    [anon_sym_IF] = ACTIONS(5649),
    [anon_sym_If] = ACTIONS(5649),
    [anon_sym_else] = ACTIONS(5649),
    [anon_sym_ELSE] = ACTIONS(5649),
    [anon_sym_Else] = ACTIONS(5649),
    [anon_sym_case] = ACTIONS(5649),
    [anon_sym_CASE] = ACTIONS(5649),
    [anon_sym_Case] = ACTIONS(5649),
    [anon_sym_for] = ACTIONS(5649),
    [anon_sym_FOR] = ACTIONS(5649),
    [anon_sym_For] = ACTIONS(5649),
    [anon_sym_foreach] = ACTIONS(5649),
    [anon_sym_FOREACH] = ACTIONS(5649),
    [anon_sym_Foreach] = ACTIONS(5649),
    [anon_sym_while] = ACTIONS(5649),
    [anon_sym_WHILE] = ACTIONS(5649),
    [anon_sym_While] = ACTIONS(5649),
    [anon_sym_repeat] = ACTIONS(5649),
    [anon_sym_REPEAT] = ACTIONS(5649),
    [anon_sym_Repeat] = ACTIONS(5649),
    [anon_sym_exit] = ACTIONS(5649),
    [anon_sym_EXIT] = ACTIONS(5649),
    [anon_sym_Exit] = ACTIONS(5649),
    [anon_sym_continue] = ACTIONS(5649),
    [anon_sym_CONTINUE] = ACTIONS(5649),
    [anon_sym_Continue] = ACTIONS(5649),
    [anon_sym_break] = ACTIONS(5649),
    [anon_sym_BREAK] = ACTIONS(5649),
    [anon_sym_Break] = ACTIONS(5649),
    [anon_sym_with] = ACTIONS(5649),
    [anon_sym_WITH] = ACTIONS(5649),
    [anon_sym_With] = ACTIONS(5649),
    [sym_asserterror_keyword] = ACTIONS(5651),
    [sym_page_keyword] = ACTIONS(5649),
    [anon_sym_codeunit] = ACTIONS(5649),
    [anon_sym_CODEUNIT] = ACTIONS(5649),
    [anon_sym_Codeunit] = ACTIONS(5649),
    [anon_sym_CodeUnit] = ACTIONS(5649),
    [anon_sym_COdeunit] = ACTIONS(5649),
    [anon_sym_codeUnit] = ACTIONS(5649),
    [sym_report_keyword] = ACTIONS(5649),
    [sym_query_keyword] = ACTIONS(5649),
    [anon_sym_xmlport] = ACTIONS(5649),
    [anon_sym_XMLPORT] = ACTIONS(5649),
    [anon_sym_Xmlport] = ACTIONS(5649),
    [anon_sym_XMLport] = ACTIONS(5649),
    [anon_sym_XMLPort] = ACTIONS(5649),
    [anon_sym_XmlPort] = ACTIONS(5649),
    [anon_sym_enum] = ACTIONS(5649),
    [anon_sym_ENUM] = ACTIONS(5649),
    [anon_sym_Enum] = ACTIONS(5649),
    [anon_sym_eNUM] = ACTIONS(5649),
    [anon_sym_eNum] = ACTIONS(5649),
    [anon_sym_ENum] = ACTIONS(5649),
    [sym_quoted_identifier] = ACTIONS(5651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5651),
    [sym_verbatim_string] = ACTIONS(5651),
    [sym_integer] = ACTIONS(5649),
    [sym_continue_as_identifier] = ACTIONS(5651),
    [sym_preproc_open] = ACTIONS(5651),
    [sym_preproc_close] = ACTIONS(5651),
  },
  [STATE(2418)] = {
    [sym_identifier] = ACTIONS(5653),
    [anon_sym_SEMI] = ACTIONS(5655),
    [anon_sym_DASH] = ACTIONS(5655),
    [aux_sym_boolean_token1] = ACTIONS(5653),
    [aux_sym_boolean_token2] = ACTIONS(5653),
    [sym_decimal] = ACTIONS(5653),
    [anon_sym_LPAREN] = ACTIONS(5655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5653),
    [anon_sym_LBRACK] = ACTIONS(5655),
    [aux_sym_record_type_token1] = ACTIONS(5653),
    [aux_sym_basic_type_token21] = ACTIONS(5653),
    [aux_sym_basic_type_token22] = ACTIONS(5653),
    [aux_sym_basic_type_token48] = ACTIONS(5653),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5653),
    [anon_sym_POUNDif] = ACTIONS(5655),
    [anon_sym_POUNDIF] = ACTIONS(5655),
    [anon_sym_POUNDIf] = ACTIONS(5655),
    [anon_sym_not] = ACTIONS(5653),
    [anon_sym_NOT] = ACTIONS(5653),
    [anon_sym_Not] = ACTIONS(5653),
    [anon_sym_POUNDelif] = ACTIONS(5655),
    [anon_sym_POUNDELIF] = ACTIONS(5655),
    [anon_sym_POUNDElif] = ACTIONS(5655),
    [anon_sym_POUNDelse] = ACTIONS(5655),
    [anon_sym_POUNDELSE] = ACTIONS(5655),
    [anon_sym_POUNDElse] = ACTIONS(5655),
    [anon_sym_POUNDelse2] = ACTIONS(5655),
    [anon_sym_POUNDELSE2] = ACTIONS(5655),
    [anon_sym_POUNDElse2] = ACTIONS(5655),
    [anon_sym_POUNDendif] = ACTIONS(5655),
    [anon_sym_POUNDENDIF] = ACTIONS(5655),
    [anon_sym_POUNDEndif] = ACTIONS(5655),
    [anon_sym_POUNDendif2] = ACTIONS(5655),
    [anon_sym_POUNDENDIF2] = ACTIONS(5655),
    [anon_sym_POUNDEndif2] = ACTIONS(5655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5653),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5653),
    [anon_sym_PLUS] = ACTIONS(5655),
    [sym_datetime_literal] = ACTIONS(5655),
    [sym_date_literal] = ACTIONS(5653),
    [sym_time_literal] = ACTIONS(5653),
    [sym_biginteger_literal] = ACTIONS(5655),
    [anon_sym_if] = ACTIONS(5653),
    [anon_sym_IF] = ACTIONS(5653),
    [anon_sym_If] = ACTIONS(5653),
    [anon_sym_else] = ACTIONS(5653),
    [anon_sym_ELSE] = ACTIONS(5653),
    [anon_sym_Else] = ACTIONS(5653),
    [anon_sym_case] = ACTIONS(5653),
    [anon_sym_CASE] = ACTIONS(5653),
    [anon_sym_Case] = ACTIONS(5653),
    [anon_sym_for] = ACTIONS(5653),
    [anon_sym_FOR] = ACTIONS(5653),
    [anon_sym_For] = ACTIONS(5653),
    [anon_sym_foreach] = ACTIONS(5653),
    [anon_sym_FOREACH] = ACTIONS(5653),
    [anon_sym_Foreach] = ACTIONS(5653),
    [anon_sym_while] = ACTIONS(5653),
    [anon_sym_WHILE] = ACTIONS(5653),
    [anon_sym_While] = ACTIONS(5653),
    [anon_sym_repeat] = ACTIONS(5653),
    [anon_sym_REPEAT] = ACTIONS(5653),
    [anon_sym_Repeat] = ACTIONS(5653),
    [anon_sym_exit] = ACTIONS(5653),
    [anon_sym_EXIT] = ACTIONS(5653),
    [anon_sym_Exit] = ACTIONS(5653),
    [anon_sym_continue] = ACTIONS(5653),
    [anon_sym_CONTINUE] = ACTIONS(5653),
    [anon_sym_Continue] = ACTIONS(5653),
    [anon_sym_break] = ACTIONS(5653),
    [anon_sym_BREAK] = ACTIONS(5653),
    [anon_sym_Break] = ACTIONS(5653),
    [anon_sym_with] = ACTIONS(5653),
    [anon_sym_WITH] = ACTIONS(5653),
    [anon_sym_With] = ACTIONS(5653),
    [sym_asserterror_keyword] = ACTIONS(5655),
    [sym_page_keyword] = ACTIONS(5653),
    [anon_sym_codeunit] = ACTIONS(5653),
    [anon_sym_CODEUNIT] = ACTIONS(5653),
    [anon_sym_Codeunit] = ACTIONS(5653),
    [anon_sym_CodeUnit] = ACTIONS(5653),
    [anon_sym_COdeunit] = ACTIONS(5653),
    [anon_sym_codeUnit] = ACTIONS(5653),
    [sym_report_keyword] = ACTIONS(5653),
    [sym_query_keyword] = ACTIONS(5653),
    [anon_sym_xmlport] = ACTIONS(5653),
    [anon_sym_XMLPORT] = ACTIONS(5653),
    [anon_sym_Xmlport] = ACTIONS(5653),
    [anon_sym_XMLport] = ACTIONS(5653),
    [anon_sym_XMLPort] = ACTIONS(5653),
    [anon_sym_XmlPort] = ACTIONS(5653),
    [anon_sym_enum] = ACTIONS(5653),
    [anon_sym_ENUM] = ACTIONS(5653),
    [anon_sym_Enum] = ACTIONS(5653),
    [anon_sym_eNUM] = ACTIONS(5653),
    [anon_sym_eNum] = ACTIONS(5653),
    [anon_sym_ENum] = ACTIONS(5653),
    [sym_quoted_identifier] = ACTIONS(5655),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5655),
    [sym_verbatim_string] = ACTIONS(5655),
    [sym_integer] = ACTIONS(5653),
    [sym_continue_as_identifier] = ACTIONS(5655),
    [sym_preproc_open] = ACTIONS(5655),
    [sym_preproc_close] = ACTIONS(5655),
  },
  [STATE(2419)] = {
    [sym_identifier] = ACTIONS(5657),
    [anon_sym_SEMI] = ACTIONS(5659),
    [anon_sym_DASH] = ACTIONS(5659),
    [aux_sym_boolean_token1] = ACTIONS(5657),
    [aux_sym_boolean_token2] = ACTIONS(5657),
    [sym_decimal] = ACTIONS(5657),
    [anon_sym_LPAREN] = ACTIONS(5659),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5657),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [aux_sym_record_type_token1] = ACTIONS(5657),
    [aux_sym_basic_type_token21] = ACTIONS(5657),
    [aux_sym_basic_type_token22] = ACTIONS(5657),
    [aux_sym_basic_type_token48] = ACTIONS(5657),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5657),
    [anon_sym_POUNDif] = ACTIONS(5659),
    [anon_sym_POUNDIF] = ACTIONS(5659),
    [anon_sym_POUNDIf] = ACTIONS(5659),
    [anon_sym_not] = ACTIONS(5657),
    [anon_sym_NOT] = ACTIONS(5657),
    [anon_sym_Not] = ACTIONS(5657),
    [anon_sym_POUNDelif] = ACTIONS(5659),
    [anon_sym_POUNDELIF] = ACTIONS(5659),
    [anon_sym_POUNDElif] = ACTIONS(5659),
    [anon_sym_POUNDelse] = ACTIONS(5659),
    [anon_sym_POUNDELSE] = ACTIONS(5659),
    [anon_sym_POUNDElse] = ACTIONS(5659),
    [anon_sym_POUNDelse2] = ACTIONS(5659),
    [anon_sym_POUNDELSE2] = ACTIONS(5659),
    [anon_sym_POUNDElse2] = ACTIONS(5659),
    [anon_sym_POUNDendif] = ACTIONS(5659),
    [anon_sym_POUNDENDIF] = ACTIONS(5659),
    [anon_sym_POUNDEndif] = ACTIONS(5659),
    [anon_sym_POUNDendif2] = ACTIONS(5659),
    [anon_sym_POUNDENDIF2] = ACTIONS(5659),
    [anon_sym_POUNDEndif2] = ACTIONS(5659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5657),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5657),
    [anon_sym_PLUS] = ACTIONS(5659),
    [sym_datetime_literal] = ACTIONS(5659),
    [sym_date_literal] = ACTIONS(5657),
    [sym_time_literal] = ACTIONS(5657),
    [sym_biginteger_literal] = ACTIONS(5659),
    [anon_sym_if] = ACTIONS(5657),
    [anon_sym_IF] = ACTIONS(5657),
    [anon_sym_If] = ACTIONS(5657),
    [anon_sym_else] = ACTIONS(5657),
    [anon_sym_ELSE] = ACTIONS(5657),
    [anon_sym_Else] = ACTIONS(5657),
    [anon_sym_case] = ACTIONS(5657),
    [anon_sym_CASE] = ACTIONS(5657),
    [anon_sym_Case] = ACTIONS(5657),
    [anon_sym_for] = ACTIONS(5657),
    [anon_sym_FOR] = ACTIONS(5657),
    [anon_sym_For] = ACTIONS(5657),
    [anon_sym_foreach] = ACTIONS(5657),
    [anon_sym_FOREACH] = ACTIONS(5657),
    [anon_sym_Foreach] = ACTIONS(5657),
    [anon_sym_while] = ACTIONS(5657),
    [anon_sym_WHILE] = ACTIONS(5657),
    [anon_sym_While] = ACTIONS(5657),
    [anon_sym_repeat] = ACTIONS(5657),
    [anon_sym_REPEAT] = ACTIONS(5657),
    [anon_sym_Repeat] = ACTIONS(5657),
    [anon_sym_exit] = ACTIONS(5657),
    [anon_sym_EXIT] = ACTIONS(5657),
    [anon_sym_Exit] = ACTIONS(5657),
    [anon_sym_continue] = ACTIONS(5657),
    [anon_sym_CONTINUE] = ACTIONS(5657),
    [anon_sym_Continue] = ACTIONS(5657),
    [anon_sym_break] = ACTIONS(5657),
    [anon_sym_BREAK] = ACTIONS(5657),
    [anon_sym_Break] = ACTIONS(5657),
    [anon_sym_with] = ACTIONS(5657),
    [anon_sym_WITH] = ACTIONS(5657),
    [anon_sym_With] = ACTIONS(5657),
    [sym_asserterror_keyword] = ACTIONS(5659),
    [sym_page_keyword] = ACTIONS(5657),
    [anon_sym_codeunit] = ACTIONS(5657),
    [anon_sym_CODEUNIT] = ACTIONS(5657),
    [anon_sym_Codeunit] = ACTIONS(5657),
    [anon_sym_CodeUnit] = ACTIONS(5657),
    [anon_sym_COdeunit] = ACTIONS(5657),
    [anon_sym_codeUnit] = ACTIONS(5657),
    [sym_report_keyword] = ACTIONS(5657),
    [sym_query_keyword] = ACTIONS(5657),
    [anon_sym_xmlport] = ACTIONS(5657),
    [anon_sym_XMLPORT] = ACTIONS(5657),
    [anon_sym_Xmlport] = ACTIONS(5657),
    [anon_sym_XMLport] = ACTIONS(5657),
    [anon_sym_XMLPort] = ACTIONS(5657),
    [anon_sym_XmlPort] = ACTIONS(5657),
    [anon_sym_enum] = ACTIONS(5657),
    [anon_sym_ENUM] = ACTIONS(5657),
    [anon_sym_Enum] = ACTIONS(5657),
    [anon_sym_eNUM] = ACTIONS(5657),
    [anon_sym_eNum] = ACTIONS(5657),
    [anon_sym_ENum] = ACTIONS(5657),
    [sym_quoted_identifier] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5659),
    [sym_verbatim_string] = ACTIONS(5659),
    [sym_integer] = ACTIONS(5657),
    [sym_continue_as_identifier] = ACTIONS(5659),
    [sym_preproc_open] = ACTIONS(5659),
    [sym_preproc_close] = ACTIONS(5659),
  },
  [STATE(2420)] = {
    [sym_identifier] = ACTIONS(5661),
    [anon_sym_SEMI] = ACTIONS(5663),
    [anon_sym_DASH] = ACTIONS(5663),
    [aux_sym_boolean_token1] = ACTIONS(5661),
    [aux_sym_boolean_token2] = ACTIONS(5661),
    [sym_decimal] = ACTIONS(5661),
    [anon_sym_LPAREN] = ACTIONS(5663),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5663),
    [aux_sym_record_type_token1] = ACTIONS(5661),
    [aux_sym_basic_type_token21] = ACTIONS(5661),
    [aux_sym_basic_type_token22] = ACTIONS(5661),
    [aux_sym_basic_type_token48] = ACTIONS(5661),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5661),
    [anon_sym_POUNDif] = ACTIONS(5663),
    [anon_sym_POUNDIF] = ACTIONS(5663),
    [anon_sym_POUNDIf] = ACTIONS(5663),
    [anon_sym_not] = ACTIONS(5661),
    [anon_sym_NOT] = ACTIONS(5661),
    [anon_sym_Not] = ACTIONS(5661),
    [anon_sym_POUNDelif] = ACTIONS(5663),
    [anon_sym_POUNDELIF] = ACTIONS(5663),
    [anon_sym_POUNDElif] = ACTIONS(5663),
    [anon_sym_POUNDelse] = ACTIONS(5663),
    [anon_sym_POUNDELSE] = ACTIONS(5663),
    [anon_sym_POUNDElse] = ACTIONS(5663),
    [anon_sym_POUNDelse2] = ACTIONS(5663),
    [anon_sym_POUNDELSE2] = ACTIONS(5663),
    [anon_sym_POUNDElse2] = ACTIONS(5663),
    [anon_sym_POUNDendif] = ACTIONS(5663),
    [anon_sym_POUNDENDIF] = ACTIONS(5663),
    [anon_sym_POUNDEndif] = ACTIONS(5663),
    [anon_sym_POUNDendif2] = ACTIONS(5663),
    [anon_sym_POUNDENDIF2] = ACTIONS(5663),
    [anon_sym_POUNDEndif2] = ACTIONS(5663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5661),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5661),
    [anon_sym_PLUS] = ACTIONS(5663),
    [sym_datetime_literal] = ACTIONS(5663),
    [sym_date_literal] = ACTIONS(5661),
    [sym_time_literal] = ACTIONS(5661),
    [sym_biginteger_literal] = ACTIONS(5663),
    [anon_sym_if] = ACTIONS(5661),
    [anon_sym_IF] = ACTIONS(5661),
    [anon_sym_If] = ACTIONS(5661),
    [anon_sym_else] = ACTIONS(5661),
    [anon_sym_ELSE] = ACTIONS(5661),
    [anon_sym_Else] = ACTIONS(5661),
    [anon_sym_case] = ACTIONS(5661),
    [anon_sym_CASE] = ACTIONS(5661),
    [anon_sym_Case] = ACTIONS(5661),
    [anon_sym_for] = ACTIONS(5661),
    [anon_sym_FOR] = ACTIONS(5661),
    [anon_sym_For] = ACTIONS(5661),
    [anon_sym_foreach] = ACTIONS(5661),
    [anon_sym_FOREACH] = ACTIONS(5661),
    [anon_sym_Foreach] = ACTIONS(5661),
    [anon_sym_while] = ACTIONS(5661),
    [anon_sym_WHILE] = ACTIONS(5661),
    [anon_sym_While] = ACTIONS(5661),
    [anon_sym_repeat] = ACTIONS(5661),
    [anon_sym_REPEAT] = ACTIONS(5661),
    [anon_sym_Repeat] = ACTIONS(5661),
    [anon_sym_exit] = ACTIONS(5661),
    [anon_sym_EXIT] = ACTIONS(5661),
    [anon_sym_Exit] = ACTIONS(5661),
    [anon_sym_continue] = ACTIONS(5661),
    [anon_sym_CONTINUE] = ACTIONS(5661),
    [anon_sym_Continue] = ACTIONS(5661),
    [anon_sym_break] = ACTIONS(5661),
    [anon_sym_BREAK] = ACTIONS(5661),
    [anon_sym_Break] = ACTIONS(5661),
    [anon_sym_with] = ACTIONS(5661),
    [anon_sym_WITH] = ACTIONS(5661),
    [anon_sym_With] = ACTIONS(5661),
    [sym_asserterror_keyword] = ACTIONS(5663),
    [sym_page_keyword] = ACTIONS(5661),
    [anon_sym_codeunit] = ACTIONS(5661),
    [anon_sym_CODEUNIT] = ACTIONS(5661),
    [anon_sym_Codeunit] = ACTIONS(5661),
    [anon_sym_CodeUnit] = ACTIONS(5661),
    [anon_sym_COdeunit] = ACTIONS(5661),
    [anon_sym_codeUnit] = ACTIONS(5661),
    [sym_report_keyword] = ACTIONS(5661),
    [sym_query_keyword] = ACTIONS(5661),
    [anon_sym_xmlport] = ACTIONS(5661),
    [anon_sym_XMLPORT] = ACTIONS(5661),
    [anon_sym_Xmlport] = ACTIONS(5661),
    [anon_sym_XMLport] = ACTIONS(5661),
    [anon_sym_XMLPort] = ACTIONS(5661),
    [anon_sym_XmlPort] = ACTIONS(5661),
    [anon_sym_enum] = ACTIONS(5661),
    [anon_sym_ENUM] = ACTIONS(5661),
    [anon_sym_Enum] = ACTIONS(5661),
    [anon_sym_eNUM] = ACTIONS(5661),
    [anon_sym_eNum] = ACTIONS(5661),
    [anon_sym_ENum] = ACTIONS(5661),
    [sym_quoted_identifier] = ACTIONS(5663),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5663),
    [sym_verbatim_string] = ACTIONS(5663),
    [sym_integer] = ACTIONS(5661),
    [sym_continue_as_identifier] = ACTIONS(5663),
    [sym_preproc_open] = ACTIONS(5663),
    [sym_preproc_close] = ACTIONS(5663),
  },
  [STATE(2421)] = {
    [sym_identifier] = ACTIONS(5665),
    [anon_sym_SEMI] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5667),
    [aux_sym_boolean_token1] = ACTIONS(5665),
    [aux_sym_boolean_token2] = ACTIONS(5665),
    [sym_decimal] = ACTIONS(5665),
    [anon_sym_LPAREN] = ACTIONS(5667),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5665),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [aux_sym_record_type_token1] = ACTIONS(5665),
    [aux_sym_basic_type_token21] = ACTIONS(5665),
    [aux_sym_basic_type_token22] = ACTIONS(5665),
    [aux_sym_basic_type_token48] = ACTIONS(5665),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5665),
    [anon_sym_POUNDif] = ACTIONS(5667),
    [anon_sym_POUNDIF] = ACTIONS(5667),
    [anon_sym_POUNDIf] = ACTIONS(5667),
    [anon_sym_not] = ACTIONS(5665),
    [anon_sym_NOT] = ACTIONS(5665),
    [anon_sym_Not] = ACTIONS(5665),
    [anon_sym_POUNDelif] = ACTIONS(5667),
    [anon_sym_POUNDELIF] = ACTIONS(5667),
    [anon_sym_POUNDElif] = ACTIONS(5667),
    [anon_sym_POUNDelse] = ACTIONS(5667),
    [anon_sym_POUNDELSE] = ACTIONS(5667),
    [anon_sym_POUNDElse] = ACTIONS(5667),
    [anon_sym_POUNDelse2] = ACTIONS(5667),
    [anon_sym_POUNDELSE2] = ACTIONS(5667),
    [anon_sym_POUNDElse2] = ACTIONS(5667),
    [anon_sym_POUNDendif] = ACTIONS(5667),
    [anon_sym_POUNDENDIF] = ACTIONS(5667),
    [anon_sym_POUNDEndif] = ACTIONS(5667),
    [anon_sym_POUNDendif2] = ACTIONS(5667),
    [anon_sym_POUNDENDIF2] = ACTIONS(5667),
    [anon_sym_POUNDEndif2] = ACTIONS(5667),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5665),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5665),
    [anon_sym_PLUS] = ACTIONS(5667),
    [sym_datetime_literal] = ACTIONS(5667),
    [sym_date_literal] = ACTIONS(5665),
    [sym_time_literal] = ACTIONS(5665),
    [sym_biginteger_literal] = ACTIONS(5667),
    [anon_sym_if] = ACTIONS(5665),
    [anon_sym_IF] = ACTIONS(5665),
    [anon_sym_If] = ACTIONS(5665),
    [anon_sym_else] = ACTIONS(5665),
    [anon_sym_ELSE] = ACTIONS(5665),
    [anon_sym_Else] = ACTIONS(5665),
    [anon_sym_case] = ACTIONS(5665),
    [anon_sym_CASE] = ACTIONS(5665),
    [anon_sym_Case] = ACTIONS(5665),
    [anon_sym_for] = ACTIONS(5665),
    [anon_sym_FOR] = ACTIONS(5665),
    [anon_sym_For] = ACTIONS(5665),
    [anon_sym_foreach] = ACTIONS(5665),
    [anon_sym_FOREACH] = ACTIONS(5665),
    [anon_sym_Foreach] = ACTIONS(5665),
    [anon_sym_while] = ACTIONS(5665),
    [anon_sym_WHILE] = ACTIONS(5665),
    [anon_sym_While] = ACTIONS(5665),
    [anon_sym_repeat] = ACTIONS(5665),
    [anon_sym_REPEAT] = ACTIONS(5665),
    [anon_sym_Repeat] = ACTIONS(5665),
    [anon_sym_exit] = ACTIONS(5665),
    [anon_sym_EXIT] = ACTIONS(5665),
    [anon_sym_Exit] = ACTIONS(5665),
    [anon_sym_continue] = ACTIONS(5665),
    [anon_sym_CONTINUE] = ACTIONS(5665),
    [anon_sym_Continue] = ACTIONS(5665),
    [anon_sym_break] = ACTIONS(5665),
    [anon_sym_BREAK] = ACTIONS(5665),
    [anon_sym_Break] = ACTIONS(5665),
    [anon_sym_with] = ACTIONS(5665),
    [anon_sym_WITH] = ACTIONS(5665),
    [anon_sym_With] = ACTIONS(5665),
    [sym_asserterror_keyword] = ACTIONS(5667),
    [sym_page_keyword] = ACTIONS(5665),
    [anon_sym_codeunit] = ACTIONS(5665),
    [anon_sym_CODEUNIT] = ACTIONS(5665),
    [anon_sym_Codeunit] = ACTIONS(5665),
    [anon_sym_CodeUnit] = ACTIONS(5665),
    [anon_sym_COdeunit] = ACTIONS(5665),
    [anon_sym_codeUnit] = ACTIONS(5665),
    [sym_report_keyword] = ACTIONS(5665),
    [sym_query_keyword] = ACTIONS(5665),
    [anon_sym_xmlport] = ACTIONS(5665),
    [anon_sym_XMLPORT] = ACTIONS(5665),
    [anon_sym_Xmlport] = ACTIONS(5665),
    [anon_sym_XMLport] = ACTIONS(5665),
    [anon_sym_XMLPort] = ACTIONS(5665),
    [anon_sym_XmlPort] = ACTIONS(5665),
    [anon_sym_enum] = ACTIONS(5665),
    [anon_sym_ENUM] = ACTIONS(5665),
    [anon_sym_Enum] = ACTIONS(5665),
    [anon_sym_eNUM] = ACTIONS(5665),
    [anon_sym_eNum] = ACTIONS(5665),
    [anon_sym_ENum] = ACTIONS(5665),
    [sym_quoted_identifier] = ACTIONS(5667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5667),
    [sym_verbatim_string] = ACTIONS(5667),
    [sym_integer] = ACTIONS(5665),
    [sym_continue_as_identifier] = ACTIONS(5667),
    [sym_preproc_open] = ACTIONS(5667),
    [sym_preproc_close] = ACTIONS(5667),
  },
  [STATE(2422)] = {
    [sym_identifier] = ACTIONS(5669),
    [anon_sym_SEMI] = ACTIONS(5671),
    [anon_sym_DASH] = ACTIONS(5671),
    [aux_sym_boolean_token1] = ACTIONS(5669),
    [aux_sym_boolean_token2] = ACTIONS(5669),
    [sym_decimal] = ACTIONS(5669),
    [anon_sym_LPAREN] = ACTIONS(5671),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5669),
    [anon_sym_LBRACK] = ACTIONS(5671),
    [aux_sym_record_type_token1] = ACTIONS(5669),
    [aux_sym_basic_type_token21] = ACTIONS(5669),
    [aux_sym_basic_type_token22] = ACTIONS(5669),
    [aux_sym_basic_type_token48] = ACTIONS(5669),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5669),
    [anon_sym_POUNDif] = ACTIONS(5671),
    [anon_sym_POUNDIF] = ACTIONS(5671),
    [anon_sym_POUNDIf] = ACTIONS(5671),
    [anon_sym_not] = ACTIONS(5669),
    [anon_sym_NOT] = ACTIONS(5669),
    [anon_sym_Not] = ACTIONS(5669),
    [anon_sym_POUNDelif] = ACTIONS(5671),
    [anon_sym_POUNDELIF] = ACTIONS(5671),
    [anon_sym_POUNDElif] = ACTIONS(5671),
    [anon_sym_POUNDelse] = ACTIONS(5671),
    [anon_sym_POUNDELSE] = ACTIONS(5671),
    [anon_sym_POUNDElse] = ACTIONS(5671),
    [anon_sym_POUNDelse2] = ACTIONS(5671),
    [anon_sym_POUNDELSE2] = ACTIONS(5671),
    [anon_sym_POUNDElse2] = ACTIONS(5671),
    [anon_sym_POUNDendif] = ACTIONS(5671),
    [anon_sym_POUNDENDIF] = ACTIONS(5671),
    [anon_sym_POUNDEndif] = ACTIONS(5671),
    [anon_sym_POUNDendif2] = ACTIONS(5671),
    [anon_sym_POUNDENDIF2] = ACTIONS(5671),
    [anon_sym_POUNDEndif2] = ACTIONS(5671),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5669),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5669),
    [anon_sym_PLUS] = ACTIONS(5671),
    [sym_datetime_literal] = ACTIONS(5671),
    [sym_date_literal] = ACTIONS(5669),
    [sym_time_literal] = ACTIONS(5669),
    [sym_biginteger_literal] = ACTIONS(5671),
    [anon_sym_if] = ACTIONS(5669),
    [anon_sym_IF] = ACTIONS(5669),
    [anon_sym_If] = ACTIONS(5669),
    [anon_sym_else] = ACTIONS(5669),
    [anon_sym_ELSE] = ACTIONS(5669),
    [anon_sym_Else] = ACTIONS(5669),
    [anon_sym_case] = ACTIONS(5669),
    [anon_sym_CASE] = ACTIONS(5669),
    [anon_sym_Case] = ACTIONS(5669),
    [anon_sym_for] = ACTIONS(5669),
    [anon_sym_FOR] = ACTIONS(5669),
    [anon_sym_For] = ACTIONS(5669),
    [anon_sym_foreach] = ACTIONS(5669),
    [anon_sym_FOREACH] = ACTIONS(5669),
    [anon_sym_Foreach] = ACTIONS(5669),
    [anon_sym_while] = ACTIONS(5669),
    [anon_sym_WHILE] = ACTIONS(5669),
    [anon_sym_While] = ACTIONS(5669),
    [anon_sym_repeat] = ACTIONS(5669),
    [anon_sym_REPEAT] = ACTIONS(5669),
    [anon_sym_Repeat] = ACTIONS(5669),
    [anon_sym_exit] = ACTIONS(5669),
    [anon_sym_EXIT] = ACTIONS(5669),
    [anon_sym_Exit] = ACTIONS(5669),
    [anon_sym_continue] = ACTIONS(5669),
    [anon_sym_CONTINUE] = ACTIONS(5669),
    [anon_sym_Continue] = ACTIONS(5669),
    [anon_sym_break] = ACTIONS(5669),
    [anon_sym_BREAK] = ACTIONS(5669),
    [anon_sym_Break] = ACTIONS(5669),
    [anon_sym_with] = ACTIONS(5669),
    [anon_sym_WITH] = ACTIONS(5669),
    [anon_sym_With] = ACTIONS(5669),
    [sym_asserterror_keyword] = ACTIONS(5671),
    [sym_page_keyword] = ACTIONS(5669),
    [anon_sym_codeunit] = ACTIONS(5669),
    [anon_sym_CODEUNIT] = ACTIONS(5669),
    [anon_sym_Codeunit] = ACTIONS(5669),
    [anon_sym_CodeUnit] = ACTIONS(5669),
    [anon_sym_COdeunit] = ACTIONS(5669),
    [anon_sym_codeUnit] = ACTIONS(5669),
    [sym_report_keyword] = ACTIONS(5669),
    [sym_query_keyword] = ACTIONS(5669),
    [anon_sym_xmlport] = ACTIONS(5669),
    [anon_sym_XMLPORT] = ACTIONS(5669),
    [anon_sym_Xmlport] = ACTIONS(5669),
    [anon_sym_XMLport] = ACTIONS(5669),
    [anon_sym_XMLPort] = ACTIONS(5669),
    [anon_sym_XmlPort] = ACTIONS(5669),
    [anon_sym_enum] = ACTIONS(5669),
    [anon_sym_ENUM] = ACTIONS(5669),
    [anon_sym_Enum] = ACTIONS(5669),
    [anon_sym_eNUM] = ACTIONS(5669),
    [anon_sym_eNum] = ACTIONS(5669),
    [anon_sym_ENum] = ACTIONS(5669),
    [sym_quoted_identifier] = ACTIONS(5671),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5671),
    [sym_verbatim_string] = ACTIONS(5671),
    [sym_integer] = ACTIONS(5669),
    [sym_continue_as_identifier] = ACTIONS(5671),
    [sym_preproc_open] = ACTIONS(5671),
    [sym_preproc_close] = ACTIONS(5671),
  },
  [STATE(2423)] = {
    [sym_identifier] = ACTIONS(5673),
    [anon_sym_SEMI] = ACTIONS(5675),
    [anon_sym_DASH] = ACTIONS(5675),
    [aux_sym_boolean_token1] = ACTIONS(5673),
    [aux_sym_boolean_token2] = ACTIONS(5673),
    [sym_decimal] = ACTIONS(5673),
    [anon_sym_LPAREN] = ACTIONS(5675),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5673),
    [anon_sym_LBRACK] = ACTIONS(5675),
    [aux_sym_record_type_token1] = ACTIONS(5673),
    [aux_sym_basic_type_token21] = ACTIONS(5673),
    [aux_sym_basic_type_token22] = ACTIONS(5673),
    [aux_sym_basic_type_token48] = ACTIONS(5673),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5673),
    [anon_sym_POUNDif] = ACTIONS(5675),
    [anon_sym_POUNDIF] = ACTIONS(5675),
    [anon_sym_POUNDIf] = ACTIONS(5675),
    [anon_sym_not] = ACTIONS(5673),
    [anon_sym_NOT] = ACTIONS(5673),
    [anon_sym_Not] = ACTIONS(5673),
    [anon_sym_POUNDelif] = ACTIONS(5675),
    [anon_sym_POUNDELIF] = ACTIONS(5675),
    [anon_sym_POUNDElif] = ACTIONS(5675),
    [anon_sym_POUNDelse] = ACTIONS(5675),
    [anon_sym_POUNDELSE] = ACTIONS(5675),
    [anon_sym_POUNDElse] = ACTIONS(5675),
    [anon_sym_POUNDelse2] = ACTIONS(5675),
    [anon_sym_POUNDELSE2] = ACTIONS(5675),
    [anon_sym_POUNDElse2] = ACTIONS(5675),
    [anon_sym_POUNDendif] = ACTIONS(5675),
    [anon_sym_POUNDENDIF] = ACTIONS(5675),
    [anon_sym_POUNDEndif] = ACTIONS(5675),
    [anon_sym_POUNDendif2] = ACTIONS(5675),
    [anon_sym_POUNDENDIF2] = ACTIONS(5675),
    [anon_sym_POUNDEndif2] = ACTIONS(5675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5673),
    [anon_sym_PLUS] = ACTIONS(5675),
    [sym_datetime_literal] = ACTIONS(5675),
    [sym_date_literal] = ACTIONS(5673),
    [sym_time_literal] = ACTIONS(5673),
    [sym_biginteger_literal] = ACTIONS(5675),
    [anon_sym_if] = ACTIONS(5673),
    [anon_sym_IF] = ACTIONS(5673),
    [anon_sym_If] = ACTIONS(5673),
    [anon_sym_else] = ACTIONS(5673),
    [anon_sym_ELSE] = ACTIONS(5673),
    [anon_sym_Else] = ACTIONS(5673),
    [anon_sym_case] = ACTIONS(5673),
    [anon_sym_CASE] = ACTIONS(5673),
    [anon_sym_Case] = ACTIONS(5673),
    [anon_sym_for] = ACTIONS(5673),
    [anon_sym_FOR] = ACTIONS(5673),
    [anon_sym_For] = ACTIONS(5673),
    [anon_sym_foreach] = ACTIONS(5673),
    [anon_sym_FOREACH] = ACTIONS(5673),
    [anon_sym_Foreach] = ACTIONS(5673),
    [anon_sym_while] = ACTIONS(5673),
    [anon_sym_WHILE] = ACTIONS(5673),
    [anon_sym_While] = ACTIONS(5673),
    [anon_sym_repeat] = ACTIONS(5673),
    [anon_sym_REPEAT] = ACTIONS(5673),
    [anon_sym_Repeat] = ACTIONS(5673),
    [anon_sym_exit] = ACTIONS(5673),
    [anon_sym_EXIT] = ACTIONS(5673),
    [anon_sym_Exit] = ACTIONS(5673),
    [anon_sym_continue] = ACTIONS(5673),
    [anon_sym_CONTINUE] = ACTIONS(5673),
    [anon_sym_Continue] = ACTIONS(5673),
    [anon_sym_break] = ACTIONS(5673),
    [anon_sym_BREAK] = ACTIONS(5673),
    [anon_sym_Break] = ACTIONS(5673),
    [anon_sym_with] = ACTIONS(5673),
    [anon_sym_WITH] = ACTIONS(5673),
    [anon_sym_With] = ACTIONS(5673),
    [sym_asserterror_keyword] = ACTIONS(5675),
    [sym_page_keyword] = ACTIONS(5673),
    [anon_sym_codeunit] = ACTIONS(5673),
    [anon_sym_CODEUNIT] = ACTIONS(5673),
    [anon_sym_Codeunit] = ACTIONS(5673),
    [anon_sym_CodeUnit] = ACTIONS(5673),
    [anon_sym_COdeunit] = ACTIONS(5673),
    [anon_sym_codeUnit] = ACTIONS(5673),
    [sym_report_keyword] = ACTIONS(5673),
    [sym_query_keyword] = ACTIONS(5673),
    [anon_sym_xmlport] = ACTIONS(5673),
    [anon_sym_XMLPORT] = ACTIONS(5673),
    [anon_sym_Xmlport] = ACTIONS(5673),
    [anon_sym_XMLport] = ACTIONS(5673),
    [anon_sym_XMLPort] = ACTIONS(5673),
    [anon_sym_XmlPort] = ACTIONS(5673),
    [anon_sym_enum] = ACTIONS(5673),
    [anon_sym_ENUM] = ACTIONS(5673),
    [anon_sym_Enum] = ACTIONS(5673),
    [anon_sym_eNUM] = ACTIONS(5673),
    [anon_sym_eNum] = ACTIONS(5673),
    [anon_sym_ENum] = ACTIONS(5673),
    [sym_quoted_identifier] = ACTIONS(5675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5675),
    [sym_verbatim_string] = ACTIONS(5675),
    [sym_integer] = ACTIONS(5673),
    [sym_continue_as_identifier] = ACTIONS(5675),
    [sym_preproc_open] = ACTIONS(5675),
    [sym_preproc_close] = ACTIONS(5675),
  },
  [STATE(2424)] = {
    [sym_identifier] = ACTIONS(5677),
    [anon_sym_SEMI] = ACTIONS(5679),
    [anon_sym_DASH] = ACTIONS(5679),
    [aux_sym_boolean_token1] = ACTIONS(5677),
    [aux_sym_boolean_token2] = ACTIONS(5677),
    [sym_decimal] = ACTIONS(5677),
    [anon_sym_LPAREN] = ACTIONS(5679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5677),
    [anon_sym_LBRACK] = ACTIONS(5679),
    [aux_sym_record_type_token1] = ACTIONS(5677),
    [aux_sym_basic_type_token21] = ACTIONS(5677),
    [aux_sym_basic_type_token22] = ACTIONS(5677),
    [aux_sym_basic_type_token48] = ACTIONS(5677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5677),
    [anon_sym_POUNDif] = ACTIONS(5679),
    [anon_sym_POUNDIF] = ACTIONS(5679),
    [anon_sym_POUNDIf] = ACTIONS(5679),
    [anon_sym_not] = ACTIONS(5677),
    [anon_sym_NOT] = ACTIONS(5677),
    [anon_sym_Not] = ACTIONS(5677),
    [anon_sym_POUNDelif] = ACTIONS(5679),
    [anon_sym_POUNDELIF] = ACTIONS(5679),
    [anon_sym_POUNDElif] = ACTIONS(5679),
    [anon_sym_POUNDelse] = ACTIONS(5679),
    [anon_sym_POUNDELSE] = ACTIONS(5679),
    [anon_sym_POUNDElse] = ACTIONS(5679),
    [anon_sym_POUNDelse2] = ACTIONS(5679),
    [anon_sym_POUNDELSE2] = ACTIONS(5679),
    [anon_sym_POUNDElse2] = ACTIONS(5679),
    [anon_sym_POUNDendif] = ACTIONS(5679),
    [anon_sym_POUNDENDIF] = ACTIONS(5679),
    [anon_sym_POUNDEndif] = ACTIONS(5679),
    [anon_sym_POUNDendif2] = ACTIONS(5679),
    [anon_sym_POUNDENDIF2] = ACTIONS(5679),
    [anon_sym_POUNDEndif2] = ACTIONS(5679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5677),
    [anon_sym_PLUS] = ACTIONS(5679),
    [sym_datetime_literal] = ACTIONS(5679),
    [sym_date_literal] = ACTIONS(5677),
    [sym_time_literal] = ACTIONS(5677),
    [sym_biginteger_literal] = ACTIONS(5679),
    [anon_sym_if] = ACTIONS(5677),
    [anon_sym_IF] = ACTIONS(5677),
    [anon_sym_If] = ACTIONS(5677),
    [anon_sym_else] = ACTIONS(5677),
    [anon_sym_ELSE] = ACTIONS(5677),
    [anon_sym_Else] = ACTIONS(5677),
    [anon_sym_case] = ACTIONS(5677),
    [anon_sym_CASE] = ACTIONS(5677),
    [anon_sym_Case] = ACTIONS(5677),
    [anon_sym_for] = ACTIONS(5677),
    [anon_sym_FOR] = ACTIONS(5677),
    [anon_sym_For] = ACTIONS(5677),
    [anon_sym_foreach] = ACTIONS(5677),
    [anon_sym_FOREACH] = ACTIONS(5677),
    [anon_sym_Foreach] = ACTIONS(5677),
    [anon_sym_while] = ACTIONS(5677),
    [anon_sym_WHILE] = ACTIONS(5677),
    [anon_sym_While] = ACTIONS(5677),
    [anon_sym_repeat] = ACTIONS(5677),
    [anon_sym_REPEAT] = ACTIONS(5677),
    [anon_sym_Repeat] = ACTIONS(5677),
    [anon_sym_exit] = ACTIONS(5677),
    [anon_sym_EXIT] = ACTIONS(5677),
    [anon_sym_Exit] = ACTIONS(5677),
    [anon_sym_continue] = ACTIONS(5677),
    [anon_sym_CONTINUE] = ACTIONS(5677),
    [anon_sym_Continue] = ACTIONS(5677),
    [anon_sym_break] = ACTIONS(5677),
    [anon_sym_BREAK] = ACTIONS(5677),
    [anon_sym_Break] = ACTIONS(5677),
    [anon_sym_with] = ACTIONS(5677),
    [anon_sym_WITH] = ACTIONS(5677),
    [anon_sym_With] = ACTIONS(5677),
    [sym_asserterror_keyword] = ACTIONS(5679),
    [sym_page_keyword] = ACTIONS(5677),
    [anon_sym_codeunit] = ACTIONS(5677),
    [anon_sym_CODEUNIT] = ACTIONS(5677),
    [anon_sym_Codeunit] = ACTIONS(5677),
    [anon_sym_CodeUnit] = ACTIONS(5677),
    [anon_sym_COdeunit] = ACTIONS(5677),
    [anon_sym_codeUnit] = ACTIONS(5677),
    [sym_report_keyword] = ACTIONS(5677),
    [sym_query_keyword] = ACTIONS(5677),
    [anon_sym_xmlport] = ACTIONS(5677),
    [anon_sym_XMLPORT] = ACTIONS(5677),
    [anon_sym_Xmlport] = ACTIONS(5677),
    [anon_sym_XMLport] = ACTIONS(5677),
    [anon_sym_XMLPort] = ACTIONS(5677),
    [anon_sym_XmlPort] = ACTIONS(5677),
    [anon_sym_enum] = ACTIONS(5677),
    [anon_sym_ENUM] = ACTIONS(5677),
    [anon_sym_Enum] = ACTIONS(5677),
    [anon_sym_eNUM] = ACTIONS(5677),
    [anon_sym_eNum] = ACTIONS(5677),
    [anon_sym_ENum] = ACTIONS(5677),
    [sym_quoted_identifier] = ACTIONS(5679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5679),
    [sym_verbatim_string] = ACTIONS(5679),
    [sym_integer] = ACTIONS(5677),
    [sym_continue_as_identifier] = ACTIONS(5679),
    [sym_preproc_open] = ACTIONS(5679),
    [sym_preproc_close] = ACTIONS(5679),
  },
  [STATE(2425)] = {
    [sym_identifier] = ACTIONS(5681),
    [anon_sym_SEMI] = ACTIONS(5683),
    [anon_sym_DASH] = ACTIONS(5683),
    [aux_sym_boolean_token1] = ACTIONS(5681),
    [aux_sym_boolean_token2] = ACTIONS(5681),
    [sym_decimal] = ACTIONS(5681),
    [anon_sym_LPAREN] = ACTIONS(5683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5681),
    [anon_sym_LBRACK] = ACTIONS(5683),
    [aux_sym_record_type_token1] = ACTIONS(5681),
    [aux_sym_basic_type_token21] = ACTIONS(5681),
    [aux_sym_basic_type_token22] = ACTIONS(5681),
    [aux_sym_basic_type_token48] = ACTIONS(5681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5681),
    [anon_sym_POUNDif] = ACTIONS(5683),
    [anon_sym_POUNDIF] = ACTIONS(5683),
    [anon_sym_POUNDIf] = ACTIONS(5683),
    [anon_sym_not] = ACTIONS(5681),
    [anon_sym_NOT] = ACTIONS(5681),
    [anon_sym_Not] = ACTIONS(5681),
    [anon_sym_POUNDelif] = ACTIONS(5683),
    [anon_sym_POUNDELIF] = ACTIONS(5683),
    [anon_sym_POUNDElif] = ACTIONS(5683),
    [anon_sym_POUNDelse] = ACTIONS(5683),
    [anon_sym_POUNDELSE] = ACTIONS(5683),
    [anon_sym_POUNDElse] = ACTIONS(5683),
    [anon_sym_POUNDelse2] = ACTIONS(5683),
    [anon_sym_POUNDELSE2] = ACTIONS(5683),
    [anon_sym_POUNDElse2] = ACTIONS(5683),
    [anon_sym_POUNDendif] = ACTIONS(5683),
    [anon_sym_POUNDENDIF] = ACTIONS(5683),
    [anon_sym_POUNDEndif] = ACTIONS(5683),
    [anon_sym_POUNDendif2] = ACTIONS(5683),
    [anon_sym_POUNDENDIF2] = ACTIONS(5683),
    [anon_sym_POUNDEndif2] = ACTIONS(5683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5681),
    [anon_sym_PLUS] = ACTIONS(5683),
    [sym_datetime_literal] = ACTIONS(5683),
    [sym_date_literal] = ACTIONS(5681),
    [sym_time_literal] = ACTIONS(5681),
    [sym_biginteger_literal] = ACTIONS(5683),
    [anon_sym_if] = ACTIONS(5681),
    [anon_sym_IF] = ACTIONS(5681),
    [anon_sym_If] = ACTIONS(5681),
    [anon_sym_else] = ACTIONS(5681),
    [anon_sym_ELSE] = ACTIONS(5681),
    [anon_sym_Else] = ACTIONS(5681),
    [anon_sym_case] = ACTIONS(5681),
    [anon_sym_CASE] = ACTIONS(5681),
    [anon_sym_Case] = ACTIONS(5681),
    [anon_sym_for] = ACTIONS(5681),
    [anon_sym_FOR] = ACTIONS(5681),
    [anon_sym_For] = ACTIONS(5681),
    [anon_sym_foreach] = ACTIONS(5681),
    [anon_sym_FOREACH] = ACTIONS(5681),
    [anon_sym_Foreach] = ACTIONS(5681),
    [anon_sym_while] = ACTIONS(5681),
    [anon_sym_WHILE] = ACTIONS(5681),
    [anon_sym_While] = ACTIONS(5681),
    [anon_sym_repeat] = ACTIONS(5681),
    [anon_sym_REPEAT] = ACTIONS(5681),
    [anon_sym_Repeat] = ACTIONS(5681),
    [anon_sym_exit] = ACTIONS(5681),
    [anon_sym_EXIT] = ACTIONS(5681),
    [anon_sym_Exit] = ACTIONS(5681),
    [anon_sym_continue] = ACTIONS(5681),
    [anon_sym_CONTINUE] = ACTIONS(5681),
    [anon_sym_Continue] = ACTIONS(5681),
    [anon_sym_break] = ACTIONS(5681),
    [anon_sym_BREAK] = ACTIONS(5681),
    [anon_sym_Break] = ACTIONS(5681),
    [anon_sym_with] = ACTIONS(5681),
    [anon_sym_WITH] = ACTIONS(5681),
    [anon_sym_With] = ACTIONS(5681),
    [sym_asserterror_keyword] = ACTIONS(5683),
    [sym_page_keyword] = ACTIONS(5681),
    [anon_sym_codeunit] = ACTIONS(5681),
    [anon_sym_CODEUNIT] = ACTIONS(5681),
    [anon_sym_Codeunit] = ACTIONS(5681),
    [anon_sym_CodeUnit] = ACTIONS(5681),
    [anon_sym_COdeunit] = ACTIONS(5681),
    [anon_sym_codeUnit] = ACTIONS(5681),
    [sym_report_keyword] = ACTIONS(5681),
    [sym_query_keyword] = ACTIONS(5681),
    [anon_sym_xmlport] = ACTIONS(5681),
    [anon_sym_XMLPORT] = ACTIONS(5681),
    [anon_sym_Xmlport] = ACTIONS(5681),
    [anon_sym_XMLport] = ACTIONS(5681),
    [anon_sym_XMLPort] = ACTIONS(5681),
    [anon_sym_XmlPort] = ACTIONS(5681),
    [anon_sym_enum] = ACTIONS(5681),
    [anon_sym_ENUM] = ACTIONS(5681),
    [anon_sym_Enum] = ACTIONS(5681),
    [anon_sym_eNUM] = ACTIONS(5681),
    [anon_sym_eNum] = ACTIONS(5681),
    [anon_sym_ENum] = ACTIONS(5681),
    [sym_quoted_identifier] = ACTIONS(5683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5683),
    [sym_verbatim_string] = ACTIONS(5683),
    [sym_integer] = ACTIONS(5681),
    [sym_continue_as_identifier] = ACTIONS(5683),
    [sym_preproc_open] = ACTIONS(5683),
    [sym_preproc_close] = ACTIONS(5683),
  },
  [STATE(2426)] = {
    [sym_identifier] = ACTIONS(5685),
    [anon_sym_SEMI] = ACTIONS(5687),
    [anon_sym_DASH] = ACTIONS(5687),
    [aux_sym_boolean_token1] = ACTIONS(5685),
    [aux_sym_boolean_token2] = ACTIONS(5685),
    [sym_decimal] = ACTIONS(5685),
    [anon_sym_LPAREN] = ACTIONS(5687),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5685),
    [anon_sym_LBRACK] = ACTIONS(5687),
    [aux_sym_record_type_token1] = ACTIONS(5685),
    [aux_sym_basic_type_token21] = ACTIONS(5685),
    [aux_sym_basic_type_token22] = ACTIONS(5685),
    [aux_sym_basic_type_token48] = ACTIONS(5685),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5685),
    [anon_sym_POUNDif] = ACTIONS(5687),
    [anon_sym_POUNDIF] = ACTIONS(5687),
    [anon_sym_POUNDIf] = ACTIONS(5687),
    [anon_sym_not] = ACTIONS(5685),
    [anon_sym_NOT] = ACTIONS(5685),
    [anon_sym_Not] = ACTIONS(5685),
    [anon_sym_POUNDelif] = ACTIONS(5687),
    [anon_sym_POUNDELIF] = ACTIONS(5687),
    [anon_sym_POUNDElif] = ACTIONS(5687),
    [anon_sym_POUNDelse] = ACTIONS(5687),
    [anon_sym_POUNDELSE] = ACTIONS(5687),
    [anon_sym_POUNDElse] = ACTIONS(5687),
    [anon_sym_POUNDelse2] = ACTIONS(5687),
    [anon_sym_POUNDELSE2] = ACTIONS(5687),
    [anon_sym_POUNDElse2] = ACTIONS(5687),
    [anon_sym_POUNDendif] = ACTIONS(5687),
    [anon_sym_POUNDENDIF] = ACTIONS(5687),
    [anon_sym_POUNDEndif] = ACTIONS(5687),
    [anon_sym_POUNDendif2] = ACTIONS(5687),
    [anon_sym_POUNDENDIF2] = ACTIONS(5687),
    [anon_sym_POUNDEndif2] = ACTIONS(5687),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5685),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5685),
    [anon_sym_PLUS] = ACTIONS(5687),
    [sym_datetime_literal] = ACTIONS(5687),
    [sym_date_literal] = ACTIONS(5685),
    [sym_time_literal] = ACTIONS(5685),
    [sym_biginteger_literal] = ACTIONS(5687),
    [anon_sym_if] = ACTIONS(5685),
    [anon_sym_IF] = ACTIONS(5685),
    [anon_sym_If] = ACTIONS(5685),
    [anon_sym_else] = ACTIONS(5685),
    [anon_sym_ELSE] = ACTIONS(5685),
    [anon_sym_Else] = ACTIONS(5685),
    [anon_sym_case] = ACTIONS(5685),
    [anon_sym_CASE] = ACTIONS(5685),
    [anon_sym_Case] = ACTIONS(5685),
    [anon_sym_for] = ACTIONS(5685),
    [anon_sym_FOR] = ACTIONS(5685),
    [anon_sym_For] = ACTIONS(5685),
    [anon_sym_foreach] = ACTIONS(5685),
    [anon_sym_FOREACH] = ACTIONS(5685),
    [anon_sym_Foreach] = ACTIONS(5685),
    [anon_sym_while] = ACTIONS(5685),
    [anon_sym_WHILE] = ACTIONS(5685),
    [anon_sym_While] = ACTIONS(5685),
    [anon_sym_repeat] = ACTIONS(5685),
    [anon_sym_REPEAT] = ACTIONS(5685),
    [anon_sym_Repeat] = ACTIONS(5685),
    [anon_sym_exit] = ACTIONS(5685),
    [anon_sym_EXIT] = ACTIONS(5685),
    [anon_sym_Exit] = ACTIONS(5685),
    [anon_sym_continue] = ACTIONS(5685),
    [anon_sym_CONTINUE] = ACTIONS(5685),
    [anon_sym_Continue] = ACTIONS(5685),
    [anon_sym_break] = ACTIONS(5685),
    [anon_sym_BREAK] = ACTIONS(5685),
    [anon_sym_Break] = ACTIONS(5685),
    [anon_sym_with] = ACTIONS(5685),
    [anon_sym_WITH] = ACTIONS(5685),
    [anon_sym_With] = ACTIONS(5685),
    [sym_asserterror_keyword] = ACTIONS(5687),
    [sym_page_keyword] = ACTIONS(5685),
    [anon_sym_codeunit] = ACTIONS(5685),
    [anon_sym_CODEUNIT] = ACTIONS(5685),
    [anon_sym_Codeunit] = ACTIONS(5685),
    [anon_sym_CodeUnit] = ACTIONS(5685),
    [anon_sym_COdeunit] = ACTIONS(5685),
    [anon_sym_codeUnit] = ACTIONS(5685),
    [sym_report_keyword] = ACTIONS(5685),
    [sym_query_keyword] = ACTIONS(5685),
    [anon_sym_xmlport] = ACTIONS(5685),
    [anon_sym_XMLPORT] = ACTIONS(5685),
    [anon_sym_Xmlport] = ACTIONS(5685),
    [anon_sym_XMLport] = ACTIONS(5685),
    [anon_sym_XMLPort] = ACTIONS(5685),
    [anon_sym_XmlPort] = ACTIONS(5685),
    [anon_sym_enum] = ACTIONS(5685),
    [anon_sym_ENUM] = ACTIONS(5685),
    [anon_sym_Enum] = ACTIONS(5685),
    [anon_sym_eNUM] = ACTIONS(5685),
    [anon_sym_eNum] = ACTIONS(5685),
    [anon_sym_ENum] = ACTIONS(5685),
    [sym_quoted_identifier] = ACTIONS(5687),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5687),
    [sym_verbatim_string] = ACTIONS(5687),
    [sym_integer] = ACTIONS(5685),
    [sym_continue_as_identifier] = ACTIONS(5687),
    [sym_preproc_open] = ACTIONS(5687),
    [sym_preproc_close] = ACTIONS(5687),
  },
  [STATE(2427)] = {
    [sym_identifier] = ACTIONS(5689),
    [anon_sym_SEMI] = ACTIONS(5691),
    [anon_sym_DASH] = ACTIONS(5691),
    [aux_sym_boolean_token1] = ACTIONS(5689),
    [aux_sym_boolean_token2] = ACTIONS(5689),
    [sym_decimal] = ACTIONS(5689),
    [anon_sym_LPAREN] = ACTIONS(5691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5689),
    [anon_sym_LBRACK] = ACTIONS(5691),
    [aux_sym_record_type_token1] = ACTIONS(5689),
    [aux_sym_basic_type_token21] = ACTIONS(5689),
    [aux_sym_basic_type_token22] = ACTIONS(5689),
    [aux_sym_basic_type_token48] = ACTIONS(5689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5689),
    [anon_sym_POUNDif] = ACTIONS(5691),
    [anon_sym_POUNDIF] = ACTIONS(5691),
    [anon_sym_POUNDIf] = ACTIONS(5691),
    [anon_sym_not] = ACTIONS(5689),
    [anon_sym_NOT] = ACTIONS(5689),
    [anon_sym_Not] = ACTIONS(5689),
    [anon_sym_POUNDelif] = ACTIONS(5691),
    [anon_sym_POUNDELIF] = ACTIONS(5691),
    [anon_sym_POUNDElif] = ACTIONS(5691),
    [anon_sym_POUNDelse] = ACTIONS(5691),
    [anon_sym_POUNDELSE] = ACTIONS(5691),
    [anon_sym_POUNDElse] = ACTIONS(5691),
    [anon_sym_POUNDelse2] = ACTIONS(5691),
    [anon_sym_POUNDELSE2] = ACTIONS(5691),
    [anon_sym_POUNDElse2] = ACTIONS(5691),
    [anon_sym_POUNDendif] = ACTIONS(5691),
    [anon_sym_POUNDENDIF] = ACTIONS(5691),
    [anon_sym_POUNDEndif] = ACTIONS(5691),
    [anon_sym_POUNDendif2] = ACTIONS(5691),
    [anon_sym_POUNDENDIF2] = ACTIONS(5691),
    [anon_sym_POUNDEndif2] = ACTIONS(5691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5689),
    [anon_sym_PLUS] = ACTIONS(5691),
    [sym_datetime_literal] = ACTIONS(5691),
    [sym_date_literal] = ACTIONS(5689),
    [sym_time_literal] = ACTIONS(5689),
    [sym_biginteger_literal] = ACTIONS(5691),
    [anon_sym_if] = ACTIONS(5689),
    [anon_sym_IF] = ACTIONS(5689),
    [anon_sym_If] = ACTIONS(5689),
    [anon_sym_else] = ACTIONS(5689),
    [anon_sym_ELSE] = ACTIONS(5689),
    [anon_sym_Else] = ACTIONS(5689),
    [anon_sym_case] = ACTIONS(5689),
    [anon_sym_CASE] = ACTIONS(5689),
    [anon_sym_Case] = ACTIONS(5689),
    [anon_sym_for] = ACTIONS(5689),
    [anon_sym_FOR] = ACTIONS(5689),
    [anon_sym_For] = ACTIONS(5689),
    [anon_sym_foreach] = ACTIONS(5689),
    [anon_sym_FOREACH] = ACTIONS(5689),
    [anon_sym_Foreach] = ACTIONS(5689),
    [anon_sym_while] = ACTIONS(5689),
    [anon_sym_WHILE] = ACTIONS(5689),
    [anon_sym_While] = ACTIONS(5689),
    [anon_sym_repeat] = ACTIONS(5689),
    [anon_sym_REPEAT] = ACTIONS(5689),
    [anon_sym_Repeat] = ACTIONS(5689),
    [anon_sym_exit] = ACTIONS(5689),
    [anon_sym_EXIT] = ACTIONS(5689),
    [anon_sym_Exit] = ACTIONS(5689),
    [anon_sym_continue] = ACTIONS(5689),
    [anon_sym_CONTINUE] = ACTIONS(5689),
    [anon_sym_Continue] = ACTIONS(5689),
    [anon_sym_break] = ACTIONS(5689),
    [anon_sym_BREAK] = ACTIONS(5689),
    [anon_sym_Break] = ACTIONS(5689),
    [anon_sym_with] = ACTIONS(5689),
    [anon_sym_WITH] = ACTIONS(5689),
    [anon_sym_With] = ACTIONS(5689),
    [sym_asserterror_keyword] = ACTIONS(5691),
    [sym_page_keyword] = ACTIONS(5689),
    [anon_sym_codeunit] = ACTIONS(5689),
    [anon_sym_CODEUNIT] = ACTIONS(5689),
    [anon_sym_Codeunit] = ACTIONS(5689),
    [anon_sym_CodeUnit] = ACTIONS(5689),
    [anon_sym_COdeunit] = ACTIONS(5689),
    [anon_sym_codeUnit] = ACTIONS(5689),
    [sym_report_keyword] = ACTIONS(5689),
    [sym_query_keyword] = ACTIONS(5689),
    [anon_sym_xmlport] = ACTIONS(5689),
    [anon_sym_XMLPORT] = ACTIONS(5689),
    [anon_sym_Xmlport] = ACTIONS(5689),
    [anon_sym_XMLport] = ACTIONS(5689),
    [anon_sym_XMLPort] = ACTIONS(5689),
    [anon_sym_XmlPort] = ACTIONS(5689),
    [anon_sym_enum] = ACTIONS(5689),
    [anon_sym_ENUM] = ACTIONS(5689),
    [anon_sym_Enum] = ACTIONS(5689),
    [anon_sym_eNUM] = ACTIONS(5689),
    [anon_sym_eNum] = ACTIONS(5689),
    [anon_sym_ENum] = ACTIONS(5689),
    [sym_quoted_identifier] = ACTIONS(5691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5691),
    [sym_verbatim_string] = ACTIONS(5691),
    [sym_integer] = ACTIONS(5689),
    [sym_continue_as_identifier] = ACTIONS(5691),
    [sym_preproc_open] = ACTIONS(5691),
    [sym_preproc_close] = ACTIONS(5691),
  },
  [STATE(2428)] = {
    [anon_sym_POUNDif] = ACTIONS(5372),
    [anon_sym_POUNDIF] = ACTIONS(5372),
    [anon_sym_POUNDIf] = ACTIONS(5372),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5693),
    [anon_sym_PIPE_PIPE] = ACTIONS(5693),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5695),
    [anon_sym_AMP_AMP] = ACTIONS(5695),
    [anon_sym_POUNDelif] = ACTIONS(5372),
    [anon_sym_POUNDELIF] = ACTIONS(5372),
    [anon_sym_POUNDElif] = ACTIONS(5372),
    [anon_sym_POUNDelse] = ACTIONS(5372),
    [anon_sym_POUNDELSE] = ACTIONS(5372),
    [anon_sym_POUNDElse] = ACTIONS(5372),
    [anon_sym_POUNDelse2] = ACTIONS(5372),
    [anon_sym_POUNDELSE2] = ACTIONS(5372),
    [anon_sym_POUNDElse2] = ACTIONS(5372),
    [anon_sym_POUNDendif] = ACTIONS(5372),
    [anon_sym_POUNDENDIF] = ACTIONS(5372),
    [anon_sym_POUNDEndif] = ACTIONS(5372),
    [anon_sym_POUNDendif2] = ACTIONS(5372),
    [anon_sym_POUNDENDIF2] = ACTIONS(5372),
    [anon_sym_POUNDEndif2] = ACTIONS(5372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5370),
    [anon_sym_tableextension] = ACTIONS(5372),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5372),
    [anon_sym_Tableextension] = ACTIONS(5372),
    [anon_sym_TableExtension] = ACTIONS(5372),
    [anon_sym_tableExtension] = ACTIONS(5372),
    [sym_page_keyword] = ACTIONS(5370),
    [anon_sym_pageextension] = ACTIONS(5372),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5372),
    [anon_sym_Pageextension] = ACTIONS(5372),
    [anon_sym_PageExtension] = ACTIONS(5372),
    [anon_sym_pageExtension] = ACTIONS(5372),
    [anon_sym_codeunit] = ACTIONS(5372),
    [anon_sym_CODEUNIT] = ACTIONS(5372),
    [anon_sym_Codeunit] = ACTIONS(5372),
    [anon_sym_CodeUnit] = ACTIONS(5372),
    [anon_sym_COdeunit] = ACTIONS(5372),
    [anon_sym_codeUnit] = ACTIONS(5372),
    [sym_report_keyword] = ACTIONS(5370),
    [anon_sym_reportextension] = ACTIONS(5372),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5372),
    [anon_sym_Reportextension] = ACTIONS(5372),
    [anon_sym_ReportExtension] = ACTIONS(5372),
    [anon_sym_reportExtension] = ACTIONS(5372),
    [sym_query_keyword] = ACTIONS(5372),
    [anon_sym_xmlport] = ACTIONS(5372),
    [anon_sym_XMLPORT] = ACTIONS(5372),
    [anon_sym_Xmlport] = ACTIONS(5372),
    [anon_sym_XMLport] = ACTIONS(5372),
    [anon_sym_XMLPort] = ACTIONS(5372),
    [anon_sym_XmlPort] = ACTIONS(5372),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_ENUM] = ACTIONS(5370),
    [anon_sym_Enum] = ACTIONS(5370),
    [anon_sym_eNUM] = ACTIONS(5372),
    [anon_sym_eNum] = ACTIONS(5372),
    [anon_sym_ENum] = ACTIONS(5372),
    [anon_sym_enumextension] = ACTIONS(5372),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5372),
    [anon_sym_Enumextension] = ACTIONS(5372),
    [anon_sym_EnumExtension] = ACTIONS(5372),
    [anon_sym_enumExtension] = ACTIONS(5372),
    [sym_interface_keyword] = ACTIONS(5372),
    [anon_sym_controladdin] = ACTIONS(5372),
    [anon_sym_CONTROLADDIN] = ACTIONS(5372),
    [anon_sym_Controladdin] = ACTIONS(5372),
    [anon_sym_ControlAddIn] = ACTIONS(5372),
    [anon_sym_ControlAddin] = ACTIONS(5372),
    [anon_sym_controlAddIn] = ACTIONS(5372),
    [anon_sym_controlAddin] = ACTIONS(5372),
    [anon_sym_dotnet] = ACTIONS(5372),
    [anon_sym_DOTNET] = ACTIONS(5372),
    [anon_sym_Dotnet] = ACTIONS(5372),
    [anon_sym_DotNet] = ACTIONS(5372),
    [anon_sym_dotNet] = ACTIONS(5372),
    [sym_profile_keyword] = ACTIONS(5370),
    [anon_sym_profileextension] = ACTIONS(5372),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5372),
    [anon_sym_Profileextension] = ACTIONS(5372),
    [anon_sym_ProfileExtension] = ACTIONS(5372),
    [anon_sym_profileExtension] = ACTIONS(5372),
    [anon_sym_permissionset] = ACTIONS(5370),
    [anon_sym_PERMISSIONSET] = ACTIONS(5370),
    [anon_sym_Permissionset] = ACTIONS(5370),
    [anon_sym_PermissionSet] = ACTIONS(5370),
    [anon_sym_permissionSet] = ACTIONS(5370),
    [anon_sym_permissionsetextension] = ACTIONS(5372),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5372),
    [anon_sym_Permissionsetextension] = ACTIONS(5372),
    [anon_sym_PermissionSetExtension] = ACTIONS(5372),
    [anon_sym_permissionSetExtension] = ACTIONS(5372),
    [sym_entitlement_keyword] = ACTIONS(5372),
    [anon_sym_pagecustomization] = ACTIONS(5372),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5372),
    [anon_sym_Pagecustomization] = ACTIONS(5372),
    [anon_sym_PageCustomization] = ACTIONS(5372),
    [anon_sym_pageCustomization] = ACTIONS(5372),
    [sym_namespace_keyword] = ACTIONS(5372),
    [sym_using_keyword] = ACTIONS(5372),
    [sym_fieldgroup_keyword] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5372),
    [sym_preproc_close] = ACTIONS(5372),
  },
  [STATE(2429)] = {
    [sym_identifier] = ACTIONS(5697),
    [anon_sym_SEMI] = ACTIONS(5699),
    [anon_sym_DASH] = ACTIONS(5699),
    [aux_sym_boolean_token1] = ACTIONS(5697),
    [aux_sym_boolean_token2] = ACTIONS(5697),
    [sym_decimal] = ACTIONS(5697),
    [anon_sym_LPAREN] = ACTIONS(5699),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5697),
    [anon_sym_LBRACK] = ACTIONS(5699),
    [aux_sym_record_type_token1] = ACTIONS(5697),
    [aux_sym_basic_type_token21] = ACTIONS(5697),
    [aux_sym_basic_type_token22] = ACTIONS(5697),
    [aux_sym_basic_type_token48] = ACTIONS(5697),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5697),
    [anon_sym_POUNDif] = ACTIONS(5699),
    [anon_sym_POUNDIF] = ACTIONS(5699),
    [anon_sym_POUNDIf] = ACTIONS(5699),
    [anon_sym_not] = ACTIONS(5697),
    [anon_sym_NOT] = ACTIONS(5697),
    [anon_sym_Not] = ACTIONS(5697),
    [anon_sym_POUNDelif] = ACTIONS(5699),
    [anon_sym_POUNDELIF] = ACTIONS(5699),
    [anon_sym_POUNDElif] = ACTIONS(5699),
    [anon_sym_POUNDelse] = ACTIONS(5699),
    [anon_sym_POUNDELSE] = ACTIONS(5699),
    [anon_sym_POUNDElse] = ACTIONS(5699),
    [anon_sym_POUNDelse2] = ACTIONS(5699),
    [anon_sym_POUNDELSE2] = ACTIONS(5699),
    [anon_sym_POUNDElse2] = ACTIONS(5699),
    [anon_sym_POUNDendif] = ACTIONS(5699),
    [anon_sym_POUNDENDIF] = ACTIONS(5699),
    [anon_sym_POUNDEndif] = ACTIONS(5699),
    [anon_sym_POUNDendif2] = ACTIONS(5699),
    [anon_sym_POUNDENDIF2] = ACTIONS(5699),
    [anon_sym_POUNDEndif2] = ACTIONS(5699),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5697),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5697),
    [anon_sym_PLUS] = ACTIONS(5699),
    [sym_datetime_literal] = ACTIONS(5699),
    [sym_date_literal] = ACTIONS(5697),
    [sym_time_literal] = ACTIONS(5697),
    [sym_biginteger_literal] = ACTIONS(5699),
    [anon_sym_if] = ACTIONS(5697),
    [anon_sym_IF] = ACTIONS(5697),
    [anon_sym_If] = ACTIONS(5697),
    [anon_sym_else] = ACTIONS(5697),
    [anon_sym_ELSE] = ACTIONS(5697),
    [anon_sym_Else] = ACTIONS(5697),
    [anon_sym_case] = ACTIONS(5697),
    [anon_sym_CASE] = ACTIONS(5697),
    [anon_sym_Case] = ACTIONS(5697),
    [anon_sym_for] = ACTIONS(5697),
    [anon_sym_FOR] = ACTIONS(5697),
    [anon_sym_For] = ACTIONS(5697),
    [anon_sym_foreach] = ACTIONS(5697),
    [anon_sym_FOREACH] = ACTIONS(5697),
    [anon_sym_Foreach] = ACTIONS(5697),
    [anon_sym_while] = ACTIONS(5697),
    [anon_sym_WHILE] = ACTIONS(5697),
    [anon_sym_While] = ACTIONS(5697),
    [anon_sym_repeat] = ACTIONS(5697),
    [anon_sym_REPEAT] = ACTIONS(5697),
    [anon_sym_Repeat] = ACTIONS(5697),
    [anon_sym_exit] = ACTIONS(5697),
    [anon_sym_EXIT] = ACTIONS(5697),
    [anon_sym_Exit] = ACTIONS(5697),
    [anon_sym_continue] = ACTIONS(5697),
    [anon_sym_CONTINUE] = ACTIONS(5697),
    [anon_sym_Continue] = ACTIONS(5697),
    [anon_sym_break] = ACTIONS(5697),
    [anon_sym_BREAK] = ACTIONS(5697),
    [anon_sym_Break] = ACTIONS(5697),
    [anon_sym_with] = ACTIONS(5697),
    [anon_sym_WITH] = ACTIONS(5697),
    [anon_sym_With] = ACTIONS(5697),
    [sym_asserterror_keyword] = ACTIONS(5699),
    [sym_page_keyword] = ACTIONS(5697),
    [anon_sym_codeunit] = ACTIONS(5697),
    [anon_sym_CODEUNIT] = ACTIONS(5697),
    [anon_sym_Codeunit] = ACTIONS(5697),
    [anon_sym_CodeUnit] = ACTIONS(5697),
    [anon_sym_COdeunit] = ACTIONS(5697),
    [anon_sym_codeUnit] = ACTIONS(5697),
    [sym_report_keyword] = ACTIONS(5697),
    [sym_query_keyword] = ACTIONS(5697),
    [anon_sym_xmlport] = ACTIONS(5697),
    [anon_sym_XMLPORT] = ACTIONS(5697),
    [anon_sym_Xmlport] = ACTIONS(5697),
    [anon_sym_XMLport] = ACTIONS(5697),
    [anon_sym_XMLPort] = ACTIONS(5697),
    [anon_sym_XmlPort] = ACTIONS(5697),
    [anon_sym_enum] = ACTIONS(5697),
    [anon_sym_ENUM] = ACTIONS(5697),
    [anon_sym_Enum] = ACTIONS(5697),
    [anon_sym_eNUM] = ACTIONS(5697),
    [anon_sym_eNum] = ACTIONS(5697),
    [anon_sym_ENum] = ACTIONS(5697),
    [sym_quoted_identifier] = ACTIONS(5699),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5699),
    [sym_verbatim_string] = ACTIONS(5699),
    [sym_integer] = ACTIONS(5697),
    [sym_continue_as_identifier] = ACTIONS(5699),
    [sym_preproc_open] = ACTIONS(5699),
    [sym_preproc_close] = ACTIONS(5699),
  },
  [STATE(2430)] = {
    [sym_identifier] = ACTIONS(5701),
    [anon_sym_SEMI] = ACTIONS(5703),
    [anon_sym_DASH] = ACTIONS(5703),
    [aux_sym_boolean_token1] = ACTIONS(5701),
    [aux_sym_boolean_token2] = ACTIONS(5701),
    [sym_decimal] = ACTIONS(5701),
    [anon_sym_LPAREN] = ACTIONS(5703),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5701),
    [anon_sym_LBRACK] = ACTIONS(5703),
    [aux_sym_record_type_token1] = ACTIONS(5701),
    [aux_sym_basic_type_token21] = ACTIONS(5701),
    [aux_sym_basic_type_token22] = ACTIONS(5701),
    [aux_sym_basic_type_token48] = ACTIONS(5701),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5701),
    [anon_sym_POUNDif] = ACTIONS(5703),
    [anon_sym_POUNDIF] = ACTIONS(5703),
    [anon_sym_POUNDIf] = ACTIONS(5703),
    [anon_sym_not] = ACTIONS(5701),
    [anon_sym_NOT] = ACTIONS(5701),
    [anon_sym_Not] = ACTIONS(5701),
    [anon_sym_POUNDelif] = ACTIONS(5703),
    [anon_sym_POUNDELIF] = ACTIONS(5703),
    [anon_sym_POUNDElif] = ACTIONS(5703),
    [anon_sym_POUNDelse] = ACTIONS(5703),
    [anon_sym_POUNDELSE] = ACTIONS(5703),
    [anon_sym_POUNDElse] = ACTIONS(5703),
    [anon_sym_POUNDelse2] = ACTIONS(5703),
    [anon_sym_POUNDELSE2] = ACTIONS(5703),
    [anon_sym_POUNDElse2] = ACTIONS(5703),
    [anon_sym_POUNDendif] = ACTIONS(5703),
    [anon_sym_POUNDENDIF] = ACTIONS(5703),
    [anon_sym_POUNDEndif] = ACTIONS(5703),
    [anon_sym_POUNDendif2] = ACTIONS(5703),
    [anon_sym_POUNDENDIF2] = ACTIONS(5703),
    [anon_sym_POUNDEndif2] = ACTIONS(5703),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5701),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5701),
    [anon_sym_PLUS] = ACTIONS(5703),
    [sym_datetime_literal] = ACTIONS(5703),
    [sym_date_literal] = ACTIONS(5701),
    [sym_time_literal] = ACTIONS(5701),
    [sym_biginteger_literal] = ACTIONS(5703),
    [anon_sym_if] = ACTIONS(5701),
    [anon_sym_IF] = ACTIONS(5701),
    [anon_sym_If] = ACTIONS(5701),
    [anon_sym_else] = ACTIONS(5701),
    [anon_sym_ELSE] = ACTIONS(5701),
    [anon_sym_Else] = ACTIONS(5701),
    [anon_sym_case] = ACTIONS(5701),
    [anon_sym_CASE] = ACTIONS(5701),
    [anon_sym_Case] = ACTIONS(5701),
    [anon_sym_for] = ACTIONS(5701),
    [anon_sym_FOR] = ACTIONS(5701),
    [anon_sym_For] = ACTIONS(5701),
    [anon_sym_foreach] = ACTIONS(5701),
    [anon_sym_FOREACH] = ACTIONS(5701),
    [anon_sym_Foreach] = ACTIONS(5701),
    [anon_sym_while] = ACTIONS(5701),
    [anon_sym_WHILE] = ACTIONS(5701),
    [anon_sym_While] = ACTIONS(5701),
    [anon_sym_repeat] = ACTIONS(5701),
    [anon_sym_REPEAT] = ACTIONS(5701),
    [anon_sym_Repeat] = ACTIONS(5701),
    [anon_sym_exit] = ACTIONS(5701),
    [anon_sym_EXIT] = ACTIONS(5701),
    [anon_sym_Exit] = ACTIONS(5701),
    [anon_sym_continue] = ACTIONS(5701),
    [anon_sym_CONTINUE] = ACTIONS(5701),
    [anon_sym_Continue] = ACTIONS(5701),
    [anon_sym_break] = ACTIONS(5701),
    [anon_sym_BREAK] = ACTIONS(5701),
    [anon_sym_Break] = ACTIONS(5701),
    [anon_sym_with] = ACTIONS(5701),
    [anon_sym_WITH] = ACTIONS(5701),
    [anon_sym_With] = ACTIONS(5701),
    [sym_asserterror_keyword] = ACTIONS(5703),
    [sym_page_keyword] = ACTIONS(5701),
    [anon_sym_codeunit] = ACTIONS(5701),
    [anon_sym_CODEUNIT] = ACTIONS(5701),
    [anon_sym_Codeunit] = ACTIONS(5701),
    [anon_sym_CodeUnit] = ACTIONS(5701),
    [anon_sym_COdeunit] = ACTIONS(5701),
    [anon_sym_codeUnit] = ACTIONS(5701),
    [sym_report_keyword] = ACTIONS(5701),
    [sym_query_keyword] = ACTIONS(5701),
    [anon_sym_xmlport] = ACTIONS(5701),
    [anon_sym_XMLPORT] = ACTIONS(5701),
    [anon_sym_Xmlport] = ACTIONS(5701),
    [anon_sym_XMLport] = ACTIONS(5701),
    [anon_sym_XMLPort] = ACTIONS(5701),
    [anon_sym_XmlPort] = ACTIONS(5701),
    [anon_sym_enum] = ACTIONS(5701),
    [anon_sym_ENUM] = ACTIONS(5701),
    [anon_sym_Enum] = ACTIONS(5701),
    [anon_sym_eNUM] = ACTIONS(5701),
    [anon_sym_eNum] = ACTIONS(5701),
    [anon_sym_ENum] = ACTIONS(5701),
    [sym_quoted_identifier] = ACTIONS(5703),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5703),
    [sym_verbatim_string] = ACTIONS(5703),
    [sym_integer] = ACTIONS(5701),
    [sym_continue_as_identifier] = ACTIONS(5703),
    [sym_preproc_open] = ACTIONS(5703),
    [sym_preproc_close] = ACTIONS(5703),
  },
  [STATE(2431)] = {
    [sym_identifier] = ACTIONS(5705),
    [anon_sym_SEMI] = ACTIONS(5707),
    [anon_sym_DASH] = ACTIONS(5707),
    [aux_sym_boolean_token1] = ACTIONS(5705),
    [aux_sym_boolean_token2] = ACTIONS(5705),
    [sym_decimal] = ACTIONS(5705),
    [anon_sym_LPAREN] = ACTIONS(5707),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5705),
    [anon_sym_LBRACK] = ACTIONS(5707),
    [aux_sym_record_type_token1] = ACTIONS(5705),
    [aux_sym_basic_type_token21] = ACTIONS(5705),
    [aux_sym_basic_type_token22] = ACTIONS(5705),
    [aux_sym_basic_type_token48] = ACTIONS(5705),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5705),
    [anon_sym_POUNDif] = ACTIONS(5707),
    [anon_sym_POUNDIF] = ACTIONS(5707),
    [anon_sym_POUNDIf] = ACTIONS(5707),
    [anon_sym_not] = ACTIONS(5705),
    [anon_sym_NOT] = ACTIONS(5705),
    [anon_sym_Not] = ACTIONS(5705),
    [anon_sym_POUNDelif] = ACTIONS(5707),
    [anon_sym_POUNDELIF] = ACTIONS(5707),
    [anon_sym_POUNDElif] = ACTIONS(5707),
    [anon_sym_POUNDelse] = ACTIONS(5707),
    [anon_sym_POUNDELSE] = ACTIONS(5707),
    [anon_sym_POUNDElse] = ACTIONS(5707),
    [anon_sym_POUNDelse2] = ACTIONS(5707),
    [anon_sym_POUNDELSE2] = ACTIONS(5707),
    [anon_sym_POUNDElse2] = ACTIONS(5707),
    [anon_sym_POUNDendif] = ACTIONS(5707),
    [anon_sym_POUNDENDIF] = ACTIONS(5707),
    [anon_sym_POUNDEndif] = ACTIONS(5707),
    [anon_sym_POUNDendif2] = ACTIONS(5707),
    [anon_sym_POUNDENDIF2] = ACTIONS(5707),
    [anon_sym_POUNDEndif2] = ACTIONS(5707),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5705),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5705),
    [anon_sym_PLUS] = ACTIONS(5707),
    [sym_datetime_literal] = ACTIONS(5707),
    [sym_date_literal] = ACTIONS(5705),
    [sym_time_literal] = ACTIONS(5705),
    [sym_biginteger_literal] = ACTIONS(5707),
    [anon_sym_if] = ACTIONS(5705),
    [anon_sym_IF] = ACTIONS(5705),
    [anon_sym_If] = ACTIONS(5705),
    [anon_sym_else] = ACTIONS(5705),
    [anon_sym_ELSE] = ACTIONS(5705),
    [anon_sym_Else] = ACTIONS(5705),
    [anon_sym_case] = ACTIONS(5705),
    [anon_sym_CASE] = ACTIONS(5705),
    [anon_sym_Case] = ACTIONS(5705),
    [anon_sym_for] = ACTIONS(5705),
    [anon_sym_FOR] = ACTIONS(5705),
    [anon_sym_For] = ACTIONS(5705),
    [anon_sym_foreach] = ACTIONS(5705),
    [anon_sym_FOREACH] = ACTIONS(5705),
    [anon_sym_Foreach] = ACTIONS(5705),
    [anon_sym_while] = ACTIONS(5705),
    [anon_sym_WHILE] = ACTIONS(5705),
    [anon_sym_While] = ACTIONS(5705),
    [anon_sym_repeat] = ACTIONS(5705),
    [anon_sym_REPEAT] = ACTIONS(5705),
    [anon_sym_Repeat] = ACTIONS(5705),
    [anon_sym_exit] = ACTIONS(5705),
    [anon_sym_EXIT] = ACTIONS(5705),
    [anon_sym_Exit] = ACTIONS(5705),
    [anon_sym_continue] = ACTIONS(5705),
    [anon_sym_CONTINUE] = ACTIONS(5705),
    [anon_sym_Continue] = ACTIONS(5705),
    [anon_sym_break] = ACTIONS(5705),
    [anon_sym_BREAK] = ACTIONS(5705),
    [anon_sym_Break] = ACTIONS(5705),
    [anon_sym_with] = ACTIONS(5705),
    [anon_sym_WITH] = ACTIONS(5705),
    [anon_sym_With] = ACTIONS(5705),
    [sym_asserterror_keyword] = ACTIONS(5707),
    [sym_page_keyword] = ACTIONS(5705),
    [anon_sym_codeunit] = ACTIONS(5705),
    [anon_sym_CODEUNIT] = ACTIONS(5705),
    [anon_sym_Codeunit] = ACTIONS(5705),
    [anon_sym_CodeUnit] = ACTIONS(5705),
    [anon_sym_COdeunit] = ACTIONS(5705),
    [anon_sym_codeUnit] = ACTIONS(5705),
    [sym_report_keyword] = ACTIONS(5705),
    [sym_query_keyword] = ACTIONS(5705),
    [anon_sym_xmlport] = ACTIONS(5705),
    [anon_sym_XMLPORT] = ACTIONS(5705),
    [anon_sym_Xmlport] = ACTIONS(5705),
    [anon_sym_XMLport] = ACTIONS(5705),
    [anon_sym_XMLPort] = ACTIONS(5705),
    [anon_sym_XmlPort] = ACTIONS(5705),
    [anon_sym_enum] = ACTIONS(5705),
    [anon_sym_ENUM] = ACTIONS(5705),
    [anon_sym_Enum] = ACTIONS(5705),
    [anon_sym_eNUM] = ACTIONS(5705),
    [anon_sym_eNum] = ACTIONS(5705),
    [anon_sym_ENum] = ACTIONS(5705),
    [sym_quoted_identifier] = ACTIONS(5707),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5707),
    [sym_verbatim_string] = ACTIONS(5707),
    [sym_integer] = ACTIONS(5705),
    [sym_continue_as_identifier] = ACTIONS(5707),
    [sym_preproc_open] = ACTIONS(5707),
    [sym_preproc_close] = ACTIONS(5707),
  },
  [STATE(2432)] = {
    [sym_identifier] = ACTIONS(5709),
    [anon_sym_SEMI] = ACTIONS(5711),
    [anon_sym_DASH] = ACTIONS(5711),
    [aux_sym_boolean_token1] = ACTIONS(5709),
    [aux_sym_boolean_token2] = ACTIONS(5709),
    [sym_decimal] = ACTIONS(5709),
    [anon_sym_LPAREN] = ACTIONS(5711),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5709),
    [anon_sym_LBRACK] = ACTIONS(5711),
    [aux_sym_record_type_token1] = ACTIONS(5709),
    [aux_sym_basic_type_token21] = ACTIONS(5709),
    [aux_sym_basic_type_token22] = ACTIONS(5709),
    [aux_sym_basic_type_token48] = ACTIONS(5709),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5709),
    [anon_sym_POUNDif] = ACTIONS(5711),
    [anon_sym_POUNDIF] = ACTIONS(5711),
    [anon_sym_POUNDIf] = ACTIONS(5711),
    [anon_sym_not] = ACTIONS(5709),
    [anon_sym_NOT] = ACTIONS(5709),
    [anon_sym_Not] = ACTIONS(5709),
    [anon_sym_POUNDelif] = ACTIONS(5711),
    [anon_sym_POUNDELIF] = ACTIONS(5711),
    [anon_sym_POUNDElif] = ACTIONS(5711),
    [anon_sym_POUNDelse] = ACTIONS(5711),
    [anon_sym_POUNDELSE] = ACTIONS(5711),
    [anon_sym_POUNDElse] = ACTIONS(5711),
    [anon_sym_POUNDelse2] = ACTIONS(5711),
    [anon_sym_POUNDELSE2] = ACTIONS(5711),
    [anon_sym_POUNDElse2] = ACTIONS(5711),
    [anon_sym_POUNDendif] = ACTIONS(5711),
    [anon_sym_POUNDENDIF] = ACTIONS(5711),
    [anon_sym_POUNDEndif] = ACTIONS(5711),
    [anon_sym_POUNDendif2] = ACTIONS(5711),
    [anon_sym_POUNDENDIF2] = ACTIONS(5711),
    [anon_sym_POUNDEndif2] = ACTIONS(5711),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5709),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5709),
    [anon_sym_PLUS] = ACTIONS(5711),
    [sym_datetime_literal] = ACTIONS(5711),
    [sym_date_literal] = ACTIONS(5709),
    [sym_time_literal] = ACTIONS(5709),
    [sym_biginteger_literal] = ACTIONS(5711),
    [anon_sym_if] = ACTIONS(5709),
    [anon_sym_IF] = ACTIONS(5709),
    [anon_sym_If] = ACTIONS(5709),
    [anon_sym_else] = ACTIONS(5709),
    [anon_sym_ELSE] = ACTIONS(5709),
    [anon_sym_Else] = ACTIONS(5709),
    [anon_sym_case] = ACTIONS(5709),
    [anon_sym_CASE] = ACTIONS(5709),
    [anon_sym_Case] = ACTIONS(5709),
    [anon_sym_for] = ACTIONS(5709),
    [anon_sym_FOR] = ACTIONS(5709),
    [anon_sym_For] = ACTIONS(5709),
    [anon_sym_foreach] = ACTIONS(5709),
    [anon_sym_FOREACH] = ACTIONS(5709),
    [anon_sym_Foreach] = ACTIONS(5709),
    [anon_sym_while] = ACTIONS(5709),
    [anon_sym_WHILE] = ACTIONS(5709),
    [anon_sym_While] = ACTIONS(5709),
    [anon_sym_repeat] = ACTIONS(5709),
    [anon_sym_REPEAT] = ACTIONS(5709),
    [anon_sym_Repeat] = ACTIONS(5709),
    [anon_sym_exit] = ACTIONS(5709),
    [anon_sym_EXIT] = ACTIONS(5709),
    [anon_sym_Exit] = ACTIONS(5709),
    [anon_sym_continue] = ACTIONS(5709),
    [anon_sym_CONTINUE] = ACTIONS(5709),
    [anon_sym_Continue] = ACTIONS(5709),
    [anon_sym_break] = ACTIONS(5709),
    [anon_sym_BREAK] = ACTIONS(5709),
    [anon_sym_Break] = ACTIONS(5709),
    [anon_sym_with] = ACTIONS(5709),
    [anon_sym_WITH] = ACTIONS(5709),
    [anon_sym_With] = ACTIONS(5709),
    [sym_asserterror_keyword] = ACTIONS(5711),
    [sym_page_keyword] = ACTIONS(5709),
    [anon_sym_codeunit] = ACTIONS(5709),
    [anon_sym_CODEUNIT] = ACTIONS(5709),
    [anon_sym_Codeunit] = ACTIONS(5709),
    [anon_sym_CodeUnit] = ACTIONS(5709),
    [anon_sym_COdeunit] = ACTIONS(5709),
    [anon_sym_codeUnit] = ACTIONS(5709),
    [sym_report_keyword] = ACTIONS(5709),
    [sym_query_keyword] = ACTIONS(5709),
    [anon_sym_xmlport] = ACTIONS(5709),
    [anon_sym_XMLPORT] = ACTIONS(5709),
    [anon_sym_Xmlport] = ACTIONS(5709),
    [anon_sym_XMLport] = ACTIONS(5709),
    [anon_sym_XMLPort] = ACTIONS(5709),
    [anon_sym_XmlPort] = ACTIONS(5709),
    [anon_sym_enum] = ACTIONS(5709),
    [anon_sym_ENUM] = ACTIONS(5709),
    [anon_sym_Enum] = ACTIONS(5709),
    [anon_sym_eNUM] = ACTIONS(5709),
    [anon_sym_eNum] = ACTIONS(5709),
    [anon_sym_ENum] = ACTIONS(5709),
    [sym_quoted_identifier] = ACTIONS(5711),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5711),
    [sym_verbatim_string] = ACTIONS(5711),
    [sym_integer] = ACTIONS(5709),
    [sym_continue_as_identifier] = ACTIONS(5711),
    [sym_preproc_open] = ACTIONS(5711),
    [sym_preproc_close] = ACTIONS(5711),
  },
  [STATE(2433)] = {
    [sym_identifier] = ACTIONS(5713),
    [anon_sym_SEMI] = ACTIONS(5715),
    [anon_sym_DASH] = ACTIONS(5715),
    [aux_sym_boolean_token1] = ACTIONS(5713),
    [aux_sym_boolean_token2] = ACTIONS(5713),
    [sym_decimal] = ACTIONS(5713),
    [anon_sym_LPAREN] = ACTIONS(5715),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5713),
    [anon_sym_LBRACK] = ACTIONS(5715),
    [aux_sym_record_type_token1] = ACTIONS(5713),
    [aux_sym_basic_type_token21] = ACTIONS(5713),
    [aux_sym_basic_type_token22] = ACTIONS(5713),
    [aux_sym_basic_type_token48] = ACTIONS(5713),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5713),
    [anon_sym_POUNDif] = ACTIONS(5715),
    [anon_sym_POUNDIF] = ACTIONS(5715),
    [anon_sym_POUNDIf] = ACTIONS(5715),
    [anon_sym_not] = ACTIONS(5713),
    [anon_sym_NOT] = ACTIONS(5713),
    [anon_sym_Not] = ACTIONS(5713),
    [anon_sym_POUNDelif] = ACTIONS(5715),
    [anon_sym_POUNDELIF] = ACTIONS(5715),
    [anon_sym_POUNDElif] = ACTIONS(5715),
    [anon_sym_POUNDelse] = ACTIONS(5715),
    [anon_sym_POUNDELSE] = ACTIONS(5715),
    [anon_sym_POUNDElse] = ACTIONS(5715),
    [anon_sym_POUNDelse2] = ACTIONS(5715),
    [anon_sym_POUNDELSE2] = ACTIONS(5715),
    [anon_sym_POUNDElse2] = ACTIONS(5715),
    [anon_sym_POUNDendif] = ACTIONS(5715),
    [anon_sym_POUNDENDIF] = ACTIONS(5715),
    [anon_sym_POUNDEndif] = ACTIONS(5715),
    [anon_sym_POUNDendif2] = ACTIONS(5715),
    [anon_sym_POUNDENDIF2] = ACTIONS(5715),
    [anon_sym_POUNDEndif2] = ACTIONS(5715),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5713),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5713),
    [anon_sym_PLUS] = ACTIONS(5715),
    [sym_datetime_literal] = ACTIONS(5715),
    [sym_date_literal] = ACTIONS(5713),
    [sym_time_literal] = ACTIONS(5713),
    [sym_biginteger_literal] = ACTIONS(5715),
    [anon_sym_if] = ACTIONS(5713),
    [anon_sym_IF] = ACTIONS(5713),
    [anon_sym_If] = ACTIONS(5713),
    [anon_sym_else] = ACTIONS(5713),
    [anon_sym_ELSE] = ACTIONS(5713),
    [anon_sym_Else] = ACTIONS(5713),
    [anon_sym_case] = ACTIONS(5713),
    [anon_sym_CASE] = ACTIONS(5713),
    [anon_sym_Case] = ACTIONS(5713),
    [anon_sym_for] = ACTIONS(5713),
    [anon_sym_FOR] = ACTIONS(5713),
    [anon_sym_For] = ACTIONS(5713),
    [anon_sym_foreach] = ACTIONS(5713),
    [anon_sym_FOREACH] = ACTIONS(5713),
    [anon_sym_Foreach] = ACTIONS(5713),
    [anon_sym_while] = ACTIONS(5713),
    [anon_sym_WHILE] = ACTIONS(5713),
    [anon_sym_While] = ACTIONS(5713),
    [anon_sym_repeat] = ACTIONS(5713),
    [anon_sym_REPEAT] = ACTIONS(5713),
    [anon_sym_Repeat] = ACTIONS(5713),
    [anon_sym_exit] = ACTIONS(5713),
    [anon_sym_EXIT] = ACTIONS(5713),
    [anon_sym_Exit] = ACTIONS(5713),
    [anon_sym_continue] = ACTIONS(5713),
    [anon_sym_CONTINUE] = ACTIONS(5713),
    [anon_sym_Continue] = ACTIONS(5713),
    [anon_sym_break] = ACTIONS(5713),
    [anon_sym_BREAK] = ACTIONS(5713),
    [anon_sym_Break] = ACTIONS(5713),
    [anon_sym_with] = ACTIONS(5713),
    [anon_sym_WITH] = ACTIONS(5713),
    [anon_sym_With] = ACTIONS(5713),
    [sym_asserterror_keyword] = ACTIONS(5715),
    [sym_page_keyword] = ACTIONS(5713),
    [anon_sym_codeunit] = ACTIONS(5713),
    [anon_sym_CODEUNIT] = ACTIONS(5713),
    [anon_sym_Codeunit] = ACTIONS(5713),
    [anon_sym_CodeUnit] = ACTIONS(5713),
    [anon_sym_COdeunit] = ACTIONS(5713),
    [anon_sym_codeUnit] = ACTIONS(5713),
    [sym_report_keyword] = ACTIONS(5713),
    [sym_query_keyword] = ACTIONS(5713),
    [anon_sym_xmlport] = ACTIONS(5713),
    [anon_sym_XMLPORT] = ACTIONS(5713),
    [anon_sym_Xmlport] = ACTIONS(5713),
    [anon_sym_XMLport] = ACTIONS(5713),
    [anon_sym_XMLPort] = ACTIONS(5713),
    [anon_sym_XmlPort] = ACTIONS(5713),
    [anon_sym_enum] = ACTIONS(5713),
    [anon_sym_ENUM] = ACTIONS(5713),
    [anon_sym_Enum] = ACTIONS(5713),
    [anon_sym_eNUM] = ACTIONS(5713),
    [anon_sym_eNum] = ACTIONS(5713),
    [anon_sym_ENum] = ACTIONS(5713),
    [sym_quoted_identifier] = ACTIONS(5715),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5715),
    [sym_verbatim_string] = ACTIONS(5715),
    [sym_integer] = ACTIONS(5713),
    [sym_continue_as_identifier] = ACTIONS(5715),
    [sym_preproc_open] = ACTIONS(5715),
    [sym_preproc_close] = ACTIONS(5715),
  },
  [STATE(2434)] = {
    [sym_identifier] = ACTIONS(5717),
    [anon_sym_SEMI] = ACTIONS(5719),
    [anon_sym_DASH] = ACTIONS(5719),
    [aux_sym_boolean_token1] = ACTIONS(5717),
    [aux_sym_boolean_token2] = ACTIONS(5717),
    [sym_decimal] = ACTIONS(5717),
    [anon_sym_LPAREN] = ACTIONS(5719),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5717),
    [anon_sym_LBRACK] = ACTIONS(5719),
    [aux_sym_record_type_token1] = ACTIONS(5717),
    [aux_sym_basic_type_token21] = ACTIONS(5717),
    [aux_sym_basic_type_token22] = ACTIONS(5717),
    [aux_sym_basic_type_token48] = ACTIONS(5717),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5717),
    [anon_sym_POUNDif] = ACTIONS(5719),
    [anon_sym_POUNDIF] = ACTIONS(5719),
    [anon_sym_POUNDIf] = ACTIONS(5719),
    [anon_sym_not] = ACTIONS(5717),
    [anon_sym_NOT] = ACTIONS(5717),
    [anon_sym_Not] = ACTIONS(5717),
    [anon_sym_POUNDelif] = ACTIONS(5719),
    [anon_sym_POUNDELIF] = ACTIONS(5719),
    [anon_sym_POUNDElif] = ACTIONS(5719),
    [anon_sym_POUNDelse] = ACTIONS(5719),
    [anon_sym_POUNDELSE] = ACTIONS(5719),
    [anon_sym_POUNDElse] = ACTIONS(5719),
    [anon_sym_POUNDelse2] = ACTIONS(5719),
    [anon_sym_POUNDELSE2] = ACTIONS(5719),
    [anon_sym_POUNDElse2] = ACTIONS(5719),
    [anon_sym_POUNDendif] = ACTIONS(5719),
    [anon_sym_POUNDENDIF] = ACTIONS(5719),
    [anon_sym_POUNDEndif] = ACTIONS(5719),
    [anon_sym_POUNDendif2] = ACTIONS(5719),
    [anon_sym_POUNDENDIF2] = ACTIONS(5719),
    [anon_sym_POUNDEndif2] = ACTIONS(5719),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5717),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5717),
    [anon_sym_PLUS] = ACTIONS(5719),
    [sym_datetime_literal] = ACTIONS(5719),
    [sym_date_literal] = ACTIONS(5717),
    [sym_time_literal] = ACTIONS(5717),
    [sym_biginteger_literal] = ACTIONS(5719),
    [anon_sym_if] = ACTIONS(5717),
    [anon_sym_IF] = ACTIONS(5717),
    [anon_sym_If] = ACTIONS(5717),
    [anon_sym_else] = ACTIONS(5717),
    [anon_sym_ELSE] = ACTIONS(5717),
    [anon_sym_Else] = ACTIONS(5717),
    [anon_sym_case] = ACTIONS(5717),
    [anon_sym_CASE] = ACTIONS(5717),
    [anon_sym_Case] = ACTIONS(5717),
    [anon_sym_for] = ACTIONS(5717),
    [anon_sym_FOR] = ACTIONS(5717),
    [anon_sym_For] = ACTIONS(5717),
    [anon_sym_foreach] = ACTIONS(5717),
    [anon_sym_FOREACH] = ACTIONS(5717),
    [anon_sym_Foreach] = ACTIONS(5717),
    [anon_sym_while] = ACTIONS(5717),
    [anon_sym_WHILE] = ACTIONS(5717),
    [anon_sym_While] = ACTIONS(5717),
    [anon_sym_repeat] = ACTIONS(5717),
    [anon_sym_REPEAT] = ACTIONS(5717),
    [anon_sym_Repeat] = ACTIONS(5717),
    [anon_sym_exit] = ACTIONS(5717),
    [anon_sym_EXIT] = ACTIONS(5717),
    [anon_sym_Exit] = ACTIONS(5717),
    [anon_sym_continue] = ACTIONS(5717),
    [anon_sym_CONTINUE] = ACTIONS(5717),
    [anon_sym_Continue] = ACTIONS(5717),
    [anon_sym_break] = ACTIONS(5717),
    [anon_sym_BREAK] = ACTIONS(5717),
    [anon_sym_Break] = ACTIONS(5717),
    [anon_sym_with] = ACTIONS(5717),
    [anon_sym_WITH] = ACTIONS(5717),
    [anon_sym_With] = ACTIONS(5717),
    [sym_asserterror_keyword] = ACTIONS(5719),
    [sym_page_keyword] = ACTIONS(5717),
    [anon_sym_codeunit] = ACTIONS(5717),
    [anon_sym_CODEUNIT] = ACTIONS(5717),
    [anon_sym_Codeunit] = ACTIONS(5717),
    [anon_sym_CodeUnit] = ACTIONS(5717),
    [anon_sym_COdeunit] = ACTIONS(5717),
    [anon_sym_codeUnit] = ACTIONS(5717),
    [sym_report_keyword] = ACTIONS(5717),
    [sym_query_keyword] = ACTIONS(5717),
    [anon_sym_xmlport] = ACTIONS(5717),
    [anon_sym_XMLPORT] = ACTIONS(5717),
    [anon_sym_Xmlport] = ACTIONS(5717),
    [anon_sym_XMLport] = ACTIONS(5717),
    [anon_sym_XMLPort] = ACTIONS(5717),
    [anon_sym_XmlPort] = ACTIONS(5717),
    [anon_sym_enum] = ACTIONS(5717),
    [anon_sym_ENUM] = ACTIONS(5717),
    [anon_sym_Enum] = ACTIONS(5717),
    [anon_sym_eNUM] = ACTIONS(5717),
    [anon_sym_eNum] = ACTIONS(5717),
    [anon_sym_ENum] = ACTIONS(5717),
    [sym_quoted_identifier] = ACTIONS(5719),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5719),
    [sym_verbatim_string] = ACTIONS(5719),
    [sym_integer] = ACTIONS(5717),
    [sym_continue_as_identifier] = ACTIONS(5719),
    [sym_preproc_open] = ACTIONS(5719),
    [sym_preproc_close] = ACTIONS(5719),
  },
  [STATE(2435)] = {
    [sym_identifier] = ACTIONS(5721),
    [anon_sym_SEMI] = ACTIONS(5723),
    [anon_sym_DASH] = ACTIONS(5723),
    [aux_sym_boolean_token1] = ACTIONS(5721),
    [aux_sym_boolean_token2] = ACTIONS(5721),
    [sym_decimal] = ACTIONS(5721),
    [anon_sym_LPAREN] = ACTIONS(5723),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5721),
    [anon_sym_LBRACK] = ACTIONS(5723),
    [aux_sym_record_type_token1] = ACTIONS(5721),
    [aux_sym_basic_type_token21] = ACTIONS(5721),
    [aux_sym_basic_type_token22] = ACTIONS(5721),
    [aux_sym_basic_type_token48] = ACTIONS(5721),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5721),
    [anon_sym_POUNDif] = ACTIONS(5723),
    [anon_sym_POUNDIF] = ACTIONS(5723),
    [anon_sym_POUNDIf] = ACTIONS(5723),
    [anon_sym_not] = ACTIONS(5721),
    [anon_sym_NOT] = ACTIONS(5721),
    [anon_sym_Not] = ACTIONS(5721),
    [anon_sym_POUNDelif] = ACTIONS(5723),
    [anon_sym_POUNDELIF] = ACTIONS(5723),
    [anon_sym_POUNDElif] = ACTIONS(5723),
    [anon_sym_POUNDelse] = ACTIONS(5723),
    [anon_sym_POUNDELSE] = ACTIONS(5723),
    [anon_sym_POUNDElse] = ACTIONS(5723),
    [anon_sym_POUNDelse2] = ACTIONS(5723),
    [anon_sym_POUNDELSE2] = ACTIONS(5723),
    [anon_sym_POUNDElse2] = ACTIONS(5723),
    [anon_sym_POUNDendif] = ACTIONS(5723),
    [anon_sym_POUNDENDIF] = ACTIONS(5723),
    [anon_sym_POUNDEndif] = ACTIONS(5723),
    [anon_sym_POUNDendif2] = ACTIONS(5723),
    [anon_sym_POUNDENDIF2] = ACTIONS(5723),
    [anon_sym_POUNDEndif2] = ACTIONS(5723),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5721),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5721),
    [anon_sym_PLUS] = ACTIONS(5723),
    [sym_datetime_literal] = ACTIONS(5723),
    [sym_date_literal] = ACTIONS(5721),
    [sym_time_literal] = ACTIONS(5721),
    [sym_biginteger_literal] = ACTIONS(5723),
    [anon_sym_if] = ACTIONS(5721),
    [anon_sym_IF] = ACTIONS(5721),
    [anon_sym_If] = ACTIONS(5721),
    [anon_sym_else] = ACTIONS(5721),
    [anon_sym_ELSE] = ACTIONS(5721),
    [anon_sym_Else] = ACTIONS(5721),
    [anon_sym_case] = ACTIONS(5721),
    [anon_sym_CASE] = ACTIONS(5721),
    [anon_sym_Case] = ACTIONS(5721),
    [anon_sym_for] = ACTIONS(5721),
    [anon_sym_FOR] = ACTIONS(5721),
    [anon_sym_For] = ACTIONS(5721),
    [anon_sym_foreach] = ACTIONS(5721),
    [anon_sym_FOREACH] = ACTIONS(5721),
    [anon_sym_Foreach] = ACTIONS(5721),
    [anon_sym_while] = ACTIONS(5721),
    [anon_sym_WHILE] = ACTIONS(5721),
    [anon_sym_While] = ACTIONS(5721),
    [anon_sym_repeat] = ACTIONS(5721),
    [anon_sym_REPEAT] = ACTIONS(5721),
    [anon_sym_Repeat] = ACTIONS(5721),
    [anon_sym_exit] = ACTIONS(5721),
    [anon_sym_EXIT] = ACTIONS(5721),
    [anon_sym_Exit] = ACTIONS(5721),
    [anon_sym_continue] = ACTIONS(5721),
    [anon_sym_CONTINUE] = ACTIONS(5721),
    [anon_sym_Continue] = ACTIONS(5721),
    [anon_sym_break] = ACTIONS(5721),
    [anon_sym_BREAK] = ACTIONS(5721),
    [anon_sym_Break] = ACTIONS(5721),
    [anon_sym_with] = ACTIONS(5721),
    [anon_sym_WITH] = ACTIONS(5721),
    [anon_sym_With] = ACTIONS(5721),
    [sym_asserterror_keyword] = ACTIONS(5723),
    [sym_page_keyword] = ACTIONS(5721),
    [anon_sym_codeunit] = ACTIONS(5721),
    [anon_sym_CODEUNIT] = ACTIONS(5721),
    [anon_sym_Codeunit] = ACTIONS(5721),
    [anon_sym_CodeUnit] = ACTIONS(5721),
    [anon_sym_COdeunit] = ACTIONS(5721),
    [anon_sym_codeUnit] = ACTIONS(5721),
    [sym_report_keyword] = ACTIONS(5721),
    [sym_query_keyword] = ACTIONS(5721),
    [anon_sym_xmlport] = ACTIONS(5721),
    [anon_sym_XMLPORT] = ACTIONS(5721),
    [anon_sym_Xmlport] = ACTIONS(5721),
    [anon_sym_XMLport] = ACTIONS(5721),
    [anon_sym_XMLPort] = ACTIONS(5721),
    [anon_sym_XmlPort] = ACTIONS(5721),
    [anon_sym_enum] = ACTIONS(5721),
    [anon_sym_ENUM] = ACTIONS(5721),
    [anon_sym_Enum] = ACTIONS(5721),
    [anon_sym_eNUM] = ACTIONS(5721),
    [anon_sym_eNum] = ACTIONS(5721),
    [anon_sym_ENum] = ACTIONS(5721),
    [sym_quoted_identifier] = ACTIONS(5723),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5723),
    [sym_verbatim_string] = ACTIONS(5723),
    [sym_integer] = ACTIONS(5721),
    [sym_continue_as_identifier] = ACTIONS(5723),
    [sym_preproc_open] = ACTIONS(5723),
    [sym_preproc_close] = ACTIONS(5723),
  },
  [STATE(2436)] = {
    [sym_identifier] = ACTIONS(5725),
    [anon_sym_SEMI] = ACTIONS(5727),
    [anon_sym_DASH] = ACTIONS(5727),
    [aux_sym_boolean_token1] = ACTIONS(5725),
    [aux_sym_boolean_token2] = ACTIONS(5725),
    [sym_decimal] = ACTIONS(5725),
    [anon_sym_LPAREN] = ACTIONS(5727),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5725),
    [anon_sym_LBRACK] = ACTIONS(5727),
    [aux_sym_record_type_token1] = ACTIONS(5725),
    [aux_sym_basic_type_token21] = ACTIONS(5725),
    [aux_sym_basic_type_token22] = ACTIONS(5725),
    [aux_sym_basic_type_token48] = ACTIONS(5725),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5725),
    [anon_sym_POUNDif] = ACTIONS(5727),
    [anon_sym_POUNDIF] = ACTIONS(5727),
    [anon_sym_POUNDIf] = ACTIONS(5727),
    [anon_sym_not] = ACTIONS(5725),
    [anon_sym_NOT] = ACTIONS(5725),
    [anon_sym_Not] = ACTIONS(5725),
    [anon_sym_POUNDelif] = ACTIONS(5727),
    [anon_sym_POUNDELIF] = ACTIONS(5727),
    [anon_sym_POUNDElif] = ACTIONS(5727),
    [anon_sym_POUNDelse] = ACTIONS(5727),
    [anon_sym_POUNDELSE] = ACTIONS(5727),
    [anon_sym_POUNDElse] = ACTIONS(5727),
    [anon_sym_POUNDelse2] = ACTIONS(5727),
    [anon_sym_POUNDELSE2] = ACTIONS(5727),
    [anon_sym_POUNDElse2] = ACTIONS(5727),
    [anon_sym_POUNDendif] = ACTIONS(5727),
    [anon_sym_POUNDENDIF] = ACTIONS(5727),
    [anon_sym_POUNDEndif] = ACTIONS(5727),
    [anon_sym_POUNDendif2] = ACTIONS(5727),
    [anon_sym_POUNDENDIF2] = ACTIONS(5727),
    [anon_sym_POUNDEndif2] = ACTIONS(5727),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5725),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5725),
    [anon_sym_PLUS] = ACTIONS(5727),
    [sym_datetime_literal] = ACTIONS(5727),
    [sym_date_literal] = ACTIONS(5725),
    [sym_time_literal] = ACTIONS(5725),
    [sym_biginteger_literal] = ACTIONS(5727),
    [anon_sym_if] = ACTIONS(5725),
    [anon_sym_IF] = ACTIONS(5725),
    [anon_sym_If] = ACTIONS(5725),
    [anon_sym_else] = ACTIONS(5725),
    [anon_sym_ELSE] = ACTIONS(5725),
    [anon_sym_Else] = ACTIONS(5725),
    [anon_sym_case] = ACTIONS(5725),
    [anon_sym_CASE] = ACTIONS(5725),
    [anon_sym_Case] = ACTIONS(5725),
    [anon_sym_for] = ACTIONS(5725),
    [anon_sym_FOR] = ACTIONS(5725),
    [anon_sym_For] = ACTIONS(5725),
    [anon_sym_foreach] = ACTIONS(5725),
    [anon_sym_FOREACH] = ACTIONS(5725),
    [anon_sym_Foreach] = ACTIONS(5725),
    [anon_sym_while] = ACTIONS(5725),
    [anon_sym_WHILE] = ACTIONS(5725),
    [anon_sym_While] = ACTIONS(5725),
    [anon_sym_repeat] = ACTIONS(5725),
    [anon_sym_REPEAT] = ACTIONS(5725),
    [anon_sym_Repeat] = ACTIONS(5725),
    [anon_sym_exit] = ACTIONS(5725),
    [anon_sym_EXIT] = ACTIONS(5725),
    [anon_sym_Exit] = ACTIONS(5725),
    [anon_sym_continue] = ACTIONS(5725),
    [anon_sym_CONTINUE] = ACTIONS(5725),
    [anon_sym_Continue] = ACTIONS(5725),
    [anon_sym_break] = ACTIONS(5725),
    [anon_sym_BREAK] = ACTIONS(5725),
    [anon_sym_Break] = ACTIONS(5725),
    [anon_sym_with] = ACTIONS(5725),
    [anon_sym_WITH] = ACTIONS(5725),
    [anon_sym_With] = ACTIONS(5725),
    [sym_asserterror_keyword] = ACTIONS(5727),
    [sym_page_keyword] = ACTIONS(5725),
    [anon_sym_codeunit] = ACTIONS(5725),
    [anon_sym_CODEUNIT] = ACTIONS(5725),
    [anon_sym_Codeunit] = ACTIONS(5725),
    [anon_sym_CodeUnit] = ACTIONS(5725),
    [anon_sym_COdeunit] = ACTIONS(5725),
    [anon_sym_codeUnit] = ACTIONS(5725),
    [sym_report_keyword] = ACTIONS(5725),
    [sym_query_keyword] = ACTIONS(5725),
    [anon_sym_xmlport] = ACTIONS(5725),
    [anon_sym_XMLPORT] = ACTIONS(5725),
    [anon_sym_Xmlport] = ACTIONS(5725),
    [anon_sym_XMLport] = ACTIONS(5725),
    [anon_sym_XMLPort] = ACTIONS(5725),
    [anon_sym_XmlPort] = ACTIONS(5725),
    [anon_sym_enum] = ACTIONS(5725),
    [anon_sym_ENUM] = ACTIONS(5725),
    [anon_sym_Enum] = ACTIONS(5725),
    [anon_sym_eNUM] = ACTIONS(5725),
    [anon_sym_eNum] = ACTIONS(5725),
    [anon_sym_ENum] = ACTIONS(5725),
    [sym_quoted_identifier] = ACTIONS(5727),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5727),
    [sym_verbatim_string] = ACTIONS(5727),
    [sym_integer] = ACTIONS(5725),
    [sym_continue_as_identifier] = ACTIONS(5727),
    [sym_preproc_open] = ACTIONS(5727),
    [sym_preproc_close] = ACTIONS(5727),
  },
  [STATE(2437)] = {
    [sym_identifier] = ACTIONS(5729),
    [anon_sym_SEMI] = ACTIONS(5731),
    [anon_sym_DASH] = ACTIONS(5731),
    [aux_sym_boolean_token1] = ACTIONS(5729),
    [aux_sym_boolean_token2] = ACTIONS(5729),
    [sym_decimal] = ACTIONS(5729),
    [anon_sym_LPAREN] = ACTIONS(5731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5729),
    [anon_sym_LBRACK] = ACTIONS(5731),
    [aux_sym_record_type_token1] = ACTIONS(5729),
    [aux_sym_basic_type_token21] = ACTIONS(5729),
    [aux_sym_basic_type_token22] = ACTIONS(5729),
    [aux_sym_basic_type_token48] = ACTIONS(5729),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5729),
    [anon_sym_POUNDif] = ACTIONS(5731),
    [anon_sym_POUNDIF] = ACTIONS(5731),
    [anon_sym_POUNDIf] = ACTIONS(5731),
    [anon_sym_not] = ACTIONS(5729),
    [anon_sym_NOT] = ACTIONS(5729),
    [anon_sym_Not] = ACTIONS(5729),
    [anon_sym_POUNDelif] = ACTIONS(5731),
    [anon_sym_POUNDELIF] = ACTIONS(5731),
    [anon_sym_POUNDElif] = ACTIONS(5731),
    [anon_sym_POUNDelse] = ACTIONS(5731),
    [anon_sym_POUNDELSE] = ACTIONS(5731),
    [anon_sym_POUNDElse] = ACTIONS(5731),
    [anon_sym_POUNDelse2] = ACTIONS(5731),
    [anon_sym_POUNDELSE2] = ACTIONS(5731),
    [anon_sym_POUNDElse2] = ACTIONS(5731),
    [anon_sym_POUNDendif] = ACTIONS(5731),
    [anon_sym_POUNDENDIF] = ACTIONS(5731),
    [anon_sym_POUNDEndif] = ACTIONS(5731),
    [anon_sym_POUNDendif2] = ACTIONS(5731),
    [anon_sym_POUNDENDIF2] = ACTIONS(5731),
    [anon_sym_POUNDEndif2] = ACTIONS(5731),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5729),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5729),
    [anon_sym_PLUS] = ACTIONS(5731),
    [sym_datetime_literal] = ACTIONS(5731),
    [sym_date_literal] = ACTIONS(5729),
    [sym_time_literal] = ACTIONS(5729),
    [sym_biginteger_literal] = ACTIONS(5731),
    [anon_sym_if] = ACTIONS(5729),
    [anon_sym_IF] = ACTIONS(5729),
    [anon_sym_If] = ACTIONS(5729),
    [anon_sym_else] = ACTIONS(5729),
    [anon_sym_ELSE] = ACTIONS(5729),
    [anon_sym_Else] = ACTIONS(5729),
    [anon_sym_case] = ACTIONS(5729),
    [anon_sym_CASE] = ACTIONS(5729),
    [anon_sym_Case] = ACTIONS(5729),
    [anon_sym_for] = ACTIONS(5729),
    [anon_sym_FOR] = ACTIONS(5729),
    [anon_sym_For] = ACTIONS(5729),
    [anon_sym_foreach] = ACTIONS(5729),
    [anon_sym_FOREACH] = ACTIONS(5729),
    [anon_sym_Foreach] = ACTIONS(5729),
    [anon_sym_while] = ACTIONS(5729),
    [anon_sym_WHILE] = ACTIONS(5729),
    [anon_sym_While] = ACTIONS(5729),
    [anon_sym_repeat] = ACTIONS(5729),
    [anon_sym_REPEAT] = ACTIONS(5729),
    [anon_sym_Repeat] = ACTIONS(5729),
    [anon_sym_exit] = ACTIONS(5729),
    [anon_sym_EXIT] = ACTIONS(5729),
    [anon_sym_Exit] = ACTIONS(5729),
    [anon_sym_continue] = ACTIONS(5729),
    [anon_sym_CONTINUE] = ACTIONS(5729),
    [anon_sym_Continue] = ACTIONS(5729),
    [anon_sym_break] = ACTIONS(5729),
    [anon_sym_BREAK] = ACTIONS(5729),
    [anon_sym_Break] = ACTIONS(5729),
    [anon_sym_with] = ACTIONS(5729),
    [anon_sym_WITH] = ACTIONS(5729),
    [anon_sym_With] = ACTIONS(5729),
    [sym_asserterror_keyword] = ACTIONS(5731),
    [sym_page_keyword] = ACTIONS(5729),
    [anon_sym_codeunit] = ACTIONS(5729),
    [anon_sym_CODEUNIT] = ACTIONS(5729),
    [anon_sym_Codeunit] = ACTIONS(5729),
    [anon_sym_CodeUnit] = ACTIONS(5729),
    [anon_sym_COdeunit] = ACTIONS(5729),
    [anon_sym_codeUnit] = ACTIONS(5729),
    [sym_report_keyword] = ACTIONS(5729),
    [sym_query_keyword] = ACTIONS(5729),
    [anon_sym_xmlport] = ACTIONS(5729),
    [anon_sym_XMLPORT] = ACTIONS(5729),
    [anon_sym_Xmlport] = ACTIONS(5729),
    [anon_sym_XMLport] = ACTIONS(5729),
    [anon_sym_XMLPort] = ACTIONS(5729),
    [anon_sym_XmlPort] = ACTIONS(5729),
    [anon_sym_enum] = ACTIONS(5729),
    [anon_sym_ENUM] = ACTIONS(5729),
    [anon_sym_Enum] = ACTIONS(5729),
    [anon_sym_eNUM] = ACTIONS(5729),
    [anon_sym_eNum] = ACTIONS(5729),
    [anon_sym_ENum] = ACTIONS(5729),
    [sym_quoted_identifier] = ACTIONS(5731),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5731),
    [sym_verbatim_string] = ACTIONS(5731),
    [sym_integer] = ACTIONS(5729),
    [sym_continue_as_identifier] = ACTIONS(5731),
    [sym_preproc_open] = ACTIONS(5731),
    [sym_preproc_close] = ACTIONS(5731),
  },
  [STATE(2438)] = {
    [sym_identifier] = ACTIONS(5733),
    [anon_sym_SEMI] = ACTIONS(5735),
    [anon_sym_DASH] = ACTIONS(5735),
    [aux_sym_boolean_token1] = ACTIONS(5733),
    [aux_sym_boolean_token2] = ACTIONS(5733),
    [sym_decimal] = ACTIONS(5733),
    [anon_sym_LPAREN] = ACTIONS(5735),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5733),
    [anon_sym_LBRACK] = ACTIONS(5735),
    [aux_sym_record_type_token1] = ACTIONS(5733),
    [aux_sym_basic_type_token21] = ACTIONS(5733),
    [aux_sym_basic_type_token22] = ACTIONS(5733),
    [aux_sym_basic_type_token48] = ACTIONS(5733),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5733),
    [anon_sym_POUNDif] = ACTIONS(5735),
    [anon_sym_POUNDIF] = ACTIONS(5735),
    [anon_sym_POUNDIf] = ACTIONS(5735),
    [anon_sym_not] = ACTIONS(5733),
    [anon_sym_NOT] = ACTIONS(5733),
    [anon_sym_Not] = ACTIONS(5733),
    [anon_sym_POUNDelif] = ACTIONS(5735),
    [anon_sym_POUNDELIF] = ACTIONS(5735),
    [anon_sym_POUNDElif] = ACTIONS(5735),
    [anon_sym_POUNDelse] = ACTIONS(5735),
    [anon_sym_POUNDELSE] = ACTIONS(5735),
    [anon_sym_POUNDElse] = ACTIONS(5735),
    [anon_sym_POUNDelse2] = ACTIONS(5735),
    [anon_sym_POUNDELSE2] = ACTIONS(5735),
    [anon_sym_POUNDElse2] = ACTIONS(5735),
    [anon_sym_POUNDendif] = ACTIONS(5735),
    [anon_sym_POUNDENDIF] = ACTIONS(5735),
    [anon_sym_POUNDEndif] = ACTIONS(5735),
    [anon_sym_POUNDendif2] = ACTIONS(5735),
    [anon_sym_POUNDENDIF2] = ACTIONS(5735),
    [anon_sym_POUNDEndif2] = ACTIONS(5735),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5733),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5733),
    [anon_sym_PLUS] = ACTIONS(5735),
    [sym_datetime_literal] = ACTIONS(5735),
    [sym_date_literal] = ACTIONS(5733),
    [sym_time_literal] = ACTIONS(5733),
    [sym_biginteger_literal] = ACTIONS(5735),
    [anon_sym_if] = ACTIONS(5733),
    [anon_sym_IF] = ACTIONS(5733),
    [anon_sym_If] = ACTIONS(5733),
    [anon_sym_else] = ACTIONS(5733),
    [anon_sym_ELSE] = ACTIONS(5733),
    [anon_sym_Else] = ACTIONS(5733),
    [anon_sym_case] = ACTIONS(5733),
    [anon_sym_CASE] = ACTIONS(5733),
    [anon_sym_Case] = ACTIONS(5733),
    [anon_sym_for] = ACTIONS(5733),
    [anon_sym_FOR] = ACTIONS(5733),
    [anon_sym_For] = ACTIONS(5733),
    [anon_sym_foreach] = ACTIONS(5733),
    [anon_sym_FOREACH] = ACTIONS(5733),
    [anon_sym_Foreach] = ACTIONS(5733),
    [anon_sym_while] = ACTIONS(5733),
    [anon_sym_WHILE] = ACTIONS(5733),
    [anon_sym_While] = ACTIONS(5733),
    [anon_sym_repeat] = ACTIONS(5733),
    [anon_sym_REPEAT] = ACTIONS(5733),
    [anon_sym_Repeat] = ACTIONS(5733),
    [anon_sym_exit] = ACTIONS(5733),
    [anon_sym_EXIT] = ACTIONS(5733),
    [anon_sym_Exit] = ACTIONS(5733),
    [anon_sym_continue] = ACTIONS(5733),
    [anon_sym_CONTINUE] = ACTIONS(5733),
    [anon_sym_Continue] = ACTIONS(5733),
    [anon_sym_break] = ACTIONS(5733),
    [anon_sym_BREAK] = ACTIONS(5733),
    [anon_sym_Break] = ACTIONS(5733),
    [anon_sym_with] = ACTIONS(5733),
    [anon_sym_WITH] = ACTIONS(5733),
    [anon_sym_With] = ACTIONS(5733),
    [sym_asserterror_keyword] = ACTIONS(5735),
    [sym_page_keyword] = ACTIONS(5733),
    [anon_sym_codeunit] = ACTIONS(5733),
    [anon_sym_CODEUNIT] = ACTIONS(5733),
    [anon_sym_Codeunit] = ACTIONS(5733),
    [anon_sym_CodeUnit] = ACTIONS(5733),
    [anon_sym_COdeunit] = ACTIONS(5733),
    [anon_sym_codeUnit] = ACTIONS(5733),
    [sym_report_keyword] = ACTIONS(5733),
    [sym_query_keyword] = ACTIONS(5733),
    [anon_sym_xmlport] = ACTIONS(5733),
    [anon_sym_XMLPORT] = ACTIONS(5733),
    [anon_sym_Xmlport] = ACTIONS(5733),
    [anon_sym_XMLport] = ACTIONS(5733),
    [anon_sym_XMLPort] = ACTIONS(5733),
    [anon_sym_XmlPort] = ACTIONS(5733),
    [anon_sym_enum] = ACTIONS(5733),
    [anon_sym_ENUM] = ACTIONS(5733),
    [anon_sym_Enum] = ACTIONS(5733),
    [anon_sym_eNUM] = ACTIONS(5733),
    [anon_sym_eNum] = ACTIONS(5733),
    [anon_sym_ENum] = ACTIONS(5733),
    [sym_quoted_identifier] = ACTIONS(5735),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5735),
    [sym_verbatim_string] = ACTIONS(5735),
    [sym_integer] = ACTIONS(5733),
    [sym_continue_as_identifier] = ACTIONS(5735),
    [sym_preproc_open] = ACTIONS(5735),
    [sym_preproc_close] = ACTIONS(5735),
  },
  [STATE(2439)] = {
    [sym_identifier] = ACTIONS(5737),
    [anon_sym_SEMI] = ACTIONS(5739),
    [anon_sym_DASH] = ACTIONS(5739),
    [aux_sym_boolean_token1] = ACTIONS(5737),
    [aux_sym_boolean_token2] = ACTIONS(5737),
    [sym_decimal] = ACTIONS(5737),
    [anon_sym_LPAREN] = ACTIONS(5739),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5737),
    [anon_sym_LBRACK] = ACTIONS(5739),
    [aux_sym_record_type_token1] = ACTIONS(5737),
    [aux_sym_basic_type_token21] = ACTIONS(5737),
    [aux_sym_basic_type_token22] = ACTIONS(5737),
    [aux_sym_basic_type_token48] = ACTIONS(5737),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5737),
    [anon_sym_POUNDif] = ACTIONS(5739),
    [anon_sym_POUNDIF] = ACTIONS(5739),
    [anon_sym_POUNDIf] = ACTIONS(5739),
    [anon_sym_not] = ACTIONS(5737),
    [anon_sym_NOT] = ACTIONS(5737),
    [anon_sym_Not] = ACTIONS(5737),
    [anon_sym_POUNDelif] = ACTIONS(5739),
    [anon_sym_POUNDELIF] = ACTIONS(5739),
    [anon_sym_POUNDElif] = ACTIONS(5739),
    [anon_sym_POUNDelse] = ACTIONS(5739),
    [anon_sym_POUNDELSE] = ACTIONS(5739),
    [anon_sym_POUNDElse] = ACTIONS(5739),
    [anon_sym_POUNDelse2] = ACTIONS(5739),
    [anon_sym_POUNDELSE2] = ACTIONS(5739),
    [anon_sym_POUNDElse2] = ACTIONS(5739),
    [anon_sym_POUNDendif] = ACTIONS(5739),
    [anon_sym_POUNDENDIF] = ACTIONS(5739),
    [anon_sym_POUNDEndif] = ACTIONS(5739),
    [anon_sym_POUNDendif2] = ACTIONS(5739),
    [anon_sym_POUNDENDIF2] = ACTIONS(5739),
    [anon_sym_POUNDEndif2] = ACTIONS(5739),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5737),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5737),
    [anon_sym_PLUS] = ACTIONS(5739),
    [sym_datetime_literal] = ACTIONS(5739),
    [sym_date_literal] = ACTIONS(5737),
    [sym_time_literal] = ACTIONS(5737),
    [sym_biginteger_literal] = ACTIONS(5739),
    [anon_sym_if] = ACTIONS(5737),
    [anon_sym_IF] = ACTIONS(5737),
    [anon_sym_If] = ACTIONS(5737),
    [anon_sym_else] = ACTIONS(5737),
    [anon_sym_ELSE] = ACTIONS(5737),
    [anon_sym_Else] = ACTIONS(5737),
    [anon_sym_case] = ACTIONS(5737),
    [anon_sym_CASE] = ACTIONS(5737),
    [anon_sym_Case] = ACTIONS(5737),
    [anon_sym_for] = ACTIONS(5737),
    [anon_sym_FOR] = ACTIONS(5737),
    [anon_sym_For] = ACTIONS(5737),
    [anon_sym_foreach] = ACTIONS(5737),
    [anon_sym_FOREACH] = ACTIONS(5737),
    [anon_sym_Foreach] = ACTIONS(5737),
    [anon_sym_while] = ACTIONS(5737),
    [anon_sym_WHILE] = ACTIONS(5737),
    [anon_sym_While] = ACTIONS(5737),
    [anon_sym_repeat] = ACTIONS(5737),
    [anon_sym_REPEAT] = ACTIONS(5737),
    [anon_sym_Repeat] = ACTIONS(5737),
    [anon_sym_exit] = ACTIONS(5737),
    [anon_sym_EXIT] = ACTIONS(5737),
    [anon_sym_Exit] = ACTIONS(5737),
    [anon_sym_continue] = ACTIONS(5737),
    [anon_sym_CONTINUE] = ACTIONS(5737),
    [anon_sym_Continue] = ACTIONS(5737),
    [anon_sym_break] = ACTIONS(5737),
    [anon_sym_BREAK] = ACTIONS(5737),
    [anon_sym_Break] = ACTIONS(5737),
    [anon_sym_with] = ACTIONS(5737),
    [anon_sym_WITH] = ACTIONS(5737),
    [anon_sym_With] = ACTIONS(5737),
    [sym_asserterror_keyword] = ACTIONS(5739),
    [sym_page_keyword] = ACTIONS(5737),
    [anon_sym_codeunit] = ACTIONS(5737),
    [anon_sym_CODEUNIT] = ACTIONS(5737),
    [anon_sym_Codeunit] = ACTIONS(5737),
    [anon_sym_CodeUnit] = ACTIONS(5737),
    [anon_sym_COdeunit] = ACTIONS(5737),
    [anon_sym_codeUnit] = ACTIONS(5737),
    [sym_report_keyword] = ACTIONS(5737),
    [sym_query_keyword] = ACTIONS(5737),
    [anon_sym_xmlport] = ACTIONS(5737),
    [anon_sym_XMLPORT] = ACTIONS(5737),
    [anon_sym_Xmlport] = ACTIONS(5737),
    [anon_sym_XMLport] = ACTIONS(5737),
    [anon_sym_XMLPort] = ACTIONS(5737),
    [anon_sym_XmlPort] = ACTIONS(5737),
    [anon_sym_enum] = ACTIONS(5737),
    [anon_sym_ENUM] = ACTIONS(5737),
    [anon_sym_Enum] = ACTIONS(5737),
    [anon_sym_eNUM] = ACTIONS(5737),
    [anon_sym_eNum] = ACTIONS(5737),
    [anon_sym_ENum] = ACTIONS(5737),
    [sym_quoted_identifier] = ACTIONS(5739),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5739),
    [sym_verbatim_string] = ACTIONS(5739),
    [sym_integer] = ACTIONS(5737),
    [sym_continue_as_identifier] = ACTIONS(5739),
    [sym_preproc_open] = ACTIONS(5739),
    [sym_preproc_close] = ACTIONS(5739),
  },
  [STATE(2440)] = {
    [sym_identifier] = ACTIONS(5741),
    [anon_sym_SEMI] = ACTIONS(5743),
    [anon_sym_DASH] = ACTIONS(5743),
    [aux_sym_boolean_token1] = ACTIONS(5741),
    [aux_sym_boolean_token2] = ACTIONS(5741),
    [sym_decimal] = ACTIONS(5741),
    [anon_sym_LPAREN] = ACTIONS(5743),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5741),
    [anon_sym_LBRACK] = ACTIONS(5743),
    [aux_sym_record_type_token1] = ACTIONS(5741),
    [aux_sym_basic_type_token21] = ACTIONS(5741),
    [aux_sym_basic_type_token22] = ACTIONS(5741),
    [aux_sym_basic_type_token48] = ACTIONS(5741),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5741),
    [anon_sym_POUNDif] = ACTIONS(5743),
    [anon_sym_POUNDIF] = ACTIONS(5743),
    [anon_sym_POUNDIf] = ACTIONS(5743),
    [anon_sym_not] = ACTIONS(5741),
    [anon_sym_NOT] = ACTIONS(5741),
    [anon_sym_Not] = ACTIONS(5741),
    [anon_sym_POUNDelif] = ACTIONS(5743),
    [anon_sym_POUNDELIF] = ACTIONS(5743),
    [anon_sym_POUNDElif] = ACTIONS(5743),
    [anon_sym_POUNDelse] = ACTIONS(5743),
    [anon_sym_POUNDELSE] = ACTIONS(5743),
    [anon_sym_POUNDElse] = ACTIONS(5743),
    [anon_sym_POUNDelse2] = ACTIONS(5743),
    [anon_sym_POUNDELSE2] = ACTIONS(5743),
    [anon_sym_POUNDElse2] = ACTIONS(5743),
    [anon_sym_POUNDendif] = ACTIONS(5743),
    [anon_sym_POUNDENDIF] = ACTIONS(5743),
    [anon_sym_POUNDEndif] = ACTIONS(5743),
    [anon_sym_POUNDendif2] = ACTIONS(5743),
    [anon_sym_POUNDENDIF2] = ACTIONS(5743),
    [anon_sym_POUNDEndif2] = ACTIONS(5743),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5741),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5741),
    [anon_sym_PLUS] = ACTIONS(5743),
    [sym_datetime_literal] = ACTIONS(5743),
    [sym_date_literal] = ACTIONS(5741),
    [sym_time_literal] = ACTIONS(5741),
    [sym_biginteger_literal] = ACTIONS(5743),
    [anon_sym_if] = ACTIONS(5741),
    [anon_sym_IF] = ACTIONS(5741),
    [anon_sym_If] = ACTIONS(5741),
    [anon_sym_else] = ACTIONS(5741),
    [anon_sym_ELSE] = ACTIONS(5741),
    [anon_sym_Else] = ACTIONS(5741),
    [anon_sym_case] = ACTIONS(5741),
    [anon_sym_CASE] = ACTIONS(5741),
    [anon_sym_Case] = ACTIONS(5741),
    [anon_sym_for] = ACTIONS(5741),
    [anon_sym_FOR] = ACTIONS(5741),
    [anon_sym_For] = ACTIONS(5741),
    [anon_sym_foreach] = ACTIONS(5741),
    [anon_sym_FOREACH] = ACTIONS(5741),
    [anon_sym_Foreach] = ACTIONS(5741),
    [anon_sym_while] = ACTIONS(5741),
    [anon_sym_WHILE] = ACTIONS(5741),
    [anon_sym_While] = ACTIONS(5741),
    [anon_sym_repeat] = ACTIONS(5741),
    [anon_sym_REPEAT] = ACTIONS(5741),
    [anon_sym_Repeat] = ACTIONS(5741),
    [anon_sym_exit] = ACTIONS(5741),
    [anon_sym_EXIT] = ACTIONS(5741),
    [anon_sym_Exit] = ACTIONS(5741),
    [anon_sym_continue] = ACTIONS(5741),
    [anon_sym_CONTINUE] = ACTIONS(5741),
    [anon_sym_Continue] = ACTIONS(5741),
    [anon_sym_break] = ACTIONS(5741),
    [anon_sym_BREAK] = ACTIONS(5741),
    [anon_sym_Break] = ACTIONS(5741),
    [anon_sym_with] = ACTIONS(5741),
    [anon_sym_WITH] = ACTIONS(5741),
    [anon_sym_With] = ACTIONS(5741),
    [sym_asserterror_keyword] = ACTIONS(5743),
    [sym_page_keyword] = ACTIONS(5741),
    [anon_sym_codeunit] = ACTIONS(5741),
    [anon_sym_CODEUNIT] = ACTIONS(5741),
    [anon_sym_Codeunit] = ACTIONS(5741),
    [anon_sym_CodeUnit] = ACTIONS(5741),
    [anon_sym_COdeunit] = ACTIONS(5741),
    [anon_sym_codeUnit] = ACTIONS(5741),
    [sym_report_keyword] = ACTIONS(5741),
    [sym_query_keyword] = ACTIONS(5741),
    [anon_sym_xmlport] = ACTIONS(5741),
    [anon_sym_XMLPORT] = ACTIONS(5741),
    [anon_sym_Xmlport] = ACTIONS(5741),
    [anon_sym_XMLport] = ACTIONS(5741),
    [anon_sym_XMLPort] = ACTIONS(5741),
    [anon_sym_XmlPort] = ACTIONS(5741),
    [anon_sym_enum] = ACTIONS(5741),
    [anon_sym_ENUM] = ACTIONS(5741),
    [anon_sym_Enum] = ACTIONS(5741),
    [anon_sym_eNUM] = ACTIONS(5741),
    [anon_sym_eNum] = ACTIONS(5741),
    [anon_sym_ENum] = ACTIONS(5741),
    [sym_quoted_identifier] = ACTIONS(5743),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5743),
    [sym_verbatim_string] = ACTIONS(5743),
    [sym_integer] = ACTIONS(5741),
    [sym_continue_as_identifier] = ACTIONS(5743),
    [sym_preproc_open] = ACTIONS(5743),
    [sym_preproc_close] = ACTIONS(5743),
  },
  [STATE(2441)] = {
    [sym_identifier] = ACTIONS(5745),
    [anon_sym_SEMI] = ACTIONS(5747),
    [anon_sym_DASH] = ACTIONS(5747),
    [aux_sym_boolean_token1] = ACTIONS(5745),
    [aux_sym_boolean_token2] = ACTIONS(5745),
    [sym_decimal] = ACTIONS(5745),
    [anon_sym_LPAREN] = ACTIONS(5747),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5745),
    [anon_sym_LBRACK] = ACTIONS(5747),
    [aux_sym_record_type_token1] = ACTIONS(5745),
    [aux_sym_basic_type_token21] = ACTIONS(5745),
    [aux_sym_basic_type_token22] = ACTIONS(5745),
    [aux_sym_basic_type_token48] = ACTIONS(5745),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5745),
    [anon_sym_POUNDif] = ACTIONS(5747),
    [anon_sym_POUNDIF] = ACTIONS(5747),
    [anon_sym_POUNDIf] = ACTIONS(5747),
    [anon_sym_not] = ACTIONS(5745),
    [anon_sym_NOT] = ACTIONS(5745),
    [anon_sym_Not] = ACTIONS(5745),
    [anon_sym_POUNDelif] = ACTIONS(5747),
    [anon_sym_POUNDELIF] = ACTIONS(5747),
    [anon_sym_POUNDElif] = ACTIONS(5747),
    [anon_sym_POUNDelse] = ACTIONS(5747),
    [anon_sym_POUNDELSE] = ACTIONS(5747),
    [anon_sym_POUNDElse] = ACTIONS(5747),
    [anon_sym_POUNDelse2] = ACTIONS(5747),
    [anon_sym_POUNDELSE2] = ACTIONS(5747),
    [anon_sym_POUNDElse2] = ACTIONS(5747),
    [anon_sym_POUNDendif] = ACTIONS(5747),
    [anon_sym_POUNDENDIF] = ACTIONS(5747),
    [anon_sym_POUNDEndif] = ACTIONS(5747),
    [anon_sym_POUNDendif2] = ACTIONS(5747),
    [anon_sym_POUNDENDIF2] = ACTIONS(5747),
    [anon_sym_POUNDEndif2] = ACTIONS(5747),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5745),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5745),
    [anon_sym_PLUS] = ACTIONS(5747),
    [sym_datetime_literal] = ACTIONS(5747),
    [sym_date_literal] = ACTIONS(5745),
    [sym_time_literal] = ACTIONS(5745),
    [sym_biginteger_literal] = ACTIONS(5747),
    [anon_sym_if] = ACTIONS(5745),
    [anon_sym_IF] = ACTIONS(5745),
    [anon_sym_If] = ACTIONS(5745),
    [anon_sym_else] = ACTIONS(5745),
    [anon_sym_ELSE] = ACTIONS(5745),
    [anon_sym_Else] = ACTIONS(5745),
    [anon_sym_case] = ACTIONS(5745),
    [anon_sym_CASE] = ACTIONS(5745),
    [anon_sym_Case] = ACTIONS(5745),
    [anon_sym_for] = ACTIONS(5745),
    [anon_sym_FOR] = ACTIONS(5745),
    [anon_sym_For] = ACTIONS(5745),
    [anon_sym_foreach] = ACTIONS(5745),
    [anon_sym_FOREACH] = ACTIONS(5745),
    [anon_sym_Foreach] = ACTIONS(5745),
    [anon_sym_while] = ACTIONS(5745),
    [anon_sym_WHILE] = ACTIONS(5745),
    [anon_sym_While] = ACTIONS(5745),
    [anon_sym_repeat] = ACTIONS(5745),
    [anon_sym_REPEAT] = ACTIONS(5745),
    [anon_sym_Repeat] = ACTIONS(5745),
    [anon_sym_exit] = ACTIONS(5745),
    [anon_sym_EXIT] = ACTIONS(5745),
    [anon_sym_Exit] = ACTIONS(5745),
    [anon_sym_continue] = ACTIONS(5745),
    [anon_sym_CONTINUE] = ACTIONS(5745),
    [anon_sym_Continue] = ACTIONS(5745),
    [anon_sym_break] = ACTIONS(5745),
    [anon_sym_BREAK] = ACTIONS(5745),
    [anon_sym_Break] = ACTIONS(5745),
    [anon_sym_with] = ACTIONS(5745),
    [anon_sym_WITH] = ACTIONS(5745),
    [anon_sym_With] = ACTIONS(5745),
    [sym_asserterror_keyword] = ACTIONS(5747),
    [sym_page_keyword] = ACTIONS(5745),
    [anon_sym_codeunit] = ACTIONS(5745),
    [anon_sym_CODEUNIT] = ACTIONS(5745),
    [anon_sym_Codeunit] = ACTIONS(5745),
    [anon_sym_CodeUnit] = ACTIONS(5745),
    [anon_sym_COdeunit] = ACTIONS(5745),
    [anon_sym_codeUnit] = ACTIONS(5745),
    [sym_report_keyword] = ACTIONS(5745),
    [sym_query_keyword] = ACTIONS(5745),
    [anon_sym_xmlport] = ACTIONS(5745),
    [anon_sym_XMLPORT] = ACTIONS(5745),
    [anon_sym_Xmlport] = ACTIONS(5745),
    [anon_sym_XMLport] = ACTIONS(5745),
    [anon_sym_XMLPort] = ACTIONS(5745),
    [anon_sym_XmlPort] = ACTIONS(5745),
    [anon_sym_enum] = ACTIONS(5745),
    [anon_sym_ENUM] = ACTIONS(5745),
    [anon_sym_Enum] = ACTIONS(5745),
    [anon_sym_eNUM] = ACTIONS(5745),
    [anon_sym_eNum] = ACTIONS(5745),
    [anon_sym_ENum] = ACTIONS(5745),
    [sym_quoted_identifier] = ACTIONS(5747),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5747),
    [sym_verbatim_string] = ACTIONS(5747),
    [sym_integer] = ACTIONS(5745),
    [sym_continue_as_identifier] = ACTIONS(5747),
    [sym_preproc_open] = ACTIONS(5747),
    [sym_preproc_close] = ACTIONS(5747),
  },
  [STATE(2442)] = {
    [sym_identifier] = ACTIONS(5749),
    [anon_sym_SEMI] = ACTIONS(5751),
    [anon_sym_DASH] = ACTIONS(5751),
    [aux_sym_boolean_token1] = ACTIONS(5749),
    [aux_sym_boolean_token2] = ACTIONS(5749),
    [sym_decimal] = ACTIONS(5749),
    [anon_sym_LPAREN] = ACTIONS(5751),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5749),
    [anon_sym_LBRACK] = ACTIONS(5751),
    [aux_sym_record_type_token1] = ACTIONS(5749),
    [aux_sym_basic_type_token21] = ACTIONS(5749),
    [aux_sym_basic_type_token22] = ACTIONS(5749),
    [aux_sym_basic_type_token48] = ACTIONS(5749),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5749),
    [anon_sym_POUNDif] = ACTIONS(5751),
    [anon_sym_POUNDIF] = ACTIONS(5751),
    [anon_sym_POUNDIf] = ACTIONS(5751),
    [anon_sym_not] = ACTIONS(5749),
    [anon_sym_NOT] = ACTIONS(5749),
    [anon_sym_Not] = ACTIONS(5749),
    [anon_sym_POUNDelif] = ACTIONS(5751),
    [anon_sym_POUNDELIF] = ACTIONS(5751),
    [anon_sym_POUNDElif] = ACTIONS(5751),
    [anon_sym_POUNDelse] = ACTIONS(5751),
    [anon_sym_POUNDELSE] = ACTIONS(5751),
    [anon_sym_POUNDElse] = ACTIONS(5751),
    [anon_sym_POUNDelse2] = ACTIONS(5751),
    [anon_sym_POUNDELSE2] = ACTIONS(5751),
    [anon_sym_POUNDElse2] = ACTIONS(5751),
    [anon_sym_POUNDendif] = ACTIONS(5751),
    [anon_sym_POUNDENDIF] = ACTIONS(5751),
    [anon_sym_POUNDEndif] = ACTIONS(5751),
    [anon_sym_POUNDendif2] = ACTIONS(5751),
    [anon_sym_POUNDENDIF2] = ACTIONS(5751),
    [anon_sym_POUNDEndif2] = ACTIONS(5751),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5749),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5749),
    [anon_sym_PLUS] = ACTIONS(5751),
    [sym_datetime_literal] = ACTIONS(5751),
    [sym_date_literal] = ACTIONS(5749),
    [sym_time_literal] = ACTIONS(5749),
    [sym_biginteger_literal] = ACTIONS(5751),
    [anon_sym_if] = ACTIONS(5749),
    [anon_sym_IF] = ACTIONS(5749),
    [anon_sym_If] = ACTIONS(5749),
    [anon_sym_else] = ACTIONS(5749),
    [anon_sym_ELSE] = ACTIONS(5749),
    [anon_sym_Else] = ACTIONS(5749),
    [anon_sym_case] = ACTIONS(5749),
    [anon_sym_CASE] = ACTIONS(5749),
    [anon_sym_Case] = ACTIONS(5749),
    [anon_sym_for] = ACTIONS(5749),
    [anon_sym_FOR] = ACTIONS(5749),
    [anon_sym_For] = ACTIONS(5749),
    [anon_sym_foreach] = ACTIONS(5749),
    [anon_sym_FOREACH] = ACTIONS(5749),
    [anon_sym_Foreach] = ACTIONS(5749),
    [anon_sym_while] = ACTIONS(5749),
    [anon_sym_WHILE] = ACTIONS(5749),
    [anon_sym_While] = ACTIONS(5749),
    [anon_sym_repeat] = ACTIONS(5749),
    [anon_sym_REPEAT] = ACTIONS(5749),
    [anon_sym_Repeat] = ACTIONS(5749),
    [anon_sym_exit] = ACTIONS(5749),
    [anon_sym_EXIT] = ACTIONS(5749),
    [anon_sym_Exit] = ACTIONS(5749),
    [anon_sym_continue] = ACTIONS(5749),
    [anon_sym_CONTINUE] = ACTIONS(5749),
    [anon_sym_Continue] = ACTIONS(5749),
    [anon_sym_break] = ACTIONS(5749),
    [anon_sym_BREAK] = ACTIONS(5749),
    [anon_sym_Break] = ACTIONS(5749),
    [anon_sym_with] = ACTIONS(5749),
    [anon_sym_WITH] = ACTIONS(5749),
    [anon_sym_With] = ACTIONS(5749),
    [sym_asserterror_keyword] = ACTIONS(5751),
    [sym_page_keyword] = ACTIONS(5749),
    [anon_sym_codeunit] = ACTIONS(5749),
    [anon_sym_CODEUNIT] = ACTIONS(5749),
    [anon_sym_Codeunit] = ACTIONS(5749),
    [anon_sym_CodeUnit] = ACTIONS(5749),
    [anon_sym_COdeunit] = ACTIONS(5749),
    [anon_sym_codeUnit] = ACTIONS(5749),
    [sym_report_keyword] = ACTIONS(5749),
    [sym_query_keyword] = ACTIONS(5749),
    [anon_sym_xmlport] = ACTIONS(5749),
    [anon_sym_XMLPORT] = ACTIONS(5749),
    [anon_sym_Xmlport] = ACTIONS(5749),
    [anon_sym_XMLport] = ACTIONS(5749),
    [anon_sym_XMLPort] = ACTIONS(5749),
    [anon_sym_XmlPort] = ACTIONS(5749),
    [anon_sym_enum] = ACTIONS(5749),
    [anon_sym_ENUM] = ACTIONS(5749),
    [anon_sym_Enum] = ACTIONS(5749),
    [anon_sym_eNUM] = ACTIONS(5749),
    [anon_sym_eNum] = ACTIONS(5749),
    [anon_sym_ENum] = ACTIONS(5749),
    [sym_quoted_identifier] = ACTIONS(5751),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5751),
    [sym_verbatim_string] = ACTIONS(5751),
    [sym_integer] = ACTIONS(5749),
    [sym_continue_as_identifier] = ACTIONS(5751),
    [sym_preproc_open] = ACTIONS(5751),
    [sym_preproc_close] = ACTIONS(5751),
  },
  [STATE(2443)] = {
    [sym_identifier] = ACTIONS(5753),
    [anon_sym_SEMI] = ACTIONS(5755),
    [anon_sym_DASH] = ACTIONS(5755),
    [aux_sym_boolean_token1] = ACTIONS(5753),
    [aux_sym_boolean_token2] = ACTIONS(5753),
    [sym_decimal] = ACTIONS(5753),
    [anon_sym_LPAREN] = ACTIONS(5755),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5753),
    [anon_sym_LBRACK] = ACTIONS(5755),
    [aux_sym_record_type_token1] = ACTIONS(5753),
    [aux_sym_basic_type_token21] = ACTIONS(5753),
    [aux_sym_basic_type_token22] = ACTIONS(5753),
    [aux_sym_basic_type_token48] = ACTIONS(5753),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5753),
    [anon_sym_POUNDif] = ACTIONS(5755),
    [anon_sym_POUNDIF] = ACTIONS(5755),
    [anon_sym_POUNDIf] = ACTIONS(5755),
    [anon_sym_not] = ACTIONS(5753),
    [anon_sym_NOT] = ACTIONS(5753),
    [anon_sym_Not] = ACTIONS(5753),
    [anon_sym_POUNDelif] = ACTIONS(5755),
    [anon_sym_POUNDELIF] = ACTIONS(5755),
    [anon_sym_POUNDElif] = ACTIONS(5755),
    [anon_sym_POUNDelse] = ACTIONS(5755),
    [anon_sym_POUNDELSE] = ACTIONS(5755),
    [anon_sym_POUNDElse] = ACTIONS(5755),
    [anon_sym_POUNDelse2] = ACTIONS(5755),
    [anon_sym_POUNDELSE2] = ACTIONS(5755),
    [anon_sym_POUNDElse2] = ACTIONS(5755),
    [anon_sym_POUNDendif] = ACTIONS(5755),
    [anon_sym_POUNDENDIF] = ACTIONS(5755),
    [anon_sym_POUNDEndif] = ACTIONS(5755),
    [anon_sym_POUNDendif2] = ACTIONS(5755),
    [anon_sym_POUNDENDIF2] = ACTIONS(5755),
    [anon_sym_POUNDEndif2] = ACTIONS(5755),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5753),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5753),
    [anon_sym_PLUS] = ACTIONS(5755),
    [sym_datetime_literal] = ACTIONS(5755),
    [sym_date_literal] = ACTIONS(5753),
    [sym_time_literal] = ACTIONS(5753),
    [sym_biginteger_literal] = ACTIONS(5755),
    [anon_sym_if] = ACTIONS(5753),
    [anon_sym_IF] = ACTIONS(5753),
    [anon_sym_If] = ACTIONS(5753),
    [anon_sym_else] = ACTIONS(5753),
    [anon_sym_ELSE] = ACTIONS(5753),
    [anon_sym_Else] = ACTIONS(5753),
    [anon_sym_case] = ACTIONS(5753),
    [anon_sym_CASE] = ACTIONS(5753),
    [anon_sym_Case] = ACTIONS(5753),
    [anon_sym_for] = ACTIONS(5753),
    [anon_sym_FOR] = ACTIONS(5753),
    [anon_sym_For] = ACTIONS(5753),
    [anon_sym_foreach] = ACTIONS(5753),
    [anon_sym_FOREACH] = ACTIONS(5753),
    [anon_sym_Foreach] = ACTIONS(5753),
    [anon_sym_while] = ACTIONS(5753),
    [anon_sym_WHILE] = ACTIONS(5753),
    [anon_sym_While] = ACTIONS(5753),
    [anon_sym_repeat] = ACTIONS(5753),
    [anon_sym_REPEAT] = ACTIONS(5753),
    [anon_sym_Repeat] = ACTIONS(5753),
    [anon_sym_exit] = ACTIONS(5753),
    [anon_sym_EXIT] = ACTIONS(5753),
    [anon_sym_Exit] = ACTIONS(5753),
    [anon_sym_continue] = ACTIONS(5753),
    [anon_sym_CONTINUE] = ACTIONS(5753),
    [anon_sym_Continue] = ACTIONS(5753),
    [anon_sym_break] = ACTIONS(5753),
    [anon_sym_BREAK] = ACTIONS(5753),
    [anon_sym_Break] = ACTIONS(5753),
    [anon_sym_with] = ACTIONS(5753),
    [anon_sym_WITH] = ACTIONS(5753),
    [anon_sym_With] = ACTIONS(5753),
    [sym_asserterror_keyword] = ACTIONS(5755),
    [sym_page_keyword] = ACTIONS(5753),
    [anon_sym_codeunit] = ACTIONS(5753),
    [anon_sym_CODEUNIT] = ACTIONS(5753),
    [anon_sym_Codeunit] = ACTIONS(5753),
    [anon_sym_CodeUnit] = ACTIONS(5753),
    [anon_sym_COdeunit] = ACTIONS(5753),
    [anon_sym_codeUnit] = ACTIONS(5753),
    [sym_report_keyword] = ACTIONS(5753),
    [sym_query_keyword] = ACTIONS(5753),
    [anon_sym_xmlport] = ACTIONS(5753),
    [anon_sym_XMLPORT] = ACTIONS(5753),
    [anon_sym_Xmlport] = ACTIONS(5753),
    [anon_sym_XMLport] = ACTIONS(5753),
    [anon_sym_XMLPort] = ACTIONS(5753),
    [anon_sym_XmlPort] = ACTIONS(5753),
    [anon_sym_enum] = ACTIONS(5753),
    [anon_sym_ENUM] = ACTIONS(5753),
    [anon_sym_Enum] = ACTIONS(5753),
    [anon_sym_eNUM] = ACTIONS(5753),
    [anon_sym_eNum] = ACTIONS(5753),
    [anon_sym_ENum] = ACTIONS(5753),
    [sym_quoted_identifier] = ACTIONS(5755),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5755),
    [sym_verbatim_string] = ACTIONS(5755),
    [sym_integer] = ACTIONS(5753),
    [sym_continue_as_identifier] = ACTIONS(5755),
    [sym_preproc_open] = ACTIONS(5755),
    [sym_preproc_close] = ACTIONS(5755),
  },
  [STATE(2444)] = {
    [sym_identifier] = ACTIONS(5757),
    [anon_sym_SEMI] = ACTIONS(5759),
    [anon_sym_DASH] = ACTIONS(5759),
    [aux_sym_boolean_token1] = ACTIONS(5757),
    [aux_sym_boolean_token2] = ACTIONS(5757),
    [sym_decimal] = ACTIONS(5757),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5757),
    [anon_sym_LBRACK] = ACTIONS(5759),
    [aux_sym_record_type_token1] = ACTIONS(5757),
    [aux_sym_basic_type_token21] = ACTIONS(5757),
    [aux_sym_basic_type_token22] = ACTIONS(5757),
    [aux_sym_basic_type_token48] = ACTIONS(5757),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5757),
    [anon_sym_POUNDif] = ACTIONS(5759),
    [anon_sym_POUNDIF] = ACTIONS(5759),
    [anon_sym_POUNDIf] = ACTIONS(5759),
    [anon_sym_not] = ACTIONS(5757),
    [anon_sym_NOT] = ACTIONS(5757),
    [anon_sym_Not] = ACTIONS(5757),
    [anon_sym_POUNDelif] = ACTIONS(5759),
    [anon_sym_POUNDELIF] = ACTIONS(5759),
    [anon_sym_POUNDElif] = ACTIONS(5759),
    [anon_sym_POUNDelse] = ACTIONS(5759),
    [anon_sym_POUNDELSE] = ACTIONS(5759),
    [anon_sym_POUNDElse] = ACTIONS(5759),
    [anon_sym_POUNDelse2] = ACTIONS(5759),
    [anon_sym_POUNDELSE2] = ACTIONS(5759),
    [anon_sym_POUNDElse2] = ACTIONS(5759),
    [anon_sym_POUNDendif] = ACTIONS(5759),
    [anon_sym_POUNDENDIF] = ACTIONS(5759),
    [anon_sym_POUNDEndif] = ACTIONS(5759),
    [anon_sym_POUNDendif2] = ACTIONS(5759),
    [anon_sym_POUNDENDIF2] = ACTIONS(5759),
    [anon_sym_POUNDEndif2] = ACTIONS(5759),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5757),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5757),
    [anon_sym_PLUS] = ACTIONS(5759),
    [sym_datetime_literal] = ACTIONS(5759),
    [sym_date_literal] = ACTIONS(5757),
    [sym_time_literal] = ACTIONS(5757),
    [sym_biginteger_literal] = ACTIONS(5759),
    [anon_sym_if] = ACTIONS(5757),
    [anon_sym_IF] = ACTIONS(5757),
    [anon_sym_If] = ACTIONS(5757),
    [anon_sym_else] = ACTIONS(5757),
    [anon_sym_ELSE] = ACTIONS(5757),
    [anon_sym_Else] = ACTIONS(5757),
    [anon_sym_case] = ACTIONS(5757),
    [anon_sym_CASE] = ACTIONS(5757),
    [anon_sym_Case] = ACTIONS(5757),
    [anon_sym_for] = ACTIONS(5757),
    [anon_sym_FOR] = ACTIONS(5757),
    [anon_sym_For] = ACTIONS(5757),
    [anon_sym_foreach] = ACTIONS(5757),
    [anon_sym_FOREACH] = ACTIONS(5757),
    [anon_sym_Foreach] = ACTIONS(5757),
    [anon_sym_while] = ACTIONS(5757),
    [anon_sym_WHILE] = ACTIONS(5757),
    [anon_sym_While] = ACTIONS(5757),
    [anon_sym_repeat] = ACTIONS(5757),
    [anon_sym_REPEAT] = ACTIONS(5757),
    [anon_sym_Repeat] = ACTIONS(5757),
    [anon_sym_exit] = ACTIONS(5757),
    [anon_sym_EXIT] = ACTIONS(5757),
    [anon_sym_Exit] = ACTIONS(5757),
    [anon_sym_continue] = ACTIONS(5757),
    [anon_sym_CONTINUE] = ACTIONS(5757),
    [anon_sym_Continue] = ACTIONS(5757),
    [anon_sym_break] = ACTIONS(5757),
    [anon_sym_BREAK] = ACTIONS(5757),
    [anon_sym_Break] = ACTIONS(5757),
    [anon_sym_with] = ACTIONS(5757),
    [anon_sym_WITH] = ACTIONS(5757),
    [anon_sym_With] = ACTIONS(5757),
    [sym_asserterror_keyword] = ACTIONS(5759),
    [sym_page_keyword] = ACTIONS(5757),
    [anon_sym_codeunit] = ACTIONS(5757),
    [anon_sym_CODEUNIT] = ACTIONS(5757),
    [anon_sym_Codeunit] = ACTIONS(5757),
    [anon_sym_CodeUnit] = ACTIONS(5757),
    [anon_sym_COdeunit] = ACTIONS(5757),
    [anon_sym_codeUnit] = ACTIONS(5757),
    [sym_report_keyword] = ACTIONS(5757),
    [sym_query_keyword] = ACTIONS(5757),
    [anon_sym_xmlport] = ACTIONS(5757),
    [anon_sym_XMLPORT] = ACTIONS(5757),
    [anon_sym_Xmlport] = ACTIONS(5757),
    [anon_sym_XMLport] = ACTIONS(5757),
    [anon_sym_XMLPort] = ACTIONS(5757),
    [anon_sym_XmlPort] = ACTIONS(5757),
    [anon_sym_enum] = ACTIONS(5757),
    [anon_sym_ENUM] = ACTIONS(5757),
    [anon_sym_Enum] = ACTIONS(5757),
    [anon_sym_eNUM] = ACTIONS(5757),
    [anon_sym_eNum] = ACTIONS(5757),
    [anon_sym_ENum] = ACTIONS(5757),
    [sym_quoted_identifier] = ACTIONS(5759),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5759),
    [sym_verbatim_string] = ACTIONS(5759),
    [sym_integer] = ACTIONS(5757),
    [sym_continue_as_identifier] = ACTIONS(5759),
    [sym_preproc_open] = ACTIONS(5759),
    [sym_preproc_close] = ACTIONS(5759),
  },
  [STATE(2445)] = {
    [sym_identifier] = ACTIONS(5761),
    [anon_sym_SEMI] = ACTIONS(5763),
    [anon_sym_DASH] = ACTIONS(5763),
    [aux_sym_boolean_token1] = ACTIONS(5761),
    [aux_sym_boolean_token2] = ACTIONS(5761),
    [sym_decimal] = ACTIONS(5761),
    [anon_sym_LPAREN] = ACTIONS(5763),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5761),
    [anon_sym_LBRACK] = ACTIONS(5763),
    [aux_sym_record_type_token1] = ACTIONS(5761),
    [aux_sym_basic_type_token21] = ACTIONS(5761),
    [aux_sym_basic_type_token22] = ACTIONS(5761),
    [aux_sym_basic_type_token48] = ACTIONS(5761),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5761),
    [anon_sym_POUNDif] = ACTIONS(5763),
    [anon_sym_POUNDIF] = ACTIONS(5763),
    [anon_sym_POUNDIf] = ACTIONS(5763),
    [anon_sym_not] = ACTIONS(5761),
    [anon_sym_NOT] = ACTIONS(5761),
    [anon_sym_Not] = ACTIONS(5761),
    [anon_sym_POUNDelif] = ACTIONS(5763),
    [anon_sym_POUNDELIF] = ACTIONS(5763),
    [anon_sym_POUNDElif] = ACTIONS(5763),
    [anon_sym_POUNDelse] = ACTIONS(5763),
    [anon_sym_POUNDELSE] = ACTIONS(5763),
    [anon_sym_POUNDElse] = ACTIONS(5763),
    [anon_sym_POUNDelse2] = ACTIONS(5763),
    [anon_sym_POUNDELSE2] = ACTIONS(5763),
    [anon_sym_POUNDElse2] = ACTIONS(5763),
    [anon_sym_POUNDendif] = ACTIONS(5763),
    [anon_sym_POUNDENDIF] = ACTIONS(5763),
    [anon_sym_POUNDEndif] = ACTIONS(5763),
    [anon_sym_POUNDendif2] = ACTIONS(5763),
    [anon_sym_POUNDENDIF2] = ACTIONS(5763),
    [anon_sym_POUNDEndif2] = ACTIONS(5763),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5761),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5761),
    [anon_sym_PLUS] = ACTIONS(5763),
    [sym_datetime_literal] = ACTIONS(5763),
    [sym_date_literal] = ACTIONS(5761),
    [sym_time_literal] = ACTIONS(5761),
    [sym_biginteger_literal] = ACTIONS(5763),
    [anon_sym_if] = ACTIONS(5761),
    [anon_sym_IF] = ACTIONS(5761),
    [anon_sym_If] = ACTIONS(5761),
    [anon_sym_else] = ACTIONS(5761),
    [anon_sym_ELSE] = ACTIONS(5761),
    [anon_sym_Else] = ACTIONS(5761),
    [anon_sym_case] = ACTIONS(5761),
    [anon_sym_CASE] = ACTIONS(5761),
    [anon_sym_Case] = ACTIONS(5761),
    [anon_sym_for] = ACTIONS(5761),
    [anon_sym_FOR] = ACTIONS(5761),
    [anon_sym_For] = ACTIONS(5761),
    [anon_sym_foreach] = ACTIONS(5761),
    [anon_sym_FOREACH] = ACTIONS(5761),
    [anon_sym_Foreach] = ACTIONS(5761),
    [anon_sym_while] = ACTIONS(5761),
    [anon_sym_WHILE] = ACTIONS(5761),
    [anon_sym_While] = ACTIONS(5761),
    [anon_sym_repeat] = ACTIONS(5761),
    [anon_sym_REPEAT] = ACTIONS(5761),
    [anon_sym_Repeat] = ACTIONS(5761),
    [anon_sym_exit] = ACTIONS(5761),
    [anon_sym_EXIT] = ACTIONS(5761),
    [anon_sym_Exit] = ACTIONS(5761),
    [anon_sym_continue] = ACTIONS(5761),
    [anon_sym_CONTINUE] = ACTIONS(5761),
    [anon_sym_Continue] = ACTIONS(5761),
    [anon_sym_break] = ACTIONS(5761),
    [anon_sym_BREAK] = ACTIONS(5761),
    [anon_sym_Break] = ACTIONS(5761),
    [anon_sym_with] = ACTIONS(5761),
    [anon_sym_WITH] = ACTIONS(5761),
    [anon_sym_With] = ACTIONS(5761),
    [sym_asserterror_keyword] = ACTIONS(5763),
    [sym_page_keyword] = ACTIONS(5761),
    [anon_sym_codeunit] = ACTIONS(5761),
    [anon_sym_CODEUNIT] = ACTIONS(5761),
    [anon_sym_Codeunit] = ACTIONS(5761),
    [anon_sym_CodeUnit] = ACTIONS(5761),
    [anon_sym_COdeunit] = ACTIONS(5761),
    [anon_sym_codeUnit] = ACTIONS(5761),
    [sym_report_keyword] = ACTIONS(5761),
    [sym_query_keyword] = ACTIONS(5761),
    [anon_sym_xmlport] = ACTIONS(5761),
    [anon_sym_XMLPORT] = ACTIONS(5761),
    [anon_sym_Xmlport] = ACTIONS(5761),
    [anon_sym_XMLport] = ACTIONS(5761),
    [anon_sym_XMLPort] = ACTIONS(5761),
    [anon_sym_XmlPort] = ACTIONS(5761),
    [anon_sym_enum] = ACTIONS(5761),
    [anon_sym_ENUM] = ACTIONS(5761),
    [anon_sym_Enum] = ACTIONS(5761),
    [anon_sym_eNUM] = ACTIONS(5761),
    [anon_sym_eNum] = ACTIONS(5761),
    [anon_sym_ENum] = ACTIONS(5761),
    [sym_quoted_identifier] = ACTIONS(5763),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5763),
    [sym_verbatim_string] = ACTIONS(5763),
    [sym_integer] = ACTIONS(5761),
    [sym_continue_as_identifier] = ACTIONS(5763),
    [sym_preproc_open] = ACTIONS(5763),
    [sym_preproc_close] = ACTIONS(5763),
  },
  [STATE(2446)] = {
    [sym_identifier] = ACTIONS(5765),
    [anon_sym_SEMI] = ACTIONS(5767),
    [anon_sym_DASH] = ACTIONS(5767),
    [aux_sym_boolean_token1] = ACTIONS(5765),
    [aux_sym_boolean_token2] = ACTIONS(5765),
    [sym_decimal] = ACTIONS(5765),
    [anon_sym_LPAREN] = ACTIONS(5767),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5765),
    [anon_sym_LBRACK] = ACTIONS(5767),
    [aux_sym_record_type_token1] = ACTIONS(5765),
    [aux_sym_basic_type_token21] = ACTIONS(5765),
    [aux_sym_basic_type_token22] = ACTIONS(5765),
    [aux_sym_basic_type_token48] = ACTIONS(5765),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5765),
    [anon_sym_POUNDif] = ACTIONS(5767),
    [anon_sym_POUNDIF] = ACTIONS(5767),
    [anon_sym_POUNDIf] = ACTIONS(5767),
    [anon_sym_not] = ACTIONS(5765),
    [anon_sym_NOT] = ACTIONS(5765),
    [anon_sym_Not] = ACTIONS(5765),
    [anon_sym_POUNDelif] = ACTIONS(5767),
    [anon_sym_POUNDELIF] = ACTIONS(5767),
    [anon_sym_POUNDElif] = ACTIONS(5767),
    [anon_sym_POUNDelse] = ACTIONS(5767),
    [anon_sym_POUNDELSE] = ACTIONS(5767),
    [anon_sym_POUNDElse] = ACTIONS(5767),
    [anon_sym_POUNDelse2] = ACTIONS(5767),
    [anon_sym_POUNDELSE2] = ACTIONS(5767),
    [anon_sym_POUNDElse2] = ACTIONS(5767),
    [anon_sym_POUNDendif] = ACTIONS(5767),
    [anon_sym_POUNDENDIF] = ACTIONS(5767),
    [anon_sym_POUNDEndif] = ACTIONS(5767),
    [anon_sym_POUNDendif2] = ACTIONS(5767),
    [anon_sym_POUNDENDIF2] = ACTIONS(5767),
    [anon_sym_POUNDEndif2] = ACTIONS(5767),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5765),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5765),
    [anon_sym_PLUS] = ACTIONS(5767),
    [sym_datetime_literal] = ACTIONS(5767),
    [sym_date_literal] = ACTIONS(5765),
    [sym_time_literal] = ACTIONS(5765),
    [sym_biginteger_literal] = ACTIONS(5767),
    [anon_sym_if] = ACTIONS(5765),
    [anon_sym_IF] = ACTIONS(5765),
    [anon_sym_If] = ACTIONS(5765),
    [anon_sym_else] = ACTIONS(5765),
    [anon_sym_ELSE] = ACTIONS(5765),
    [anon_sym_Else] = ACTIONS(5765),
    [anon_sym_case] = ACTIONS(5765),
    [anon_sym_CASE] = ACTIONS(5765),
    [anon_sym_Case] = ACTIONS(5765),
    [anon_sym_for] = ACTIONS(5765),
    [anon_sym_FOR] = ACTIONS(5765),
    [anon_sym_For] = ACTIONS(5765),
    [anon_sym_foreach] = ACTIONS(5765),
    [anon_sym_FOREACH] = ACTIONS(5765),
    [anon_sym_Foreach] = ACTIONS(5765),
    [anon_sym_while] = ACTIONS(5765),
    [anon_sym_WHILE] = ACTIONS(5765),
    [anon_sym_While] = ACTIONS(5765),
    [anon_sym_repeat] = ACTIONS(5765),
    [anon_sym_REPEAT] = ACTIONS(5765),
    [anon_sym_Repeat] = ACTIONS(5765),
    [anon_sym_exit] = ACTIONS(5765),
    [anon_sym_EXIT] = ACTIONS(5765),
    [anon_sym_Exit] = ACTIONS(5765),
    [anon_sym_continue] = ACTIONS(5765),
    [anon_sym_CONTINUE] = ACTIONS(5765),
    [anon_sym_Continue] = ACTIONS(5765),
    [anon_sym_break] = ACTIONS(5765),
    [anon_sym_BREAK] = ACTIONS(5765),
    [anon_sym_Break] = ACTIONS(5765),
    [anon_sym_with] = ACTIONS(5765),
    [anon_sym_WITH] = ACTIONS(5765),
    [anon_sym_With] = ACTIONS(5765),
    [sym_asserterror_keyword] = ACTIONS(5767),
    [sym_page_keyword] = ACTIONS(5765),
    [anon_sym_codeunit] = ACTIONS(5765),
    [anon_sym_CODEUNIT] = ACTIONS(5765),
    [anon_sym_Codeunit] = ACTIONS(5765),
    [anon_sym_CodeUnit] = ACTIONS(5765),
    [anon_sym_COdeunit] = ACTIONS(5765),
    [anon_sym_codeUnit] = ACTIONS(5765),
    [sym_report_keyword] = ACTIONS(5765),
    [sym_query_keyword] = ACTIONS(5765),
    [anon_sym_xmlport] = ACTIONS(5765),
    [anon_sym_XMLPORT] = ACTIONS(5765),
    [anon_sym_Xmlport] = ACTIONS(5765),
    [anon_sym_XMLport] = ACTIONS(5765),
    [anon_sym_XMLPort] = ACTIONS(5765),
    [anon_sym_XmlPort] = ACTIONS(5765),
    [anon_sym_enum] = ACTIONS(5765),
    [anon_sym_ENUM] = ACTIONS(5765),
    [anon_sym_Enum] = ACTIONS(5765),
    [anon_sym_eNUM] = ACTIONS(5765),
    [anon_sym_eNum] = ACTIONS(5765),
    [anon_sym_ENum] = ACTIONS(5765),
    [sym_quoted_identifier] = ACTIONS(5767),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5767),
    [sym_verbatim_string] = ACTIONS(5767),
    [sym_integer] = ACTIONS(5765),
    [sym_continue_as_identifier] = ACTIONS(5767),
    [sym_preproc_open] = ACTIONS(5767),
    [sym_preproc_close] = ACTIONS(5767),
  },
  [STATE(2447)] = {
    [sym_identifier] = ACTIONS(5769),
    [anon_sym_SEMI] = ACTIONS(5771),
    [anon_sym_DASH] = ACTIONS(5771),
    [aux_sym_boolean_token1] = ACTIONS(5769),
    [aux_sym_boolean_token2] = ACTIONS(5769),
    [sym_decimal] = ACTIONS(5769),
    [anon_sym_LPAREN] = ACTIONS(5771),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5769),
    [anon_sym_LBRACK] = ACTIONS(5771),
    [aux_sym_record_type_token1] = ACTIONS(5769),
    [aux_sym_basic_type_token21] = ACTIONS(5769),
    [aux_sym_basic_type_token22] = ACTIONS(5769),
    [aux_sym_basic_type_token48] = ACTIONS(5769),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5769),
    [anon_sym_POUNDif] = ACTIONS(5771),
    [anon_sym_POUNDIF] = ACTIONS(5771),
    [anon_sym_POUNDIf] = ACTIONS(5771),
    [anon_sym_not] = ACTIONS(5769),
    [anon_sym_NOT] = ACTIONS(5769),
    [anon_sym_Not] = ACTIONS(5769),
    [anon_sym_POUNDelif] = ACTIONS(5771),
    [anon_sym_POUNDELIF] = ACTIONS(5771),
    [anon_sym_POUNDElif] = ACTIONS(5771),
    [anon_sym_POUNDelse] = ACTIONS(5771),
    [anon_sym_POUNDELSE] = ACTIONS(5771),
    [anon_sym_POUNDElse] = ACTIONS(5771),
    [anon_sym_POUNDelse2] = ACTIONS(5771),
    [anon_sym_POUNDELSE2] = ACTIONS(5771),
    [anon_sym_POUNDElse2] = ACTIONS(5771),
    [anon_sym_POUNDendif] = ACTIONS(5771),
    [anon_sym_POUNDENDIF] = ACTIONS(5771),
    [anon_sym_POUNDEndif] = ACTIONS(5771),
    [anon_sym_POUNDendif2] = ACTIONS(5771),
    [anon_sym_POUNDENDIF2] = ACTIONS(5771),
    [anon_sym_POUNDEndif2] = ACTIONS(5771),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5769),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5769),
    [anon_sym_PLUS] = ACTIONS(5771),
    [sym_datetime_literal] = ACTIONS(5771),
    [sym_date_literal] = ACTIONS(5769),
    [sym_time_literal] = ACTIONS(5769),
    [sym_biginteger_literal] = ACTIONS(5771),
    [anon_sym_if] = ACTIONS(5769),
    [anon_sym_IF] = ACTIONS(5769),
    [anon_sym_If] = ACTIONS(5769),
    [anon_sym_else] = ACTIONS(5769),
    [anon_sym_ELSE] = ACTIONS(5769),
    [anon_sym_Else] = ACTIONS(5769),
    [anon_sym_case] = ACTIONS(5769),
    [anon_sym_CASE] = ACTIONS(5769),
    [anon_sym_Case] = ACTIONS(5769),
    [anon_sym_for] = ACTIONS(5769),
    [anon_sym_FOR] = ACTIONS(5769),
    [anon_sym_For] = ACTIONS(5769),
    [anon_sym_foreach] = ACTIONS(5769),
    [anon_sym_FOREACH] = ACTIONS(5769),
    [anon_sym_Foreach] = ACTIONS(5769),
    [anon_sym_while] = ACTIONS(5769),
    [anon_sym_WHILE] = ACTIONS(5769),
    [anon_sym_While] = ACTIONS(5769),
    [anon_sym_repeat] = ACTIONS(5769),
    [anon_sym_REPEAT] = ACTIONS(5769),
    [anon_sym_Repeat] = ACTIONS(5769),
    [anon_sym_exit] = ACTIONS(5769),
    [anon_sym_EXIT] = ACTIONS(5769),
    [anon_sym_Exit] = ACTIONS(5769),
    [anon_sym_continue] = ACTIONS(5769),
    [anon_sym_CONTINUE] = ACTIONS(5769),
    [anon_sym_Continue] = ACTIONS(5769),
    [anon_sym_break] = ACTIONS(5769),
    [anon_sym_BREAK] = ACTIONS(5769),
    [anon_sym_Break] = ACTIONS(5769),
    [anon_sym_with] = ACTIONS(5769),
    [anon_sym_WITH] = ACTIONS(5769),
    [anon_sym_With] = ACTIONS(5769),
    [sym_asserterror_keyword] = ACTIONS(5771),
    [sym_page_keyword] = ACTIONS(5769),
    [anon_sym_codeunit] = ACTIONS(5769),
    [anon_sym_CODEUNIT] = ACTIONS(5769),
    [anon_sym_Codeunit] = ACTIONS(5769),
    [anon_sym_CodeUnit] = ACTIONS(5769),
    [anon_sym_COdeunit] = ACTIONS(5769),
    [anon_sym_codeUnit] = ACTIONS(5769),
    [sym_report_keyword] = ACTIONS(5769),
    [sym_query_keyword] = ACTIONS(5769),
    [anon_sym_xmlport] = ACTIONS(5769),
    [anon_sym_XMLPORT] = ACTIONS(5769),
    [anon_sym_Xmlport] = ACTIONS(5769),
    [anon_sym_XMLport] = ACTIONS(5769),
    [anon_sym_XMLPort] = ACTIONS(5769),
    [anon_sym_XmlPort] = ACTIONS(5769),
    [anon_sym_enum] = ACTIONS(5769),
    [anon_sym_ENUM] = ACTIONS(5769),
    [anon_sym_Enum] = ACTIONS(5769),
    [anon_sym_eNUM] = ACTIONS(5769),
    [anon_sym_eNum] = ACTIONS(5769),
    [anon_sym_ENum] = ACTIONS(5769),
    [sym_quoted_identifier] = ACTIONS(5771),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5771),
    [sym_verbatim_string] = ACTIONS(5771),
    [sym_integer] = ACTIONS(5769),
    [sym_continue_as_identifier] = ACTIONS(5771),
    [sym_preproc_open] = ACTIONS(5771),
    [sym_preproc_close] = ACTIONS(5771),
  },
  [STATE(2448)] = {
    [sym_identifier] = ACTIONS(5773),
    [anon_sym_SEMI] = ACTIONS(5775),
    [anon_sym_DASH] = ACTIONS(5775),
    [aux_sym_boolean_token1] = ACTIONS(5773),
    [aux_sym_boolean_token2] = ACTIONS(5773),
    [sym_decimal] = ACTIONS(5773),
    [anon_sym_LPAREN] = ACTIONS(5775),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5773),
    [anon_sym_LBRACK] = ACTIONS(5775),
    [aux_sym_record_type_token1] = ACTIONS(5773),
    [aux_sym_basic_type_token21] = ACTIONS(5773),
    [aux_sym_basic_type_token22] = ACTIONS(5773),
    [aux_sym_basic_type_token48] = ACTIONS(5773),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5773),
    [anon_sym_POUNDif] = ACTIONS(5775),
    [anon_sym_POUNDIF] = ACTIONS(5775),
    [anon_sym_POUNDIf] = ACTIONS(5775),
    [anon_sym_not] = ACTIONS(5773),
    [anon_sym_NOT] = ACTIONS(5773),
    [anon_sym_Not] = ACTIONS(5773),
    [anon_sym_POUNDelif] = ACTIONS(5775),
    [anon_sym_POUNDELIF] = ACTIONS(5775),
    [anon_sym_POUNDElif] = ACTIONS(5775),
    [anon_sym_POUNDelse] = ACTIONS(5775),
    [anon_sym_POUNDELSE] = ACTIONS(5775),
    [anon_sym_POUNDElse] = ACTIONS(5775),
    [anon_sym_POUNDelse2] = ACTIONS(5775),
    [anon_sym_POUNDELSE2] = ACTIONS(5775),
    [anon_sym_POUNDElse2] = ACTIONS(5775),
    [anon_sym_POUNDendif] = ACTIONS(5775),
    [anon_sym_POUNDENDIF] = ACTIONS(5775),
    [anon_sym_POUNDEndif] = ACTIONS(5775),
    [anon_sym_POUNDendif2] = ACTIONS(5775),
    [anon_sym_POUNDENDIF2] = ACTIONS(5775),
    [anon_sym_POUNDEndif2] = ACTIONS(5775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5773),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5773),
    [anon_sym_PLUS] = ACTIONS(5775),
    [sym_datetime_literal] = ACTIONS(5775),
    [sym_date_literal] = ACTIONS(5773),
    [sym_time_literal] = ACTIONS(5773),
    [sym_biginteger_literal] = ACTIONS(5775),
    [anon_sym_if] = ACTIONS(5773),
    [anon_sym_IF] = ACTIONS(5773),
    [anon_sym_If] = ACTIONS(5773),
    [anon_sym_else] = ACTIONS(5773),
    [anon_sym_ELSE] = ACTIONS(5773),
    [anon_sym_Else] = ACTIONS(5773),
    [anon_sym_case] = ACTIONS(5773),
    [anon_sym_CASE] = ACTIONS(5773),
    [anon_sym_Case] = ACTIONS(5773),
    [anon_sym_for] = ACTIONS(5773),
    [anon_sym_FOR] = ACTIONS(5773),
    [anon_sym_For] = ACTIONS(5773),
    [anon_sym_foreach] = ACTIONS(5773),
    [anon_sym_FOREACH] = ACTIONS(5773),
    [anon_sym_Foreach] = ACTIONS(5773),
    [anon_sym_while] = ACTIONS(5773),
    [anon_sym_WHILE] = ACTIONS(5773),
    [anon_sym_While] = ACTIONS(5773),
    [anon_sym_repeat] = ACTIONS(5773),
    [anon_sym_REPEAT] = ACTIONS(5773),
    [anon_sym_Repeat] = ACTIONS(5773),
    [anon_sym_exit] = ACTIONS(5773),
    [anon_sym_EXIT] = ACTIONS(5773),
    [anon_sym_Exit] = ACTIONS(5773),
    [anon_sym_continue] = ACTIONS(5773),
    [anon_sym_CONTINUE] = ACTIONS(5773),
    [anon_sym_Continue] = ACTIONS(5773),
    [anon_sym_break] = ACTIONS(5773),
    [anon_sym_BREAK] = ACTIONS(5773),
    [anon_sym_Break] = ACTIONS(5773),
    [anon_sym_with] = ACTIONS(5773),
    [anon_sym_WITH] = ACTIONS(5773),
    [anon_sym_With] = ACTIONS(5773),
    [sym_asserterror_keyword] = ACTIONS(5775),
    [sym_page_keyword] = ACTIONS(5773),
    [anon_sym_codeunit] = ACTIONS(5773),
    [anon_sym_CODEUNIT] = ACTIONS(5773),
    [anon_sym_Codeunit] = ACTIONS(5773),
    [anon_sym_CodeUnit] = ACTIONS(5773),
    [anon_sym_COdeunit] = ACTIONS(5773),
    [anon_sym_codeUnit] = ACTIONS(5773),
    [sym_report_keyword] = ACTIONS(5773),
    [sym_query_keyword] = ACTIONS(5773),
    [anon_sym_xmlport] = ACTIONS(5773),
    [anon_sym_XMLPORT] = ACTIONS(5773),
    [anon_sym_Xmlport] = ACTIONS(5773),
    [anon_sym_XMLport] = ACTIONS(5773),
    [anon_sym_XMLPort] = ACTIONS(5773),
    [anon_sym_XmlPort] = ACTIONS(5773),
    [anon_sym_enum] = ACTIONS(5773),
    [anon_sym_ENUM] = ACTIONS(5773),
    [anon_sym_Enum] = ACTIONS(5773),
    [anon_sym_eNUM] = ACTIONS(5773),
    [anon_sym_eNum] = ACTIONS(5773),
    [anon_sym_ENum] = ACTIONS(5773),
    [sym_quoted_identifier] = ACTIONS(5775),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5775),
    [sym_verbatim_string] = ACTIONS(5775),
    [sym_integer] = ACTIONS(5773),
    [sym_continue_as_identifier] = ACTIONS(5775),
    [sym_preproc_open] = ACTIONS(5775),
    [sym_preproc_close] = ACTIONS(5775),
  },
  [STATE(2449)] = {
    [sym_identifier] = ACTIONS(5777),
    [anon_sym_SEMI] = ACTIONS(5779),
    [anon_sym_DASH] = ACTIONS(5779),
    [aux_sym_boolean_token1] = ACTIONS(5777),
    [aux_sym_boolean_token2] = ACTIONS(5777),
    [sym_decimal] = ACTIONS(5777),
    [anon_sym_LPAREN] = ACTIONS(5779),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5777),
    [anon_sym_LBRACK] = ACTIONS(5779),
    [aux_sym_record_type_token1] = ACTIONS(5777),
    [aux_sym_basic_type_token21] = ACTIONS(5777),
    [aux_sym_basic_type_token22] = ACTIONS(5777),
    [aux_sym_basic_type_token48] = ACTIONS(5777),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5777),
    [anon_sym_POUNDif] = ACTIONS(5779),
    [anon_sym_POUNDIF] = ACTIONS(5779),
    [anon_sym_POUNDIf] = ACTIONS(5779),
    [anon_sym_not] = ACTIONS(5777),
    [anon_sym_NOT] = ACTIONS(5777),
    [anon_sym_Not] = ACTIONS(5777),
    [anon_sym_POUNDelif] = ACTIONS(5779),
    [anon_sym_POUNDELIF] = ACTIONS(5779),
    [anon_sym_POUNDElif] = ACTIONS(5779),
    [anon_sym_POUNDelse] = ACTIONS(5779),
    [anon_sym_POUNDELSE] = ACTIONS(5779),
    [anon_sym_POUNDElse] = ACTIONS(5779),
    [anon_sym_POUNDelse2] = ACTIONS(5779),
    [anon_sym_POUNDELSE2] = ACTIONS(5779),
    [anon_sym_POUNDElse2] = ACTIONS(5779),
    [anon_sym_POUNDendif] = ACTIONS(5779),
    [anon_sym_POUNDENDIF] = ACTIONS(5779),
    [anon_sym_POUNDEndif] = ACTIONS(5779),
    [anon_sym_POUNDendif2] = ACTIONS(5779),
    [anon_sym_POUNDENDIF2] = ACTIONS(5779),
    [anon_sym_POUNDEndif2] = ACTIONS(5779),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5777),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5777),
    [anon_sym_PLUS] = ACTIONS(5779),
    [sym_datetime_literal] = ACTIONS(5779),
    [sym_date_literal] = ACTIONS(5777),
    [sym_time_literal] = ACTIONS(5777),
    [sym_biginteger_literal] = ACTIONS(5779),
    [anon_sym_if] = ACTIONS(5777),
    [anon_sym_IF] = ACTIONS(5777),
    [anon_sym_If] = ACTIONS(5777),
    [anon_sym_else] = ACTIONS(5777),
    [anon_sym_ELSE] = ACTIONS(5777),
    [anon_sym_Else] = ACTIONS(5777),
    [anon_sym_case] = ACTIONS(5777),
    [anon_sym_CASE] = ACTIONS(5777),
    [anon_sym_Case] = ACTIONS(5777),
    [anon_sym_for] = ACTIONS(5777),
    [anon_sym_FOR] = ACTIONS(5777),
    [anon_sym_For] = ACTIONS(5777),
    [anon_sym_foreach] = ACTIONS(5777),
    [anon_sym_FOREACH] = ACTIONS(5777),
    [anon_sym_Foreach] = ACTIONS(5777),
    [anon_sym_while] = ACTIONS(5777),
    [anon_sym_WHILE] = ACTIONS(5777),
    [anon_sym_While] = ACTIONS(5777),
    [anon_sym_repeat] = ACTIONS(5777),
    [anon_sym_REPEAT] = ACTIONS(5777),
    [anon_sym_Repeat] = ACTIONS(5777),
    [anon_sym_exit] = ACTIONS(5777),
    [anon_sym_EXIT] = ACTIONS(5777),
    [anon_sym_Exit] = ACTIONS(5777),
    [anon_sym_continue] = ACTIONS(5777),
    [anon_sym_CONTINUE] = ACTIONS(5777),
    [anon_sym_Continue] = ACTIONS(5777),
    [anon_sym_break] = ACTIONS(5777),
    [anon_sym_BREAK] = ACTIONS(5777),
    [anon_sym_Break] = ACTIONS(5777),
    [anon_sym_with] = ACTIONS(5777),
    [anon_sym_WITH] = ACTIONS(5777),
    [anon_sym_With] = ACTIONS(5777),
    [sym_asserterror_keyword] = ACTIONS(5779),
    [sym_page_keyword] = ACTIONS(5777),
    [anon_sym_codeunit] = ACTIONS(5777),
    [anon_sym_CODEUNIT] = ACTIONS(5777),
    [anon_sym_Codeunit] = ACTIONS(5777),
    [anon_sym_CodeUnit] = ACTIONS(5777),
    [anon_sym_COdeunit] = ACTIONS(5777),
    [anon_sym_codeUnit] = ACTIONS(5777),
    [sym_report_keyword] = ACTIONS(5777),
    [sym_query_keyword] = ACTIONS(5777),
    [anon_sym_xmlport] = ACTIONS(5777),
    [anon_sym_XMLPORT] = ACTIONS(5777),
    [anon_sym_Xmlport] = ACTIONS(5777),
    [anon_sym_XMLport] = ACTIONS(5777),
    [anon_sym_XMLPort] = ACTIONS(5777),
    [anon_sym_XmlPort] = ACTIONS(5777),
    [anon_sym_enum] = ACTIONS(5777),
    [anon_sym_ENUM] = ACTIONS(5777),
    [anon_sym_Enum] = ACTIONS(5777),
    [anon_sym_eNUM] = ACTIONS(5777),
    [anon_sym_eNum] = ACTIONS(5777),
    [anon_sym_ENum] = ACTIONS(5777),
    [sym_quoted_identifier] = ACTIONS(5779),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5779),
    [sym_verbatim_string] = ACTIONS(5779),
    [sym_integer] = ACTIONS(5777),
    [sym_continue_as_identifier] = ACTIONS(5779),
    [sym_preproc_open] = ACTIONS(5779),
    [sym_preproc_close] = ACTIONS(5779),
  },
  [STATE(2450)] = {
    [sym_identifier] = ACTIONS(5781),
    [anon_sym_SEMI] = ACTIONS(5783),
    [anon_sym_DASH] = ACTIONS(5783),
    [aux_sym_boolean_token1] = ACTIONS(5781),
    [aux_sym_boolean_token2] = ACTIONS(5781),
    [sym_decimal] = ACTIONS(5781),
    [anon_sym_LPAREN] = ACTIONS(5783),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5781),
    [anon_sym_LBRACK] = ACTIONS(5783),
    [aux_sym_record_type_token1] = ACTIONS(5781),
    [aux_sym_basic_type_token21] = ACTIONS(5781),
    [aux_sym_basic_type_token22] = ACTIONS(5781),
    [aux_sym_basic_type_token48] = ACTIONS(5781),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5781),
    [anon_sym_POUNDif] = ACTIONS(5783),
    [anon_sym_POUNDIF] = ACTIONS(5783),
    [anon_sym_POUNDIf] = ACTIONS(5783),
    [anon_sym_not] = ACTIONS(5781),
    [anon_sym_NOT] = ACTIONS(5781),
    [anon_sym_Not] = ACTIONS(5781),
    [anon_sym_POUNDelif] = ACTIONS(5783),
    [anon_sym_POUNDELIF] = ACTIONS(5783),
    [anon_sym_POUNDElif] = ACTIONS(5783),
    [anon_sym_POUNDelse] = ACTIONS(5783),
    [anon_sym_POUNDELSE] = ACTIONS(5783),
    [anon_sym_POUNDElse] = ACTIONS(5783),
    [anon_sym_POUNDelse2] = ACTIONS(5783),
    [anon_sym_POUNDELSE2] = ACTIONS(5783),
    [anon_sym_POUNDElse2] = ACTIONS(5783),
    [anon_sym_POUNDendif] = ACTIONS(5783),
    [anon_sym_POUNDENDIF] = ACTIONS(5783),
    [anon_sym_POUNDEndif] = ACTIONS(5783),
    [anon_sym_POUNDendif2] = ACTIONS(5783),
    [anon_sym_POUNDENDIF2] = ACTIONS(5783),
    [anon_sym_POUNDEndif2] = ACTIONS(5783),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5781),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5781),
    [anon_sym_PLUS] = ACTIONS(5783),
    [sym_datetime_literal] = ACTIONS(5783),
    [sym_date_literal] = ACTIONS(5781),
    [sym_time_literal] = ACTIONS(5781),
    [sym_biginteger_literal] = ACTIONS(5783),
    [anon_sym_if] = ACTIONS(5781),
    [anon_sym_IF] = ACTIONS(5781),
    [anon_sym_If] = ACTIONS(5781),
    [anon_sym_else] = ACTIONS(5781),
    [anon_sym_ELSE] = ACTIONS(5781),
    [anon_sym_Else] = ACTIONS(5781),
    [anon_sym_case] = ACTIONS(5781),
    [anon_sym_CASE] = ACTIONS(5781),
    [anon_sym_Case] = ACTIONS(5781),
    [anon_sym_for] = ACTIONS(5781),
    [anon_sym_FOR] = ACTIONS(5781),
    [anon_sym_For] = ACTIONS(5781),
    [anon_sym_foreach] = ACTIONS(5781),
    [anon_sym_FOREACH] = ACTIONS(5781),
    [anon_sym_Foreach] = ACTIONS(5781),
    [anon_sym_while] = ACTIONS(5781),
    [anon_sym_WHILE] = ACTIONS(5781),
    [anon_sym_While] = ACTIONS(5781),
    [anon_sym_repeat] = ACTIONS(5781),
    [anon_sym_REPEAT] = ACTIONS(5781),
    [anon_sym_Repeat] = ACTIONS(5781),
    [anon_sym_exit] = ACTIONS(5781),
    [anon_sym_EXIT] = ACTIONS(5781),
    [anon_sym_Exit] = ACTIONS(5781),
    [anon_sym_continue] = ACTIONS(5781),
    [anon_sym_CONTINUE] = ACTIONS(5781),
    [anon_sym_Continue] = ACTIONS(5781),
    [anon_sym_break] = ACTIONS(5781),
    [anon_sym_BREAK] = ACTIONS(5781),
    [anon_sym_Break] = ACTIONS(5781),
    [anon_sym_with] = ACTIONS(5781),
    [anon_sym_WITH] = ACTIONS(5781),
    [anon_sym_With] = ACTIONS(5781),
    [sym_asserterror_keyword] = ACTIONS(5783),
    [sym_page_keyword] = ACTIONS(5781),
    [anon_sym_codeunit] = ACTIONS(5781),
    [anon_sym_CODEUNIT] = ACTIONS(5781),
    [anon_sym_Codeunit] = ACTIONS(5781),
    [anon_sym_CodeUnit] = ACTIONS(5781),
    [anon_sym_COdeunit] = ACTIONS(5781),
    [anon_sym_codeUnit] = ACTIONS(5781),
    [sym_report_keyword] = ACTIONS(5781),
    [sym_query_keyword] = ACTIONS(5781),
    [anon_sym_xmlport] = ACTIONS(5781),
    [anon_sym_XMLPORT] = ACTIONS(5781),
    [anon_sym_Xmlport] = ACTIONS(5781),
    [anon_sym_XMLport] = ACTIONS(5781),
    [anon_sym_XMLPort] = ACTIONS(5781),
    [anon_sym_XmlPort] = ACTIONS(5781),
    [anon_sym_enum] = ACTIONS(5781),
    [anon_sym_ENUM] = ACTIONS(5781),
    [anon_sym_Enum] = ACTIONS(5781),
    [anon_sym_eNUM] = ACTIONS(5781),
    [anon_sym_eNum] = ACTIONS(5781),
    [anon_sym_ENum] = ACTIONS(5781),
    [sym_quoted_identifier] = ACTIONS(5783),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5783),
    [sym_verbatim_string] = ACTIONS(5783),
    [sym_integer] = ACTIONS(5781),
    [sym_continue_as_identifier] = ACTIONS(5783),
    [sym_preproc_open] = ACTIONS(5783),
    [sym_preproc_close] = ACTIONS(5783),
  },
  [STATE(2451)] = {
    [sym_identifier] = ACTIONS(5785),
    [anon_sym_SEMI] = ACTIONS(5787),
    [anon_sym_DASH] = ACTIONS(5787),
    [aux_sym_boolean_token1] = ACTIONS(5785),
    [aux_sym_boolean_token2] = ACTIONS(5785),
    [sym_decimal] = ACTIONS(5785),
    [anon_sym_LPAREN] = ACTIONS(5787),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5785),
    [anon_sym_LBRACK] = ACTIONS(5787),
    [aux_sym_record_type_token1] = ACTIONS(5785),
    [aux_sym_basic_type_token21] = ACTIONS(5785),
    [aux_sym_basic_type_token22] = ACTIONS(5785),
    [aux_sym_basic_type_token48] = ACTIONS(5785),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5785),
    [anon_sym_POUNDif] = ACTIONS(5787),
    [anon_sym_POUNDIF] = ACTIONS(5787),
    [anon_sym_POUNDIf] = ACTIONS(5787),
    [anon_sym_not] = ACTIONS(5785),
    [anon_sym_NOT] = ACTIONS(5785),
    [anon_sym_Not] = ACTIONS(5785),
    [anon_sym_POUNDelif] = ACTIONS(5787),
    [anon_sym_POUNDELIF] = ACTIONS(5787),
    [anon_sym_POUNDElif] = ACTIONS(5787),
    [anon_sym_POUNDelse] = ACTIONS(5787),
    [anon_sym_POUNDELSE] = ACTIONS(5787),
    [anon_sym_POUNDElse] = ACTIONS(5787),
    [anon_sym_POUNDelse2] = ACTIONS(5787),
    [anon_sym_POUNDELSE2] = ACTIONS(5787),
    [anon_sym_POUNDElse2] = ACTIONS(5787),
    [anon_sym_POUNDendif] = ACTIONS(5787),
    [anon_sym_POUNDENDIF] = ACTIONS(5787),
    [anon_sym_POUNDEndif] = ACTIONS(5787),
    [anon_sym_POUNDendif2] = ACTIONS(5787),
    [anon_sym_POUNDENDIF2] = ACTIONS(5787),
    [anon_sym_POUNDEndif2] = ACTIONS(5787),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5785),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5785),
    [anon_sym_PLUS] = ACTIONS(5787),
    [sym_datetime_literal] = ACTIONS(5787),
    [sym_date_literal] = ACTIONS(5785),
    [sym_time_literal] = ACTIONS(5785),
    [sym_biginteger_literal] = ACTIONS(5787),
    [anon_sym_if] = ACTIONS(5785),
    [anon_sym_IF] = ACTIONS(5785),
    [anon_sym_If] = ACTIONS(5785),
    [anon_sym_else] = ACTIONS(5785),
    [anon_sym_ELSE] = ACTIONS(5785),
    [anon_sym_Else] = ACTIONS(5785),
    [anon_sym_case] = ACTIONS(5785),
    [anon_sym_CASE] = ACTIONS(5785),
    [anon_sym_Case] = ACTIONS(5785),
    [anon_sym_for] = ACTIONS(5785),
    [anon_sym_FOR] = ACTIONS(5785),
    [anon_sym_For] = ACTIONS(5785),
    [anon_sym_foreach] = ACTIONS(5785),
    [anon_sym_FOREACH] = ACTIONS(5785),
    [anon_sym_Foreach] = ACTIONS(5785),
    [anon_sym_while] = ACTIONS(5785),
    [anon_sym_WHILE] = ACTIONS(5785),
    [anon_sym_While] = ACTIONS(5785),
    [anon_sym_repeat] = ACTIONS(5785),
    [anon_sym_REPEAT] = ACTIONS(5785),
    [anon_sym_Repeat] = ACTIONS(5785),
    [anon_sym_exit] = ACTIONS(5785),
    [anon_sym_EXIT] = ACTIONS(5785),
    [anon_sym_Exit] = ACTIONS(5785),
    [anon_sym_continue] = ACTIONS(5785),
    [anon_sym_CONTINUE] = ACTIONS(5785),
    [anon_sym_Continue] = ACTIONS(5785),
    [anon_sym_break] = ACTIONS(5785),
    [anon_sym_BREAK] = ACTIONS(5785),
    [anon_sym_Break] = ACTIONS(5785),
    [anon_sym_with] = ACTIONS(5785),
    [anon_sym_WITH] = ACTIONS(5785),
    [anon_sym_With] = ACTIONS(5785),
    [sym_asserterror_keyword] = ACTIONS(5787),
    [sym_page_keyword] = ACTIONS(5785),
    [anon_sym_codeunit] = ACTIONS(5785),
    [anon_sym_CODEUNIT] = ACTIONS(5785),
    [anon_sym_Codeunit] = ACTIONS(5785),
    [anon_sym_CodeUnit] = ACTIONS(5785),
    [anon_sym_COdeunit] = ACTIONS(5785),
    [anon_sym_codeUnit] = ACTIONS(5785),
    [sym_report_keyword] = ACTIONS(5785),
    [sym_query_keyword] = ACTIONS(5785),
    [anon_sym_xmlport] = ACTIONS(5785),
    [anon_sym_XMLPORT] = ACTIONS(5785),
    [anon_sym_Xmlport] = ACTIONS(5785),
    [anon_sym_XMLport] = ACTIONS(5785),
    [anon_sym_XMLPort] = ACTIONS(5785),
    [anon_sym_XmlPort] = ACTIONS(5785),
    [anon_sym_enum] = ACTIONS(5785),
    [anon_sym_ENUM] = ACTIONS(5785),
    [anon_sym_Enum] = ACTIONS(5785),
    [anon_sym_eNUM] = ACTIONS(5785),
    [anon_sym_eNum] = ACTIONS(5785),
    [anon_sym_ENum] = ACTIONS(5785),
    [sym_quoted_identifier] = ACTIONS(5787),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5787),
    [sym_verbatim_string] = ACTIONS(5787),
    [sym_integer] = ACTIONS(5785),
    [sym_continue_as_identifier] = ACTIONS(5787),
    [sym_preproc_open] = ACTIONS(5787),
    [sym_preproc_close] = ACTIONS(5787),
  },
  [STATE(2452)] = {
    [sym_identifier] = ACTIONS(5789),
    [anon_sym_SEMI] = ACTIONS(5791),
    [anon_sym_DASH] = ACTIONS(5793),
    [aux_sym_boolean_token1] = ACTIONS(5789),
    [aux_sym_boolean_token2] = ACTIONS(5789),
    [sym_decimal] = ACTIONS(5789),
    [anon_sym_LPAREN] = ACTIONS(5793),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5789),
    [anon_sym_LBRACK] = ACTIONS(5793),
    [aux_sym_record_type_token1] = ACTIONS(5789),
    [aux_sym_basic_type_token21] = ACTIONS(5789),
    [aux_sym_basic_type_token22] = ACTIONS(5789),
    [aux_sym_basic_type_token48] = ACTIONS(5789),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5789),
    [anon_sym_POUNDif] = ACTIONS(5793),
    [anon_sym_POUNDIF] = ACTIONS(5793),
    [anon_sym_POUNDIf] = ACTIONS(5793),
    [anon_sym_not] = ACTIONS(5789),
    [anon_sym_NOT] = ACTIONS(5789),
    [anon_sym_Not] = ACTIONS(5789),
    [anon_sym_POUNDelif] = ACTIONS(5793),
    [anon_sym_POUNDELIF] = ACTIONS(5793),
    [anon_sym_POUNDElif] = ACTIONS(5793),
    [anon_sym_POUNDelse] = ACTIONS(5793),
    [anon_sym_POUNDELSE] = ACTIONS(5793),
    [anon_sym_POUNDElse] = ACTIONS(5793),
    [anon_sym_POUNDelse2] = ACTIONS(5793),
    [anon_sym_POUNDELSE2] = ACTIONS(5793),
    [anon_sym_POUNDElse2] = ACTIONS(5793),
    [anon_sym_POUNDendif] = ACTIONS(5793),
    [anon_sym_POUNDENDIF] = ACTIONS(5793),
    [anon_sym_POUNDEndif] = ACTIONS(5793),
    [anon_sym_POUNDendif2] = ACTIONS(5793),
    [anon_sym_POUNDENDIF2] = ACTIONS(5793),
    [anon_sym_POUNDEndif2] = ACTIONS(5793),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5789),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5789),
    [anon_sym_PLUS] = ACTIONS(5793),
    [sym_datetime_literal] = ACTIONS(5793),
    [sym_date_literal] = ACTIONS(5789),
    [sym_time_literal] = ACTIONS(5789),
    [sym_biginteger_literal] = ACTIONS(5793),
    [anon_sym_if] = ACTIONS(5789),
    [anon_sym_IF] = ACTIONS(5789),
    [anon_sym_If] = ACTIONS(5789),
    [anon_sym_else] = ACTIONS(5789),
    [anon_sym_ELSE] = ACTIONS(5789),
    [anon_sym_Else] = ACTIONS(5789),
    [anon_sym_case] = ACTIONS(5789),
    [anon_sym_CASE] = ACTIONS(5789),
    [anon_sym_Case] = ACTIONS(5789),
    [anon_sym_for] = ACTIONS(5789),
    [anon_sym_FOR] = ACTIONS(5789),
    [anon_sym_For] = ACTIONS(5789),
    [anon_sym_foreach] = ACTIONS(5789),
    [anon_sym_FOREACH] = ACTIONS(5789),
    [anon_sym_Foreach] = ACTIONS(5789),
    [anon_sym_while] = ACTIONS(5789),
    [anon_sym_WHILE] = ACTIONS(5789),
    [anon_sym_While] = ACTIONS(5789),
    [anon_sym_repeat] = ACTIONS(5789),
    [anon_sym_REPEAT] = ACTIONS(5789),
    [anon_sym_Repeat] = ACTIONS(5789),
    [anon_sym_exit] = ACTIONS(5789),
    [anon_sym_EXIT] = ACTIONS(5789),
    [anon_sym_Exit] = ACTIONS(5789),
    [anon_sym_continue] = ACTIONS(5789),
    [anon_sym_CONTINUE] = ACTIONS(5789),
    [anon_sym_Continue] = ACTIONS(5789),
    [anon_sym_break] = ACTIONS(5789),
    [anon_sym_BREAK] = ACTIONS(5789),
    [anon_sym_Break] = ACTIONS(5789),
    [anon_sym_with] = ACTIONS(5789),
    [anon_sym_WITH] = ACTIONS(5789),
    [anon_sym_With] = ACTIONS(5789),
    [sym_asserterror_keyword] = ACTIONS(5793),
    [sym_page_keyword] = ACTIONS(5789),
    [anon_sym_codeunit] = ACTIONS(5789),
    [anon_sym_CODEUNIT] = ACTIONS(5789),
    [anon_sym_Codeunit] = ACTIONS(5789),
    [anon_sym_CodeUnit] = ACTIONS(5789),
    [anon_sym_COdeunit] = ACTIONS(5789),
    [anon_sym_codeUnit] = ACTIONS(5789),
    [sym_report_keyword] = ACTIONS(5789),
    [sym_query_keyword] = ACTIONS(5789),
    [anon_sym_xmlport] = ACTIONS(5789),
    [anon_sym_XMLPORT] = ACTIONS(5789),
    [anon_sym_Xmlport] = ACTIONS(5789),
    [anon_sym_XMLport] = ACTIONS(5789),
    [anon_sym_XMLPort] = ACTIONS(5789),
    [anon_sym_XmlPort] = ACTIONS(5789),
    [anon_sym_enum] = ACTIONS(5789),
    [anon_sym_ENUM] = ACTIONS(5789),
    [anon_sym_Enum] = ACTIONS(5789),
    [anon_sym_eNUM] = ACTIONS(5789),
    [anon_sym_eNum] = ACTIONS(5789),
    [anon_sym_ENum] = ACTIONS(5789),
    [sym_quoted_identifier] = ACTIONS(5793),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5793),
    [sym_verbatim_string] = ACTIONS(5793),
    [sym_integer] = ACTIONS(5789),
    [sym_continue_as_identifier] = ACTIONS(5793),
    [sym_preproc_open] = ACTIONS(5793),
    [sym_preproc_close] = ACTIONS(5793),
  },
  [STATE(2453)] = {
    [sym_identifier] = ACTIONS(5795),
    [anon_sym_SEMI] = ACTIONS(5797),
    [anon_sym_DASH] = ACTIONS(5797),
    [aux_sym_boolean_token1] = ACTIONS(5795),
    [aux_sym_boolean_token2] = ACTIONS(5795),
    [sym_decimal] = ACTIONS(5795),
    [anon_sym_LPAREN] = ACTIONS(5797),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5795),
    [anon_sym_LBRACK] = ACTIONS(5797),
    [aux_sym_record_type_token1] = ACTIONS(5795),
    [aux_sym_basic_type_token21] = ACTIONS(5795),
    [aux_sym_basic_type_token22] = ACTIONS(5795),
    [aux_sym_basic_type_token48] = ACTIONS(5795),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5795),
    [anon_sym_POUNDif] = ACTIONS(5797),
    [anon_sym_POUNDIF] = ACTIONS(5797),
    [anon_sym_POUNDIf] = ACTIONS(5797),
    [anon_sym_not] = ACTIONS(5795),
    [anon_sym_NOT] = ACTIONS(5795),
    [anon_sym_Not] = ACTIONS(5795),
    [anon_sym_POUNDelif] = ACTIONS(5797),
    [anon_sym_POUNDELIF] = ACTIONS(5797),
    [anon_sym_POUNDElif] = ACTIONS(5797),
    [anon_sym_POUNDelse] = ACTIONS(5797),
    [anon_sym_POUNDELSE] = ACTIONS(5797),
    [anon_sym_POUNDElse] = ACTIONS(5797),
    [anon_sym_POUNDelse2] = ACTIONS(5797),
    [anon_sym_POUNDELSE2] = ACTIONS(5797),
    [anon_sym_POUNDElse2] = ACTIONS(5797),
    [anon_sym_POUNDendif] = ACTIONS(5797),
    [anon_sym_POUNDENDIF] = ACTIONS(5797),
    [anon_sym_POUNDEndif] = ACTIONS(5797),
    [anon_sym_POUNDendif2] = ACTIONS(5797),
    [anon_sym_POUNDENDIF2] = ACTIONS(5797),
    [anon_sym_POUNDEndif2] = ACTIONS(5797),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5795),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5795),
    [anon_sym_PLUS] = ACTIONS(5797),
    [sym_datetime_literal] = ACTIONS(5797),
    [sym_date_literal] = ACTIONS(5795),
    [sym_time_literal] = ACTIONS(5795),
    [sym_biginteger_literal] = ACTIONS(5797),
    [anon_sym_if] = ACTIONS(5795),
    [anon_sym_IF] = ACTIONS(5795),
    [anon_sym_If] = ACTIONS(5795),
    [anon_sym_else] = ACTIONS(5795),
    [anon_sym_ELSE] = ACTIONS(5795),
    [anon_sym_Else] = ACTIONS(5795),
    [anon_sym_case] = ACTIONS(5795),
    [anon_sym_CASE] = ACTIONS(5795),
    [anon_sym_Case] = ACTIONS(5795),
    [anon_sym_for] = ACTIONS(5795),
    [anon_sym_FOR] = ACTIONS(5795),
    [anon_sym_For] = ACTIONS(5795),
    [anon_sym_foreach] = ACTIONS(5795),
    [anon_sym_FOREACH] = ACTIONS(5795),
    [anon_sym_Foreach] = ACTIONS(5795),
    [anon_sym_while] = ACTIONS(5795),
    [anon_sym_WHILE] = ACTIONS(5795),
    [anon_sym_While] = ACTIONS(5795),
    [anon_sym_repeat] = ACTIONS(5795),
    [anon_sym_REPEAT] = ACTIONS(5795),
    [anon_sym_Repeat] = ACTIONS(5795),
    [anon_sym_exit] = ACTIONS(5795),
    [anon_sym_EXIT] = ACTIONS(5795),
    [anon_sym_Exit] = ACTIONS(5795),
    [anon_sym_continue] = ACTIONS(5795),
    [anon_sym_CONTINUE] = ACTIONS(5795),
    [anon_sym_Continue] = ACTIONS(5795),
    [anon_sym_break] = ACTIONS(5795),
    [anon_sym_BREAK] = ACTIONS(5795),
    [anon_sym_Break] = ACTIONS(5795),
    [anon_sym_with] = ACTIONS(5795),
    [anon_sym_WITH] = ACTIONS(5795),
    [anon_sym_With] = ACTIONS(5795),
    [sym_asserterror_keyword] = ACTIONS(5797),
    [sym_page_keyword] = ACTIONS(5795),
    [anon_sym_codeunit] = ACTIONS(5795),
    [anon_sym_CODEUNIT] = ACTIONS(5795),
    [anon_sym_Codeunit] = ACTIONS(5795),
    [anon_sym_CodeUnit] = ACTIONS(5795),
    [anon_sym_COdeunit] = ACTIONS(5795),
    [anon_sym_codeUnit] = ACTIONS(5795),
    [sym_report_keyword] = ACTIONS(5795),
    [sym_query_keyword] = ACTIONS(5795),
    [anon_sym_xmlport] = ACTIONS(5795),
    [anon_sym_XMLPORT] = ACTIONS(5795),
    [anon_sym_Xmlport] = ACTIONS(5795),
    [anon_sym_XMLport] = ACTIONS(5795),
    [anon_sym_XMLPort] = ACTIONS(5795),
    [anon_sym_XmlPort] = ACTIONS(5795),
    [anon_sym_enum] = ACTIONS(5795),
    [anon_sym_ENUM] = ACTIONS(5795),
    [anon_sym_Enum] = ACTIONS(5795),
    [anon_sym_eNUM] = ACTIONS(5795),
    [anon_sym_eNum] = ACTIONS(5795),
    [anon_sym_ENum] = ACTIONS(5795),
    [sym_quoted_identifier] = ACTIONS(5797),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5797),
    [sym_verbatim_string] = ACTIONS(5797),
    [sym_integer] = ACTIONS(5795),
    [sym_continue_as_identifier] = ACTIONS(5797),
    [sym_preproc_open] = ACTIONS(5797),
    [sym_preproc_close] = ACTIONS(5797),
  },
  [STATE(2454)] = {
    [sym_identifier] = ACTIONS(5799),
    [anon_sym_SEMI] = ACTIONS(5801),
    [anon_sym_DASH] = ACTIONS(5801),
    [aux_sym_boolean_token1] = ACTIONS(5799),
    [aux_sym_boolean_token2] = ACTIONS(5799),
    [sym_decimal] = ACTIONS(5799),
    [anon_sym_LPAREN] = ACTIONS(5801),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5799),
    [anon_sym_LBRACK] = ACTIONS(5801),
    [aux_sym_record_type_token1] = ACTIONS(5799),
    [aux_sym_basic_type_token21] = ACTIONS(5799),
    [aux_sym_basic_type_token22] = ACTIONS(5799),
    [aux_sym_basic_type_token48] = ACTIONS(5799),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5799),
    [anon_sym_POUNDif] = ACTIONS(5801),
    [anon_sym_POUNDIF] = ACTIONS(5801),
    [anon_sym_POUNDIf] = ACTIONS(5801),
    [anon_sym_not] = ACTIONS(5799),
    [anon_sym_NOT] = ACTIONS(5799),
    [anon_sym_Not] = ACTIONS(5799),
    [anon_sym_POUNDelif] = ACTIONS(5801),
    [anon_sym_POUNDELIF] = ACTIONS(5801),
    [anon_sym_POUNDElif] = ACTIONS(5801),
    [anon_sym_POUNDelse] = ACTIONS(5801),
    [anon_sym_POUNDELSE] = ACTIONS(5801),
    [anon_sym_POUNDElse] = ACTIONS(5801),
    [anon_sym_POUNDelse2] = ACTIONS(5801),
    [anon_sym_POUNDELSE2] = ACTIONS(5801),
    [anon_sym_POUNDElse2] = ACTIONS(5801),
    [anon_sym_POUNDendif] = ACTIONS(5801),
    [anon_sym_POUNDENDIF] = ACTIONS(5801),
    [anon_sym_POUNDEndif] = ACTIONS(5801),
    [anon_sym_POUNDendif2] = ACTIONS(5801),
    [anon_sym_POUNDENDIF2] = ACTIONS(5801),
    [anon_sym_POUNDEndif2] = ACTIONS(5801),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5799),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5799),
    [anon_sym_PLUS] = ACTIONS(5801),
    [sym_datetime_literal] = ACTIONS(5801),
    [sym_date_literal] = ACTIONS(5799),
    [sym_time_literal] = ACTIONS(5799),
    [sym_biginteger_literal] = ACTIONS(5801),
    [anon_sym_if] = ACTIONS(5799),
    [anon_sym_IF] = ACTIONS(5799),
    [anon_sym_If] = ACTIONS(5799),
    [anon_sym_else] = ACTIONS(5799),
    [anon_sym_ELSE] = ACTIONS(5799),
    [anon_sym_Else] = ACTIONS(5799),
    [anon_sym_case] = ACTIONS(5799),
    [anon_sym_CASE] = ACTIONS(5799),
    [anon_sym_Case] = ACTIONS(5799),
    [anon_sym_for] = ACTIONS(5799),
    [anon_sym_FOR] = ACTIONS(5799),
    [anon_sym_For] = ACTIONS(5799),
    [anon_sym_foreach] = ACTIONS(5799),
    [anon_sym_FOREACH] = ACTIONS(5799),
    [anon_sym_Foreach] = ACTIONS(5799),
    [anon_sym_while] = ACTIONS(5799),
    [anon_sym_WHILE] = ACTIONS(5799),
    [anon_sym_While] = ACTIONS(5799),
    [anon_sym_repeat] = ACTIONS(5799),
    [anon_sym_REPEAT] = ACTIONS(5799),
    [anon_sym_Repeat] = ACTIONS(5799),
    [anon_sym_exit] = ACTIONS(5799),
    [anon_sym_EXIT] = ACTIONS(5799),
    [anon_sym_Exit] = ACTIONS(5799),
    [anon_sym_continue] = ACTIONS(5799),
    [anon_sym_CONTINUE] = ACTIONS(5799),
    [anon_sym_Continue] = ACTIONS(5799),
    [anon_sym_break] = ACTIONS(5799),
    [anon_sym_BREAK] = ACTIONS(5799),
    [anon_sym_Break] = ACTIONS(5799),
    [anon_sym_with] = ACTIONS(5799),
    [anon_sym_WITH] = ACTIONS(5799),
    [anon_sym_With] = ACTIONS(5799),
    [sym_asserterror_keyword] = ACTIONS(5801),
    [sym_page_keyword] = ACTIONS(5799),
    [anon_sym_codeunit] = ACTIONS(5799),
    [anon_sym_CODEUNIT] = ACTIONS(5799),
    [anon_sym_Codeunit] = ACTIONS(5799),
    [anon_sym_CodeUnit] = ACTIONS(5799),
    [anon_sym_COdeunit] = ACTIONS(5799),
    [anon_sym_codeUnit] = ACTIONS(5799),
    [sym_report_keyword] = ACTIONS(5799),
    [sym_query_keyword] = ACTIONS(5799),
    [anon_sym_xmlport] = ACTIONS(5799),
    [anon_sym_XMLPORT] = ACTIONS(5799),
    [anon_sym_Xmlport] = ACTIONS(5799),
    [anon_sym_XMLport] = ACTIONS(5799),
    [anon_sym_XMLPort] = ACTIONS(5799),
    [anon_sym_XmlPort] = ACTIONS(5799),
    [anon_sym_enum] = ACTIONS(5799),
    [anon_sym_ENUM] = ACTIONS(5799),
    [anon_sym_Enum] = ACTIONS(5799),
    [anon_sym_eNUM] = ACTIONS(5799),
    [anon_sym_eNum] = ACTIONS(5799),
    [anon_sym_ENum] = ACTIONS(5799),
    [sym_quoted_identifier] = ACTIONS(5801),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5801),
    [sym_verbatim_string] = ACTIONS(5801),
    [sym_integer] = ACTIONS(5799),
    [sym_continue_as_identifier] = ACTIONS(5801),
    [sym_preproc_open] = ACTIONS(5801),
    [sym_preproc_close] = ACTIONS(5801),
  },
  [STATE(2455)] = {
    [sym_identifier] = ACTIONS(5803),
    [anon_sym_SEMI] = ACTIONS(5805),
    [anon_sym_DASH] = ACTIONS(5805),
    [aux_sym_boolean_token1] = ACTIONS(5803),
    [aux_sym_boolean_token2] = ACTIONS(5803),
    [sym_decimal] = ACTIONS(5803),
    [anon_sym_LPAREN] = ACTIONS(5805),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5803),
    [anon_sym_LBRACK] = ACTIONS(5805),
    [aux_sym_record_type_token1] = ACTIONS(5803),
    [aux_sym_basic_type_token21] = ACTIONS(5803),
    [aux_sym_basic_type_token22] = ACTIONS(5803),
    [aux_sym_basic_type_token48] = ACTIONS(5803),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5803),
    [anon_sym_POUNDif] = ACTIONS(5805),
    [anon_sym_POUNDIF] = ACTIONS(5805),
    [anon_sym_POUNDIf] = ACTIONS(5805),
    [anon_sym_not] = ACTIONS(5803),
    [anon_sym_NOT] = ACTIONS(5803),
    [anon_sym_Not] = ACTIONS(5803),
    [anon_sym_POUNDelif] = ACTIONS(5805),
    [anon_sym_POUNDELIF] = ACTIONS(5805),
    [anon_sym_POUNDElif] = ACTIONS(5805),
    [anon_sym_POUNDelse] = ACTIONS(5805),
    [anon_sym_POUNDELSE] = ACTIONS(5805),
    [anon_sym_POUNDElse] = ACTIONS(5805),
    [anon_sym_POUNDelse2] = ACTIONS(5805),
    [anon_sym_POUNDELSE2] = ACTIONS(5805),
    [anon_sym_POUNDElse2] = ACTIONS(5805),
    [anon_sym_POUNDendif] = ACTIONS(5805),
    [anon_sym_POUNDENDIF] = ACTIONS(5805),
    [anon_sym_POUNDEndif] = ACTIONS(5805),
    [anon_sym_POUNDendif2] = ACTIONS(5805),
    [anon_sym_POUNDENDIF2] = ACTIONS(5805),
    [anon_sym_POUNDEndif2] = ACTIONS(5805),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5803),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5803),
    [anon_sym_PLUS] = ACTIONS(5805),
    [sym_datetime_literal] = ACTIONS(5805),
    [sym_date_literal] = ACTIONS(5803),
    [sym_time_literal] = ACTIONS(5803),
    [sym_biginteger_literal] = ACTIONS(5805),
    [anon_sym_if] = ACTIONS(5803),
    [anon_sym_IF] = ACTIONS(5803),
    [anon_sym_If] = ACTIONS(5803),
    [anon_sym_else] = ACTIONS(5803),
    [anon_sym_ELSE] = ACTIONS(5803),
    [anon_sym_Else] = ACTIONS(5803),
    [anon_sym_case] = ACTIONS(5803),
    [anon_sym_CASE] = ACTIONS(5803),
    [anon_sym_Case] = ACTIONS(5803),
    [anon_sym_for] = ACTIONS(5803),
    [anon_sym_FOR] = ACTIONS(5803),
    [anon_sym_For] = ACTIONS(5803),
    [anon_sym_foreach] = ACTIONS(5803),
    [anon_sym_FOREACH] = ACTIONS(5803),
    [anon_sym_Foreach] = ACTIONS(5803),
    [anon_sym_while] = ACTIONS(5803),
    [anon_sym_WHILE] = ACTIONS(5803),
    [anon_sym_While] = ACTIONS(5803),
    [anon_sym_repeat] = ACTIONS(5803),
    [anon_sym_REPEAT] = ACTIONS(5803),
    [anon_sym_Repeat] = ACTIONS(5803),
    [anon_sym_exit] = ACTIONS(5803),
    [anon_sym_EXIT] = ACTIONS(5803),
    [anon_sym_Exit] = ACTIONS(5803),
    [anon_sym_continue] = ACTIONS(5803),
    [anon_sym_CONTINUE] = ACTIONS(5803),
    [anon_sym_Continue] = ACTIONS(5803),
    [anon_sym_break] = ACTIONS(5803),
    [anon_sym_BREAK] = ACTIONS(5803),
    [anon_sym_Break] = ACTIONS(5803),
    [anon_sym_with] = ACTIONS(5803),
    [anon_sym_WITH] = ACTIONS(5803),
    [anon_sym_With] = ACTIONS(5803),
    [sym_asserterror_keyword] = ACTIONS(5805),
    [sym_page_keyword] = ACTIONS(5803),
    [anon_sym_codeunit] = ACTIONS(5803),
    [anon_sym_CODEUNIT] = ACTIONS(5803),
    [anon_sym_Codeunit] = ACTIONS(5803),
    [anon_sym_CodeUnit] = ACTIONS(5803),
    [anon_sym_COdeunit] = ACTIONS(5803),
    [anon_sym_codeUnit] = ACTIONS(5803),
    [sym_report_keyword] = ACTIONS(5803),
    [sym_query_keyword] = ACTIONS(5803),
    [anon_sym_xmlport] = ACTIONS(5803),
    [anon_sym_XMLPORT] = ACTIONS(5803),
    [anon_sym_Xmlport] = ACTIONS(5803),
    [anon_sym_XMLport] = ACTIONS(5803),
    [anon_sym_XMLPort] = ACTIONS(5803),
    [anon_sym_XmlPort] = ACTIONS(5803),
    [anon_sym_enum] = ACTIONS(5803),
    [anon_sym_ENUM] = ACTIONS(5803),
    [anon_sym_Enum] = ACTIONS(5803),
    [anon_sym_eNUM] = ACTIONS(5803),
    [anon_sym_eNum] = ACTIONS(5803),
    [anon_sym_ENum] = ACTIONS(5803),
    [sym_quoted_identifier] = ACTIONS(5805),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5805),
    [sym_verbatim_string] = ACTIONS(5805),
    [sym_integer] = ACTIONS(5803),
    [sym_continue_as_identifier] = ACTIONS(5805),
    [sym_preproc_open] = ACTIONS(5805),
    [sym_preproc_close] = ACTIONS(5805),
  },
  [STATE(2456)] = {
    [sym_identifier] = ACTIONS(5807),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_DASH] = ACTIONS(5809),
    [aux_sym_boolean_token1] = ACTIONS(5807),
    [aux_sym_boolean_token2] = ACTIONS(5807),
    [sym_decimal] = ACTIONS(5807),
    [anon_sym_LPAREN] = ACTIONS(5809),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5809),
    [aux_sym_record_type_token1] = ACTIONS(5807),
    [aux_sym_basic_type_token21] = ACTIONS(5807),
    [aux_sym_basic_type_token22] = ACTIONS(5807),
    [aux_sym_basic_type_token48] = ACTIONS(5807),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5807),
    [anon_sym_POUNDif] = ACTIONS(5809),
    [anon_sym_POUNDIF] = ACTIONS(5809),
    [anon_sym_POUNDIf] = ACTIONS(5809),
    [anon_sym_not] = ACTIONS(5807),
    [anon_sym_NOT] = ACTIONS(5807),
    [anon_sym_Not] = ACTIONS(5807),
    [anon_sym_POUNDelif] = ACTIONS(5809),
    [anon_sym_POUNDELIF] = ACTIONS(5809),
    [anon_sym_POUNDElif] = ACTIONS(5809),
    [anon_sym_POUNDelse] = ACTIONS(5809),
    [anon_sym_POUNDELSE] = ACTIONS(5809),
    [anon_sym_POUNDElse] = ACTIONS(5809),
    [anon_sym_POUNDelse2] = ACTIONS(5809),
    [anon_sym_POUNDELSE2] = ACTIONS(5809),
    [anon_sym_POUNDElse2] = ACTIONS(5809),
    [anon_sym_POUNDendif] = ACTIONS(5809),
    [anon_sym_POUNDENDIF] = ACTIONS(5809),
    [anon_sym_POUNDEndif] = ACTIONS(5809),
    [anon_sym_POUNDendif2] = ACTIONS(5809),
    [anon_sym_POUNDENDIF2] = ACTIONS(5809),
    [anon_sym_POUNDEndif2] = ACTIONS(5809),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5807),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5807),
    [anon_sym_PLUS] = ACTIONS(5809),
    [sym_datetime_literal] = ACTIONS(5809),
    [sym_date_literal] = ACTIONS(5807),
    [sym_time_literal] = ACTIONS(5807),
    [sym_biginteger_literal] = ACTIONS(5809),
    [anon_sym_if] = ACTIONS(5807),
    [anon_sym_IF] = ACTIONS(5807),
    [anon_sym_If] = ACTIONS(5807),
    [anon_sym_else] = ACTIONS(5807),
    [anon_sym_ELSE] = ACTIONS(5807),
    [anon_sym_Else] = ACTIONS(5807),
    [anon_sym_case] = ACTIONS(5807),
    [anon_sym_CASE] = ACTIONS(5807),
    [anon_sym_Case] = ACTIONS(5807),
    [anon_sym_for] = ACTIONS(5807),
    [anon_sym_FOR] = ACTIONS(5807),
    [anon_sym_For] = ACTIONS(5807),
    [anon_sym_foreach] = ACTIONS(5807),
    [anon_sym_FOREACH] = ACTIONS(5807),
    [anon_sym_Foreach] = ACTIONS(5807),
    [anon_sym_while] = ACTIONS(5807),
    [anon_sym_WHILE] = ACTIONS(5807),
    [anon_sym_While] = ACTIONS(5807),
    [anon_sym_repeat] = ACTIONS(5807),
    [anon_sym_REPEAT] = ACTIONS(5807),
    [anon_sym_Repeat] = ACTIONS(5807),
    [anon_sym_exit] = ACTIONS(5807),
    [anon_sym_EXIT] = ACTIONS(5807),
    [anon_sym_Exit] = ACTIONS(5807),
    [anon_sym_continue] = ACTIONS(5807),
    [anon_sym_CONTINUE] = ACTIONS(5807),
    [anon_sym_Continue] = ACTIONS(5807),
    [anon_sym_break] = ACTIONS(5807),
    [anon_sym_BREAK] = ACTIONS(5807),
    [anon_sym_Break] = ACTIONS(5807),
    [anon_sym_with] = ACTIONS(5807),
    [anon_sym_WITH] = ACTIONS(5807),
    [anon_sym_With] = ACTIONS(5807),
    [sym_asserterror_keyword] = ACTIONS(5809),
    [sym_page_keyword] = ACTIONS(5807),
    [anon_sym_codeunit] = ACTIONS(5807),
    [anon_sym_CODEUNIT] = ACTIONS(5807),
    [anon_sym_Codeunit] = ACTIONS(5807),
    [anon_sym_CodeUnit] = ACTIONS(5807),
    [anon_sym_COdeunit] = ACTIONS(5807),
    [anon_sym_codeUnit] = ACTIONS(5807),
    [sym_report_keyword] = ACTIONS(5807),
    [sym_query_keyword] = ACTIONS(5807),
    [anon_sym_xmlport] = ACTIONS(5807),
    [anon_sym_XMLPORT] = ACTIONS(5807),
    [anon_sym_Xmlport] = ACTIONS(5807),
    [anon_sym_XMLport] = ACTIONS(5807),
    [anon_sym_XMLPort] = ACTIONS(5807),
    [anon_sym_XmlPort] = ACTIONS(5807),
    [anon_sym_enum] = ACTIONS(5807),
    [anon_sym_ENUM] = ACTIONS(5807),
    [anon_sym_Enum] = ACTIONS(5807),
    [anon_sym_eNUM] = ACTIONS(5807),
    [anon_sym_eNum] = ACTIONS(5807),
    [anon_sym_ENum] = ACTIONS(5807),
    [sym_quoted_identifier] = ACTIONS(5809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5809),
    [sym_verbatim_string] = ACTIONS(5809),
    [sym_integer] = ACTIONS(5807),
    [sym_continue_as_identifier] = ACTIONS(5809),
    [sym_preproc_open] = ACTIONS(5809),
    [sym_preproc_close] = ACTIONS(5809),
  },
  [STATE(2457)] = {
    [sym_identifier] = ACTIONS(5811),
    [anon_sym_SEMI] = ACTIONS(5813),
    [anon_sym_DASH] = ACTIONS(5813),
    [aux_sym_boolean_token1] = ACTIONS(5811),
    [aux_sym_boolean_token2] = ACTIONS(5811),
    [sym_decimal] = ACTIONS(5811),
    [anon_sym_LPAREN] = ACTIONS(5813),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5811),
    [anon_sym_LBRACK] = ACTIONS(5813),
    [aux_sym_record_type_token1] = ACTIONS(5811),
    [aux_sym_basic_type_token21] = ACTIONS(5811),
    [aux_sym_basic_type_token22] = ACTIONS(5811),
    [aux_sym_basic_type_token48] = ACTIONS(5811),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5811),
    [anon_sym_POUNDif] = ACTIONS(5813),
    [anon_sym_POUNDIF] = ACTIONS(5813),
    [anon_sym_POUNDIf] = ACTIONS(5813),
    [anon_sym_not] = ACTIONS(5811),
    [anon_sym_NOT] = ACTIONS(5811),
    [anon_sym_Not] = ACTIONS(5811),
    [anon_sym_POUNDelif] = ACTIONS(5813),
    [anon_sym_POUNDELIF] = ACTIONS(5813),
    [anon_sym_POUNDElif] = ACTIONS(5813),
    [anon_sym_POUNDelse] = ACTIONS(5813),
    [anon_sym_POUNDELSE] = ACTIONS(5813),
    [anon_sym_POUNDElse] = ACTIONS(5813),
    [anon_sym_POUNDelse2] = ACTIONS(5813),
    [anon_sym_POUNDELSE2] = ACTIONS(5813),
    [anon_sym_POUNDElse2] = ACTIONS(5813),
    [anon_sym_POUNDendif] = ACTIONS(5813),
    [anon_sym_POUNDENDIF] = ACTIONS(5813),
    [anon_sym_POUNDEndif] = ACTIONS(5813),
    [anon_sym_POUNDendif2] = ACTIONS(5813),
    [anon_sym_POUNDENDIF2] = ACTIONS(5813),
    [anon_sym_POUNDEndif2] = ACTIONS(5813),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5811),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5811),
    [anon_sym_PLUS] = ACTIONS(5813),
    [sym_datetime_literal] = ACTIONS(5813),
    [sym_date_literal] = ACTIONS(5811),
    [sym_time_literal] = ACTIONS(5811),
    [sym_biginteger_literal] = ACTIONS(5813),
    [anon_sym_if] = ACTIONS(5811),
    [anon_sym_IF] = ACTIONS(5811),
    [anon_sym_If] = ACTIONS(5811),
    [anon_sym_else] = ACTIONS(5811),
    [anon_sym_ELSE] = ACTIONS(5811),
    [anon_sym_Else] = ACTIONS(5811),
    [anon_sym_case] = ACTIONS(5811),
    [anon_sym_CASE] = ACTIONS(5811),
    [anon_sym_Case] = ACTIONS(5811),
    [anon_sym_for] = ACTIONS(5811),
    [anon_sym_FOR] = ACTIONS(5811),
    [anon_sym_For] = ACTIONS(5811),
    [anon_sym_foreach] = ACTIONS(5811),
    [anon_sym_FOREACH] = ACTIONS(5811),
    [anon_sym_Foreach] = ACTIONS(5811),
    [anon_sym_while] = ACTIONS(5811),
    [anon_sym_WHILE] = ACTIONS(5811),
    [anon_sym_While] = ACTIONS(5811),
    [anon_sym_repeat] = ACTIONS(5811),
    [anon_sym_REPEAT] = ACTIONS(5811),
    [anon_sym_Repeat] = ACTIONS(5811),
    [anon_sym_exit] = ACTIONS(5811),
    [anon_sym_EXIT] = ACTIONS(5811),
    [anon_sym_Exit] = ACTIONS(5811),
    [anon_sym_continue] = ACTIONS(5811),
    [anon_sym_CONTINUE] = ACTIONS(5811),
    [anon_sym_Continue] = ACTIONS(5811),
    [anon_sym_break] = ACTIONS(5811),
    [anon_sym_BREAK] = ACTIONS(5811),
    [anon_sym_Break] = ACTIONS(5811),
    [anon_sym_with] = ACTIONS(5811),
    [anon_sym_WITH] = ACTIONS(5811),
    [anon_sym_With] = ACTIONS(5811),
    [sym_asserterror_keyword] = ACTIONS(5813),
    [sym_page_keyword] = ACTIONS(5811),
    [anon_sym_codeunit] = ACTIONS(5811),
    [anon_sym_CODEUNIT] = ACTIONS(5811),
    [anon_sym_Codeunit] = ACTIONS(5811),
    [anon_sym_CodeUnit] = ACTIONS(5811),
    [anon_sym_COdeunit] = ACTIONS(5811),
    [anon_sym_codeUnit] = ACTIONS(5811),
    [sym_report_keyword] = ACTIONS(5811),
    [sym_query_keyword] = ACTIONS(5811),
    [anon_sym_xmlport] = ACTIONS(5811),
    [anon_sym_XMLPORT] = ACTIONS(5811),
    [anon_sym_Xmlport] = ACTIONS(5811),
    [anon_sym_XMLport] = ACTIONS(5811),
    [anon_sym_XMLPort] = ACTIONS(5811),
    [anon_sym_XmlPort] = ACTIONS(5811),
    [anon_sym_enum] = ACTIONS(5811),
    [anon_sym_ENUM] = ACTIONS(5811),
    [anon_sym_Enum] = ACTIONS(5811),
    [anon_sym_eNUM] = ACTIONS(5811),
    [anon_sym_eNum] = ACTIONS(5811),
    [anon_sym_ENum] = ACTIONS(5811),
    [sym_quoted_identifier] = ACTIONS(5813),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5813),
    [sym_verbatim_string] = ACTIONS(5813),
    [sym_integer] = ACTIONS(5811),
    [sym_continue_as_identifier] = ACTIONS(5813),
    [sym_preproc_open] = ACTIONS(5813),
    [sym_preproc_close] = ACTIONS(5813),
  },
  [STATE(2458)] = {
    [sym_identifier] = ACTIONS(5815),
    [anon_sym_SEMI] = ACTIONS(5817),
    [anon_sym_DASH] = ACTIONS(5817),
    [aux_sym_boolean_token1] = ACTIONS(5815),
    [aux_sym_boolean_token2] = ACTIONS(5815),
    [sym_decimal] = ACTIONS(5815),
    [anon_sym_LPAREN] = ACTIONS(5817),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(5817),
    [aux_sym_record_type_token1] = ACTIONS(5815),
    [aux_sym_basic_type_token21] = ACTIONS(5815),
    [aux_sym_basic_type_token22] = ACTIONS(5815),
    [aux_sym_basic_type_token48] = ACTIONS(5815),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5815),
    [anon_sym_POUNDif] = ACTIONS(5817),
    [anon_sym_POUNDIF] = ACTIONS(5817),
    [anon_sym_POUNDIf] = ACTIONS(5817),
    [anon_sym_not] = ACTIONS(5815),
    [anon_sym_NOT] = ACTIONS(5815),
    [anon_sym_Not] = ACTIONS(5815),
    [anon_sym_POUNDelif] = ACTIONS(5817),
    [anon_sym_POUNDELIF] = ACTIONS(5817),
    [anon_sym_POUNDElif] = ACTIONS(5817),
    [anon_sym_POUNDelse] = ACTIONS(5817),
    [anon_sym_POUNDELSE] = ACTIONS(5817),
    [anon_sym_POUNDElse] = ACTIONS(5817),
    [anon_sym_POUNDelse2] = ACTIONS(5817),
    [anon_sym_POUNDELSE2] = ACTIONS(5817),
    [anon_sym_POUNDElse2] = ACTIONS(5817),
    [anon_sym_POUNDendif] = ACTIONS(5817),
    [anon_sym_POUNDENDIF] = ACTIONS(5817),
    [anon_sym_POUNDEndif] = ACTIONS(5817),
    [anon_sym_POUNDendif2] = ACTIONS(5817),
    [anon_sym_POUNDENDIF2] = ACTIONS(5817),
    [anon_sym_POUNDEndif2] = ACTIONS(5817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5815),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5815),
    [anon_sym_PLUS] = ACTIONS(5817),
    [sym_datetime_literal] = ACTIONS(5817),
    [sym_date_literal] = ACTIONS(5815),
    [sym_time_literal] = ACTIONS(5815),
    [sym_biginteger_literal] = ACTIONS(5817),
    [anon_sym_if] = ACTIONS(5815),
    [anon_sym_IF] = ACTIONS(5815),
    [anon_sym_If] = ACTIONS(5815),
    [anon_sym_else] = ACTIONS(5815),
    [anon_sym_ELSE] = ACTIONS(5815),
    [anon_sym_Else] = ACTIONS(5815),
    [anon_sym_case] = ACTIONS(5815),
    [anon_sym_CASE] = ACTIONS(5815),
    [anon_sym_Case] = ACTIONS(5815),
    [anon_sym_for] = ACTIONS(5815),
    [anon_sym_FOR] = ACTIONS(5815),
    [anon_sym_For] = ACTIONS(5815),
    [anon_sym_foreach] = ACTIONS(5815),
    [anon_sym_FOREACH] = ACTIONS(5815),
    [anon_sym_Foreach] = ACTIONS(5815),
    [anon_sym_while] = ACTIONS(5815),
    [anon_sym_WHILE] = ACTIONS(5815),
    [anon_sym_While] = ACTIONS(5815),
    [anon_sym_repeat] = ACTIONS(5815),
    [anon_sym_REPEAT] = ACTIONS(5815),
    [anon_sym_Repeat] = ACTIONS(5815),
    [anon_sym_exit] = ACTIONS(5815),
    [anon_sym_EXIT] = ACTIONS(5815),
    [anon_sym_Exit] = ACTIONS(5815),
    [anon_sym_continue] = ACTIONS(5815),
    [anon_sym_CONTINUE] = ACTIONS(5815),
    [anon_sym_Continue] = ACTIONS(5815),
    [anon_sym_break] = ACTIONS(5815),
    [anon_sym_BREAK] = ACTIONS(5815),
    [anon_sym_Break] = ACTIONS(5815),
    [anon_sym_with] = ACTIONS(5815),
    [anon_sym_WITH] = ACTIONS(5815),
    [anon_sym_With] = ACTIONS(5815),
    [sym_asserterror_keyword] = ACTIONS(5817),
    [sym_page_keyword] = ACTIONS(5815),
    [anon_sym_codeunit] = ACTIONS(5815),
    [anon_sym_CODEUNIT] = ACTIONS(5815),
    [anon_sym_Codeunit] = ACTIONS(5815),
    [anon_sym_CodeUnit] = ACTIONS(5815),
    [anon_sym_COdeunit] = ACTIONS(5815),
    [anon_sym_codeUnit] = ACTIONS(5815),
    [sym_report_keyword] = ACTIONS(5815),
    [sym_query_keyword] = ACTIONS(5815),
    [anon_sym_xmlport] = ACTIONS(5815),
    [anon_sym_XMLPORT] = ACTIONS(5815),
    [anon_sym_Xmlport] = ACTIONS(5815),
    [anon_sym_XMLport] = ACTIONS(5815),
    [anon_sym_XMLPort] = ACTIONS(5815),
    [anon_sym_XmlPort] = ACTIONS(5815),
    [anon_sym_enum] = ACTIONS(5815),
    [anon_sym_ENUM] = ACTIONS(5815),
    [anon_sym_Enum] = ACTIONS(5815),
    [anon_sym_eNUM] = ACTIONS(5815),
    [anon_sym_eNum] = ACTIONS(5815),
    [anon_sym_ENum] = ACTIONS(5815),
    [sym_quoted_identifier] = ACTIONS(5817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5817),
    [sym_verbatim_string] = ACTIONS(5817),
    [sym_integer] = ACTIONS(5815),
    [sym_continue_as_identifier] = ACTIONS(5817),
    [sym_preproc_open] = ACTIONS(5817),
    [sym_preproc_close] = ACTIONS(5817),
  },
  [STATE(2459)] = {
    [sym_identifier] = ACTIONS(5819),
    [anon_sym_SEMI] = ACTIONS(5821),
    [anon_sym_DASH] = ACTIONS(5821),
    [aux_sym_boolean_token1] = ACTIONS(5819),
    [aux_sym_boolean_token2] = ACTIONS(5819),
    [sym_decimal] = ACTIONS(5819),
    [anon_sym_LPAREN] = ACTIONS(5821),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5819),
    [anon_sym_LBRACK] = ACTIONS(5821),
    [aux_sym_record_type_token1] = ACTIONS(5819),
    [aux_sym_basic_type_token21] = ACTIONS(5819),
    [aux_sym_basic_type_token22] = ACTIONS(5819),
    [aux_sym_basic_type_token48] = ACTIONS(5819),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5819),
    [anon_sym_POUNDif] = ACTIONS(5821),
    [anon_sym_POUNDIF] = ACTIONS(5821),
    [anon_sym_POUNDIf] = ACTIONS(5821),
    [anon_sym_not] = ACTIONS(5819),
    [anon_sym_NOT] = ACTIONS(5819),
    [anon_sym_Not] = ACTIONS(5819),
    [anon_sym_POUNDelif] = ACTIONS(5821),
    [anon_sym_POUNDELIF] = ACTIONS(5821),
    [anon_sym_POUNDElif] = ACTIONS(5821),
    [anon_sym_POUNDelse] = ACTIONS(5821),
    [anon_sym_POUNDELSE] = ACTIONS(5821),
    [anon_sym_POUNDElse] = ACTIONS(5821),
    [anon_sym_POUNDelse2] = ACTIONS(5821),
    [anon_sym_POUNDELSE2] = ACTIONS(5821),
    [anon_sym_POUNDElse2] = ACTIONS(5821),
    [anon_sym_POUNDendif] = ACTIONS(5821),
    [anon_sym_POUNDENDIF] = ACTIONS(5821),
    [anon_sym_POUNDEndif] = ACTIONS(5821),
    [anon_sym_POUNDendif2] = ACTIONS(5821),
    [anon_sym_POUNDENDIF2] = ACTIONS(5821),
    [anon_sym_POUNDEndif2] = ACTIONS(5821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5819),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5819),
    [anon_sym_PLUS] = ACTIONS(5821),
    [sym_datetime_literal] = ACTIONS(5821),
    [sym_date_literal] = ACTIONS(5819),
    [sym_time_literal] = ACTIONS(5819),
    [sym_biginteger_literal] = ACTIONS(5821),
    [anon_sym_if] = ACTIONS(5819),
    [anon_sym_IF] = ACTIONS(5819),
    [anon_sym_If] = ACTIONS(5819),
    [anon_sym_else] = ACTIONS(5819),
    [anon_sym_ELSE] = ACTIONS(5819),
    [anon_sym_Else] = ACTIONS(5819),
    [anon_sym_case] = ACTIONS(5819),
    [anon_sym_CASE] = ACTIONS(5819),
    [anon_sym_Case] = ACTIONS(5819),
    [anon_sym_for] = ACTIONS(5819),
    [anon_sym_FOR] = ACTIONS(5819),
    [anon_sym_For] = ACTIONS(5819),
    [anon_sym_foreach] = ACTIONS(5819),
    [anon_sym_FOREACH] = ACTIONS(5819),
    [anon_sym_Foreach] = ACTIONS(5819),
    [anon_sym_while] = ACTIONS(5819),
    [anon_sym_WHILE] = ACTIONS(5819),
    [anon_sym_While] = ACTIONS(5819),
    [anon_sym_repeat] = ACTIONS(5819),
    [anon_sym_REPEAT] = ACTIONS(5819),
    [anon_sym_Repeat] = ACTIONS(5819),
    [anon_sym_exit] = ACTIONS(5819),
    [anon_sym_EXIT] = ACTIONS(5819),
    [anon_sym_Exit] = ACTIONS(5819),
    [anon_sym_continue] = ACTIONS(5819),
    [anon_sym_CONTINUE] = ACTIONS(5819),
    [anon_sym_Continue] = ACTIONS(5819),
    [anon_sym_break] = ACTIONS(5819),
    [anon_sym_BREAK] = ACTIONS(5819),
    [anon_sym_Break] = ACTIONS(5819),
    [anon_sym_with] = ACTIONS(5819),
    [anon_sym_WITH] = ACTIONS(5819),
    [anon_sym_With] = ACTIONS(5819),
    [sym_asserterror_keyword] = ACTIONS(5821),
    [sym_page_keyword] = ACTIONS(5819),
    [anon_sym_codeunit] = ACTIONS(5819),
    [anon_sym_CODEUNIT] = ACTIONS(5819),
    [anon_sym_Codeunit] = ACTIONS(5819),
    [anon_sym_CodeUnit] = ACTIONS(5819),
    [anon_sym_COdeunit] = ACTIONS(5819),
    [anon_sym_codeUnit] = ACTIONS(5819),
    [sym_report_keyword] = ACTIONS(5819),
    [sym_query_keyword] = ACTIONS(5819),
    [anon_sym_xmlport] = ACTIONS(5819),
    [anon_sym_XMLPORT] = ACTIONS(5819),
    [anon_sym_Xmlport] = ACTIONS(5819),
    [anon_sym_XMLport] = ACTIONS(5819),
    [anon_sym_XMLPort] = ACTIONS(5819),
    [anon_sym_XmlPort] = ACTIONS(5819),
    [anon_sym_enum] = ACTIONS(5819),
    [anon_sym_ENUM] = ACTIONS(5819),
    [anon_sym_Enum] = ACTIONS(5819),
    [anon_sym_eNUM] = ACTIONS(5819),
    [anon_sym_eNum] = ACTIONS(5819),
    [anon_sym_ENum] = ACTIONS(5819),
    [sym_quoted_identifier] = ACTIONS(5821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5821),
    [sym_verbatim_string] = ACTIONS(5821),
    [sym_integer] = ACTIONS(5819),
    [sym_continue_as_identifier] = ACTIONS(5821),
    [sym_preproc_open] = ACTIONS(5821),
    [sym_preproc_close] = ACTIONS(5821),
  },
  [STATE(2460)] = {
    [sym_identifier] = ACTIONS(5823),
    [anon_sym_SEMI] = ACTIONS(5825),
    [anon_sym_DASH] = ACTIONS(5825),
    [aux_sym_boolean_token1] = ACTIONS(5823),
    [aux_sym_boolean_token2] = ACTIONS(5823),
    [sym_decimal] = ACTIONS(5823),
    [anon_sym_LPAREN] = ACTIONS(5825),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5823),
    [anon_sym_LBRACK] = ACTIONS(5825),
    [aux_sym_record_type_token1] = ACTIONS(5823),
    [aux_sym_basic_type_token21] = ACTIONS(5823),
    [aux_sym_basic_type_token22] = ACTIONS(5823),
    [aux_sym_basic_type_token48] = ACTIONS(5823),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5823),
    [anon_sym_POUNDif] = ACTIONS(5825),
    [anon_sym_POUNDIF] = ACTIONS(5825),
    [anon_sym_POUNDIf] = ACTIONS(5825),
    [anon_sym_not] = ACTIONS(5823),
    [anon_sym_NOT] = ACTIONS(5823),
    [anon_sym_Not] = ACTIONS(5823),
    [anon_sym_POUNDelif] = ACTIONS(5825),
    [anon_sym_POUNDELIF] = ACTIONS(5825),
    [anon_sym_POUNDElif] = ACTIONS(5825),
    [anon_sym_POUNDelse] = ACTIONS(5825),
    [anon_sym_POUNDELSE] = ACTIONS(5825),
    [anon_sym_POUNDElse] = ACTIONS(5825),
    [anon_sym_POUNDelse2] = ACTIONS(5825),
    [anon_sym_POUNDELSE2] = ACTIONS(5825),
    [anon_sym_POUNDElse2] = ACTIONS(5825),
    [anon_sym_POUNDendif] = ACTIONS(5825),
    [anon_sym_POUNDENDIF] = ACTIONS(5825),
    [anon_sym_POUNDEndif] = ACTIONS(5825),
    [anon_sym_POUNDendif2] = ACTIONS(5825),
    [anon_sym_POUNDENDIF2] = ACTIONS(5825),
    [anon_sym_POUNDEndif2] = ACTIONS(5825),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5823),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5823),
    [anon_sym_PLUS] = ACTIONS(5825),
    [sym_datetime_literal] = ACTIONS(5825),
    [sym_date_literal] = ACTIONS(5823),
    [sym_time_literal] = ACTIONS(5823),
    [sym_biginteger_literal] = ACTIONS(5825),
    [anon_sym_if] = ACTIONS(5823),
    [anon_sym_IF] = ACTIONS(5823),
    [anon_sym_If] = ACTIONS(5823),
    [anon_sym_else] = ACTIONS(5823),
    [anon_sym_ELSE] = ACTIONS(5823),
    [anon_sym_Else] = ACTIONS(5823),
    [anon_sym_case] = ACTIONS(5823),
    [anon_sym_CASE] = ACTIONS(5823),
    [anon_sym_Case] = ACTIONS(5823),
    [anon_sym_for] = ACTIONS(5823),
    [anon_sym_FOR] = ACTIONS(5823),
    [anon_sym_For] = ACTIONS(5823),
    [anon_sym_foreach] = ACTIONS(5823),
    [anon_sym_FOREACH] = ACTIONS(5823),
    [anon_sym_Foreach] = ACTIONS(5823),
    [anon_sym_while] = ACTIONS(5823),
    [anon_sym_WHILE] = ACTIONS(5823),
    [anon_sym_While] = ACTIONS(5823),
    [anon_sym_repeat] = ACTIONS(5823),
    [anon_sym_REPEAT] = ACTIONS(5823),
    [anon_sym_Repeat] = ACTIONS(5823),
    [anon_sym_exit] = ACTIONS(5823),
    [anon_sym_EXIT] = ACTIONS(5823),
    [anon_sym_Exit] = ACTIONS(5823),
    [anon_sym_continue] = ACTIONS(5823),
    [anon_sym_CONTINUE] = ACTIONS(5823),
    [anon_sym_Continue] = ACTIONS(5823),
    [anon_sym_break] = ACTIONS(5823),
    [anon_sym_BREAK] = ACTIONS(5823),
    [anon_sym_Break] = ACTIONS(5823),
    [anon_sym_with] = ACTIONS(5823),
    [anon_sym_WITH] = ACTIONS(5823),
    [anon_sym_With] = ACTIONS(5823),
    [sym_asserterror_keyword] = ACTIONS(5825),
    [sym_page_keyword] = ACTIONS(5823),
    [anon_sym_codeunit] = ACTIONS(5823),
    [anon_sym_CODEUNIT] = ACTIONS(5823),
    [anon_sym_Codeunit] = ACTIONS(5823),
    [anon_sym_CodeUnit] = ACTIONS(5823),
    [anon_sym_COdeunit] = ACTIONS(5823),
    [anon_sym_codeUnit] = ACTIONS(5823),
    [sym_report_keyword] = ACTIONS(5823),
    [sym_query_keyword] = ACTIONS(5823),
    [anon_sym_xmlport] = ACTIONS(5823),
    [anon_sym_XMLPORT] = ACTIONS(5823),
    [anon_sym_Xmlport] = ACTIONS(5823),
    [anon_sym_XMLport] = ACTIONS(5823),
    [anon_sym_XMLPort] = ACTIONS(5823),
    [anon_sym_XmlPort] = ACTIONS(5823),
    [anon_sym_enum] = ACTIONS(5823),
    [anon_sym_ENUM] = ACTIONS(5823),
    [anon_sym_Enum] = ACTIONS(5823),
    [anon_sym_eNUM] = ACTIONS(5823),
    [anon_sym_eNum] = ACTIONS(5823),
    [anon_sym_ENum] = ACTIONS(5823),
    [sym_quoted_identifier] = ACTIONS(5825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5825),
    [sym_verbatim_string] = ACTIONS(5825),
    [sym_integer] = ACTIONS(5823),
    [sym_continue_as_identifier] = ACTIONS(5825),
    [sym_preproc_open] = ACTIONS(5825),
    [sym_preproc_close] = ACTIONS(5825),
  },
  [STATE(2461)] = {
    [sym_identifier] = ACTIONS(5827),
    [anon_sym_SEMI] = ACTIONS(5829),
    [anon_sym_DASH] = ACTIONS(5829),
    [aux_sym_boolean_token1] = ACTIONS(5827),
    [aux_sym_boolean_token2] = ACTIONS(5827),
    [sym_decimal] = ACTIONS(5827),
    [anon_sym_LPAREN] = ACTIONS(5829),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5827),
    [anon_sym_LBRACK] = ACTIONS(5829),
    [aux_sym_record_type_token1] = ACTIONS(5827),
    [aux_sym_basic_type_token21] = ACTIONS(5827),
    [aux_sym_basic_type_token22] = ACTIONS(5827),
    [aux_sym_basic_type_token48] = ACTIONS(5827),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5827),
    [anon_sym_POUNDif] = ACTIONS(5829),
    [anon_sym_POUNDIF] = ACTIONS(5829),
    [anon_sym_POUNDIf] = ACTIONS(5829),
    [anon_sym_not] = ACTIONS(5827),
    [anon_sym_NOT] = ACTIONS(5827),
    [anon_sym_Not] = ACTIONS(5827),
    [anon_sym_POUNDelif] = ACTIONS(5829),
    [anon_sym_POUNDELIF] = ACTIONS(5829),
    [anon_sym_POUNDElif] = ACTIONS(5829),
    [anon_sym_POUNDelse] = ACTIONS(5829),
    [anon_sym_POUNDELSE] = ACTIONS(5829),
    [anon_sym_POUNDElse] = ACTIONS(5829),
    [anon_sym_POUNDelse2] = ACTIONS(5829),
    [anon_sym_POUNDELSE2] = ACTIONS(5829),
    [anon_sym_POUNDElse2] = ACTIONS(5829),
    [anon_sym_POUNDendif] = ACTIONS(5829),
    [anon_sym_POUNDENDIF] = ACTIONS(5829),
    [anon_sym_POUNDEndif] = ACTIONS(5829),
    [anon_sym_POUNDendif2] = ACTIONS(5829),
    [anon_sym_POUNDENDIF2] = ACTIONS(5829),
    [anon_sym_POUNDEndif2] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5827),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5827),
    [anon_sym_PLUS] = ACTIONS(5829),
    [sym_datetime_literal] = ACTIONS(5829),
    [sym_date_literal] = ACTIONS(5827),
    [sym_time_literal] = ACTIONS(5827),
    [sym_biginteger_literal] = ACTIONS(5829),
    [anon_sym_if] = ACTIONS(5827),
    [anon_sym_IF] = ACTIONS(5827),
    [anon_sym_If] = ACTIONS(5827),
    [anon_sym_else] = ACTIONS(5827),
    [anon_sym_ELSE] = ACTIONS(5827),
    [anon_sym_Else] = ACTIONS(5827),
    [anon_sym_case] = ACTIONS(5827),
    [anon_sym_CASE] = ACTIONS(5827),
    [anon_sym_Case] = ACTIONS(5827),
    [anon_sym_for] = ACTIONS(5827),
    [anon_sym_FOR] = ACTIONS(5827),
    [anon_sym_For] = ACTIONS(5827),
    [anon_sym_foreach] = ACTIONS(5827),
    [anon_sym_FOREACH] = ACTIONS(5827),
    [anon_sym_Foreach] = ACTIONS(5827),
    [anon_sym_while] = ACTIONS(5827),
    [anon_sym_WHILE] = ACTIONS(5827),
    [anon_sym_While] = ACTIONS(5827),
    [anon_sym_repeat] = ACTIONS(5827),
    [anon_sym_REPEAT] = ACTIONS(5827),
    [anon_sym_Repeat] = ACTIONS(5827),
    [anon_sym_exit] = ACTIONS(5827),
    [anon_sym_EXIT] = ACTIONS(5827),
    [anon_sym_Exit] = ACTIONS(5827),
    [anon_sym_continue] = ACTIONS(5827),
    [anon_sym_CONTINUE] = ACTIONS(5827),
    [anon_sym_Continue] = ACTIONS(5827),
    [anon_sym_break] = ACTIONS(5827),
    [anon_sym_BREAK] = ACTIONS(5827),
    [anon_sym_Break] = ACTIONS(5827),
    [anon_sym_with] = ACTIONS(5827),
    [anon_sym_WITH] = ACTIONS(5827),
    [anon_sym_With] = ACTIONS(5827),
    [sym_asserterror_keyword] = ACTIONS(5829),
    [sym_page_keyword] = ACTIONS(5827),
    [anon_sym_codeunit] = ACTIONS(5827),
    [anon_sym_CODEUNIT] = ACTIONS(5827),
    [anon_sym_Codeunit] = ACTIONS(5827),
    [anon_sym_CodeUnit] = ACTIONS(5827),
    [anon_sym_COdeunit] = ACTIONS(5827),
    [anon_sym_codeUnit] = ACTIONS(5827),
    [sym_report_keyword] = ACTIONS(5827),
    [sym_query_keyword] = ACTIONS(5827),
    [anon_sym_xmlport] = ACTIONS(5827),
    [anon_sym_XMLPORT] = ACTIONS(5827),
    [anon_sym_Xmlport] = ACTIONS(5827),
    [anon_sym_XMLport] = ACTIONS(5827),
    [anon_sym_XMLPort] = ACTIONS(5827),
    [anon_sym_XmlPort] = ACTIONS(5827),
    [anon_sym_enum] = ACTIONS(5827),
    [anon_sym_ENUM] = ACTIONS(5827),
    [anon_sym_Enum] = ACTIONS(5827),
    [anon_sym_eNUM] = ACTIONS(5827),
    [anon_sym_eNum] = ACTIONS(5827),
    [anon_sym_ENum] = ACTIONS(5827),
    [sym_quoted_identifier] = ACTIONS(5829),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5829),
    [sym_verbatim_string] = ACTIONS(5829),
    [sym_integer] = ACTIONS(5827),
    [sym_continue_as_identifier] = ACTIONS(5829),
    [sym_preproc_open] = ACTIONS(5829),
    [sym_preproc_close] = ACTIONS(5829),
  },
  [STATE(2462)] = {
    [sym_identifier] = ACTIONS(5831),
    [anon_sym_SEMI] = ACTIONS(5833),
    [anon_sym_DASH] = ACTIONS(5833),
    [aux_sym_boolean_token1] = ACTIONS(5831),
    [aux_sym_boolean_token2] = ACTIONS(5831),
    [sym_decimal] = ACTIONS(5831),
    [anon_sym_LPAREN] = ACTIONS(5833),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5831),
    [anon_sym_LBRACK] = ACTIONS(5833),
    [aux_sym_record_type_token1] = ACTIONS(5831),
    [aux_sym_basic_type_token21] = ACTIONS(5831),
    [aux_sym_basic_type_token22] = ACTIONS(5831),
    [aux_sym_basic_type_token48] = ACTIONS(5831),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5831),
    [anon_sym_POUNDif] = ACTIONS(5833),
    [anon_sym_POUNDIF] = ACTIONS(5833),
    [anon_sym_POUNDIf] = ACTIONS(5833),
    [anon_sym_not] = ACTIONS(5831),
    [anon_sym_NOT] = ACTIONS(5831),
    [anon_sym_Not] = ACTIONS(5831),
    [anon_sym_POUNDelif] = ACTIONS(5833),
    [anon_sym_POUNDELIF] = ACTIONS(5833),
    [anon_sym_POUNDElif] = ACTIONS(5833),
    [anon_sym_POUNDelse] = ACTIONS(5833),
    [anon_sym_POUNDELSE] = ACTIONS(5833),
    [anon_sym_POUNDElse] = ACTIONS(5833),
    [anon_sym_POUNDelse2] = ACTIONS(5833),
    [anon_sym_POUNDELSE2] = ACTIONS(5833),
    [anon_sym_POUNDElse2] = ACTIONS(5833),
    [anon_sym_POUNDendif] = ACTIONS(5833),
    [anon_sym_POUNDENDIF] = ACTIONS(5833),
    [anon_sym_POUNDEndif] = ACTIONS(5833),
    [anon_sym_POUNDendif2] = ACTIONS(5833),
    [anon_sym_POUNDENDIF2] = ACTIONS(5833),
    [anon_sym_POUNDEndif2] = ACTIONS(5833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5831),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5831),
    [anon_sym_PLUS] = ACTIONS(5833),
    [sym_datetime_literal] = ACTIONS(5833),
    [sym_date_literal] = ACTIONS(5831),
    [sym_time_literal] = ACTIONS(5831),
    [sym_biginteger_literal] = ACTIONS(5833),
    [anon_sym_if] = ACTIONS(5831),
    [anon_sym_IF] = ACTIONS(5831),
    [anon_sym_If] = ACTIONS(5831),
    [anon_sym_else] = ACTIONS(5831),
    [anon_sym_ELSE] = ACTIONS(5831),
    [anon_sym_Else] = ACTIONS(5831),
    [anon_sym_case] = ACTIONS(5831),
    [anon_sym_CASE] = ACTIONS(5831),
    [anon_sym_Case] = ACTIONS(5831),
    [anon_sym_for] = ACTIONS(5831),
    [anon_sym_FOR] = ACTIONS(5831),
    [anon_sym_For] = ACTIONS(5831),
    [anon_sym_foreach] = ACTIONS(5831),
    [anon_sym_FOREACH] = ACTIONS(5831),
    [anon_sym_Foreach] = ACTIONS(5831),
    [anon_sym_while] = ACTIONS(5831),
    [anon_sym_WHILE] = ACTIONS(5831),
    [anon_sym_While] = ACTIONS(5831),
    [anon_sym_repeat] = ACTIONS(5831),
    [anon_sym_REPEAT] = ACTIONS(5831),
    [anon_sym_Repeat] = ACTIONS(5831),
    [anon_sym_exit] = ACTIONS(5831),
    [anon_sym_EXIT] = ACTIONS(5831),
    [anon_sym_Exit] = ACTIONS(5831),
    [anon_sym_continue] = ACTIONS(5831),
    [anon_sym_CONTINUE] = ACTIONS(5831),
    [anon_sym_Continue] = ACTIONS(5831),
    [anon_sym_break] = ACTIONS(5831),
    [anon_sym_BREAK] = ACTIONS(5831),
    [anon_sym_Break] = ACTIONS(5831),
    [anon_sym_with] = ACTIONS(5831),
    [anon_sym_WITH] = ACTIONS(5831),
    [anon_sym_With] = ACTIONS(5831),
    [sym_asserterror_keyword] = ACTIONS(5833),
    [sym_page_keyword] = ACTIONS(5831),
    [anon_sym_codeunit] = ACTIONS(5831),
    [anon_sym_CODEUNIT] = ACTIONS(5831),
    [anon_sym_Codeunit] = ACTIONS(5831),
    [anon_sym_CodeUnit] = ACTIONS(5831),
    [anon_sym_COdeunit] = ACTIONS(5831),
    [anon_sym_codeUnit] = ACTIONS(5831),
    [sym_report_keyword] = ACTIONS(5831),
    [sym_query_keyword] = ACTIONS(5831),
    [anon_sym_xmlport] = ACTIONS(5831),
    [anon_sym_XMLPORT] = ACTIONS(5831),
    [anon_sym_Xmlport] = ACTIONS(5831),
    [anon_sym_XMLport] = ACTIONS(5831),
    [anon_sym_XMLPort] = ACTIONS(5831),
    [anon_sym_XmlPort] = ACTIONS(5831),
    [anon_sym_enum] = ACTIONS(5831),
    [anon_sym_ENUM] = ACTIONS(5831),
    [anon_sym_Enum] = ACTIONS(5831),
    [anon_sym_eNUM] = ACTIONS(5831),
    [anon_sym_eNum] = ACTIONS(5831),
    [anon_sym_ENum] = ACTIONS(5831),
    [sym_quoted_identifier] = ACTIONS(5833),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5833),
    [sym_verbatim_string] = ACTIONS(5833),
    [sym_integer] = ACTIONS(5831),
    [sym_continue_as_identifier] = ACTIONS(5833),
    [sym_preproc_open] = ACTIONS(5833),
    [sym_preproc_close] = ACTIONS(5833),
  },
  [STATE(2463)] = {
    [sym_identifier] = ACTIONS(5835),
    [anon_sym_SEMI] = ACTIONS(5837),
    [anon_sym_DASH] = ACTIONS(5837),
    [aux_sym_boolean_token1] = ACTIONS(5835),
    [aux_sym_boolean_token2] = ACTIONS(5835),
    [sym_decimal] = ACTIONS(5835),
    [anon_sym_LPAREN] = ACTIONS(5837),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5835),
    [anon_sym_LBRACK] = ACTIONS(5837),
    [aux_sym_record_type_token1] = ACTIONS(5835),
    [aux_sym_basic_type_token21] = ACTIONS(5835),
    [aux_sym_basic_type_token22] = ACTIONS(5835),
    [aux_sym_basic_type_token48] = ACTIONS(5835),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5835),
    [anon_sym_POUNDif] = ACTIONS(5837),
    [anon_sym_POUNDIF] = ACTIONS(5837),
    [anon_sym_POUNDIf] = ACTIONS(5837),
    [anon_sym_not] = ACTIONS(5835),
    [anon_sym_NOT] = ACTIONS(5835),
    [anon_sym_Not] = ACTIONS(5835),
    [anon_sym_POUNDelif] = ACTIONS(5837),
    [anon_sym_POUNDELIF] = ACTIONS(5837),
    [anon_sym_POUNDElif] = ACTIONS(5837),
    [anon_sym_POUNDelse] = ACTIONS(5837),
    [anon_sym_POUNDELSE] = ACTIONS(5837),
    [anon_sym_POUNDElse] = ACTIONS(5837),
    [anon_sym_POUNDelse2] = ACTIONS(5837),
    [anon_sym_POUNDELSE2] = ACTIONS(5837),
    [anon_sym_POUNDElse2] = ACTIONS(5837),
    [anon_sym_POUNDendif] = ACTIONS(5837),
    [anon_sym_POUNDENDIF] = ACTIONS(5837),
    [anon_sym_POUNDEndif] = ACTIONS(5837),
    [anon_sym_POUNDendif2] = ACTIONS(5837),
    [anon_sym_POUNDENDIF2] = ACTIONS(5837),
    [anon_sym_POUNDEndif2] = ACTIONS(5837),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5835),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5835),
    [anon_sym_PLUS] = ACTIONS(5837),
    [sym_datetime_literal] = ACTIONS(5837),
    [sym_date_literal] = ACTIONS(5835),
    [sym_time_literal] = ACTIONS(5835),
    [sym_biginteger_literal] = ACTIONS(5837),
    [anon_sym_if] = ACTIONS(5835),
    [anon_sym_IF] = ACTIONS(5835),
    [anon_sym_If] = ACTIONS(5835),
    [anon_sym_else] = ACTIONS(5835),
    [anon_sym_ELSE] = ACTIONS(5835),
    [anon_sym_Else] = ACTIONS(5835),
    [anon_sym_case] = ACTIONS(5835),
    [anon_sym_CASE] = ACTIONS(5835),
    [anon_sym_Case] = ACTIONS(5835),
    [anon_sym_for] = ACTIONS(5835),
    [anon_sym_FOR] = ACTIONS(5835),
    [anon_sym_For] = ACTIONS(5835),
    [anon_sym_foreach] = ACTIONS(5835),
    [anon_sym_FOREACH] = ACTIONS(5835),
    [anon_sym_Foreach] = ACTIONS(5835),
    [anon_sym_while] = ACTIONS(5835),
    [anon_sym_WHILE] = ACTIONS(5835),
    [anon_sym_While] = ACTIONS(5835),
    [anon_sym_repeat] = ACTIONS(5835),
    [anon_sym_REPEAT] = ACTIONS(5835),
    [anon_sym_Repeat] = ACTIONS(5835),
    [anon_sym_exit] = ACTIONS(5835),
    [anon_sym_EXIT] = ACTIONS(5835),
    [anon_sym_Exit] = ACTIONS(5835),
    [anon_sym_continue] = ACTIONS(5835),
    [anon_sym_CONTINUE] = ACTIONS(5835),
    [anon_sym_Continue] = ACTIONS(5835),
    [anon_sym_break] = ACTIONS(5835),
    [anon_sym_BREAK] = ACTIONS(5835),
    [anon_sym_Break] = ACTIONS(5835),
    [anon_sym_with] = ACTIONS(5835),
    [anon_sym_WITH] = ACTIONS(5835),
    [anon_sym_With] = ACTIONS(5835),
    [sym_asserterror_keyword] = ACTIONS(5837),
    [sym_page_keyword] = ACTIONS(5835),
    [anon_sym_codeunit] = ACTIONS(5835),
    [anon_sym_CODEUNIT] = ACTIONS(5835),
    [anon_sym_Codeunit] = ACTIONS(5835),
    [anon_sym_CodeUnit] = ACTIONS(5835),
    [anon_sym_COdeunit] = ACTIONS(5835),
    [anon_sym_codeUnit] = ACTIONS(5835),
    [sym_report_keyword] = ACTIONS(5835),
    [sym_query_keyword] = ACTIONS(5835),
    [anon_sym_xmlport] = ACTIONS(5835),
    [anon_sym_XMLPORT] = ACTIONS(5835),
    [anon_sym_Xmlport] = ACTIONS(5835),
    [anon_sym_XMLport] = ACTIONS(5835),
    [anon_sym_XMLPort] = ACTIONS(5835),
    [anon_sym_XmlPort] = ACTIONS(5835),
    [anon_sym_enum] = ACTIONS(5835),
    [anon_sym_ENUM] = ACTIONS(5835),
    [anon_sym_Enum] = ACTIONS(5835),
    [anon_sym_eNUM] = ACTIONS(5835),
    [anon_sym_eNum] = ACTIONS(5835),
    [anon_sym_ENum] = ACTIONS(5835),
    [sym_quoted_identifier] = ACTIONS(5837),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5837),
    [sym_verbatim_string] = ACTIONS(5837),
    [sym_integer] = ACTIONS(5835),
    [sym_continue_as_identifier] = ACTIONS(5837),
    [sym_preproc_open] = ACTIONS(5837),
    [sym_preproc_close] = ACTIONS(5837),
  },
  [STATE(2464)] = {
    [sym_identifier] = ACTIONS(5839),
    [anon_sym_SEMI] = ACTIONS(5841),
    [anon_sym_DASH] = ACTIONS(5841),
    [aux_sym_boolean_token1] = ACTIONS(5839),
    [aux_sym_boolean_token2] = ACTIONS(5839),
    [sym_decimal] = ACTIONS(5839),
    [anon_sym_LPAREN] = ACTIONS(5841),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5839),
    [anon_sym_LBRACK] = ACTIONS(5841),
    [aux_sym_record_type_token1] = ACTIONS(5839),
    [aux_sym_basic_type_token21] = ACTIONS(5839),
    [aux_sym_basic_type_token22] = ACTIONS(5839),
    [aux_sym_basic_type_token48] = ACTIONS(5839),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5839),
    [anon_sym_POUNDif] = ACTIONS(5841),
    [anon_sym_POUNDIF] = ACTIONS(5841),
    [anon_sym_POUNDIf] = ACTIONS(5841),
    [anon_sym_not] = ACTIONS(5839),
    [anon_sym_NOT] = ACTIONS(5839),
    [anon_sym_Not] = ACTIONS(5839),
    [anon_sym_POUNDelif] = ACTIONS(5841),
    [anon_sym_POUNDELIF] = ACTIONS(5841),
    [anon_sym_POUNDElif] = ACTIONS(5841),
    [anon_sym_POUNDelse] = ACTIONS(5841),
    [anon_sym_POUNDELSE] = ACTIONS(5841),
    [anon_sym_POUNDElse] = ACTIONS(5841),
    [anon_sym_POUNDelse2] = ACTIONS(5841),
    [anon_sym_POUNDELSE2] = ACTIONS(5841),
    [anon_sym_POUNDElse2] = ACTIONS(5841),
    [anon_sym_POUNDendif] = ACTIONS(5841),
    [anon_sym_POUNDENDIF] = ACTIONS(5841),
    [anon_sym_POUNDEndif] = ACTIONS(5841),
    [anon_sym_POUNDendif2] = ACTIONS(5841),
    [anon_sym_POUNDENDIF2] = ACTIONS(5841),
    [anon_sym_POUNDEndif2] = ACTIONS(5841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5839),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5839),
    [anon_sym_PLUS] = ACTIONS(5841),
    [sym_datetime_literal] = ACTIONS(5841),
    [sym_date_literal] = ACTIONS(5839),
    [sym_time_literal] = ACTIONS(5839),
    [sym_biginteger_literal] = ACTIONS(5841),
    [anon_sym_if] = ACTIONS(5839),
    [anon_sym_IF] = ACTIONS(5839),
    [anon_sym_If] = ACTIONS(5839),
    [anon_sym_else] = ACTIONS(5839),
    [anon_sym_ELSE] = ACTIONS(5839),
    [anon_sym_Else] = ACTIONS(5839),
    [anon_sym_case] = ACTIONS(5839),
    [anon_sym_CASE] = ACTIONS(5839),
    [anon_sym_Case] = ACTIONS(5839),
    [anon_sym_for] = ACTIONS(5839),
    [anon_sym_FOR] = ACTIONS(5839),
    [anon_sym_For] = ACTIONS(5839),
    [anon_sym_foreach] = ACTIONS(5839),
    [anon_sym_FOREACH] = ACTIONS(5839),
    [anon_sym_Foreach] = ACTIONS(5839),
    [anon_sym_while] = ACTIONS(5839),
    [anon_sym_WHILE] = ACTIONS(5839),
    [anon_sym_While] = ACTIONS(5839),
    [anon_sym_repeat] = ACTIONS(5839),
    [anon_sym_REPEAT] = ACTIONS(5839),
    [anon_sym_Repeat] = ACTIONS(5839),
    [anon_sym_exit] = ACTIONS(5839),
    [anon_sym_EXIT] = ACTIONS(5839),
    [anon_sym_Exit] = ACTIONS(5839),
    [anon_sym_continue] = ACTIONS(5839),
    [anon_sym_CONTINUE] = ACTIONS(5839),
    [anon_sym_Continue] = ACTIONS(5839),
    [anon_sym_break] = ACTIONS(5839),
    [anon_sym_BREAK] = ACTIONS(5839),
    [anon_sym_Break] = ACTIONS(5839),
    [anon_sym_with] = ACTIONS(5839),
    [anon_sym_WITH] = ACTIONS(5839),
    [anon_sym_With] = ACTIONS(5839),
    [sym_asserterror_keyword] = ACTIONS(5841),
    [sym_page_keyword] = ACTIONS(5839),
    [anon_sym_codeunit] = ACTIONS(5839),
    [anon_sym_CODEUNIT] = ACTIONS(5839),
    [anon_sym_Codeunit] = ACTIONS(5839),
    [anon_sym_CodeUnit] = ACTIONS(5839),
    [anon_sym_COdeunit] = ACTIONS(5839),
    [anon_sym_codeUnit] = ACTIONS(5839),
    [sym_report_keyword] = ACTIONS(5839),
    [sym_query_keyword] = ACTIONS(5839),
    [anon_sym_xmlport] = ACTIONS(5839),
    [anon_sym_XMLPORT] = ACTIONS(5839),
    [anon_sym_Xmlport] = ACTIONS(5839),
    [anon_sym_XMLport] = ACTIONS(5839),
    [anon_sym_XMLPort] = ACTIONS(5839),
    [anon_sym_XmlPort] = ACTIONS(5839),
    [anon_sym_enum] = ACTIONS(5839),
    [anon_sym_ENUM] = ACTIONS(5839),
    [anon_sym_Enum] = ACTIONS(5839),
    [anon_sym_eNUM] = ACTIONS(5839),
    [anon_sym_eNum] = ACTIONS(5839),
    [anon_sym_ENum] = ACTIONS(5839),
    [sym_quoted_identifier] = ACTIONS(5841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5841),
    [sym_verbatim_string] = ACTIONS(5841),
    [sym_integer] = ACTIONS(5839),
    [sym_continue_as_identifier] = ACTIONS(5841),
    [sym_preproc_open] = ACTIONS(5841),
    [sym_preproc_close] = ACTIONS(5841),
  },
  [STATE(2465)] = {
    [sym_else_keyword] = STATE(118),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelif] = ACTIONS(5487),
    [anon_sym_POUNDELIF] = ACTIONS(5487),
    [anon_sym_POUNDElif] = ACTIONS(5487),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [anon_sym_POUNDendif] = ACTIONS(5487),
    [anon_sym_POUNDENDIF] = ACTIONS(5487),
    [anon_sym_POUNDEndif] = ACTIONS(5487),
    [anon_sym_POUNDendif2] = ACTIONS(5487),
    [anon_sym_POUNDENDIF2] = ACTIONS(5487),
    [anon_sym_POUNDEndif2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_preproc_close] = ACTIONS(5487),
  },
  [STATE(2466)] = {
    [sym_else_keyword] = STATE(119),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelif] = ACTIONS(5455),
    [anon_sym_POUNDELIF] = ACTIONS(5455),
    [anon_sym_POUNDElif] = ACTIONS(5455),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [anon_sym_POUNDendif] = ACTIONS(5455),
    [anon_sym_POUNDENDIF] = ACTIONS(5455),
    [anon_sym_POUNDEndif] = ACTIONS(5455),
    [anon_sym_POUNDendif2] = ACTIONS(5455),
    [anon_sym_POUNDENDIF2] = ACTIONS(5455),
    [anon_sym_POUNDEndif2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_preproc_close] = ACTIONS(5455),
  },
  [STATE(2467)] = {
    [sym_identifier] = ACTIONS(5843),
    [anon_sym_SEMI] = ACTIONS(5845),
    [anon_sym_DASH] = ACTIONS(5845),
    [aux_sym_boolean_token1] = ACTIONS(5843),
    [aux_sym_boolean_token2] = ACTIONS(5843),
    [sym_decimal] = ACTIONS(5843),
    [anon_sym_LPAREN] = ACTIONS(5845),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5843),
    [anon_sym_LBRACK] = ACTIONS(5845),
    [aux_sym_record_type_token1] = ACTIONS(5843),
    [aux_sym_basic_type_token21] = ACTIONS(5843),
    [aux_sym_basic_type_token22] = ACTIONS(5843),
    [aux_sym_basic_type_token48] = ACTIONS(5843),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5843),
    [anon_sym_POUNDif] = ACTIONS(5845),
    [anon_sym_POUNDIF] = ACTIONS(5845),
    [anon_sym_POUNDIf] = ACTIONS(5845),
    [anon_sym_not] = ACTIONS(5843),
    [anon_sym_NOT] = ACTIONS(5843),
    [anon_sym_Not] = ACTIONS(5843),
    [anon_sym_POUNDelif] = ACTIONS(5845),
    [anon_sym_POUNDELIF] = ACTIONS(5845),
    [anon_sym_POUNDElif] = ACTIONS(5845),
    [anon_sym_POUNDelse] = ACTIONS(5845),
    [anon_sym_POUNDELSE] = ACTIONS(5845),
    [anon_sym_POUNDElse] = ACTIONS(5845),
    [anon_sym_POUNDelse2] = ACTIONS(5845),
    [anon_sym_POUNDELSE2] = ACTIONS(5845),
    [anon_sym_POUNDElse2] = ACTIONS(5845),
    [anon_sym_POUNDendif] = ACTIONS(5845),
    [anon_sym_POUNDENDIF] = ACTIONS(5845),
    [anon_sym_POUNDEndif] = ACTIONS(5845),
    [anon_sym_POUNDendif2] = ACTIONS(5845),
    [anon_sym_POUNDENDIF2] = ACTIONS(5845),
    [anon_sym_POUNDEndif2] = ACTIONS(5845),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5843),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5843),
    [anon_sym_PLUS] = ACTIONS(5845),
    [sym_datetime_literal] = ACTIONS(5845),
    [sym_date_literal] = ACTIONS(5843),
    [sym_time_literal] = ACTIONS(5843),
    [sym_biginteger_literal] = ACTIONS(5845),
    [anon_sym_if] = ACTIONS(5843),
    [anon_sym_IF] = ACTIONS(5843),
    [anon_sym_If] = ACTIONS(5843),
    [anon_sym_else] = ACTIONS(5843),
    [anon_sym_ELSE] = ACTIONS(5843),
    [anon_sym_Else] = ACTIONS(5843),
    [anon_sym_case] = ACTIONS(5843),
    [anon_sym_CASE] = ACTIONS(5843),
    [anon_sym_Case] = ACTIONS(5843),
    [anon_sym_for] = ACTIONS(5843),
    [anon_sym_FOR] = ACTIONS(5843),
    [anon_sym_For] = ACTIONS(5843),
    [anon_sym_foreach] = ACTIONS(5843),
    [anon_sym_FOREACH] = ACTIONS(5843),
    [anon_sym_Foreach] = ACTIONS(5843),
    [anon_sym_while] = ACTIONS(5843),
    [anon_sym_WHILE] = ACTIONS(5843),
    [anon_sym_While] = ACTIONS(5843),
    [anon_sym_repeat] = ACTIONS(5843),
    [anon_sym_REPEAT] = ACTIONS(5843),
    [anon_sym_Repeat] = ACTIONS(5843),
    [anon_sym_exit] = ACTIONS(5843),
    [anon_sym_EXIT] = ACTIONS(5843),
    [anon_sym_Exit] = ACTIONS(5843),
    [anon_sym_continue] = ACTIONS(5843),
    [anon_sym_CONTINUE] = ACTIONS(5843),
    [anon_sym_Continue] = ACTIONS(5843),
    [anon_sym_break] = ACTIONS(5843),
    [anon_sym_BREAK] = ACTIONS(5843),
    [anon_sym_Break] = ACTIONS(5843),
    [anon_sym_with] = ACTIONS(5843),
    [anon_sym_WITH] = ACTIONS(5843),
    [anon_sym_With] = ACTIONS(5843),
    [sym_asserterror_keyword] = ACTIONS(5845),
    [sym_page_keyword] = ACTIONS(5843),
    [anon_sym_codeunit] = ACTIONS(5843),
    [anon_sym_CODEUNIT] = ACTIONS(5843),
    [anon_sym_Codeunit] = ACTIONS(5843),
    [anon_sym_CodeUnit] = ACTIONS(5843),
    [anon_sym_COdeunit] = ACTIONS(5843),
    [anon_sym_codeUnit] = ACTIONS(5843),
    [sym_report_keyword] = ACTIONS(5843),
    [sym_query_keyword] = ACTIONS(5843),
    [anon_sym_xmlport] = ACTIONS(5843),
    [anon_sym_XMLPORT] = ACTIONS(5843),
    [anon_sym_Xmlport] = ACTIONS(5843),
    [anon_sym_XMLport] = ACTIONS(5843),
    [anon_sym_XMLPort] = ACTIONS(5843),
    [anon_sym_XmlPort] = ACTIONS(5843),
    [anon_sym_enum] = ACTIONS(5843),
    [anon_sym_ENUM] = ACTIONS(5843),
    [anon_sym_Enum] = ACTIONS(5843),
    [anon_sym_eNUM] = ACTIONS(5843),
    [anon_sym_eNum] = ACTIONS(5843),
    [anon_sym_ENum] = ACTIONS(5843),
    [sym_quoted_identifier] = ACTIONS(5845),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5845),
    [sym_verbatim_string] = ACTIONS(5845),
    [sym_integer] = ACTIONS(5843),
    [sym_continue_as_identifier] = ACTIONS(5845),
    [sym_preproc_open] = ACTIONS(5845),
    [sym_preproc_close] = ACTIONS(5845),
  },
  [STATE(2468)] = {
    [sym_identifier] = ACTIONS(5847),
    [anon_sym_SEMI] = ACTIONS(5849),
    [anon_sym_DASH] = ACTIONS(5849),
    [aux_sym_boolean_token1] = ACTIONS(5847),
    [aux_sym_boolean_token2] = ACTIONS(5847),
    [sym_decimal] = ACTIONS(5847),
    [anon_sym_LPAREN] = ACTIONS(5849),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5847),
    [anon_sym_LBRACK] = ACTIONS(5849),
    [aux_sym_record_type_token1] = ACTIONS(5847),
    [aux_sym_basic_type_token21] = ACTIONS(5847),
    [aux_sym_basic_type_token22] = ACTIONS(5847),
    [aux_sym_basic_type_token48] = ACTIONS(5847),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5847),
    [anon_sym_POUNDif] = ACTIONS(5849),
    [anon_sym_POUNDIF] = ACTIONS(5849),
    [anon_sym_POUNDIf] = ACTIONS(5849),
    [anon_sym_not] = ACTIONS(5847),
    [anon_sym_NOT] = ACTIONS(5847),
    [anon_sym_Not] = ACTIONS(5847),
    [anon_sym_POUNDelif] = ACTIONS(5849),
    [anon_sym_POUNDELIF] = ACTIONS(5849),
    [anon_sym_POUNDElif] = ACTIONS(5849),
    [anon_sym_POUNDelse] = ACTIONS(5849),
    [anon_sym_POUNDELSE] = ACTIONS(5849),
    [anon_sym_POUNDElse] = ACTIONS(5849),
    [anon_sym_POUNDelse2] = ACTIONS(5849),
    [anon_sym_POUNDELSE2] = ACTIONS(5849),
    [anon_sym_POUNDElse2] = ACTIONS(5849),
    [anon_sym_POUNDendif] = ACTIONS(5849),
    [anon_sym_POUNDENDIF] = ACTIONS(5849),
    [anon_sym_POUNDEndif] = ACTIONS(5849),
    [anon_sym_POUNDendif2] = ACTIONS(5849),
    [anon_sym_POUNDENDIF2] = ACTIONS(5849),
    [anon_sym_POUNDEndif2] = ACTIONS(5849),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5847),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5847),
    [anon_sym_PLUS] = ACTIONS(5849),
    [sym_datetime_literal] = ACTIONS(5849),
    [sym_date_literal] = ACTIONS(5847),
    [sym_time_literal] = ACTIONS(5847),
    [sym_biginteger_literal] = ACTIONS(5849),
    [anon_sym_if] = ACTIONS(5847),
    [anon_sym_IF] = ACTIONS(5847),
    [anon_sym_If] = ACTIONS(5847),
    [anon_sym_else] = ACTIONS(5847),
    [anon_sym_ELSE] = ACTIONS(5847),
    [anon_sym_Else] = ACTIONS(5847),
    [anon_sym_case] = ACTIONS(5847),
    [anon_sym_CASE] = ACTIONS(5847),
    [anon_sym_Case] = ACTIONS(5847),
    [anon_sym_for] = ACTIONS(5847),
    [anon_sym_FOR] = ACTIONS(5847),
    [anon_sym_For] = ACTIONS(5847),
    [anon_sym_foreach] = ACTIONS(5847),
    [anon_sym_FOREACH] = ACTIONS(5847),
    [anon_sym_Foreach] = ACTIONS(5847),
    [anon_sym_while] = ACTIONS(5847),
    [anon_sym_WHILE] = ACTIONS(5847),
    [anon_sym_While] = ACTIONS(5847),
    [anon_sym_repeat] = ACTIONS(5847),
    [anon_sym_REPEAT] = ACTIONS(5847),
    [anon_sym_Repeat] = ACTIONS(5847),
    [anon_sym_exit] = ACTIONS(5847),
    [anon_sym_EXIT] = ACTIONS(5847),
    [anon_sym_Exit] = ACTIONS(5847),
    [anon_sym_continue] = ACTIONS(5847),
    [anon_sym_CONTINUE] = ACTIONS(5847),
    [anon_sym_Continue] = ACTIONS(5847),
    [anon_sym_break] = ACTIONS(5847),
    [anon_sym_BREAK] = ACTIONS(5847),
    [anon_sym_Break] = ACTIONS(5847),
    [anon_sym_with] = ACTIONS(5847),
    [anon_sym_WITH] = ACTIONS(5847),
    [anon_sym_With] = ACTIONS(5847),
    [sym_asserterror_keyword] = ACTIONS(5849),
    [sym_page_keyword] = ACTIONS(5847),
    [anon_sym_codeunit] = ACTIONS(5847),
    [anon_sym_CODEUNIT] = ACTIONS(5847),
    [anon_sym_Codeunit] = ACTIONS(5847),
    [anon_sym_CodeUnit] = ACTIONS(5847),
    [anon_sym_COdeunit] = ACTIONS(5847),
    [anon_sym_codeUnit] = ACTIONS(5847),
    [sym_report_keyword] = ACTIONS(5847),
    [sym_query_keyword] = ACTIONS(5847),
    [anon_sym_xmlport] = ACTIONS(5847),
    [anon_sym_XMLPORT] = ACTIONS(5847),
    [anon_sym_Xmlport] = ACTIONS(5847),
    [anon_sym_XMLport] = ACTIONS(5847),
    [anon_sym_XMLPort] = ACTIONS(5847),
    [anon_sym_XmlPort] = ACTIONS(5847),
    [anon_sym_enum] = ACTIONS(5847),
    [anon_sym_ENUM] = ACTIONS(5847),
    [anon_sym_Enum] = ACTIONS(5847),
    [anon_sym_eNUM] = ACTIONS(5847),
    [anon_sym_eNum] = ACTIONS(5847),
    [anon_sym_ENum] = ACTIONS(5847),
    [sym_quoted_identifier] = ACTIONS(5849),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5849),
    [sym_verbatim_string] = ACTIONS(5849),
    [sym_integer] = ACTIONS(5847),
    [sym_continue_as_identifier] = ACTIONS(5849),
    [sym_preproc_open] = ACTIONS(5849),
    [sym_preproc_close] = ACTIONS(5849),
  },
  [STATE(2469)] = {
    [sym_identifier] = ACTIONS(5851),
    [anon_sym_SEMI] = ACTIONS(5853),
    [anon_sym_DASH] = ACTIONS(5853),
    [aux_sym_boolean_token1] = ACTIONS(5851),
    [aux_sym_boolean_token2] = ACTIONS(5851),
    [sym_decimal] = ACTIONS(5851),
    [anon_sym_LPAREN] = ACTIONS(5853),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5851),
    [anon_sym_LBRACK] = ACTIONS(5853),
    [aux_sym_record_type_token1] = ACTIONS(5851),
    [aux_sym_basic_type_token21] = ACTIONS(5851),
    [aux_sym_basic_type_token22] = ACTIONS(5851),
    [aux_sym_basic_type_token48] = ACTIONS(5851),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5851),
    [anon_sym_POUNDif] = ACTIONS(5853),
    [anon_sym_POUNDIF] = ACTIONS(5853),
    [anon_sym_POUNDIf] = ACTIONS(5853),
    [anon_sym_not] = ACTIONS(5851),
    [anon_sym_NOT] = ACTIONS(5851),
    [anon_sym_Not] = ACTIONS(5851),
    [anon_sym_POUNDelif] = ACTIONS(5853),
    [anon_sym_POUNDELIF] = ACTIONS(5853),
    [anon_sym_POUNDElif] = ACTIONS(5853),
    [anon_sym_POUNDelse] = ACTIONS(5853),
    [anon_sym_POUNDELSE] = ACTIONS(5853),
    [anon_sym_POUNDElse] = ACTIONS(5853),
    [anon_sym_POUNDelse2] = ACTIONS(5853),
    [anon_sym_POUNDELSE2] = ACTIONS(5853),
    [anon_sym_POUNDElse2] = ACTIONS(5853),
    [anon_sym_POUNDendif] = ACTIONS(5853),
    [anon_sym_POUNDENDIF] = ACTIONS(5853),
    [anon_sym_POUNDEndif] = ACTIONS(5853),
    [anon_sym_POUNDendif2] = ACTIONS(5853),
    [anon_sym_POUNDENDIF2] = ACTIONS(5853),
    [anon_sym_POUNDEndif2] = ACTIONS(5853),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5851),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5851),
    [anon_sym_PLUS] = ACTIONS(5853),
    [sym_datetime_literal] = ACTIONS(5853),
    [sym_date_literal] = ACTIONS(5851),
    [sym_time_literal] = ACTIONS(5851),
    [sym_biginteger_literal] = ACTIONS(5853),
    [anon_sym_if] = ACTIONS(5851),
    [anon_sym_IF] = ACTIONS(5851),
    [anon_sym_If] = ACTIONS(5851),
    [anon_sym_else] = ACTIONS(5851),
    [anon_sym_ELSE] = ACTIONS(5851),
    [anon_sym_Else] = ACTIONS(5851),
    [anon_sym_case] = ACTIONS(5851),
    [anon_sym_CASE] = ACTIONS(5851),
    [anon_sym_Case] = ACTIONS(5851),
    [anon_sym_for] = ACTIONS(5851),
    [anon_sym_FOR] = ACTIONS(5851),
    [anon_sym_For] = ACTIONS(5851),
    [anon_sym_foreach] = ACTIONS(5851),
    [anon_sym_FOREACH] = ACTIONS(5851),
    [anon_sym_Foreach] = ACTIONS(5851),
    [anon_sym_while] = ACTIONS(5851),
    [anon_sym_WHILE] = ACTIONS(5851),
    [anon_sym_While] = ACTIONS(5851),
    [anon_sym_repeat] = ACTIONS(5851),
    [anon_sym_REPEAT] = ACTIONS(5851),
    [anon_sym_Repeat] = ACTIONS(5851),
    [anon_sym_exit] = ACTIONS(5851),
    [anon_sym_EXIT] = ACTIONS(5851),
    [anon_sym_Exit] = ACTIONS(5851),
    [anon_sym_continue] = ACTIONS(5851),
    [anon_sym_CONTINUE] = ACTIONS(5851),
    [anon_sym_Continue] = ACTIONS(5851),
    [anon_sym_break] = ACTIONS(5851),
    [anon_sym_BREAK] = ACTIONS(5851),
    [anon_sym_Break] = ACTIONS(5851),
    [anon_sym_with] = ACTIONS(5851),
    [anon_sym_WITH] = ACTIONS(5851),
    [anon_sym_With] = ACTIONS(5851),
    [sym_asserterror_keyword] = ACTIONS(5853),
    [sym_page_keyword] = ACTIONS(5851),
    [anon_sym_codeunit] = ACTIONS(5851),
    [anon_sym_CODEUNIT] = ACTIONS(5851),
    [anon_sym_Codeunit] = ACTIONS(5851),
    [anon_sym_CodeUnit] = ACTIONS(5851),
    [anon_sym_COdeunit] = ACTIONS(5851),
    [anon_sym_codeUnit] = ACTIONS(5851),
    [sym_report_keyword] = ACTIONS(5851),
    [sym_query_keyword] = ACTIONS(5851),
    [anon_sym_xmlport] = ACTIONS(5851),
    [anon_sym_XMLPORT] = ACTIONS(5851),
    [anon_sym_Xmlport] = ACTIONS(5851),
    [anon_sym_XMLport] = ACTIONS(5851),
    [anon_sym_XMLPort] = ACTIONS(5851),
    [anon_sym_XmlPort] = ACTIONS(5851),
    [anon_sym_enum] = ACTIONS(5851),
    [anon_sym_ENUM] = ACTIONS(5851),
    [anon_sym_Enum] = ACTIONS(5851),
    [anon_sym_eNUM] = ACTIONS(5851),
    [anon_sym_eNum] = ACTIONS(5851),
    [anon_sym_ENum] = ACTIONS(5851),
    [sym_quoted_identifier] = ACTIONS(5853),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5853),
    [sym_verbatim_string] = ACTIONS(5853),
    [sym_integer] = ACTIONS(5851),
    [sym_continue_as_identifier] = ACTIONS(5853),
    [sym_preproc_open] = ACTIONS(5853),
    [sym_preproc_close] = ACTIONS(5853),
  },
  [STATE(2470)] = {
    [sym_identifier] = ACTIONS(5855),
    [anon_sym_SEMI] = ACTIONS(5857),
    [anon_sym_DASH] = ACTIONS(5857),
    [aux_sym_boolean_token1] = ACTIONS(5855),
    [aux_sym_boolean_token2] = ACTIONS(5855),
    [sym_decimal] = ACTIONS(5855),
    [anon_sym_LPAREN] = ACTIONS(5857),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5855),
    [anon_sym_LBRACK] = ACTIONS(5857),
    [aux_sym_record_type_token1] = ACTIONS(5855),
    [aux_sym_basic_type_token21] = ACTIONS(5855),
    [aux_sym_basic_type_token22] = ACTIONS(5855),
    [aux_sym_basic_type_token48] = ACTIONS(5855),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5855),
    [anon_sym_POUNDif] = ACTIONS(5857),
    [anon_sym_POUNDIF] = ACTIONS(5857),
    [anon_sym_POUNDIf] = ACTIONS(5857),
    [anon_sym_not] = ACTIONS(5855),
    [anon_sym_NOT] = ACTIONS(5855),
    [anon_sym_Not] = ACTIONS(5855),
    [anon_sym_POUNDelif] = ACTIONS(5857),
    [anon_sym_POUNDELIF] = ACTIONS(5857),
    [anon_sym_POUNDElif] = ACTIONS(5857),
    [anon_sym_POUNDelse] = ACTIONS(5857),
    [anon_sym_POUNDELSE] = ACTIONS(5857),
    [anon_sym_POUNDElse] = ACTIONS(5857),
    [anon_sym_POUNDelse2] = ACTIONS(5857),
    [anon_sym_POUNDELSE2] = ACTIONS(5857),
    [anon_sym_POUNDElse2] = ACTIONS(5857),
    [anon_sym_POUNDendif] = ACTIONS(5857),
    [anon_sym_POUNDENDIF] = ACTIONS(5857),
    [anon_sym_POUNDEndif] = ACTIONS(5857),
    [anon_sym_POUNDendif2] = ACTIONS(5857),
    [anon_sym_POUNDENDIF2] = ACTIONS(5857),
    [anon_sym_POUNDEndif2] = ACTIONS(5857),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5855),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5855),
    [anon_sym_PLUS] = ACTIONS(5857),
    [sym_datetime_literal] = ACTIONS(5857),
    [sym_date_literal] = ACTIONS(5855),
    [sym_time_literal] = ACTIONS(5855),
    [sym_biginteger_literal] = ACTIONS(5857),
    [anon_sym_if] = ACTIONS(5855),
    [anon_sym_IF] = ACTIONS(5855),
    [anon_sym_If] = ACTIONS(5855),
    [anon_sym_else] = ACTIONS(5855),
    [anon_sym_ELSE] = ACTIONS(5855),
    [anon_sym_Else] = ACTIONS(5855),
    [anon_sym_case] = ACTIONS(5855),
    [anon_sym_CASE] = ACTIONS(5855),
    [anon_sym_Case] = ACTIONS(5855),
    [anon_sym_for] = ACTIONS(5855),
    [anon_sym_FOR] = ACTIONS(5855),
    [anon_sym_For] = ACTIONS(5855),
    [anon_sym_foreach] = ACTIONS(5855),
    [anon_sym_FOREACH] = ACTIONS(5855),
    [anon_sym_Foreach] = ACTIONS(5855),
    [anon_sym_while] = ACTIONS(5855),
    [anon_sym_WHILE] = ACTIONS(5855),
    [anon_sym_While] = ACTIONS(5855),
    [anon_sym_repeat] = ACTIONS(5855),
    [anon_sym_REPEAT] = ACTIONS(5855),
    [anon_sym_Repeat] = ACTIONS(5855),
    [anon_sym_exit] = ACTIONS(5855),
    [anon_sym_EXIT] = ACTIONS(5855),
    [anon_sym_Exit] = ACTIONS(5855),
    [anon_sym_continue] = ACTIONS(5855),
    [anon_sym_CONTINUE] = ACTIONS(5855),
    [anon_sym_Continue] = ACTIONS(5855),
    [anon_sym_break] = ACTIONS(5855),
    [anon_sym_BREAK] = ACTIONS(5855),
    [anon_sym_Break] = ACTIONS(5855),
    [anon_sym_with] = ACTIONS(5855),
    [anon_sym_WITH] = ACTIONS(5855),
    [anon_sym_With] = ACTIONS(5855),
    [sym_asserterror_keyword] = ACTIONS(5857),
    [sym_page_keyword] = ACTIONS(5855),
    [anon_sym_codeunit] = ACTIONS(5855),
    [anon_sym_CODEUNIT] = ACTIONS(5855),
    [anon_sym_Codeunit] = ACTIONS(5855),
    [anon_sym_CodeUnit] = ACTIONS(5855),
    [anon_sym_COdeunit] = ACTIONS(5855),
    [anon_sym_codeUnit] = ACTIONS(5855),
    [sym_report_keyword] = ACTIONS(5855),
    [sym_query_keyword] = ACTIONS(5855),
    [anon_sym_xmlport] = ACTIONS(5855),
    [anon_sym_XMLPORT] = ACTIONS(5855),
    [anon_sym_Xmlport] = ACTIONS(5855),
    [anon_sym_XMLport] = ACTIONS(5855),
    [anon_sym_XMLPort] = ACTIONS(5855),
    [anon_sym_XmlPort] = ACTIONS(5855),
    [anon_sym_enum] = ACTIONS(5855),
    [anon_sym_ENUM] = ACTIONS(5855),
    [anon_sym_Enum] = ACTIONS(5855),
    [anon_sym_eNUM] = ACTIONS(5855),
    [anon_sym_eNum] = ACTIONS(5855),
    [anon_sym_ENum] = ACTIONS(5855),
    [sym_quoted_identifier] = ACTIONS(5857),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5857),
    [sym_verbatim_string] = ACTIONS(5857),
    [sym_integer] = ACTIONS(5855),
    [sym_continue_as_identifier] = ACTIONS(5857),
    [sym_preproc_open] = ACTIONS(5857),
    [sym_preproc_close] = ACTIONS(5857),
  },
  [STATE(2471)] = {
    [sym_identifier] = ACTIONS(5859),
    [anon_sym_SEMI] = ACTIONS(5861),
    [anon_sym_DASH] = ACTIONS(5861),
    [aux_sym_boolean_token1] = ACTIONS(5859),
    [aux_sym_boolean_token2] = ACTIONS(5859),
    [sym_decimal] = ACTIONS(5859),
    [anon_sym_LPAREN] = ACTIONS(5861),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5859),
    [anon_sym_LBRACK] = ACTIONS(5861),
    [aux_sym_record_type_token1] = ACTIONS(5859),
    [aux_sym_basic_type_token21] = ACTIONS(5859),
    [aux_sym_basic_type_token22] = ACTIONS(5859),
    [aux_sym_basic_type_token48] = ACTIONS(5859),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5859),
    [anon_sym_POUNDif] = ACTIONS(5861),
    [anon_sym_POUNDIF] = ACTIONS(5861),
    [anon_sym_POUNDIf] = ACTIONS(5861),
    [anon_sym_not] = ACTIONS(5859),
    [anon_sym_NOT] = ACTIONS(5859),
    [anon_sym_Not] = ACTIONS(5859),
    [anon_sym_POUNDelif] = ACTIONS(5861),
    [anon_sym_POUNDELIF] = ACTIONS(5861),
    [anon_sym_POUNDElif] = ACTIONS(5861),
    [anon_sym_POUNDelse] = ACTIONS(5861),
    [anon_sym_POUNDELSE] = ACTIONS(5861),
    [anon_sym_POUNDElse] = ACTIONS(5861),
    [anon_sym_POUNDelse2] = ACTIONS(5861),
    [anon_sym_POUNDELSE2] = ACTIONS(5861),
    [anon_sym_POUNDElse2] = ACTIONS(5861),
    [anon_sym_POUNDendif] = ACTIONS(5861),
    [anon_sym_POUNDENDIF] = ACTIONS(5861),
    [anon_sym_POUNDEndif] = ACTIONS(5861),
    [anon_sym_POUNDendif2] = ACTIONS(5861),
    [anon_sym_POUNDENDIF2] = ACTIONS(5861),
    [anon_sym_POUNDEndif2] = ACTIONS(5861),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5859),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5859),
    [anon_sym_PLUS] = ACTIONS(5861),
    [sym_datetime_literal] = ACTIONS(5861),
    [sym_date_literal] = ACTIONS(5859),
    [sym_time_literal] = ACTIONS(5859),
    [sym_biginteger_literal] = ACTIONS(5861),
    [anon_sym_if] = ACTIONS(5859),
    [anon_sym_IF] = ACTIONS(5859),
    [anon_sym_If] = ACTIONS(5859),
    [anon_sym_else] = ACTIONS(5859),
    [anon_sym_ELSE] = ACTIONS(5859),
    [anon_sym_Else] = ACTIONS(5859),
    [anon_sym_case] = ACTIONS(5859),
    [anon_sym_CASE] = ACTIONS(5859),
    [anon_sym_Case] = ACTIONS(5859),
    [anon_sym_for] = ACTIONS(5859),
    [anon_sym_FOR] = ACTIONS(5859),
    [anon_sym_For] = ACTIONS(5859),
    [anon_sym_foreach] = ACTIONS(5859),
    [anon_sym_FOREACH] = ACTIONS(5859),
    [anon_sym_Foreach] = ACTIONS(5859),
    [anon_sym_while] = ACTIONS(5859),
    [anon_sym_WHILE] = ACTIONS(5859),
    [anon_sym_While] = ACTIONS(5859),
    [anon_sym_repeat] = ACTIONS(5859),
    [anon_sym_REPEAT] = ACTIONS(5859),
    [anon_sym_Repeat] = ACTIONS(5859),
    [anon_sym_exit] = ACTIONS(5859),
    [anon_sym_EXIT] = ACTIONS(5859),
    [anon_sym_Exit] = ACTIONS(5859),
    [anon_sym_continue] = ACTIONS(5859),
    [anon_sym_CONTINUE] = ACTIONS(5859),
    [anon_sym_Continue] = ACTIONS(5859),
    [anon_sym_break] = ACTIONS(5859),
    [anon_sym_BREAK] = ACTIONS(5859),
    [anon_sym_Break] = ACTIONS(5859),
    [anon_sym_with] = ACTIONS(5859),
    [anon_sym_WITH] = ACTIONS(5859),
    [anon_sym_With] = ACTIONS(5859),
    [sym_asserterror_keyword] = ACTIONS(5861),
    [sym_page_keyword] = ACTIONS(5859),
    [anon_sym_codeunit] = ACTIONS(5859),
    [anon_sym_CODEUNIT] = ACTIONS(5859),
    [anon_sym_Codeunit] = ACTIONS(5859),
    [anon_sym_CodeUnit] = ACTIONS(5859),
    [anon_sym_COdeunit] = ACTIONS(5859),
    [anon_sym_codeUnit] = ACTIONS(5859),
    [sym_report_keyword] = ACTIONS(5859),
    [sym_query_keyword] = ACTIONS(5859),
    [anon_sym_xmlport] = ACTIONS(5859),
    [anon_sym_XMLPORT] = ACTIONS(5859),
    [anon_sym_Xmlport] = ACTIONS(5859),
    [anon_sym_XMLport] = ACTIONS(5859),
    [anon_sym_XMLPort] = ACTIONS(5859),
    [anon_sym_XmlPort] = ACTIONS(5859),
    [anon_sym_enum] = ACTIONS(5859),
    [anon_sym_ENUM] = ACTIONS(5859),
    [anon_sym_Enum] = ACTIONS(5859),
    [anon_sym_eNUM] = ACTIONS(5859),
    [anon_sym_eNum] = ACTIONS(5859),
    [anon_sym_ENum] = ACTIONS(5859),
    [sym_quoted_identifier] = ACTIONS(5861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5861),
    [sym_verbatim_string] = ACTIONS(5861),
    [sym_integer] = ACTIONS(5859),
    [sym_continue_as_identifier] = ACTIONS(5861),
    [sym_preproc_open] = ACTIONS(5861),
    [sym_preproc_close] = ACTIONS(5861),
  },
  [STATE(2472)] = {
    [sym_identifier] = ACTIONS(5863),
    [anon_sym_SEMI] = ACTIONS(5865),
    [anon_sym_DASH] = ACTIONS(5865),
    [aux_sym_boolean_token1] = ACTIONS(5863),
    [aux_sym_boolean_token2] = ACTIONS(5863),
    [sym_decimal] = ACTIONS(5863),
    [anon_sym_LPAREN] = ACTIONS(5865),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5863),
    [anon_sym_LBRACK] = ACTIONS(5865),
    [aux_sym_record_type_token1] = ACTIONS(5863),
    [aux_sym_basic_type_token21] = ACTIONS(5863),
    [aux_sym_basic_type_token22] = ACTIONS(5863),
    [aux_sym_basic_type_token48] = ACTIONS(5863),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5863),
    [anon_sym_POUNDif] = ACTIONS(5865),
    [anon_sym_POUNDIF] = ACTIONS(5865),
    [anon_sym_POUNDIf] = ACTIONS(5865),
    [anon_sym_not] = ACTIONS(5863),
    [anon_sym_NOT] = ACTIONS(5863),
    [anon_sym_Not] = ACTIONS(5863),
    [anon_sym_POUNDelif] = ACTIONS(5865),
    [anon_sym_POUNDELIF] = ACTIONS(5865),
    [anon_sym_POUNDElif] = ACTIONS(5865),
    [anon_sym_POUNDelse] = ACTIONS(5865),
    [anon_sym_POUNDELSE] = ACTIONS(5865),
    [anon_sym_POUNDElse] = ACTIONS(5865),
    [anon_sym_POUNDelse2] = ACTIONS(5865),
    [anon_sym_POUNDELSE2] = ACTIONS(5865),
    [anon_sym_POUNDElse2] = ACTIONS(5865),
    [anon_sym_POUNDendif] = ACTIONS(5865),
    [anon_sym_POUNDENDIF] = ACTIONS(5865),
    [anon_sym_POUNDEndif] = ACTIONS(5865),
    [anon_sym_POUNDendif2] = ACTIONS(5865),
    [anon_sym_POUNDENDIF2] = ACTIONS(5865),
    [anon_sym_POUNDEndif2] = ACTIONS(5865),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5863),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5863),
    [anon_sym_PLUS] = ACTIONS(5865),
    [sym_datetime_literal] = ACTIONS(5865),
    [sym_date_literal] = ACTIONS(5863),
    [sym_time_literal] = ACTIONS(5863),
    [sym_biginteger_literal] = ACTIONS(5865),
    [anon_sym_if] = ACTIONS(5863),
    [anon_sym_IF] = ACTIONS(5863),
    [anon_sym_If] = ACTIONS(5863),
    [anon_sym_else] = ACTIONS(5863),
    [anon_sym_ELSE] = ACTIONS(5863),
    [anon_sym_Else] = ACTIONS(5863),
    [anon_sym_case] = ACTIONS(5863),
    [anon_sym_CASE] = ACTIONS(5863),
    [anon_sym_Case] = ACTIONS(5863),
    [anon_sym_for] = ACTIONS(5863),
    [anon_sym_FOR] = ACTIONS(5863),
    [anon_sym_For] = ACTIONS(5863),
    [anon_sym_foreach] = ACTIONS(5863),
    [anon_sym_FOREACH] = ACTIONS(5863),
    [anon_sym_Foreach] = ACTIONS(5863),
    [anon_sym_while] = ACTIONS(5863),
    [anon_sym_WHILE] = ACTIONS(5863),
    [anon_sym_While] = ACTIONS(5863),
    [anon_sym_repeat] = ACTIONS(5863),
    [anon_sym_REPEAT] = ACTIONS(5863),
    [anon_sym_Repeat] = ACTIONS(5863),
    [anon_sym_exit] = ACTIONS(5863),
    [anon_sym_EXIT] = ACTIONS(5863),
    [anon_sym_Exit] = ACTIONS(5863),
    [anon_sym_continue] = ACTIONS(5863),
    [anon_sym_CONTINUE] = ACTIONS(5863),
    [anon_sym_Continue] = ACTIONS(5863),
    [anon_sym_break] = ACTIONS(5863),
    [anon_sym_BREAK] = ACTIONS(5863),
    [anon_sym_Break] = ACTIONS(5863),
    [anon_sym_with] = ACTIONS(5863),
    [anon_sym_WITH] = ACTIONS(5863),
    [anon_sym_With] = ACTIONS(5863),
    [sym_asserterror_keyword] = ACTIONS(5865),
    [sym_page_keyword] = ACTIONS(5863),
    [anon_sym_codeunit] = ACTIONS(5863),
    [anon_sym_CODEUNIT] = ACTIONS(5863),
    [anon_sym_Codeunit] = ACTIONS(5863),
    [anon_sym_CodeUnit] = ACTIONS(5863),
    [anon_sym_COdeunit] = ACTIONS(5863),
    [anon_sym_codeUnit] = ACTIONS(5863),
    [sym_report_keyword] = ACTIONS(5863),
    [sym_query_keyword] = ACTIONS(5863),
    [anon_sym_xmlport] = ACTIONS(5863),
    [anon_sym_XMLPORT] = ACTIONS(5863),
    [anon_sym_Xmlport] = ACTIONS(5863),
    [anon_sym_XMLport] = ACTIONS(5863),
    [anon_sym_XMLPort] = ACTIONS(5863),
    [anon_sym_XmlPort] = ACTIONS(5863),
    [anon_sym_enum] = ACTIONS(5863),
    [anon_sym_ENUM] = ACTIONS(5863),
    [anon_sym_Enum] = ACTIONS(5863),
    [anon_sym_eNUM] = ACTIONS(5863),
    [anon_sym_eNum] = ACTIONS(5863),
    [anon_sym_ENum] = ACTIONS(5863),
    [sym_quoted_identifier] = ACTIONS(5865),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5865),
    [sym_verbatim_string] = ACTIONS(5865),
    [sym_integer] = ACTIONS(5863),
    [sym_continue_as_identifier] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5865),
    [sym_preproc_close] = ACTIONS(5865),
  },
  [STATE(2473)] = {
    [sym_identifier] = ACTIONS(5867),
    [anon_sym_SEMI] = ACTIONS(5869),
    [anon_sym_DASH] = ACTIONS(5869),
    [aux_sym_boolean_token1] = ACTIONS(5867),
    [aux_sym_boolean_token2] = ACTIONS(5867),
    [sym_decimal] = ACTIONS(5867),
    [anon_sym_LPAREN] = ACTIONS(5869),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5867),
    [anon_sym_LBRACK] = ACTIONS(5869),
    [aux_sym_record_type_token1] = ACTIONS(5867),
    [aux_sym_basic_type_token21] = ACTIONS(5867),
    [aux_sym_basic_type_token22] = ACTIONS(5867),
    [aux_sym_basic_type_token48] = ACTIONS(5867),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5867),
    [anon_sym_POUNDif] = ACTIONS(5869),
    [anon_sym_POUNDIF] = ACTIONS(5869),
    [anon_sym_POUNDIf] = ACTIONS(5869),
    [anon_sym_not] = ACTIONS(5867),
    [anon_sym_NOT] = ACTIONS(5867),
    [anon_sym_Not] = ACTIONS(5867),
    [anon_sym_POUNDelif] = ACTIONS(5869),
    [anon_sym_POUNDELIF] = ACTIONS(5869),
    [anon_sym_POUNDElif] = ACTIONS(5869),
    [anon_sym_POUNDelse] = ACTIONS(5869),
    [anon_sym_POUNDELSE] = ACTIONS(5869),
    [anon_sym_POUNDElse] = ACTIONS(5869),
    [anon_sym_POUNDelse2] = ACTIONS(5869),
    [anon_sym_POUNDELSE2] = ACTIONS(5869),
    [anon_sym_POUNDElse2] = ACTIONS(5869),
    [anon_sym_POUNDendif] = ACTIONS(5869),
    [anon_sym_POUNDENDIF] = ACTIONS(5869),
    [anon_sym_POUNDEndif] = ACTIONS(5869),
    [anon_sym_POUNDendif2] = ACTIONS(5869),
    [anon_sym_POUNDENDIF2] = ACTIONS(5869),
    [anon_sym_POUNDEndif2] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5867),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5867),
    [anon_sym_PLUS] = ACTIONS(5869),
    [sym_datetime_literal] = ACTIONS(5869),
    [sym_date_literal] = ACTIONS(5867),
    [sym_time_literal] = ACTIONS(5867),
    [sym_biginteger_literal] = ACTIONS(5869),
    [anon_sym_if] = ACTIONS(5867),
    [anon_sym_IF] = ACTIONS(5867),
    [anon_sym_If] = ACTIONS(5867),
    [anon_sym_else] = ACTIONS(5867),
    [anon_sym_ELSE] = ACTIONS(5867),
    [anon_sym_Else] = ACTIONS(5867),
    [anon_sym_case] = ACTIONS(5867),
    [anon_sym_CASE] = ACTIONS(5867),
    [anon_sym_Case] = ACTIONS(5867),
    [anon_sym_for] = ACTIONS(5867),
    [anon_sym_FOR] = ACTIONS(5867),
    [anon_sym_For] = ACTIONS(5867),
    [anon_sym_foreach] = ACTIONS(5867),
    [anon_sym_FOREACH] = ACTIONS(5867),
    [anon_sym_Foreach] = ACTIONS(5867),
    [anon_sym_while] = ACTIONS(5867),
    [anon_sym_WHILE] = ACTIONS(5867),
    [anon_sym_While] = ACTIONS(5867),
    [anon_sym_repeat] = ACTIONS(5867),
    [anon_sym_REPEAT] = ACTIONS(5867),
    [anon_sym_Repeat] = ACTIONS(5867),
    [anon_sym_exit] = ACTIONS(5867),
    [anon_sym_EXIT] = ACTIONS(5867),
    [anon_sym_Exit] = ACTIONS(5867),
    [anon_sym_continue] = ACTIONS(5867),
    [anon_sym_CONTINUE] = ACTIONS(5867),
    [anon_sym_Continue] = ACTIONS(5867),
    [anon_sym_break] = ACTIONS(5867),
    [anon_sym_BREAK] = ACTIONS(5867),
    [anon_sym_Break] = ACTIONS(5867),
    [anon_sym_with] = ACTIONS(5867),
    [anon_sym_WITH] = ACTIONS(5867),
    [anon_sym_With] = ACTIONS(5867),
    [sym_asserterror_keyword] = ACTIONS(5869),
    [sym_page_keyword] = ACTIONS(5867),
    [anon_sym_codeunit] = ACTIONS(5867),
    [anon_sym_CODEUNIT] = ACTIONS(5867),
    [anon_sym_Codeunit] = ACTIONS(5867),
    [anon_sym_CodeUnit] = ACTIONS(5867),
    [anon_sym_COdeunit] = ACTIONS(5867),
    [anon_sym_codeUnit] = ACTIONS(5867),
    [sym_report_keyword] = ACTIONS(5867),
    [sym_query_keyword] = ACTIONS(5867),
    [anon_sym_xmlport] = ACTIONS(5867),
    [anon_sym_XMLPORT] = ACTIONS(5867),
    [anon_sym_Xmlport] = ACTIONS(5867),
    [anon_sym_XMLport] = ACTIONS(5867),
    [anon_sym_XMLPort] = ACTIONS(5867),
    [anon_sym_XmlPort] = ACTIONS(5867),
    [anon_sym_enum] = ACTIONS(5867),
    [anon_sym_ENUM] = ACTIONS(5867),
    [anon_sym_Enum] = ACTIONS(5867),
    [anon_sym_eNUM] = ACTIONS(5867),
    [anon_sym_eNum] = ACTIONS(5867),
    [anon_sym_ENum] = ACTIONS(5867),
    [sym_quoted_identifier] = ACTIONS(5869),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5869),
    [sym_verbatim_string] = ACTIONS(5869),
    [sym_integer] = ACTIONS(5867),
    [sym_continue_as_identifier] = ACTIONS(5869),
    [sym_preproc_open] = ACTIONS(5869),
    [sym_preproc_close] = ACTIONS(5869),
  },
  [STATE(2474)] = {
    [sym_identifier] = ACTIONS(5871),
    [anon_sym_SEMI] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [aux_sym_boolean_token1] = ACTIONS(5871),
    [aux_sym_boolean_token2] = ACTIONS(5871),
    [sym_decimal] = ACTIONS(5871),
    [anon_sym_LPAREN] = ACTIONS(5873),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5871),
    [anon_sym_LBRACK] = ACTIONS(5873),
    [aux_sym_record_type_token1] = ACTIONS(5871),
    [aux_sym_basic_type_token21] = ACTIONS(5871),
    [aux_sym_basic_type_token22] = ACTIONS(5871),
    [aux_sym_basic_type_token48] = ACTIONS(5871),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5871),
    [anon_sym_POUNDif] = ACTIONS(5873),
    [anon_sym_POUNDIF] = ACTIONS(5873),
    [anon_sym_POUNDIf] = ACTIONS(5873),
    [anon_sym_not] = ACTIONS(5871),
    [anon_sym_NOT] = ACTIONS(5871),
    [anon_sym_Not] = ACTIONS(5871),
    [anon_sym_POUNDelif] = ACTIONS(5873),
    [anon_sym_POUNDELIF] = ACTIONS(5873),
    [anon_sym_POUNDElif] = ACTIONS(5873),
    [anon_sym_POUNDelse] = ACTIONS(5873),
    [anon_sym_POUNDELSE] = ACTIONS(5873),
    [anon_sym_POUNDElse] = ACTIONS(5873),
    [anon_sym_POUNDelse2] = ACTIONS(5873),
    [anon_sym_POUNDELSE2] = ACTIONS(5873),
    [anon_sym_POUNDElse2] = ACTIONS(5873),
    [anon_sym_POUNDendif] = ACTIONS(5873),
    [anon_sym_POUNDENDIF] = ACTIONS(5873),
    [anon_sym_POUNDEndif] = ACTIONS(5873),
    [anon_sym_POUNDendif2] = ACTIONS(5873),
    [anon_sym_POUNDENDIF2] = ACTIONS(5873),
    [anon_sym_POUNDEndif2] = ACTIONS(5873),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5871),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5871),
    [anon_sym_PLUS] = ACTIONS(5873),
    [sym_datetime_literal] = ACTIONS(5873),
    [sym_date_literal] = ACTIONS(5871),
    [sym_time_literal] = ACTIONS(5871),
    [sym_biginteger_literal] = ACTIONS(5873),
    [anon_sym_if] = ACTIONS(5871),
    [anon_sym_IF] = ACTIONS(5871),
    [anon_sym_If] = ACTIONS(5871),
    [anon_sym_else] = ACTIONS(5871),
    [anon_sym_ELSE] = ACTIONS(5871),
    [anon_sym_Else] = ACTIONS(5871),
    [anon_sym_case] = ACTIONS(5871),
    [anon_sym_CASE] = ACTIONS(5871),
    [anon_sym_Case] = ACTIONS(5871),
    [anon_sym_for] = ACTIONS(5871),
    [anon_sym_FOR] = ACTIONS(5871),
    [anon_sym_For] = ACTIONS(5871),
    [anon_sym_foreach] = ACTIONS(5871),
    [anon_sym_FOREACH] = ACTIONS(5871),
    [anon_sym_Foreach] = ACTIONS(5871),
    [anon_sym_while] = ACTIONS(5871),
    [anon_sym_WHILE] = ACTIONS(5871),
    [anon_sym_While] = ACTIONS(5871),
    [anon_sym_repeat] = ACTIONS(5871),
    [anon_sym_REPEAT] = ACTIONS(5871),
    [anon_sym_Repeat] = ACTIONS(5871),
    [anon_sym_exit] = ACTIONS(5871),
    [anon_sym_EXIT] = ACTIONS(5871),
    [anon_sym_Exit] = ACTIONS(5871),
    [anon_sym_continue] = ACTIONS(5871),
    [anon_sym_CONTINUE] = ACTIONS(5871),
    [anon_sym_Continue] = ACTIONS(5871),
    [anon_sym_break] = ACTIONS(5871),
    [anon_sym_BREAK] = ACTIONS(5871),
    [anon_sym_Break] = ACTIONS(5871),
    [anon_sym_with] = ACTIONS(5871),
    [anon_sym_WITH] = ACTIONS(5871),
    [anon_sym_With] = ACTIONS(5871),
    [sym_asserterror_keyword] = ACTIONS(5873),
    [sym_page_keyword] = ACTIONS(5871),
    [anon_sym_codeunit] = ACTIONS(5871),
    [anon_sym_CODEUNIT] = ACTIONS(5871),
    [anon_sym_Codeunit] = ACTIONS(5871),
    [anon_sym_CodeUnit] = ACTIONS(5871),
    [anon_sym_COdeunit] = ACTIONS(5871),
    [anon_sym_codeUnit] = ACTIONS(5871),
    [sym_report_keyword] = ACTIONS(5871),
    [sym_query_keyword] = ACTIONS(5871),
    [anon_sym_xmlport] = ACTIONS(5871),
    [anon_sym_XMLPORT] = ACTIONS(5871),
    [anon_sym_Xmlport] = ACTIONS(5871),
    [anon_sym_XMLport] = ACTIONS(5871),
    [anon_sym_XMLPort] = ACTIONS(5871),
    [anon_sym_XmlPort] = ACTIONS(5871),
    [anon_sym_enum] = ACTIONS(5871),
    [anon_sym_ENUM] = ACTIONS(5871),
    [anon_sym_Enum] = ACTIONS(5871),
    [anon_sym_eNUM] = ACTIONS(5871),
    [anon_sym_eNum] = ACTIONS(5871),
    [anon_sym_ENum] = ACTIONS(5871),
    [sym_quoted_identifier] = ACTIONS(5873),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5873),
    [sym_verbatim_string] = ACTIONS(5873),
    [sym_integer] = ACTIONS(5871),
    [sym_continue_as_identifier] = ACTIONS(5873),
    [sym_preproc_open] = ACTIONS(5873),
    [sym_preproc_close] = ACTIONS(5873),
  },
  [STATE(2475)] = {
    [sym_identifier] = ACTIONS(5875),
    [anon_sym_SEMI] = ACTIONS(5877),
    [anon_sym_DASH] = ACTIONS(5877),
    [aux_sym_boolean_token1] = ACTIONS(5875),
    [aux_sym_boolean_token2] = ACTIONS(5875),
    [sym_decimal] = ACTIONS(5875),
    [anon_sym_LPAREN] = ACTIONS(5877),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5875),
    [anon_sym_LBRACK] = ACTIONS(5877),
    [aux_sym_record_type_token1] = ACTIONS(5875),
    [aux_sym_basic_type_token21] = ACTIONS(5875),
    [aux_sym_basic_type_token22] = ACTIONS(5875),
    [aux_sym_basic_type_token48] = ACTIONS(5875),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5875),
    [anon_sym_POUNDif] = ACTIONS(5877),
    [anon_sym_POUNDIF] = ACTIONS(5877),
    [anon_sym_POUNDIf] = ACTIONS(5877),
    [anon_sym_not] = ACTIONS(5875),
    [anon_sym_NOT] = ACTIONS(5875),
    [anon_sym_Not] = ACTIONS(5875),
    [anon_sym_POUNDelif] = ACTIONS(5877),
    [anon_sym_POUNDELIF] = ACTIONS(5877),
    [anon_sym_POUNDElif] = ACTIONS(5877),
    [anon_sym_POUNDelse] = ACTIONS(5877),
    [anon_sym_POUNDELSE] = ACTIONS(5877),
    [anon_sym_POUNDElse] = ACTIONS(5877),
    [anon_sym_POUNDelse2] = ACTIONS(5877),
    [anon_sym_POUNDELSE2] = ACTIONS(5877),
    [anon_sym_POUNDElse2] = ACTIONS(5877),
    [anon_sym_POUNDendif] = ACTIONS(5877),
    [anon_sym_POUNDENDIF] = ACTIONS(5877),
    [anon_sym_POUNDEndif] = ACTIONS(5877),
    [anon_sym_POUNDendif2] = ACTIONS(5877),
    [anon_sym_POUNDENDIF2] = ACTIONS(5877),
    [anon_sym_POUNDEndif2] = ACTIONS(5877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5875),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5875),
    [anon_sym_PLUS] = ACTIONS(5877),
    [sym_datetime_literal] = ACTIONS(5877),
    [sym_date_literal] = ACTIONS(5875),
    [sym_time_literal] = ACTIONS(5875),
    [sym_biginteger_literal] = ACTIONS(5877),
    [anon_sym_if] = ACTIONS(5875),
    [anon_sym_IF] = ACTIONS(5875),
    [anon_sym_If] = ACTIONS(5875),
    [anon_sym_else] = ACTIONS(5875),
    [anon_sym_ELSE] = ACTIONS(5875),
    [anon_sym_Else] = ACTIONS(5875),
    [anon_sym_case] = ACTIONS(5875),
    [anon_sym_CASE] = ACTIONS(5875),
    [anon_sym_Case] = ACTIONS(5875),
    [anon_sym_for] = ACTIONS(5875),
    [anon_sym_FOR] = ACTIONS(5875),
    [anon_sym_For] = ACTIONS(5875),
    [anon_sym_foreach] = ACTIONS(5875),
    [anon_sym_FOREACH] = ACTIONS(5875),
    [anon_sym_Foreach] = ACTIONS(5875),
    [anon_sym_while] = ACTIONS(5875),
    [anon_sym_WHILE] = ACTIONS(5875),
    [anon_sym_While] = ACTIONS(5875),
    [anon_sym_repeat] = ACTIONS(5875),
    [anon_sym_REPEAT] = ACTIONS(5875),
    [anon_sym_Repeat] = ACTIONS(5875),
    [anon_sym_exit] = ACTIONS(5875),
    [anon_sym_EXIT] = ACTIONS(5875),
    [anon_sym_Exit] = ACTIONS(5875),
    [anon_sym_continue] = ACTIONS(5875),
    [anon_sym_CONTINUE] = ACTIONS(5875),
    [anon_sym_Continue] = ACTIONS(5875),
    [anon_sym_break] = ACTIONS(5875),
    [anon_sym_BREAK] = ACTIONS(5875),
    [anon_sym_Break] = ACTIONS(5875),
    [anon_sym_with] = ACTIONS(5875),
    [anon_sym_WITH] = ACTIONS(5875),
    [anon_sym_With] = ACTIONS(5875),
    [sym_asserterror_keyword] = ACTIONS(5877),
    [sym_page_keyword] = ACTIONS(5875),
    [anon_sym_codeunit] = ACTIONS(5875),
    [anon_sym_CODEUNIT] = ACTIONS(5875),
    [anon_sym_Codeunit] = ACTIONS(5875),
    [anon_sym_CodeUnit] = ACTIONS(5875),
    [anon_sym_COdeunit] = ACTIONS(5875),
    [anon_sym_codeUnit] = ACTIONS(5875),
    [sym_report_keyword] = ACTIONS(5875),
    [sym_query_keyword] = ACTIONS(5875),
    [anon_sym_xmlport] = ACTIONS(5875),
    [anon_sym_XMLPORT] = ACTIONS(5875),
    [anon_sym_Xmlport] = ACTIONS(5875),
    [anon_sym_XMLport] = ACTIONS(5875),
    [anon_sym_XMLPort] = ACTIONS(5875),
    [anon_sym_XmlPort] = ACTIONS(5875),
    [anon_sym_enum] = ACTIONS(5875),
    [anon_sym_ENUM] = ACTIONS(5875),
    [anon_sym_Enum] = ACTIONS(5875),
    [anon_sym_eNUM] = ACTIONS(5875),
    [anon_sym_eNum] = ACTIONS(5875),
    [anon_sym_ENum] = ACTIONS(5875),
    [sym_quoted_identifier] = ACTIONS(5877),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5877),
    [sym_verbatim_string] = ACTIONS(5877),
    [sym_integer] = ACTIONS(5875),
    [sym_continue_as_identifier] = ACTIONS(5877),
    [sym_preproc_open] = ACTIONS(5877),
    [sym_preproc_close] = ACTIONS(5877),
  },
  [STATE(2476)] = {
    [sym_identifier] = ACTIONS(5879),
    [anon_sym_SEMI] = ACTIONS(5881),
    [anon_sym_DASH] = ACTIONS(5881),
    [aux_sym_boolean_token1] = ACTIONS(5879),
    [aux_sym_boolean_token2] = ACTIONS(5879),
    [sym_decimal] = ACTIONS(5879),
    [anon_sym_LPAREN] = ACTIONS(5881),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5879),
    [anon_sym_LBRACK] = ACTIONS(5881),
    [aux_sym_record_type_token1] = ACTIONS(5879),
    [aux_sym_basic_type_token21] = ACTIONS(5879),
    [aux_sym_basic_type_token22] = ACTIONS(5879),
    [aux_sym_basic_type_token48] = ACTIONS(5879),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5879),
    [anon_sym_POUNDif] = ACTIONS(5881),
    [anon_sym_POUNDIF] = ACTIONS(5881),
    [anon_sym_POUNDIf] = ACTIONS(5881),
    [anon_sym_not] = ACTIONS(5879),
    [anon_sym_NOT] = ACTIONS(5879),
    [anon_sym_Not] = ACTIONS(5879),
    [anon_sym_POUNDelif] = ACTIONS(5881),
    [anon_sym_POUNDELIF] = ACTIONS(5881),
    [anon_sym_POUNDElif] = ACTIONS(5881),
    [anon_sym_POUNDelse] = ACTIONS(5881),
    [anon_sym_POUNDELSE] = ACTIONS(5881),
    [anon_sym_POUNDElse] = ACTIONS(5881),
    [anon_sym_POUNDelse2] = ACTIONS(5881),
    [anon_sym_POUNDELSE2] = ACTIONS(5881),
    [anon_sym_POUNDElse2] = ACTIONS(5881),
    [anon_sym_POUNDendif] = ACTIONS(5881),
    [anon_sym_POUNDENDIF] = ACTIONS(5881),
    [anon_sym_POUNDEndif] = ACTIONS(5881),
    [anon_sym_POUNDendif2] = ACTIONS(5881),
    [anon_sym_POUNDENDIF2] = ACTIONS(5881),
    [anon_sym_POUNDEndif2] = ACTIONS(5881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5879),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5879),
    [anon_sym_PLUS] = ACTIONS(5881),
    [sym_datetime_literal] = ACTIONS(5881),
    [sym_date_literal] = ACTIONS(5879),
    [sym_time_literal] = ACTIONS(5879),
    [sym_biginteger_literal] = ACTIONS(5881),
    [anon_sym_if] = ACTIONS(5879),
    [anon_sym_IF] = ACTIONS(5879),
    [anon_sym_If] = ACTIONS(5879),
    [anon_sym_else] = ACTIONS(5879),
    [anon_sym_ELSE] = ACTIONS(5879),
    [anon_sym_Else] = ACTIONS(5879),
    [anon_sym_case] = ACTIONS(5879),
    [anon_sym_CASE] = ACTIONS(5879),
    [anon_sym_Case] = ACTIONS(5879),
    [anon_sym_for] = ACTIONS(5879),
    [anon_sym_FOR] = ACTIONS(5879),
    [anon_sym_For] = ACTIONS(5879),
    [anon_sym_foreach] = ACTIONS(5879),
    [anon_sym_FOREACH] = ACTIONS(5879),
    [anon_sym_Foreach] = ACTIONS(5879),
    [anon_sym_while] = ACTIONS(5879),
    [anon_sym_WHILE] = ACTIONS(5879),
    [anon_sym_While] = ACTIONS(5879),
    [anon_sym_repeat] = ACTIONS(5879),
    [anon_sym_REPEAT] = ACTIONS(5879),
    [anon_sym_Repeat] = ACTIONS(5879),
    [anon_sym_exit] = ACTIONS(5879),
    [anon_sym_EXIT] = ACTIONS(5879),
    [anon_sym_Exit] = ACTIONS(5879),
    [anon_sym_continue] = ACTIONS(5879),
    [anon_sym_CONTINUE] = ACTIONS(5879),
    [anon_sym_Continue] = ACTIONS(5879),
    [anon_sym_break] = ACTIONS(5879),
    [anon_sym_BREAK] = ACTIONS(5879),
    [anon_sym_Break] = ACTIONS(5879),
    [anon_sym_with] = ACTIONS(5879),
    [anon_sym_WITH] = ACTIONS(5879),
    [anon_sym_With] = ACTIONS(5879),
    [sym_asserterror_keyword] = ACTIONS(5881),
    [sym_page_keyword] = ACTIONS(5879),
    [anon_sym_codeunit] = ACTIONS(5879),
    [anon_sym_CODEUNIT] = ACTIONS(5879),
    [anon_sym_Codeunit] = ACTIONS(5879),
    [anon_sym_CodeUnit] = ACTIONS(5879),
    [anon_sym_COdeunit] = ACTIONS(5879),
    [anon_sym_codeUnit] = ACTIONS(5879),
    [sym_report_keyword] = ACTIONS(5879),
    [sym_query_keyword] = ACTIONS(5879),
    [anon_sym_xmlport] = ACTIONS(5879),
    [anon_sym_XMLPORT] = ACTIONS(5879),
    [anon_sym_Xmlport] = ACTIONS(5879),
    [anon_sym_XMLport] = ACTIONS(5879),
    [anon_sym_XMLPort] = ACTIONS(5879),
    [anon_sym_XmlPort] = ACTIONS(5879),
    [anon_sym_enum] = ACTIONS(5879),
    [anon_sym_ENUM] = ACTIONS(5879),
    [anon_sym_Enum] = ACTIONS(5879),
    [anon_sym_eNUM] = ACTIONS(5879),
    [anon_sym_eNum] = ACTIONS(5879),
    [anon_sym_ENum] = ACTIONS(5879),
    [sym_quoted_identifier] = ACTIONS(5881),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5881),
    [sym_verbatim_string] = ACTIONS(5881),
    [sym_integer] = ACTIONS(5879),
    [sym_continue_as_identifier] = ACTIONS(5881),
    [sym_preproc_open] = ACTIONS(5881),
    [sym_preproc_close] = ACTIONS(5881),
  },
  [STATE(2477)] = {
    [sym_identifier] = ACTIONS(5883),
    [anon_sym_SEMI] = ACTIONS(5885),
    [anon_sym_DASH] = ACTIONS(5885),
    [aux_sym_boolean_token1] = ACTIONS(5883),
    [aux_sym_boolean_token2] = ACTIONS(5883),
    [sym_decimal] = ACTIONS(5883),
    [anon_sym_LPAREN] = ACTIONS(5885),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5883),
    [anon_sym_LBRACK] = ACTIONS(5885),
    [aux_sym_record_type_token1] = ACTIONS(5883),
    [aux_sym_basic_type_token21] = ACTIONS(5883),
    [aux_sym_basic_type_token22] = ACTIONS(5883),
    [aux_sym_basic_type_token48] = ACTIONS(5883),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5883),
    [anon_sym_POUNDif] = ACTIONS(5885),
    [anon_sym_POUNDIF] = ACTIONS(5885),
    [anon_sym_POUNDIf] = ACTIONS(5885),
    [anon_sym_not] = ACTIONS(5883),
    [anon_sym_NOT] = ACTIONS(5883),
    [anon_sym_Not] = ACTIONS(5883),
    [anon_sym_POUNDelif] = ACTIONS(5885),
    [anon_sym_POUNDELIF] = ACTIONS(5885),
    [anon_sym_POUNDElif] = ACTIONS(5885),
    [anon_sym_POUNDelse] = ACTIONS(5885),
    [anon_sym_POUNDELSE] = ACTIONS(5885),
    [anon_sym_POUNDElse] = ACTIONS(5885),
    [anon_sym_POUNDelse2] = ACTIONS(5885),
    [anon_sym_POUNDELSE2] = ACTIONS(5885),
    [anon_sym_POUNDElse2] = ACTIONS(5885),
    [anon_sym_POUNDendif] = ACTIONS(5885),
    [anon_sym_POUNDENDIF] = ACTIONS(5885),
    [anon_sym_POUNDEndif] = ACTIONS(5885),
    [anon_sym_POUNDendif2] = ACTIONS(5885),
    [anon_sym_POUNDENDIF2] = ACTIONS(5885),
    [anon_sym_POUNDEndif2] = ACTIONS(5885),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5883),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5883),
    [anon_sym_PLUS] = ACTIONS(5885),
    [sym_datetime_literal] = ACTIONS(5885),
    [sym_date_literal] = ACTIONS(5883),
    [sym_time_literal] = ACTIONS(5883),
    [sym_biginteger_literal] = ACTIONS(5885),
    [anon_sym_if] = ACTIONS(5883),
    [anon_sym_IF] = ACTIONS(5883),
    [anon_sym_If] = ACTIONS(5883),
    [anon_sym_else] = ACTIONS(5883),
    [anon_sym_ELSE] = ACTIONS(5883),
    [anon_sym_Else] = ACTIONS(5883),
    [anon_sym_case] = ACTIONS(5883),
    [anon_sym_CASE] = ACTIONS(5883),
    [anon_sym_Case] = ACTIONS(5883),
    [anon_sym_for] = ACTIONS(5883),
    [anon_sym_FOR] = ACTIONS(5883),
    [anon_sym_For] = ACTIONS(5883),
    [anon_sym_foreach] = ACTIONS(5883),
    [anon_sym_FOREACH] = ACTIONS(5883),
    [anon_sym_Foreach] = ACTIONS(5883),
    [anon_sym_while] = ACTIONS(5883),
    [anon_sym_WHILE] = ACTIONS(5883),
    [anon_sym_While] = ACTIONS(5883),
    [anon_sym_repeat] = ACTIONS(5883),
    [anon_sym_REPEAT] = ACTIONS(5883),
    [anon_sym_Repeat] = ACTIONS(5883),
    [anon_sym_exit] = ACTIONS(5883),
    [anon_sym_EXIT] = ACTIONS(5883),
    [anon_sym_Exit] = ACTIONS(5883),
    [anon_sym_continue] = ACTIONS(5883),
    [anon_sym_CONTINUE] = ACTIONS(5883),
    [anon_sym_Continue] = ACTIONS(5883),
    [anon_sym_break] = ACTIONS(5883),
    [anon_sym_BREAK] = ACTIONS(5883),
    [anon_sym_Break] = ACTIONS(5883),
    [anon_sym_with] = ACTIONS(5883),
    [anon_sym_WITH] = ACTIONS(5883),
    [anon_sym_With] = ACTIONS(5883),
    [sym_asserterror_keyword] = ACTIONS(5885),
    [sym_page_keyword] = ACTIONS(5883),
    [anon_sym_codeunit] = ACTIONS(5883),
    [anon_sym_CODEUNIT] = ACTIONS(5883),
    [anon_sym_Codeunit] = ACTIONS(5883),
    [anon_sym_CodeUnit] = ACTIONS(5883),
    [anon_sym_COdeunit] = ACTIONS(5883),
    [anon_sym_codeUnit] = ACTIONS(5883),
    [sym_report_keyword] = ACTIONS(5883),
    [sym_query_keyword] = ACTIONS(5883),
    [anon_sym_xmlport] = ACTIONS(5883),
    [anon_sym_XMLPORT] = ACTIONS(5883),
    [anon_sym_Xmlport] = ACTIONS(5883),
    [anon_sym_XMLport] = ACTIONS(5883),
    [anon_sym_XMLPort] = ACTIONS(5883),
    [anon_sym_XmlPort] = ACTIONS(5883),
    [anon_sym_enum] = ACTIONS(5883),
    [anon_sym_ENUM] = ACTIONS(5883),
    [anon_sym_Enum] = ACTIONS(5883),
    [anon_sym_eNUM] = ACTIONS(5883),
    [anon_sym_eNum] = ACTIONS(5883),
    [anon_sym_ENum] = ACTIONS(5883),
    [sym_quoted_identifier] = ACTIONS(5885),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5885),
    [sym_verbatim_string] = ACTIONS(5885),
    [sym_integer] = ACTIONS(5883),
    [sym_continue_as_identifier] = ACTIONS(5885),
    [sym_preproc_open] = ACTIONS(5885),
    [sym_preproc_close] = ACTIONS(5885),
  },
  [STATE(2478)] = {
    [sym_identifier] = ACTIONS(5887),
    [anon_sym_SEMI] = ACTIONS(5889),
    [anon_sym_DASH] = ACTIONS(5889),
    [aux_sym_boolean_token1] = ACTIONS(5887),
    [aux_sym_boolean_token2] = ACTIONS(5887),
    [sym_decimal] = ACTIONS(5887),
    [anon_sym_LPAREN] = ACTIONS(5889),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5887),
    [anon_sym_LBRACK] = ACTIONS(5889),
    [aux_sym_record_type_token1] = ACTIONS(5887),
    [aux_sym_basic_type_token21] = ACTIONS(5887),
    [aux_sym_basic_type_token22] = ACTIONS(5887),
    [aux_sym_basic_type_token48] = ACTIONS(5887),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5887),
    [anon_sym_POUNDif] = ACTIONS(5889),
    [anon_sym_POUNDIF] = ACTIONS(5889),
    [anon_sym_POUNDIf] = ACTIONS(5889),
    [anon_sym_not] = ACTIONS(5887),
    [anon_sym_NOT] = ACTIONS(5887),
    [anon_sym_Not] = ACTIONS(5887),
    [anon_sym_POUNDelif] = ACTIONS(5889),
    [anon_sym_POUNDELIF] = ACTIONS(5889),
    [anon_sym_POUNDElif] = ACTIONS(5889),
    [anon_sym_POUNDelse] = ACTIONS(5889),
    [anon_sym_POUNDELSE] = ACTIONS(5889),
    [anon_sym_POUNDElse] = ACTIONS(5889),
    [anon_sym_POUNDelse2] = ACTIONS(5889),
    [anon_sym_POUNDELSE2] = ACTIONS(5889),
    [anon_sym_POUNDElse2] = ACTIONS(5889),
    [anon_sym_POUNDendif] = ACTIONS(5889),
    [anon_sym_POUNDENDIF] = ACTIONS(5889),
    [anon_sym_POUNDEndif] = ACTIONS(5889),
    [anon_sym_POUNDendif2] = ACTIONS(5889),
    [anon_sym_POUNDENDIF2] = ACTIONS(5889),
    [anon_sym_POUNDEndif2] = ACTIONS(5889),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5887),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5887),
    [anon_sym_PLUS] = ACTIONS(5889),
    [sym_datetime_literal] = ACTIONS(5889),
    [sym_date_literal] = ACTIONS(5887),
    [sym_time_literal] = ACTIONS(5887),
    [sym_biginteger_literal] = ACTIONS(5889),
    [anon_sym_if] = ACTIONS(5887),
    [anon_sym_IF] = ACTIONS(5887),
    [anon_sym_If] = ACTIONS(5887),
    [anon_sym_else] = ACTIONS(5887),
    [anon_sym_ELSE] = ACTIONS(5887),
    [anon_sym_Else] = ACTIONS(5887),
    [anon_sym_case] = ACTIONS(5887),
    [anon_sym_CASE] = ACTIONS(5887),
    [anon_sym_Case] = ACTIONS(5887),
    [anon_sym_for] = ACTIONS(5887),
    [anon_sym_FOR] = ACTIONS(5887),
    [anon_sym_For] = ACTIONS(5887),
    [anon_sym_foreach] = ACTIONS(5887),
    [anon_sym_FOREACH] = ACTIONS(5887),
    [anon_sym_Foreach] = ACTIONS(5887),
    [anon_sym_while] = ACTIONS(5887),
    [anon_sym_WHILE] = ACTIONS(5887),
    [anon_sym_While] = ACTIONS(5887),
    [anon_sym_repeat] = ACTIONS(5887),
    [anon_sym_REPEAT] = ACTIONS(5887),
    [anon_sym_Repeat] = ACTIONS(5887),
    [anon_sym_exit] = ACTIONS(5887),
    [anon_sym_EXIT] = ACTIONS(5887),
    [anon_sym_Exit] = ACTIONS(5887),
    [anon_sym_continue] = ACTIONS(5887),
    [anon_sym_CONTINUE] = ACTIONS(5887),
    [anon_sym_Continue] = ACTIONS(5887),
    [anon_sym_break] = ACTIONS(5887),
    [anon_sym_BREAK] = ACTIONS(5887),
    [anon_sym_Break] = ACTIONS(5887),
    [anon_sym_with] = ACTIONS(5887),
    [anon_sym_WITH] = ACTIONS(5887),
    [anon_sym_With] = ACTIONS(5887),
    [sym_asserterror_keyword] = ACTIONS(5889),
    [sym_page_keyword] = ACTIONS(5887),
    [anon_sym_codeunit] = ACTIONS(5887),
    [anon_sym_CODEUNIT] = ACTIONS(5887),
    [anon_sym_Codeunit] = ACTIONS(5887),
    [anon_sym_CodeUnit] = ACTIONS(5887),
    [anon_sym_COdeunit] = ACTIONS(5887),
    [anon_sym_codeUnit] = ACTIONS(5887),
    [sym_report_keyword] = ACTIONS(5887),
    [sym_query_keyword] = ACTIONS(5887),
    [anon_sym_xmlport] = ACTIONS(5887),
    [anon_sym_XMLPORT] = ACTIONS(5887),
    [anon_sym_Xmlport] = ACTIONS(5887),
    [anon_sym_XMLport] = ACTIONS(5887),
    [anon_sym_XMLPort] = ACTIONS(5887),
    [anon_sym_XmlPort] = ACTIONS(5887),
    [anon_sym_enum] = ACTIONS(5887),
    [anon_sym_ENUM] = ACTIONS(5887),
    [anon_sym_Enum] = ACTIONS(5887),
    [anon_sym_eNUM] = ACTIONS(5887),
    [anon_sym_eNum] = ACTIONS(5887),
    [anon_sym_ENum] = ACTIONS(5887),
    [sym_quoted_identifier] = ACTIONS(5889),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5889),
    [sym_verbatim_string] = ACTIONS(5889),
    [sym_integer] = ACTIONS(5887),
    [sym_continue_as_identifier] = ACTIONS(5889),
    [sym_preproc_open] = ACTIONS(5889),
    [sym_preproc_close] = ACTIONS(5889),
  },
  [STATE(2479)] = {
    [sym_identifier] = ACTIONS(5891),
    [anon_sym_SEMI] = ACTIONS(5893),
    [anon_sym_DASH] = ACTIONS(5893),
    [aux_sym_boolean_token1] = ACTIONS(5891),
    [aux_sym_boolean_token2] = ACTIONS(5891),
    [sym_decimal] = ACTIONS(5891),
    [anon_sym_LPAREN] = ACTIONS(5893),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5891),
    [anon_sym_LBRACK] = ACTIONS(5893),
    [aux_sym_record_type_token1] = ACTIONS(5891),
    [aux_sym_basic_type_token21] = ACTIONS(5891),
    [aux_sym_basic_type_token22] = ACTIONS(5891),
    [aux_sym_basic_type_token48] = ACTIONS(5891),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5891),
    [anon_sym_POUNDif] = ACTIONS(5893),
    [anon_sym_POUNDIF] = ACTIONS(5893),
    [anon_sym_POUNDIf] = ACTIONS(5893),
    [anon_sym_not] = ACTIONS(5891),
    [anon_sym_NOT] = ACTIONS(5891),
    [anon_sym_Not] = ACTIONS(5891),
    [anon_sym_POUNDelif] = ACTIONS(5893),
    [anon_sym_POUNDELIF] = ACTIONS(5893),
    [anon_sym_POUNDElif] = ACTIONS(5893),
    [anon_sym_POUNDelse] = ACTIONS(5893),
    [anon_sym_POUNDELSE] = ACTIONS(5893),
    [anon_sym_POUNDElse] = ACTIONS(5893),
    [anon_sym_POUNDelse2] = ACTIONS(5893),
    [anon_sym_POUNDELSE2] = ACTIONS(5893),
    [anon_sym_POUNDElse2] = ACTIONS(5893),
    [anon_sym_POUNDendif] = ACTIONS(5893),
    [anon_sym_POUNDENDIF] = ACTIONS(5893),
    [anon_sym_POUNDEndif] = ACTIONS(5893),
    [anon_sym_POUNDendif2] = ACTIONS(5893),
    [anon_sym_POUNDENDIF2] = ACTIONS(5893),
    [anon_sym_POUNDEndif2] = ACTIONS(5893),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5891),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5891),
    [anon_sym_PLUS] = ACTIONS(5893),
    [sym_datetime_literal] = ACTIONS(5893),
    [sym_date_literal] = ACTIONS(5891),
    [sym_time_literal] = ACTIONS(5891),
    [sym_biginteger_literal] = ACTIONS(5893),
    [anon_sym_if] = ACTIONS(5891),
    [anon_sym_IF] = ACTIONS(5891),
    [anon_sym_If] = ACTIONS(5891),
    [anon_sym_else] = ACTIONS(5891),
    [anon_sym_ELSE] = ACTIONS(5891),
    [anon_sym_Else] = ACTIONS(5891),
    [anon_sym_case] = ACTIONS(5891),
    [anon_sym_CASE] = ACTIONS(5891),
    [anon_sym_Case] = ACTIONS(5891),
    [anon_sym_for] = ACTIONS(5891),
    [anon_sym_FOR] = ACTIONS(5891),
    [anon_sym_For] = ACTIONS(5891),
    [anon_sym_foreach] = ACTIONS(5891),
    [anon_sym_FOREACH] = ACTIONS(5891),
    [anon_sym_Foreach] = ACTIONS(5891),
    [anon_sym_while] = ACTIONS(5891),
    [anon_sym_WHILE] = ACTIONS(5891),
    [anon_sym_While] = ACTIONS(5891),
    [anon_sym_repeat] = ACTIONS(5891),
    [anon_sym_REPEAT] = ACTIONS(5891),
    [anon_sym_Repeat] = ACTIONS(5891),
    [anon_sym_exit] = ACTIONS(5891),
    [anon_sym_EXIT] = ACTIONS(5891),
    [anon_sym_Exit] = ACTIONS(5891),
    [anon_sym_continue] = ACTIONS(5891),
    [anon_sym_CONTINUE] = ACTIONS(5891),
    [anon_sym_Continue] = ACTIONS(5891),
    [anon_sym_break] = ACTIONS(5891),
    [anon_sym_BREAK] = ACTIONS(5891),
    [anon_sym_Break] = ACTIONS(5891),
    [anon_sym_with] = ACTIONS(5891),
    [anon_sym_WITH] = ACTIONS(5891),
    [anon_sym_With] = ACTIONS(5891),
    [sym_asserterror_keyword] = ACTIONS(5893),
    [sym_page_keyword] = ACTIONS(5891),
    [anon_sym_codeunit] = ACTIONS(5891),
    [anon_sym_CODEUNIT] = ACTIONS(5891),
    [anon_sym_Codeunit] = ACTIONS(5891),
    [anon_sym_CodeUnit] = ACTIONS(5891),
    [anon_sym_COdeunit] = ACTIONS(5891),
    [anon_sym_codeUnit] = ACTIONS(5891),
    [sym_report_keyword] = ACTIONS(5891),
    [sym_query_keyword] = ACTIONS(5891),
    [anon_sym_xmlport] = ACTIONS(5891),
    [anon_sym_XMLPORT] = ACTIONS(5891),
    [anon_sym_Xmlport] = ACTIONS(5891),
    [anon_sym_XMLport] = ACTIONS(5891),
    [anon_sym_XMLPort] = ACTIONS(5891),
    [anon_sym_XmlPort] = ACTIONS(5891),
    [anon_sym_enum] = ACTIONS(5891),
    [anon_sym_ENUM] = ACTIONS(5891),
    [anon_sym_Enum] = ACTIONS(5891),
    [anon_sym_eNUM] = ACTIONS(5891),
    [anon_sym_eNum] = ACTIONS(5891),
    [anon_sym_ENum] = ACTIONS(5891),
    [sym_quoted_identifier] = ACTIONS(5893),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5893),
    [sym_verbatim_string] = ACTIONS(5893),
    [sym_integer] = ACTIONS(5891),
    [sym_continue_as_identifier] = ACTIONS(5893),
    [sym_preproc_open] = ACTIONS(5893),
    [sym_preproc_close] = ACTIONS(5893),
  },
  [STATE(2480)] = {
    [sym_identifier] = ACTIONS(5895),
    [anon_sym_SEMI] = ACTIONS(5897),
    [anon_sym_DASH] = ACTIONS(5897),
    [aux_sym_boolean_token1] = ACTIONS(5895),
    [aux_sym_boolean_token2] = ACTIONS(5895),
    [sym_decimal] = ACTIONS(5895),
    [anon_sym_LPAREN] = ACTIONS(5897),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5895),
    [anon_sym_LBRACK] = ACTIONS(5897),
    [aux_sym_record_type_token1] = ACTIONS(5895),
    [aux_sym_basic_type_token21] = ACTIONS(5895),
    [aux_sym_basic_type_token22] = ACTIONS(5895),
    [aux_sym_basic_type_token48] = ACTIONS(5895),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5895),
    [anon_sym_POUNDif] = ACTIONS(5897),
    [anon_sym_POUNDIF] = ACTIONS(5897),
    [anon_sym_POUNDIf] = ACTIONS(5897),
    [anon_sym_not] = ACTIONS(5895),
    [anon_sym_NOT] = ACTIONS(5895),
    [anon_sym_Not] = ACTIONS(5895),
    [anon_sym_POUNDelif] = ACTIONS(5897),
    [anon_sym_POUNDELIF] = ACTIONS(5897),
    [anon_sym_POUNDElif] = ACTIONS(5897),
    [anon_sym_POUNDelse] = ACTIONS(5897),
    [anon_sym_POUNDELSE] = ACTIONS(5897),
    [anon_sym_POUNDElse] = ACTIONS(5897),
    [anon_sym_POUNDelse2] = ACTIONS(5897),
    [anon_sym_POUNDELSE2] = ACTIONS(5897),
    [anon_sym_POUNDElse2] = ACTIONS(5897),
    [anon_sym_POUNDendif] = ACTIONS(5897),
    [anon_sym_POUNDENDIF] = ACTIONS(5897),
    [anon_sym_POUNDEndif] = ACTIONS(5897),
    [anon_sym_POUNDendif2] = ACTIONS(5897),
    [anon_sym_POUNDENDIF2] = ACTIONS(5897),
    [anon_sym_POUNDEndif2] = ACTIONS(5897),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5895),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5895),
    [anon_sym_PLUS] = ACTIONS(5897),
    [sym_datetime_literal] = ACTIONS(5897),
    [sym_date_literal] = ACTIONS(5895),
    [sym_time_literal] = ACTIONS(5895),
    [sym_biginteger_literal] = ACTIONS(5897),
    [anon_sym_if] = ACTIONS(5895),
    [anon_sym_IF] = ACTIONS(5895),
    [anon_sym_If] = ACTIONS(5895),
    [anon_sym_else] = ACTIONS(5895),
    [anon_sym_ELSE] = ACTIONS(5895),
    [anon_sym_Else] = ACTIONS(5895),
    [anon_sym_case] = ACTIONS(5895),
    [anon_sym_CASE] = ACTIONS(5895),
    [anon_sym_Case] = ACTIONS(5895),
    [anon_sym_for] = ACTIONS(5895),
    [anon_sym_FOR] = ACTIONS(5895),
    [anon_sym_For] = ACTIONS(5895),
    [anon_sym_foreach] = ACTIONS(5895),
    [anon_sym_FOREACH] = ACTIONS(5895),
    [anon_sym_Foreach] = ACTIONS(5895),
    [anon_sym_while] = ACTIONS(5895),
    [anon_sym_WHILE] = ACTIONS(5895),
    [anon_sym_While] = ACTIONS(5895),
    [anon_sym_repeat] = ACTIONS(5895),
    [anon_sym_REPEAT] = ACTIONS(5895),
    [anon_sym_Repeat] = ACTIONS(5895),
    [anon_sym_exit] = ACTIONS(5895),
    [anon_sym_EXIT] = ACTIONS(5895),
    [anon_sym_Exit] = ACTIONS(5895),
    [anon_sym_continue] = ACTIONS(5895),
    [anon_sym_CONTINUE] = ACTIONS(5895),
    [anon_sym_Continue] = ACTIONS(5895),
    [anon_sym_break] = ACTIONS(5895),
    [anon_sym_BREAK] = ACTIONS(5895),
    [anon_sym_Break] = ACTIONS(5895),
    [anon_sym_with] = ACTIONS(5895),
    [anon_sym_WITH] = ACTIONS(5895),
    [anon_sym_With] = ACTIONS(5895),
    [sym_asserterror_keyword] = ACTIONS(5897),
    [sym_page_keyword] = ACTIONS(5895),
    [anon_sym_codeunit] = ACTIONS(5895),
    [anon_sym_CODEUNIT] = ACTIONS(5895),
    [anon_sym_Codeunit] = ACTIONS(5895),
    [anon_sym_CodeUnit] = ACTIONS(5895),
    [anon_sym_COdeunit] = ACTIONS(5895),
    [anon_sym_codeUnit] = ACTIONS(5895),
    [sym_report_keyword] = ACTIONS(5895),
    [sym_query_keyword] = ACTIONS(5895),
    [anon_sym_xmlport] = ACTIONS(5895),
    [anon_sym_XMLPORT] = ACTIONS(5895),
    [anon_sym_Xmlport] = ACTIONS(5895),
    [anon_sym_XMLport] = ACTIONS(5895),
    [anon_sym_XMLPort] = ACTIONS(5895),
    [anon_sym_XmlPort] = ACTIONS(5895),
    [anon_sym_enum] = ACTIONS(5895),
    [anon_sym_ENUM] = ACTIONS(5895),
    [anon_sym_Enum] = ACTIONS(5895),
    [anon_sym_eNUM] = ACTIONS(5895),
    [anon_sym_eNum] = ACTIONS(5895),
    [anon_sym_ENum] = ACTIONS(5895),
    [sym_quoted_identifier] = ACTIONS(5897),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5897),
    [sym_verbatim_string] = ACTIONS(5897),
    [sym_integer] = ACTIONS(5895),
    [sym_continue_as_identifier] = ACTIONS(5897),
    [sym_preproc_open] = ACTIONS(5897),
    [sym_preproc_close] = ACTIONS(5897),
  },
  [STATE(2481)] = {
    [sym_identifier] = ACTIONS(5899),
    [anon_sym_SEMI] = ACTIONS(5901),
    [anon_sym_DASH] = ACTIONS(5901),
    [aux_sym_boolean_token1] = ACTIONS(5899),
    [aux_sym_boolean_token2] = ACTIONS(5899),
    [sym_decimal] = ACTIONS(5899),
    [anon_sym_LPAREN] = ACTIONS(5901),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5899),
    [anon_sym_LBRACK] = ACTIONS(5901),
    [aux_sym_record_type_token1] = ACTIONS(5899),
    [aux_sym_basic_type_token21] = ACTIONS(5899),
    [aux_sym_basic_type_token22] = ACTIONS(5899),
    [aux_sym_basic_type_token48] = ACTIONS(5899),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5899),
    [anon_sym_POUNDif] = ACTIONS(5901),
    [anon_sym_POUNDIF] = ACTIONS(5901),
    [anon_sym_POUNDIf] = ACTIONS(5901),
    [anon_sym_not] = ACTIONS(5899),
    [anon_sym_NOT] = ACTIONS(5899),
    [anon_sym_Not] = ACTIONS(5899),
    [anon_sym_POUNDelif] = ACTIONS(5901),
    [anon_sym_POUNDELIF] = ACTIONS(5901),
    [anon_sym_POUNDElif] = ACTIONS(5901),
    [anon_sym_POUNDelse] = ACTIONS(5901),
    [anon_sym_POUNDELSE] = ACTIONS(5901),
    [anon_sym_POUNDElse] = ACTIONS(5901),
    [anon_sym_POUNDelse2] = ACTIONS(5901),
    [anon_sym_POUNDELSE2] = ACTIONS(5901),
    [anon_sym_POUNDElse2] = ACTIONS(5901),
    [anon_sym_POUNDendif] = ACTIONS(5901),
    [anon_sym_POUNDENDIF] = ACTIONS(5901),
    [anon_sym_POUNDEndif] = ACTIONS(5901),
    [anon_sym_POUNDendif2] = ACTIONS(5901),
    [anon_sym_POUNDENDIF2] = ACTIONS(5901),
    [anon_sym_POUNDEndif2] = ACTIONS(5901),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5899),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5899),
    [anon_sym_PLUS] = ACTIONS(5901),
    [sym_datetime_literal] = ACTIONS(5901),
    [sym_date_literal] = ACTIONS(5899),
    [sym_time_literal] = ACTIONS(5899),
    [sym_biginteger_literal] = ACTIONS(5901),
    [anon_sym_if] = ACTIONS(5899),
    [anon_sym_IF] = ACTIONS(5899),
    [anon_sym_If] = ACTIONS(5899),
    [anon_sym_else] = ACTIONS(5899),
    [anon_sym_ELSE] = ACTIONS(5899),
    [anon_sym_Else] = ACTIONS(5899),
    [anon_sym_case] = ACTIONS(5899),
    [anon_sym_CASE] = ACTIONS(5899),
    [anon_sym_Case] = ACTIONS(5899),
    [anon_sym_for] = ACTIONS(5899),
    [anon_sym_FOR] = ACTIONS(5899),
    [anon_sym_For] = ACTIONS(5899),
    [anon_sym_foreach] = ACTIONS(5899),
    [anon_sym_FOREACH] = ACTIONS(5899),
    [anon_sym_Foreach] = ACTIONS(5899),
    [anon_sym_while] = ACTIONS(5899),
    [anon_sym_WHILE] = ACTIONS(5899),
    [anon_sym_While] = ACTIONS(5899),
    [anon_sym_repeat] = ACTIONS(5899),
    [anon_sym_REPEAT] = ACTIONS(5899),
    [anon_sym_Repeat] = ACTIONS(5899),
    [anon_sym_exit] = ACTIONS(5899),
    [anon_sym_EXIT] = ACTIONS(5899),
    [anon_sym_Exit] = ACTIONS(5899),
    [anon_sym_continue] = ACTIONS(5899),
    [anon_sym_CONTINUE] = ACTIONS(5899),
    [anon_sym_Continue] = ACTIONS(5899),
    [anon_sym_break] = ACTIONS(5899),
    [anon_sym_BREAK] = ACTIONS(5899),
    [anon_sym_Break] = ACTIONS(5899),
    [anon_sym_with] = ACTIONS(5899),
    [anon_sym_WITH] = ACTIONS(5899),
    [anon_sym_With] = ACTIONS(5899),
    [sym_asserterror_keyword] = ACTIONS(5901),
    [sym_page_keyword] = ACTIONS(5899),
    [anon_sym_codeunit] = ACTIONS(5899),
    [anon_sym_CODEUNIT] = ACTIONS(5899),
    [anon_sym_Codeunit] = ACTIONS(5899),
    [anon_sym_CodeUnit] = ACTIONS(5899),
    [anon_sym_COdeunit] = ACTIONS(5899),
    [anon_sym_codeUnit] = ACTIONS(5899),
    [sym_report_keyword] = ACTIONS(5899),
    [sym_query_keyword] = ACTIONS(5899),
    [anon_sym_xmlport] = ACTIONS(5899),
    [anon_sym_XMLPORT] = ACTIONS(5899),
    [anon_sym_Xmlport] = ACTIONS(5899),
    [anon_sym_XMLport] = ACTIONS(5899),
    [anon_sym_XMLPort] = ACTIONS(5899),
    [anon_sym_XmlPort] = ACTIONS(5899),
    [anon_sym_enum] = ACTIONS(5899),
    [anon_sym_ENUM] = ACTIONS(5899),
    [anon_sym_Enum] = ACTIONS(5899),
    [anon_sym_eNUM] = ACTIONS(5899),
    [anon_sym_eNum] = ACTIONS(5899),
    [anon_sym_ENum] = ACTIONS(5899),
    [sym_quoted_identifier] = ACTIONS(5901),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5901),
    [sym_verbatim_string] = ACTIONS(5901),
    [sym_integer] = ACTIONS(5899),
    [sym_continue_as_identifier] = ACTIONS(5901),
    [sym_preproc_open] = ACTIONS(5901),
    [sym_preproc_close] = ACTIONS(5901),
  },
  [STATE(2482)] = {
    [sym_identifier] = ACTIONS(5903),
    [anon_sym_SEMI] = ACTIONS(5905),
    [anon_sym_DASH] = ACTIONS(5905),
    [aux_sym_boolean_token1] = ACTIONS(5903),
    [aux_sym_boolean_token2] = ACTIONS(5903),
    [sym_decimal] = ACTIONS(5903),
    [anon_sym_LPAREN] = ACTIONS(5905),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5903),
    [anon_sym_LBRACK] = ACTIONS(5905),
    [aux_sym_record_type_token1] = ACTIONS(5903),
    [aux_sym_basic_type_token21] = ACTIONS(5903),
    [aux_sym_basic_type_token22] = ACTIONS(5903),
    [aux_sym_basic_type_token48] = ACTIONS(5903),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5903),
    [anon_sym_POUNDif] = ACTIONS(5905),
    [anon_sym_POUNDIF] = ACTIONS(5905),
    [anon_sym_POUNDIf] = ACTIONS(5905),
    [anon_sym_not] = ACTIONS(5903),
    [anon_sym_NOT] = ACTIONS(5903),
    [anon_sym_Not] = ACTIONS(5903),
    [anon_sym_POUNDelif] = ACTIONS(5905),
    [anon_sym_POUNDELIF] = ACTIONS(5905),
    [anon_sym_POUNDElif] = ACTIONS(5905),
    [anon_sym_POUNDelse] = ACTIONS(5905),
    [anon_sym_POUNDELSE] = ACTIONS(5905),
    [anon_sym_POUNDElse] = ACTIONS(5905),
    [anon_sym_POUNDelse2] = ACTIONS(5905),
    [anon_sym_POUNDELSE2] = ACTIONS(5905),
    [anon_sym_POUNDElse2] = ACTIONS(5905),
    [anon_sym_POUNDendif] = ACTIONS(5905),
    [anon_sym_POUNDENDIF] = ACTIONS(5905),
    [anon_sym_POUNDEndif] = ACTIONS(5905),
    [anon_sym_POUNDendif2] = ACTIONS(5905),
    [anon_sym_POUNDENDIF2] = ACTIONS(5905),
    [anon_sym_POUNDEndif2] = ACTIONS(5905),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5903),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5903),
    [anon_sym_PLUS] = ACTIONS(5905),
    [sym_datetime_literal] = ACTIONS(5905),
    [sym_date_literal] = ACTIONS(5903),
    [sym_time_literal] = ACTIONS(5903),
    [sym_biginteger_literal] = ACTIONS(5905),
    [anon_sym_if] = ACTIONS(5903),
    [anon_sym_IF] = ACTIONS(5903),
    [anon_sym_If] = ACTIONS(5903),
    [anon_sym_else] = ACTIONS(5903),
    [anon_sym_ELSE] = ACTIONS(5903),
    [anon_sym_Else] = ACTIONS(5903),
    [anon_sym_case] = ACTIONS(5903),
    [anon_sym_CASE] = ACTIONS(5903),
    [anon_sym_Case] = ACTIONS(5903),
    [anon_sym_for] = ACTIONS(5903),
    [anon_sym_FOR] = ACTIONS(5903),
    [anon_sym_For] = ACTIONS(5903),
    [anon_sym_foreach] = ACTIONS(5903),
    [anon_sym_FOREACH] = ACTIONS(5903),
    [anon_sym_Foreach] = ACTIONS(5903),
    [anon_sym_while] = ACTIONS(5903),
    [anon_sym_WHILE] = ACTIONS(5903),
    [anon_sym_While] = ACTIONS(5903),
    [anon_sym_repeat] = ACTIONS(5903),
    [anon_sym_REPEAT] = ACTIONS(5903),
    [anon_sym_Repeat] = ACTIONS(5903),
    [anon_sym_exit] = ACTIONS(5903),
    [anon_sym_EXIT] = ACTIONS(5903),
    [anon_sym_Exit] = ACTIONS(5903),
    [anon_sym_continue] = ACTIONS(5903),
    [anon_sym_CONTINUE] = ACTIONS(5903),
    [anon_sym_Continue] = ACTIONS(5903),
    [anon_sym_break] = ACTIONS(5903),
    [anon_sym_BREAK] = ACTIONS(5903),
    [anon_sym_Break] = ACTIONS(5903),
    [anon_sym_with] = ACTIONS(5903),
    [anon_sym_WITH] = ACTIONS(5903),
    [anon_sym_With] = ACTIONS(5903),
    [sym_asserterror_keyword] = ACTIONS(5905),
    [sym_page_keyword] = ACTIONS(5903),
    [anon_sym_codeunit] = ACTIONS(5903),
    [anon_sym_CODEUNIT] = ACTIONS(5903),
    [anon_sym_Codeunit] = ACTIONS(5903),
    [anon_sym_CodeUnit] = ACTIONS(5903),
    [anon_sym_COdeunit] = ACTIONS(5903),
    [anon_sym_codeUnit] = ACTIONS(5903),
    [sym_report_keyword] = ACTIONS(5903),
    [sym_query_keyword] = ACTIONS(5903),
    [anon_sym_xmlport] = ACTIONS(5903),
    [anon_sym_XMLPORT] = ACTIONS(5903),
    [anon_sym_Xmlport] = ACTIONS(5903),
    [anon_sym_XMLport] = ACTIONS(5903),
    [anon_sym_XMLPort] = ACTIONS(5903),
    [anon_sym_XmlPort] = ACTIONS(5903),
    [anon_sym_enum] = ACTIONS(5903),
    [anon_sym_ENUM] = ACTIONS(5903),
    [anon_sym_Enum] = ACTIONS(5903),
    [anon_sym_eNUM] = ACTIONS(5903),
    [anon_sym_eNum] = ACTIONS(5903),
    [anon_sym_ENum] = ACTIONS(5903),
    [sym_quoted_identifier] = ACTIONS(5905),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5905),
    [sym_verbatim_string] = ACTIONS(5905),
    [sym_integer] = ACTIONS(5903),
    [sym_continue_as_identifier] = ACTIONS(5905),
    [sym_preproc_open] = ACTIONS(5905),
    [sym_preproc_close] = ACTIONS(5905),
  },
  [STATE(2483)] = {
    [sym_identifier] = ACTIONS(5907),
    [anon_sym_SEMI] = ACTIONS(5909),
    [anon_sym_DASH] = ACTIONS(5909),
    [aux_sym_boolean_token1] = ACTIONS(5907),
    [aux_sym_boolean_token2] = ACTIONS(5907),
    [sym_decimal] = ACTIONS(5907),
    [anon_sym_LPAREN] = ACTIONS(5909),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5907),
    [anon_sym_LBRACK] = ACTIONS(5909),
    [aux_sym_record_type_token1] = ACTIONS(5907),
    [aux_sym_basic_type_token21] = ACTIONS(5907),
    [aux_sym_basic_type_token22] = ACTIONS(5907),
    [aux_sym_basic_type_token48] = ACTIONS(5907),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5907),
    [anon_sym_POUNDif] = ACTIONS(5909),
    [anon_sym_POUNDIF] = ACTIONS(5909),
    [anon_sym_POUNDIf] = ACTIONS(5909),
    [anon_sym_not] = ACTIONS(5907),
    [anon_sym_NOT] = ACTIONS(5907),
    [anon_sym_Not] = ACTIONS(5907),
    [anon_sym_POUNDelif] = ACTIONS(5909),
    [anon_sym_POUNDELIF] = ACTIONS(5909),
    [anon_sym_POUNDElif] = ACTIONS(5909),
    [anon_sym_POUNDelse] = ACTIONS(5909),
    [anon_sym_POUNDELSE] = ACTIONS(5909),
    [anon_sym_POUNDElse] = ACTIONS(5909),
    [anon_sym_POUNDelse2] = ACTIONS(5909),
    [anon_sym_POUNDELSE2] = ACTIONS(5909),
    [anon_sym_POUNDElse2] = ACTIONS(5909),
    [anon_sym_POUNDendif] = ACTIONS(5909),
    [anon_sym_POUNDENDIF] = ACTIONS(5909),
    [anon_sym_POUNDEndif] = ACTIONS(5909),
    [anon_sym_POUNDendif2] = ACTIONS(5909),
    [anon_sym_POUNDENDIF2] = ACTIONS(5909),
    [anon_sym_POUNDEndif2] = ACTIONS(5909),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5907),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5907),
    [anon_sym_PLUS] = ACTIONS(5909),
    [sym_datetime_literal] = ACTIONS(5909),
    [sym_date_literal] = ACTIONS(5907),
    [sym_time_literal] = ACTIONS(5907),
    [sym_biginteger_literal] = ACTIONS(5909),
    [anon_sym_if] = ACTIONS(5907),
    [anon_sym_IF] = ACTIONS(5907),
    [anon_sym_If] = ACTIONS(5907),
    [anon_sym_else] = ACTIONS(5907),
    [anon_sym_ELSE] = ACTIONS(5907),
    [anon_sym_Else] = ACTIONS(5907),
    [anon_sym_case] = ACTIONS(5907),
    [anon_sym_CASE] = ACTIONS(5907),
    [anon_sym_Case] = ACTIONS(5907),
    [anon_sym_for] = ACTIONS(5907),
    [anon_sym_FOR] = ACTIONS(5907),
    [anon_sym_For] = ACTIONS(5907),
    [anon_sym_foreach] = ACTIONS(5907),
    [anon_sym_FOREACH] = ACTIONS(5907),
    [anon_sym_Foreach] = ACTIONS(5907),
    [anon_sym_while] = ACTIONS(5907),
    [anon_sym_WHILE] = ACTIONS(5907),
    [anon_sym_While] = ACTIONS(5907),
    [anon_sym_repeat] = ACTIONS(5907),
    [anon_sym_REPEAT] = ACTIONS(5907),
    [anon_sym_Repeat] = ACTIONS(5907),
    [anon_sym_exit] = ACTIONS(5907),
    [anon_sym_EXIT] = ACTIONS(5907),
    [anon_sym_Exit] = ACTIONS(5907),
    [anon_sym_continue] = ACTIONS(5907),
    [anon_sym_CONTINUE] = ACTIONS(5907),
    [anon_sym_Continue] = ACTIONS(5907),
    [anon_sym_break] = ACTIONS(5907),
    [anon_sym_BREAK] = ACTIONS(5907),
    [anon_sym_Break] = ACTIONS(5907),
    [anon_sym_with] = ACTIONS(5907),
    [anon_sym_WITH] = ACTIONS(5907),
    [anon_sym_With] = ACTIONS(5907),
    [sym_asserterror_keyword] = ACTIONS(5909),
    [sym_page_keyword] = ACTIONS(5907),
    [anon_sym_codeunit] = ACTIONS(5907),
    [anon_sym_CODEUNIT] = ACTIONS(5907),
    [anon_sym_Codeunit] = ACTIONS(5907),
    [anon_sym_CodeUnit] = ACTIONS(5907),
    [anon_sym_COdeunit] = ACTIONS(5907),
    [anon_sym_codeUnit] = ACTIONS(5907),
    [sym_report_keyword] = ACTIONS(5907),
    [sym_query_keyword] = ACTIONS(5907),
    [anon_sym_xmlport] = ACTIONS(5907),
    [anon_sym_XMLPORT] = ACTIONS(5907),
    [anon_sym_Xmlport] = ACTIONS(5907),
    [anon_sym_XMLport] = ACTIONS(5907),
    [anon_sym_XMLPort] = ACTIONS(5907),
    [anon_sym_XmlPort] = ACTIONS(5907),
    [anon_sym_enum] = ACTIONS(5907),
    [anon_sym_ENUM] = ACTIONS(5907),
    [anon_sym_Enum] = ACTIONS(5907),
    [anon_sym_eNUM] = ACTIONS(5907),
    [anon_sym_eNum] = ACTIONS(5907),
    [anon_sym_ENum] = ACTIONS(5907),
    [sym_quoted_identifier] = ACTIONS(5909),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5909),
    [sym_verbatim_string] = ACTIONS(5909),
    [sym_integer] = ACTIONS(5907),
    [sym_continue_as_identifier] = ACTIONS(5909),
    [sym_preproc_open] = ACTIONS(5909),
    [sym_preproc_close] = ACTIONS(5909),
  },
  [STATE(2484)] = {
    [sym_identifier] = ACTIONS(5911),
    [anon_sym_SEMI] = ACTIONS(5913),
    [anon_sym_DASH] = ACTIONS(5913),
    [aux_sym_boolean_token1] = ACTIONS(5911),
    [aux_sym_boolean_token2] = ACTIONS(5911),
    [sym_decimal] = ACTIONS(5911),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5911),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [aux_sym_record_type_token1] = ACTIONS(5911),
    [aux_sym_basic_type_token21] = ACTIONS(5911),
    [aux_sym_basic_type_token22] = ACTIONS(5911),
    [aux_sym_basic_type_token48] = ACTIONS(5911),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5911),
    [anon_sym_POUNDif] = ACTIONS(5913),
    [anon_sym_POUNDIF] = ACTIONS(5913),
    [anon_sym_POUNDIf] = ACTIONS(5913),
    [anon_sym_not] = ACTIONS(5911),
    [anon_sym_NOT] = ACTIONS(5911),
    [anon_sym_Not] = ACTIONS(5911),
    [anon_sym_POUNDelif] = ACTIONS(5913),
    [anon_sym_POUNDELIF] = ACTIONS(5913),
    [anon_sym_POUNDElif] = ACTIONS(5913),
    [anon_sym_POUNDelse] = ACTIONS(5913),
    [anon_sym_POUNDELSE] = ACTIONS(5913),
    [anon_sym_POUNDElse] = ACTIONS(5913),
    [anon_sym_POUNDelse2] = ACTIONS(5913),
    [anon_sym_POUNDELSE2] = ACTIONS(5913),
    [anon_sym_POUNDElse2] = ACTIONS(5913),
    [anon_sym_POUNDendif] = ACTIONS(5913),
    [anon_sym_POUNDENDIF] = ACTIONS(5913),
    [anon_sym_POUNDEndif] = ACTIONS(5913),
    [anon_sym_POUNDendif2] = ACTIONS(5913),
    [anon_sym_POUNDENDIF2] = ACTIONS(5913),
    [anon_sym_POUNDEndif2] = ACTIONS(5913),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5911),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5911),
    [anon_sym_PLUS] = ACTIONS(5913),
    [sym_datetime_literal] = ACTIONS(5913),
    [sym_date_literal] = ACTIONS(5911),
    [sym_time_literal] = ACTIONS(5911),
    [sym_biginteger_literal] = ACTIONS(5913),
    [anon_sym_if] = ACTIONS(5911),
    [anon_sym_IF] = ACTIONS(5911),
    [anon_sym_If] = ACTIONS(5911),
    [anon_sym_else] = ACTIONS(5911),
    [anon_sym_ELSE] = ACTIONS(5911),
    [anon_sym_Else] = ACTIONS(5911),
    [anon_sym_case] = ACTIONS(5911),
    [anon_sym_CASE] = ACTIONS(5911),
    [anon_sym_Case] = ACTIONS(5911),
    [anon_sym_for] = ACTIONS(5911),
    [anon_sym_FOR] = ACTIONS(5911),
    [anon_sym_For] = ACTIONS(5911),
    [anon_sym_foreach] = ACTIONS(5911),
    [anon_sym_FOREACH] = ACTIONS(5911),
    [anon_sym_Foreach] = ACTIONS(5911),
    [anon_sym_while] = ACTIONS(5911),
    [anon_sym_WHILE] = ACTIONS(5911),
    [anon_sym_While] = ACTIONS(5911),
    [anon_sym_repeat] = ACTIONS(5911),
    [anon_sym_REPEAT] = ACTIONS(5911),
    [anon_sym_Repeat] = ACTIONS(5911),
    [anon_sym_exit] = ACTIONS(5911),
    [anon_sym_EXIT] = ACTIONS(5911),
    [anon_sym_Exit] = ACTIONS(5911),
    [anon_sym_continue] = ACTIONS(5911),
    [anon_sym_CONTINUE] = ACTIONS(5911),
    [anon_sym_Continue] = ACTIONS(5911),
    [anon_sym_break] = ACTIONS(5911),
    [anon_sym_BREAK] = ACTIONS(5911),
    [anon_sym_Break] = ACTIONS(5911),
    [anon_sym_with] = ACTIONS(5911),
    [anon_sym_WITH] = ACTIONS(5911),
    [anon_sym_With] = ACTIONS(5911),
    [sym_asserterror_keyword] = ACTIONS(5913),
    [sym_page_keyword] = ACTIONS(5911),
    [anon_sym_codeunit] = ACTIONS(5911),
    [anon_sym_CODEUNIT] = ACTIONS(5911),
    [anon_sym_Codeunit] = ACTIONS(5911),
    [anon_sym_CodeUnit] = ACTIONS(5911),
    [anon_sym_COdeunit] = ACTIONS(5911),
    [anon_sym_codeUnit] = ACTIONS(5911),
    [sym_report_keyword] = ACTIONS(5911),
    [sym_query_keyword] = ACTIONS(5911),
    [anon_sym_xmlport] = ACTIONS(5911),
    [anon_sym_XMLPORT] = ACTIONS(5911),
    [anon_sym_Xmlport] = ACTIONS(5911),
    [anon_sym_XMLport] = ACTIONS(5911),
    [anon_sym_XMLPort] = ACTIONS(5911),
    [anon_sym_XmlPort] = ACTIONS(5911),
    [anon_sym_enum] = ACTIONS(5911),
    [anon_sym_ENUM] = ACTIONS(5911),
    [anon_sym_Enum] = ACTIONS(5911),
    [anon_sym_eNUM] = ACTIONS(5911),
    [anon_sym_eNum] = ACTIONS(5911),
    [anon_sym_ENum] = ACTIONS(5911),
    [sym_quoted_identifier] = ACTIONS(5913),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5913),
    [sym_verbatim_string] = ACTIONS(5913),
    [sym_integer] = ACTIONS(5911),
    [sym_continue_as_identifier] = ACTIONS(5913),
    [sym_preproc_open] = ACTIONS(5913),
    [sym_preproc_close] = ACTIONS(5913),
  },
  [STATE(2485)] = {
    [sym_identifier] = ACTIONS(5915),
    [anon_sym_SEMI] = ACTIONS(5917),
    [anon_sym_DASH] = ACTIONS(5917),
    [aux_sym_boolean_token1] = ACTIONS(5915),
    [aux_sym_boolean_token2] = ACTIONS(5915),
    [sym_decimal] = ACTIONS(5915),
    [anon_sym_LPAREN] = ACTIONS(5917),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5915),
    [anon_sym_LBRACK] = ACTIONS(5917),
    [aux_sym_record_type_token1] = ACTIONS(5915),
    [aux_sym_basic_type_token21] = ACTIONS(5915),
    [aux_sym_basic_type_token22] = ACTIONS(5915),
    [aux_sym_basic_type_token48] = ACTIONS(5915),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5915),
    [anon_sym_POUNDif] = ACTIONS(5917),
    [anon_sym_POUNDIF] = ACTIONS(5917),
    [anon_sym_POUNDIf] = ACTIONS(5917),
    [anon_sym_not] = ACTIONS(5915),
    [anon_sym_NOT] = ACTIONS(5915),
    [anon_sym_Not] = ACTIONS(5915),
    [anon_sym_POUNDelif] = ACTIONS(5917),
    [anon_sym_POUNDELIF] = ACTIONS(5917),
    [anon_sym_POUNDElif] = ACTIONS(5917),
    [anon_sym_POUNDelse] = ACTIONS(5917),
    [anon_sym_POUNDELSE] = ACTIONS(5917),
    [anon_sym_POUNDElse] = ACTIONS(5917),
    [anon_sym_POUNDelse2] = ACTIONS(5917),
    [anon_sym_POUNDELSE2] = ACTIONS(5917),
    [anon_sym_POUNDElse2] = ACTIONS(5917),
    [anon_sym_POUNDendif] = ACTIONS(5917),
    [anon_sym_POUNDENDIF] = ACTIONS(5917),
    [anon_sym_POUNDEndif] = ACTIONS(5917),
    [anon_sym_POUNDendif2] = ACTIONS(5917),
    [anon_sym_POUNDENDIF2] = ACTIONS(5917),
    [anon_sym_POUNDEndif2] = ACTIONS(5917),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5915),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5915),
    [anon_sym_PLUS] = ACTIONS(5917),
    [sym_datetime_literal] = ACTIONS(5917),
    [sym_date_literal] = ACTIONS(5915),
    [sym_time_literal] = ACTIONS(5915),
    [sym_biginteger_literal] = ACTIONS(5917),
    [anon_sym_if] = ACTIONS(5915),
    [anon_sym_IF] = ACTIONS(5915),
    [anon_sym_If] = ACTIONS(5915),
    [anon_sym_else] = ACTIONS(5915),
    [anon_sym_ELSE] = ACTIONS(5915),
    [anon_sym_Else] = ACTIONS(5915),
    [anon_sym_case] = ACTIONS(5915),
    [anon_sym_CASE] = ACTIONS(5915),
    [anon_sym_Case] = ACTIONS(5915),
    [anon_sym_for] = ACTIONS(5915),
    [anon_sym_FOR] = ACTIONS(5915),
    [anon_sym_For] = ACTIONS(5915),
    [anon_sym_foreach] = ACTIONS(5915),
    [anon_sym_FOREACH] = ACTIONS(5915),
    [anon_sym_Foreach] = ACTIONS(5915),
    [anon_sym_while] = ACTIONS(5915),
    [anon_sym_WHILE] = ACTIONS(5915),
    [anon_sym_While] = ACTIONS(5915),
    [anon_sym_repeat] = ACTIONS(5915),
    [anon_sym_REPEAT] = ACTIONS(5915),
    [anon_sym_Repeat] = ACTIONS(5915),
    [anon_sym_exit] = ACTIONS(5915),
    [anon_sym_EXIT] = ACTIONS(5915),
    [anon_sym_Exit] = ACTIONS(5915),
    [anon_sym_continue] = ACTIONS(5915),
    [anon_sym_CONTINUE] = ACTIONS(5915),
    [anon_sym_Continue] = ACTIONS(5915),
    [anon_sym_break] = ACTIONS(5915),
    [anon_sym_BREAK] = ACTIONS(5915),
    [anon_sym_Break] = ACTIONS(5915),
    [anon_sym_with] = ACTIONS(5915),
    [anon_sym_WITH] = ACTIONS(5915),
    [anon_sym_With] = ACTIONS(5915),
    [sym_asserterror_keyword] = ACTIONS(5917),
    [sym_page_keyword] = ACTIONS(5915),
    [anon_sym_codeunit] = ACTIONS(5915),
    [anon_sym_CODEUNIT] = ACTIONS(5915),
    [anon_sym_Codeunit] = ACTIONS(5915),
    [anon_sym_CodeUnit] = ACTIONS(5915),
    [anon_sym_COdeunit] = ACTIONS(5915),
    [anon_sym_codeUnit] = ACTIONS(5915),
    [sym_report_keyword] = ACTIONS(5915),
    [sym_query_keyword] = ACTIONS(5915),
    [anon_sym_xmlport] = ACTIONS(5915),
    [anon_sym_XMLPORT] = ACTIONS(5915),
    [anon_sym_Xmlport] = ACTIONS(5915),
    [anon_sym_XMLport] = ACTIONS(5915),
    [anon_sym_XMLPort] = ACTIONS(5915),
    [anon_sym_XmlPort] = ACTIONS(5915),
    [anon_sym_enum] = ACTIONS(5915),
    [anon_sym_ENUM] = ACTIONS(5915),
    [anon_sym_Enum] = ACTIONS(5915),
    [anon_sym_eNUM] = ACTIONS(5915),
    [anon_sym_eNum] = ACTIONS(5915),
    [anon_sym_ENum] = ACTIONS(5915),
    [sym_quoted_identifier] = ACTIONS(5917),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5917),
    [sym_verbatim_string] = ACTIONS(5917),
    [sym_integer] = ACTIONS(5915),
    [sym_continue_as_identifier] = ACTIONS(5917),
    [sym_preproc_open] = ACTIONS(5917),
    [sym_preproc_close] = ACTIONS(5917),
  },
  [STATE(2486)] = {
    [sym_identifier] = ACTIONS(5919),
    [anon_sym_SEMI] = ACTIONS(5921),
    [anon_sym_DASH] = ACTIONS(5921),
    [aux_sym_boolean_token1] = ACTIONS(5919),
    [aux_sym_boolean_token2] = ACTIONS(5919),
    [sym_decimal] = ACTIONS(5919),
    [anon_sym_LPAREN] = ACTIONS(5921),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5919),
    [anon_sym_LBRACK] = ACTIONS(5921),
    [aux_sym_record_type_token1] = ACTIONS(5919),
    [aux_sym_basic_type_token21] = ACTIONS(5919),
    [aux_sym_basic_type_token22] = ACTIONS(5919),
    [aux_sym_basic_type_token48] = ACTIONS(5919),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5919),
    [anon_sym_POUNDif] = ACTIONS(5921),
    [anon_sym_POUNDIF] = ACTIONS(5921),
    [anon_sym_POUNDIf] = ACTIONS(5921),
    [anon_sym_not] = ACTIONS(5919),
    [anon_sym_NOT] = ACTIONS(5919),
    [anon_sym_Not] = ACTIONS(5919),
    [anon_sym_POUNDelif] = ACTIONS(5921),
    [anon_sym_POUNDELIF] = ACTIONS(5921),
    [anon_sym_POUNDElif] = ACTIONS(5921),
    [anon_sym_POUNDelse] = ACTIONS(5921),
    [anon_sym_POUNDELSE] = ACTIONS(5921),
    [anon_sym_POUNDElse] = ACTIONS(5921),
    [anon_sym_POUNDelse2] = ACTIONS(5921),
    [anon_sym_POUNDELSE2] = ACTIONS(5921),
    [anon_sym_POUNDElse2] = ACTIONS(5921),
    [anon_sym_POUNDendif] = ACTIONS(5921),
    [anon_sym_POUNDENDIF] = ACTIONS(5921),
    [anon_sym_POUNDEndif] = ACTIONS(5921),
    [anon_sym_POUNDendif2] = ACTIONS(5921),
    [anon_sym_POUNDENDIF2] = ACTIONS(5921),
    [anon_sym_POUNDEndif2] = ACTIONS(5921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5919),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5919),
    [anon_sym_PLUS] = ACTIONS(5921),
    [sym_datetime_literal] = ACTIONS(5921),
    [sym_date_literal] = ACTIONS(5919),
    [sym_time_literal] = ACTIONS(5919),
    [sym_biginteger_literal] = ACTIONS(5921),
    [anon_sym_if] = ACTIONS(5919),
    [anon_sym_IF] = ACTIONS(5919),
    [anon_sym_If] = ACTIONS(5919),
    [anon_sym_else] = ACTIONS(5919),
    [anon_sym_ELSE] = ACTIONS(5919),
    [anon_sym_Else] = ACTIONS(5919),
    [anon_sym_case] = ACTIONS(5919),
    [anon_sym_CASE] = ACTIONS(5919),
    [anon_sym_Case] = ACTIONS(5919),
    [anon_sym_for] = ACTIONS(5919),
    [anon_sym_FOR] = ACTIONS(5919),
    [anon_sym_For] = ACTIONS(5919),
    [anon_sym_foreach] = ACTIONS(5919),
    [anon_sym_FOREACH] = ACTIONS(5919),
    [anon_sym_Foreach] = ACTIONS(5919),
    [anon_sym_while] = ACTIONS(5919),
    [anon_sym_WHILE] = ACTIONS(5919),
    [anon_sym_While] = ACTIONS(5919),
    [anon_sym_repeat] = ACTIONS(5919),
    [anon_sym_REPEAT] = ACTIONS(5919),
    [anon_sym_Repeat] = ACTIONS(5919),
    [anon_sym_exit] = ACTIONS(5919),
    [anon_sym_EXIT] = ACTIONS(5919),
    [anon_sym_Exit] = ACTIONS(5919),
    [anon_sym_continue] = ACTIONS(5919),
    [anon_sym_CONTINUE] = ACTIONS(5919),
    [anon_sym_Continue] = ACTIONS(5919),
    [anon_sym_break] = ACTIONS(5919),
    [anon_sym_BREAK] = ACTIONS(5919),
    [anon_sym_Break] = ACTIONS(5919),
    [anon_sym_with] = ACTIONS(5919),
    [anon_sym_WITH] = ACTIONS(5919),
    [anon_sym_With] = ACTIONS(5919),
    [sym_asserterror_keyword] = ACTIONS(5921),
    [sym_page_keyword] = ACTIONS(5919),
    [anon_sym_codeunit] = ACTIONS(5919),
    [anon_sym_CODEUNIT] = ACTIONS(5919),
    [anon_sym_Codeunit] = ACTIONS(5919),
    [anon_sym_CodeUnit] = ACTIONS(5919),
    [anon_sym_COdeunit] = ACTIONS(5919),
    [anon_sym_codeUnit] = ACTIONS(5919),
    [sym_report_keyword] = ACTIONS(5919),
    [sym_query_keyword] = ACTIONS(5919),
    [anon_sym_xmlport] = ACTIONS(5919),
    [anon_sym_XMLPORT] = ACTIONS(5919),
    [anon_sym_Xmlport] = ACTIONS(5919),
    [anon_sym_XMLport] = ACTIONS(5919),
    [anon_sym_XMLPort] = ACTIONS(5919),
    [anon_sym_XmlPort] = ACTIONS(5919),
    [anon_sym_enum] = ACTIONS(5919),
    [anon_sym_ENUM] = ACTIONS(5919),
    [anon_sym_Enum] = ACTIONS(5919),
    [anon_sym_eNUM] = ACTIONS(5919),
    [anon_sym_eNum] = ACTIONS(5919),
    [anon_sym_ENum] = ACTIONS(5919),
    [sym_quoted_identifier] = ACTIONS(5921),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5921),
    [sym_verbatim_string] = ACTIONS(5921),
    [sym_integer] = ACTIONS(5919),
    [sym_continue_as_identifier] = ACTIONS(5921),
    [sym_preproc_open] = ACTIONS(5921),
    [sym_preproc_close] = ACTIONS(5921),
  },
  [STATE(2487)] = {
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_SEMI] = ACTIONS(5925),
    [anon_sym_DASH] = ACTIONS(5925),
    [aux_sym_boolean_token1] = ACTIONS(5923),
    [aux_sym_boolean_token2] = ACTIONS(5923),
    [sym_decimal] = ACTIONS(5923),
    [anon_sym_LPAREN] = ACTIONS(5925),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5923),
    [anon_sym_LBRACK] = ACTIONS(5925),
    [aux_sym_record_type_token1] = ACTIONS(5923),
    [aux_sym_basic_type_token21] = ACTIONS(5923),
    [aux_sym_basic_type_token22] = ACTIONS(5923),
    [aux_sym_basic_type_token48] = ACTIONS(5923),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5923),
    [anon_sym_POUNDif] = ACTIONS(5925),
    [anon_sym_POUNDIF] = ACTIONS(5925),
    [anon_sym_POUNDIf] = ACTIONS(5925),
    [anon_sym_not] = ACTIONS(5923),
    [anon_sym_NOT] = ACTIONS(5923),
    [anon_sym_Not] = ACTIONS(5923),
    [anon_sym_POUNDelif] = ACTIONS(5925),
    [anon_sym_POUNDELIF] = ACTIONS(5925),
    [anon_sym_POUNDElif] = ACTIONS(5925),
    [anon_sym_POUNDelse] = ACTIONS(5925),
    [anon_sym_POUNDELSE] = ACTIONS(5925),
    [anon_sym_POUNDElse] = ACTIONS(5925),
    [anon_sym_POUNDelse2] = ACTIONS(5925),
    [anon_sym_POUNDELSE2] = ACTIONS(5925),
    [anon_sym_POUNDElse2] = ACTIONS(5925),
    [anon_sym_POUNDendif] = ACTIONS(5925),
    [anon_sym_POUNDENDIF] = ACTIONS(5925),
    [anon_sym_POUNDEndif] = ACTIONS(5925),
    [anon_sym_POUNDendif2] = ACTIONS(5925),
    [anon_sym_POUNDENDIF2] = ACTIONS(5925),
    [anon_sym_POUNDEndif2] = ACTIONS(5925),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5923),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5923),
    [anon_sym_PLUS] = ACTIONS(5925),
    [sym_datetime_literal] = ACTIONS(5925),
    [sym_date_literal] = ACTIONS(5923),
    [sym_time_literal] = ACTIONS(5923),
    [sym_biginteger_literal] = ACTIONS(5925),
    [anon_sym_if] = ACTIONS(5923),
    [anon_sym_IF] = ACTIONS(5923),
    [anon_sym_If] = ACTIONS(5923),
    [anon_sym_else] = ACTIONS(5923),
    [anon_sym_ELSE] = ACTIONS(5923),
    [anon_sym_Else] = ACTIONS(5923),
    [anon_sym_case] = ACTIONS(5923),
    [anon_sym_CASE] = ACTIONS(5923),
    [anon_sym_Case] = ACTIONS(5923),
    [anon_sym_for] = ACTIONS(5923),
    [anon_sym_FOR] = ACTIONS(5923),
    [anon_sym_For] = ACTIONS(5923),
    [anon_sym_foreach] = ACTIONS(5923),
    [anon_sym_FOREACH] = ACTIONS(5923),
    [anon_sym_Foreach] = ACTIONS(5923),
    [anon_sym_while] = ACTIONS(5923),
    [anon_sym_WHILE] = ACTIONS(5923),
    [anon_sym_While] = ACTIONS(5923),
    [anon_sym_repeat] = ACTIONS(5923),
    [anon_sym_REPEAT] = ACTIONS(5923),
    [anon_sym_Repeat] = ACTIONS(5923),
    [anon_sym_exit] = ACTIONS(5923),
    [anon_sym_EXIT] = ACTIONS(5923),
    [anon_sym_Exit] = ACTIONS(5923),
    [anon_sym_continue] = ACTIONS(5923),
    [anon_sym_CONTINUE] = ACTIONS(5923),
    [anon_sym_Continue] = ACTIONS(5923),
    [anon_sym_break] = ACTIONS(5923),
    [anon_sym_BREAK] = ACTIONS(5923),
    [anon_sym_Break] = ACTIONS(5923),
    [anon_sym_with] = ACTIONS(5923),
    [anon_sym_WITH] = ACTIONS(5923),
    [anon_sym_With] = ACTIONS(5923),
    [sym_asserterror_keyword] = ACTIONS(5925),
    [sym_page_keyword] = ACTIONS(5923),
    [anon_sym_codeunit] = ACTIONS(5923),
    [anon_sym_CODEUNIT] = ACTIONS(5923),
    [anon_sym_Codeunit] = ACTIONS(5923),
    [anon_sym_CodeUnit] = ACTIONS(5923),
    [anon_sym_COdeunit] = ACTIONS(5923),
    [anon_sym_codeUnit] = ACTIONS(5923),
    [sym_report_keyword] = ACTIONS(5923),
    [sym_query_keyword] = ACTIONS(5923),
    [anon_sym_xmlport] = ACTIONS(5923),
    [anon_sym_XMLPORT] = ACTIONS(5923),
    [anon_sym_Xmlport] = ACTIONS(5923),
    [anon_sym_XMLport] = ACTIONS(5923),
    [anon_sym_XMLPort] = ACTIONS(5923),
    [anon_sym_XmlPort] = ACTIONS(5923),
    [anon_sym_enum] = ACTIONS(5923),
    [anon_sym_ENUM] = ACTIONS(5923),
    [anon_sym_Enum] = ACTIONS(5923),
    [anon_sym_eNUM] = ACTIONS(5923),
    [anon_sym_eNum] = ACTIONS(5923),
    [anon_sym_ENum] = ACTIONS(5923),
    [sym_quoted_identifier] = ACTIONS(5925),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5925),
    [sym_verbatim_string] = ACTIONS(5925),
    [sym_integer] = ACTIONS(5923),
    [sym_continue_as_identifier] = ACTIONS(5925),
    [sym_preproc_open] = ACTIONS(5925),
    [sym_preproc_close] = ACTIONS(5925),
  },
  [STATE(2488)] = {
    [sym_identifier] = ACTIONS(5927),
    [anon_sym_SEMI] = ACTIONS(5929),
    [anon_sym_DASH] = ACTIONS(5929),
    [aux_sym_boolean_token1] = ACTIONS(5927),
    [aux_sym_boolean_token2] = ACTIONS(5927),
    [sym_decimal] = ACTIONS(5927),
    [anon_sym_LPAREN] = ACTIONS(5929),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5927),
    [anon_sym_LBRACK] = ACTIONS(5929),
    [aux_sym_record_type_token1] = ACTIONS(5927),
    [aux_sym_basic_type_token21] = ACTIONS(5927),
    [aux_sym_basic_type_token22] = ACTIONS(5927),
    [aux_sym_basic_type_token48] = ACTIONS(5927),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5927),
    [anon_sym_POUNDif] = ACTIONS(5929),
    [anon_sym_POUNDIF] = ACTIONS(5929),
    [anon_sym_POUNDIf] = ACTIONS(5929),
    [anon_sym_not] = ACTIONS(5927),
    [anon_sym_NOT] = ACTIONS(5927),
    [anon_sym_Not] = ACTIONS(5927),
    [anon_sym_POUNDelif] = ACTIONS(5929),
    [anon_sym_POUNDELIF] = ACTIONS(5929),
    [anon_sym_POUNDElif] = ACTIONS(5929),
    [anon_sym_POUNDelse] = ACTIONS(5929),
    [anon_sym_POUNDELSE] = ACTIONS(5929),
    [anon_sym_POUNDElse] = ACTIONS(5929),
    [anon_sym_POUNDelse2] = ACTIONS(5929),
    [anon_sym_POUNDELSE2] = ACTIONS(5929),
    [anon_sym_POUNDElse2] = ACTIONS(5929),
    [anon_sym_POUNDendif] = ACTIONS(5929),
    [anon_sym_POUNDENDIF] = ACTIONS(5929),
    [anon_sym_POUNDEndif] = ACTIONS(5929),
    [anon_sym_POUNDendif2] = ACTIONS(5929),
    [anon_sym_POUNDENDIF2] = ACTIONS(5929),
    [anon_sym_POUNDEndif2] = ACTIONS(5929),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5927),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5927),
    [anon_sym_PLUS] = ACTIONS(5929),
    [sym_datetime_literal] = ACTIONS(5929),
    [sym_date_literal] = ACTIONS(5927),
    [sym_time_literal] = ACTIONS(5927),
    [sym_biginteger_literal] = ACTIONS(5929),
    [anon_sym_if] = ACTIONS(5927),
    [anon_sym_IF] = ACTIONS(5927),
    [anon_sym_If] = ACTIONS(5927),
    [anon_sym_else] = ACTIONS(5927),
    [anon_sym_ELSE] = ACTIONS(5927),
    [anon_sym_Else] = ACTIONS(5927),
    [anon_sym_case] = ACTIONS(5927),
    [anon_sym_CASE] = ACTIONS(5927),
    [anon_sym_Case] = ACTIONS(5927),
    [anon_sym_for] = ACTIONS(5927),
    [anon_sym_FOR] = ACTIONS(5927),
    [anon_sym_For] = ACTIONS(5927),
    [anon_sym_foreach] = ACTIONS(5927),
    [anon_sym_FOREACH] = ACTIONS(5927),
    [anon_sym_Foreach] = ACTIONS(5927),
    [anon_sym_while] = ACTIONS(5927),
    [anon_sym_WHILE] = ACTIONS(5927),
    [anon_sym_While] = ACTIONS(5927),
    [anon_sym_repeat] = ACTIONS(5927),
    [anon_sym_REPEAT] = ACTIONS(5927),
    [anon_sym_Repeat] = ACTIONS(5927),
    [anon_sym_exit] = ACTIONS(5927),
    [anon_sym_EXIT] = ACTIONS(5927),
    [anon_sym_Exit] = ACTIONS(5927),
    [anon_sym_continue] = ACTIONS(5927),
    [anon_sym_CONTINUE] = ACTIONS(5927),
    [anon_sym_Continue] = ACTIONS(5927),
    [anon_sym_break] = ACTIONS(5927),
    [anon_sym_BREAK] = ACTIONS(5927),
    [anon_sym_Break] = ACTIONS(5927),
    [anon_sym_with] = ACTIONS(5927),
    [anon_sym_WITH] = ACTIONS(5927),
    [anon_sym_With] = ACTIONS(5927),
    [sym_asserterror_keyword] = ACTIONS(5929),
    [sym_page_keyword] = ACTIONS(5927),
    [anon_sym_codeunit] = ACTIONS(5927),
    [anon_sym_CODEUNIT] = ACTIONS(5927),
    [anon_sym_Codeunit] = ACTIONS(5927),
    [anon_sym_CodeUnit] = ACTIONS(5927),
    [anon_sym_COdeunit] = ACTIONS(5927),
    [anon_sym_codeUnit] = ACTIONS(5927),
    [sym_report_keyword] = ACTIONS(5927),
    [sym_query_keyword] = ACTIONS(5927),
    [anon_sym_xmlport] = ACTIONS(5927),
    [anon_sym_XMLPORT] = ACTIONS(5927),
    [anon_sym_Xmlport] = ACTIONS(5927),
    [anon_sym_XMLport] = ACTIONS(5927),
    [anon_sym_XMLPort] = ACTIONS(5927),
    [anon_sym_XmlPort] = ACTIONS(5927),
    [anon_sym_enum] = ACTIONS(5927),
    [anon_sym_ENUM] = ACTIONS(5927),
    [anon_sym_Enum] = ACTIONS(5927),
    [anon_sym_eNUM] = ACTIONS(5927),
    [anon_sym_eNum] = ACTIONS(5927),
    [anon_sym_ENum] = ACTIONS(5927),
    [sym_quoted_identifier] = ACTIONS(5929),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5929),
    [sym_verbatim_string] = ACTIONS(5929),
    [sym_integer] = ACTIONS(5927),
    [sym_continue_as_identifier] = ACTIONS(5929),
    [sym_preproc_open] = ACTIONS(5929),
    [sym_preproc_close] = ACTIONS(5929),
  },
  [STATE(2489)] = {
    [sym_identifier] = ACTIONS(5931),
    [anon_sym_SEMI] = ACTIONS(5933),
    [anon_sym_DASH] = ACTIONS(5933),
    [aux_sym_boolean_token1] = ACTIONS(5931),
    [aux_sym_boolean_token2] = ACTIONS(5931),
    [sym_decimal] = ACTIONS(5931),
    [anon_sym_LPAREN] = ACTIONS(5933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5931),
    [anon_sym_LBRACK] = ACTIONS(5933),
    [aux_sym_record_type_token1] = ACTIONS(5931),
    [aux_sym_basic_type_token21] = ACTIONS(5931),
    [aux_sym_basic_type_token22] = ACTIONS(5931),
    [aux_sym_basic_type_token48] = ACTIONS(5931),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5931),
    [anon_sym_POUNDif] = ACTIONS(5933),
    [anon_sym_POUNDIF] = ACTIONS(5933),
    [anon_sym_POUNDIf] = ACTIONS(5933),
    [anon_sym_not] = ACTIONS(5931),
    [anon_sym_NOT] = ACTIONS(5931),
    [anon_sym_Not] = ACTIONS(5931),
    [anon_sym_POUNDelif] = ACTIONS(5933),
    [anon_sym_POUNDELIF] = ACTIONS(5933),
    [anon_sym_POUNDElif] = ACTIONS(5933),
    [anon_sym_POUNDelse] = ACTIONS(5933),
    [anon_sym_POUNDELSE] = ACTIONS(5933),
    [anon_sym_POUNDElse] = ACTIONS(5933),
    [anon_sym_POUNDelse2] = ACTIONS(5933),
    [anon_sym_POUNDELSE2] = ACTIONS(5933),
    [anon_sym_POUNDElse2] = ACTIONS(5933),
    [anon_sym_POUNDendif] = ACTIONS(5933),
    [anon_sym_POUNDENDIF] = ACTIONS(5933),
    [anon_sym_POUNDEndif] = ACTIONS(5933),
    [anon_sym_POUNDendif2] = ACTIONS(5933),
    [anon_sym_POUNDENDIF2] = ACTIONS(5933),
    [anon_sym_POUNDEndif2] = ACTIONS(5933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5931),
    [anon_sym_PLUS] = ACTIONS(5933),
    [sym_datetime_literal] = ACTIONS(5933),
    [sym_date_literal] = ACTIONS(5931),
    [sym_time_literal] = ACTIONS(5931),
    [sym_biginteger_literal] = ACTIONS(5933),
    [anon_sym_if] = ACTIONS(5931),
    [anon_sym_IF] = ACTIONS(5931),
    [anon_sym_If] = ACTIONS(5931),
    [anon_sym_else] = ACTIONS(5931),
    [anon_sym_ELSE] = ACTIONS(5931),
    [anon_sym_Else] = ACTIONS(5931),
    [anon_sym_case] = ACTIONS(5931),
    [anon_sym_CASE] = ACTIONS(5931),
    [anon_sym_Case] = ACTIONS(5931),
    [anon_sym_for] = ACTIONS(5931),
    [anon_sym_FOR] = ACTIONS(5931),
    [anon_sym_For] = ACTIONS(5931),
    [anon_sym_foreach] = ACTIONS(5931),
    [anon_sym_FOREACH] = ACTIONS(5931),
    [anon_sym_Foreach] = ACTIONS(5931),
    [anon_sym_while] = ACTIONS(5931),
    [anon_sym_WHILE] = ACTIONS(5931),
    [anon_sym_While] = ACTIONS(5931),
    [anon_sym_repeat] = ACTIONS(5931),
    [anon_sym_REPEAT] = ACTIONS(5931),
    [anon_sym_Repeat] = ACTIONS(5931),
    [anon_sym_exit] = ACTIONS(5931),
    [anon_sym_EXIT] = ACTIONS(5931),
    [anon_sym_Exit] = ACTIONS(5931),
    [anon_sym_continue] = ACTIONS(5931),
    [anon_sym_CONTINUE] = ACTIONS(5931),
    [anon_sym_Continue] = ACTIONS(5931),
    [anon_sym_break] = ACTIONS(5931),
    [anon_sym_BREAK] = ACTIONS(5931),
    [anon_sym_Break] = ACTIONS(5931),
    [anon_sym_with] = ACTIONS(5931),
    [anon_sym_WITH] = ACTIONS(5931),
    [anon_sym_With] = ACTIONS(5931),
    [sym_asserterror_keyword] = ACTIONS(5933),
    [sym_page_keyword] = ACTIONS(5931),
    [anon_sym_codeunit] = ACTIONS(5931),
    [anon_sym_CODEUNIT] = ACTIONS(5931),
    [anon_sym_Codeunit] = ACTIONS(5931),
    [anon_sym_CodeUnit] = ACTIONS(5931),
    [anon_sym_COdeunit] = ACTIONS(5931),
    [anon_sym_codeUnit] = ACTIONS(5931),
    [sym_report_keyword] = ACTIONS(5931),
    [sym_query_keyword] = ACTIONS(5931),
    [anon_sym_xmlport] = ACTIONS(5931),
    [anon_sym_XMLPORT] = ACTIONS(5931),
    [anon_sym_Xmlport] = ACTIONS(5931),
    [anon_sym_XMLport] = ACTIONS(5931),
    [anon_sym_XMLPort] = ACTIONS(5931),
    [anon_sym_XmlPort] = ACTIONS(5931),
    [anon_sym_enum] = ACTIONS(5931),
    [anon_sym_ENUM] = ACTIONS(5931),
    [anon_sym_Enum] = ACTIONS(5931),
    [anon_sym_eNUM] = ACTIONS(5931),
    [anon_sym_eNum] = ACTIONS(5931),
    [anon_sym_ENum] = ACTIONS(5931),
    [sym_quoted_identifier] = ACTIONS(5933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5933),
    [sym_verbatim_string] = ACTIONS(5933),
    [sym_integer] = ACTIONS(5931),
    [sym_continue_as_identifier] = ACTIONS(5933),
    [sym_preproc_open] = ACTIONS(5933),
    [sym_preproc_close] = ACTIONS(5933),
  },
  [STATE(2490)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_DASH] = ACTIONS(5937),
    [aux_sym_boolean_token1] = ACTIONS(5935),
    [aux_sym_boolean_token2] = ACTIONS(5935),
    [sym_decimal] = ACTIONS(5935),
    [anon_sym_LPAREN] = ACTIONS(5937),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_record_type_token1] = ACTIONS(5935),
    [aux_sym_basic_type_token21] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token48] = ACTIONS(5935),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_not] = ACTIONS(5935),
    [anon_sym_NOT] = ACTIONS(5935),
    [anon_sym_Not] = ACTIONS(5935),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5935),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5935),
    [anon_sym_PLUS] = ACTIONS(5937),
    [sym_datetime_literal] = ACTIONS(5937),
    [sym_date_literal] = ACTIONS(5935),
    [sym_time_literal] = ACTIONS(5935),
    [sym_biginteger_literal] = ACTIONS(5937),
    [anon_sym_if] = ACTIONS(5935),
    [anon_sym_IF] = ACTIONS(5935),
    [anon_sym_If] = ACTIONS(5935),
    [anon_sym_else] = ACTIONS(5935),
    [anon_sym_ELSE] = ACTIONS(5935),
    [anon_sym_Else] = ACTIONS(5935),
    [anon_sym_case] = ACTIONS(5935),
    [anon_sym_CASE] = ACTIONS(5935),
    [anon_sym_Case] = ACTIONS(5935),
    [anon_sym_for] = ACTIONS(5935),
    [anon_sym_FOR] = ACTIONS(5935),
    [anon_sym_For] = ACTIONS(5935),
    [anon_sym_foreach] = ACTIONS(5935),
    [anon_sym_FOREACH] = ACTIONS(5935),
    [anon_sym_Foreach] = ACTIONS(5935),
    [anon_sym_while] = ACTIONS(5935),
    [anon_sym_WHILE] = ACTIONS(5935),
    [anon_sym_While] = ACTIONS(5935),
    [anon_sym_repeat] = ACTIONS(5935),
    [anon_sym_REPEAT] = ACTIONS(5935),
    [anon_sym_Repeat] = ACTIONS(5935),
    [anon_sym_exit] = ACTIONS(5935),
    [anon_sym_EXIT] = ACTIONS(5935),
    [anon_sym_Exit] = ACTIONS(5935),
    [anon_sym_continue] = ACTIONS(5935),
    [anon_sym_CONTINUE] = ACTIONS(5935),
    [anon_sym_Continue] = ACTIONS(5935),
    [anon_sym_break] = ACTIONS(5935),
    [anon_sym_BREAK] = ACTIONS(5935),
    [anon_sym_Break] = ACTIONS(5935),
    [anon_sym_with] = ACTIONS(5935),
    [anon_sym_WITH] = ACTIONS(5935),
    [anon_sym_With] = ACTIONS(5935),
    [sym_asserterror_keyword] = ACTIONS(5937),
    [sym_page_keyword] = ACTIONS(5935),
    [anon_sym_codeunit] = ACTIONS(5935),
    [anon_sym_CODEUNIT] = ACTIONS(5935),
    [anon_sym_Codeunit] = ACTIONS(5935),
    [anon_sym_CodeUnit] = ACTIONS(5935),
    [anon_sym_COdeunit] = ACTIONS(5935),
    [anon_sym_codeUnit] = ACTIONS(5935),
    [sym_report_keyword] = ACTIONS(5935),
    [sym_query_keyword] = ACTIONS(5935),
    [anon_sym_xmlport] = ACTIONS(5935),
    [anon_sym_XMLPORT] = ACTIONS(5935),
    [anon_sym_Xmlport] = ACTIONS(5935),
    [anon_sym_XMLport] = ACTIONS(5935),
    [anon_sym_XMLPort] = ACTIONS(5935),
    [anon_sym_XmlPort] = ACTIONS(5935),
    [anon_sym_enum] = ACTIONS(5935),
    [anon_sym_ENUM] = ACTIONS(5935),
    [anon_sym_Enum] = ACTIONS(5935),
    [anon_sym_eNUM] = ACTIONS(5935),
    [anon_sym_eNum] = ACTIONS(5935),
    [anon_sym_ENum] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5937),
    [sym_verbatim_string] = ACTIONS(5937),
    [sym_integer] = ACTIONS(5935),
    [sym_continue_as_identifier] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
  },
  [STATE(2491)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_DASH] = ACTIONS(5937),
    [aux_sym_boolean_token1] = ACTIONS(5935),
    [aux_sym_boolean_token2] = ACTIONS(5935),
    [sym_decimal] = ACTIONS(5935),
    [anon_sym_LPAREN] = ACTIONS(5937),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_record_type_token1] = ACTIONS(5935),
    [aux_sym_basic_type_token21] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token48] = ACTIONS(5935),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_not] = ACTIONS(5935),
    [anon_sym_NOT] = ACTIONS(5935),
    [anon_sym_Not] = ACTIONS(5935),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5935),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5935),
    [anon_sym_PLUS] = ACTIONS(5937),
    [sym_datetime_literal] = ACTIONS(5937),
    [sym_date_literal] = ACTIONS(5935),
    [sym_time_literal] = ACTIONS(5935),
    [sym_biginteger_literal] = ACTIONS(5937),
    [anon_sym_if] = ACTIONS(5935),
    [anon_sym_IF] = ACTIONS(5935),
    [anon_sym_If] = ACTIONS(5935),
    [anon_sym_else] = ACTIONS(5935),
    [anon_sym_ELSE] = ACTIONS(5935),
    [anon_sym_Else] = ACTIONS(5935),
    [anon_sym_case] = ACTIONS(5935),
    [anon_sym_CASE] = ACTIONS(5935),
    [anon_sym_Case] = ACTIONS(5935),
    [anon_sym_for] = ACTIONS(5935),
    [anon_sym_FOR] = ACTIONS(5935),
    [anon_sym_For] = ACTIONS(5935),
    [anon_sym_foreach] = ACTIONS(5935),
    [anon_sym_FOREACH] = ACTIONS(5935),
    [anon_sym_Foreach] = ACTIONS(5935),
    [anon_sym_while] = ACTIONS(5935),
    [anon_sym_WHILE] = ACTIONS(5935),
    [anon_sym_While] = ACTIONS(5935),
    [anon_sym_repeat] = ACTIONS(5935),
    [anon_sym_REPEAT] = ACTIONS(5935),
    [anon_sym_Repeat] = ACTIONS(5935),
    [anon_sym_exit] = ACTIONS(5935),
    [anon_sym_EXIT] = ACTIONS(5935),
    [anon_sym_Exit] = ACTIONS(5935),
    [anon_sym_continue] = ACTIONS(5935),
    [anon_sym_CONTINUE] = ACTIONS(5935),
    [anon_sym_Continue] = ACTIONS(5935),
    [anon_sym_break] = ACTIONS(5935),
    [anon_sym_BREAK] = ACTIONS(5935),
    [anon_sym_Break] = ACTIONS(5935),
    [anon_sym_with] = ACTIONS(5935),
    [anon_sym_WITH] = ACTIONS(5935),
    [anon_sym_With] = ACTIONS(5935),
    [sym_asserterror_keyword] = ACTIONS(5937),
    [sym_page_keyword] = ACTIONS(5935),
    [anon_sym_codeunit] = ACTIONS(5935),
    [anon_sym_CODEUNIT] = ACTIONS(5935),
    [anon_sym_Codeunit] = ACTIONS(5935),
    [anon_sym_CodeUnit] = ACTIONS(5935),
    [anon_sym_COdeunit] = ACTIONS(5935),
    [anon_sym_codeUnit] = ACTIONS(5935),
    [sym_report_keyword] = ACTIONS(5935),
    [sym_query_keyword] = ACTIONS(5935),
    [anon_sym_xmlport] = ACTIONS(5935),
    [anon_sym_XMLPORT] = ACTIONS(5935),
    [anon_sym_Xmlport] = ACTIONS(5935),
    [anon_sym_XMLport] = ACTIONS(5935),
    [anon_sym_XMLPort] = ACTIONS(5935),
    [anon_sym_XmlPort] = ACTIONS(5935),
    [anon_sym_enum] = ACTIONS(5935),
    [anon_sym_ENUM] = ACTIONS(5935),
    [anon_sym_Enum] = ACTIONS(5935),
    [anon_sym_eNUM] = ACTIONS(5935),
    [anon_sym_eNum] = ACTIONS(5935),
    [anon_sym_ENum] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5937),
    [sym_verbatim_string] = ACTIONS(5937),
    [sym_integer] = ACTIONS(5935),
    [sym_continue_as_identifier] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
  },
  [STATE(2492)] = {
    [sym_identifier] = ACTIONS(5939),
    [anon_sym_SEMI] = ACTIONS(5941),
    [anon_sym_DASH] = ACTIONS(5943),
    [aux_sym_boolean_token1] = ACTIONS(5939),
    [aux_sym_boolean_token2] = ACTIONS(5939),
    [sym_decimal] = ACTIONS(5939),
    [anon_sym_LPAREN] = ACTIONS(5943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5939),
    [anon_sym_LBRACK] = ACTIONS(5943),
    [aux_sym_record_type_token1] = ACTIONS(5939),
    [aux_sym_basic_type_token21] = ACTIONS(5939),
    [aux_sym_basic_type_token22] = ACTIONS(5939),
    [aux_sym_basic_type_token48] = ACTIONS(5939),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5939),
    [anon_sym_POUNDif] = ACTIONS(5943),
    [anon_sym_POUNDIF] = ACTIONS(5943),
    [anon_sym_POUNDIf] = ACTIONS(5943),
    [anon_sym_not] = ACTIONS(5939),
    [anon_sym_NOT] = ACTIONS(5939),
    [anon_sym_Not] = ACTIONS(5939),
    [anon_sym_POUNDelif] = ACTIONS(5943),
    [anon_sym_POUNDELIF] = ACTIONS(5943),
    [anon_sym_POUNDElif] = ACTIONS(5943),
    [anon_sym_POUNDelse] = ACTIONS(5943),
    [anon_sym_POUNDELSE] = ACTIONS(5943),
    [anon_sym_POUNDElse] = ACTIONS(5943),
    [anon_sym_POUNDelse2] = ACTIONS(5943),
    [anon_sym_POUNDELSE2] = ACTIONS(5943),
    [anon_sym_POUNDElse2] = ACTIONS(5943),
    [anon_sym_POUNDendif] = ACTIONS(5943),
    [anon_sym_POUNDENDIF] = ACTIONS(5943),
    [anon_sym_POUNDEndif] = ACTIONS(5943),
    [anon_sym_POUNDendif2] = ACTIONS(5943),
    [anon_sym_POUNDENDIF2] = ACTIONS(5943),
    [anon_sym_POUNDEndif2] = ACTIONS(5943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5939),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5939),
    [anon_sym_PLUS] = ACTIONS(5943),
    [sym_datetime_literal] = ACTIONS(5943),
    [sym_date_literal] = ACTIONS(5939),
    [sym_time_literal] = ACTIONS(5939),
    [sym_biginteger_literal] = ACTIONS(5943),
    [anon_sym_if] = ACTIONS(5939),
    [anon_sym_IF] = ACTIONS(5939),
    [anon_sym_If] = ACTIONS(5939),
    [anon_sym_else] = ACTIONS(5939),
    [anon_sym_ELSE] = ACTIONS(5939),
    [anon_sym_Else] = ACTIONS(5939),
    [anon_sym_case] = ACTIONS(5939),
    [anon_sym_CASE] = ACTIONS(5939),
    [anon_sym_Case] = ACTIONS(5939),
    [anon_sym_for] = ACTIONS(5939),
    [anon_sym_FOR] = ACTIONS(5939),
    [anon_sym_For] = ACTIONS(5939),
    [anon_sym_foreach] = ACTIONS(5939),
    [anon_sym_FOREACH] = ACTIONS(5939),
    [anon_sym_Foreach] = ACTIONS(5939),
    [anon_sym_while] = ACTIONS(5939),
    [anon_sym_WHILE] = ACTIONS(5939),
    [anon_sym_While] = ACTIONS(5939),
    [anon_sym_repeat] = ACTIONS(5939),
    [anon_sym_REPEAT] = ACTIONS(5939),
    [anon_sym_Repeat] = ACTIONS(5939),
    [anon_sym_exit] = ACTIONS(5939),
    [anon_sym_EXIT] = ACTIONS(5939),
    [anon_sym_Exit] = ACTIONS(5939),
    [anon_sym_continue] = ACTIONS(5939),
    [anon_sym_CONTINUE] = ACTIONS(5939),
    [anon_sym_Continue] = ACTIONS(5939),
    [anon_sym_break] = ACTIONS(5939),
    [anon_sym_BREAK] = ACTIONS(5939),
    [anon_sym_Break] = ACTIONS(5939),
    [anon_sym_with] = ACTIONS(5939),
    [anon_sym_WITH] = ACTIONS(5939),
    [anon_sym_With] = ACTIONS(5939),
    [sym_asserterror_keyword] = ACTIONS(5943),
    [sym_page_keyword] = ACTIONS(5939),
    [anon_sym_codeunit] = ACTIONS(5939),
    [anon_sym_CODEUNIT] = ACTIONS(5939),
    [anon_sym_Codeunit] = ACTIONS(5939),
    [anon_sym_CodeUnit] = ACTIONS(5939),
    [anon_sym_COdeunit] = ACTIONS(5939),
    [anon_sym_codeUnit] = ACTIONS(5939),
    [sym_report_keyword] = ACTIONS(5939),
    [sym_query_keyword] = ACTIONS(5939),
    [anon_sym_xmlport] = ACTIONS(5939),
    [anon_sym_XMLPORT] = ACTIONS(5939),
    [anon_sym_Xmlport] = ACTIONS(5939),
    [anon_sym_XMLport] = ACTIONS(5939),
    [anon_sym_XMLPort] = ACTIONS(5939),
    [anon_sym_XmlPort] = ACTIONS(5939),
    [anon_sym_enum] = ACTIONS(5939),
    [anon_sym_ENUM] = ACTIONS(5939),
    [anon_sym_Enum] = ACTIONS(5939),
    [anon_sym_eNUM] = ACTIONS(5939),
    [anon_sym_eNum] = ACTIONS(5939),
    [anon_sym_ENum] = ACTIONS(5939),
    [sym_quoted_identifier] = ACTIONS(5943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5943),
    [sym_verbatim_string] = ACTIONS(5943),
    [sym_integer] = ACTIONS(5939),
    [sym_continue_as_identifier] = ACTIONS(5943),
    [sym_preproc_open] = ACTIONS(5943),
    [sym_preproc_close] = ACTIONS(5943),
  },
  [STATE(2493)] = {
    [sym_identifier] = ACTIONS(5945),
    [anon_sym_SEMI] = ACTIONS(5947),
    [anon_sym_DASH] = ACTIONS(5947),
    [aux_sym_boolean_token1] = ACTIONS(5945),
    [aux_sym_boolean_token2] = ACTIONS(5945),
    [sym_decimal] = ACTIONS(5945),
    [anon_sym_LPAREN] = ACTIONS(5947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5945),
    [anon_sym_LBRACK] = ACTIONS(5947),
    [aux_sym_record_type_token1] = ACTIONS(5945),
    [aux_sym_basic_type_token21] = ACTIONS(5945),
    [aux_sym_basic_type_token22] = ACTIONS(5945),
    [aux_sym_basic_type_token48] = ACTIONS(5945),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5945),
    [anon_sym_POUNDif] = ACTIONS(5947),
    [anon_sym_POUNDIF] = ACTIONS(5947),
    [anon_sym_POUNDIf] = ACTIONS(5947),
    [anon_sym_not] = ACTIONS(5945),
    [anon_sym_NOT] = ACTIONS(5945),
    [anon_sym_Not] = ACTIONS(5945),
    [anon_sym_POUNDelif] = ACTIONS(5947),
    [anon_sym_POUNDELIF] = ACTIONS(5947),
    [anon_sym_POUNDElif] = ACTIONS(5947),
    [anon_sym_POUNDelse] = ACTIONS(5947),
    [anon_sym_POUNDELSE] = ACTIONS(5947),
    [anon_sym_POUNDElse] = ACTIONS(5947),
    [anon_sym_POUNDelse2] = ACTIONS(5947),
    [anon_sym_POUNDELSE2] = ACTIONS(5947),
    [anon_sym_POUNDElse2] = ACTIONS(5947),
    [anon_sym_POUNDendif] = ACTIONS(5947),
    [anon_sym_POUNDENDIF] = ACTIONS(5947),
    [anon_sym_POUNDEndif] = ACTIONS(5947),
    [anon_sym_POUNDendif2] = ACTIONS(5947),
    [anon_sym_POUNDENDIF2] = ACTIONS(5947),
    [anon_sym_POUNDEndif2] = ACTIONS(5947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5945),
    [anon_sym_PLUS] = ACTIONS(5947),
    [sym_datetime_literal] = ACTIONS(5947),
    [sym_date_literal] = ACTIONS(5945),
    [sym_time_literal] = ACTIONS(5945),
    [sym_biginteger_literal] = ACTIONS(5947),
    [anon_sym_if] = ACTIONS(5945),
    [anon_sym_IF] = ACTIONS(5945),
    [anon_sym_If] = ACTIONS(5945),
    [anon_sym_else] = ACTIONS(5945),
    [anon_sym_ELSE] = ACTIONS(5945),
    [anon_sym_Else] = ACTIONS(5945),
    [anon_sym_case] = ACTIONS(5945),
    [anon_sym_CASE] = ACTIONS(5945),
    [anon_sym_Case] = ACTIONS(5945),
    [anon_sym_for] = ACTIONS(5945),
    [anon_sym_FOR] = ACTIONS(5945),
    [anon_sym_For] = ACTIONS(5945),
    [anon_sym_foreach] = ACTIONS(5945),
    [anon_sym_FOREACH] = ACTIONS(5945),
    [anon_sym_Foreach] = ACTIONS(5945),
    [anon_sym_while] = ACTIONS(5945),
    [anon_sym_WHILE] = ACTIONS(5945),
    [anon_sym_While] = ACTIONS(5945),
    [anon_sym_repeat] = ACTIONS(5945),
    [anon_sym_REPEAT] = ACTIONS(5945),
    [anon_sym_Repeat] = ACTIONS(5945),
    [anon_sym_exit] = ACTIONS(5945),
    [anon_sym_EXIT] = ACTIONS(5945),
    [anon_sym_Exit] = ACTIONS(5945),
    [anon_sym_continue] = ACTIONS(5945),
    [anon_sym_CONTINUE] = ACTIONS(5945),
    [anon_sym_Continue] = ACTIONS(5945),
    [anon_sym_break] = ACTIONS(5945),
    [anon_sym_BREAK] = ACTIONS(5945),
    [anon_sym_Break] = ACTIONS(5945),
    [anon_sym_with] = ACTIONS(5945),
    [anon_sym_WITH] = ACTIONS(5945),
    [anon_sym_With] = ACTIONS(5945),
    [sym_asserterror_keyword] = ACTIONS(5947),
    [sym_page_keyword] = ACTIONS(5945),
    [anon_sym_codeunit] = ACTIONS(5945),
    [anon_sym_CODEUNIT] = ACTIONS(5945),
    [anon_sym_Codeunit] = ACTIONS(5945),
    [anon_sym_CodeUnit] = ACTIONS(5945),
    [anon_sym_COdeunit] = ACTIONS(5945),
    [anon_sym_codeUnit] = ACTIONS(5945),
    [sym_report_keyword] = ACTIONS(5945),
    [sym_query_keyword] = ACTIONS(5945),
    [anon_sym_xmlport] = ACTIONS(5945),
    [anon_sym_XMLPORT] = ACTIONS(5945),
    [anon_sym_Xmlport] = ACTIONS(5945),
    [anon_sym_XMLport] = ACTIONS(5945),
    [anon_sym_XMLPort] = ACTIONS(5945),
    [anon_sym_XmlPort] = ACTIONS(5945),
    [anon_sym_enum] = ACTIONS(5945),
    [anon_sym_ENUM] = ACTIONS(5945),
    [anon_sym_Enum] = ACTIONS(5945),
    [anon_sym_eNUM] = ACTIONS(5945),
    [anon_sym_eNum] = ACTIONS(5945),
    [anon_sym_ENum] = ACTIONS(5945),
    [sym_quoted_identifier] = ACTIONS(5947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5947),
    [sym_verbatim_string] = ACTIONS(5947),
    [sym_integer] = ACTIONS(5945),
    [sym_continue_as_identifier] = ACTIONS(5947),
    [sym_preproc_open] = ACTIONS(5947),
    [sym_preproc_close] = ACTIONS(5947),
  },
  [STATE(2494)] = {
    [sym_identifier] = ACTIONS(5949),
    [anon_sym_SEMI] = ACTIONS(5951),
    [anon_sym_DASH] = ACTIONS(5951),
    [aux_sym_boolean_token1] = ACTIONS(5949),
    [aux_sym_boolean_token2] = ACTIONS(5949),
    [sym_decimal] = ACTIONS(5949),
    [anon_sym_LPAREN] = ACTIONS(5951),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5949),
    [anon_sym_LBRACK] = ACTIONS(5951),
    [aux_sym_record_type_token1] = ACTIONS(5949),
    [aux_sym_basic_type_token21] = ACTIONS(5949),
    [aux_sym_basic_type_token22] = ACTIONS(5949),
    [aux_sym_basic_type_token48] = ACTIONS(5949),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5949),
    [anon_sym_POUNDif] = ACTIONS(5951),
    [anon_sym_POUNDIF] = ACTIONS(5951),
    [anon_sym_POUNDIf] = ACTIONS(5951),
    [anon_sym_not] = ACTIONS(5949),
    [anon_sym_NOT] = ACTIONS(5949),
    [anon_sym_Not] = ACTIONS(5949),
    [anon_sym_POUNDelif] = ACTIONS(5951),
    [anon_sym_POUNDELIF] = ACTIONS(5951),
    [anon_sym_POUNDElif] = ACTIONS(5951),
    [anon_sym_POUNDelse] = ACTIONS(5951),
    [anon_sym_POUNDELSE] = ACTIONS(5951),
    [anon_sym_POUNDElse] = ACTIONS(5951),
    [anon_sym_POUNDelse2] = ACTIONS(5951),
    [anon_sym_POUNDELSE2] = ACTIONS(5951),
    [anon_sym_POUNDElse2] = ACTIONS(5951),
    [anon_sym_POUNDendif] = ACTIONS(5951),
    [anon_sym_POUNDENDIF] = ACTIONS(5951),
    [anon_sym_POUNDEndif] = ACTIONS(5951),
    [anon_sym_POUNDendif2] = ACTIONS(5951),
    [anon_sym_POUNDENDIF2] = ACTIONS(5951),
    [anon_sym_POUNDEndif2] = ACTIONS(5951),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5949),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5949),
    [anon_sym_PLUS] = ACTIONS(5951),
    [sym_datetime_literal] = ACTIONS(5951),
    [sym_date_literal] = ACTIONS(5949),
    [sym_time_literal] = ACTIONS(5949),
    [sym_biginteger_literal] = ACTIONS(5951),
    [anon_sym_if] = ACTIONS(5949),
    [anon_sym_IF] = ACTIONS(5949),
    [anon_sym_If] = ACTIONS(5949),
    [anon_sym_else] = ACTIONS(5949),
    [anon_sym_ELSE] = ACTIONS(5949),
    [anon_sym_Else] = ACTIONS(5949),
    [anon_sym_case] = ACTIONS(5949),
    [anon_sym_CASE] = ACTIONS(5949),
    [anon_sym_Case] = ACTIONS(5949),
    [anon_sym_for] = ACTIONS(5949),
    [anon_sym_FOR] = ACTIONS(5949),
    [anon_sym_For] = ACTIONS(5949),
    [anon_sym_foreach] = ACTIONS(5949),
    [anon_sym_FOREACH] = ACTIONS(5949),
    [anon_sym_Foreach] = ACTIONS(5949),
    [anon_sym_while] = ACTIONS(5949),
    [anon_sym_WHILE] = ACTIONS(5949),
    [anon_sym_While] = ACTIONS(5949),
    [anon_sym_repeat] = ACTIONS(5949),
    [anon_sym_REPEAT] = ACTIONS(5949),
    [anon_sym_Repeat] = ACTIONS(5949),
    [anon_sym_exit] = ACTIONS(5949),
    [anon_sym_EXIT] = ACTIONS(5949),
    [anon_sym_Exit] = ACTIONS(5949),
    [anon_sym_continue] = ACTIONS(5949),
    [anon_sym_CONTINUE] = ACTIONS(5949),
    [anon_sym_Continue] = ACTIONS(5949),
    [anon_sym_break] = ACTIONS(5949),
    [anon_sym_BREAK] = ACTIONS(5949),
    [anon_sym_Break] = ACTIONS(5949),
    [anon_sym_with] = ACTIONS(5949),
    [anon_sym_WITH] = ACTIONS(5949),
    [anon_sym_With] = ACTIONS(5949),
    [sym_asserterror_keyword] = ACTIONS(5951),
    [sym_page_keyword] = ACTIONS(5949),
    [anon_sym_codeunit] = ACTIONS(5949),
    [anon_sym_CODEUNIT] = ACTIONS(5949),
    [anon_sym_Codeunit] = ACTIONS(5949),
    [anon_sym_CodeUnit] = ACTIONS(5949),
    [anon_sym_COdeunit] = ACTIONS(5949),
    [anon_sym_codeUnit] = ACTIONS(5949),
    [sym_report_keyword] = ACTIONS(5949),
    [sym_query_keyword] = ACTIONS(5949),
    [anon_sym_xmlport] = ACTIONS(5949),
    [anon_sym_XMLPORT] = ACTIONS(5949),
    [anon_sym_Xmlport] = ACTIONS(5949),
    [anon_sym_XMLport] = ACTIONS(5949),
    [anon_sym_XMLPort] = ACTIONS(5949),
    [anon_sym_XmlPort] = ACTIONS(5949),
    [anon_sym_enum] = ACTIONS(5949),
    [anon_sym_ENUM] = ACTIONS(5949),
    [anon_sym_Enum] = ACTIONS(5949),
    [anon_sym_eNUM] = ACTIONS(5949),
    [anon_sym_eNum] = ACTIONS(5949),
    [anon_sym_ENum] = ACTIONS(5949),
    [sym_quoted_identifier] = ACTIONS(5951),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5951),
    [sym_verbatim_string] = ACTIONS(5951),
    [sym_integer] = ACTIONS(5949),
    [sym_continue_as_identifier] = ACTIONS(5951),
    [sym_preproc_open] = ACTIONS(5951),
    [sym_preproc_close] = ACTIONS(5951),
  },
  [STATE(2495)] = {
    [sym_identifier] = ACTIONS(5953),
    [anon_sym_SEMI] = ACTIONS(5955),
    [anon_sym_DASH] = ACTIONS(5955),
    [aux_sym_boolean_token1] = ACTIONS(5953),
    [aux_sym_boolean_token2] = ACTIONS(5953),
    [sym_decimal] = ACTIONS(5953),
    [anon_sym_LPAREN] = ACTIONS(5955),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5953),
    [anon_sym_LBRACK] = ACTIONS(5955),
    [aux_sym_record_type_token1] = ACTIONS(5953),
    [aux_sym_basic_type_token21] = ACTIONS(5953),
    [aux_sym_basic_type_token22] = ACTIONS(5953),
    [aux_sym_basic_type_token48] = ACTIONS(5953),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5953),
    [anon_sym_POUNDif] = ACTIONS(5955),
    [anon_sym_POUNDIF] = ACTIONS(5955),
    [anon_sym_POUNDIf] = ACTIONS(5955),
    [anon_sym_not] = ACTIONS(5953),
    [anon_sym_NOT] = ACTIONS(5953),
    [anon_sym_Not] = ACTIONS(5953),
    [anon_sym_POUNDelif] = ACTIONS(5955),
    [anon_sym_POUNDELIF] = ACTIONS(5955),
    [anon_sym_POUNDElif] = ACTIONS(5955),
    [anon_sym_POUNDelse] = ACTIONS(5955),
    [anon_sym_POUNDELSE] = ACTIONS(5955),
    [anon_sym_POUNDElse] = ACTIONS(5955),
    [anon_sym_POUNDelse2] = ACTIONS(5955),
    [anon_sym_POUNDELSE2] = ACTIONS(5955),
    [anon_sym_POUNDElse2] = ACTIONS(5955),
    [anon_sym_POUNDendif] = ACTIONS(5955),
    [anon_sym_POUNDENDIF] = ACTIONS(5955),
    [anon_sym_POUNDEndif] = ACTIONS(5955),
    [anon_sym_POUNDendif2] = ACTIONS(5955),
    [anon_sym_POUNDENDIF2] = ACTIONS(5955),
    [anon_sym_POUNDEndif2] = ACTIONS(5955),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5953),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5953),
    [anon_sym_PLUS] = ACTIONS(5955),
    [sym_datetime_literal] = ACTIONS(5955),
    [sym_date_literal] = ACTIONS(5953),
    [sym_time_literal] = ACTIONS(5953),
    [sym_biginteger_literal] = ACTIONS(5955),
    [anon_sym_if] = ACTIONS(5953),
    [anon_sym_IF] = ACTIONS(5953),
    [anon_sym_If] = ACTIONS(5953),
    [anon_sym_else] = ACTIONS(5953),
    [anon_sym_ELSE] = ACTIONS(5953),
    [anon_sym_Else] = ACTIONS(5953),
    [anon_sym_case] = ACTIONS(5953),
    [anon_sym_CASE] = ACTIONS(5953),
    [anon_sym_Case] = ACTIONS(5953),
    [anon_sym_for] = ACTIONS(5953),
    [anon_sym_FOR] = ACTIONS(5953),
    [anon_sym_For] = ACTIONS(5953),
    [anon_sym_foreach] = ACTIONS(5953),
    [anon_sym_FOREACH] = ACTIONS(5953),
    [anon_sym_Foreach] = ACTIONS(5953),
    [anon_sym_while] = ACTIONS(5953),
    [anon_sym_WHILE] = ACTIONS(5953),
    [anon_sym_While] = ACTIONS(5953),
    [anon_sym_repeat] = ACTIONS(5953),
    [anon_sym_REPEAT] = ACTIONS(5953),
    [anon_sym_Repeat] = ACTIONS(5953),
    [anon_sym_exit] = ACTIONS(5953),
    [anon_sym_EXIT] = ACTIONS(5953),
    [anon_sym_Exit] = ACTIONS(5953),
    [anon_sym_continue] = ACTIONS(5953),
    [anon_sym_CONTINUE] = ACTIONS(5953),
    [anon_sym_Continue] = ACTIONS(5953),
    [anon_sym_break] = ACTIONS(5953),
    [anon_sym_BREAK] = ACTIONS(5953),
    [anon_sym_Break] = ACTIONS(5953),
    [anon_sym_with] = ACTIONS(5953),
    [anon_sym_WITH] = ACTIONS(5953),
    [anon_sym_With] = ACTIONS(5953),
    [sym_asserterror_keyword] = ACTIONS(5955),
    [sym_page_keyword] = ACTIONS(5953),
    [anon_sym_codeunit] = ACTIONS(5953),
    [anon_sym_CODEUNIT] = ACTIONS(5953),
    [anon_sym_Codeunit] = ACTIONS(5953),
    [anon_sym_CodeUnit] = ACTIONS(5953),
    [anon_sym_COdeunit] = ACTIONS(5953),
    [anon_sym_codeUnit] = ACTIONS(5953),
    [sym_report_keyword] = ACTIONS(5953),
    [sym_query_keyword] = ACTIONS(5953),
    [anon_sym_xmlport] = ACTIONS(5953),
    [anon_sym_XMLPORT] = ACTIONS(5953),
    [anon_sym_Xmlport] = ACTIONS(5953),
    [anon_sym_XMLport] = ACTIONS(5953),
    [anon_sym_XMLPort] = ACTIONS(5953),
    [anon_sym_XmlPort] = ACTIONS(5953),
    [anon_sym_enum] = ACTIONS(5953),
    [anon_sym_ENUM] = ACTIONS(5953),
    [anon_sym_Enum] = ACTIONS(5953),
    [anon_sym_eNUM] = ACTIONS(5953),
    [anon_sym_eNum] = ACTIONS(5953),
    [anon_sym_ENum] = ACTIONS(5953),
    [sym_quoted_identifier] = ACTIONS(5955),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5955),
    [sym_verbatim_string] = ACTIONS(5955),
    [sym_integer] = ACTIONS(5953),
    [sym_continue_as_identifier] = ACTIONS(5955),
    [sym_preproc_open] = ACTIONS(5955),
    [sym_preproc_close] = ACTIONS(5955),
  },
  [STATE(2496)] = {
    [sym_identifier] = ACTIONS(5957),
    [anon_sym_SEMI] = ACTIONS(5959),
    [anon_sym_DASH] = ACTIONS(5959),
    [aux_sym_boolean_token1] = ACTIONS(5957),
    [aux_sym_boolean_token2] = ACTIONS(5957),
    [sym_decimal] = ACTIONS(5957),
    [anon_sym_LPAREN] = ACTIONS(5959),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5957),
    [anon_sym_LBRACK] = ACTIONS(5959),
    [aux_sym_record_type_token1] = ACTIONS(5957),
    [aux_sym_basic_type_token21] = ACTIONS(5957),
    [aux_sym_basic_type_token22] = ACTIONS(5957),
    [aux_sym_basic_type_token48] = ACTIONS(5957),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5957),
    [anon_sym_POUNDif] = ACTIONS(5959),
    [anon_sym_POUNDIF] = ACTIONS(5959),
    [anon_sym_POUNDIf] = ACTIONS(5959),
    [anon_sym_not] = ACTIONS(5957),
    [anon_sym_NOT] = ACTIONS(5957),
    [anon_sym_Not] = ACTIONS(5957),
    [anon_sym_POUNDelif] = ACTIONS(5959),
    [anon_sym_POUNDELIF] = ACTIONS(5959),
    [anon_sym_POUNDElif] = ACTIONS(5959),
    [anon_sym_POUNDelse] = ACTIONS(5959),
    [anon_sym_POUNDELSE] = ACTIONS(5959),
    [anon_sym_POUNDElse] = ACTIONS(5959),
    [anon_sym_POUNDelse2] = ACTIONS(5959),
    [anon_sym_POUNDELSE2] = ACTIONS(5959),
    [anon_sym_POUNDElse2] = ACTIONS(5959),
    [anon_sym_POUNDendif] = ACTIONS(5959),
    [anon_sym_POUNDENDIF] = ACTIONS(5959),
    [anon_sym_POUNDEndif] = ACTIONS(5959),
    [anon_sym_POUNDendif2] = ACTIONS(5959),
    [anon_sym_POUNDENDIF2] = ACTIONS(5959),
    [anon_sym_POUNDEndif2] = ACTIONS(5959),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5957),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5957),
    [anon_sym_PLUS] = ACTIONS(5959),
    [sym_datetime_literal] = ACTIONS(5959),
    [sym_date_literal] = ACTIONS(5957),
    [sym_time_literal] = ACTIONS(5957),
    [sym_biginteger_literal] = ACTIONS(5959),
    [anon_sym_if] = ACTIONS(5957),
    [anon_sym_IF] = ACTIONS(5957),
    [anon_sym_If] = ACTIONS(5957),
    [anon_sym_else] = ACTIONS(5957),
    [anon_sym_ELSE] = ACTIONS(5957),
    [anon_sym_Else] = ACTIONS(5957),
    [anon_sym_case] = ACTIONS(5957),
    [anon_sym_CASE] = ACTIONS(5957),
    [anon_sym_Case] = ACTIONS(5957),
    [anon_sym_for] = ACTIONS(5957),
    [anon_sym_FOR] = ACTIONS(5957),
    [anon_sym_For] = ACTIONS(5957),
    [anon_sym_foreach] = ACTIONS(5957),
    [anon_sym_FOREACH] = ACTIONS(5957),
    [anon_sym_Foreach] = ACTIONS(5957),
    [anon_sym_while] = ACTIONS(5957),
    [anon_sym_WHILE] = ACTIONS(5957),
    [anon_sym_While] = ACTIONS(5957),
    [anon_sym_repeat] = ACTIONS(5957),
    [anon_sym_REPEAT] = ACTIONS(5957),
    [anon_sym_Repeat] = ACTIONS(5957),
    [anon_sym_exit] = ACTIONS(5957),
    [anon_sym_EXIT] = ACTIONS(5957),
    [anon_sym_Exit] = ACTIONS(5957),
    [anon_sym_continue] = ACTIONS(5957),
    [anon_sym_CONTINUE] = ACTIONS(5957),
    [anon_sym_Continue] = ACTIONS(5957),
    [anon_sym_break] = ACTIONS(5957),
    [anon_sym_BREAK] = ACTIONS(5957),
    [anon_sym_Break] = ACTIONS(5957),
    [anon_sym_with] = ACTIONS(5957),
    [anon_sym_WITH] = ACTIONS(5957),
    [anon_sym_With] = ACTIONS(5957),
    [sym_asserterror_keyword] = ACTIONS(5959),
    [sym_page_keyword] = ACTIONS(5957),
    [anon_sym_codeunit] = ACTIONS(5957),
    [anon_sym_CODEUNIT] = ACTIONS(5957),
    [anon_sym_Codeunit] = ACTIONS(5957),
    [anon_sym_CodeUnit] = ACTIONS(5957),
    [anon_sym_COdeunit] = ACTIONS(5957),
    [anon_sym_codeUnit] = ACTIONS(5957),
    [sym_report_keyword] = ACTIONS(5957),
    [sym_query_keyword] = ACTIONS(5957),
    [anon_sym_xmlport] = ACTIONS(5957),
    [anon_sym_XMLPORT] = ACTIONS(5957),
    [anon_sym_Xmlport] = ACTIONS(5957),
    [anon_sym_XMLport] = ACTIONS(5957),
    [anon_sym_XMLPort] = ACTIONS(5957),
    [anon_sym_XmlPort] = ACTIONS(5957),
    [anon_sym_enum] = ACTIONS(5957),
    [anon_sym_ENUM] = ACTIONS(5957),
    [anon_sym_Enum] = ACTIONS(5957),
    [anon_sym_eNUM] = ACTIONS(5957),
    [anon_sym_eNum] = ACTIONS(5957),
    [anon_sym_ENum] = ACTIONS(5957),
    [sym_quoted_identifier] = ACTIONS(5959),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5959),
    [sym_verbatim_string] = ACTIONS(5959),
    [sym_integer] = ACTIONS(5957),
    [sym_continue_as_identifier] = ACTIONS(5959),
    [sym_preproc_open] = ACTIONS(5959),
    [sym_preproc_close] = ACTIONS(5959),
  },
  [STATE(2497)] = {
    [sym_identifier] = ACTIONS(5957),
    [anon_sym_SEMI] = ACTIONS(5959),
    [anon_sym_DASH] = ACTIONS(5959),
    [aux_sym_boolean_token1] = ACTIONS(5957),
    [aux_sym_boolean_token2] = ACTIONS(5957),
    [sym_decimal] = ACTIONS(5957),
    [anon_sym_LPAREN] = ACTIONS(5959),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5957),
    [anon_sym_LBRACK] = ACTIONS(5959),
    [aux_sym_record_type_token1] = ACTIONS(5957),
    [aux_sym_basic_type_token21] = ACTIONS(5957),
    [aux_sym_basic_type_token22] = ACTIONS(5957),
    [aux_sym_basic_type_token48] = ACTIONS(5957),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5957),
    [anon_sym_POUNDif] = ACTIONS(5959),
    [anon_sym_POUNDIF] = ACTIONS(5959),
    [anon_sym_POUNDIf] = ACTIONS(5959),
    [anon_sym_not] = ACTIONS(5957),
    [anon_sym_NOT] = ACTIONS(5957),
    [anon_sym_Not] = ACTIONS(5957),
    [anon_sym_POUNDelif] = ACTIONS(5959),
    [anon_sym_POUNDELIF] = ACTIONS(5959),
    [anon_sym_POUNDElif] = ACTIONS(5959),
    [anon_sym_POUNDelse] = ACTIONS(5959),
    [anon_sym_POUNDELSE] = ACTIONS(5959),
    [anon_sym_POUNDElse] = ACTIONS(5959),
    [anon_sym_POUNDelse2] = ACTIONS(5959),
    [anon_sym_POUNDELSE2] = ACTIONS(5959),
    [anon_sym_POUNDElse2] = ACTIONS(5959),
    [anon_sym_POUNDendif] = ACTIONS(5959),
    [anon_sym_POUNDENDIF] = ACTIONS(5959),
    [anon_sym_POUNDEndif] = ACTIONS(5959),
    [anon_sym_POUNDendif2] = ACTIONS(5959),
    [anon_sym_POUNDENDIF2] = ACTIONS(5959),
    [anon_sym_POUNDEndif2] = ACTIONS(5959),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5957),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5957),
    [anon_sym_PLUS] = ACTIONS(5959),
    [sym_datetime_literal] = ACTIONS(5959),
    [sym_date_literal] = ACTIONS(5957),
    [sym_time_literal] = ACTIONS(5957),
    [sym_biginteger_literal] = ACTIONS(5959),
    [anon_sym_if] = ACTIONS(5957),
    [anon_sym_IF] = ACTIONS(5957),
    [anon_sym_If] = ACTIONS(5957),
    [anon_sym_else] = ACTIONS(5957),
    [anon_sym_ELSE] = ACTIONS(5957),
    [anon_sym_Else] = ACTIONS(5957),
    [anon_sym_case] = ACTIONS(5957),
    [anon_sym_CASE] = ACTIONS(5957),
    [anon_sym_Case] = ACTIONS(5957),
    [anon_sym_for] = ACTIONS(5957),
    [anon_sym_FOR] = ACTIONS(5957),
    [anon_sym_For] = ACTIONS(5957),
    [anon_sym_foreach] = ACTIONS(5957),
    [anon_sym_FOREACH] = ACTIONS(5957),
    [anon_sym_Foreach] = ACTIONS(5957),
    [anon_sym_while] = ACTIONS(5957),
    [anon_sym_WHILE] = ACTIONS(5957),
    [anon_sym_While] = ACTIONS(5957),
    [anon_sym_repeat] = ACTIONS(5957),
    [anon_sym_REPEAT] = ACTIONS(5957),
    [anon_sym_Repeat] = ACTIONS(5957),
    [anon_sym_exit] = ACTIONS(5957),
    [anon_sym_EXIT] = ACTIONS(5957),
    [anon_sym_Exit] = ACTIONS(5957),
    [anon_sym_continue] = ACTIONS(5957),
    [anon_sym_CONTINUE] = ACTIONS(5957),
    [anon_sym_Continue] = ACTIONS(5957),
    [anon_sym_break] = ACTIONS(5957),
    [anon_sym_BREAK] = ACTIONS(5957),
    [anon_sym_Break] = ACTIONS(5957),
    [anon_sym_with] = ACTIONS(5957),
    [anon_sym_WITH] = ACTIONS(5957),
    [anon_sym_With] = ACTIONS(5957),
    [sym_asserterror_keyword] = ACTIONS(5959),
    [sym_page_keyword] = ACTIONS(5957),
    [anon_sym_codeunit] = ACTIONS(5957),
    [anon_sym_CODEUNIT] = ACTIONS(5957),
    [anon_sym_Codeunit] = ACTIONS(5957),
    [anon_sym_CodeUnit] = ACTIONS(5957),
    [anon_sym_COdeunit] = ACTIONS(5957),
    [anon_sym_codeUnit] = ACTIONS(5957),
    [sym_report_keyword] = ACTIONS(5957),
    [sym_query_keyword] = ACTIONS(5957),
    [anon_sym_xmlport] = ACTIONS(5957),
    [anon_sym_XMLPORT] = ACTIONS(5957),
    [anon_sym_Xmlport] = ACTIONS(5957),
    [anon_sym_XMLport] = ACTIONS(5957),
    [anon_sym_XMLPort] = ACTIONS(5957),
    [anon_sym_XmlPort] = ACTIONS(5957),
    [anon_sym_enum] = ACTIONS(5957),
    [anon_sym_ENUM] = ACTIONS(5957),
    [anon_sym_Enum] = ACTIONS(5957),
    [anon_sym_eNUM] = ACTIONS(5957),
    [anon_sym_eNum] = ACTIONS(5957),
    [anon_sym_ENum] = ACTIONS(5957),
    [sym_quoted_identifier] = ACTIONS(5959),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5959),
    [sym_verbatim_string] = ACTIONS(5959),
    [sym_integer] = ACTIONS(5957),
    [sym_continue_as_identifier] = ACTIONS(5959),
    [sym_preproc_open] = ACTIONS(5959),
    [sym_preproc_close] = ACTIONS(5959),
  },
  [STATE(2498)] = {
    [sym_else_keyword] = STATE(121),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelif] = ACTIONS(5487),
    [anon_sym_POUNDELIF] = ACTIONS(5487),
    [anon_sym_POUNDElif] = ACTIONS(5487),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [anon_sym_POUNDendif] = ACTIONS(5487),
    [anon_sym_POUNDENDIF] = ACTIONS(5487),
    [anon_sym_POUNDEndif] = ACTIONS(5487),
    [anon_sym_POUNDendif2] = ACTIONS(5487),
    [anon_sym_POUNDENDIF2] = ACTIONS(5487),
    [anon_sym_POUNDEndif2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_preproc_close] = ACTIONS(5487),
  },
  [STATE(2499)] = {
    [sym_else_keyword] = STATE(122),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelif] = ACTIONS(5455),
    [anon_sym_POUNDELIF] = ACTIONS(5455),
    [anon_sym_POUNDElif] = ACTIONS(5455),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [anon_sym_POUNDendif] = ACTIONS(5455),
    [anon_sym_POUNDENDIF] = ACTIONS(5455),
    [anon_sym_POUNDEndif] = ACTIONS(5455),
    [anon_sym_POUNDendif2] = ACTIONS(5455),
    [anon_sym_POUNDENDIF2] = ACTIONS(5455),
    [anon_sym_POUNDEndif2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_preproc_close] = ACTIONS(5455),
  },
  [STATE(2500)] = {
    [anon_sym_POUNDif] = ACTIONS(5380),
    [anon_sym_POUNDIF] = ACTIONS(5380),
    [anon_sym_POUNDIf] = ACTIONS(5380),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5380),
    [anon_sym_PIPE_PIPE] = ACTIONS(5380),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5695),
    [anon_sym_AMP_AMP] = ACTIONS(5695),
    [anon_sym_POUNDelif] = ACTIONS(5380),
    [anon_sym_POUNDELIF] = ACTIONS(5380),
    [anon_sym_POUNDElif] = ACTIONS(5380),
    [anon_sym_POUNDelse] = ACTIONS(5380),
    [anon_sym_POUNDELSE] = ACTIONS(5380),
    [anon_sym_POUNDElse] = ACTIONS(5380),
    [anon_sym_POUNDelse2] = ACTIONS(5380),
    [anon_sym_POUNDELSE2] = ACTIONS(5380),
    [anon_sym_POUNDElse2] = ACTIONS(5380),
    [anon_sym_POUNDendif] = ACTIONS(5380),
    [anon_sym_POUNDENDIF] = ACTIONS(5380),
    [anon_sym_POUNDEndif] = ACTIONS(5380),
    [anon_sym_POUNDendif2] = ACTIONS(5380),
    [anon_sym_POUNDENDIF2] = ACTIONS(5380),
    [anon_sym_POUNDEndif2] = ACTIONS(5380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5378),
    [anon_sym_tableextension] = ACTIONS(5380),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5380),
    [anon_sym_Tableextension] = ACTIONS(5380),
    [anon_sym_TableExtension] = ACTIONS(5380),
    [anon_sym_tableExtension] = ACTIONS(5380),
    [sym_page_keyword] = ACTIONS(5378),
    [anon_sym_pageextension] = ACTIONS(5380),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5380),
    [anon_sym_Pageextension] = ACTIONS(5380),
    [anon_sym_PageExtension] = ACTIONS(5380),
    [anon_sym_pageExtension] = ACTIONS(5380),
    [anon_sym_codeunit] = ACTIONS(5380),
    [anon_sym_CODEUNIT] = ACTIONS(5380),
    [anon_sym_Codeunit] = ACTIONS(5380),
    [anon_sym_CodeUnit] = ACTIONS(5380),
    [anon_sym_COdeunit] = ACTIONS(5380),
    [anon_sym_codeUnit] = ACTIONS(5380),
    [sym_report_keyword] = ACTIONS(5378),
    [anon_sym_reportextension] = ACTIONS(5380),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5380),
    [anon_sym_Reportextension] = ACTIONS(5380),
    [anon_sym_ReportExtension] = ACTIONS(5380),
    [anon_sym_reportExtension] = ACTIONS(5380),
    [sym_query_keyword] = ACTIONS(5380),
    [anon_sym_xmlport] = ACTIONS(5380),
    [anon_sym_XMLPORT] = ACTIONS(5380),
    [anon_sym_Xmlport] = ACTIONS(5380),
    [anon_sym_XMLport] = ACTIONS(5380),
    [anon_sym_XMLPort] = ACTIONS(5380),
    [anon_sym_XmlPort] = ACTIONS(5380),
    [anon_sym_enum] = ACTIONS(5378),
    [anon_sym_ENUM] = ACTIONS(5378),
    [anon_sym_Enum] = ACTIONS(5378),
    [anon_sym_eNUM] = ACTIONS(5380),
    [anon_sym_eNum] = ACTIONS(5380),
    [anon_sym_ENum] = ACTIONS(5380),
    [anon_sym_enumextension] = ACTIONS(5380),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5380),
    [anon_sym_Enumextension] = ACTIONS(5380),
    [anon_sym_EnumExtension] = ACTIONS(5380),
    [anon_sym_enumExtension] = ACTIONS(5380),
    [sym_interface_keyword] = ACTIONS(5380),
    [anon_sym_controladdin] = ACTIONS(5380),
    [anon_sym_CONTROLADDIN] = ACTIONS(5380),
    [anon_sym_Controladdin] = ACTIONS(5380),
    [anon_sym_ControlAddIn] = ACTIONS(5380),
    [anon_sym_ControlAddin] = ACTIONS(5380),
    [anon_sym_controlAddIn] = ACTIONS(5380),
    [anon_sym_controlAddin] = ACTIONS(5380),
    [anon_sym_dotnet] = ACTIONS(5380),
    [anon_sym_DOTNET] = ACTIONS(5380),
    [anon_sym_Dotnet] = ACTIONS(5380),
    [anon_sym_DotNet] = ACTIONS(5380),
    [anon_sym_dotNet] = ACTIONS(5380),
    [sym_profile_keyword] = ACTIONS(5378),
    [anon_sym_profileextension] = ACTIONS(5380),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5380),
    [anon_sym_Profileextension] = ACTIONS(5380),
    [anon_sym_ProfileExtension] = ACTIONS(5380),
    [anon_sym_profileExtension] = ACTIONS(5380),
    [anon_sym_permissionset] = ACTIONS(5378),
    [anon_sym_PERMISSIONSET] = ACTIONS(5378),
    [anon_sym_Permissionset] = ACTIONS(5378),
    [anon_sym_PermissionSet] = ACTIONS(5378),
    [anon_sym_permissionSet] = ACTIONS(5378),
    [anon_sym_permissionsetextension] = ACTIONS(5380),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5380),
    [anon_sym_Permissionsetextension] = ACTIONS(5380),
    [anon_sym_PermissionSetExtension] = ACTIONS(5380),
    [anon_sym_permissionSetExtension] = ACTIONS(5380),
    [sym_entitlement_keyword] = ACTIONS(5380),
    [anon_sym_pagecustomization] = ACTIONS(5380),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5380),
    [anon_sym_Pagecustomization] = ACTIONS(5380),
    [anon_sym_PageCustomization] = ACTIONS(5380),
    [anon_sym_pageCustomization] = ACTIONS(5380),
    [sym_namespace_keyword] = ACTIONS(5380),
    [sym_using_keyword] = ACTIONS(5380),
    [sym_fieldgroup_keyword] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5380),
    [sym_preproc_close] = ACTIONS(5380),
  },
  [STATE(2501)] = {
    [sym_else_keyword] = STATE(123),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelif] = ACTIONS(5487),
    [anon_sym_POUNDELIF] = ACTIONS(5487),
    [anon_sym_POUNDElif] = ACTIONS(5487),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [anon_sym_POUNDendif] = ACTIONS(5487),
    [anon_sym_POUNDENDIF] = ACTIONS(5487),
    [anon_sym_POUNDEndif] = ACTIONS(5487),
    [anon_sym_POUNDendif2] = ACTIONS(5487),
    [anon_sym_POUNDENDIF2] = ACTIONS(5487),
    [anon_sym_POUNDEndif2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_preproc_close] = ACTIONS(5487),
  },
  [STATE(2502)] = {
    [sym_else_keyword] = STATE(124),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelif] = ACTIONS(5455),
    [anon_sym_POUNDELIF] = ACTIONS(5455),
    [anon_sym_POUNDElif] = ACTIONS(5455),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [anon_sym_POUNDendif] = ACTIONS(5455),
    [anon_sym_POUNDENDIF] = ACTIONS(5455),
    [anon_sym_POUNDEndif] = ACTIONS(5455),
    [anon_sym_POUNDendif2] = ACTIONS(5455),
    [anon_sym_POUNDENDIF2] = ACTIONS(5455),
    [anon_sym_POUNDEndif2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_preproc_close] = ACTIONS(5455),
  },
  [STATE(2503)] = {
    [sym_else_keyword] = STATE(125),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelif] = ACTIONS(5487),
    [anon_sym_POUNDELIF] = ACTIONS(5487),
    [anon_sym_POUNDElif] = ACTIONS(5487),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [anon_sym_POUNDendif] = ACTIONS(5487),
    [anon_sym_POUNDENDIF] = ACTIONS(5487),
    [anon_sym_POUNDEndif] = ACTIONS(5487),
    [anon_sym_POUNDendif2] = ACTIONS(5487),
    [anon_sym_POUNDENDIF2] = ACTIONS(5487),
    [anon_sym_POUNDEndif2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_preproc_close] = ACTIONS(5487),
  },
  [STATE(2504)] = {
    [sym_else_keyword] = STATE(126),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelif] = ACTIONS(5455),
    [anon_sym_POUNDELIF] = ACTIONS(5455),
    [anon_sym_POUNDElif] = ACTIONS(5455),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [anon_sym_POUNDendif] = ACTIONS(5455),
    [anon_sym_POUNDENDIF] = ACTIONS(5455),
    [anon_sym_POUNDEndif] = ACTIONS(5455),
    [anon_sym_POUNDendif2] = ACTIONS(5455),
    [anon_sym_POUNDENDIF2] = ACTIONS(5455),
    [anon_sym_POUNDEndif2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_preproc_close] = ACTIONS(5455),
  },
  [STATE(2505)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5963),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(2506)] = {
    [sym_identifier] = ACTIONS(5967),
    [anon_sym_SEMI] = ACTIONS(5969),
    [anon_sym_DASH] = ACTIONS(5969),
    [aux_sym_boolean_token1] = ACTIONS(5967),
    [aux_sym_boolean_token2] = ACTIONS(5967),
    [sym_decimal] = ACTIONS(5967),
    [anon_sym_LPAREN] = ACTIONS(5969),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5967),
    [anon_sym_LBRACK] = ACTIONS(5969),
    [aux_sym_record_type_token1] = ACTIONS(5967),
    [aux_sym_basic_type_token21] = ACTIONS(5967),
    [aux_sym_basic_type_token22] = ACTIONS(5967),
    [aux_sym_basic_type_token48] = ACTIONS(5967),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5967),
    [anon_sym_POUNDif] = ACTIONS(5969),
    [anon_sym_POUNDIF] = ACTIONS(5969),
    [anon_sym_POUNDIf] = ACTIONS(5969),
    [anon_sym_not] = ACTIONS(5967),
    [anon_sym_NOT] = ACTIONS(5967),
    [anon_sym_Not] = ACTIONS(5967),
    [anon_sym_POUNDelif] = ACTIONS(5969),
    [anon_sym_POUNDELIF] = ACTIONS(5969),
    [anon_sym_POUNDElif] = ACTIONS(5969),
    [anon_sym_POUNDelse] = ACTIONS(5969),
    [anon_sym_POUNDELSE] = ACTIONS(5969),
    [anon_sym_POUNDElse] = ACTIONS(5969),
    [anon_sym_POUNDelse2] = ACTIONS(5969),
    [anon_sym_POUNDELSE2] = ACTIONS(5969),
    [anon_sym_POUNDElse2] = ACTIONS(5969),
    [anon_sym_POUNDendif] = ACTIONS(5969),
    [anon_sym_POUNDENDIF] = ACTIONS(5969),
    [anon_sym_POUNDEndif] = ACTIONS(5969),
    [anon_sym_POUNDendif2] = ACTIONS(5969),
    [anon_sym_POUNDENDIF2] = ACTIONS(5969),
    [anon_sym_POUNDEndif2] = ACTIONS(5969),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5967),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5967),
    [anon_sym_PLUS] = ACTIONS(5969),
    [sym_datetime_literal] = ACTIONS(5969),
    [sym_date_literal] = ACTIONS(5967),
    [sym_time_literal] = ACTIONS(5967),
    [sym_biginteger_literal] = ACTIONS(5969),
    [anon_sym_if] = ACTIONS(5967),
    [anon_sym_IF] = ACTIONS(5967),
    [anon_sym_If] = ACTIONS(5967),
    [anon_sym_else] = ACTIONS(5967),
    [anon_sym_ELSE] = ACTIONS(5967),
    [anon_sym_Else] = ACTIONS(5967),
    [anon_sym_case] = ACTIONS(5967),
    [anon_sym_CASE] = ACTIONS(5967),
    [anon_sym_Case] = ACTIONS(5967),
    [anon_sym_for] = ACTIONS(5967),
    [anon_sym_FOR] = ACTIONS(5967),
    [anon_sym_For] = ACTIONS(5967),
    [anon_sym_foreach] = ACTIONS(5967),
    [anon_sym_FOREACH] = ACTIONS(5967),
    [anon_sym_Foreach] = ACTIONS(5967),
    [anon_sym_while] = ACTIONS(5967),
    [anon_sym_WHILE] = ACTIONS(5967),
    [anon_sym_While] = ACTIONS(5967),
    [anon_sym_repeat] = ACTIONS(5967),
    [anon_sym_REPEAT] = ACTIONS(5967),
    [anon_sym_Repeat] = ACTIONS(5967),
    [anon_sym_exit] = ACTIONS(5967),
    [anon_sym_EXIT] = ACTIONS(5967),
    [anon_sym_Exit] = ACTIONS(5967),
    [anon_sym_continue] = ACTIONS(5967),
    [anon_sym_CONTINUE] = ACTIONS(5967),
    [anon_sym_Continue] = ACTIONS(5967),
    [anon_sym_break] = ACTIONS(5967),
    [anon_sym_BREAK] = ACTIONS(5967),
    [anon_sym_Break] = ACTIONS(5967),
    [anon_sym_with] = ACTIONS(5967),
    [anon_sym_WITH] = ACTIONS(5967),
    [anon_sym_With] = ACTIONS(5967),
    [sym_asserterror_keyword] = ACTIONS(5969),
    [sym_page_keyword] = ACTIONS(5967),
    [anon_sym_codeunit] = ACTIONS(5967),
    [anon_sym_CODEUNIT] = ACTIONS(5967),
    [anon_sym_Codeunit] = ACTIONS(5967),
    [anon_sym_CodeUnit] = ACTIONS(5967),
    [anon_sym_COdeunit] = ACTIONS(5967),
    [anon_sym_codeUnit] = ACTIONS(5967),
    [sym_report_keyword] = ACTIONS(5967),
    [sym_query_keyword] = ACTIONS(5967),
    [anon_sym_xmlport] = ACTIONS(5967),
    [anon_sym_XMLPORT] = ACTIONS(5967),
    [anon_sym_Xmlport] = ACTIONS(5967),
    [anon_sym_XMLport] = ACTIONS(5967),
    [anon_sym_XMLPort] = ACTIONS(5967),
    [anon_sym_XmlPort] = ACTIONS(5967),
    [anon_sym_enum] = ACTIONS(5967),
    [anon_sym_ENUM] = ACTIONS(5967),
    [anon_sym_Enum] = ACTIONS(5967),
    [anon_sym_eNUM] = ACTIONS(5967),
    [anon_sym_eNum] = ACTIONS(5967),
    [anon_sym_ENum] = ACTIONS(5967),
    [sym_quoted_identifier] = ACTIONS(5969),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5969),
    [sym_verbatim_string] = ACTIONS(5969),
    [sym_integer] = ACTIONS(5967),
    [sym_continue_as_identifier] = ACTIONS(5969),
    [sym_preproc_open] = ACTIONS(5969),
    [sym_preproc_close] = ACTIONS(5969),
  },
  [STATE(2507)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5971),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(2508)] = {
    [sym_identifier] = ACTIONS(5973),
    [anon_sym_SEMI] = ACTIONS(5975),
    [anon_sym_DASH] = ACTIONS(5975),
    [aux_sym_boolean_token1] = ACTIONS(5973),
    [aux_sym_boolean_token2] = ACTIONS(5973),
    [sym_decimal] = ACTIONS(5973),
    [anon_sym_LPAREN] = ACTIONS(5975),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5973),
    [anon_sym_LBRACK] = ACTIONS(5975),
    [aux_sym_record_type_token1] = ACTIONS(5973),
    [aux_sym_basic_type_token21] = ACTIONS(5973),
    [aux_sym_basic_type_token22] = ACTIONS(5973),
    [aux_sym_basic_type_token48] = ACTIONS(5973),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5973),
    [anon_sym_POUNDif] = ACTIONS(5975),
    [anon_sym_POUNDIF] = ACTIONS(5975),
    [anon_sym_POUNDIf] = ACTIONS(5975),
    [anon_sym_not] = ACTIONS(5973),
    [anon_sym_NOT] = ACTIONS(5973),
    [anon_sym_Not] = ACTIONS(5973),
    [anon_sym_POUNDelif] = ACTIONS(5975),
    [anon_sym_POUNDELIF] = ACTIONS(5975),
    [anon_sym_POUNDElif] = ACTIONS(5975),
    [anon_sym_POUNDelse] = ACTIONS(5975),
    [anon_sym_POUNDELSE] = ACTIONS(5975),
    [anon_sym_POUNDElse] = ACTIONS(5975),
    [anon_sym_POUNDelse2] = ACTIONS(5975),
    [anon_sym_POUNDELSE2] = ACTIONS(5975),
    [anon_sym_POUNDElse2] = ACTIONS(5975),
    [anon_sym_POUNDendif] = ACTIONS(5975),
    [anon_sym_POUNDENDIF] = ACTIONS(5975),
    [anon_sym_POUNDEndif] = ACTIONS(5975),
    [anon_sym_POUNDendif2] = ACTIONS(5975),
    [anon_sym_POUNDENDIF2] = ACTIONS(5975),
    [anon_sym_POUNDEndif2] = ACTIONS(5975),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5973),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5973),
    [anon_sym_PLUS] = ACTIONS(5975),
    [sym_datetime_literal] = ACTIONS(5975),
    [sym_date_literal] = ACTIONS(5973),
    [sym_time_literal] = ACTIONS(5973),
    [sym_biginteger_literal] = ACTIONS(5975),
    [anon_sym_if] = ACTIONS(5973),
    [anon_sym_IF] = ACTIONS(5973),
    [anon_sym_If] = ACTIONS(5973),
    [anon_sym_else] = ACTIONS(5973),
    [anon_sym_ELSE] = ACTIONS(5973),
    [anon_sym_Else] = ACTIONS(5973),
    [anon_sym_case] = ACTIONS(5973),
    [anon_sym_CASE] = ACTIONS(5973),
    [anon_sym_Case] = ACTIONS(5973),
    [anon_sym_for] = ACTIONS(5973),
    [anon_sym_FOR] = ACTIONS(5973),
    [anon_sym_For] = ACTIONS(5973),
    [anon_sym_foreach] = ACTIONS(5973),
    [anon_sym_FOREACH] = ACTIONS(5973),
    [anon_sym_Foreach] = ACTIONS(5973),
    [anon_sym_while] = ACTIONS(5973),
    [anon_sym_WHILE] = ACTIONS(5973),
    [anon_sym_While] = ACTIONS(5973),
    [anon_sym_repeat] = ACTIONS(5973),
    [anon_sym_REPEAT] = ACTIONS(5973),
    [anon_sym_Repeat] = ACTIONS(5973),
    [anon_sym_exit] = ACTIONS(5973),
    [anon_sym_EXIT] = ACTIONS(5973),
    [anon_sym_Exit] = ACTIONS(5973),
    [anon_sym_continue] = ACTIONS(5973),
    [anon_sym_CONTINUE] = ACTIONS(5973),
    [anon_sym_Continue] = ACTIONS(5973),
    [anon_sym_break] = ACTIONS(5973),
    [anon_sym_BREAK] = ACTIONS(5973),
    [anon_sym_Break] = ACTIONS(5973),
    [anon_sym_with] = ACTIONS(5973),
    [anon_sym_WITH] = ACTIONS(5973),
    [anon_sym_With] = ACTIONS(5973),
    [sym_asserterror_keyword] = ACTIONS(5975),
    [sym_page_keyword] = ACTIONS(5973),
    [anon_sym_codeunit] = ACTIONS(5973),
    [anon_sym_CODEUNIT] = ACTIONS(5973),
    [anon_sym_Codeunit] = ACTIONS(5973),
    [anon_sym_CodeUnit] = ACTIONS(5973),
    [anon_sym_COdeunit] = ACTIONS(5973),
    [anon_sym_codeUnit] = ACTIONS(5973),
    [sym_report_keyword] = ACTIONS(5973),
    [sym_query_keyword] = ACTIONS(5973),
    [anon_sym_xmlport] = ACTIONS(5973),
    [anon_sym_XMLPORT] = ACTIONS(5973),
    [anon_sym_Xmlport] = ACTIONS(5973),
    [anon_sym_XMLport] = ACTIONS(5973),
    [anon_sym_XMLPort] = ACTIONS(5973),
    [anon_sym_XmlPort] = ACTIONS(5973),
    [anon_sym_enum] = ACTIONS(5973),
    [anon_sym_ENUM] = ACTIONS(5973),
    [anon_sym_Enum] = ACTIONS(5973),
    [anon_sym_eNUM] = ACTIONS(5973),
    [anon_sym_eNum] = ACTIONS(5973),
    [anon_sym_ENum] = ACTIONS(5973),
    [sym_quoted_identifier] = ACTIONS(5975),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5975),
    [sym_verbatim_string] = ACTIONS(5975),
    [sym_integer] = ACTIONS(5973),
    [sym_continue_as_identifier] = ACTIONS(5975),
    [sym_preproc_open] = ACTIONS(5975),
    [sym_preproc_close] = ACTIONS(5975),
  },
  [STATE(2509)] = {
    [sym__body_element] = STATE(4033),
    [sym_empty_statement] = STATE(4033),
    [sym_property] = STATE(6513),
    [sym_permissions_property] = STATE(4033),
    [sym_table_relation_property] = STATE(4033),
    [sym_fields_section] = STATE(4033),
    [sym_keys_section] = STATE(4033),
    [sym_fieldgroups_section] = STATE(4033),
    [sym_enum_value_declaration] = STATE(4033),
    [sym_labels_section] = STATE(4033),
    [sym_layout_section] = STATE(4033),
    [sym_modify_modification] = STATE(4033),
    [sym_actions_section] = STATE(4033),
    [sym__action_element] = STATE(6523),
    [sym_action_area_section] = STATE(6523),
    [sym_action_group_section] = STATE(6523),
    [sym_action_declaration] = STATE(6523),
    [sym_separator_action] = STATE(6523),
    [sym_actionref_declaration] = STATE(6523),
    [sym_systemaction_declaration] = STATE(6523),
    [sym_fileuploadaction_declaration] = STATE(6523),
    [sym_customaction_declaration] = STATE(6523),
    [sym_addfirst_action_modification] = STATE(6523),
    [sym_addlast_action_modification] = STATE(6523),
    [sym_addafter_action_modification] = STATE(6523),
    [sym_addbefore_action_modification] = STATE(6523),
    [sym_modify_action_modification] = STATE(6523),
    [sym_views_section] = STATE(4033),
    [sym_dataset_section] = STATE(4033),
    [sym_requestpage_section] = STATE(4033),
    [sym_rendering_section] = STATE(4033),
    [sym_elements_section] = STATE(4033),
    [sym_schema_section] = STATE(4033),
    [sym_assembly_declaration] = STATE(4033),
    [sym_event_declaration] = STATE(4033),
    [sym_procedure] = STATE(4033),
    [sym_preproc_split_procedure] = STATE(4033),
    [sym_preproc_split_procedure_preamble] = STATE(4033),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(6513),
    [sym_var_section] = STATE(4033),
    [sym_attribute_item] = STATE(6513),
    [sym_preproc_conditional] = STATE(4033),
    [sym_preproc_if] = STATE(2238),
    [sym_preproc_conditional_actions] = STATE(6523),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4033),
    [aux_sym_actions_section_repeat1] = STATE(6523),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(5201),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(5977),
    [anon_sym_POUNDELIF] = ACTIONS(5977),
    [anon_sym_POUNDElif] = ACTIONS(5977),
    [anon_sym_POUNDelse] = ACTIONS(5977),
    [anon_sym_POUNDELSE] = ACTIONS(5977),
    [anon_sym_POUNDElse] = ACTIONS(5977),
    [anon_sym_POUNDelse2] = ACTIONS(5977),
    [anon_sym_POUNDELSE2] = ACTIONS(5977),
    [anon_sym_POUNDElse2] = ACTIONS(5977),
    [anon_sym_POUNDendif] = ACTIONS(5977),
    [anon_sym_POUNDENDIF] = ACTIONS(5977),
    [anon_sym_POUNDEndif] = ACTIONS(5977),
    [anon_sym_POUNDendif2] = ACTIONS(5977),
    [anon_sym_POUNDENDIF2] = ACTIONS(5977),
    [anon_sym_POUNDEndif2] = ACTIONS(5977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5977),
  },
  [STATE(2510)] = {
    [anon_sym_POUNDif] = ACTIONS(5376),
    [anon_sym_POUNDIF] = ACTIONS(5376),
    [anon_sym_POUNDIf] = ACTIONS(5376),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5376),
    [anon_sym_PIPE_PIPE] = ACTIONS(5376),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5376),
    [anon_sym_AMP_AMP] = ACTIONS(5376),
    [anon_sym_POUNDelif] = ACTIONS(5376),
    [anon_sym_POUNDELIF] = ACTIONS(5376),
    [anon_sym_POUNDElif] = ACTIONS(5376),
    [anon_sym_POUNDelse] = ACTIONS(5376),
    [anon_sym_POUNDELSE] = ACTIONS(5376),
    [anon_sym_POUNDElse] = ACTIONS(5376),
    [anon_sym_POUNDelse2] = ACTIONS(5376),
    [anon_sym_POUNDELSE2] = ACTIONS(5376),
    [anon_sym_POUNDElse2] = ACTIONS(5376),
    [anon_sym_POUNDendif] = ACTIONS(5376),
    [anon_sym_POUNDENDIF] = ACTIONS(5376),
    [anon_sym_POUNDEndif] = ACTIONS(5376),
    [anon_sym_POUNDendif2] = ACTIONS(5376),
    [anon_sym_POUNDENDIF2] = ACTIONS(5376),
    [anon_sym_POUNDEndif2] = ACTIONS(5376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5374),
    [anon_sym_tableextension] = ACTIONS(5376),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5376),
    [anon_sym_Tableextension] = ACTIONS(5376),
    [anon_sym_TableExtension] = ACTIONS(5376),
    [anon_sym_tableExtension] = ACTIONS(5376),
    [sym_page_keyword] = ACTIONS(5374),
    [anon_sym_pageextension] = ACTIONS(5376),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5376),
    [anon_sym_Pageextension] = ACTIONS(5376),
    [anon_sym_PageExtension] = ACTIONS(5376),
    [anon_sym_pageExtension] = ACTIONS(5376),
    [anon_sym_codeunit] = ACTIONS(5376),
    [anon_sym_CODEUNIT] = ACTIONS(5376),
    [anon_sym_Codeunit] = ACTIONS(5376),
    [anon_sym_CodeUnit] = ACTIONS(5376),
    [anon_sym_COdeunit] = ACTIONS(5376),
    [anon_sym_codeUnit] = ACTIONS(5376),
    [sym_report_keyword] = ACTIONS(5374),
    [anon_sym_reportextension] = ACTIONS(5376),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5376),
    [anon_sym_Reportextension] = ACTIONS(5376),
    [anon_sym_ReportExtension] = ACTIONS(5376),
    [anon_sym_reportExtension] = ACTIONS(5376),
    [sym_query_keyword] = ACTIONS(5376),
    [anon_sym_xmlport] = ACTIONS(5376),
    [anon_sym_XMLPORT] = ACTIONS(5376),
    [anon_sym_Xmlport] = ACTIONS(5376),
    [anon_sym_XMLport] = ACTIONS(5376),
    [anon_sym_XMLPort] = ACTIONS(5376),
    [anon_sym_XmlPort] = ACTIONS(5376),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_ENUM] = ACTIONS(5374),
    [anon_sym_Enum] = ACTIONS(5374),
    [anon_sym_eNUM] = ACTIONS(5376),
    [anon_sym_eNum] = ACTIONS(5376),
    [anon_sym_ENum] = ACTIONS(5376),
    [anon_sym_enumextension] = ACTIONS(5376),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5376),
    [anon_sym_Enumextension] = ACTIONS(5376),
    [anon_sym_EnumExtension] = ACTIONS(5376),
    [anon_sym_enumExtension] = ACTIONS(5376),
    [sym_interface_keyword] = ACTIONS(5376),
    [anon_sym_controladdin] = ACTIONS(5376),
    [anon_sym_CONTROLADDIN] = ACTIONS(5376),
    [anon_sym_Controladdin] = ACTIONS(5376),
    [anon_sym_ControlAddIn] = ACTIONS(5376),
    [anon_sym_ControlAddin] = ACTIONS(5376),
    [anon_sym_controlAddIn] = ACTIONS(5376),
    [anon_sym_controlAddin] = ACTIONS(5376),
    [anon_sym_dotnet] = ACTIONS(5376),
    [anon_sym_DOTNET] = ACTIONS(5376),
    [anon_sym_Dotnet] = ACTIONS(5376),
    [anon_sym_DotNet] = ACTIONS(5376),
    [anon_sym_dotNet] = ACTIONS(5376),
    [sym_profile_keyword] = ACTIONS(5374),
    [anon_sym_profileextension] = ACTIONS(5376),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5376),
    [anon_sym_Profileextension] = ACTIONS(5376),
    [anon_sym_ProfileExtension] = ACTIONS(5376),
    [anon_sym_profileExtension] = ACTIONS(5376),
    [anon_sym_permissionset] = ACTIONS(5374),
    [anon_sym_PERMISSIONSET] = ACTIONS(5374),
    [anon_sym_Permissionset] = ACTIONS(5374),
    [anon_sym_PermissionSet] = ACTIONS(5374),
    [anon_sym_permissionSet] = ACTIONS(5374),
    [anon_sym_permissionsetextension] = ACTIONS(5376),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5376),
    [anon_sym_Permissionsetextension] = ACTIONS(5376),
    [anon_sym_PermissionSetExtension] = ACTIONS(5376),
    [anon_sym_permissionSetExtension] = ACTIONS(5376),
    [sym_entitlement_keyword] = ACTIONS(5376),
    [anon_sym_pagecustomization] = ACTIONS(5376),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5376),
    [anon_sym_Pagecustomization] = ACTIONS(5376),
    [anon_sym_PageCustomization] = ACTIONS(5376),
    [anon_sym_pageCustomization] = ACTIONS(5376),
    [sym_namespace_keyword] = ACTIONS(5376),
    [sym_using_keyword] = ACTIONS(5376),
    [sym_fieldgroup_keyword] = ACTIONS(5376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5376),
    [sym_preproc_close] = ACTIONS(5376),
  },
  [STATE(2511)] = {
    [anon_sym_POUNDif] = ACTIONS(5401),
    [anon_sym_POUNDIF] = ACTIONS(5401),
    [anon_sym_POUNDIf] = ACTIONS(5401),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5693),
    [anon_sym_PIPE_PIPE] = ACTIONS(5693),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5695),
    [anon_sym_AMP_AMP] = ACTIONS(5695),
    [anon_sym_POUNDelif] = ACTIONS(5401),
    [anon_sym_POUNDELIF] = ACTIONS(5401),
    [anon_sym_POUNDElif] = ACTIONS(5401),
    [anon_sym_POUNDelse] = ACTIONS(5401),
    [anon_sym_POUNDELSE] = ACTIONS(5401),
    [anon_sym_POUNDElse] = ACTIONS(5401),
    [anon_sym_POUNDelse2] = ACTIONS(5401),
    [anon_sym_POUNDELSE2] = ACTIONS(5401),
    [anon_sym_POUNDElse2] = ACTIONS(5401),
    [anon_sym_POUNDendif] = ACTIONS(5401),
    [anon_sym_POUNDENDIF] = ACTIONS(5401),
    [anon_sym_POUNDEndif] = ACTIONS(5401),
    [anon_sym_POUNDendif2] = ACTIONS(5401),
    [anon_sym_POUNDENDIF2] = ACTIONS(5401),
    [anon_sym_POUNDEndif2] = ACTIONS(5401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5399),
    [anon_sym_tableextension] = ACTIONS(5401),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5401),
    [anon_sym_Tableextension] = ACTIONS(5401),
    [anon_sym_TableExtension] = ACTIONS(5401),
    [anon_sym_tableExtension] = ACTIONS(5401),
    [sym_page_keyword] = ACTIONS(5399),
    [anon_sym_pageextension] = ACTIONS(5401),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5401),
    [anon_sym_Pageextension] = ACTIONS(5401),
    [anon_sym_PageExtension] = ACTIONS(5401),
    [anon_sym_pageExtension] = ACTIONS(5401),
    [anon_sym_codeunit] = ACTIONS(5401),
    [anon_sym_CODEUNIT] = ACTIONS(5401),
    [anon_sym_Codeunit] = ACTIONS(5401),
    [anon_sym_CodeUnit] = ACTIONS(5401),
    [anon_sym_COdeunit] = ACTIONS(5401),
    [anon_sym_codeUnit] = ACTIONS(5401),
    [sym_report_keyword] = ACTIONS(5399),
    [anon_sym_reportextension] = ACTIONS(5401),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5401),
    [anon_sym_Reportextension] = ACTIONS(5401),
    [anon_sym_ReportExtension] = ACTIONS(5401),
    [anon_sym_reportExtension] = ACTIONS(5401),
    [sym_query_keyword] = ACTIONS(5401),
    [anon_sym_xmlport] = ACTIONS(5401),
    [anon_sym_XMLPORT] = ACTIONS(5401),
    [anon_sym_Xmlport] = ACTIONS(5401),
    [anon_sym_XMLport] = ACTIONS(5401),
    [anon_sym_XMLPort] = ACTIONS(5401),
    [anon_sym_XmlPort] = ACTIONS(5401),
    [anon_sym_enum] = ACTIONS(5399),
    [anon_sym_ENUM] = ACTIONS(5399),
    [anon_sym_Enum] = ACTIONS(5399),
    [anon_sym_eNUM] = ACTIONS(5401),
    [anon_sym_eNum] = ACTIONS(5401),
    [anon_sym_ENum] = ACTIONS(5401),
    [anon_sym_enumextension] = ACTIONS(5401),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5401),
    [anon_sym_Enumextension] = ACTIONS(5401),
    [anon_sym_EnumExtension] = ACTIONS(5401),
    [anon_sym_enumExtension] = ACTIONS(5401),
    [sym_interface_keyword] = ACTIONS(5401),
    [anon_sym_controladdin] = ACTIONS(5401),
    [anon_sym_CONTROLADDIN] = ACTIONS(5401),
    [anon_sym_Controladdin] = ACTIONS(5401),
    [anon_sym_ControlAddIn] = ACTIONS(5401),
    [anon_sym_ControlAddin] = ACTIONS(5401),
    [anon_sym_controlAddIn] = ACTIONS(5401),
    [anon_sym_controlAddin] = ACTIONS(5401),
    [anon_sym_dotnet] = ACTIONS(5401),
    [anon_sym_DOTNET] = ACTIONS(5401),
    [anon_sym_Dotnet] = ACTIONS(5401),
    [anon_sym_DotNet] = ACTIONS(5401),
    [anon_sym_dotNet] = ACTIONS(5401),
    [sym_profile_keyword] = ACTIONS(5399),
    [anon_sym_profileextension] = ACTIONS(5401),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5401),
    [anon_sym_Profileextension] = ACTIONS(5401),
    [anon_sym_ProfileExtension] = ACTIONS(5401),
    [anon_sym_profileExtension] = ACTIONS(5401),
    [anon_sym_permissionset] = ACTIONS(5399),
    [anon_sym_PERMISSIONSET] = ACTIONS(5399),
    [anon_sym_Permissionset] = ACTIONS(5399),
    [anon_sym_PermissionSet] = ACTIONS(5399),
    [anon_sym_permissionSet] = ACTIONS(5399),
    [anon_sym_permissionsetextension] = ACTIONS(5401),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5401),
    [anon_sym_Permissionsetextension] = ACTIONS(5401),
    [anon_sym_PermissionSetExtension] = ACTIONS(5401),
    [anon_sym_permissionSetExtension] = ACTIONS(5401),
    [sym_entitlement_keyword] = ACTIONS(5401),
    [anon_sym_pagecustomization] = ACTIONS(5401),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5401),
    [anon_sym_Pagecustomization] = ACTIONS(5401),
    [anon_sym_PageCustomization] = ACTIONS(5401),
    [anon_sym_pageCustomization] = ACTIONS(5401),
    [sym_namespace_keyword] = ACTIONS(5401),
    [sym_using_keyword] = ACTIONS(5401),
    [sym_fieldgroup_keyword] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5401),
    [sym_preproc_close] = ACTIONS(5401),
  },
  [STATE(2512)] = {
    [sym_identifier] = ACTIONS(5980),
    [anon_sym_SEMI] = ACTIONS(5982),
    [anon_sym_DASH] = ACTIONS(5982),
    [aux_sym_boolean_token1] = ACTIONS(5980),
    [aux_sym_boolean_token2] = ACTIONS(5980),
    [sym_decimal] = ACTIONS(5980),
    [anon_sym_LPAREN] = ACTIONS(5982),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5980),
    [anon_sym_LBRACK] = ACTIONS(5982),
    [aux_sym_record_type_token1] = ACTIONS(5980),
    [aux_sym_basic_type_token21] = ACTIONS(5980),
    [aux_sym_basic_type_token22] = ACTIONS(5980),
    [aux_sym_basic_type_token48] = ACTIONS(5980),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5980),
    [anon_sym_POUNDif] = ACTIONS(5982),
    [anon_sym_POUNDIF] = ACTIONS(5982),
    [anon_sym_POUNDIf] = ACTIONS(5982),
    [anon_sym_not] = ACTIONS(5980),
    [anon_sym_NOT] = ACTIONS(5980),
    [anon_sym_Not] = ACTIONS(5980),
    [anon_sym_POUNDelif] = ACTIONS(5982),
    [anon_sym_POUNDELIF] = ACTIONS(5982),
    [anon_sym_POUNDElif] = ACTIONS(5982),
    [anon_sym_POUNDelse] = ACTIONS(5982),
    [anon_sym_POUNDELSE] = ACTIONS(5982),
    [anon_sym_POUNDElse] = ACTIONS(5982),
    [anon_sym_POUNDelse2] = ACTIONS(5982),
    [anon_sym_POUNDELSE2] = ACTIONS(5982),
    [anon_sym_POUNDElse2] = ACTIONS(5982),
    [anon_sym_POUNDendif] = ACTIONS(5982),
    [anon_sym_POUNDENDIF] = ACTIONS(5982),
    [anon_sym_POUNDEndif] = ACTIONS(5982),
    [anon_sym_POUNDendif2] = ACTIONS(5982),
    [anon_sym_POUNDENDIF2] = ACTIONS(5982),
    [anon_sym_POUNDEndif2] = ACTIONS(5982),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5980),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5980),
    [anon_sym_PLUS] = ACTIONS(5982),
    [sym_datetime_literal] = ACTIONS(5982),
    [sym_date_literal] = ACTIONS(5980),
    [sym_time_literal] = ACTIONS(5980),
    [sym_biginteger_literal] = ACTIONS(5982),
    [anon_sym_if] = ACTIONS(5980),
    [anon_sym_IF] = ACTIONS(5980),
    [anon_sym_If] = ACTIONS(5980),
    [anon_sym_else] = ACTIONS(5980),
    [anon_sym_ELSE] = ACTIONS(5980),
    [anon_sym_Else] = ACTIONS(5980),
    [anon_sym_case] = ACTIONS(5980),
    [anon_sym_CASE] = ACTIONS(5980),
    [anon_sym_Case] = ACTIONS(5980),
    [anon_sym_for] = ACTIONS(5980),
    [anon_sym_FOR] = ACTIONS(5980),
    [anon_sym_For] = ACTIONS(5980),
    [anon_sym_foreach] = ACTIONS(5980),
    [anon_sym_FOREACH] = ACTIONS(5980),
    [anon_sym_Foreach] = ACTIONS(5980),
    [anon_sym_while] = ACTIONS(5980),
    [anon_sym_WHILE] = ACTIONS(5980),
    [anon_sym_While] = ACTIONS(5980),
    [anon_sym_repeat] = ACTIONS(5980),
    [anon_sym_REPEAT] = ACTIONS(5980),
    [anon_sym_Repeat] = ACTIONS(5980),
    [anon_sym_exit] = ACTIONS(5980),
    [anon_sym_EXIT] = ACTIONS(5980),
    [anon_sym_Exit] = ACTIONS(5980),
    [anon_sym_continue] = ACTIONS(5980),
    [anon_sym_CONTINUE] = ACTIONS(5980),
    [anon_sym_Continue] = ACTIONS(5980),
    [anon_sym_break] = ACTIONS(5980),
    [anon_sym_BREAK] = ACTIONS(5980),
    [anon_sym_Break] = ACTIONS(5980),
    [anon_sym_with] = ACTIONS(5980),
    [anon_sym_WITH] = ACTIONS(5980),
    [anon_sym_With] = ACTIONS(5980),
    [sym_asserterror_keyword] = ACTIONS(5982),
    [sym_page_keyword] = ACTIONS(5980),
    [anon_sym_codeunit] = ACTIONS(5980),
    [anon_sym_CODEUNIT] = ACTIONS(5980),
    [anon_sym_Codeunit] = ACTIONS(5980),
    [anon_sym_CodeUnit] = ACTIONS(5980),
    [anon_sym_COdeunit] = ACTIONS(5980),
    [anon_sym_codeUnit] = ACTIONS(5980),
    [sym_report_keyword] = ACTIONS(5980),
    [sym_query_keyword] = ACTIONS(5980),
    [anon_sym_xmlport] = ACTIONS(5980),
    [anon_sym_XMLPORT] = ACTIONS(5980),
    [anon_sym_Xmlport] = ACTIONS(5980),
    [anon_sym_XMLport] = ACTIONS(5980),
    [anon_sym_XMLPort] = ACTIONS(5980),
    [anon_sym_XmlPort] = ACTIONS(5980),
    [anon_sym_enum] = ACTIONS(5980),
    [anon_sym_ENUM] = ACTIONS(5980),
    [anon_sym_Enum] = ACTIONS(5980),
    [anon_sym_eNUM] = ACTIONS(5980),
    [anon_sym_eNum] = ACTIONS(5980),
    [anon_sym_ENum] = ACTIONS(5980),
    [sym_quoted_identifier] = ACTIONS(5982),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5982),
    [sym_verbatim_string] = ACTIONS(5982),
    [sym_integer] = ACTIONS(5980),
    [sym_continue_as_identifier] = ACTIONS(5982),
    [sym_preproc_open] = ACTIONS(5982),
    [sym_preproc_close] = ACTIONS(5982),
  },
  [STATE(2513)] = {
    [sym_identifier] = ACTIONS(5984),
    [anon_sym_SEMI] = ACTIONS(5986),
    [anon_sym_DASH] = ACTIONS(5986),
    [aux_sym_boolean_token1] = ACTIONS(5984),
    [aux_sym_boolean_token2] = ACTIONS(5984),
    [sym_decimal] = ACTIONS(5984),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5984),
    [anon_sym_LBRACK] = ACTIONS(5986),
    [aux_sym_record_type_token1] = ACTIONS(5984),
    [aux_sym_basic_type_token21] = ACTIONS(5984),
    [aux_sym_basic_type_token22] = ACTIONS(5984),
    [aux_sym_basic_type_token48] = ACTIONS(5984),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5984),
    [anon_sym_POUNDif] = ACTIONS(5986),
    [anon_sym_POUNDIF] = ACTIONS(5986),
    [anon_sym_POUNDIf] = ACTIONS(5986),
    [anon_sym_not] = ACTIONS(5984),
    [anon_sym_NOT] = ACTIONS(5984),
    [anon_sym_Not] = ACTIONS(5984),
    [anon_sym_POUNDelif] = ACTIONS(5986),
    [anon_sym_POUNDELIF] = ACTIONS(5986),
    [anon_sym_POUNDElif] = ACTIONS(5986),
    [anon_sym_POUNDelse] = ACTIONS(5986),
    [anon_sym_POUNDELSE] = ACTIONS(5986),
    [anon_sym_POUNDElse] = ACTIONS(5986),
    [anon_sym_POUNDelse2] = ACTIONS(5986),
    [anon_sym_POUNDELSE2] = ACTIONS(5986),
    [anon_sym_POUNDElse2] = ACTIONS(5986),
    [anon_sym_POUNDendif] = ACTIONS(5986),
    [anon_sym_POUNDENDIF] = ACTIONS(5986),
    [anon_sym_POUNDEndif] = ACTIONS(5986),
    [anon_sym_POUNDendif2] = ACTIONS(5986),
    [anon_sym_POUNDENDIF2] = ACTIONS(5986),
    [anon_sym_POUNDEndif2] = ACTIONS(5986),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5984),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5984),
    [anon_sym_PLUS] = ACTIONS(5986),
    [sym_datetime_literal] = ACTIONS(5986),
    [sym_date_literal] = ACTIONS(5984),
    [sym_time_literal] = ACTIONS(5984),
    [sym_biginteger_literal] = ACTIONS(5986),
    [anon_sym_if] = ACTIONS(5984),
    [anon_sym_IF] = ACTIONS(5984),
    [anon_sym_If] = ACTIONS(5984),
    [anon_sym_else] = ACTIONS(5984),
    [anon_sym_ELSE] = ACTIONS(5984),
    [anon_sym_Else] = ACTIONS(5984),
    [anon_sym_case] = ACTIONS(5984),
    [anon_sym_CASE] = ACTIONS(5984),
    [anon_sym_Case] = ACTIONS(5984),
    [anon_sym_for] = ACTIONS(5984),
    [anon_sym_FOR] = ACTIONS(5984),
    [anon_sym_For] = ACTIONS(5984),
    [anon_sym_foreach] = ACTIONS(5984),
    [anon_sym_FOREACH] = ACTIONS(5984),
    [anon_sym_Foreach] = ACTIONS(5984),
    [anon_sym_while] = ACTIONS(5984),
    [anon_sym_WHILE] = ACTIONS(5984),
    [anon_sym_While] = ACTIONS(5984),
    [anon_sym_repeat] = ACTIONS(5984),
    [anon_sym_REPEAT] = ACTIONS(5984),
    [anon_sym_Repeat] = ACTIONS(5984),
    [anon_sym_exit] = ACTIONS(5984),
    [anon_sym_EXIT] = ACTIONS(5984),
    [anon_sym_Exit] = ACTIONS(5984),
    [anon_sym_continue] = ACTIONS(5984),
    [anon_sym_CONTINUE] = ACTIONS(5984),
    [anon_sym_Continue] = ACTIONS(5984),
    [anon_sym_break] = ACTIONS(5984),
    [anon_sym_BREAK] = ACTIONS(5984),
    [anon_sym_Break] = ACTIONS(5984),
    [anon_sym_with] = ACTIONS(5984),
    [anon_sym_WITH] = ACTIONS(5984),
    [anon_sym_With] = ACTIONS(5984),
    [sym_asserterror_keyword] = ACTIONS(5986),
    [sym_page_keyword] = ACTIONS(5984),
    [anon_sym_codeunit] = ACTIONS(5984),
    [anon_sym_CODEUNIT] = ACTIONS(5984),
    [anon_sym_Codeunit] = ACTIONS(5984),
    [anon_sym_CodeUnit] = ACTIONS(5984),
    [anon_sym_COdeunit] = ACTIONS(5984),
    [anon_sym_codeUnit] = ACTIONS(5984),
    [sym_report_keyword] = ACTIONS(5984),
    [sym_query_keyword] = ACTIONS(5984),
    [anon_sym_xmlport] = ACTIONS(5984),
    [anon_sym_XMLPORT] = ACTIONS(5984),
    [anon_sym_Xmlport] = ACTIONS(5984),
    [anon_sym_XMLport] = ACTIONS(5984),
    [anon_sym_XMLPort] = ACTIONS(5984),
    [anon_sym_XmlPort] = ACTIONS(5984),
    [anon_sym_enum] = ACTIONS(5984),
    [anon_sym_ENUM] = ACTIONS(5984),
    [anon_sym_Enum] = ACTIONS(5984),
    [anon_sym_eNUM] = ACTIONS(5984),
    [anon_sym_eNum] = ACTIONS(5984),
    [anon_sym_ENum] = ACTIONS(5984),
    [sym_quoted_identifier] = ACTIONS(5986),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5986),
    [sym_verbatim_string] = ACTIONS(5986),
    [sym_integer] = ACTIONS(5984),
    [sym_continue_as_identifier] = ACTIONS(5986),
    [sym_preproc_open] = ACTIONS(5986),
    [sym_preproc_close] = ACTIONS(5986),
  },
  [STATE(2514)] = {
    [sym_identifier] = ACTIONS(5988),
    [anon_sym_SEMI] = ACTIONS(5990),
    [anon_sym_DASH] = ACTIONS(5990),
    [aux_sym_boolean_token1] = ACTIONS(5988),
    [aux_sym_boolean_token2] = ACTIONS(5988),
    [sym_decimal] = ACTIONS(5988),
    [anon_sym_LPAREN] = ACTIONS(5990),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5988),
    [anon_sym_LBRACK] = ACTIONS(5990),
    [aux_sym_record_type_token1] = ACTIONS(5988),
    [aux_sym_basic_type_token21] = ACTIONS(5988),
    [aux_sym_basic_type_token22] = ACTIONS(5988),
    [aux_sym_basic_type_token48] = ACTIONS(5988),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5988),
    [anon_sym_POUNDif] = ACTIONS(5990),
    [anon_sym_POUNDIF] = ACTIONS(5990),
    [anon_sym_POUNDIf] = ACTIONS(5990),
    [anon_sym_not] = ACTIONS(5988),
    [anon_sym_NOT] = ACTIONS(5988),
    [anon_sym_Not] = ACTIONS(5988),
    [anon_sym_POUNDelif] = ACTIONS(5990),
    [anon_sym_POUNDELIF] = ACTIONS(5990),
    [anon_sym_POUNDElif] = ACTIONS(5990),
    [anon_sym_POUNDelse] = ACTIONS(5990),
    [anon_sym_POUNDELSE] = ACTIONS(5990),
    [anon_sym_POUNDElse] = ACTIONS(5990),
    [anon_sym_POUNDelse2] = ACTIONS(5990),
    [anon_sym_POUNDELSE2] = ACTIONS(5990),
    [anon_sym_POUNDElse2] = ACTIONS(5990),
    [anon_sym_POUNDendif] = ACTIONS(5990),
    [anon_sym_POUNDENDIF] = ACTIONS(5990),
    [anon_sym_POUNDEndif] = ACTIONS(5990),
    [anon_sym_POUNDendif2] = ACTIONS(5990),
    [anon_sym_POUNDENDIF2] = ACTIONS(5990),
    [anon_sym_POUNDEndif2] = ACTIONS(5990),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5988),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5988),
    [anon_sym_PLUS] = ACTIONS(5990),
    [sym_datetime_literal] = ACTIONS(5990),
    [sym_date_literal] = ACTIONS(5988),
    [sym_time_literal] = ACTIONS(5988),
    [sym_biginteger_literal] = ACTIONS(5990),
    [anon_sym_if] = ACTIONS(5988),
    [anon_sym_IF] = ACTIONS(5988),
    [anon_sym_If] = ACTIONS(5988),
    [anon_sym_else] = ACTIONS(5988),
    [anon_sym_ELSE] = ACTIONS(5988),
    [anon_sym_Else] = ACTIONS(5988),
    [anon_sym_case] = ACTIONS(5988),
    [anon_sym_CASE] = ACTIONS(5988),
    [anon_sym_Case] = ACTIONS(5988),
    [anon_sym_for] = ACTIONS(5988),
    [anon_sym_FOR] = ACTIONS(5988),
    [anon_sym_For] = ACTIONS(5988),
    [anon_sym_foreach] = ACTIONS(5988),
    [anon_sym_FOREACH] = ACTIONS(5988),
    [anon_sym_Foreach] = ACTIONS(5988),
    [anon_sym_while] = ACTIONS(5988),
    [anon_sym_WHILE] = ACTIONS(5988),
    [anon_sym_While] = ACTIONS(5988),
    [anon_sym_repeat] = ACTIONS(5988),
    [anon_sym_REPEAT] = ACTIONS(5988),
    [anon_sym_Repeat] = ACTIONS(5988),
    [anon_sym_exit] = ACTIONS(5988),
    [anon_sym_EXIT] = ACTIONS(5988),
    [anon_sym_Exit] = ACTIONS(5988),
    [anon_sym_continue] = ACTIONS(5988),
    [anon_sym_CONTINUE] = ACTIONS(5988),
    [anon_sym_Continue] = ACTIONS(5988),
    [anon_sym_break] = ACTIONS(5988),
    [anon_sym_BREAK] = ACTIONS(5988),
    [anon_sym_Break] = ACTIONS(5988),
    [anon_sym_with] = ACTIONS(5988),
    [anon_sym_WITH] = ACTIONS(5988),
    [anon_sym_With] = ACTIONS(5988),
    [sym_asserterror_keyword] = ACTIONS(5990),
    [sym_page_keyword] = ACTIONS(5988),
    [anon_sym_codeunit] = ACTIONS(5988),
    [anon_sym_CODEUNIT] = ACTIONS(5988),
    [anon_sym_Codeunit] = ACTIONS(5988),
    [anon_sym_CodeUnit] = ACTIONS(5988),
    [anon_sym_COdeunit] = ACTIONS(5988),
    [anon_sym_codeUnit] = ACTIONS(5988),
    [sym_report_keyword] = ACTIONS(5988),
    [sym_query_keyword] = ACTIONS(5988),
    [anon_sym_xmlport] = ACTIONS(5988),
    [anon_sym_XMLPORT] = ACTIONS(5988),
    [anon_sym_Xmlport] = ACTIONS(5988),
    [anon_sym_XMLport] = ACTIONS(5988),
    [anon_sym_XMLPort] = ACTIONS(5988),
    [anon_sym_XmlPort] = ACTIONS(5988),
    [anon_sym_enum] = ACTIONS(5988),
    [anon_sym_ENUM] = ACTIONS(5988),
    [anon_sym_Enum] = ACTIONS(5988),
    [anon_sym_eNUM] = ACTIONS(5988),
    [anon_sym_eNum] = ACTIONS(5988),
    [anon_sym_ENum] = ACTIONS(5988),
    [sym_quoted_identifier] = ACTIONS(5990),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5990),
    [sym_verbatim_string] = ACTIONS(5990),
    [sym_integer] = ACTIONS(5988),
    [sym_continue_as_identifier] = ACTIONS(5990),
    [sym_preproc_open] = ACTIONS(5990),
    [sym_preproc_close] = ACTIONS(5990),
  },
  [STATE(2515)] = {
    [sym_identifier] = ACTIONS(5992),
    [anon_sym_SEMI] = ACTIONS(5994),
    [anon_sym_DASH] = ACTIONS(5994),
    [aux_sym_boolean_token1] = ACTIONS(5992),
    [aux_sym_boolean_token2] = ACTIONS(5992),
    [sym_decimal] = ACTIONS(5992),
    [anon_sym_LPAREN] = ACTIONS(5994),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5992),
    [anon_sym_LBRACK] = ACTIONS(5994),
    [aux_sym_record_type_token1] = ACTIONS(5992),
    [aux_sym_basic_type_token21] = ACTIONS(5992),
    [aux_sym_basic_type_token22] = ACTIONS(5992),
    [aux_sym_basic_type_token48] = ACTIONS(5992),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5992),
    [anon_sym_POUNDif] = ACTIONS(5994),
    [anon_sym_POUNDIF] = ACTIONS(5994),
    [anon_sym_POUNDIf] = ACTIONS(5994),
    [anon_sym_not] = ACTIONS(5992),
    [anon_sym_NOT] = ACTIONS(5992),
    [anon_sym_Not] = ACTIONS(5992),
    [anon_sym_POUNDelif] = ACTIONS(5994),
    [anon_sym_POUNDELIF] = ACTIONS(5994),
    [anon_sym_POUNDElif] = ACTIONS(5994),
    [anon_sym_POUNDelse] = ACTIONS(5994),
    [anon_sym_POUNDELSE] = ACTIONS(5994),
    [anon_sym_POUNDElse] = ACTIONS(5994),
    [anon_sym_POUNDelse2] = ACTIONS(5994),
    [anon_sym_POUNDELSE2] = ACTIONS(5994),
    [anon_sym_POUNDElse2] = ACTIONS(5994),
    [anon_sym_POUNDendif] = ACTIONS(5994),
    [anon_sym_POUNDENDIF] = ACTIONS(5994),
    [anon_sym_POUNDEndif] = ACTIONS(5994),
    [anon_sym_POUNDendif2] = ACTIONS(5994),
    [anon_sym_POUNDENDIF2] = ACTIONS(5994),
    [anon_sym_POUNDEndif2] = ACTIONS(5994),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5992),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5992),
    [anon_sym_PLUS] = ACTIONS(5994),
    [sym_datetime_literal] = ACTIONS(5994),
    [sym_date_literal] = ACTIONS(5992),
    [sym_time_literal] = ACTIONS(5992),
    [sym_biginteger_literal] = ACTIONS(5994),
    [anon_sym_if] = ACTIONS(5992),
    [anon_sym_IF] = ACTIONS(5992),
    [anon_sym_If] = ACTIONS(5992),
    [anon_sym_else] = ACTIONS(5992),
    [anon_sym_ELSE] = ACTIONS(5992),
    [anon_sym_Else] = ACTIONS(5992),
    [anon_sym_case] = ACTIONS(5992),
    [anon_sym_CASE] = ACTIONS(5992),
    [anon_sym_Case] = ACTIONS(5992),
    [anon_sym_for] = ACTIONS(5992),
    [anon_sym_FOR] = ACTIONS(5992),
    [anon_sym_For] = ACTIONS(5992),
    [anon_sym_foreach] = ACTIONS(5992),
    [anon_sym_FOREACH] = ACTIONS(5992),
    [anon_sym_Foreach] = ACTIONS(5992),
    [anon_sym_while] = ACTIONS(5992),
    [anon_sym_WHILE] = ACTIONS(5992),
    [anon_sym_While] = ACTIONS(5992),
    [anon_sym_repeat] = ACTIONS(5992),
    [anon_sym_REPEAT] = ACTIONS(5992),
    [anon_sym_Repeat] = ACTIONS(5992),
    [anon_sym_exit] = ACTIONS(5992),
    [anon_sym_EXIT] = ACTIONS(5992),
    [anon_sym_Exit] = ACTIONS(5992),
    [anon_sym_continue] = ACTIONS(5992),
    [anon_sym_CONTINUE] = ACTIONS(5992),
    [anon_sym_Continue] = ACTIONS(5992),
    [anon_sym_break] = ACTIONS(5992),
    [anon_sym_BREAK] = ACTIONS(5992),
    [anon_sym_Break] = ACTIONS(5992),
    [anon_sym_with] = ACTIONS(5992),
    [anon_sym_WITH] = ACTIONS(5992),
    [anon_sym_With] = ACTIONS(5992),
    [sym_asserterror_keyword] = ACTIONS(5994),
    [sym_page_keyword] = ACTIONS(5992),
    [anon_sym_codeunit] = ACTIONS(5992),
    [anon_sym_CODEUNIT] = ACTIONS(5992),
    [anon_sym_Codeunit] = ACTIONS(5992),
    [anon_sym_CodeUnit] = ACTIONS(5992),
    [anon_sym_COdeunit] = ACTIONS(5992),
    [anon_sym_codeUnit] = ACTIONS(5992),
    [sym_report_keyword] = ACTIONS(5992),
    [sym_query_keyword] = ACTIONS(5992),
    [anon_sym_xmlport] = ACTIONS(5992),
    [anon_sym_XMLPORT] = ACTIONS(5992),
    [anon_sym_Xmlport] = ACTIONS(5992),
    [anon_sym_XMLport] = ACTIONS(5992),
    [anon_sym_XMLPort] = ACTIONS(5992),
    [anon_sym_XmlPort] = ACTIONS(5992),
    [anon_sym_enum] = ACTIONS(5992),
    [anon_sym_ENUM] = ACTIONS(5992),
    [anon_sym_Enum] = ACTIONS(5992),
    [anon_sym_eNUM] = ACTIONS(5992),
    [anon_sym_eNum] = ACTIONS(5992),
    [anon_sym_ENum] = ACTIONS(5992),
    [sym_quoted_identifier] = ACTIONS(5994),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5994),
    [sym_verbatim_string] = ACTIONS(5994),
    [sym_integer] = ACTIONS(5992),
    [sym_continue_as_identifier] = ACTIONS(5994),
    [sym_preproc_open] = ACTIONS(5994),
    [sym_preproc_close] = ACTIONS(5994),
  },
  [STATE(2516)] = {
    [sym_identifier] = ACTIONS(5988),
    [anon_sym_SEMI] = ACTIONS(5990),
    [anon_sym_DASH] = ACTIONS(5990),
    [aux_sym_boolean_token1] = ACTIONS(5988),
    [aux_sym_boolean_token2] = ACTIONS(5988),
    [sym_decimal] = ACTIONS(5988),
    [anon_sym_LPAREN] = ACTIONS(5990),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5988),
    [anon_sym_LBRACK] = ACTIONS(5990),
    [aux_sym_record_type_token1] = ACTIONS(5988),
    [aux_sym_basic_type_token21] = ACTIONS(5988),
    [aux_sym_basic_type_token22] = ACTIONS(5988),
    [aux_sym_basic_type_token48] = ACTIONS(5988),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5988),
    [anon_sym_POUNDif] = ACTIONS(5990),
    [anon_sym_POUNDIF] = ACTIONS(5990),
    [anon_sym_POUNDIf] = ACTIONS(5990),
    [anon_sym_not] = ACTIONS(5988),
    [anon_sym_NOT] = ACTIONS(5988),
    [anon_sym_Not] = ACTIONS(5988),
    [anon_sym_POUNDelif] = ACTIONS(5990),
    [anon_sym_POUNDELIF] = ACTIONS(5990),
    [anon_sym_POUNDElif] = ACTIONS(5990),
    [anon_sym_POUNDelse] = ACTIONS(5990),
    [anon_sym_POUNDELSE] = ACTIONS(5990),
    [anon_sym_POUNDElse] = ACTIONS(5990),
    [anon_sym_POUNDelse2] = ACTIONS(5990),
    [anon_sym_POUNDELSE2] = ACTIONS(5990),
    [anon_sym_POUNDElse2] = ACTIONS(5990),
    [anon_sym_POUNDendif] = ACTIONS(5990),
    [anon_sym_POUNDENDIF] = ACTIONS(5990),
    [anon_sym_POUNDEndif] = ACTIONS(5990),
    [anon_sym_POUNDendif2] = ACTIONS(5990),
    [anon_sym_POUNDENDIF2] = ACTIONS(5990),
    [anon_sym_POUNDEndif2] = ACTIONS(5990),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5988),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5988),
    [anon_sym_PLUS] = ACTIONS(5990),
    [sym_datetime_literal] = ACTIONS(5990),
    [sym_date_literal] = ACTIONS(5988),
    [sym_time_literal] = ACTIONS(5988),
    [sym_biginteger_literal] = ACTIONS(5990),
    [anon_sym_if] = ACTIONS(5988),
    [anon_sym_IF] = ACTIONS(5988),
    [anon_sym_If] = ACTIONS(5988),
    [anon_sym_else] = ACTIONS(5988),
    [anon_sym_ELSE] = ACTIONS(5988),
    [anon_sym_Else] = ACTIONS(5988),
    [anon_sym_case] = ACTIONS(5988),
    [anon_sym_CASE] = ACTIONS(5988),
    [anon_sym_Case] = ACTIONS(5988),
    [anon_sym_for] = ACTIONS(5988),
    [anon_sym_FOR] = ACTIONS(5988),
    [anon_sym_For] = ACTIONS(5988),
    [anon_sym_foreach] = ACTIONS(5988),
    [anon_sym_FOREACH] = ACTIONS(5988),
    [anon_sym_Foreach] = ACTIONS(5988),
    [anon_sym_while] = ACTIONS(5988),
    [anon_sym_WHILE] = ACTIONS(5988),
    [anon_sym_While] = ACTIONS(5988),
    [anon_sym_repeat] = ACTIONS(5988),
    [anon_sym_REPEAT] = ACTIONS(5988),
    [anon_sym_Repeat] = ACTIONS(5988),
    [anon_sym_exit] = ACTIONS(5988),
    [anon_sym_EXIT] = ACTIONS(5988),
    [anon_sym_Exit] = ACTIONS(5988),
    [anon_sym_continue] = ACTIONS(5988),
    [anon_sym_CONTINUE] = ACTIONS(5988),
    [anon_sym_Continue] = ACTIONS(5988),
    [anon_sym_break] = ACTIONS(5988),
    [anon_sym_BREAK] = ACTIONS(5988),
    [anon_sym_Break] = ACTIONS(5988),
    [anon_sym_with] = ACTIONS(5988),
    [anon_sym_WITH] = ACTIONS(5988),
    [anon_sym_With] = ACTIONS(5988),
    [sym_asserterror_keyword] = ACTIONS(5990),
    [sym_page_keyword] = ACTIONS(5988),
    [anon_sym_codeunit] = ACTIONS(5988),
    [anon_sym_CODEUNIT] = ACTIONS(5988),
    [anon_sym_Codeunit] = ACTIONS(5988),
    [anon_sym_CodeUnit] = ACTIONS(5988),
    [anon_sym_COdeunit] = ACTIONS(5988),
    [anon_sym_codeUnit] = ACTIONS(5988),
    [sym_report_keyword] = ACTIONS(5988),
    [sym_query_keyword] = ACTIONS(5988),
    [anon_sym_xmlport] = ACTIONS(5988),
    [anon_sym_XMLPORT] = ACTIONS(5988),
    [anon_sym_Xmlport] = ACTIONS(5988),
    [anon_sym_XMLport] = ACTIONS(5988),
    [anon_sym_XMLPort] = ACTIONS(5988),
    [anon_sym_XmlPort] = ACTIONS(5988),
    [anon_sym_enum] = ACTIONS(5988),
    [anon_sym_ENUM] = ACTIONS(5988),
    [anon_sym_Enum] = ACTIONS(5988),
    [anon_sym_eNUM] = ACTIONS(5988),
    [anon_sym_eNum] = ACTIONS(5988),
    [anon_sym_ENum] = ACTIONS(5988),
    [sym_quoted_identifier] = ACTIONS(5990),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5990),
    [sym_verbatim_string] = ACTIONS(5990),
    [sym_integer] = ACTIONS(5988),
    [sym_continue_as_identifier] = ACTIONS(5990),
    [sym_preproc_open] = ACTIONS(5990),
    [sym_preproc_close] = ACTIONS(5990),
  },
  [STATE(2517)] = {
    [sym_identifier] = ACTIONS(5996),
    [anon_sym_SEMI] = ACTIONS(5998),
    [anon_sym_DASH] = ACTIONS(5998),
    [aux_sym_boolean_token1] = ACTIONS(5996),
    [aux_sym_boolean_token2] = ACTIONS(5996),
    [sym_decimal] = ACTIONS(5996),
    [anon_sym_LPAREN] = ACTIONS(5998),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5996),
    [anon_sym_LBRACK] = ACTIONS(5998),
    [aux_sym_record_type_token1] = ACTIONS(5996),
    [aux_sym_basic_type_token21] = ACTIONS(5996),
    [aux_sym_basic_type_token22] = ACTIONS(5996),
    [aux_sym_basic_type_token48] = ACTIONS(5996),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5996),
    [anon_sym_POUNDif] = ACTIONS(5998),
    [anon_sym_POUNDIF] = ACTIONS(5998),
    [anon_sym_POUNDIf] = ACTIONS(5998),
    [anon_sym_not] = ACTIONS(5996),
    [anon_sym_NOT] = ACTIONS(5996),
    [anon_sym_Not] = ACTIONS(5996),
    [anon_sym_POUNDelif] = ACTIONS(5998),
    [anon_sym_POUNDELIF] = ACTIONS(5998),
    [anon_sym_POUNDElif] = ACTIONS(5998),
    [anon_sym_POUNDelse] = ACTIONS(5998),
    [anon_sym_POUNDELSE] = ACTIONS(5998),
    [anon_sym_POUNDElse] = ACTIONS(5998),
    [anon_sym_POUNDelse2] = ACTIONS(5998),
    [anon_sym_POUNDELSE2] = ACTIONS(5998),
    [anon_sym_POUNDElse2] = ACTIONS(5998),
    [anon_sym_POUNDendif] = ACTIONS(5998),
    [anon_sym_POUNDENDIF] = ACTIONS(5998),
    [anon_sym_POUNDEndif] = ACTIONS(5998),
    [anon_sym_POUNDendif2] = ACTIONS(5998),
    [anon_sym_POUNDENDIF2] = ACTIONS(5998),
    [anon_sym_POUNDEndif2] = ACTIONS(5998),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5996),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5996),
    [anon_sym_PLUS] = ACTIONS(5998),
    [sym_datetime_literal] = ACTIONS(5998),
    [sym_date_literal] = ACTIONS(5996),
    [sym_time_literal] = ACTIONS(5996),
    [sym_biginteger_literal] = ACTIONS(5998),
    [anon_sym_if] = ACTIONS(5996),
    [anon_sym_IF] = ACTIONS(5996),
    [anon_sym_If] = ACTIONS(5996),
    [anon_sym_else] = ACTIONS(5996),
    [anon_sym_ELSE] = ACTIONS(5996),
    [anon_sym_Else] = ACTIONS(5996),
    [anon_sym_case] = ACTIONS(5996),
    [anon_sym_CASE] = ACTIONS(5996),
    [anon_sym_Case] = ACTIONS(5996),
    [anon_sym_for] = ACTIONS(5996),
    [anon_sym_FOR] = ACTIONS(5996),
    [anon_sym_For] = ACTIONS(5996),
    [anon_sym_foreach] = ACTIONS(5996),
    [anon_sym_FOREACH] = ACTIONS(5996),
    [anon_sym_Foreach] = ACTIONS(5996),
    [anon_sym_while] = ACTIONS(5996),
    [anon_sym_WHILE] = ACTIONS(5996),
    [anon_sym_While] = ACTIONS(5996),
    [anon_sym_repeat] = ACTIONS(5996),
    [anon_sym_REPEAT] = ACTIONS(5996),
    [anon_sym_Repeat] = ACTIONS(5996),
    [anon_sym_exit] = ACTIONS(5996),
    [anon_sym_EXIT] = ACTIONS(5996),
    [anon_sym_Exit] = ACTIONS(5996),
    [anon_sym_continue] = ACTIONS(5996),
    [anon_sym_CONTINUE] = ACTIONS(5996),
    [anon_sym_Continue] = ACTIONS(5996),
    [anon_sym_break] = ACTIONS(5996),
    [anon_sym_BREAK] = ACTIONS(5996),
    [anon_sym_Break] = ACTIONS(5996),
    [anon_sym_with] = ACTIONS(5996),
    [anon_sym_WITH] = ACTIONS(5996),
    [anon_sym_With] = ACTIONS(5996),
    [sym_asserterror_keyword] = ACTIONS(5998),
    [sym_page_keyword] = ACTIONS(5996),
    [anon_sym_codeunit] = ACTIONS(5996),
    [anon_sym_CODEUNIT] = ACTIONS(5996),
    [anon_sym_Codeunit] = ACTIONS(5996),
    [anon_sym_CodeUnit] = ACTIONS(5996),
    [anon_sym_COdeunit] = ACTIONS(5996),
    [anon_sym_codeUnit] = ACTIONS(5996),
    [sym_report_keyword] = ACTIONS(5996),
    [sym_query_keyword] = ACTIONS(5996),
    [anon_sym_xmlport] = ACTIONS(5996),
    [anon_sym_XMLPORT] = ACTIONS(5996),
    [anon_sym_Xmlport] = ACTIONS(5996),
    [anon_sym_XMLport] = ACTIONS(5996),
    [anon_sym_XMLPort] = ACTIONS(5996),
    [anon_sym_XmlPort] = ACTIONS(5996),
    [anon_sym_enum] = ACTIONS(5996),
    [anon_sym_ENUM] = ACTIONS(5996),
    [anon_sym_Enum] = ACTIONS(5996),
    [anon_sym_eNUM] = ACTIONS(5996),
    [anon_sym_eNum] = ACTIONS(5996),
    [anon_sym_ENum] = ACTIONS(5996),
    [sym_quoted_identifier] = ACTIONS(5998),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5998),
    [sym_verbatim_string] = ACTIONS(5998),
    [sym_integer] = ACTIONS(5996),
    [sym_continue_as_identifier] = ACTIONS(5998),
    [sym_preproc_open] = ACTIONS(5998),
    [sym_preproc_close] = ACTIONS(5998),
  },
  [STATE(2518)] = {
    [sym_argument_list] = STATE(2317),
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_COLON] = ACTIONS(6000),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(5354),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_COLON_COLON] = ACTIONS(5356),
    [anon_sym_POUNDif] = ACTIONS(6002),
    [anon_sym_POUNDIF] = ACTIONS(6002),
    [anon_sym_POUNDIf] = ACTIONS(6002),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [anon_sym_POUNDelif] = ACTIONS(6002),
    [anon_sym_POUNDELIF] = ACTIONS(6002),
    [anon_sym_POUNDElif] = ACTIONS(6002),
    [anon_sym_POUNDelse] = ACTIONS(6002),
    [anon_sym_POUNDELSE] = ACTIONS(6002),
    [anon_sym_POUNDElse] = ACTIONS(6002),
    [anon_sym_POUNDelse2] = ACTIONS(6002),
    [anon_sym_POUNDELSE2] = ACTIONS(6002),
    [anon_sym_POUNDElse2] = ACTIONS(6002),
    [anon_sym_POUNDendif] = ACTIONS(6002),
    [anon_sym_POUNDENDIF] = ACTIONS(6002),
    [anon_sym_POUNDEndif] = ACTIONS(6002),
    [anon_sym_POUNDendif2] = ACTIONS(6002),
    [anon_sym_POUNDENDIF2] = ACTIONS(6002),
    [anon_sym_POUNDEndif2] = ACTIONS(6002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_open] = ACTIONS(6002),
    [sym_preproc_close] = ACTIONS(6002),
  },
  [STATE(2519)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5965),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(2520)] = {
    [sym_identifier] = ACTIONS(6010),
    [anon_sym_SEMI] = ACTIONS(6012),
    [anon_sym_DASH] = ACTIONS(6012),
    [aux_sym_boolean_token1] = ACTIONS(6010),
    [aux_sym_boolean_token2] = ACTIONS(6010),
    [sym_decimal] = ACTIONS(6010),
    [anon_sym_LPAREN] = ACTIONS(6012),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6010),
    [anon_sym_LBRACK] = ACTIONS(6012),
    [aux_sym_record_type_token1] = ACTIONS(6010),
    [aux_sym_basic_type_token21] = ACTIONS(6010),
    [aux_sym_basic_type_token22] = ACTIONS(6010),
    [aux_sym_basic_type_token48] = ACTIONS(6010),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6010),
    [anon_sym_POUNDif] = ACTIONS(6012),
    [anon_sym_POUNDIF] = ACTIONS(6012),
    [anon_sym_POUNDIf] = ACTIONS(6012),
    [anon_sym_not] = ACTIONS(6010),
    [anon_sym_NOT] = ACTIONS(6010),
    [anon_sym_Not] = ACTIONS(6010),
    [anon_sym_POUNDelif] = ACTIONS(6012),
    [anon_sym_POUNDELIF] = ACTIONS(6012),
    [anon_sym_POUNDElif] = ACTIONS(6012),
    [anon_sym_POUNDelse] = ACTIONS(6012),
    [anon_sym_POUNDELSE] = ACTIONS(6012),
    [anon_sym_POUNDElse] = ACTIONS(6012),
    [anon_sym_POUNDelse2] = ACTIONS(6012),
    [anon_sym_POUNDELSE2] = ACTIONS(6012),
    [anon_sym_POUNDElse2] = ACTIONS(6012),
    [anon_sym_POUNDendif] = ACTIONS(6012),
    [anon_sym_POUNDENDIF] = ACTIONS(6012),
    [anon_sym_POUNDEndif] = ACTIONS(6012),
    [anon_sym_POUNDendif2] = ACTIONS(6012),
    [anon_sym_POUNDENDIF2] = ACTIONS(6012),
    [anon_sym_POUNDEndif2] = ACTIONS(6012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6010),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6010),
    [anon_sym_PLUS] = ACTIONS(6012),
    [sym_datetime_literal] = ACTIONS(6012),
    [sym_date_literal] = ACTIONS(6010),
    [sym_time_literal] = ACTIONS(6010),
    [sym_biginteger_literal] = ACTIONS(6012),
    [anon_sym_if] = ACTIONS(6010),
    [anon_sym_IF] = ACTIONS(6010),
    [anon_sym_If] = ACTIONS(6010),
    [anon_sym_else] = ACTIONS(6010),
    [anon_sym_ELSE] = ACTIONS(6010),
    [anon_sym_Else] = ACTIONS(6010),
    [anon_sym_case] = ACTIONS(6010),
    [anon_sym_CASE] = ACTIONS(6010),
    [anon_sym_Case] = ACTIONS(6010),
    [anon_sym_for] = ACTIONS(6010),
    [anon_sym_FOR] = ACTIONS(6010),
    [anon_sym_For] = ACTIONS(6010),
    [anon_sym_foreach] = ACTIONS(6010),
    [anon_sym_FOREACH] = ACTIONS(6010),
    [anon_sym_Foreach] = ACTIONS(6010),
    [anon_sym_while] = ACTIONS(6010),
    [anon_sym_WHILE] = ACTIONS(6010),
    [anon_sym_While] = ACTIONS(6010),
    [anon_sym_repeat] = ACTIONS(6010),
    [anon_sym_REPEAT] = ACTIONS(6010),
    [anon_sym_Repeat] = ACTIONS(6010),
    [anon_sym_exit] = ACTIONS(6010),
    [anon_sym_EXIT] = ACTIONS(6010),
    [anon_sym_Exit] = ACTIONS(6010),
    [anon_sym_continue] = ACTIONS(6010),
    [anon_sym_CONTINUE] = ACTIONS(6010),
    [anon_sym_Continue] = ACTIONS(6010),
    [anon_sym_break] = ACTIONS(6010),
    [anon_sym_BREAK] = ACTIONS(6010),
    [anon_sym_Break] = ACTIONS(6010),
    [anon_sym_with] = ACTIONS(6010),
    [anon_sym_WITH] = ACTIONS(6010),
    [anon_sym_With] = ACTIONS(6010),
    [sym_asserterror_keyword] = ACTIONS(6012),
    [sym_page_keyword] = ACTIONS(6010),
    [anon_sym_codeunit] = ACTIONS(6010),
    [anon_sym_CODEUNIT] = ACTIONS(6010),
    [anon_sym_Codeunit] = ACTIONS(6010),
    [anon_sym_CodeUnit] = ACTIONS(6010),
    [anon_sym_COdeunit] = ACTIONS(6010),
    [anon_sym_codeUnit] = ACTIONS(6010),
    [sym_report_keyword] = ACTIONS(6010),
    [sym_query_keyword] = ACTIONS(6010),
    [anon_sym_xmlport] = ACTIONS(6010),
    [anon_sym_XMLPORT] = ACTIONS(6010),
    [anon_sym_Xmlport] = ACTIONS(6010),
    [anon_sym_XMLport] = ACTIONS(6010),
    [anon_sym_XMLPort] = ACTIONS(6010),
    [anon_sym_XmlPort] = ACTIONS(6010),
    [anon_sym_enum] = ACTIONS(6010),
    [anon_sym_ENUM] = ACTIONS(6010),
    [anon_sym_Enum] = ACTIONS(6010),
    [anon_sym_eNUM] = ACTIONS(6010),
    [anon_sym_eNum] = ACTIONS(6010),
    [anon_sym_ENum] = ACTIONS(6010),
    [sym_quoted_identifier] = ACTIONS(6012),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6012),
    [sym_verbatim_string] = ACTIONS(6012),
    [sym_integer] = ACTIONS(6010),
    [sym_continue_as_identifier] = ACTIONS(6012),
    [sym_preproc_open] = ACTIONS(6012),
    [sym_preproc_close] = ACTIONS(6012),
  },
  [STATE(2521)] = {
    [sym_identifier] = ACTIONS(6014),
    [anon_sym_SEMI] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6016),
    [aux_sym_boolean_token1] = ACTIONS(6014),
    [aux_sym_boolean_token2] = ACTIONS(6014),
    [sym_decimal] = ACTIONS(6014),
    [anon_sym_LPAREN] = ACTIONS(6016),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6014),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [aux_sym_record_type_token1] = ACTIONS(6014),
    [aux_sym_basic_type_token21] = ACTIONS(6014),
    [aux_sym_basic_type_token22] = ACTIONS(6014),
    [aux_sym_basic_type_token48] = ACTIONS(6014),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6014),
    [anon_sym_POUNDif] = ACTIONS(6016),
    [anon_sym_POUNDIF] = ACTIONS(6016),
    [anon_sym_POUNDIf] = ACTIONS(6016),
    [anon_sym_not] = ACTIONS(6014),
    [anon_sym_NOT] = ACTIONS(6014),
    [anon_sym_Not] = ACTIONS(6014),
    [anon_sym_POUNDelif] = ACTIONS(6016),
    [anon_sym_POUNDELIF] = ACTIONS(6016),
    [anon_sym_POUNDElif] = ACTIONS(6016),
    [anon_sym_POUNDelse] = ACTIONS(6016),
    [anon_sym_POUNDELSE] = ACTIONS(6016),
    [anon_sym_POUNDElse] = ACTIONS(6016),
    [anon_sym_POUNDelse2] = ACTIONS(6016),
    [anon_sym_POUNDELSE2] = ACTIONS(6016),
    [anon_sym_POUNDElse2] = ACTIONS(6016),
    [anon_sym_POUNDendif] = ACTIONS(6016),
    [anon_sym_POUNDENDIF] = ACTIONS(6016),
    [anon_sym_POUNDEndif] = ACTIONS(6016),
    [anon_sym_POUNDendif2] = ACTIONS(6016),
    [anon_sym_POUNDENDIF2] = ACTIONS(6016),
    [anon_sym_POUNDEndif2] = ACTIONS(6016),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6014),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6014),
    [anon_sym_PLUS] = ACTIONS(6016),
    [sym_datetime_literal] = ACTIONS(6016),
    [sym_date_literal] = ACTIONS(6014),
    [sym_time_literal] = ACTIONS(6014),
    [sym_biginteger_literal] = ACTIONS(6016),
    [anon_sym_if] = ACTIONS(6014),
    [anon_sym_IF] = ACTIONS(6014),
    [anon_sym_If] = ACTIONS(6014),
    [anon_sym_else] = ACTIONS(6014),
    [anon_sym_ELSE] = ACTIONS(6014),
    [anon_sym_Else] = ACTIONS(6014),
    [anon_sym_case] = ACTIONS(6014),
    [anon_sym_CASE] = ACTIONS(6014),
    [anon_sym_Case] = ACTIONS(6014),
    [anon_sym_for] = ACTIONS(6014),
    [anon_sym_FOR] = ACTIONS(6014),
    [anon_sym_For] = ACTIONS(6014),
    [anon_sym_foreach] = ACTIONS(6014),
    [anon_sym_FOREACH] = ACTIONS(6014),
    [anon_sym_Foreach] = ACTIONS(6014),
    [anon_sym_while] = ACTIONS(6014),
    [anon_sym_WHILE] = ACTIONS(6014),
    [anon_sym_While] = ACTIONS(6014),
    [anon_sym_repeat] = ACTIONS(6014),
    [anon_sym_REPEAT] = ACTIONS(6014),
    [anon_sym_Repeat] = ACTIONS(6014),
    [anon_sym_exit] = ACTIONS(6014),
    [anon_sym_EXIT] = ACTIONS(6014),
    [anon_sym_Exit] = ACTIONS(6014),
    [anon_sym_continue] = ACTIONS(6014),
    [anon_sym_CONTINUE] = ACTIONS(6014),
    [anon_sym_Continue] = ACTIONS(6014),
    [anon_sym_break] = ACTIONS(6014),
    [anon_sym_BREAK] = ACTIONS(6014),
    [anon_sym_Break] = ACTIONS(6014),
    [anon_sym_with] = ACTIONS(6014),
    [anon_sym_WITH] = ACTIONS(6014),
    [anon_sym_With] = ACTIONS(6014),
    [sym_asserterror_keyword] = ACTIONS(6016),
    [sym_page_keyword] = ACTIONS(6014),
    [anon_sym_codeunit] = ACTIONS(6014),
    [anon_sym_CODEUNIT] = ACTIONS(6014),
    [anon_sym_Codeunit] = ACTIONS(6014),
    [anon_sym_CodeUnit] = ACTIONS(6014),
    [anon_sym_COdeunit] = ACTIONS(6014),
    [anon_sym_codeUnit] = ACTIONS(6014),
    [sym_report_keyword] = ACTIONS(6014),
    [sym_query_keyword] = ACTIONS(6014),
    [anon_sym_xmlport] = ACTIONS(6014),
    [anon_sym_XMLPORT] = ACTIONS(6014),
    [anon_sym_Xmlport] = ACTIONS(6014),
    [anon_sym_XMLport] = ACTIONS(6014),
    [anon_sym_XMLPort] = ACTIONS(6014),
    [anon_sym_XmlPort] = ACTIONS(6014),
    [anon_sym_enum] = ACTIONS(6014),
    [anon_sym_ENUM] = ACTIONS(6014),
    [anon_sym_Enum] = ACTIONS(6014),
    [anon_sym_eNUM] = ACTIONS(6014),
    [anon_sym_eNum] = ACTIONS(6014),
    [anon_sym_ENum] = ACTIONS(6014),
    [sym_quoted_identifier] = ACTIONS(6016),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6016),
    [sym_verbatim_string] = ACTIONS(6016),
    [sym_integer] = ACTIONS(6014),
    [sym_continue_as_identifier] = ACTIONS(6016),
    [sym_preproc_open] = ACTIONS(6016),
    [sym_preproc_close] = ACTIONS(6016),
  },
  [STATE(2522)] = {
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [aux_sym_where_condition_token1] = ACTIONS(5410),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5405),
    [anon_sym_STAR] = ACTIONS(3681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5405),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5405),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_basic_type_token6] = ACTIONS(5410),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5405),
    [aux_sym_addafter_modification_token1] = ACTIONS(5405),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5405),
    [aux_sym_modify_modification_token1] = ACTIONS(5405),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5405),
    [aux_sym_movelast_modification_token1] = ACTIONS(5405),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5405),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [anon_sym_POUNDelif] = ACTIONS(5405),
    [anon_sym_POUNDELIF] = ACTIONS(5405),
    [anon_sym_POUNDElif] = ACTIONS(5405),
    [anon_sym_POUNDelse] = ACTIONS(5405),
    [anon_sym_POUNDELSE] = ACTIONS(5405),
    [anon_sym_POUNDElse] = ACTIONS(5405),
    [anon_sym_POUNDelse2] = ACTIONS(5405),
    [anon_sym_POUNDELSE2] = ACTIONS(5405),
    [anon_sym_POUNDElse2] = ACTIONS(5405),
    [anon_sym_POUNDendif] = ACTIONS(5405),
    [anon_sym_POUNDENDIF] = ACTIONS(5405),
    [anon_sym_POUNDEndif] = ACTIONS(5405),
    [anon_sym_POUNDendif2] = ACTIONS(5405),
    [anon_sym_POUNDENDIF2] = ACTIONS(5405),
    [anon_sym_POUNDEndif2] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5405),
    [sym_trigger_keyword] = ACTIONS(5405),
    [sym_var_keyword] = ACTIONS(5405),
    [sym_local_keyword] = ACTIONS(5405),
    [sym_internal_keyword] = ACTIONS(5405),
    [sym_protected_keyword] = ACTIONS(5405),
    [sym_event_keyword] = ACTIONS(5405),
    [sym_fields_keyword] = ACTIONS(5405),
    [sym_keys_keyword] = ACTIONS(5405),
    [sym_fieldgroups_keyword] = ACTIONS(5405),
    [sym_actions_keyword] = ACTIONS(5405),
    [sym_layout_keyword] = ACTIONS(5405),
    [sym_area_keyword] = ACTIONS(5405),
    [sym_group_keyword] = ACTIONS(5405),
    [sym_repeater_keyword] = ACTIONS(5405),
    [sym_cuegroup_keyword] = ACTIONS(5405),
    [sym_fixed_keyword] = ACTIONS(5405),
    [sym_grid_keyword] = ACTIONS(5405),
    [sym_part_keyword] = ACTIONS(5405),
    [sym_systempart_keyword] = ACTIONS(5405),
    [sym_usercontrol_keyword] = ACTIONS(5405),
    [sym_dataset_keyword] = ACTIONS(5405),
    [sym_elements_keyword] = ACTIONS(5405),
    [sym_dataitem_keyword] = ACTIONS(5405),
    [sym_column_keyword] = ACTIONS(5405),
    [sym_filter_keyword] = ACTIONS(5405),
    [sym_labels_keyword] = ACTIONS(5405),
    [sym_rendering_keyword] = ACTIONS(5405),
    [sym_requestpage_keyword] = ACTIONS(5405),
    [sym_schema_keyword] = ACTIONS(5405),
    [sym_views_keyword] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
    [sym_preproc_close] = ACTIONS(5405),
  },
  [STATE(2523)] = {
    [sym_identifier] = ACTIONS(6018),
    [anon_sym_SEMI] = ACTIONS(6020),
    [anon_sym_DASH] = ACTIONS(6020),
    [aux_sym_boolean_token1] = ACTIONS(6018),
    [aux_sym_boolean_token2] = ACTIONS(6018),
    [sym_decimal] = ACTIONS(6018),
    [anon_sym_LPAREN] = ACTIONS(6020),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6018),
    [anon_sym_LBRACK] = ACTIONS(6020),
    [aux_sym_record_type_token1] = ACTIONS(6018),
    [aux_sym_basic_type_token21] = ACTIONS(6018),
    [aux_sym_basic_type_token22] = ACTIONS(6018),
    [aux_sym_basic_type_token48] = ACTIONS(6018),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6018),
    [anon_sym_POUNDif] = ACTIONS(6020),
    [anon_sym_POUNDIF] = ACTIONS(6020),
    [anon_sym_POUNDIf] = ACTIONS(6020),
    [anon_sym_not] = ACTIONS(6018),
    [anon_sym_NOT] = ACTIONS(6018),
    [anon_sym_Not] = ACTIONS(6018),
    [anon_sym_POUNDelif] = ACTIONS(6020),
    [anon_sym_POUNDELIF] = ACTIONS(6020),
    [anon_sym_POUNDElif] = ACTIONS(6020),
    [anon_sym_POUNDelse] = ACTIONS(6020),
    [anon_sym_POUNDELSE] = ACTIONS(6020),
    [anon_sym_POUNDElse] = ACTIONS(6020),
    [anon_sym_POUNDelse2] = ACTIONS(6020),
    [anon_sym_POUNDELSE2] = ACTIONS(6020),
    [anon_sym_POUNDElse2] = ACTIONS(6020),
    [anon_sym_POUNDendif] = ACTIONS(6020),
    [anon_sym_POUNDENDIF] = ACTIONS(6020),
    [anon_sym_POUNDEndif] = ACTIONS(6020),
    [anon_sym_POUNDendif2] = ACTIONS(6020),
    [anon_sym_POUNDENDIF2] = ACTIONS(6020),
    [anon_sym_POUNDEndif2] = ACTIONS(6020),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6018),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6020),
    [sym_datetime_literal] = ACTIONS(6020),
    [sym_date_literal] = ACTIONS(6018),
    [sym_time_literal] = ACTIONS(6018),
    [sym_biginteger_literal] = ACTIONS(6020),
    [anon_sym_if] = ACTIONS(6018),
    [anon_sym_IF] = ACTIONS(6018),
    [anon_sym_If] = ACTIONS(6018),
    [anon_sym_else] = ACTIONS(6018),
    [anon_sym_ELSE] = ACTIONS(6018),
    [anon_sym_Else] = ACTIONS(6018),
    [anon_sym_case] = ACTIONS(6018),
    [anon_sym_CASE] = ACTIONS(6018),
    [anon_sym_Case] = ACTIONS(6018),
    [anon_sym_for] = ACTIONS(6018),
    [anon_sym_FOR] = ACTIONS(6018),
    [anon_sym_For] = ACTIONS(6018),
    [anon_sym_foreach] = ACTIONS(6018),
    [anon_sym_FOREACH] = ACTIONS(6018),
    [anon_sym_Foreach] = ACTIONS(6018),
    [anon_sym_while] = ACTIONS(6018),
    [anon_sym_WHILE] = ACTIONS(6018),
    [anon_sym_While] = ACTIONS(6018),
    [anon_sym_repeat] = ACTIONS(6018),
    [anon_sym_REPEAT] = ACTIONS(6018),
    [anon_sym_Repeat] = ACTIONS(6018),
    [anon_sym_exit] = ACTIONS(6018),
    [anon_sym_EXIT] = ACTIONS(6018),
    [anon_sym_Exit] = ACTIONS(6018),
    [anon_sym_continue] = ACTIONS(6018),
    [anon_sym_CONTINUE] = ACTIONS(6018),
    [anon_sym_Continue] = ACTIONS(6018),
    [anon_sym_break] = ACTIONS(6018),
    [anon_sym_BREAK] = ACTIONS(6018),
    [anon_sym_Break] = ACTIONS(6018),
    [anon_sym_with] = ACTIONS(6018),
    [anon_sym_WITH] = ACTIONS(6018),
    [anon_sym_With] = ACTIONS(6018),
    [sym_asserterror_keyword] = ACTIONS(6020),
    [sym_page_keyword] = ACTIONS(6018),
    [anon_sym_codeunit] = ACTIONS(6018),
    [anon_sym_CODEUNIT] = ACTIONS(6018),
    [anon_sym_Codeunit] = ACTIONS(6018),
    [anon_sym_CodeUnit] = ACTIONS(6018),
    [anon_sym_COdeunit] = ACTIONS(6018),
    [anon_sym_codeUnit] = ACTIONS(6018),
    [sym_report_keyword] = ACTIONS(6018),
    [sym_query_keyword] = ACTIONS(6018),
    [anon_sym_xmlport] = ACTIONS(6018),
    [anon_sym_XMLPORT] = ACTIONS(6018),
    [anon_sym_Xmlport] = ACTIONS(6018),
    [anon_sym_XMLport] = ACTIONS(6018),
    [anon_sym_XMLPort] = ACTIONS(6018),
    [anon_sym_XmlPort] = ACTIONS(6018),
    [anon_sym_enum] = ACTIONS(6018),
    [anon_sym_ENUM] = ACTIONS(6018),
    [anon_sym_Enum] = ACTIONS(6018),
    [anon_sym_eNUM] = ACTIONS(6018),
    [anon_sym_eNum] = ACTIONS(6018),
    [anon_sym_ENum] = ACTIONS(6018),
    [sym_quoted_identifier] = ACTIONS(6020),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6020),
    [sym_verbatim_string] = ACTIONS(6020),
    [sym_integer] = ACTIONS(6018),
    [sym_continue_as_identifier] = ACTIONS(6020),
    [sym_preproc_open] = ACTIONS(6020),
    [sym_preproc_close] = ACTIONS(6020),
  },
  [STATE(2524)] = {
    [sym_identifier] = ACTIONS(6022),
    [anon_sym_SEMI] = ACTIONS(6024),
    [anon_sym_DASH] = ACTIONS(6024),
    [aux_sym_boolean_token1] = ACTIONS(6022),
    [aux_sym_boolean_token2] = ACTIONS(6022),
    [sym_decimal] = ACTIONS(6022),
    [anon_sym_LPAREN] = ACTIONS(6024),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6022),
    [anon_sym_LBRACK] = ACTIONS(6024),
    [aux_sym_record_type_token1] = ACTIONS(6022),
    [aux_sym_basic_type_token21] = ACTIONS(6022),
    [aux_sym_basic_type_token22] = ACTIONS(6022),
    [aux_sym_basic_type_token48] = ACTIONS(6022),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6022),
    [anon_sym_POUNDif] = ACTIONS(6024),
    [anon_sym_POUNDIF] = ACTIONS(6024),
    [anon_sym_POUNDIf] = ACTIONS(6024),
    [anon_sym_not] = ACTIONS(6022),
    [anon_sym_NOT] = ACTIONS(6022),
    [anon_sym_Not] = ACTIONS(6022),
    [anon_sym_POUNDelif] = ACTIONS(6024),
    [anon_sym_POUNDELIF] = ACTIONS(6024),
    [anon_sym_POUNDElif] = ACTIONS(6024),
    [anon_sym_POUNDelse] = ACTIONS(6024),
    [anon_sym_POUNDELSE] = ACTIONS(6024),
    [anon_sym_POUNDElse] = ACTIONS(6024),
    [anon_sym_POUNDelse2] = ACTIONS(6024),
    [anon_sym_POUNDELSE2] = ACTIONS(6024),
    [anon_sym_POUNDElse2] = ACTIONS(6024),
    [anon_sym_POUNDendif] = ACTIONS(6024),
    [anon_sym_POUNDENDIF] = ACTIONS(6024),
    [anon_sym_POUNDEndif] = ACTIONS(6024),
    [anon_sym_POUNDendif2] = ACTIONS(6024),
    [anon_sym_POUNDENDIF2] = ACTIONS(6024),
    [anon_sym_POUNDEndif2] = ACTIONS(6024),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6022),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6022),
    [anon_sym_PLUS] = ACTIONS(6024),
    [sym_datetime_literal] = ACTIONS(6024),
    [sym_date_literal] = ACTIONS(6022),
    [sym_time_literal] = ACTIONS(6022),
    [sym_biginteger_literal] = ACTIONS(6024),
    [anon_sym_if] = ACTIONS(6022),
    [anon_sym_IF] = ACTIONS(6022),
    [anon_sym_If] = ACTIONS(6022),
    [anon_sym_else] = ACTIONS(6022),
    [anon_sym_ELSE] = ACTIONS(6022),
    [anon_sym_Else] = ACTIONS(6022),
    [anon_sym_case] = ACTIONS(6022),
    [anon_sym_CASE] = ACTIONS(6022),
    [anon_sym_Case] = ACTIONS(6022),
    [anon_sym_for] = ACTIONS(6022),
    [anon_sym_FOR] = ACTIONS(6022),
    [anon_sym_For] = ACTIONS(6022),
    [anon_sym_foreach] = ACTIONS(6022),
    [anon_sym_FOREACH] = ACTIONS(6022),
    [anon_sym_Foreach] = ACTIONS(6022),
    [anon_sym_while] = ACTIONS(6022),
    [anon_sym_WHILE] = ACTIONS(6022),
    [anon_sym_While] = ACTIONS(6022),
    [anon_sym_repeat] = ACTIONS(6022),
    [anon_sym_REPEAT] = ACTIONS(6022),
    [anon_sym_Repeat] = ACTIONS(6022),
    [anon_sym_exit] = ACTIONS(6022),
    [anon_sym_EXIT] = ACTIONS(6022),
    [anon_sym_Exit] = ACTIONS(6022),
    [anon_sym_continue] = ACTIONS(6022),
    [anon_sym_CONTINUE] = ACTIONS(6022),
    [anon_sym_Continue] = ACTIONS(6022),
    [anon_sym_break] = ACTIONS(6022),
    [anon_sym_BREAK] = ACTIONS(6022),
    [anon_sym_Break] = ACTIONS(6022),
    [anon_sym_with] = ACTIONS(6022),
    [anon_sym_WITH] = ACTIONS(6022),
    [anon_sym_With] = ACTIONS(6022),
    [sym_asserterror_keyword] = ACTIONS(6024),
    [sym_page_keyword] = ACTIONS(6022),
    [anon_sym_codeunit] = ACTIONS(6022),
    [anon_sym_CODEUNIT] = ACTIONS(6022),
    [anon_sym_Codeunit] = ACTIONS(6022),
    [anon_sym_CodeUnit] = ACTIONS(6022),
    [anon_sym_COdeunit] = ACTIONS(6022),
    [anon_sym_codeUnit] = ACTIONS(6022),
    [sym_report_keyword] = ACTIONS(6022),
    [sym_query_keyword] = ACTIONS(6022),
    [anon_sym_xmlport] = ACTIONS(6022),
    [anon_sym_XMLPORT] = ACTIONS(6022),
    [anon_sym_Xmlport] = ACTIONS(6022),
    [anon_sym_XMLport] = ACTIONS(6022),
    [anon_sym_XMLPort] = ACTIONS(6022),
    [anon_sym_XmlPort] = ACTIONS(6022),
    [anon_sym_enum] = ACTIONS(6022),
    [anon_sym_ENUM] = ACTIONS(6022),
    [anon_sym_Enum] = ACTIONS(6022),
    [anon_sym_eNUM] = ACTIONS(6022),
    [anon_sym_eNum] = ACTIONS(6022),
    [anon_sym_ENum] = ACTIONS(6022),
    [sym_quoted_identifier] = ACTIONS(6024),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6024),
    [sym_verbatim_string] = ACTIONS(6024),
    [sym_integer] = ACTIONS(6022),
    [sym_continue_as_identifier] = ACTIONS(6024),
    [sym_preproc_open] = ACTIONS(6024),
    [sym_preproc_close] = ACTIONS(6024),
  },
  [STATE(2525)] = {
    [sym_identifier] = ACTIONS(6026),
    [anon_sym_SEMI] = ACTIONS(6028),
    [anon_sym_DASH] = ACTIONS(6028),
    [aux_sym_boolean_token1] = ACTIONS(6026),
    [aux_sym_boolean_token2] = ACTIONS(6026),
    [sym_decimal] = ACTIONS(6026),
    [anon_sym_LPAREN] = ACTIONS(6028),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6026),
    [anon_sym_LBRACK] = ACTIONS(6028),
    [aux_sym_record_type_token1] = ACTIONS(6026),
    [aux_sym_basic_type_token21] = ACTIONS(6026),
    [aux_sym_basic_type_token22] = ACTIONS(6026),
    [aux_sym_basic_type_token48] = ACTIONS(6026),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6026),
    [anon_sym_POUNDif] = ACTIONS(6028),
    [anon_sym_POUNDIF] = ACTIONS(6028),
    [anon_sym_POUNDIf] = ACTIONS(6028),
    [anon_sym_not] = ACTIONS(6026),
    [anon_sym_NOT] = ACTIONS(6026),
    [anon_sym_Not] = ACTIONS(6026),
    [anon_sym_POUNDelif] = ACTIONS(6028),
    [anon_sym_POUNDELIF] = ACTIONS(6028),
    [anon_sym_POUNDElif] = ACTIONS(6028),
    [anon_sym_POUNDelse] = ACTIONS(6028),
    [anon_sym_POUNDELSE] = ACTIONS(6028),
    [anon_sym_POUNDElse] = ACTIONS(6028),
    [anon_sym_POUNDelse2] = ACTIONS(6028),
    [anon_sym_POUNDELSE2] = ACTIONS(6028),
    [anon_sym_POUNDElse2] = ACTIONS(6028),
    [anon_sym_POUNDendif] = ACTIONS(6028),
    [anon_sym_POUNDENDIF] = ACTIONS(6028),
    [anon_sym_POUNDEndif] = ACTIONS(6028),
    [anon_sym_POUNDendif2] = ACTIONS(6028),
    [anon_sym_POUNDENDIF2] = ACTIONS(6028),
    [anon_sym_POUNDEndif2] = ACTIONS(6028),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6026),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6026),
    [anon_sym_PLUS] = ACTIONS(6028),
    [sym_datetime_literal] = ACTIONS(6028),
    [sym_date_literal] = ACTIONS(6026),
    [sym_time_literal] = ACTIONS(6026),
    [sym_biginteger_literal] = ACTIONS(6028),
    [anon_sym_if] = ACTIONS(6026),
    [anon_sym_IF] = ACTIONS(6026),
    [anon_sym_If] = ACTIONS(6026),
    [anon_sym_else] = ACTIONS(6026),
    [anon_sym_ELSE] = ACTIONS(6026),
    [anon_sym_Else] = ACTIONS(6026),
    [anon_sym_case] = ACTIONS(6026),
    [anon_sym_CASE] = ACTIONS(6026),
    [anon_sym_Case] = ACTIONS(6026),
    [anon_sym_for] = ACTIONS(6026),
    [anon_sym_FOR] = ACTIONS(6026),
    [anon_sym_For] = ACTIONS(6026),
    [anon_sym_foreach] = ACTIONS(6026),
    [anon_sym_FOREACH] = ACTIONS(6026),
    [anon_sym_Foreach] = ACTIONS(6026),
    [anon_sym_while] = ACTIONS(6026),
    [anon_sym_WHILE] = ACTIONS(6026),
    [anon_sym_While] = ACTIONS(6026),
    [anon_sym_repeat] = ACTIONS(6026),
    [anon_sym_REPEAT] = ACTIONS(6026),
    [anon_sym_Repeat] = ACTIONS(6026),
    [anon_sym_exit] = ACTIONS(6026),
    [anon_sym_EXIT] = ACTIONS(6026),
    [anon_sym_Exit] = ACTIONS(6026),
    [anon_sym_continue] = ACTIONS(6026),
    [anon_sym_CONTINUE] = ACTIONS(6026),
    [anon_sym_Continue] = ACTIONS(6026),
    [anon_sym_break] = ACTIONS(6026),
    [anon_sym_BREAK] = ACTIONS(6026),
    [anon_sym_Break] = ACTIONS(6026),
    [anon_sym_with] = ACTIONS(6026),
    [anon_sym_WITH] = ACTIONS(6026),
    [anon_sym_With] = ACTIONS(6026),
    [sym_asserterror_keyword] = ACTIONS(6028),
    [sym_page_keyword] = ACTIONS(6026),
    [anon_sym_codeunit] = ACTIONS(6026),
    [anon_sym_CODEUNIT] = ACTIONS(6026),
    [anon_sym_Codeunit] = ACTIONS(6026),
    [anon_sym_CodeUnit] = ACTIONS(6026),
    [anon_sym_COdeunit] = ACTIONS(6026),
    [anon_sym_codeUnit] = ACTIONS(6026),
    [sym_report_keyword] = ACTIONS(6026),
    [sym_query_keyword] = ACTIONS(6026),
    [anon_sym_xmlport] = ACTIONS(6026),
    [anon_sym_XMLPORT] = ACTIONS(6026),
    [anon_sym_Xmlport] = ACTIONS(6026),
    [anon_sym_XMLport] = ACTIONS(6026),
    [anon_sym_XMLPort] = ACTIONS(6026),
    [anon_sym_XmlPort] = ACTIONS(6026),
    [anon_sym_enum] = ACTIONS(6026),
    [anon_sym_ENUM] = ACTIONS(6026),
    [anon_sym_Enum] = ACTIONS(6026),
    [anon_sym_eNUM] = ACTIONS(6026),
    [anon_sym_eNum] = ACTIONS(6026),
    [anon_sym_ENum] = ACTIONS(6026),
    [sym_quoted_identifier] = ACTIONS(6028),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6028),
    [sym_verbatim_string] = ACTIONS(6028),
    [sym_integer] = ACTIONS(6026),
    [sym_continue_as_identifier] = ACTIONS(6028),
    [sym_preproc_open] = ACTIONS(6028),
    [sym_preproc_close] = ACTIONS(6028),
  },
  [STATE(2526)] = {
    [sym_boolean] = STATE(7226),
    [sym_option_member_list] = STATE(7208),
    [sym_option_member] = STATE(7530),
    [sym_keyword_identifier] = STATE(7226),
    [sym_codeunit_keyword] = STATE(6858),
    [sym_xmlport_keyword] = STATE(6858),
    [sym_enum_keyword] = STATE(6858),
    [sym_keyword_as_identifier] = STATE(7226),
    [aux_sym_option_member_list_repeat2] = STATE(2657),
    [sym_identifier] = ACTIONS(3993),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(6030),
    [anon_sym_COLON] = ACTIONS(584),
    [anon_sym_DASH] = ACTIONS(6032),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [anon_sym_RPAREN] = ACTIONS(582),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_RBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(6034),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(582),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1382),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_then] = ACTIONS(584),
    [anon_sym_THEN] = ACTIONS(584),
    [anon_sym_Then] = ACTIONS(584),
    [anon_sym_of] = ACTIONS(584),
    [anon_sym_OF] = ACTIONS(584),
    [anon_sym_Of] = ACTIONS(584),
    [anon_sym_do] = ACTIONS(584),
    [anon_sym_DO] = ACTIONS(584),
    [anon_sym_Do] = ACTIONS(584),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_page_keyword] = ACTIONS(1382),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1382),
    [sym_query_keyword] = ACTIONS(1382),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6036),
    [sym_integer] = ACTIONS(6036),
  },
  [STATE(2527)] = {
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6040),
    [anon_sym_DASH] = ACTIONS(6040),
    [aux_sym_boolean_token1] = ACTIONS(6038),
    [aux_sym_boolean_token2] = ACTIONS(6038),
    [sym_decimal] = ACTIONS(6038),
    [anon_sym_LPAREN] = ACTIONS(6040),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6038),
    [anon_sym_LBRACK] = ACTIONS(6040),
    [aux_sym_record_type_token1] = ACTIONS(6038),
    [aux_sym_basic_type_token21] = ACTIONS(6038),
    [aux_sym_basic_type_token22] = ACTIONS(6038),
    [aux_sym_basic_type_token48] = ACTIONS(6038),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6038),
    [anon_sym_POUNDif] = ACTIONS(6040),
    [anon_sym_POUNDIF] = ACTIONS(6040),
    [anon_sym_POUNDIf] = ACTIONS(6040),
    [anon_sym_not] = ACTIONS(6038),
    [anon_sym_NOT] = ACTIONS(6038),
    [anon_sym_Not] = ACTIONS(6038),
    [anon_sym_POUNDelif] = ACTIONS(6040),
    [anon_sym_POUNDELIF] = ACTIONS(6040),
    [anon_sym_POUNDElif] = ACTIONS(6040),
    [anon_sym_POUNDelse] = ACTIONS(6040),
    [anon_sym_POUNDELSE] = ACTIONS(6040),
    [anon_sym_POUNDElse] = ACTIONS(6040),
    [anon_sym_POUNDelse2] = ACTIONS(6040),
    [anon_sym_POUNDELSE2] = ACTIONS(6040),
    [anon_sym_POUNDElse2] = ACTIONS(6040),
    [anon_sym_POUNDendif] = ACTIONS(6040),
    [anon_sym_POUNDENDIF] = ACTIONS(6040),
    [anon_sym_POUNDEndif] = ACTIONS(6040),
    [anon_sym_POUNDendif2] = ACTIONS(6040),
    [anon_sym_POUNDENDIF2] = ACTIONS(6040),
    [anon_sym_POUNDEndif2] = ACTIONS(6040),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6038),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6038),
    [anon_sym_PLUS] = ACTIONS(6040),
    [sym_datetime_literal] = ACTIONS(6040),
    [sym_date_literal] = ACTIONS(6038),
    [sym_time_literal] = ACTIONS(6038),
    [sym_biginteger_literal] = ACTIONS(6040),
    [anon_sym_if] = ACTIONS(6038),
    [anon_sym_IF] = ACTIONS(6038),
    [anon_sym_If] = ACTIONS(6038),
    [anon_sym_else] = ACTIONS(6038),
    [anon_sym_ELSE] = ACTIONS(6038),
    [anon_sym_Else] = ACTIONS(6038),
    [anon_sym_case] = ACTIONS(6038),
    [anon_sym_CASE] = ACTIONS(6038),
    [anon_sym_Case] = ACTIONS(6038),
    [anon_sym_for] = ACTIONS(6038),
    [anon_sym_FOR] = ACTIONS(6038),
    [anon_sym_For] = ACTIONS(6038),
    [anon_sym_foreach] = ACTIONS(6038),
    [anon_sym_FOREACH] = ACTIONS(6038),
    [anon_sym_Foreach] = ACTIONS(6038),
    [anon_sym_while] = ACTIONS(6038),
    [anon_sym_WHILE] = ACTIONS(6038),
    [anon_sym_While] = ACTIONS(6038),
    [anon_sym_repeat] = ACTIONS(6038),
    [anon_sym_REPEAT] = ACTIONS(6038),
    [anon_sym_Repeat] = ACTIONS(6038),
    [anon_sym_exit] = ACTIONS(6038),
    [anon_sym_EXIT] = ACTIONS(6038),
    [anon_sym_Exit] = ACTIONS(6038),
    [anon_sym_continue] = ACTIONS(6038),
    [anon_sym_CONTINUE] = ACTIONS(6038),
    [anon_sym_Continue] = ACTIONS(6038),
    [anon_sym_break] = ACTIONS(6038),
    [anon_sym_BREAK] = ACTIONS(6038),
    [anon_sym_Break] = ACTIONS(6038),
    [anon_sym_with] = ACTIONS(6038),
    [anon_sym_WITH] = ACTIONS(6038),
    [anon_sym_With] = ACTIONS(6038),
    [sym_asserterror_keyword] = ACTIONS(6040),
    [sym_page_keyword] = ACTIONS(6038),
    [anon_sym_codeunit] = ACTIONS(6038),
    [anon_sym_CODEUNIT] = ACTIONS(6038),
    [anon_sym_Codeunit] = ACTIONS(6038),
    [anon_sym_CodeUnit] = ACTIONS(6038),
    [anon_sym_COdeunit] = ACTIONS(6038),
    [anon_sym_codeUnit] = ACTIONS(6038),
    [sym_report_keyword] = ACTIONS(6038),
    [sym_query_keyword] = ACTIONS(6038),
    [anon_sym_xmlport] = ACTIONS(6038),
    [anon_sym_XMLPORT] = ACTIONS(6038),
    [anon_sym_Xmlport] = ACTIONS(6038),
    [anon_sym_XMLport] = ACTIONS(6038),
    [anon_sym_XMLPort] = ACTIONS(6038),
    [anon_sym_XmlPort] = ACTIONS(6038),
    [anon_sym_enum] = ACTIONS(6038),
    [anon_sym_ENUM] = ACTIONS(6038),
    [anon_sym_Enum] = ACTIONS(6038),
    [anon_sym_eNUM] = ACTIONS(6038),
    [anon_sym_eNum] = ACTIONS(6038),
    [anon_sym_ENum] = ACTIONS(6038),
    [sym_quoted_identifier] = ACTIONS(6040),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6040),
    [sym_verbatim_string] = ACTIONS(6040),
    [sym_integer] = ACTIONS(6038),
    [sym_continue_as_identifier] = ACTIONS(6040),
    [sym_preproc_open] = ACTIONS(6040),
    [sym_preproc_close] = ACTIONS(6040),
  },
  [STATE(2528)] = {
    [sym_identifier] = ACTIONS(6042),
    [anon_sym_SEMI] = ACTIONS(6044),
    [anon_sym_DASH] = ACTIONS(6044),
    [aux_sym_boolean_token1] = ACTIONS(6042),
    [aux_sym_boolean_token2] = ACTIONS(6042),
    [sym_decimal] = ACTIONS(6042),
    [anon_sym_LPAREN] = ACTIONS(6044),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6042),
    [anon_sym_LBRACK] = ACTIONS(6044),
    [aux_sym_record_type_token1] = ACTIONS(6042),
    [aux_sym_basic_type_token21] = ACTIONS(6042),
    [aux_sym_basic_type_token22] = ACTIONS(6042),
    [aux_sym_basic_type_token48] = ACTIONS(6042),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6042),
    [anon_sym_POUNDif] = ACTIONS(6044),
    [anon_sym_POUNDIF] = ACTIONS(6044),
    [anon_sym_POUNDIf] = ACTIONS(6044),
    [anon_sym_not] = ACTIONS(6042),
    [anon_sym_NOT] = ACTIONS(6042),
    [anon_sym_Not] = ACTIONS(6042),
    [anon_sym_POUNDelif] = ACTIONS(6044),
    [anon_sym_POUNDELIF] = ACTIONS(6044),
    [anon_sym_POUNDElif] = ACTIONS(6044),
    [anon_sym_POUNDelse] = ACTIONS(6044),
    [anon_sym_POUNDELSE] = ACTIONS(6044),
    [anon_sym_POUNDElse] = ACTIONS(6044),
    [anon_sym_POUNDelse2] = ACTIONS(6044),
    [anon_sym_POUNDELSE2] = ACTIONS(6044),
    [anon_sym_POUNDElse2] = ACTIONS(6044),
    [anon_sym_POUNDendif] = ACTIONS(6044),
    [anon_sym_POUNDENDIF] = ACTIONS(6044),
    [anon_sym_POUNDEndif] = ACTIONS(6044),
    [anon_sym_POUNDendif2] = ACTIONS(6044),
    [anon_sym_POUNDENDIF2] = ACTIONS(6044),
    [anon_sym_POUNDEndif2] = ACTIONS(6044),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6042),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6042),
    [anon_sym_PLUS] = ACTIONS(6044),
    [sym_datetime_literal] = ACTIONS(6044),
    [sym_date_literal] = ACTIONS(6042),
    [sym_time_literal] = ACTIONS(6042),
    [sym_biginteger_literal] = ACTIONS(6044),
    [anon_sym_if] = ACTIONS(6042),
    [anon_sym_IF] = ACTIONS(6042),
    [anon_sym_If] = ACTIONS(6042),
    [anon_sym_else] = ACTIONS(6042),
    [anon_sym_ELSE] = ACTIONS(6042),
    [anon_sym_Else] = ACTIONS(6042),
    [anon_sym_case] = ACTIONS(6042),
    [anon_sym_CASE] = ACTIONS(6042),
    [anon_sym_Case] = ACTIONS(6042),
    [anon_sym_for] = ACTIONS(6042),
    [anon_sym_FOR] = ACTIONS(6042),
    [anon_sym_For] = ACTIONS(6042),
    [anon_sym_foreach] = ACTIONS(6042),
    [anon_sym_FOREACH] = ACTIONS(6042),
    [anon_sym_Foreach] = ACTIONS(6042),
    [anon_sym_while] = ACTIONS(6042),
    [anon_sym_WHILE] = ACTIONS(6042),
    [anon_sym_While] = ACTIONS(6042),
    [anon_sym_repeat] = ACTIONS(6042),
    [anon_sym_REPEAT] = ACTIONS(6042),
    [anon_sym_Repeat] = ACTIONS(6042),
    [anon_sym_exit] = ACTIONS(6042),
    [anon_sym_EXIT] = ACTIONS(6042),
    [anon_sym_Exit] = ACTIONS(6042),
    [anon_sym_continue] = ACTIONS(6042),
    [anon_sym_CONTINUE] = ACTIONS(6042),
    [anon_sym_Continue] = ACTIONS(6042),
    [anon_sym_break] = ACTIONS(6042),
    [anon_sym_BREAK] = ACTIONS(6042),
    [anon_sym_Break] = ACTIONS(6042),
    [anon_sym_with] = ACTIONS(6042),
    [anon_sym_WITH] = ACTIONS(6042),
    [anon_sym_With] = ACTIONS(6042),
    [sym_asserterror_keyword] = ACTIONS(6044),
    [sym_page_keyword] = ACTIONS(6042),
    [anon_sym_codeunit] = ACTIONS(6042),
    [anon_sym_CODEUNIT] = ACTIONS(6042),
    [anon_sym_Codeunit] = ACTIONS(6042),
    [anon_sym_CodeUnit] = ACTIONS(6042),
    [anon_sym_COdeunit] = ACTIONS(6042),
    [anon_sym_codeUnit] = ACTIONS(6042),
    [sym_report_keyword] = ACTIONS(6042),
    [sym_query_keyword] = ACTIONS(6042),
    [anon_sym_xmlport] = ACTIONS(6042),
    [anon_sym_XMLPORT] = ACTIONS(6042),
    [anon_sym_Xmlport] = ACTIONS(6042),
    [anon_sym_XMLport] = ACTIONS(6042),
    [anon_sym_XMLPort] = ACTIONS(6042),
    [anon_sym_XmlPort] = ACTIONS(6042),
    [anon_sym_enum] = ACTIONS(6042),
    [anon_sym_ENUM] = ACTIONS(6042),
    [anon_sym_Enum] = ACTIONS(6042),
    [anon_sym_eNUM] = ACTIONS(6042),
    [anon_sym_eNum] = ACTIONS(6042),
    [anon_sym_ENum] = ACTIONS(6042),
    [sym_quoted_identifier] = ACTIONS(6044),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6044),
    [sym_verbatim_string] = ACTIONS(6044),
    [sym_integer] = ACTIONS(6042),
    [sym_continue_as_identifier] = ACTIONS(6044),
    [sym_preproc_open] = ACTIONS(6044),
    [sym_preproc_close] = ACTIONS(6044),
  },
  [STATE(2529)] = {
    [sym_identifier] = ACTIONS(6046),
    [anon_sym_SEMI] = ACTIONS(6048),
    [anon_sym_DASH] = ACTIONS(6048),
    [aux_sym_boolean_token1] = ACTIONS(6046),
    [aux_sym_boolean_token2] = ACTIONS(6046),
    [sym_decimal] = ACTIONS(6046),
    [anon_sym_LPAREN] = ACTIONS(6048),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6046),
    [anon_sym_LBRACK] = ACTIONS(6048),
    [aux_sym_record_type_token1] = ACTIONS(6046),
    [aux_sym_basic_type_token21] = ACTIONS(6046),
    [aux_sym_basic_type_token22] = ACTIONS(6046),
    [aux_sym_basic_type_token48] = ACTIONS(6046),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6046),
    [anon_sym_POUNDif] = ACTIONS(6048),
    [anon_sym_POUNDIF] = ACTIONS(6048),
    [anon_sym_POUNDIf] = ACTIONS(6048),
    [anon_sym_not] = ACTIONS(6046),
    [anon_sym_NOT] = ACTIONS(6046),
    [anon_sym_Not] = ACTIONS(6046),
    [anon_sym_POUNDelif] = ACTIONS(6048),
    [anon_sym_POUNDELIF] = ACTIONS(6048),
    [anon_sym_POUNDElif] = ACTIONS(6048),
    [anon_sym_POUNDelse] = ACTIONS(6048),
    [anon_sym_POUNDELSE] = ACTIONS(6048),
    [anon_sym_POUNDElse] = ACTIONS(6048),
    [anon_sym_POUNDelse2] = ACTIONS(6048),
    [anon_sym_POUNDELSE2] = ACTIONS(6048),
    [anon_sym_POUNDElse2] = ACTIONS(6048),
    [anon_sym_POUNDendif] = ACTIONS(6048),
    [anon_sym_POUNDENDIF] = ACTIONS(6048),
    [anon_sym_POUNDEndif] = ACTIONS(6048),
    [anon_sym_POUNDendif2] = ACTIONS(6048),
    [anon_sym_POUNDENDIF2] = ACTIONS(6048),
    [anon_sym_POUNDEndif2] = ACTIONS(6048),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6046),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6046),
    [anon_sym_PLUS] = ACTIONS(6048),
    [sym_datetime_literal] = ACTIONS(6048),
    [sym_date_literal] = ACTIONS(6046),
    [sym_time_literal] = ACTIONS(6046),
    [sym_biginteger_literal] = ACTIONS(6048),
    [anon_sym_if] = ACTIONS(6046),
    [anon_sym_IF] = ACTIONS(6046),
    [anon_sym_If] = ACTIONS(6046),
    [anon_sym_else] = ACTIONS(6046),
    [anon_sym_ELSE] = ACTIONS(6046),
    [anon_sym_Else] = ACTIONS(6046),
    [anon_sym_case] = ACTIONS(6046),
    [anon_sym_CASE] = ACTIONS(6046),
    [anon_sym_Case] = ACTIONS(6046),
    [anon_sym_for] = ACTIONS(6046),
    [anon_sym_FOR] = ACTIONS(6046),
    [anon_sym_For] = ACTIONS(6046),
    [anon_sym_foreach] = ACTIONS(6046),
    [anon_sym_FOREACH] = ACTIONS(6046),
    [anon_sym_Foreach] = ACTIONS(6046),
    [anon_sym_while] = ACTIONS(6046),
    [anon_sym_WHILE] = ACTIONS(6046),
    [anon_sym_While] = ACTIONS(6046),
    [anon_sym_repeat] = ACTIONS(6046),
    [anon_sym_REPEAT] = ACTIONS(6046),
    [anon_sym_Repeat] = ACTIONS(6046),
    [anon_sym_exit] = ACTIONS(6046),
    [anon_sym_EXIT] = ACTIONS(6046),
    [anon_sym_Exit] = ACTIONS(6046),
    [anon_sym_continue] = ACTIONS(6046),
    [anon_sym_CONTINUE] = ACTIONS(6046),
    [anon_sym_Continue] = ACTIONS(6046),
    [anon_sym_break] = ACTIONS(6046),
    [anon_sym_BREAK] = ACTIONS(6046),
    [anon_sym_Break] = ACTIONS(6046),
    [anon_sym_with] = ACTIONS(6046),
    [anon_sym_WITH] = ACTIONS(6046),
    [anon_sym_With] = ACTIONS(6046),
    [sym_asserterror_keyword] = ACTIONS(6048),
    [sym_page_keyword] = ACTIONS(6046),
    [anon_sym_codeunit] = ACTIONS(6046),
    [anon_sym_CODEUNIT] = ACTIONS(6046),
    [anon_sym_Codeunit] = ACTIONS(6046),
    [anon_sym_CodeUnit] = ACTIONS(6046),
    [anon_sym_COdeunit] = ACTIONS(6046),
    [anon_sym_codeUnit] = ACTIONS(6046),
    [sym_report_keyword] = ACTIONS(6046),
    [sym_query_keyword] = ACTIONS(6046),
    [anon_sym_xmlport] = ACTIONS(6046),
    [anon_sym_XMLPORT] = ACTIONS(6046),
    [anon_sym_Xmlport] = ACTIONS(6046),
    [anon_sym_XMLport] = ACTIONS(6046),
    [anon_sym_XMLPort] = ACTIONS(6046),
    [anon_sym_XmlPort] = ACTIONS(6046),
    [anon_sym_enum] = ACTIONS(6046),
    [anon_sym_ENUM] = ACTIONS(6046),
    [anon_sym_Enum] = ACTIONS(6046),
    [anon_sym_eNUM] = ACTIONS(6046),
    [anon_sym_eNum] = ACTIONS(6046),
    [anon_sym_ENum] = ACTIONS(6046),
    [sym_quoted_identifier] = ACTIONS(6048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6048),
    [sym_verbatim_string] = ACTIONS(6048),
    [sym_integer] = ACTIONS(6046),
    [sym_continue_as_identifier] = ACTIONS(6048),
    [sym_preproc_open] = ACTIONS(6048),
    [sym_preproc_close] = ACTIONS(6048),
  },
  [STATE(2530)] = {
    [sym_identifier] = ACTIONS(6050),
    [anon_sym_SEMI] = ACTIONS(6052),
    [anon_sym_DASH] = ACTIONS(6052),
    [aux_sym_boolean_token1] = ACTIONS(6050),
    [aux_sym_boolean_token2] = ACTIONS(6050),
    [sym_decimal] = ACTIONS(6050),
    [anon_sym_LPAREN] = ACTIONS(6052),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6050),
    [anon_sym_LBRACK] = ACTIONS(6052),
    [aux_sym_record_type_token1] = ACTIONS(6050),
    [aux_sym_basic_type_token21] = ACTIONS(6050),
    [aux_sym_basic_type_token22] = ACTIONS(6050),
    [aux_sym_basic_type_token48] = ACTIONS(6050),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6050),
    [anon_sym_POUNDif] = ACTIONS(6052),
    [anon_sym_POUNDIF] = ACTIONS(6052),
    [anon_sym_POUNDIf] = ACTIONS(6052),
    [anon_sym_not] = ACTIONS(6050),
    [anon_sym_NOT] = ACTIONS(6050),
    [anon_sym_Not] = ACTIONS(6050),
    [anon_sym_POUNDelif] = ACTIONS(6052),
    [anon_sym_POUNDELIF] = ACTIONS(6052),
    [anon_sym_POUNDElif] = ACTIONS(6052),
    [anon_sym_POUNDelse] = ACTIONS(6052),
    [anon_sym_POUNDELSE] = ACTIONS(6052),
    [anon_sym_POUNDElse] = ACTIONS(6052),
    [anon_sym_POUNDelse2] = ACTIONS(6052),
    [anon_sym_POUNDELSE2] = ACTIONS(6052),
    [anon_sym_POUNDElse2] = ACTIONS(6052),
    [anon_sym_POUNDendif] = ACTIONS(6052),
    [anon_sym_POUNDENDIF] = ACTIONS(6052),
    [anon_sym_POUNDEndif] = ACTIONS(6052),
    [anon_sym_POUNDendif2] = ACTIONS(6052),
    [anon_sym_POUNDENDIF2] = ACTIONS(6052),
    [anon_sym_POUNDEndif2] = ACTIONS(6052),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6050),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6050),
    [anon_sym_PLUS] = ACTIONS(6052),
    [sym_datetime_literal] = ACTIONS(6052),
    [sym_date_literal] = ACTIONS(6050),
    [sym_time_literal] = ACTIONS(6050),
    [sym_biginteger_literal] = ACTIONS(6052),
    [anon_sym_if] = ACTIONS(6050),
    [anon_sym_IF] = ACTIONS(6050),
    [anon_sym_If] = ACTIONS(6050),
    [anon_sym_else] = ACTIONS(6050),
    [anon_sym_ELSE] = ACTIONS(6050),
    [anon_sym_Else] = ACTIONS(6050),
    [anon_sym_case] = ACTIONS(6050),
    [anon_sym_CASE] = ACTIONS(6050),
    [anon_sym_Case] = ACTIONS(6050),
    [anon_sym_for] = ACTIONS(6050),
    [anon_sym_FOR] = ACTIONS(6050),
    [anon_sym_For] = ACTIONS(6050),
    [anon_sym_foreach] = ACTIONS(6050),
    [anon_sym_FOREACH] = ACTIONS(6050),
    [anon_sym_Foreach] = ACTIONS(6050),
    [anon_sym_while] = ACTIONS(6050),
    [anon_sym_WHILE] = ACTIONS(6050),
    [anon_sym_While] = ACTIONS(6050),
    [anon_sym_repeat] = ACTIONS(6050),
    [anon_sym_REPEAT] = ACTIONS(6050),
    [anon_sym_Repeat] = ACTIONS(6050),
    [anon_sym_exit] = ACTIONS(6050),
    [anon_sym_EXIT] = ACTIONS(6050),
    [anon_sym_Exit] = ACTIONS(6050),
    [anon_sym_continue] = ACTIONS(6050),
    [anon_sym_CONTINUE] = ACTIONS(6050),
    [anon_sym_Continue] = ACTIONS(6050),
    [anon_sym_break] = ACTIONS(6050),
    [anon_sym_BREAK] = ACTIONS(6050),
    [anon_sym_Break] = ACTIONS(6050),
    [anon_sym_with] = ACTIONS(6050),
    [anon_sym_WITH] = ACTIONS(6050),
    [anon_sym_With] = ACTIONS(6050),
    [sym_asserterror_keyword] = ACTIONS(6052),
    [sym_page_keyword] = ACTIONS(6050),
    [anon_sym_codeunit] = ACTIONS(6050),
    [anon_sym_CODEUNIT] = ACTIONS(6050),
    [anon_sym_Codeunit] = ACTIONS(6050),
    [anon_sym_CodeUnit] = ACTIONS(6050),
    [anon_sym_COdeunit] = ACTIONS(6050),
    [anon_sym_codeUnit] = ACTIONS(6050),
    [sym_report_keyword] = ACTIONS(6050),
    [sym_query_keyword] = ACTIONS(6050),
    [anon_sym_xmlport] = ACTIONS(6050),
    [anon_sym_XMLPORT] = ACTIONS(6050),
    [anon_sym_Xmlport] = ACTIONS(6050),
    [anon_sym_XMLport] = ACTIONS(6050),
    [anon_sym_XMLPort] = ACTIONS(6050),
    [anon_sym_XmlPort] = ACTIONS(6050),
    [anon_sym_enum] = ACTIONS(6050),
    [anon_sym_ENUM] = ACTIONS(6050),
    [anon_sym_Enum] = ACTIONS(6050),
    [anon_sym_eNUM] = ACTIONS(6050),
    [anon_sym_eNum] = ACTIONS(6050),
    [anon_sym_ENum] = ACTIONS(6050),
    [sym_quoted_identifier] = ACTIONS(6052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6052),
    [sym_verbatim_string] = ACTIONS(6052),
    [sym_integer] = ACTIONS(6050),
    [sym_continue_as_identifier] = ACTIONS(6052),
    [sym_preproc_open] = ACTIONS(6052),
    [sym_preproc_close] = ACTIONS(6052),
  },
  [STATE(2531)] = {
    [sym_identifier] = ACTIONS(6046),
    [anon_sym_SEMI] = ACTIONS(6048),
    [anon_sym_DASH] = ACTIONS(6048),
    [aux_sym_boolean_token1] = ACTIONS(6046),
    [aux_sym_boolean_token2] = ACTIONS(6046),
    [sym_decimal] = ACTIONS(6046),
    [anon_sym_LPAREN] = ACTIONS(6048),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6046),
    [anon_sym_LBRACK] = ACTIONS(6048),
    [aux_sym_record_type_token1] = ACTIONS(6046),
    [aux_sym_basic_type_token21] = ACTIONS(6046),
    [aux_sym_basic_type_token22] = ACTIONS(6046),
    [aux_sym_basic_type_token48] = ACTIONS(6046),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6046),
    [anon_sym_POUNDif] = ACTIONS(6048),
    [anon_sym_POUNDIF] = ACTIONS(6048),
    [anon_sym_POUNDIf] = ACTIONS(6048),
    [anon_sym_not] = ACTIONS(6046),
    [anon_sym_NOT] = ACTIONS(6046),
    [anon_sym_Not] = ACTIONS(6046),
    [anon_sym_POUNDelif] = ACTIONS(6048),
    [anon_sym_POUNDELIF] = ACTIONS(6048),
    [anon_sym_POUNDElif] = ACTIONS(6048),
    [anon_sym_POUNDelse] = ACTIONS(6048),
    [anon_sym_POUNDELSE] = ACTIONS(6048),
    [anon_sym_POUNDElse] = ACTIONS(6048),
    [anon_sym_POUNDelse2] = ACTIONS(6048),
    [anon_sym_POUNDELSE2] = ACTIONS(6048),
    [anon_sym_POUNDElse2] = ACTIONS(6048),
    [anon_sym_POUNDendif] = ACTIONS(6048),
    [anon_sym_POUNDENDIF] = ACTIONS(6048),
    [anon_sym_POUNDEndif] = ACTIONS(6048),
    [anon_sym_POUNDendif2] = ACTIONS(6048),
    [anon_sym_POUNDENDIF2] = ACTIONS(6048),
    [anon_sym_POUNDEndif2] = ACTIONS(6048),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6046),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6046),
    [anon_sym_PLUS] = ACTIONS(6048),
    [sym_datetime_literal] = ACTIONS(6048),
    [sym_date_literal] = ACTIONS(6046),
    [sym_time_literal] = ACTIONS(6046),
    [sym_biginteger_literal] = ACTIONS(6048),
    [anon_sym_if] = ACTIONS(6046),
    [anon_sym_IF] = ACTIONS(6046),
    [anon_sym_If] = ACTIONS(6046),
    [anon_sym_else] = ACTIONS(6046),
    [anon_sym_ELSE] = ACTIONS(6046),
    [anon_sym_Else] = ACTIONS(6046),
    [anon_sym_case] = ACTIONS(6046),
    [anon_sym_CASE] = ACTIONS(6046),
    [anon_sym_Case] = ACTIONS(6046),
    [anon_sym_for] = ACTIONS(6046),
    [anon_sym_FOR] = ACTIONS(6046),
    [anon_sym_For] = ACTIONS(6046),
    [anon_sym_foreach] = ACTIONS(6046),
    [anon_sym_FOREACH] = ACTIONS(6046),
    [anon_sym_Foreach] = ACTIONS(6046),
    [anon_sym_while] = ACTIONS(6046),
    [anon_sym_WHILE] = ACTIONS(6046),
    [anon_sym_While] = ACTIONS(6046),
    [anon_sym_repeat] = ACTIONS(6046),
    [anon_sym_REPEAT] = ACTIONS(6046),
    [anon_sym_Repeat] = ACTIONS(6046),
    [anon_sym_exit] = ACTIONS(6046),
    [anon_sym_EXIT] = ACTIONS(6046),
    [anon_sym_Exit] = ACTIONS(6046),
    [anon_sym_continue] = ACTIONS(6046),
    [anon_sym_CONTINUE] = ACTIONS(6046),
    [anon_sym_Continue] = ACTIONS(6046),
    [anon_sym_break] = ACTIONS(6046),
    [anon_sym_BREAK] = ACTIONS(6046),
    [anon_sym_Break] = ACTIONS(6046),
    [anon_sym_with] = ACTIONS(6046),
    [anon_sym_WITH] = ACTIONS(6046),
    [anon_sym_With] = ACTIONS(6046),
    [sym_asserterror_keyword] = ACTIONS(6048),
    [sym_page_keyword] = ACTIONS(6046),
    [anon_sym_codeunit] = ACTIONS(6046),
    [anon_sym_CODEUNIT] = ACTIONS(6046),
    [anon_sym_Codeunit] = ACTIONS(6046),
    [anon_sym_CodeUnit] = ACTIONS(6046),
    [anon_sym_COdeunit] = ACTIONS(6046),
    [anon_sym_codeUnit] = ACTIONS(6046),
    [sym_report_keyword] = ACTIONS(6046),
    [sym_query_keyword] = ACTIONS(6046),
    [anon_sym_xmlport] = ACTIONS(6046),
    [anon_sym_XMLPORT] = ACTIONS(6046),
    [anon_sym_Xmlport] = ACTIONS(6046),
    [anon_sym_XMLport] = ACTIONS(6046),
    [anon_sym_XMLPort] = ACTIONS(6046),
    [anon_sym_XmlPort] = ACTIONS(6046),
    [anon_sym_enum] = ACTIONS(6046),
    [anon_sym_ENUM] = ACTIONS(6046),
    [anon_sym_Enum] = ACTIONS(6046),
    [anon_sym_eNUM] = ACTIONS(6046),
    [anon_sym_eNum] = ACTIONS(6046),
    [anon_sym_ENum] = ACTIONS(6046),
    [sym_quoted_identifier] = ACTIONS(6048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6048),
    [sym_verbatim_string] = ACTIONS(6048),
    [sym_integer] = ACTIONS(6046),
    [sym_continue_as_identifier] = ACTIONS(6048),
    [sym_preproc_open] = ACTIONS(6048),
    [sym_preproc_close] = ACTIONS(6048),
  },
  [STATE(2532)] = {
    [sym_identifier] = ACTIONS(6054),
    [anon_sym_SEMI] = ACTIONS(6056),
    [anon_sym_DASH] = ACTIONS(6056),
    [aux_sym_boolean_token1] = ACTIONS(6054),
    [aux_sym_boolean_token2] = ACTIONS(6054),
    [sym_decimal] = ACTIONS(6054),
    [anon_sym_LPAREN] = ACTIONS(6056),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6054),
    [anon_sym_LBRACK] = ACTIONS(6056),
    [aux_sym_record_type_token1] = ACTIONS(6054),
    [aux_sym_basic_type_token21] = ACTIONS(6054),
    [aux_sym_basic_type_token22] = ACTIONS(6054),
    [aux_sym_basic_type_token48] = ACTIONS(6054),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6054),
    [anon_sym_POUNDif] = ACTIONS(6056),
    [anon_sym_POUNDIF] = ACTIONS(6056),
    [anon_sym_POUNDIf] = ACTIONS(6056),
    [anon_sym_not] = ACTIONS(6054),
    [anon_sym_NOT] = ACTIONS(6054),
    [anon_sym_Not] = ACTIONS(6054),
    [anon_sym_POUNDelif] = ACTIONS(6056),
    [anon_sym_POUNDELIF] = ACTIONS(6056),
    [anon_sym_POUNDElif] = ACTIONS(6056),
    [anon_sym_POUNDelse] = ACTIONS(6056),
    [anon_sym_POUNDELSE] = ACTIONS(6056),
    [anon_sym_POUNDElse] = ACTIONS(6056),
    [anon_sym_POUNDelse2] = ACTIONS(6056),
    [anon_sym_POUNDELSE2] = ACTIONS(6056),
    [anon_sym_POUNDElse2] = ACTIONS(6056),
    [anon_sym_POUNDendif] = ACTIONS(6056),
    [anon_sym_POUNDENDIF] = ACTIONS(6056),
    [anon_sym_POUNDEndif] = ACTIONS(6056),
    [anon_sym_POUNDendif2] = ACTIONS(6056),
    [anon_sym_POUNDENDIF2] = ACTIONS(6056),
    [anon_sym_POUNDEndif2] = ACTIONS(6056),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6054),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6054),
    [anon_sym_PLUS] = ACTIONS(6056),
    [sym_datetime_literal] = ACTIONS(6056),
    [sym_date_literal] = ACTIONS(6054),
    [sym_time_literal] = ACTIONS(6054),
    [sym_biginteger_literal] = ACTIONS(6056),
    [anon_sym_if] = ACTIONS(6054),
    [anon_sym_IF] = ACTIONS(6054),
    [anon_sym_If] = ACTIONS(6054),
    [anon_sym_else] = ACTIONS(6054),
    [anon_sym_ELSE] = ACTIONS(6054),
    [anon_sym_Else] = ACTIONS(6054),
    [anon_sym_case] = ACTIONS(6054),
    [anon_sym_CASE] = ACTIONS(6054),
    [anon_sym_Case] = ACTIONS(6054),
    [anon_sym_for] = ACTIONS(6054),
    [anon_sym_FOR] = ACTIONS(6054),
    [anon_sym_For] = ACTIONS(6054),
    [anon_sym_foreach] = ACTIONS(6054),
    [anon_sym_FOREACH] = ACTIONS(6054),
    [anon_sym_Foreach] = ACTIONS(6054),
    [anon_sym_while] = ACTIONS(6054),
    [anon_sym_WHILE] = ACTIONS(6054),
    [anon_sym_While] = ACTIONS(6054),
    [anon_sym_repeat] = ACTIONS(6054),
    [anon_sym_REPEAT] = ACTIONS(6054),
    [anon_sym_Repeat] = ACTIONS(6054),
    [anon_sym_exit] = ACTIONS(6054),
    [anon_sym_EXIT] = ACTIONS(6054),
    [anon_sym_Exit] = ACTIONS(6054),
    [anon_sym_continue] = ACTIONS(6054),
    [anon_sym_CONTINUE] = ACTIONS(6054),
    [anon_sym_Continue] = ACTIONS(6054),
    [anon_sym_break] = ACTIONS(6054),
    [anon_sym_BREAK] = ACTIONS(6054),
    [anon_sym_Break] = ACTIONS(6054),
    [anon_sym_with] = ACTIONS(6054),
    [anon_sym_WITH] = ACTIONS(6054),
    [anon_sym_With] = ACTIONS(6054),
    [sym_asserterror_keyword] = ACTIONS(6056),
    [sym_page_keyword] = ACTIONS(6054),
    [anon_sym_codeunit] = ACTIONS(6054),
    [anon_sym_CODEUNIT] = ACTIONS(6054),
    [anon_sym_Codeunit] = ACTIONS(6054),
    [anon_sym_CodeUnit] = ACTIONS(6054),
    [anon_sym_COdeunit] = ACTIONS(6054),
    [anon_sym_codeUnit] = ACTIONS(6054),
    [sym_report_keyword] = ACTIONS(6054),
    [sym_query_keyword] = ACTIONS(6054),
    [anon_sym_xmlport] = ACTIONS(6054),
    [anon_sym_XMLPORT] = ACTIONS(6054),
    [anon_sym_Xmlport] = ACTIONS(6054),
    [anon_sym_XMLport] = ACTIONS(6054),
    [anon_sym_XMLPort] = ACTIONS(6054),
    [anon_sym_XmlPort] = ACTIONS(6054),
    [anon_sym_enum] = ACTIONS(6054),
    [anon_sym_ENUM] = ACTIONS(6054),
    [anon_sym_Enum] = ACTIONS(6054),
    [anon_sym_eNUM] = ACTIONS(6054),
    [anon_sym_eNum] = ACTIONS(6054),
    [anon_sym_ENum] = ACTIONS(6054),
    [sym_quoted_identifier] = ACTIONS(6056),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6056),
    [sym_verbatim_string] = ACTIONS(6056),
    [sym_integer] = ACTIONS(6054),
    [sym_continue_as_identifier] = ACTIONS(6056),
    [sym_preproc_open] = ACTIONS(6056),
    [sym_preproc_close] = ACTIONS(6056),
  },
  [STATE(2533)] = {
    [sym_identifier] = ACTIONS(6054),
    [anon_sym_SEMI] = ACTIONS(6056),
    [anon_sym_DASH] = ACTIONS(6056),
    [aux_sym_boolean_token1] = ACTIONS(6054),
    [aux_sym_boolean_token2] = ACTIONS(6054),
    [sym_decimal] = ACTIONS(6054),
    [anon_sym_LPAREN] = ACTIONS(6056),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6054),
    [anon_sym_LBRACK] = ACTIONS(6056),
    [aux_sym_record_type_token1] = ACTIONS(6054),
    [aux_sym_basic_type_token21] = ACTIONS(6054),
    [aux_sym_basic_type_token22] = ACTIONS(6054),
    [aux_sym_basic_type_token48] = ACTIONS(6054),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6054),
    [anon_sym_POUNDif] = ACTIONS(6056),
    [anon_sym_POUNDIF] = ACTIONS(6056),
    [anon_sym_POUNDIf] = ACTIONS(6056),
    [anon_sym_not] = ACTIONS(6054),
    [anon_sym_NOT] = ACTIONS(6054),
    [anon_sym_Not] = ACTIONS(6054),
    [anon_sym_POUNDelif] = ACTIONS(6056),
    [anon_sym_POUNDELIF] = ACTIONS(6056),
    [anon_sym_POUNDElif] = ACTIONS(6056),
    [anon_sym_POUNDelse] = ACTIONS(6056),
    [anon_sym_POUNDELSE] = ACTIONS(6056),
    [anon_sym_POUNDElse] = ACTIONS(6056),
    [anon_sym_POUNDelse2] = ACTIONS(6056),
    [anon_sym_POUNDELSE2] = ACTIONS(6056),
    [anon_sym_POUNDElse2] = ACTIONS(6056),
    [anon_sym_POUNDendif] = ACTIONS(6056),
    [anon_sym_POUNDENDIF] = ACTIONS(6056),
    [anon_sym_POUNDEndif] = ACTIONS(6056),
    [anon_sym_POUNDendif2] = ACTIONS(6056),
    [anon_sym_POUNDENDIF2] = ACTIONS(6056),
    [anon_sym_POUNDEndif2] = ACTIONS(6056),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6054),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6054),
    [anon_sym_PLUS] = ACTIONS(6056),
    [sym_datetime_literal] = ACTIONS(6056),
    [sym_date_literal] = ACTIONS(6054),
    [sym_time_literal] = ACTIONS(6054),
    [sym_biginteger_literal] = ACTIONS(6056),
    [anon_sym_if] = ACTIONS(6054),
    [anon_sym_IF] = ACTIONS(6054),
    [anon_sym_If] = ACTIONS(6054),
    [anon_sym_else] = ACTIONS(6054),
    [anon_sym_ELSE] = ACTIONS(6054),
    [anon_sym_Else] = ACTIONS(6054),
    [anon_sym_case] = ACTIONS(6054),
    [anon_sym_CASE] = ACTIONS(6054),
    [anon_sym_Case] = ACTIONS(6054),
    [anon_sym_for] = ACTIONS(6054),
    [anon_sym_FOR] = ACTIONS(6054),
    [anon_sym_For] = ACTIONS(6054),
    [anon_sym_foreach] = ACTIONS(6054),
    [anon_sym_FOREACH] = ACTIONS(6054),
    [anon_sym_Foreach] = ACTIONS(6054),
    [anon_sym_while] = ACTIONS(6054),
    [anon_sym_WHILE] = ACTIONS(6054),
    [anon_sym_While] = ACTIONS(6054),
    [anon_sym_repeat] = ACTIONS(6054),
    [anon_sym_REPEAT] = ACTIONS(6054),
    [anon_sym_Repeat] = ACTIONS(6054),
    [anon_sym_exit] = ACTIONS(6054),
    [anon_sym_EXIT] = ACTIONS(6054),
    [anon_sym_Exit] = ACTIONS(6054),
    [anon_sym_continue] = ACTIONS(6054),
    [anon_sym_CONTINUE] = ACTIONS(6054),
    [anon_sym_Continue] = ACTIONS(6054),
    [anon_sym_break] = ACTIONS(6054),
    [anon_sym_BREAK] = ACTIONS(6054),
    [anon_sym_Break] = ACTIONS(6054),
    [anon_sym_with] = ACTIONS(6054),
    [anon_sym_WITH] = ACTIONS(6054),
    [anon_sym_With] = ACTIONS(6054),
    [sym_asserterror_keyword] = ACTIONS(6056),
    [sym_page_keyword] = ACTIONS(6054),
    [anon_sym_codeunit] = ACTIONS(6054),
    [anon_sym_CODEUNIT] = ACTIONS(6054),
    [anon_sym_Codeunit] = ACTIONS(6054),
    [anon_sym_CodeUnit] = ACTIONS(6054),
    [anon_sym_COdeunit] = ACTIONS(6054),
    [anon_sym_codeUnit] = ACTIONS(6054),
    [sym_report_keyword] = ACTIONS(6054),
    [sym_query_keyword] = ACTIONS(6054),
    [anon_sym_xmlport] = ACTIONS(6054),
    [anon_sym_XMLPORT] = ACTIONS(6054),
    [anon_sym_Xmlport] = ACTIONS(6054),
    [anon_sym_XMLport] = ACTIONS(6054),
    [anon_sym_XMLPort] = ACTIONS(6054),
    [anon_sym_XmlPort] = ACTIONS(6054),
    [anon_sym_enum] = ACTIONS(6054),
    [anon_sym_ENUM] = ACTIONS(6054),
    [anon_sym_Enum] = ACTIONS(6054),
    [anon_sym_eNUM] = ACTIONS(6054),
    [anon_sym_eNum] = ACTIONS(6054),
    [anon_sym_ENum] = ACTIONS(6054),
    [sym_quoted_identifier] = ACTIONS(6056),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6056),
    [sym_verbatim_string] = ACTIONS(6056),
    [sym_integer] = ACTIONS(6054),
    [sym_continue_as_identifier] = ACTIONS(6056),
    [sym_preproc_open] = ACTIONS(6056),
    [sym_preproc_close] = ACTIONS(6056),
  },
  [STATE(2534)] = {
    [sym_identifier] = ACTIONS(6058),
    [anon_sym_SEMI] = ACTIONS(6060),
    [anon_sym_DASH] = ACTIONS(6060),
    [aux_sym_boolean_token1] = ACTIONS(6058),
    [aux_sym_boolean_token2] = ACTIONS(6058),
    [sym_decimal] = ACTIONS(6058),
    [anon_sym_LPAREN] = ACTIONS(6060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6058),
    [anon_sym_LBRACK] = ACTIONS(6060),
    [aux_sym_record_type_token1] = ACTIONS(6058),
    [aux_sym_basic_type_token21] = ACTIONS(6058),
    [aux_sym_basic_type_token22] = ACTIONS(6058),
    [aux_sym_basic_type_token48] = ACTIONS(6058),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6058),
    [anon_sym_POUNDif] = ACTIONS(6060),
    [anon_sym_POUNDIF] = ACTIONS(6060),
    [anon_sym_POUNDIf] = ACTIONS(6060),
    [anon_sym_not] = ACTIONS(6058),
    [anon_sym_NOT] = ACTIONS(6058),
    [anon_sym_Not] = ACTIONS(6058),
    [anon_sym_POUNDelif] = ACTIONS(6060),
    [anon_sym_POUNDELIF] = ACTIONS(6060),
    [anon_sym_POUNDElif] = ACTIONS(6060),
    [anon_sym_POUNDelse] = ACTIONS(6060),
    [anon_sym_POUNDELSE] = ACTIONS(6060),
    [anon_sym_POUNDElse] = ACTIONS(6060),
    [anon_sym_POUNDelse2] = ACTIONS(6060),
    [anon_sym_POUNDELSE2] = ACTIONS(6060),
    [anon_sym_POUNDElse2] = ACTIONS(6060),
    [anon_sym_POUNDendif] = ACTIONS(6060),
    [anon_sym_POUNDENDIF] = ACTIONS(6060),
    [anon_sym_POUNDEndif] = ACTIONS(6060),
    [anon_sym_POUNDendif2] = ACTIONS(6060),
    [anon_sym_POUNDENDIF2] = ACTIONS(6060),
    [anon_sym_POUNDEndif2] = ACTIONS(6060),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6058),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6058),
    [anon_sym_PLUS] = ACTIONS(6060),
    [sym_datetime_literal] = ACTIONS(6060),
    [sym_date_literal] = ACTIONS(6058),
    [sym_time_literal] = ACTIONS(6058),
    [sym_biginteger_literal] = ACTIONS(6060),
    [anon_sym_if] = ACTIONS(6058),
    [anon_sym_IF] = ACTIONS(6058),
    [anon_sym_If] = ACTIONS(6058),
    [anon_sym_else] = ACTIONS(6058),
    [anon_sym_ELSE] = ACTIONS(6058),
    [anon_sym_Else] = ACTIONS(6058),
    [anon_sym_case] = ACTIONS(6058),
    [anon_sym_CASE] = ACTIONS(6058),
    [anon_sym_Case] = ACTIONS(6058),
    [anon_sym_for] = ACTIONS(6058),
    [anon_sym_FOR] = ACTIONS(6058),
    [anon_sym_For] = ACTIONS(6058),
    [anon_sym_foreach] = ACTIONS(6058),
    [anon_sym_FOREACH] = ACTIONS(6058),
    [anon_sym_Foreach] = ACTIONS(6058),
    [anon_sym_while] = ACTIONS(6058),
    [anon_sym_WHILE] = ACTIONS(6058),
    [anon_sym_While] = ACTIONS(6058),
    [anon_sym_repeat] = ACTIONS(6058),
    [anon_sym_REPEAT] = ACTIONS(6058),
    [anon_sym_Repeat] = ACTIONS(6058),
    [anon_sym_exit] = ACTIONS(6058),
    [anon_sym_EXIT] = ACTIONS(6058),
    [anon_sym_Exit] = ACTIONS(6058),
    [anon_sym_continue] = ACTIONS(6058),
    [anon_sym_CONTINUE] = ACTIONS(6058),
    [anon_sym_Continue] = ACTIONS(6058),
    [anon_sym_break] = ACTIONS(6058),
    [anon_sym_BREAK] = ACTIONS(6058),
    [anon_sym_Break] = ACTIONS(6058),
    [anon_sym_with] = ACTIONS(6058),
    [anon_sym_WITH] = ACTIONS(6058),
    [anon_sym_With] = ACTIONS(6058),
    [sym_asserterror_keyword] = ACTIONS(6060),
    [sym_page_keyword] = ACTIONS(6058),
    [anon_sym_codeunit] = ACTIONS(6058),
    [anon_sym_CODEUNIT] = ACTIONS(6058),
    [anon_sym_Codeunit] = ACTIONS(6058),
    [anon_sym_CodeUnit] = ACTIONS(6058),
    [anon_sym_COdeunit] = ACTIONS(6058),
    [anon_sym_codeUnit] = ACTIONS(6058),
    [sym_report_keyword] = ACTIONS(6058),
    [sym_query_keyword] = ACTIONS(6058),
    [anon_sym_xmlport] = ACTIONS(6058),
    [anon_sym_XMLPORT] = ACTIONS(6058),
    [anon_sym_Xmlport] = ACTIONS(6058),
    [anon_sym_XMLport] = ACTIONS(6058),
    [anon_sym_XMLPort] = ACTIONS(6058),
    [anon_sym_XmlPort] = ACTIONS(6058),
    [anon_sym_enum] = ACTIONS(6058),
    [anon_sym_ENUM] = ACTIONS(6058),
    [anon_sym_Enum] = ACTIONS(6058),
    [anon_sym_eNUM] = ACTIONS(6058),
    [anon_sym_eNum] = ACTIONS(6058),
    [anon_sym_ENum] = ACTIONS(6058),
    [sym_quoted_identifier] = ACTIONS(6060),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6060),
    [sym_verbatim_string] = ACTIONS(6060),
    [sym_integer] = ACTIONS(6058),
    [sym_continue_as_identifier] = ACTIONS(6060),
    [sym_preproc_open] = ACTIONS(6060),
    [sym_preproc_close] = ACTIONS(6060),
  },
  [STATE(2535)] = {
    [sym_identifier] = ACTIONS(6062),
    [anon_sym_SEMI] = ACTIONS(6064),
    [anon_sym_DASH] = ACTIONS(6064),
    [aux_sym_boolean_token1] = ACTIONS(6062),
    [aux_sym_boolean_token2] = ACTIONS(6062),
    [sym_decimal] = ACTIONS(6062),
    [anon_sym_LPAREN] = ACTIONS(6064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6062),
    [anon_sym_LBRACK] = ACTIONS(6064),
    [aux_sym_record_type_token1] = ACTIONS(6062),
    [aux_sym_basic_type_token21] = ACTIONS(6062),
    [aux_sym_basic_type_token22] = ACTIONS(6062),
    [aux_sym_basic_type_token48] = ACTIONS(6062),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6062),
    [anon_sym_POUNDif] = ACTIONS(6064),
    [anon_sym_POUNDIF] = ACTIONS(6064),
    [anon_sym_POUNDIf] = ACTIONS(6064),
    [anon_sym_not] = ACTIONS(6062),
    [anon_sym_NOT] = ACTIONS(6062),
    [anon_sym_Not] = ACTIONS(6062),
    [anon_sym_POUNDelif] = ACTIONS(6064),
    [anon_sym_POUNDELIF] = ACTIONS(6064),
    [anon_sym_POUNDElif] = ACTIONS(6064),
    [anon_sym_POUNDelse] = ACTIONS(6064),
    [anon_sym_POUNDELSE] = ACTIONS(6064),
    [anon_sym_POUNDElse] = ACTIONS(6064),
    [anon_sym_POUNDelse2] = ACTIONS(6064),
    [anon_sym_POUNDELSE2] = ACTIONS(6064),
    [anon_sym_POUNDElse2] = ACTIONS(6064),
    [anon_sym_POUNDendif] = ACTIONS(6064),
    [anon_sym_POUNDENDIF] = ACTIONS(6064),
    [anon_sym_POUNDEndif] = ACTIONS(6064),
    [anon_sym_POUNDendif2] = ACTIONS(6064),
    [anon_sym_POUNDENDIF2] = ACTIONS(6064),
    [anon_sym_POUNDEndif2] = ACTIONS(6064),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6062),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6062),
    [anon_sym_PLUS] = ACTIONS(6064),
    [sym_datetime_literal] = ACTIONS(6064),
    [sym_date_literal] = ACTIONS(6062),
    [sym_time_literal] = ACTIONS(6062),
    [sym_biginteger_literal] = ACTIONS(6064),
    [anon_sym_if] = ACTIONS(6062),
    [anon_sym_IF] = ACTIONS(6062),
    [anon_sym_If] = ACTIONS(6062),
    [anon_sym_else] = ACTIONS(6062),
    [anon_sym_ELSE] = ACTIONS(6062),
    [anon_sym_Else] = ACTIONS(6062),
    [anon_sym_case] = ACTIONS(6062),
    [anon_sym_CASE] = ACTIONS(6062),
    [anon_sym_Case] = ACTIONS(6062),
    [anon_sym_for] = ACTIONS(6062),
    [anon_sym_FOR] = ACTIONS(6062),
    [anon_sym_For] = ACTIONS(6062),
    [anon_sym_foreach] = ACTIONS(6062),
    [anon_sym_FOREACH] = ACTIONS(6062),
    [anon_sym_Foreach] = ACTIONS(6062),
    [anon_sym_while] = ACTIONS(6062),
    [anon_sym_WHILE] = ACTIONS(6062),
    [anon_sym_While] = ACTIONS(6062),
    [anon_sym_repeat] = ACTIONS(6062),
    [anon_sym_REPEAT] = ACTIONS(6062),
    [anon_sym_Repeat] = ACTIONS(6062),
    [anon_sym_exit] = ACTIONS(6062),
    [anon_sym_EXIT] = ACTIONS(6062),
    [anon_sym_Exit] = ACTIONS(6062),
    [anon_sym_continue] = ACTIONS(6062),
    [anon_sym_CONTINUE] = ACTIONS(6062),
    [anon_sym_Continue] = ACTIONS(6062),
    [anon_sym_break] = ACTIONS(6062),
    [anon_sym_BREAK] = ACTIONS(6062),
    [anon_sym_Break] = ACTIONS(6062),
    [anon_sym_with] = ACTIONS(6062),
    [anon_sym_WITH] = ACTIONS(6062),
    [anon_sym_With] = ACTIONS(6062),
    [sym_asserterror_keyword] = ACTIONS(6064),
    [sym_page_keyword] = ACTIONS(6062),
    [anon_sym_codeunit] = ACTIONS(6062),
    [anon_sym_CODEUNIT] = ACTIONS(6062),
    [anon_sym_Codeunit] = ACTIONS(6062),
    [anon_sym_CodeUnit] = ACTIONS(6062),
    [anon_sym_COdeunit] = ACTIONS(6062),
    [anon_sym_codeUnit] = ACTIONS(6062),
    [sym_report_keyword] = ACTIONS(6062),
    [sym_query_keyword] = ACTIONS(6062),
    [anon_sym_xmlport] = ACTIONS(6062),
    [anon_sym_XMLPORT] = ACTIONS(6062),
    [anon_sym_Xmlport] = ACTIONS(6062),
    [anon_sym_XMLport] = ACTIONS(6062),
    [anon_sym_XMLPort] = ACTIONS(6062),
    [anon_sym_XmlPort] = ACTIONS(6062),
    [anon_sym_enum] = ACTIONS(6062),
    [anon_sym_ENUM] = ACTIONS(6062),
    [anon_sym_Enum] = ACTIONS(6062),
    [anon_sym_eNUM] = ACTIONS(6062),
    [anon_sym_eNum] = ACTIONS(6062),
    [anon_sym_ENum] = ACTIONS(6062),
    [sym_quoted_identifier] = ACTIONS(6064),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6064),
    [sym_verbatim_string] = ACTIONS(6064),
    [sym_integer] = ACTIONS(6062),
    [sym_continue_as_identifier] = ACTIONS(6064),
    [sym_preproc_open] = ACTIONS(6064),
    [sym_preproc_close] = ACTIONS(6064),
  },
  [STATE(2536)] = {
    [sym_identifier] = ACTIONS(6058),
    [anon_sym_SEMI] = ACTIONS(6060),
    [anon_sym_DASH] = ACTIONS(6060),
    [aux_sym_boolean_token1] = ACTIONS(6058),
    [aux_sym_boolean_token2] = ACTIONS(6058),
    [sym_decimal] = ACTIONS(6058),
    [anon_sym_LPAREN] = ACTIONS(6060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6058),
    [anon_sym_LBRACK] = ACTIONS(6060),
    [aux_sym_record_type_token1] = ACTIONS(6058),
    [aux_sym_basic_type_token21] = ACTIONS(6058),
    [aux_sym_basic_type_token22] = ACTIONS(6058),
    [aux_sym_basic_type_token48] = ACTIONS(6058),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6058),
    [anon_sym_POUNDif] = ACTIONS(6060),
    [anon_sym_POUNDIF] = ACTIONS(6060),
    [anon_sym_POUNDIf] = ACTIONS(6060),
    [anon_sym_not] = ACTIONS(6058),
    [anon_sym_NOT] = ACTIONS(6058),
    [anon_sym_Not] = ACTIONS(6058),
    [anon_sym_POUNDelif] = ACTIONS(6060),
    [anon_sym_POUNDELIF] = ACTIONS(6060),
    [anon_sym_POUNDElif] = ACTIONS(6060),
    [anon_sym_POUNDelse] = ACTIONS(6060),
    [anon_sym_POUNDELSE] = ACTIONS(6060),
    [anon_sym_POUNDElse] = ACTIONS(6060),
    [anon_sym_POUNDelse2] = ACTIONS(6060),
    [anon_sym_POUNDELSE2] = ACTIONS(6060),
    [anon_sym_POUNDElse2] = ACTIONS(6060),
    [anon_sym_POUNDendif] = ACTIONS(6060),
    [anon_sym_POUNDENDIF] = ACTIONS(6060),
    [anon_sym_POUNDEndif] = ACTIONS(6060),
    [anon_sym_POUNDendif2] = ACTIONS(6060),
    [anon_sym_POUNDENDIF2] = ACTIONS(6060),
    [anon_sym_POUNDEndif2] = ACTIONS(6060),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6058),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6058),
    [anon_sym_PLUS] = ACTIONS(6060),
    [sym_datetime_literal] = ACTIONS(6060),
    [sym_date_literal] = ACTIONS(6058),
    [sym_time_literal] = ACTIONS(6058),
    [sym_biginteger_literal] = ACTIONS(6060),
    [anon_sym_if] = ACTIONS(6058),
    [anon_sym_IF] = ACTIONS(6058),
    [anon_sym_If] = ACTIONS(6058),
    [anon_sym_else] = ACTIONS(6058),
    [anon_sym_ELSE] = ACTIONS(6058),
    [anon_sym_Else] = ACTIONS(6058),
    [anon_sym_case] = ACTIONS(6058),
    [anon_sym_CASE] = ACTIONS(6058),
    [anon_sym_Case] = ACTIONS(6058),
    [anon_sym_for] = ACTIONS(6058),
    [anon_sym_FOR] = ACTIONS(6058),
    [anon_sym_For] = ACTIONS(6058),
    [anon_sym_foreach] = ACTIONS(6058),
    [anon_sym_FOREACH] = ACTIONS(6058),
    [anon_sym_Foreach] = ACTIONS(6058),
    [anon_sym_while] = ACTIONS(6058),
    [anon_sym_WHILE] = ACTIONS(6058),
    [anon_sym_While] = ACTIONS(6058),
    [anon_sym_repeat] = ACTIONS(6058),
    [anon_sym_REPEAT] = ACTIONS(6058),
    [anon_sym_Repeat] = ACTIONS(6058),
    [anon_sym_exit] = ACTIONS(6058),
    [anon_sym_EXIT] = ACTIONS(6058),
    [anon_sym_Exit] = ACTIONS(6058),
    [anon_sym_continue] = ACTIONS(6058),
    [anon_sym_CONTINUE] = ACTIONS(6058),
    [anon_sym_Continue] = ACTIONS(6058),
    [anon_sym_break] = ACTIONS(6058),
    [anon_sym_BREAK] = ACTIONS(6058),
    [anon_sym_Break] = ACTIONS(6058),
    [anon_sym_with] = ACTIONS(6058),
    [anon_sym_WITH] = ACTIONS(6058),
    [anon_sym_With] = ACTIONS(6058),
    [sym_asserterror_keyword] = ACTIONS(6060),
    [sym_page_keyword] = ACTIONS(6058),
    [anon_sym_codeunit] = ACTIONS(6058),
    [anon_sym_CODEUNIT] = ACTIONS(6058),
    [anon_sym_Codeunit] = ACTIONS(6058),
    [anon_sym_CodeUnit] = ACTIONS(6058),
    [anon_sym_COdeunit] = ACTIONS(6058),
    [anon_sym_codeUnit] = ACTIONS(6058),
    [sym_report_keyword] = ACTIONS(6058),
    [sym_query_keyword] = ACTIONS(6058),
    [anon_sym_xmlport] = ACTIONS(6058),
    [anon_sym_XMLPORT] = ACTIONS(6058),
    [anon_sym_Xmlport] = ACTIONS(6058),
    [anon_sym_XMLport] = ACTIONS(6058),
    [anon_sym_XMLPort] = ACTIONS(6058),
    [anon_sym_XmlPort] = ACTIONS(6058),
    [anon_sym_enum] = ACTIONS(6058),
    [anon_sym_ENUM] = ACTIONS(6058),
    [anon_sym_Enum] = ACTIONS(6058),
    [anon_sym_eNUM] = ACTIONS(6058),
    [anon_sym_eNum] = ACTIONS(6058),
    [anon_sym_ENum] = ACTIONS(6058),
    [sym_quoted_identifier] = ACTIONS(6060),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6060),
    [sym_verbatim_string] = ACTIONS(6060),
    [sym_integer] = ACTIONS(6058),
    [sym_continue_as_identifier] = ACTIONS(6060),
    [sym_preproc_open] = ACTIONS(6060),
    [sym_preproc_close] = ACTIONS(6060),
  },
  [STATE(2537)] = {
    [sym_identifier] = ACTIONS(6066),
    [anon_sym_SEMI] = ACTIONS(6068),
    [anon_sym_DASH] = ACTIONS(6068),
    [aux_sym_boolean_token1] = ACTIONS(6066),
    [aux_sym_boolean_token2] = ACTIONS(6066),
    [sym_decimal] = ACTIONS(6066),
    [anon_sym_LPAREN] = ACTIONS(6068),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6066),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [aux_sym_record_type_token1] = ACTIONS(6066),
    [aux_sym_basic_type_token21] = ACTIONS(6066),
    [aux_sym_basic_type_token22] = ACTIONS(6066),
    [aux_sym_basic_type_token48] = ACTIONS(6066),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6066),
    [anon_sym_POUNDif] = ACTIONS(6068),
    [anon_sym_POUNDIF] = ACTIONS(6068),
    [anon_sym_POUNDIf] = ACTIONS(6068),
    [anon_sym_not] = ACTIONS(6066),
    [anon_sym_NOT] = ACTIONS(6066),
    [anon_sym_Not] = ACTIONS(6066),
    [anon_sym_POUNDelif] = ACTIONS(6068),
    [anon_sym_POUNDELIF] = ACTIONS(6068),
    [anon_sym_POUNDElif] = ACTIONS(6068),
    [anon_sym_POUNDelse] = ACTIONS(6068),
    [anon_sym_POUNDELSE] = ACTIONS(6068),
    [anon_sym_POUNDElse] = ACTIONS(6068),
    [anon_sym_POUNDelse2] = ACTIONS(6068),
    [anon_sym_POUNDELSE2] = ACTIONS(6068),
    [anon_sym_POUNDElse2] = ACTIONS(6068),
    [anon_sym_POUNDendif] = ACTIONS(6068),
    [anon_sym_POUNDENDIF] = ACTIONS(6068),
    [anon_sym_POUNDEndif] = ACTIONS(6068),
    [anon_sym_POUNDendif2] = ACTIONS(6068),
    [anon_sym_POUNDENDIF2] = ACTIONS(6068),
    [anon_sym_POUNDEndif2] = ACTIONS(6068),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6066),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6066),
    [anon_sym_PLUS] = ACTIONS(6068),
    [sym_datetime_literal] = ACTIONS(6068),
    [sym_date_literal] = ACTIONS(6066),
    [sym_time_literal] = ACTIONS(6066),
    [sym_biginteger_literal] = ACTIONS(6068),
    [anon_sym_if] = ACTIONS(6066),
    [anon_sym_IF] = ACTIONS(6066),
    [anon_sym_If] = ACTIONS(6066),
    [anon_sym_else] = ACTIONS(6066),
    [anon_sym_ELSE] = ACTIONS(6066),
    [anon_sym_Else] = ACTIONS(6066),
    [anon_sym_case] = ACTIONS(6066),
    [anon_sym_CASE] = ACTIONS(6066),
    [anon_sym_Case] = ACTIONS(6066),
    [anon_sym_for] = ACTIONS(6066),
    [anon_sym_FOR] = ACTIONS(6066),
    [anon_sym_For] = ACTIONS(6066),
    [anon_sym_foreach] = ACTIONS(6066),
    [anon_sym_FOREACH] = ACTIONS(6066),
    [anon_sym_Foreach] = ACTIONS(6066),
    [anon_sym_while] = ACTIONS(6066),
    [anon_sym_WHILE] = ACTIONS(6066),
    [anon_sym_While] = ACTIONS(6066),
    [anon_sym_repeat] = ACTIONS(6066),
    [anon_sym_REPEAT] = ACTIONS(6066),
    [anon_sym_Repeat] = ACTIONS(6066),
    [anon_sym_exit] = ACTIONS(6066),
    [anon_sym_EXIT] = ACTIONS(6066),
    [anon_sym_Exit] = ACTIONS(6066),
    [anon_sym_continue] = ACTIONS(6066),
    [anon_sym_CONTINUE] = ACTIONS(6066),
    [anon_sym_Continue] = ACTIONS(6066),
    [anon_sym_break] = ACTIONS(6066),
    [anon_sym_BREAK] = ACTIONS(6066),
    [anon_sym_Break] = ACTIONS(6066),
    [anon_sym_with] = ACTIONS(6066),
    [anon_sym_WITH] = ACTIONS(6066),
    [anon_sym_With] = ACTIONS(6066),
    [sym_asserterror_keyword] = ACTIONS(6068),
    [sym_page_keyword] = ACTIONS(6066),
    [anon_sym_codeunit] = ACTIONS(6066),
    [anon_sym_CODEUNIT] = ACTIONS(6066),
    [anon_sym_Codeunit] = ACTIONS(6066),
    [anon_sym_CodeUnit] = ACTIONS(6066),
    [anon_sym_COdeunit] = ACTIONS(6066),
    [anon_sym_codeUnit] = ACTIONS(6066),
    [sym_report_keyword] = ACTIONS(6066),
    [sym_query_keyword] = ACTIONS(6066),
    [anon_sym_xmlport] = ACTIONS(6066),
    [anon_sym_XMLPORT] = ACTIONS(6066),
    [anon_sym_Xmlport] = ACTIONS(6066),
    [anon_sym_XMLport] = ACTIONS(6066),
    [anon_sym_XMLPort] = ACTIONS(6066),
    [anon_sym_XmlPort] = ACTIONS(6066),
    [anon_sym_enum] = ACTIONS(6066),
    [anon_sym_ENUM] = ACTIONS(6066),
    [anon_sym_Enum] = ACTIONS(6066),
    [anon_sym_eNUM] = ACTIONS(6066),
    [anon_sym_eNum] = ACTIONS(6066),
    [anon_sym_ENum] = ACTIONS(6066),
    [sym_quoted_identifier] = ACTIONS(6068),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6068),
    [sym_verbatim_string] = ACTIONS(6068),
    [sym_integer] = ACTIONS(6066),
    [sym_continue_as_identifier] = ACTIONS(6068),
    [sym_preproc_open] = ACTIONS(6068),
    [sym_preproc_close] = ACTIONS(6068),
  },
  [STATE(2538)] = {
    [sym_identifier] = ACTIONS(6070),
    [anon_sym_SEMI] = ACTIONS(6072),
    [anon_sym_DASH] = ACTIONS(6072),
    [aux_sym_boolean_token1] = ACTIONS(6070),
    [aux_sym_boolean_token2] = ACTIONS(6070),
    [sym_decimal] = ACTIONS(6070),
    [anon_sym_LPAREN] = ACTIONS(6072),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6070),
    [anon_sym_LBRACK] = ACTIONS(6072),
    [aux_sym_record_type_token1] = ACTIONS(6070),
    [aux_sym_basic_type_token21] = ACTIONS(6070),
    [aux_sym_basic_type_token22] = ACTIONS(6070),
    [aux_sym_basic_type_token48] = ACTIONS(6070),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6070),
    [anon_sym_POUNDif] = ACTIONS(6072),
    [anon_sym_POUNDIF] = ACTIONS(6072),
    [anon_sym_POUNDIf] = ACTIONS(6072),
    [anon_sym_not] = ACTIONS(6070),
    [anon_sym_NOT] = ACTIONS(6070),
    [anon_sym_Not] = ACTIONS(6070),
    [anon_sym_POUNDelif] = ACTIONS(6072),
    [anon_sym_POUNDELIF] = ACTIONS(6072),
    [anon_sym_POUNDElif] = ACTIONS(6072),
    [anon_sym_POUNDelse] = ACTIONS(6072),
    [anon_sym_POUNDELSE] = ACTIONS(6072),
    [anon_sym_POUNDElse] = ACTIONS(6072),
    [anon_sym_POUNDelse2] = ACTIONS(6072),
    [anon_sym_POUNDELSE2] = ACTIONS(6072),
    [anon_sym_POUNDElse2] = ACTIONS(6072),
    [anon_sym_POUNDendif] = ACTIONS(6072),
    [anon_sym_POUNDENDIF] = ACTIONS(6072),
    [anon_sym_POUNDEndif] = ACTIONS(6072),
    [anon_sym_POUNDendif2] = ACTIONS(6072),
    [anon_sym_POUNDENDIF2] = ACTIONS(6072),
    [anon_sym_POUNDEndif2] = ACTIONS(6072),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6070),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6070),
    [anon_sym_PLUS] = ACTIONS(6072),
    [sym_datetime_literal] = ACTIONS(6072),
    [sym_date_literal] = ACTIONS(6070),
    [sym_time_literal] = ACTIONS(6070),
    [sym_biginteger_literal] = ACTIONS(6072),
    [anon_sym_if] = ACTIONS(6070),
    [anon_sym_IF] = ACTIONS(6070),
    [anon_sym_If] = ACTIONS(6070),
    [anon_sym_else] = ACTIONS(6070),
    [anon_sym_ELSE] = ACTIONS(6070),
    [anon_sym_Else] = ACTIONS(6070),
    [anon_sym_case] = ACTIONS(6070),
    [anon_sym_CASE] = ACTIONS(6070),
    [anon_sym_Case] = ACTIONS(6070),
    [anon_sym_for] = ACTIONS(6070),
    [anon_sym_FOR] = ACTIONS(6070),
    [anon_sym_For] = ACTIONS(6070),
    [anon_sym_foreach] = ACTIONS(6070),
    [anon_sym_FOREACH] = ACTIONS(6070),
    [anon_sym_Foreach] = ACTIONS(6070),
    [anon_sym_while] = ACTIONS(6070),
    [anon_sym_WHILE] = ACTIONS(6070),
    [anon_sym_While] = ACTIONS(6070),
    [anon_sym_repeat] = ACTIONS(6070),
    [anon_sym_REPEAT] = ACTIONS(6070),
    [anon_sym_Repeat] = ACTIONS(6070),
    [anon_sym_exit] = ACTIONS(6070),
    [anon_sym_EXIT] = ACTIONS(6070),
    [anon_sym_Exit] = ACTIONS(6070),
    [anon_sym_continue] = ACTIONS(6070),
    [anon_sym_CONTINUE] = ACTIONS(6070),
    [anon_sym_Continue] = ACTIONS(6070),
    [anon_sym_break] = ACTIONS(6070),
    [anon_sym_BREAK] = ACTIONS(6070),
    [anon_sym_Break] = ACTIONS(6070),
    [anon_sym_with] = ACTIONS(6070),
    [anon_sym_WITH] = ACTIONS(6070),
    [anon_sym_With] = ACTIONS(6070),
    [sym_asserterror_keyword] = ACTIONS(6072),
    [sym_page_keyword] = ACTIONS(6070),
    [anon_sym_codeunit] = ACTIONS(6070),
    [anon_sym_CODEUNIT] = ACTIONS(6070),
    [anon_sym_Codeunit] = ACTIONS(6070),
    [anon_sym_CodeUnit] = ACTIONS(6070),
    [anon_sym_COdeunit] = ACTIONS(6070),
    [anon_sym_codeUnit] = ACTIONS(6070),
    [sym_report_keyword] = ACTIONS(6070),
    [sym_query_keyword] = ACTIONS(6070),
    [anon_sym_xmlport] = ACTIONS(6070),
    [anon_sym_XMLPORT] = ACTIONS(6070),
    [anon_sym_Xmlport] = ACTIONS(6070),
    [anon_sym_XMLport] = ACTIONS(6070),
    [anon_sym_XMLPort] = ACTIONS(6070),
    [anon_sym_XmlPort] = ACTIONS(6070),
    [anon_sym_enum] = ACTIONS(6070),
    [anon_sym_ENUM] = ACTIONS(6070),
    [anon_sym_Enum] = ACTIONS(6070),
    [anon_sym_eNUM] = ACTIONS(6070),
    [anon_sym_eNum] = ACTIONS(6070),
    [anon_sym_ENum] = ACTIONS(6070),
    [sym_quoted_identifier] = ACTIONS(6072),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6072),
    [sym_verbatim_string] = ACTIONS(6072),
    [sym_integer] = ACTIONS(6070),
    [sym_continue_as_identifier] = ACTIONS(6072),
    [sym_preproc_open] = ACTIONS(6072),
    [sym_preproc_close] = ACTIONS(6072),
  },
  [STATE(2539)] = {
    [sym_identifier] = ACTIONS(6066),
    [anon_sym_SEMI] = ACTIONS(6068),
    [anon_sym_DASH] = ACTIONS(6068),
    [aux_sym_boolean_token1] = ACTIONS(6066),
    [aux_sym_boolean_token2] = ACTIONS(6066),
    [sym_decimal] = ACTIONS(6066),
    [anon_sym_LPAREN] = ACTIONS(6068),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6066),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [aux_sym_record_type_token1] = ACTIONS(6066),
    [aux_sym_basic_type_token21] = ACTIONS(6066),
    [aux_sym_basic_type_token22] = ACTIONS(6066),
    [aux_sym_basic_type_token48] = ACTIONS(6066),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6066),
    [anon_sym_POUNDif] = ACTIONS(6068),
    [anon_sym_POUNDIF] = ACTIONS(6068),
    [anon_sym_POUNDIf] = ACTIONS(6068),
    [anon_sym_not] = ACTIONS(6066),
    [anon_sym_NOT] = ACTIONS(6066),
    [anon_sym_Not] = ACTIONS(6066),
    [anon_sym_POUNDelif] = ACTIONS(6068),
    [anon_sym_POUNDELIF] = ACTIONS(6068),
    [anon_sym_POUNDElif] = ACTIONS(6068),
    [anon_sym_POUNDelse] = ACTIONS(6068),
    [anon_sym_POUNDELSE] = ACTIONS(6068),
    [anon_sym_POUNDElse] = ACTIONS(6068),
    [anon_sym_POUNDelse2] = ACTIONS(6068),
    [anon_sym_POUNDELSE2] = ACTIONS(6068),
    [anon_sym_POUNDElse2] = ACTIONS(6068),
    [anon_sym_POUNDendif] = ACTIONS(6068),
    [anon_sym_POUNDENDIF] = ACTIONS(6068),
    [anon_sym_POUNDEndif] = ACTIONS(6068),
    [anon_sym_POUNDendif2] = ACTIONS(6068),
    [anon_sym_POUNDENDIF2] = ACTIONS(6068),
    [anon_sym_POUNDEndif2] = ACTIONS(6068),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6066),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6066),
    [anon_sym_PLUS] = ACTIONS(6068),
    [sym_datetime_literal] = ACTIONS(6068),
    [sym_date_literal] = ACTIONS(6066),
    [sym_time_literal] = ACTIONS(6066),
    [sym_biginteger_literal] = ACTIONS(6068),
    [anon_sym_if] = ACTIONS(6066),
    [anon_sym_IF] = ACTIONS(6066),
    [anon_sym_If] = ACTIONS(6066),
    [anon_sym_else] = ACTIONS(6066),
    [anon_sym_ELSE] = ACTIONS(6066),
    [anon_sym_Else] = ACTIONS(6066),
    [anon_sym_case] = ACTIONS(6066),
    [anon_sym_CASE] = ACTIONS(6066),
    [anon_sym_Case] = ACTIONS(6066),
    [anon_sym_for] = ACTIONS(6066),
    [anon_sym_FOR] = ACTIONS(6066),
    [anon_sym_For] = ACTIONS(6066),
    [anon_sym_foreach] = ACTIONS(6066),
    [anon_sym_FOREACH] = ACTIONS(6066),
    [anon_sym_Foreach] = ACTIONS(6066),
    [anon_sym_while] = ACTIONS(6066),
    [anon_sym_WHILE] = ACTIONS(6066),
    [anon_sym_While] = ACTIONS(6066),
    [anon_sym_repeat] = ACTIONS(6066),
    [anon_sym_REPEAT] = ACTIONS(6066),
    [anon_sym_Repeat] = ACTIONS(6066),
    [anon_sym_exit] = ACTIONS(6066),
    [anon_sym_EXIT] = ACTIONS(6066),
    [anon_sym_Exit] = ACTIONS(6066),
    [anon_sym_continue] = ACTIONS(6066),
    [anon_sym_CONTINUE] = ACTIONS(6066),
    [anon_sym_Continue] = ACTIONS(6066),
    [anon_sym_break] = ACTIONS(6066),
    [anon_sym_BREAK] = ACTIONS(6066),
    [anon_sym_Break] = ACTIONS(6066),
    [anon_sym_with] = ACTIONS(6066),
    [anon_sym_WITH] = ACTIONS(6066),
    [anon_sym_With] = ACTIONS(6066),
    [sym_asserterror_keyword] = ACTIONS(6068),
    [sym_page_keyword] = ACTIONS(6066),
    [anon_sym_codeunit] = ACTIONS(6066),
    [anon_sym_CODEUNIT] = ACTIONS(6066),
    [anon_sym_Codeunit] = ACTIONS(6066),
    [anon_sym_CodeUnit] = ACTIONS(6066),
    [anon_sym_COdeunit] = ACTIONS(6066),
    [anon_sym_codeUnit] = ACTIONS(6066),
    [sym_report_keyword] = ACTIONS(6066),
    [sym_query_keyword] = ACTIONS(6066),
    [anon_sym_xmlport] = ACTIONS(6066),
    [anon_sym_XMLPORT] = ACTIONS(6066),
    [anon_sym_Xmlport] = ACTIONS(6066),
    [anon_sym_XMLport] = ACTIONS(6066),
    [anon_sym_XMLPort] = ACTIONS(6066),
    [anon_sym_XmlPort] = ACTIONS(6066),
    [anon_sym_enum] = ACTIONS(6066),
    [anon_sym_ENUM] = ACTIONS(6066),
    [anon_sym_Enum] = ACTIONS(6066),
    [anon_sym_eNUM] = ACTIONS(6066),
    [anon_sym_eNum] = ACTIONS(6066),
    [anon_sym_ENum] = ACTIONS(6066),
    [sym_quoted_identifier] = ACTIONS(6068),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6068),
    [sym_verbatim_string] = ACTIONS(6068),
    [sym_integer] = ACTIONS(6066),
    [sym_continue_as_identifier] = ACTIONS(6068),
    [sym_preproc_open] = ACTIONS(6068),
    [sym_preproc_close] = ACTIONS(6068),
  },
  [STATE(2540)] = {
    [sym_identifier] = ACTIONS(6074),
    [anon_sym_SEMI] = ACTIONS(6076),
    [anon_sym_DASH] = ACTIONS(6076),
    [aux_sym_boolean_token1] = ACTIONS(6074),
    [aux_sym_boolean_token2] = ACTIONS(6074),
    [sym_decimal] = ACTIONS(6074),
    [anon_sym_LPAREN] = ACTIONS(6076),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6074),
    [anon_sym_LBRACK] = ACTIONS(6076),
    [aux_sym_record_type_token1] = ACTIONS(6074),
    [aux_sym_basic_type_token21] = ACTIONS(6074),
    [aux_sym_basic_type_token22] = ACTIONS(6074),
    [aux_sym_basic_type_token48] = ACTIONS(6074),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6074),
    [anon_sym_POUNDif] = ACTIONS(6076),
    [anon_sym_POUNDIF] = ACTIONS(6076),
    [anon_sym_POUNDIf] = ACTIONS(6076),
    [anon_sym_not] = ACTIONS(6074),
    [anon_sym_NOT] = ACTIONS(6074),
    [anon_sym_Not] = ACTIONS(6074),
    [anon_sym_POUNDelif] = ACTIONS(6076),
    [anon_sym_POUNDELIF] = ACTIONS(6076),
    [anon_sym_POUNDElif] = ACTIONS(6076),
    [anon_sym_POUNDelse] = ACTIONS(6076),
    [anon_sym_POUNDELSE] = ACTIONS(6076),
    [anon_sym_POUNDElse] = ACTIONS(6076),
    [anon_sym_POUNDelse2] = ACTIONS(6076),
    [anon_sym_POUNDELSE2] = ACTIONS(6076),
    [anon_sym_POUNDElse2] = ACTIONS(6076),
    [anon_sym_POUNDendif] = ACTIONS(6076),
    [anon_sym_POUNDENDIF] = ACTIONS(6076),
    [anon_sym_POUNDEndif] = ACTIONS(6076),
    [anon_sym_POUNDendif2] = ACTIONS(6076),
    [anon_sym_POUNDENDIF2] = ACTIONS(6076),
    [anon_sym_POUNDEndif2] = ACTIONS(6076),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6074),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6074),
    [anon_sym_PLUS] = ACTIONS(6076),
    [sym_datetime_literal] = ACTIONS(6076),
    [sym_date_literal] = ACTIONS(6074),
    [sym_time_literal] = ACTIONS(6074),
    [sym_biginteger_literal] = ACTIONS(6076),
    [anon_sym_if] = ACTIONS(6074),
    [anon_sym_IF] = ACTIONS(6074),
    [anon_sym_If] = ACTIONS(6074),
    [anon_sym_else] = ACTIONS(6074),
    [anon_sym_ELSE] = ACTIONS(6074),
    [anon_sym_Else] = ACTIONS(6074),
    [anon_sym_case] = ACTIONS(6074),
    [anon_sym_CASE] = ACTIONS(6074),
    [anon_sym_Case] = ACTIONS(6074),
    [anon_sym_for] = ACTIONS(6074),
    [anon_sym_FOR] = ACTIONS(6074),
    [anon_sym_For] = ACTIONS(6074),
    [anon_sym_foreach] = ACTIONS(6074),
    [anon_sym_FOREACH] = ACTIONS(6074),
    [anon_sym_Foreach] = ACTIONS(6074),
    [anon_sym_while] = ACTIONS(6074),
    [anon_sym_WHILE] = ACTIONS(6074),
    [anon_sym_While] = ACTIONS(6074),
    [anon_sym_repeat] = ACTIONS(6074),
    [anon_sym_REPEAT] = ACTIONS(6074),
    [anon_sym_Repeat] = ACTIONS(6074),
    [anon_sym_exit] = ACTIONS(6074),
    [anon_sym_EXIT] = ACTIONS(6074),
    [anon_sym_Exit] = ACTIONS(6074),
    [anon_sym_continue] = ACTIONS(6074),
    [anon_sym_CONTINUE] = ACTIONS(6074),
    [anon_sym_Continue] = ACTIONS(6074),
    [anon_sym_break] = ACTIONS(6074),
    [anon_sym_BREAK] = ACTIONS(6074),
    [anon_sym_Break] = ACTIONS(6074),
    [anon_sym_with] = ACTIONS(6074),
    [anon_sym_WITH] = ACTIONS(6074),
    [anon_sym_With] = ACTIONS(6074),
    [sym_asserterror_keyword] = ACTIONS(6076),
    [sym_page_keyword] = ACTIONS(6074),
    [anon_sym_codeunit] = ACTIONS(6074),
    [anon_sym_CODEUNIT] = ACTIONS(6074),
    [anon_sym_Codeunit] = ACTIONS(6074),
    [anon_sym_CodeUnit] = ACTIONS(6074),
    [anon_sym_COdeunit] = ACTIONS(6074),
    [anon_sym_codeUnit] = ACTIONS(6074),
    [sym_report_keyword] = ACTIONS(6074),
    [sym_query_keyword] = ACTIONS(6074),
    [anon_sym_xmlport] = ACTIONS(6074),
    [anon_sym_XMLPORT] = ACTIONS(6074),
    [anon_sym_Xmlport] = ACTIONS(6074),
    [anon_sym_XMLport] = ACTIONS(6074),
    [anon_sym_XMLPort] = ACTIONS(6074),
    [anon_sym_XmlPort] = ACTIONS(6074),
    [anon_sym_enum] = ACTIONS(6074),
    [anon_sym_ENUM] = ACTIONS(6074),
    [anon_sym_Enum] = ACTIONS(6074),
    [anon_sym_eNUM] = ACTIONS(6074),
    [anon_sym_eNum] = ACTIONS(6074),
    [anon_sym_ENum] = ACTIONS(6074),
    [sym_quoted_identifier] = ACTIONS(6076),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6076),
    [sym_verbatim_string] = ACTIONS(6076),
    [sym_integer] = ACTIONS(6074),
    [sym_continue_as_identifier] = ACTIONS(6076),
    [sym_preproc_open] = ACTIONS(6076),
    [sym_preproc_close] = ACTIONS(6076),
  },
  [STATE(2541)] = {
    [sym_identifier] = ACTIONS(6078),
    [anon_sym_SEMI] = ACTIONS(6080),
    [anon_sym_DASH] = ACTIONS(6080),
    [aux_sym_boolean_token1] = ACTIONS(6078),
    [aux_sym_boolean_token2] = ACTIONS(6078),
    [sym_decimal] = ACTIONS(6078),
    [anon_sym_LPAREN] = ACTIONS(6080),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6078),
    [anon_sym_LBRACK] = ACTIONS(6080),
    [aux_sym_record_type_token1] = ACTIONS(6078),
    [aux_sym_basic_type_token21] = ACTIONS(6078),
    [aux_sym_basic_type_token22] = ACTIONS(6078),
    [aux_sym_basic_type_token48] = ACTIONS(6078),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6078),
    [anon_sym_POUNDif] = ACTIONS(6080),
    [anon_sym_POUNDIF] = ACTIONS(6080),
    [anon_sym_POUNDIf] = ACTIONS(6080),
    [anon_sym_not] = ACTIONS(6078),
    [anon_sym_NOT] = ACTIONS(6078),
    [anon_sym_Not] = ACTIONS(6078),
    [anon_sym_POUNDelif] = ACTIONS(6080),
    [anon_sym_POUNDELIF] = ACTIONS(6080),
    [anon_sym_POUNDElif] = ACTIONS(6080),
    [anon_sym_POUNDelse] = ACTIONS(6080),
    [anon_sym_POUNDELSE] = ACTIONS(6080),
    [anon_sym_POUNDElse] = ACTIONS(6080),
    [anon_sym_POUNDelse2] = ACTIONS(6080),
    [anon_sym_POUNDELSE2] = ACTIONS(6080),
    [anon_sym_POUNDElse2] = ACTIONS(6080),
    [anon_sym_POUNDendif] = ACTIONS(6080),
    [anon_sym_POUNDENDIF] = ACTIONS(6080),
    [anon_sym_POUNDEndif] = ACTIONS(6080),
    [anon_sym_POUNDendif2] = ACTIONS(6080),
    [anon_sym_POUNDENDIF2] = ACTIONS(6080),
    [anon_sym_POUNDEndif2] = ACTIONS(6080),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6078),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6078),
    [anon_sym_PLUS] = ACTIONS(6080),
    [sym_datetime_literal] = ACTIONS(6080),
    [sym_date_literal] = ACTIONS(6078),
    [sym_time_literal] = ACTIONS(6078),
    [sym_biginteger_literal] = ACTIONS(6080),
    [anon_sym_if] = ACTIONS(6078),
    [anon_sym_IF] = ACTIONS(6078),
    [anon_sym_If] = ACTIONS(6078),
    [anon_sym_else] = ACTIONS(6078),
    [anon_sym_ELSE] = ACTIONS(6078),
    [anon_sym_Else] = ACTIONS(6078),
    [anon_sym_case] = ACTIONS(6078),
    [anon_sym_CASE] = ACTIONS(6078),
    [anon_sym_Case] = ACTIONS(6078),
    [anon_sym_for] = ACTIONS(6078),
    [anon_sym_FOR] = ACTIONS(6078),
    [anon_sym_For] = ACTIONS(6078),
    [anon_sym_foreach] = ACTIONS(6078),
    [anon_sym_FOREACH] = ACTIONS(6078),
    [anon_sym_Foreach] = ACTIONS(6078),
    [anon_sym_while] = ACTIONS(6078),
    [anon_sym_WHILE] = ACTIONS(6078),
    [anon_sym_While] = ACTIONS(6078),
    [anon_sym_repeat] = ACTIONS(6078),
    [anon_sym_REPEAT] = ACTIONS(6078),
    [anon_sym_Repeat] = ACTIONS(6078),
    [anon_sym_exit] = ACTIONS(6078),
    [anon_sym_EXIT] = ACTIONS(6078),
    [anon_sym_Exit] = ACTIONS(6078),
    [anon_sym_continue] = ACTIONS(6078),
    [anon_sym_CONTINUE] = ACTIONS(6078),
    [anon_sym_Continue] = ACTIONS(6078),
    [anon_sym_break] = ACTIONS(6078),
    [anon_sym_BREAK] = ACTIONS(6078),
    [anon_sym_Break] = ACTIONS(6078),
    [anon_sym_with] = ACTIONS(6078),
    [anon_sym_WITH] = ACTIONS(6078),
    [anon_sym_With] = ACTIONS(6078),
    [sym_asserterror_keyword] = ACTIONS(6080),
    [sym_page_keyword] = ACTIONS(6078),
    [anon_sym_codeunit] = ACTIONS(6078),
    [anon_sym_CODEUNIT] = ACTIONS(6078),
    [anon_sym_Codeunit] = ACTIONS(6078),
    [anon_sym_CodeUnit] = ACTIONS(6078),
    [anon_sym_COdeunit] = ACTIONS(6078),
    [anon_sym_codeUnit] = ACTIONS(6078),
    [sym_report_keyword] = ACTIONS(6078),
    [sym_query_keyword] = ACTIONS(6078),
    [anon_sym_xmlport] = ACTIONS(6078),
    [anon_sym_XMLPORT] = ACTIONS(6078),
    [anon_sym_Xmlport] = ACTIONS(6078),
    [anon_sym_XMLport] = ACTIONS(6078),
    [anon_sym_XMLPort] = ACTIONS(6078),
    [anon_sym_XmlPort] = ACTIONS(6078),
    [anon_sym_enum] = ACTIONS(6078),
    [anon_sym_ENUM] = ACTIONS(6078),
    [anon_sym_Enum] = ACTIONS(6078),
    [anon_sym_eNUM] = ACTIONS(6078),
    [anon_sym_eNum] = ACTIONS(6078),
    [anon_sym_ENum] = ACTIONS(6078),
    [sym_quoted_identifier] = ACTIONS(6080),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6080),
    [sym_verbatim_string] = ACTIONS(6080),
    [sym_integer] = ACTIONS(6078),
    [sym_continue_as_identifier] = ACTIONS(6080),
    [sym_preproc_open] = ACTIONS(6080),
    [sym_preproc_close] = ACTIONS(6080),
  },
  [STATE(2542)] = {
    [sym_identifier] = ACTIONS(6082),
    [anon_sym_SEMI] = ACTIONS(6084),
    [anon_sym_DASH] = ACTIONS(6084),
    [aux_sym_boolean_token1] = ACTIONS(6082),
    [aux_sym_boolean_token2] = ACTIONS(6082),
    [sym_decimal] = ACTIONS(6082),
    [anon_sym_LPAREN] = ACTIONS(6084),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6082),
    [anon_sym_LBRACK] = ACTIONS(6084),
    [aux_sym_record_type_token1] = ACTIONS(6082),
    [aux_sym_basic_type_token21] = ACTIONS(6082),
    [aux_sym_basic_type_token22] = ACTIONS(6082),
    [aux_sym_basic_type_token48] = ACTIONS(6082),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6082),
    [anon_sym_POUNDif] = ACTIONS(6084),
    [anon_sym_POUNDIF] = ACTIONS(6084),
    [anon_sym_POUNDIf] = ACTIONS(6084),
    [anon_sym_not] = ACTIONS(6082),
    [anon_sym_NOT] = ACTIONS(6082),
    [anon_sym_Not] = ACTIONS(6082),
    [anon_sym_POUNDelif] = ACTIONS(6084),
    [anon_sym_POUNDELIF] = ACTIONS(6084),
    [anon_sym_POUNDElif] = ACTIONS(6084),
    [anon_sym_POUNDelse] = ACTIONS(6084),
    [anon_sym_POUNDELSE] = ACTIONS(6084),
    [anon_sym_POUNDElse] = ACTIONS(6084),
    [anon_sym_POUNDelse2] = ACTIONS(6084),
    [anon_sym_POUNDELSE2] = ACTIONS(6084),
    [anon_sym_POUNDElse2] = ACTIONS(6084),
    [anon_sym_POUNDendif] = ACTIONS(6084),
    [anon_sym_POUNDENDIF] = ACTIONS(6084),
    [anon_sym_POUNDEndif] = ACTIONS(6084),
    [anon_sym_POUNDendif2] = ACTIONS(6084),
    [anon_sym_POUNDENDIF2] = ACTIONS(6084),
    [anon_sym_POUNDEndif2] = ACTIONS(6084),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6082),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6082),
    [anon_sym_PLUS] = ACTIONS(6084),
    [sym_datetime_literal] = ACTIONS(6084),
    [sym_date_literal] = ACTIONS(6082),
    [sym_time_literal] = ACTIONS(6082),
    [sym_biginteger_literal] = ACTIONS(6084),
    [anon_sym_if] = ACTIONS(6082),
    [anon_sym_IF] = ACTIONS(6082),
    [anon_sym_If] = ACTIONS(6082),
    [anon_sym_else] = ACTIONS(6082),
    [anon_sym_ELSE] = ACTIONS(6082),
    [anon_sym_Else] = ACTIONS(6082),
    [anon_sym_case] = ACTIONS(6082),
    [anon_sym_CASE] = ACTIONS(6082),
    [anon_sym_Case] = ACTIONS(6082),
    [anon_sym_for] = ACTIONS(6082),
    [anon_sym_FOR] = ACTIONS(6082),
    [anon_sym_For] = ACTIONS(6082),
    [anon_sym_foreach] = ACTIONS(6082),
    [anon_sym_FOREACH] = ACTIONS(6082),
    [anon_sym_Foreach] = ACTIONS(6082),
    [anon_sym_while] = ACTIONS(6082),
    [anon_sym_WHILE] = ACTIONS(6082),
    [anon_sym_While] = ACTIONS(6082),
    [anon_sym_repeat] = ACTIONS(6082),
    [anon_sym_REPEAT] = ACTIONS(6082),
    [anon_sym_Repeat] = ACTIONS(6082),
    [anon_sym_exit] = ACTIONS(6082),
    [anon_sym_EXIT] = ACTIONS(6082),
    [anon_sym_Exit] = ACTIONS(6082),
    [anon_sym_continue] = ACTIONS(6082),
    [anon_sym_CONTINUE] = ACTIONS(6082),
    [anon_sym_Continue] = ACTIONS(6082),
    [anon_sym_break] = ACTIONS(6082),
    [anon_sym_BREAK] = ACTIONS(6082),
    [anon_sym_Break] = ACTIONS(6082),
    [anon_sym_with] = ACTIONS(6082),
    [anon_sym_WITH] = ACTIONS(6082),
    [anon_sym_With] = ACTIONS(6082),
    [sym_asserterror_keyword] = ACTIONS(6084),
    [sym_page_keyword] = ACTIONS(6082),
    [anon_sym_codeunit] = ACTIONS(6082),
    [anon_sym_CODEUNIT] = ACTIONS(6082),
    [anon_sym_Codeunit] = ACTIONS(6082),
    [anon_sym_CodeUnit] = ACTIONS(6082),
    [anon_sym_COdeunit] = ACTIONS(6082),
    [anon_sym_codeUnit] = ACTIONS(6082),
    [sym_report_keyword] = ACTIONS(6082),
    [sym_query_keyword] = ACTIONS(6082),
    [anon_sym_xmlport] = ACTIONS(6082),
    [anon_sym_XMLPORT] = ACTIONS(6082),
    [anon_sym_Xmlport] = ACTIONS(6082),
    [anon_sym_XMLport] = ACTIONS(6082),
    [anon_sym_XMLPort] = ACTIONS(6082),
    [anon_sym_XmlPort] = ACTIONS(6082),
    [anon_sym_enum] = ACTIONS(6082),
    [anon_sym_ENUM] = ACTIONS(6082),
    [anon_sym_Enum] = ACTIONS(6082),
    [anon_sym_eNUM] = ACTIONS(6082),
    [anon_sym_eNum] = ACTIONS(6082),
    [anon_sym_ENum] = ACTIONS(6082),
    [sym_quoted_identifier] = ACTIONS(6084),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6084),
    [sym_verbatim_string] = ACTIONS(6084),
    [sym_integer] = ACTIONS(6082),
    [sym_continue_as_identifier] = ACTIONS(6084),
    [sym_preproc_open] = ACTIONS(6084),
    [sym_preproc_close] = ACTIONS(6084),
  },
  [STATE(2543)] = {
    [sym_identifier] = ACTIONS(6086),
    [anon_sym_SEMI] = ACTIONS(6088),
    [anon_sym_DASH] = ACTIONS(6088),
    [aux_sym_boolean_token1] = ACTIONS(6086),
    [aux_sym_boolean_token2] = ACTIONS(6086),
    [sym_decimal] = ACTIONS(6086),
    [anon_sym_LPAREN] = ACTIONS(6088),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6086),
    [anon_sym_LBRACK] = ACTIONS(6088),
    [aux_sym_record_type_token1] = ACTIONS(6086),
    [aux_sym_basic_type_token21] = ACTIONS(6086),
    [aux_sym_basic_type_token22] = ACTIONS(6086),
    [aux_sym_basic_type_token48] = ACTIONS(6086),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6086),
    [anon_sym_POUNDif] = ACTIONS(6088),
    [anon_sym_POUNDIF] = ACTIONS(6088),
    [anon_sym_POUNDIf] = ACTIONS(6088),
    [anon_sym_not] = ACTIONS(6086),
    [anon_sym_NOT] = ACTIONS(6086),
    [anon_sym_Not] = ACTIONS(6086),
    [anon_sym_POUNDelif] = ACTIONS(6088),
    [anon_sym_POUNDELIF] = ACTIONS(6088),
    [anon_sym_POUNDElif] = ACTIONS(6088),
    [anon_sym_POUNDelse] = ACTIONS(6088),
    [anon_sym_POUNDELSE] = ACTIONS(6088),
    [anon_sym_POUNDElse] = ACTIONS(6088),
    [anon_sym_POUNDelse2] = ACTIONS(6088),
    [anon_sym_POUNDELSE2] = ACTIONS(6088),
    [anon_sym_POUNDElse2] = ACTIONS(6088),
    [anon_sym_POUNDendif] = ACTIONS(6088),
    [anon_sym_POUNDENDIF] = ACTIONS(6088),
    [anon_sym_POUNDEndif] = ACTIONS(6088),
    [anon_sym_POUNDendif2] = ACTIONS(6088),
    [anon_sym_POUNDENDIF2] = ACTIONS(6088),
    [anon_sym_POUNDEndif2] = ACTIONS(6088),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6086),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6086),
    [anon_sym_PLUS] = ACTIONS(6088),
    [sym_datetime_literal] = ACTIONS(6088),
    [sym_date_literal] = ACTIONS(6086),
    [sym_time_literal] = ACTIONS(6086),
    [sym_biginteger_literal] = ACTIONS(6088),
    [anon_sym_if] = ACTIONS(6086),
    [anon_sym_IF] = ACTIONS(6086),
    [anon_sym_If] = ACTIONS(6086),
    [anon_sym_else] = ACTIONS(6086),
    [anon_sym_ELSE] = ACTIONS(6086),
    [anon_sym_Else] = ACTIONS(6086),
    [anon_sym_case] = ACTIONS(6086),
    [anon_sym_CASE] = ACTIONS(6086),
    [anon_sym_Case] = ACTIONS(6086),
    [anon_sym_for] = ACTIONS(6086),
    [anon_sym_FOR] = ACTIONS(6086),
    [anon_sym_For] = ACTIONS(6086),
    [anon_sym_foreach] = ACTIONS(6086),
    [anon_sym_FOREACH] = ACTIONS(6086),
    [anon_sym_Foreach] = ACTIONS(6086),
    [anon_sym_while] = ACTIONS(6086),
    [anon_sym_WHILE] = ACTIONS(6086),
    [anon_sym_While] = ACTIONS(6086),
    [anon_sym_repeat] = ACTIONS(6086),
    [anon_sym_REPEAT] = ACTIONS(6086),
    [anon_sym_Repeat] = ACTIONS(6086),
    [anon_sym_exit] = ACTIONS(6086),
    [anon_sym_EXIT] = ACTIONS(6086),
    [anon_sym_Exit] = ACTIONS(6086),
    [anon_sym_continue] = ACTIONS(6086),
    [anon_sym_CONTINUE] = ACTIONS(6086),
    [anon_sym_Continue] = ACTIONS(6086),
    [anon_sym_break] = ACTIONS(6086),
    [anon_sym_BREAK] = ACTIONS(6086),
    [anon_sym_Break] = ACTIONS(6086),
    [anon_sym_with] = ACTIONS(6086),
    [anon_sym_WITH] = ACTIONS(6086),
    [anon_sym_With] = ACTIONS(6086),
    [sym_asserterror_keyword] = ACTIONS(6088),
    [sym_page_keyword] = ACTIONS(6086),
    [anon_sym_codeunit] = ACTIONS(6086),
    [anon_sym_CODEUNIT] = ACTIONS(6086),
    [anon_sym_Codeunit] = ACTIONS(6086),
    [anon_sym_CodeUnit] = ACTIONS(6086),
    [anon_sym_COdeunit] = ACTIONS(6086),
    [anon_sym_codeUnit] = ACTIONS(6086),
    [sym_report_keyword] = ACTIONS(6086),
    [sym_query_keyword] = ACTIONS(6086),
    [anon_sym_xmlport] = ACTIONS(6086),
    [anon_sym_XMLPORT] = ACTIONS(6086),
    [anon_sym_Xmlport] = ACTIONS(6086),
    [anon_sym_XMLport] = ACTIONS(6086),
    [anon_sym_XMLPort] = ACTIONS(6086),
    [anon_sym_XmlPort] = ACTIONS(6086),
    [anon_sym_enum] = ACTIONS(6086),
    [anon_sym_ENUM] = ACTIONS(6086),
    [anon_sym_Enum] = ACTIONS(6086),
    [anon_sym_eNUM] = ACTIONS(6086),
    [anon_sym_eNum] = ACTIONS(6086),
    [anon_sym_ENum] = ACTIONS(6086),
    [sym_quoted_identifier] = ACTIONS(6088),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6088),
    [sym_verbatim_string] = ACTIONS(6088),
    [sym_integer] = ACTIONS(6086),
    [sym_continue_as_identifier] = ACTIONS(6088),
    [sym_preproc_open] = ACTIONS(6088),
    [sym_preproc_close] = ACTIONS(6088),
  },
  [STATE(2544)] = {
    [sym_identifier] = ACTIONS(6090),
    [anon_sym_SEMI] = ACTIONS(6092),
    [anon_sym_DASH] = ACTIONS(6092),
    [aux_sym_boolean_token1] = ACTIONS(6090),
    [aux_sym_boolean_token2] = ACTIONS(6090),
    [sym_decimal] = ACTIONS(6090),
    [anon_sym_LPAREN] = ACTIONS(6092),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6090),
    [anon_sym_LBRACK] = ACTIONS(6092),
    [aux_sym_record_type_token1] = ACTIONS(6090),
    [aux_sym_basic_type_token21] = ACTIONS(6090),
    [aux_sym_basic_type_token22] = ACTIONS(6090),
    [aux_sym_basic_type_token48] = ACTIONS(6090),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6090),
    [anon_sym_POUNDif] = ACTIONS(6092),
    [anon_sym_POUNDIF] = ACTIONS(6092),
    [anon_sym_POUNDIf] = ACTIONS(6092),
    [anon_sym_not] = ACTIONS(6090),
    [anon_sym_NOT] = ACTIONS(6090),
    [anon_sym_Not] = ACTIONS(6090),
    [anon_sym_POUNDelif] = ACTIONS(6092),
    [anon_sym_POUNDELIF] = ACTIONS(6092),
    [anon_sym_POUNDElif] = ACTIONS(6092),
    [anon_sym_POUNDelse] = ACTIONS(6092),
    [anon_sym_POUNDELSE] = ACTIONS(6092),
    [anon_sym_POUNDElse] = ACTIONS(6092),
    [anon_sym_POUNDelse2] = ACTIONS(6092),
    [anon_sym_POUNDELSE2] = ACTIONS(6092),
    [anon_sym_POUNDElse2] = ACTIONS(6092),
    [anon_sym_POUNDendif] = ACTIONS(6092),
    [anon_sym_POUNDENDIF] = ACTIONS(6092),
    [anon_sym_POUNDEndif] = ACTIONS(6092),
    [anon_sym_POUNDendif2] = ACTIONS(6092),
    [anon_sym_POUNDENDIF2] = ACTIONS(6092),
    [anon_sym_POUNDEndif2] = ACTIONS(6092),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6090),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6090),
    [anon_sym_PLUS] = ACTIONS(6092),
    [sym_datetime_literal] = ACTIONS(6092),
    [sym_date_literal] = ACTIONS(6090),
    [sym_time_literal] = ACTIONS(6090),
    [sym_biginteger_literal] = ACTIONS(6092),
    [anon_sym_if] = ACTIONS(6090),
    [anon_sym_IF] = ACTIONS(6090),
    [anon_sym_If] = ACTIONS(6090),
    [anon_sym_else] = ACTIONS(6090),
    [anon_sym_ELSE] = ACTIONS(6090),
    [anon_sym_Else] = ACTIONS(6090),
    [anon_sym_case] = ACTIONS(6090),
    [anon_sym_CASE] = ACTIONS(6090),
    [anon_sym_Case] = ACTIONS(6090),
    [anon_sym_for] = ACTIONS(6090),
    [anon_sym_FOR] = ACTIONS(6090),
    [anon_sym_For] = ACTIONS(6090),
    [anon_sym_foreach] = ACTIONS(6090),
    [anon_sym_FOREACH] = ACTIONS(6090),
    [anon_sym_Foreach] = ACTIONS(6090),
    [anon_sym_while] = ACTIONS(6090),
    [anon_sym_WHILE] = ACTIONS(6090),
    [anon_sym_While] = ACTIONS(6090),
    [anon_sym_repeat] = ACTIONS(6090),
    [anon_sym_REPEAT] = ACTIONS(6090),
    [anon_sym_Repeat] = ACTIONS(6090),
    [anon_sym_exit] = ACTIONS(6090),
    [anon_sym_EXIT] = ACTIONS(6090),
    [anon_sym_Exit] = ACTIONS(6090),
    [anon_sym_continue] = ACTIONS(6090),
    [anon_sym_CONTINUE] = ACTIONS(6090),
    [anon_sym_Continue] = ACTIONS(6090),
    [anon_sym_break] = ACTIONS(6090),
    [anon_sym_BREAK] = ACTIONS(6090),
    [anon_sym_Break] = ACTIONS(6090),
    [anon_sym_with] = ACTIONS(6090),
    [anon_sym_WITH] = ACTIONS(6090),
    [anon_sym_With] = ACTIONS(6090),
    [sym_asserterror_keyword] = ACTIONS(6092),
    [sym_page_keyword] = ACTIONS(6090),
    [anon_sym_codeunit] = ACTIONS(6090),
    [anon_sym_CODEUNIT] = ACTIONS(6090),
    [anon_sym_Codeunit] = ACTIONS(6090),
    [anon_sym_CodeUnit] = ACTIONS(6090),
    [anon_sym_COdeunit] = ACTIONS(6090),
    [anon_sym_codeUnit] = ACTIONS(6090),
    [sym_report_keyword] = ACTIONS(6090),
    [sym_query_keyword] = ACTIONS(6090),
    [anon_sym_xmlport] = ACTIONS(6090),
    [anon_sym_XMLPORT] = ACTIONS(6090),
    [anon_sym_Xmlport] = ACTIONS(6090),
    [anon_sym_XMLport] = ACTIONS(6090),
    [anon_sym_XMLPort] = ACTIONS(6090),
    [anon_sym_XmlPort] = ACTIONS(6090),
    [anon_sym_enum] = ACTIONS(6090),
    [anon_sym_ENUM] = ACTIONS(6090),
    [anon_sym_Enum] = ACTIONS(6090),
    [anon_sym_eNUM] = ACTIONS(6090),
    [anon_sym_eNum] = ACTIONS(6090),
    [anon_sym_ENum] = ACTIONS(6090),
    [sym_quoted_identifier] = ACTIONS(6092),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6092),
    [sym_verbatim_string] = ACTIONS(6092),
    [sym_integer] = ACTIONS(6090),
    [sym_continue_as_identifier] = ACTIONS(6092),
    [sym_preproc_open] = ACTIONS(6092),
    [sym_preproc_close] = ACTIONS(6092),
  },
  [STATE(2545)] = {
    [sym_identifier] = ACTIONS(6086),
    [anon_sym_SEMI] = ACTIONS(6088),
    [anon_sym_DASH] = ACTIONS(6088),
    [aux_sym_boolean_token1] = ACTIONS(6086),
    [aux_sym_boolean_token2] = ACTIONS(6086),
    [sym_decimal] = ACTIONS(6086),
    [anon_sym_LPAREN] = ACTIONS(6088),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6086),
    [anon_sym_LBRACK] = ACTIONS(6088),
    [aux_sym_record_type_token1] = ACTIONS(6086),
    [aux_sym_basic_type_token21] = ACTIONS(6086),
    [aux_sym_basic_type_token22] = ACTIONS(6086),
    [aux_sym_basic_type_token48] = ACTIONS(6086),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6086),
    [anon_sym_POUNDif] = ACTIONS(6088),
    [anon_sym_POUNDIF] = ACTIONS(6088),
    [anon_sym_POUNDIf] = ACTIONS(6088),
    [anon_sym_not] = ACTIONS(6086),
    [anon_sym_NOT] = ACTIONS(6086),
    [anon_sym_Not] = ACTIONS(6086),
    [anon_sym_POUNDelif] = ACTIONS(6088),
    [anon_sym_POUNDELIF] = ACTIONS(6088),
    [anon_sym_POUNDElif] = ACTIONS(6088),
    [anon_sym_POUNDelse] = ACTIONS(6088),
    [anon_sym_POUNDELSE] = ACTIONS(6088),
    [anon_sym_POUNDElse] = ACTIONS(6088),
    [anon_sym_POUNDelse2] = ACTIONS(6088),
    [anon_sym_POUNDELSE2] = ACTIONS(6088),
    [anon_sym_POUNDElse2] = ACTIONS(6088),
    [anon_sym_POUNDendif] = ACTIONS(6088),
    [anon_sym_POUNDENDIF] = ACTIONS(6088),
    [anon_sym_POUNDEndif] = ACTIONS(6088),
    [anon_sym_POUNDendif2] = ACTIONS(6088),
    [anon_sym_POUNDENDIF2] = ACTIONS(6088),
    [anon_sym_POUNDEndif2] = ACTIONS(6088),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6086),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6086),
    [anon_sym_PLUS] = ACTIONS(6088),
    [sym_datetime_literal] = ACTIONS(6088),
    [sym_date_literal] = ACTIONS(6086),
    [sym_time_literal] = ACTIONS(6086),
    [sym_biginteger_literal] = ACTIONS(6088),
    [anon_sym_if] = ACTIONS(6086),
    [anon_sym_IF] = ACTIONS(6086),
    [anon_sym_If] = ACTIONS(6086),
    [anon_sym_else] = ACTIONS(6086),
    [anon_sym_ELSE] = ACTIONS(6086),
    [anon_sym_Else] = ACTIONS(6086),
    [anon_sym_case] = ACTIONS(6086),
    [anon_sym_CASE] = ACTIONS(6086),
    [anon_sym_Case] = ACTIONS(6086),
    [anon_sym_for] = ACTIONS(6086),
    [anon_sym_FOR] = ACTIONS(6086),
    [anon_sym_For] = ACTIONS(6086),
    [anon_sym_foreach] = ACTIONS(6086),
    [anon_sym_FOREACH] = ACTIONS(6086),
    [anon_sym_Foreach] = ACTIONS(6086),
    [anon_sym_while] = ACTIONS(6086),
    [anon_sym_WHILE] = ACTIONS(6086),
    [anon_sym_While] = ACTIONS(6086),
    [anon_sym_repeat] = ACTIONS(6086),
    [anon_sym_REPEAT] = ACTIONS(6086),
    [anon_sym_Repeat] = ACTIONS(6086),
    [anon_sym_exit] = ACTIONS(6086),
    [anon_sym_EXIT] = ACTIONS(6086),
    [anon_sym_Exit] = ACTIONS(6086),
    [anon_sym_continue] = ACTIONS(6086),
    [anon_sym_CONTINUE] = ACTIONS(6086),
    [anon_sym_Continue] = ACTIONS(6086),
    [anon_sym_break] = ACTIONS(6086),
    [anon_sym_BREAK] = ACTIONS(6086),
    [anon_sym_Break] = ACTIONS(6086),
    [anon_sym_with] = ACTIONS(6086),
    [anon_sym_WITH] = ACTIONS(6086),
    [anon_sym_With] = ACTIONS(6086),
    [sym_asserterror_keyword] = ACTIONS(6088),
    [sym_page_keyword] = ACTIONS(6086),
    [anon_sym_codeunit] = ACTIONS(6086),
    [anon_sym_CODEUNIT] = ACTIONS(6086),
    [anon_sym_Codeunit] = ACTIONS(6086),
    [anon_sym_CodeUnit] = ACTIONS(6086),
    [anon_sym_COdeunit] = ACTIONS(6086),
    [anon_sym_codeUnit] = ACTIONS(6086),
    [sym_report_keyword] = ACTIONS(6086),
    [sym_query_keyword] = ACTIONS(6086),
    [anon_sym_xmlport] = ACTIONS(6086),
    [anon_sym_XMLPORT] = ACTIONS(6086),
    [anon_sym_Xmlport] = ACTIONS(6086),
    [anon_sym_XMLport] = ACTIONS(6086),
    [anon_sym_XMLPort] = ACTIONS(6086),
    [anon_sym_XmlPort] = ACTIONS(6086),
    [anon_sym_enum] = ACTIONS(6086),
    [anon_sym_ENUM] = ACTIONS(6086),
    [anon_sym_Enum] = ACTIONS(6086),
    [anon_sym_eNUM] = ACTIONS(6086),
    [anon_sym_eNum] = ACTIONS(6086),
    [anon_sym_ENum] = ACTIONS(6086),
    [sym_quoted_identifier] = ACTIONS(6088),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6088),
    [sym_verbatim_string] = ACTIONS(6088),
    [sym_integer] = ACTIONS(6086),
    [sym_continue_as_identifier] = ACTIONS(6088),
    [sym_preproc_open] = ACTIONS(6088),
    [sym_preproc_close] = ACTIONS(6088),
  },
  [STATE(2546)] = {
    [sym_identifier] = ACTIONS(6094),
    [anon_sym_SEMI] = ACTIONS(6096),
    [anon_sym_DASH] = ACTIONS(6096),
    [aux_sym_boolean_token1] = ACTIONS(6094),
    [aux_sym_boolean_token2] = ACTIONS(6094),
    [sym_decimal] = ACTIONS(6094),
    [anon_sym_LPAREN] = ACTIONS(6096),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6094),
    [anon_sym_LBRACK] = ACTIONS(6096),
    [aux_sym_record_type_token1] = ACTIONS(6094),
    [aux_sym_basic_type_token21] = ACTIONS(6094),
    [aux_sym_basic_type_token22] = ACTIONS(6094),
    [aux_sym_basic_type_token48] = ACTIONS(6094),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6094),
    [anon_sym_POUNDif] = ACTIONS(6096),
    [anon_sym_POUNDIF] = ACTIONS(6096),
    [anon_sym_POUNDIf] = ACTIONS(6096),
    [anon_sym_not] = ACTIONS(6094),
    [anon_sym_NOT] = ACTIONS(6094),
    [anon_sym_Not] = ACTIONS(6094),
    [anon_sym_POUNDelif] = ACTIONS(6096),
    [anon_sym_POUNDELIF] = ACTIONS(6096),
    [anon_sym_POUNDElif] = ACTIONS(6096),
    [anon_sym_POUNDelse] = ACTIONS(6096),
    [anon_sym_POUNDELSE] = ACTIONS(6096),
    [anon_sym_POUNDElse] = ACTIONS(6096),
    [anon_sym_POUNDelse2] = ACTIONS(6096),
    [anon_sym_POUNDELSE2] = ACTIONS(6096),
    [anon_sym_POUNDElse2] = ACTIONS(6096),
    [anon_sym_POUNDendif] = ACTIONS(6096),
    [anon_sym_POUNDENDIF] = ACTIONS(6096),
    [anon_sym_POUNDEndif] = ACTIONS(6096),
    [anon_sym_POUNDendif2] = ACTIONS(6096),
    [anon_sym_POUNDENDIF2] = ACTIONS(6096),
    [anon_sym_POUNDEndif2] = ACTIONS(6096),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6094),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6094),
    [anon_sym_PLUS] = ACTIONS(6096),
    [sym_datetime_literal] = ACTIONS(6096),
    [sym_date_literal] = ACTIONS(6094),
    [sym_time_literal] = ACTIONS(6094),
    [sym_biginteger_literal] = ACTIONS(6096),
    [anon_sym_if] = ACTIONS(6094),
    [anon_sym_IF] = ACTIONS(6094),
    [anon_sym_If] = ACTIONS(6094),
    [anon_sym_else] = ACTIONS(6094),
    [anon_sym_ELSE] = ACTIONS(6094),
    [anon_sym_Else] = ACTIONS(6094),
    [anon_sym_case] = ACTIONS(6094),
    [anon_sym_CASE] = ACTIONS(6094),
    [anon_sym_Case] = ACTIONS(6094),
    [anon_sym_for] = ACTIONS(6094),
    [anon_sym_FOR] = ACTIONS(6094),
    [anon_sym_For] = ACTIONS(6094),
    [anon_sym_foreach] = ACTIONS(6094),
    [anon_sym_FOREACH] = ACTIONS(6094),
    [anon_sym_Foreach] = ACTIONS(6094),
    [anon_sym_while] = ACTIONS(6094),
    [anon_sym_WHILE] = ACTIONS(6094),
    [anon_sym_While] = ACTIONS(6094),
    [anon_sym_repeat] = ACTIONS(6094),
    [anon_sym_REPEAT] = ACTIONS(6094),
    [anon_sym_Repeat] = ACTIONS(6094),
    [anon_sym_exit] = ACTIONS(6094),
    [anon_sym_EXIT] = ACTIONS(6094),
    [anon_sym_Exit] = ACTIONS(6094),
    [anon_sym_continue] = ACTIONS(6094),
    [anon_sym_CONTINUE] = ACTIONS(6094),
    [anon_sym_Continue] = ACTIONS(6094),
    [anon_sym_break] = ACTIONS(6094),
    [anon_sym_BREAK] = ACTIONS(6094),
    [anon_sym_Break] = ACTIONS(6094),
    [anon_sym_with] = ACTIONS(6094),
    [anon_sym_WITH] = ACTIONS(6094),
    [anon_sym_With] = ACTIONS(6094),
    [sym_asserterror_keyword] = ACTIONS(6096),
    [sym_page_keyword] = ACTIONS(6094),
    [anon_sym_codeunit] = ACTIONS(6094),
    [anon_sym_CODEUNIT] = ACTIONS(6094),
    [anon_sym_Codeunit] = ACTIONS(6094),
    [anon_sym_CodeUnit] = ACTIONS(6094),
    [anon_sym_COdeunit] = ACTIONS(6094),
    [anon_sym_codeUnit] = ACTIONS(6094),
    [sym_report_keyword] = ACTIONS(6094),
    [sym_query_keyword] = ACTIONS(6094),
    [anon_sym_xmlport] = ACTIONS(6094),
    [anon_sym_XMLPORT] = ACTIONS(6094),
    [anon_sym_Xmlport] = ACTIONS(6094),
    [anon_sym_XMLport] = ACTIONS(6094),
    [anon_sym_XMLPort] = ACTIONS(6094),
    [anon_sym_XmlPort] = ACTIONS(6094),
    [anon_sym_enum] = ACTIONS(6094),
    [anon_sym_ENUM] = ACTIONS(6094),
    [anon_sym_Enum] = ACTIONS(6094),
    [anon_sym_eNUM] = ACTIONS(6094),
    [anon_sym_eNum] = ACTIONS(6094),
    [anon_sym_ENum] = ACTIONS(6094),
    [sym_quoted_identifier] = ACTIONS(6096),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6096),
    [sym_verbatim_string] = ACTIONS(6096),
    [sym_integer] = ACTIONS(6094),
    [sym_continue_as_identifier] = ACTIONS(6096),
    [sym_preproc_open] = ACTIONS(6096),
    [sym_preproc_close] = ACTIONS(6096),
  },
  [STATE(2547)] = {
    [sym_identifier] = ACTIONS(6098),
    [anon_sym_SEMI] = ACTIONS(6100),
    [anon_sym_DASH] = ACTIONS(6100),
    [aux_sym_boolean_token1] = ACTIONS(6098),
    [aux_sym_boolean_token2] = ACTIONS(6098),
    [sym_decimal] = ACTIONS(6098),
    [anon_sym_LPAREN] = ACTIONS(6100),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6098),
    [anon_sym_LBRACK] = ACTIONS(6100),
    [aux_sym_record_type_token1] = ACTIONS(6098),
    [aux_sym_basic_type_token21] = ACTIONS(6098),
    [aux_sym_basic_type_token22] = ACTIONS(6098),
    [aux_sym_basic_type_token48] = ACTIONS(6098),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6098),
    [anon_sym_POUNDif] = ACTIONS(6100),
    [anon_sym_POUNDIF] = ACTIONS(6100),
    [anon_sym_POUNDIf] = ACTIONS(6100),
    [anon_sym_not] = ACTIONS(6098),
    [anon_sym_NOT] = ACTIONS(6098),
    [anon_sym_Not] = ACTIONS(6098),
    [anon_sym_POUNDelif] = ACTIONS(6100),
    [anon_sym_POUNDELIF] = ACTIONS(6100),
    [anon_sym_POUNDElif] = ACTIONS(6100),
    [anon_sym_POUNDelse] = ACTIONS(6100),
    [anon_sym_POUNDELSE] = ACTIONS(6100),
    [anon_sym_POUNDElse] = ACTIONS(6100),
    [anon_sym_POUNDelse2] = ACTIONS(6100),
    [anon_sym_POUNDELSE2] = ACTIONS(6100),
    [anon_sym_POUNDElse2] = ACTIONS(6100),
    [anon_sym_POUNDendif] = ACTIONS(6100),
    [anon_sym_POUNDENDIF] = ACTIONS(6100),
    [anon_sym_POUNDEndif] = ACTIONS(6100),
    [anon_sym_POUNDendif2] = ACTIONS(6100),
    [anon_sym_POUNDENDIF2] = ACTIONS(6100),
    [anon_sym_POUNDEndif2] = ACTIONS(6100),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6098),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6098),
    [anon_sym_PLUS] = ACTIONS(6100),
    [sym_datetime_literal] = ACTIONS(6100),
    [sym_date_literal] = ACTIONS(6098),
    [sym_time_literal] = ACTIONS(6098),
    [sym_biginteger_literal] = ACTIONS(6100),
    [anon_sym_if] = ACTIONS(6098),
    [anon_sym_IF] = ACTIONS(6098),
    [anon_sym_If] = ACTIONS(6098),
    [anon_sym_else] = ACTIONS(6098),
    [anon_sym_ELSE] = ACTIONS(6098),
    [anon_sym_Else] = ACTIONS(6098),
    [anon_sym_case] = ACTIONS(6098),
    [anon_sym_CASE] = ACTIONS(6098),
    [anon_sym_Case] = ACTIONS(6098),
    [anon_sym_for] = ACTIONS(6098),
    [anon_sym_FOR] = ACTIONS(6098),
    [anon_sym_For] = ACTIONS(6098),
    [anon_sym_foreach] = ACTIONS(6098),
    [anon_sym_FOREACH] = ACTIONS(6098),
    [anon_sym_Foreach] = ACTIONS(6098),
    [anon_sym_while] = ACTIONS(6098),
    [anon_sym_WHILE] = ACTIONS(6098),
    [anon_sym_While] = ACTIONS(6098),
    [anon_sym_repeat] = ACTIONS(6098),
    [anon_sym_REPEAT] = ACTIONS(6098),
    [anon_sym_Repeat] = ACTIONS(6098),
    [anon_sym_exit] = ACTIONS(6098),
    [anon_sym_EXIT] = ACTIONS(6098),
    [anon_sym_Exit] = ACTIONS(6098),
    [anon_sym_continue] = ACTIONS(6098),
    [anon_sym_CONTINUE] = ACTIONS(6098),
    [anon_sym_Continue] = ACTIONS(6098),
    [anon_sym_break] = ACTIONS(6098),
    [anon_sym_BREAK] = ACTIONS(6098),
    [anon_sym_Break] = ACTIONS(6098),
    [anon_sym_with] = ACTIONS(6098),
    [anon_sym_WITH] = ACTIONS(6098),
    [anon_sym_With] = ACTIONS(6098),
    [sym_asserterror_keyword] = ACTIONS(6100),
    [sym_page_keyword] = ACTIONS(6098),
    [anon_sym_codeunit] = ACTIONS(6098),
    [anon_sym_CODEUNIT] = ACTIONS(6098),
    [anon_sym_Codeunit] = ACTIONS(6098),
    [anon_sym_CodeUnit] = ACTIONS(6098),
    [anon_sym_COdeunit] = ACTIONS(6098),
    [anon_sym_codeUnit] = ACTIONS(6098),
    [sym_report_keyword] = ACTIONS(6098),
    [sym_query_keyword] = ACTIONS(6098),
    [anon_sym_xmlport] = ACTIONS(6098),
    [anon_sym_XMLPORT] = ACTIONS(6098),
    [anon_sym_Xmlport] = ACTIONS(6098),
    [anon_sym_XMLport] = ACTIONS(6098),
    [anon_sym_XMLPort] = ACTIONS(6098),
    [anon_sym_XmlPort] = ACTIONS(6098),
    [anon_sym_enum] = ACTIONS(6098),
    [anon_sym_ENUM] = ACTIONS(6098),
    [anon_sym_Enum] = ACTIONS(6098),
    [anon_sym_eNUM] = ACTIONS(6098),
    [anon_sym_eNum] = ACTIONS(6098),
    [anon_sym_ENum] = ACTIONS(6098),
    [sym_quoted_identifier] = ACTIONS(6100),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6100),
    [sym_verbatim_string] = ACTIONS(6100),
    [sym_integer] = ACTIONS(6098),
    [sym_continue_as_identifier] = ACTIONS(6100),
    [sym_preproc_open] = ACTIONS(6100),
    [sym_preproc_close] = ACTIONS(6100),
  },
  [STATE(2548)] = {
    [sym_identifier] = ACTIONS(6094),
    [anon_sym_SEMI] = ACTIONS(6096),
    [anon_sym_DASH] = ACTIONS(6096),
    [aux_sym_boolean_token1] = ACTIONS(6094),
    [aux_sym_boolean_token2] = ACTIONS(6094),
    [sym_decimal] = ACTIONS(6094),
    [anon_sym_LPAREN] = ACTIONS(6096),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6094),
    [anon_sym_LBRACK] = ACTIONS(6096),
    [aux_sym_record_type_token1] = ACTIONS(6094),
    [aux_sym_basic_type_token21] = ACTIONS(6094),
    [aux_sym_basic_type_token22] = ACTIONS(6094),
    [aux_sym_basic_type_token48] = ACTIONS(6094),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6094),
    [anon_sym_POUNDif] = ACTIONS(6096),
    [anon_sym_POUNDIF] = ACTIONS(6096),
    [anon_sym_POUNDIf] = ACTIONS(6096),
    [anon_sym_not] = ACTIONS(6094),
    [anon_sym_NOT] = ACTIONS(6094),
    [anon_sym_Not] = ACTIONS(6094),
    [anon_sym_POUNDelif] = ACTIONS(6096),
    [anon_sym_POUNDELIF] = ACTIONS(6096),
    [anon_sym_POUNDElif] = ACTIONS(6096),
    [anon_sym_POUNDelse] = ACTIONS(6096),
    [anon_sym_POUNDELSE] = ACTIONS(6096),
    [anon_sym_POUNDElse] = ACTIONS(6096),
    [anon_sym_POUNDelse2] = ACTIONS(6096),
    [anon_sym_POUNDELSE2] = ACTIONS(6096),
    [anon_sym_POUNDElse2] = ACTIONS(6096),
    [anon_sym_POUNDendif] = ACTIONS(6096),
    [anon_sym_POUNDENDIF] = ACTIONS(6096),
    [anon_sym_POUNDEndif] = ACTIONS(6096),
    [anon_sym_POUNDendif2] = ACTIONS(6096),
    [anon_sym_POUNDENDIF2] = ACTIONS(6096),
    [anon_sym_POUNDEndif2] = ACTIONS(6096),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6094),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6094),
    [anon_sym_PLUS] = ACTIONS(6096),
    [sym_datetime_literal] = ACTIONS(6096),
    [sym_date_literal] = ACTIONS(6094),
    [sym_time_literal] = ACTIONS(6094),
    [sym_biginteger_literal] = ACTIONS(6096),
    [anon_sym_if] = ACTIONS(6094),
    [anon_sym_IF] = ACTIONS(6094),
    [anon_sym_If] = ACTIONS(6094),
    [anon_sym_else] = ACTIONS(6094),
    [anon_sym_ELSE] = ACTIONS(6094),
    [anon_sym_Else] = ACTIONS(6094),
    [anon_sym_case] = ACTIONS(6094),
    [anon_sym_CASE] = ACTIONS(6094),
    [anon_sym_Case] = ACTIONS(6094),
    [anon_sym_for] = ACTIONS(6094),
    [anon_sym_FOR] = ACTIONS(6094),
    [anon_sym_For] = ACTIONS(6094),
    [anon_sym_foreach] = ACTIONS(6094),
    [anon_sym_FOREACH] = ACTIONS(6094),
    [anon_sym_Foreach] = ACTIONS(6094),
    [anon_sym_while] = ACTIONS(6094),
    [anon_sym_WHILE] = ACTIONS(6094),
    [anon_sym_While] = ACTIONS(6094),
    [anon_sym_repeat] = ACTIONS(6094),
    [anon_sym_REPEAT] = ACTIONS(6094),
    [anon_sym_Repeat] = ACTIONS(6094),
    [anon_sym_exit] = ACTIONS(6094),
    [anon_sym_EXIT] = ACTIONS(6094),
    [anon_sym_Exit] = ACTIONS(6094),
    [anon_sym_continue] = ACTIONS(6094),
    [anon_sym_CONTINUE] = ACTIONS(6094),
    [anon_sym_Continue] = ACTIONS(6094),
    [anon_sym_break] = ACTIONS(6094),
    [anon_sym_BREAK] = ACTIONS(6094),
    [anon_sym_Break] = ACTIONS(6094),
    [anon_sym_with] = ACTIONS(6094),
    [anon_sym_WITH] = ACTIONS(6094),
    [anon_sym_With] = ACTIONS(6094),
    [sym_asserterror_keyword] = ACTIONS(6096),
    [sym_page_keyword] = ACTIONS(6094),
    [anon_sym_codeunit] = ACTIONS(6094),
    [anon_sym_CODEUNIT] = ACTIONS(6094),
    [anon_sym_Codeunit] = ACTIONS(6094),
    [anon_sym_CodeUnit] = ACTIONS(6094),
    [anon_sym_COdeunit] = ACTIONS(6094),
    [anon_sym_codeUnit] = ACTIONS(6094),
    [sym_report_keyword] = ACTIONS(6094),
    [sym_query_keyword] = ACTIONS(6094),
    [anon_sym_xmlport] = ACTIONS(6094),
    [anon_sym_XMLPORT] = ACTIONS(6094),
    [anon_sym_Xmlport] = ACTIONS(6094),
    [anon_sym_XMLport] = ACTIONS(6094),
    [anon_sym_XMLPort] = ACTIONS(6094),
    [anon_sym_XmlPort] = ACTIONS(6094),
    [anon_sym_enum] = ACTIONS(6094),
    [anon_sym_ENUM] = ACTIONS(6094),
    [anon_sym_Enum] = ACTIONS(6094),
    [anon_sym_eNUM] = ACTIONS(6094),
    [anon_sym_eNum] = ACTIONS(6094),
    [anon_sym_ENum] = ACTIONS(6094),
    [sym_quoted_identifier] = ACTIONS(6096),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6096),
    [sym_verbatim_string] = ACTIONS(6096),
    [sym_integer] = ACTIONS(6094),
    [sym_continue_as_identifier] = ACTIONS(6096),
    [sym_preproc_open] = ACTIONS(6096),
    [sym_preproc_close] = ACTIONS(6096),
  },
  [STATE(2549)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_DASH] = ACTIONS(5277),
    [aux_sym_boolean_token1] = ACTIONS(5279),
    [aux_sym_boolean_token2] = ACTIONS(5279),
    [sym_decimal] = ACTIONS(5279),
    [anon_sym_LPAREN] = ACTIONS(5277),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_record_type_token1] = ACTIONS(5279),
    [aux_sym_basic_type_token21] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token48] = ACTIONS(5279),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_not] = ACTIONS(5279),
    [anon_sym_NOT] = ACTIONS(5279),
    [anon_sym_Not] = ACTIONS(5279),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5279),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5279),
    [anon_sym_PLUS] = ACTIONS(5277),
    [sym_datetime_literal] = ACTIONS(5277),
    [sym_date_literal] = ACTIONS(5279),
    [sym_time_literal] = ACTIONS(5279),
    [sym_biginteger_literal] = ACTIONS(5277),
    [anon_sym_if] = ACTIONS(5279),
    [anon_sym_IF] = ACTIONS(5279),
    [anon_sym_If] = ACTIONS(5279),
    [anon_sym_else] = ACTIONS(5279),
    [anon_sym_ELSE] = ACTIONS(5279),
    [anon_sym_Else] = ACTIONS(5279),
    [anon_sym_case] = ACTIONS(5279),
    [anon_sym_CASE] = ACTIONS(5279),
    [anon_sym_Case] = ACTIONS(5279),
    [anon_sym_for] = ACTIONS(5279),
    [anon_sym_FOR] = ACTIONS(5279),
    [anon_sym_For] = ACTIONS(5279),
    [anon_sym_foreach] = ACTIONS(5279),
    [anon_sym_FOREACH] = ACTIONS(5279),
    [anon_sym_Foreach] = ACTIONS(5279),
    [anon_sym_while] = ACTIONS(5279),
    [anon_sym_WHILE] = ACTIONS(5279),
    [anon_sym_While] = ACTIONS(5279),
    [anon_sym_repeat] = ACTIONS(5279),
    [anon_sym_REPEAT] = ACTIONS(5279),
    [anon_sym_Repeat] = ACTIONS(5279),
    [anon_sym_exit] = ACTIONS(5279),
    [anon_sym_EXIT] = ACTIONS(5279),
    [anon_sym_Exit] = ACTIONS(5279),
    [anon_sym_continue] = ACTIONS(5279),
    [anon_sym_CONTINUE] = ACTIONS(5279),
    [anon_sym_Continue] = ACTIONS(5279),
    [anon_sym_break] = ACTIONS(5279),
    [anon_sym_BREAK] = ACTIONS(5279),
    [anon_sym_Break] = ACTIONS(5279),
    [anon_sym_with] = ACTIONS(5279),
    [anon_sym_WITH] = ACTIONS(5279),
    [anon_sym_With] = ACTIONS(5279),
    [sym_asserterror_keyword] = ACTIONS(5277),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [anon_sym_enum] = ACTIONS(5279),
    [anon_sym_ENUM] = ACTIONS(5279),
    [anon_sym_Enum] = ACTIONS(5279),
    [anon_sym_eNUM] = ACTIONS(5279),
    [anon_sym_eNum] = ACTIONS(5279),
    [anon_sym_ENum] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5277),
    [sym_verbatim_string] = ACTIONS(5277),
    [sym_integer] = ACTIONS(5279),
    [sym_continue_as_identifier] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
  },
  [STATE(2550)] = {
    [sym_identifier] = ACTIONS(6102),
    [anon_sym_SEMI] = ACTIONS(6104),
    [anon_sym_DASH] = ACTIONS(6104),
    [aux_sym_boolean_token1] = ACTIONS(6102),
    [aux_sym_boolean_token2] = ACTIONS(6102),
    [sym_decimal] = ACTIONS(6102),
    [anon_sym_LPAREN] = ACTIONS(6104),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6102),
    [anon_sym_LBRACK] = ACTIONS(6104),
    [aux_sym_record_type_token1] = ACTIONS(6102),
    [aux_sym_basic_type_token21] = ACTIONS(6102),
    [aux_sym_basic_type_token22] = ACTIONS(6102),
    [aux_sym_basic_type_token48] = ACTIONS(6102),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6102),
    [anon_sym_POUNDif] = ACTIONS(6104),
    [anon_sym_POUNDIF] = ACTIONS(6104),
    [anon_sym_POUNDIf] = ACTIONS(6104),
    [anon_sym_not] = ACTIONS(6102),
    [anon_sym_NOT] = ACTIONS(6102),
    [anon_sym_Not] = ACTIONS(6102),
    [anon_sym_POUNDelif] = ACTIONS(6104),
    [anon_sym_POUNDELIF] = ACTIONS(6104),
    [anon_sym_POUNDElif] = ACTIONS(6104),
    [anon_sym_POUNDelse] = ACTIONS(6104),
    [anon_sym_POUNDELSE] = ACTIONS(6104),
    [anon_sym_POUNDElse] = ACTIONS(6104),
    [anon_sym_POUNDelse2] = ACTIONS(6104),
    [anon_sym_POUNDELSE2] = ACTIONS(6104),
    [anon_sym_POUNDElse2] = ACTIONS(6104),
    [anon_sym_POUNDendif] = ACTIONS(6104),
    [anon_sym_POUNDENDIF] = ACTIONS(6104),
    [anon_sym_POUNDEndif] = ACTIONS(6104),
    [anon_sym_POUNDendif2] = ACTIONS(6104),
    [anon_sym_POUNDENDIF2] = ACTIONS(6104),
    [anon_sym_POUNDEndif2] = ACTIONS(6104),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6102),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6102),
    [anon_sym_PLUS] = ACTIONS(6104),
    [sym_datetime_literal] = ACTIONS(6104),
    [sym_date_literal] = ACTIONS(6102),
    [sym_time_literal] = ACTIONS(6102),
    [sym_biginteger_literal] = ACTIONS(6104),
    [anon_sym_if] = ACTIONS(6102),
    [anon_sym_IF] = ACTIONS(6102),
    [anon_sym_If] = ACTIONS(6102),
    [anon_sym_else] = ACTIONS(6102),
    [anon_sym_ELSE] = ACTIONS(6102),
    [anon_sym_Else] = ACTIONS(6102),
    [anon_sym_case] = ACTIONS(6102),
    [anon_sym_CASE] = ACTIONS(6102),
    [anon_sym_Case] = ACTIONS(6102),
    [anon_sym_for] = ACTIONS(6102),
    [anon_sym_FOR] = ACTIONS(6102),
    [anon_sym_For] = ACTIONS(6102),
    [anon_sym_foreach] = ACTIONS(6102),
    [anon_sym_FOREACH] = ACTIONS(6102),
    [anon_sym_Foreach] = ACTIONS(6102),
    [anon_sym_while] = ACTIONS(6102),
    [anon_sym_WHILE] = ACTIONS(6102),
    [anon_sym_While] = ACTIONS(6102),
    [anon_sym_repeat] = ACTIONS(6102),
    [anon_sym_REPEAT] = ACTIONS(6102),
    [anon_sym_Repeat] = ACTIONS(6102),
    [anon_sym_exit] = ACTIONS(6102),
    [anon_sym_EXIT] = ACTIONS(6102),
    [anon_sym_Exit] = ACTIONS(6102),
    [anon_sym_continue] = ACTIONS(6102),
    [anon_sym_CONTINUE] = ACTIONS(6102),
    [anon_sym_Continue] = ACTIONS(6102),
    [anon_sym_break] = ACTIONS(6102),
    [anon_sym_BREAK] = ACTIONS(6102),
    [anon_sym_Break] = ACTIONS(6102),
    [anon_sym_with] = ACTIONS(6102),
    [anon_sym_WITH] = ACTIONS(6102),
    [anon_sym_With] = ACTIONS(6102),
    [sym_asserterror_keyword] = ACTIONS(6104),
    [sym_page_keyword] = ACTIONS(6102),
    [anon_sym_codeunit] = ACTIONS(6102),
    [anon_sym_CODEUNIT] = ACTIONS(6102),
    [anon_sym_Codeunit] = ACTIONS(6102),
    [anon_sym_CodeUnit] = ACTIONS(6102),
    [anon_sym_COdeunit] = ACTIONS(6102),
    [anon_sym_codeUnit] = ACTIONS(6102),
    [sym_report_keyword] = ACTIONS(6102),
    [sym_query_keyword] = ACTIONS(6102),
    [anon_sym_xmlport] = ACTIONS(6102),
    [anon_sym_XMLPORT] = ACTIONS(6102),
    [anon_sym_Xmlport] = ACTIONS(6102),
    [anon_sym_XMLport] = ACTIONS(6102),
    [anon_sym_XMLPort] = ACTIONS(6102),
    [anon_sym_XmlPort] = ACTIONS(6102),
    [anon_sym_enum] = ACTIONS(6102),
    [anon_sym_ENUM] = ACTIONS(6102),
    [anon_sym_Enum] = ACTIONS(6102),
    [anon_sym_eNUM] = ACTIONS(6102),
    [anon_sym_eNum] = ACTIONS(6102),
    [anon_sym_ENum] = ACTIONS(6102),
    [sym_quoted_identifier] = ACTIONS(6104),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6104),
    [sym_verbatim_string] = ACTIONS(6104),
    [sym_integer] = ACTIONS(6102),
    [sym_continue_as_identifier] = ACTIONS(6104),
    [sym_preproc_open] = ACTIONS(6104),
    [sym_preproc_close] = ACTIONS(6104),
  },
  [STATE(2551)] = {
    [sym_identifier] = ACTIONS(6106),
    [anon_sym_SEMI] = ACTIONS(6108),
    [anon_sym_DASH] = ACTIONS(6108),
    [aux_sym_boolean_token1] = ACTIONS(6106),
    [aux_sym_boolean_token2] = ACTIONS(6106),
    [sym_decimal] = ACTIONS(6106),
    [anon_sym_LPAREN] = ACTIONS(6108),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6106),
    [anon_sym_LBRACK] = ACTIONS(6108),
    [aux_sym_record_type_token1] = ACTIONS(6106),
    [aux_sym_basic_type_token21] = ACTIONS(6106),
    [aux_sym_basic_type_token22] = ACTIONS(6106),
    [aux_sym_basic_type_token48] = ACTIONS(6106),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6106),
    [anon_sym_POUNDif] = ACTIONS(6108),
    [anon_sym_POUNDIF] = ACTIONS(6108),
    [anon_sym_POUNDIf] = ACTIONS(6108),
    [anon_sym_not] = ACTIONS(6106),
    [anon_sym_NOT] = ACTIONS(6106),
    [anon_sym_Not] = ACTIONS(6106),
    [anon_sym_POUNDelif] = ACTIONS(6108),
    [anon_sym_POUNDELIF] = ACTIONS(6108),
    [anon_sym_POUNDElif] = ACTIONS(6108),
    [anon_sym_POUNDelse] = ACTIONS(6108),
    [anon_sym_POUNDELSE] = ACTIONS(6108),
    [anon_sym_POUNDElse] = ACTIONS(6108),
    [anon_sym_POUNDelse2] = ACTIONS(6108),
    [anon_sym_POUNDELSE2] = ACTIONS(6108),
    [anon_sym_POUNDElse2] = ACTIONS(6108),
    [anon_sym_POUNDendif] = ACTIONS(6108),
    [anon_sym_POUNDENDIF] = ACTIONS(6108),
    [anon_sym_POUNDEndif] = ACTIONS(6108),
    [anon_sym_POUNDendif2] = ACTIONS(6108),
    [anon_sym_POUNDENDIF2] = ACTIONS(6108),
    [anon_sym_POUNDEndif2] = ACTIONS(6108),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6106),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6106),
    [anon_sym_PLUS] = ACTIONS(6108),
    [sym_datetime_literal] = ACTIONS(6108),
    [sym_date_literal] = ACTIONS(6106),
    [sym_time_literal] = ACTIONS(6106),
    [sym_biginteger_literal] = ACTIONS(6108),
    [anon_sym_if] = ACTIONS(6106),
    [anon_sym_IF] = ACTIONS(6106),
    [anon_sym_If] = ACTIONS(6106),
    [anon_sym_else] = ACTIONS(6106),
    [anon_sym_ELSE] = ACTIONS(6106),
    [anon_sym_Else] = ACTIONS(6106),
    [anon_sym_case] = ACTIONS(6106),
    [anon_sym_CASE] = ACTIONS(6106),
    [anon_sym_Case] = ACTIONS(6106),
    [anon_sym_for] = ACTIONS(6106),
    [anon_sym_FOR] = ACTIONS(6106),
    [anon_sym_For] = ACTIONS(6106),
    [anon_sym_foreach] = ACTIONS(6106),
    [anon_sym_FOREACH] = ACTIONS(6106),
    [anon_sym_Foreach] = ACTIONS(6106),
    [anon_sym_while] = ACTIONS(6106),
    [anon_sym_WHILE] = ACTIONS(6106),
    [anon_sym_While] = ACTIONS(6106),
    [anon_sym_repeat] = ACTIONS(6106),
    [anon_sym_REPEAT] = ACTIONS(6106),
    [anon_sym_Repeat] = ACTIONS(6106),
    [anon_sym_exit] = ACTIONS(6106),
    [anon_sym_EXIT] = ACTIONS(6106),
    [anon_sym_Exit] = ACTIONS(6106),
    [anon_sym_continue] = ACTIONS(6106),
    [anon_sym_CONTINUE] = ACTIONS(6106),
    [anon_sym_Continue] = ACTIONS(6106),
    [anon_sym_break] = ACTIONS(6106),
    [anon_sym_BREAK] = ACTIONS(6106),
    [anon_sym_Break] = ACTIONS(6106),
    [anon_sym_with] = ACTIONS(6106),
    [anon_sym_WITH] = ACTIONS(6106),
    [anon_sym_With] = ACTIONS(6106),
    [sym_asserterror_keyword] = ACTIONS(6108),
    [sym_page_keyword] = ACTIONS(6106),
    [anon_sym_codeunit] = ACTIONS(6106),
    [anon_sym_CODEUNIT] = ACTIONS(6106),
    [anon_sym_Codeunit] = ACTIONS(6106),
    [anon_sym_CodeUnit] = ACTIONS(6106),
    [anon_sym_COdeunit] = ACTIONS(6106),
    [anon_sym_codeUnit] = ACTIONS(6106),
    [sym_report_keyword] = ACTIONS(6106),
    [sym_query_keyword] = ACTIONS(6106),
    [anon_sym_xmlport] = ACTIONS(6106),
    [anon_sym_XMLPORT] = ACTIONS(6106),
    [anon_sym_Xmlport] = ACTIONS(6106),
    [anon_sym_XMLport] = ACTIONS(6106),
    [anon_sym_XMLPort] = ACTIONS(6106),
    [anon_sym_XmlPort] = ACTIONS(6106),
    [anon_sym_enum] = ACTIONS(6106),
    [anon_sym_ENUM] = ACTIONS(6106),
    [anon_sym_Enum] = ACTIONS(6106),
    [anon_sym_eNUM] = ACTIONS(6106),
    [anon_sym_eNum] = ACTIONS(6106),
    [anon_sym_ENum] = ACTIONS(6106),
    [sym_quoted_identifier] = ACTIONS(6108),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6108),
    [sym_verbatim_string] = ACTIONS(6108),
    [sym_integer] = ACTIONS(6106),
    [sym_continue_as_identifier] = ACTIONS(6108),
    [sym_preproc_open] = ACTIONS(6108),
    [sym_preproc_close] = ACTIONS(6108),
  },
  [STATE(2552)] = {
    [sym_identifier] = ACTIONS(6110),
    [anon_sym_SEMI] = ACTIONS(6112),
    [anon_sym_DASH] = ACTIONS(6112),
    [aux_sym_boolean_token1] = ACTIONS(6110),
    [aux_sym_boolean_token2] = ACTIONS(6110),
    [sym_decimal] = ACTIONS(6110),
    [anon_sym_LPAREN] = ACTIONS(6112),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6110),
    [anon_sym_LBRACK] = ACTIONS(6112),
    [aux_sym_record_type_token1] = ACTIONS(6110),
    [aux_sym_basic_type_token21] = ACTIONS(6110),
    [aux_sym_basic_type_token22] = ACTIONS(6110),
    [aux_sym_basic_type_token48] = ACTIONS(6110),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6110),
    [anon_sym_POUNDif] = ACTIONS(6112),
    [anon_sym_POUNDIF] = ACTIONS(6112),
    [anon_sym_POUNDIf] = ACTIONS(6112),
    [anon_sym_not] = ACTIONS(6110),
    [anon_sym_NOT] = ACTIONS(6110),
    [anon_sym_Not] = ACTIONS(6110),
    [anon_sym_POUNDelif] = ACTIONS(6112),
    [anon_sym_POUNDELIF] = ACTIONS(6112),
    [anon_sym_POUNDElif] = ACTIONS(6112),
    [anon_sym_POUNDelse] = ACTIONS(6112),
    [anon_sym_POUNDELSE] = ACTIONS(6112),
    [anon_sym_POUNDElse] = ACTIONS(6112),
    [anon_sym_POUNDelse2] = ACTIONS(6112),
    [anon_sym_POUNDELSE2] = ACTIONS(6112),
    [anon_sym_POUNDElse2] = ACTIONS(6112),
    [anon_sym_POUNDendif] = ACTIONS(6112),
    [anon_sym_POUNDENDIF] = ACTIONS(6112),
    [anon_sym_POUNDEndif] = ACTIONS(6112),
    [anon_sym_POUNDendif2] = ACTIONS(6112),
    [anon_sym_POUNDENDIF2] = ACTIONS(6112),
    [anon_sym_POUNDEndif2] = ACTIONS(6112),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6110),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6110),
    [anon_sym_PLUS] = ACTIONS(6112),
    [sym_datetime_literal] = ACTIONS(6112),
    [sym_date_literal] = ACTIONS(6110),
    [sym_time_literal] = ACTIONS(6110),
    [sym_biginteger_literal] = ACTIONS(6112),
    [anon_sym_if] = ACTIONS(6110),
    [anon_sym_IF] = ACTIONS(6110),
    [anon_sym_If] = ACTIONS(6110),
    [anon_sym_else] = ACTIONS(6110),
    [anon_sym_ELSE] = ACTIONS(6110),
    [anon_sym_Else] = ACTIONS(6110),
    [anon_sym_case] = ACTIONS(6110),
    [anon_sym_CASE] = ACTIONS(6110),
    [anon_sym_Case] = ACTIONS(6110),
    [anon_sym_for] = ACTIONS(6110),
    [anon_sym_FOR] = ACTIONS(6110),
    [anon_sym_For] = ACTIONS(6110),
    [anon_sym_foreach] = ACTIONS(6110),
    [anon_sym_FOREACH] = ACTIONS(6110),
    [anon_sym_Foreach] = ACTIONS(6110),
    [anon_sym_while] = ACTIONS(6110),
    [anon_sym_WHILE] = ACTIONS(6110),
    [anon_sym_While] = ACTIONS(6110),
    [anon_sym_repeat] = ACTIONS(6110),
    [anon_sym_REPEAT] = ACTIONS(6110),
    [anon_sym_Repeat] = ACTIONS(6110),
    [anon_sym_exit] = ACTIONS(6110),
    [anon_sym_EXIT] = ACTIONS(6110),
    [anon_sym_Exit] = ACTIONS(6110),
    [anon_sym_continue] = ACTIONS(6110),
    [anon_sym_CONTINUE] = ACTIONS(6110),
    [anon_sym_Continue] = ACTIONS(6110),
    [anon_sym_break] = ACTIONS(6110),
    [anon_sym_BREAK] = ACTIONS(6110),
    [anon_sym_Break] = ACTIONS(6110),
    [anon_sym_with] = ACTIONS(6110),
    [anon_sym_WITH] = ACTIONS(6110),
    [anon_sym_With] = ACTIONS(6110),
    [sym_asserterror_keyword] = ACTIONS(6112),
    [sym_page_keyword] = ACTIONS(6110),
    [anon_sym_codeunit] = ACTIONS(6110),
    [anon_sym_CODEUNIT] = ACTIONS(6110),
    [anon_sym_Codeunit] = ACTIONS(6110),
    [anon_sym_CodeUnit] = ACTIONS(6110),
    [anon_sym_COdeunit] = ACTIONS(6110),
    [anon_sym_codeUnit] = ACTIONS(6110),
    [sym_report_keyword] = ACTIONS(6110),
    [sym_query_keyword] = ACTIONS(6110),
    [anon_sym_xmlport] = ACTIONS(6110),
    [anon_sym_XMLPORT] = ACTIONS(6110),
    [anon_sym_Xmlport] = ACTIONS(6110),
    [anon_sym_XMLport] = ACTIONS(6110),
    [anon_sym_XMLPort] = ACTIONS(6110),
    [anon_sym_XmlPort] = ACTIONS(6110),
    [anon_sym_enum] = ACTIONS(6110),
    [anon_sym_ENUM] = ACTIONS(6110),
    [anon_sym_Enum] = ACTIONS(6110),
    [anon_sym_eNUM] = ACTIONS(6110),
    [anon_sym_eNum] = ACTIONS(6110),
    [anon_sym_ENum] = ACTIONS(6110),
    [sym_quoted_identifier] = ACTIONS(6112),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6112),
    [sym_verbatim_string] = ACTIONS(6112),
    [sym_integer] = ACTIONS(6110),
    [sym_continue_as_identifier] = ACTIONS(6112),
    [sym_preproc_open] = ACTIONS(6112),
    [sym_preproc_close] = ACTIONS(6112),
  },
  [STATE(2553)] = {
    [sym_identifier] = ACTIONS(6114),
    [anon_sym_SEMI] = ACTIONS(6116),
    [anon_sym_DASH] = ACTIONS(6116),
    [aux_sym_boolean_token1] = ACTIONS(6114),
    [aux_sym_boolean_token2] = ACTIONS(6114),
    [sym_decimal] = ACTIONS(6114),
    [anon_sym_LPAREN] = ACTIONS(6116),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6114),
    [anon_sym_LBRACK] = ACTIONS(6116),
    [aux_sym_record_type_token1] = ACTIONS(6114),
    [aux_sym_basic_type_token21] = ACTIONS(6114),
    [aux_sym_basic_type_token22] = ACTIONS(6114),
    [aux_sym_basic_type_token48] = ACTIONS(6114),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6114),
    [anon_sym_POUNDif] = ACTIONS(6116),
    [anon_sym_POUNDIF] = ACTIONS(6116),
    [anon_sym_POUNDIf] = ACTIONS(6116),
    [anon_sym_not] = ACTIONS(6114),
    [anon_sym_NOT] = ACTIONS(6114),
    [anon_sym_Not] = ACTIONS(6114),
    [anon_sym_POUNDelif] = ACTIONS(6116),
    [anon_sym_POUNDELIF] = ACTIONS(6116),
    [anon_sym_POUNDElif] = ACTIONS(6116),
    [anon_sym_POUNDelse] = ACTIONS(6116),
    [anon_sym_POUNDELSE] = ACTIONS(6116),
    [anon_sym_POUNDElse] = ACTIONS(6116),
    [anon_sym_POUNDelse2] = ACTIONS(6116),
    [anon_sym_POUNDELSE2] = ACTIONS(6116),
    [anon_sym_POUNDElse2] = ACTIONS(6116),
    [anon_sym_POUNDendif] = ACTIONS(6116),
    [anon_sym_POUNDENDIF] = ACTIONS(6116),
    [anon_sym_POUNDEndif] = ACTIONS(6116),
    [anon_sym_POUNDendif2] = ACTIONS(6116),
    [anon_sym_POUNDENDIF2] = ACTIONS(6116),
    [anon_sym_POUNDEndif2] = ACTIONS(6116),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6114),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6114),
    [anon_sym_PLUS] = ACTIONS(6116),
    [sym_datetime_literal] = ACTIONS(6116),
    [sym_date_literal] = ACTIONS(6114),
    [sym_time_literal] = ACTIONS(6114),
    [sym_biginteger_literal] = ACTIONS(6116),
    [anon_sym_if] = ACTIONS(6114),
    [anon_sym_IF] = ACTIONS(6114),
    [anon_sym_If] = ACTIONS(6114),
    [anon_sym_else] = ACTIONS(6114),
    [anon_sym_ELSE] = ACTIONS(6114),
    [anon_sym_Else] = ACTIONS(6114),
    [anon_sym_case] = ACTIONS(6114),
    [anon_sym_CASE] = ACTIONS(6114),
    [anon_sym_Case] = ACTIONS(6114),
    [anon_sym_for] = ACTIONS(6114),
    [anon_sym_FOR] = ACTIONS(6114),
    [anon_sym_For] = ACTIONS(6114),
    [anon_sym_foreach] = ACTIONS(6114),
    [anon_sym_FOREACH] = ACTIONS(6114),
    [anon_sym_Foreach] = ACTIONS(6114),
    [anon_sym_while] = ACTIONS(6114),
    [anon_sym_WHILE] = ACTIONS(6114),
    [anon_sym_While] = ACTIONS(6114),
    [anon_sym_repeat] = ACTIONS(6114),
    [anon_sym_REPEAT] = ACTIONS(6114),
    [anon_sym_Repeat] = ACTIONS(6114),
    [anon_sym_exit] = ACTIONS(6114),
    [anon_sym_EXIT] = ACTIONS(6114),
    [anon_sym_Exit] = ACTIONS(6114),
    [anon_sym_continue] = ACTIONS(6114),
    [anon_sym_CONTINUE] = ACTIONS(6114),
    [anon_sym_Continue] = ACTIONS(6114),
    [anon_sym_break] = ACTIONS(6114),
    [anon_sym_BREAK] = ACTIONS(6114),
    [anon_sym_Break] = ACTIONS(6114),
    [anon_sym_with] = ACTIONS(6114),
    [anon_sym_WITH] = ACTIONS(6114),
    [anon_sym_With] = ACTIONS(6114),
    [sym_asserterror_keyword] = ACTIONS(6116),
    [sym_page_keyword] = ACTIONS(6114),
    [anon_sym_codeunit] = ACTIONS(6114),
    [anon_sym_CODEUNIT] = ACTIONS(6114),
    [anon_sym_Codeunit] = ACTIONS(6114),
    [anon_sym_CodeUnit] = ACTIONS(6114),
    [anon_sym_COdeunit] = ACTIONS(6114),
    [anon_sym_codeUnit] = ACTIONS(6114),
    [sym_report_keyword] = ACTIONS(6114),
    [sym_query_keyword] = ACTIONS(6114),
    [anon_sym_xmlport] = ACTIONS(6114),
    [anon_sym_XMLPORT] = ACTIONS(6114),
    [anon_sym_Xmlport] = ACTIONS(6114),
    [anon_sym_XMLport] = ACTIONS(6114),
    [anon_sym_XMLPort] = ACTIONS(6114),
    [anon_sym_XmlPort] = ACTIONS(6114),
    [anon_sym_enum] = ACTIONS(6114),
    [anon_sym_ENUM] = ACTIONS(6114),
    [anon_sym_Enum] = ACTIONS(6114),
    [anon_sym_eNUM] = ACTIONS(6114),
    [anon_sym_eNum] = ACTIONS(6114),
    [anon_sym_ENum] = ACTIONS(6114),
    [sym_quoted_identifier] = ACTIONS(6116),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6116),
    [sym_verbatim_string] = ACTIONS(6116),
    [sym_integer] = ACTIONS(6114),
    [sym_continue_as_identifier] = ACTIONS(6116),
    [sym_preproc_open] = ACTIONS(6116),
    [sym_preproc_close] = ACTIONS(6116),
  },
  [STATE(2554)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(6120),
    [anon_sym_DASH] = ACTIONS(6122),
    [aux_sym_boolean_token1] = ACTIONS(6118),
    [aux_sym_boolean_token2] = ACTIONS(6118),
    [sym_decimal] = ACTIONS(6118),
    [anon_sym_LPAREN] = ACTIONS(6122),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_record_type_token1] = ACTIONS(6118),
    [aux_sym_basic_type_token21] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token48] = ACTIONS(6118),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_not] = ACTIONS(6118),
    [anon_sym_NOT] = ACTIONS(6118),
    [anon_sym_Not] = ACTIONS(6118),
    [anon_sym_POUNDelif] = ACTIONS(6122),
    [anon_sym_POUNDELIF] = ACTIONS(6122),
    [anon_sym_POUNDElif] = ACTIONS(6122),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [anon_sym_POUNDendif] = ACTIONS(6122),
    [anon_sym_POUNDENDIF] = ACTIONS(6122),
    [anon_sym_POUNDEndif] = ACTIONS(6122),
    [anon_sym_POUNDendif2] = ACTIONS(6122),
    [anon_sym_POUNDENDIF2] = ACTIONS(6122),
    [anon_sym_POUNDEndif2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6118),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6118),
    [anon_sym_PLUS] = ACTIONS(6122),
    [sym_datetime_literal] = ACTIONS(6122),
    [sym_date_literal] = ACTIONS(6118),
    [sym_time_literal] = ACTIONS(6118),
    [sym_biginteger_literal] = ACTIONS(6122),
    [anon_sym_if] = ACTIONS(6118),
    [anon_sym_IF] = ACTIONS(6118),
    [anon_sym_If] = ACTIONS(6118),
    [anon_sym_else] = ACTIONS(6118),
    [anon_sym_ELSE] = ACTIONS(6118),
    [anon_sym_Else] = ACTIONS(6118),
    [anon_sym_case] = ACTIONS(6118),
    [anon_sym_CASE] = ACTIONS(6118),
    [anon_sym_Case] = ACTIONS(6118),
    [anon_sym_for] = ACTIONS(6118),
    [anon_sym_FOR] = ACTIONS(6118),
    [anon_sym_For] = ACTIONS(6118),
    [anon_sym_foreach] = ACTIONS(6118),
    [anon_sym_FOREACH] = ACTIONS(6118),
    [anon_sym_Foreach] = ACTIONS(6118),
    [anon_sym_while] = ACTIONS(6118),
    [anon_sym_WHILE] = ACTIONS(6118),
    [anon_sym_While] = ACTIONS(6118),
    [anon_sym_repeat] = ACTIONS(6118),
    [anon_sym_REPEAT] = ACTIONS(6118),
    [anon_sym_Repeat] = ACTIONS(6118),
    [anon_sym_exit] = ACTIONS(6118),
    [anon_sym_EXIT] = ACTIONS(6118),
    [anon_sym_Exit] = ACTIONS(6118),
    [anon_sym_continue] = ACTIONS(6118),
    [anon_sym_CONTINUE] = ACTIONS(6118),
    [anon_sym_Continue] = ACTIONS(6118),
    [anon_sym_break] = ACTIONS(6118),
    [anon_sym_BREAK] = ACTIONS(6118),
    [anon_sym_Break] = ACTIONS(6118),
    [anon_sym_with] = ACTIONS(6118),
    [anon_sym_WITH] = ACTIONS(6118),
    [anon_sym_With] = ACTIONS(6118),
    [sym_asserterror_keyword] = ACTIONS(6122),
    [sym_page_keyword] = ACTIONS(6118),
    [anon_sym_codeunit] = ACTIONS(6118),
    [anon_sym_CODEUNIT] = ACTIONS(6118),
    [anon_sym_Codeunit] = ACTIONS(6118),
    [anon_sym_CodeUnit] = ACTIONS(6118),
    [anon_sym_COdeunit] = ACTIONS(6118),
    [anon_sym_codeUnit] = ACTIONS(6118),
    [sym_report_keyword] = ACTIONS(6118),
    [sym_query_keyword] = ACTIONS(6118),
    [anon_sym_xmlport] = ACTIONS(6118),
    [anon_sym_XMLPORT] = ACTIONS(6118),
    [anon_sym_Xmlport] = ACTIONS(6118),
    [anon_sym_XMLport] = ACTIONS(6118),
    [anon_sym_XMLPort] = ACTIONS(6118),
    [anon_sym_XmlPort] = ACTIONS(6118),
    [anon_sym_enum] = ACTIONS(6118),
    [anon_sym_ENUM] = ACTIONS(6118),
    [anon_sym_Enum] = ACTIONS(6118),
    [anon_sym_eNUM] = ACTIONS(6118),
    [anon_sym_eNum] = ACTIONS(6118),
    [anon_sym_ENum] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6122),
    [sym_verbatim_string] = ACTIONS(6122),
    [sym_integer] = ACTIONS(6118),
    [sym_continue_as_identifier] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_preproc_close] = ACTIONS(6122),
  },
  [STATE(2555)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(6122),
    [anon_sym_DASH] = ACTIONS(6122),
    [aux_sym_boolean_token1] = ACTIONS(6118),
    [aux_sym_boolean_token2] = ACTIONS(6118),
    [sym_decimal] = ACTIONS(6118),
    [anon_sym_LPAREN] = ACTIONS(6122),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_record_type_token1] = ACTIONS(6118),
    [aux_sym_basic_type_token21] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token48] = ACTIONS(6118),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_not] = ACTIONS(6118),
    [anon_sym_NOT] = ACTIONS(6118),
    [anon_sym_Not] = ACTIONS(6118),
    [anon_sym_POUNDelif] = ACTIONS(6122),
    [anon_sym_POUNDELIF] = ACTIONS(6122),
    [anon_sym_POUNDElif] = ACTIONS(6122),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [anon_sym_POUNDendif] = ACTIONS(6122),
    [anon_sym_POUNDENDIF] = ACTIONS(6122),
    [anon_sym_POUNDEndif] = ACTIONS(6122),
    [anon_sym_POUNDendif2] = ACTIONS(6122),
    [anon_sym_POUNDENDIF2] = ACTIONS(6122),
    [anon_sym_POUNDEndif2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6118),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6118),
    [anon_sym_PLUS] = ACTIONS(6122),
    [sym_datetime_literal] = ACTIONS(6122),
    [sym_date_literal] = ACTIONS(6118),
    [sym_time_literal] = ACTIONS(6118),
    [sym_biginteger_literal] = ACTIONS(6122),
    [anon_sym_if] = ACTIONS(6118),
    [anon_sym_IF] = ACTIONS(6118),
    [anon_sym_If] = ACTIONS(6118),
    [anon_sym_else] = ACTIONS(6118),
    [anon_sym_ELSE] = ACTIONS(6118),
    [anon_sym_Else] = ACTIONS(6118),
    [anon_sym_case] = ACTIONS(6118),
    [anon_sym_CASE] = ACTIONS(6118),
    [anon_sym_Case] = ACTIONS(6118),
    [anon_sym_for] = ACTIONS(6118),
    [anon_sym_FOR] = ACTIONS(6118),
    [anon_sym_For] = ACTIONS(6118),
    [anon_sym_foreach] = ACTIONS(6118),
    [anon_sym_FOREACH] = ACTIONS(6118),
    [anon_sym_Foreach] = ACTIONS(6118),
    [anon_sym_while] = ACTIONS(6118),
    [anon_sym_WHILE] = ACTIONS(6118),
    [anon_sym_While] = ACTIONS(6118),
    [anon_sym_repeat] = ACTIONS(6118),
    [anon_sym_REPEAT] = ACTIONS(6118),
    [anon_sym_Repeat] = ACTIONS(6118),
    [anon_sym_exit] = ACTIONS(6118),
    [anon_sym_EXIT] = ACTIONS(6118),
    [anon_sym_Exit] = ACTIONS(6118),
    [anon_sym_continue] = ACTIONS(6118),
    [anon_sym_CONTINUE] = ACTIONS(6118),
    [anon_sym_Continue] = ACTIONS(6118),
    [anon_sym_break] = ACTIONS(6118),
    [anon_sym_BREAK] = ACTIONS(6118),
    [anon_sym_Break] = ACTIONS(6118),
    [anon_sym_with] = ACTIONS(6118),
    [anon_sym_WITH] = ACTIONS(6118),
    [anon_sym_With] = ACTIONS(6118),
    [sym_asserterror_keyword] = ACTIONS(6122),
    [sym_page_keyword] = ACTIONS(6118),
    [anon_sym_codeunit] = ACTIONS(6118),
    [anon_sym_CODEUNIT] = ACTIONS(6118),
    [anon_sym_Codeunit] = ACTIONS(6118),
    [anon_sym_CodeUnit] = ACTIONS(6118),
    [anon_sym_COdeunit] = ACTIONS(6118),
    [anon_sym_codeUnit] = ACTIONS(6118),
    [sym_report_keyword] = ACTIONS(6118),
    [sym_query_keyword] = ACTIONS(6118),
    [anon_sym_xmlport] = ACTIONS(6118),
    [anon_sym_XMLPORT] = ACTIONS(6118),
    [anon_sym_Xmlport] = ACTIONS(6118),
    [anon_sym_XMLport] = ACTIONS(6118),
    [anon_sym_XMLPort] = ACTIONS(6118),
    [anon_sym_XmlPort] = ACTIONS(6118),
    [anon_sym_enum] = ACTIONS(6118),
    [anon_sym_ENUM] = ACTIONS(6118),
    [anon_sym_Enum] = ACTIONS(6118),
    [anon_sym_eNUM] = ACTIONS(6118),
    [anon_sym_eNum] = ACTIONS(6118),
    [anon_sym_ENum] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6122),
    [sym_verbatim_string] = ACTIONS(6122),
    [sym_integer] = ACTIONS(6118),
    [sym_continue_as_identifier] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_preproc_close] = ACTIONS(6122),
  },
  [STATE(2556)] = {
    [sym_identifier] = ACTIONS(6124),
    [anon_sym_SEMI] = ACTIONS(6126),
    [anon_sym_DASH] = ACTIONS(6126),
    [aux_sym_boolean_token1] = ACTIONS(6124),
    [aux_sym_boolean_token2] = ACTIONS(6124),
    [sym_decimal] = ACTIONS(6124),
    [anon_sym_LPAREN] = ACTIONS(6126),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6124),
    [anon_sym_LBRACK] = ACTIONS(6126),
    [aux_sym_record_type_token1] = ACTIONS(6124),
    [aux_sym_basic_type_token21] = ACTIONS(6124),
    [aux_sym_basic_type_token22] = ACTIONS(6124),
    [aux_sym_basic_type_token48] = ACTIONS(6124),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6124),
    [anon_sym_POUNDif] = ACTIONS(6126),
    [anon_sym_POUNDIF] = ACTIONS(6126),
    [anon_sym_POUNDIf] = ACTIONS(6126),
    [anon_sym_not] = ACTIONS(6124),
    [anon_sym_NOT] = ACTIONS(6124),
    [anon_sym_Not] = ACTIONS(6124),
    [anon_sym_POUNDelif] = ACTIONS(6126),
    [anon_sym_POUNDELIF] = ACTIONS(6126),
    [anon_sym_POUNDElif] = ACTIONS(6126),
    [anon_sym_POUNDelse] = ACTIONS(6126),
    [anon_sym_POUNDELSE] = ACTIONS(6126),
    [anon_sym_POUNDElse] = ACTIONS(6126),
    [anon_sym_POUNDelse2] = ACTIONS(6126),
    [anon_sym_POUNDELSE2] = ACTIONS(6126),
    [anon_sym_POUNDElse2] = ACTIONS(6126),
    [anon_sym_POUNDendif] = ACTIONS(6126),
    [anon_sym_POUNDENDIF] = ACTIONS(6126),
    [anon_sym_POUNDEndif] = ACTIONS(6126),
    [anon_sym_POUNDendif2] = ACTIONS(6126),
    [anon_sym_POUNDENDIF2] = ACTIONS(6126),
    [anon_sym_POUNDEndif2] = ACTIONS(6126),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6124),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6124),
    [anon_sym_PLUS] = ACTIONS(6126),
    [sym_datetime_literal] = ACTIONS(6126),
    [sym_date_literal] = ACTIONS(6124),
    [sym_time_literal] = ACTIONS(6124),
    [sym_biginteger_literal] = ACTIONS(6126),
    [anon_sym_if] = ACTIONS(6124),
    [anon_sym_IF] = ACTIONS(6124),
    [anon_sym_If] = ACTIONS(6124),
    [anon_sym_else] = ACTIONS(6124),
    [anon_sym_ELSE] = ACTIONS(6124),
    [anon_sym_Else] = ACTIONS(6124),
    [anon_sym_case] = ACTIONS(6124),
    [anon_sym_CASE] = ACTIONS(6124),
    [anon_sym_Case] = ACTIONS(6124),
    [anon_sym_for] = ACTIONS(6124),
    [anon_sym_FOR] = ACTIONS(6124),
    [anon_sym_For] = ACTIONS(6124),
    [anon_sym_foreach] = ACTIONS(6124),
    [anon_sym_FOREACH] = ACTIONS(6124),
    [anon_sym_Foreach] = ACTIONS(6124),
    [anon_sym_while] = ACTIONS(6124),
    [anon_sym_WHILE] = ACTIONS(6124),
    [anon_sym_While] = ACTIONS(6124),
    [anon_sym_repeat] = ACTIONS(6124),
    [anon_sym_REPEAT] = ACTIONS(6124),
    [anon_sym_Repeat] = ACTIONS(6124),
    [anon_sym_exit] = ACTIONS(6124),
    [anon_sym_EXIT] = ACTIONS(6124),
    [anon_sym_Exit] = ACTIONS(6124),
    [anon_sym_continue] = ACTIONS(6124),
    [anon_sym_CONTINUE] = ACTIONS(6124),
    [anon_sym_Continue] = ACTIONS(6124),
    [anon_sym_break] = ACTIONS(6124),
    [anon_sym_BREAK] = ACTIONS(6124),
    [anon_sym_Break] = ACTIONS(6124),
    [anon_sym_with] = ACTIONS(6124),
    [anon_sym_WITH] = ACTIONS(6124),
    [anon_sym_With] = ACTIONS(6124),
    [sym_asserterror_keyword] = ACTIONS(6126),
    [sym_page_keyword] = ACTIONS(6124),
    [anon_sym_codeunit] = ACTIONS(6124),
    [anon_sym_CODEUNIT] = ACTIONS(6124),
    [anon_sym_Codeunit] = ACTIONS(6124),
    [anon_sym_CodeUnit] = ACTIONS(6124),
    [anon_sym_COdeunit] = ACTIONS(6124),
    [anon_sym_codeUnit] = ACTIONS(6124),
    [sym_report_keyword] = ACTIONS(6124),
    [sym_query_keyword] = ACTIONS(6124),
    [anon_sym_xmlport] = ACTIONS(6124),
    [anon_sym_XMLPORT] = ACTIONS(6124),
    [anon_sym_Xmlport] = ACTIONS(6124),
    [anon_sym_XMLport] = ACTIONS(6124),
    [anon_sym_XMLPort] = ACTIONS(6124),
    [anon_sym_XmlPort] = ACTIONS(6124),
    [anon_sym_enum] = ACTIONS(6124),
    [anon_sym_ENUM] = ACTIONS(6124),
    [anon_sym_Enum] = ACTIONS(6124),
    [anon_sym_eNUM] = ACTIONS(6124),
    [anon_sym_eNum] = ACTIONS(6124),
    [anon_sym_ENum] = ACTIONS(6124),
    [sym_quoted_identifier] = ACTIONS(6126),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6126),
    [sym_verbatim_string] = ACTIONS(6126),
    [sym_integer] = ACTIONS(6124),
    [sym_continue_as_identifier] = ACTIONS(6126),
    [sym_preproc_open] = ACTIONS(6126),
    [sym_preproc_close] = ACTIONS(6126),
  },
  [STATE(2557)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(6128),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(2558)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(6130),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(2559)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5965),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(2560)] = {
    [sym_identifier] = ACTIONS(6132),
    [anon_sym_SEMI] = ACTIONS(6134),
    [anon_sym_DASH] = ACTIONS(6134),
    [aux_sym_boolean_token1] = ACTIONS(6132),
    [aux_sym_boolean_token2] = ACTIONS(6132),
    [sym_decimal] = ACTIONS(6132),
    [anon_sym_LPAREN] = ACTIONS(6134),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6132),
    [anon_sym_LBRACK] = ACTIONS(6134),
    [aux_sym_record_type_token1] = ACTIONS(6132),
    [aux_sym_basic_type_token21] = ACTIONS(6132),
    [aux_sym_basic_type_token22] = ACTIONS(6132),
    [aux_sym_basic_type_token48] = ACTIONS(6132),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6132),
    [anon_sym_POUNDif] = ACTIONS(6134),
    [anon_sym_POUNDIF] = ACTIONS(6134),
    [anon_sym_POUNDIf] = ACTIONS(6134),
    [anon_sym_not] = ACTIONS(6132),
    [anon_sym_NOT] = ACTIONS(6132),
    [anon_sym_Not] = ACTIONS(6132),
    [anon_sym_POUNDelif] = ACTIONS(6134),
    [anon_sym_POUNDELIF] = ACTIONS(6134),
    [anon_sym_POUNDElif] = ACTIONS(6134),
    [anon_sym_POUNDelse] = ACTIONS(6134),
    [anon_sym_POUNDELSE] = ACTIONS(6134),
    [anon_sym_POUNDElse] = ACTIONS(6134),
    [anon_sym_POUNDelse2] = ACTIONS(6134),
    [anon_sym_POUNDELSE2] = ACTIONS(6134),
    [anon_sym_POUNDElse2] = ACTIONS(6134),
    [anon_sym_POUNDendif] = ACTIONS(6134),
    [anon_sym_POUNDENDIF] = ACTIONS(6134),
    [anon_sym_POUNDEndif] = ACTIONS(6134),
    [anon_sym_POUNDendif2] = ACTIONS(6134),
    [anon_sym_POUNDENDIF2] = ACTIONS(6134),
    [anon_sym_POUNDEndif2] = ACTIONS(6134),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6132),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6132),
    [anon_sym_PLUS] = ACTIONS(6134),
    [sym_datetime_literal] = ACTIONS(6134),
    [sym_date_literal] = ACTIONS(6132),
    [sym_time_literal] = ACTIONS(6132),
    [sym_biginteger_literal] = ACTIONS(6134),
    [anon_sym_if] = ACTIONS(6132),
    [anon_sym_IF] = ACTIONS(6132),
    [anon_sym_If] = ACTIONS(6132),
    [anon_sym_else] = ACTIONS(6132),
    [anon_sym_ELSE] = ACTIONS(6132),
    [anon_sym_Else] = ACTIONS(6132),
    [anon_sym_case] = ACTIONS(6132),
    [anon_sym_CASE] = ACTIONS(6132),
    [anon_sym_Case] = ACTIONS(6132),
    [anon_sym_for] = ACTIONS(6132),
    [anon_sym_FOR] = ACTIONS(6132),
    [anon_sym_For] = ACTIONS(6132),
    [anon_sym_foreach] = ACTIONS(6132),
    [anon_sym_FOREACH] = ACTIONS(6132),
    [anon_sym_Foreach] = ACTIONS(6132),
    [anon_sym_while] = ACTIONS(6132),
    [anon_sym_WHILE] = ACTIONS(6132),
    [anon_sym_While] = ACTIONS(6132),
    [anon_sym_repeat] = ACTIONS(6132),
    [anon_sym_REPEAT] = ACTIONS(6132),
    [anon_sym_Repeat] = ACTIONS(6132),
    [anon_sym_exit] = ACTIONS(6132),
    [anon_sym_EXIT] = ACTIONS(6132),
    [anon_sym_Exit] = ACTIONS(6132),
    [anon_sym_continue] = ACTIONS(6132),
    [anon_sym_CONTINUE] = ACTIONS(6132),
    [anon_sym_Continue] = ACTIONS(6132),
    [anon_sym_break] = ACTIONS(6132),
    [anon_sym_BREAK] = ACTIONS(6132),
    [anon_sym_Break] = ACTIONS(6132),
    [anon_sym_with] = ACTIONS(6132),
    [anon_sym_WITH] = ACTIONS(6132),
    [anon_sym_With] = ACTIONS(6132),
    [sym_asserterror_keyword] = ACTIONS(6134),
    [sym_page_keyword] = ACTIONS(6132),
    [anon_sym_codeunit] = ACTIONS(6132),
    [anon_sym_CODEUNIT] = ACTIONS(6132),
    [anon_sym_Codeunit] = ACTIONS(6132),
    [anon_sym_CodeUnit] = ACTIONS(6132),
    [anon_sym_COdeunit] = ACTIONS(6132),
    [anon_sym_codeUnit] = ACTIONS(6132),
    [sym_report_keyword] = ACTIONS(6132),
    [sym_query_keyword] = ACTIONS(6132),
    [anon_sym_xmlport] = ACTIONS(6132),
    [anon_sym_XMLPORT] = ACTIONS(6132),
    [anon_sym_Xmlport] = ACTIONS(6132),
    [anon_sym_XMLport] = ACTIONS(6132),
    [anon_sym_XMLPort] = ACTIONS(6132),
    [anon_sym_XmlPort] = ACTIONS(6132),
    [anon_sym_enum] = ACTIONS(6132),
    [anon_sym_ENUM] = ACTIONS(6132),
    [anon_sym_Enum] = ACTIONS(6132),
    [anon_sym_eNUM] = ACTIONS(6132),
    [anon_sym_eNum] = ACTIONS(6132),
    [anon_sym_ENum] = ACTIONS(6132),
    [sym_quoted_identifier] = ACTIONS(6134),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6134),
    [sym_verbatim_string] = ACTIONS(6134),
    [sym_integer] = ACTIONS(6132),
    [sym_continue_as_identifier] = ACTIONS(6134),
    [sym_preproc_open] = ACTIONS(6134),
    [sym_preproc_close] = ACTIONS(6134),
  },
  [STATE(2561)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_DASH] = ACTIONS(5937),
    [aux_sym_boolean_token1] = ACTIONS(5935),
    [aux_sym_boolean_token2] = ACTIONS(5935),
    [sym_decimal] = ACTIONS(5935),
    [anon_sym_LPAREN] = ACTIONS(5937),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_record_type_token1] = ACTIONS(5935),
    [aux_sym_basic_type_token21] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token48] = ACTIONS(5935),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_not] = ACTIONS(5935),
    [anon_sym_NOT] = ACTIONS(5935),
    [anon_sym_Not] = ACTIONS(5935),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5935),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5935),
    [anon_sym_PLUS] = ACTIONS(5937),
    [sym_datetime_literal] = ACTIONS(5937),
    [sym_date_literal] = ACTIONS(5935),
    [sym_time_literal] = ACTIONS(5935),
    [sym_biginteger_literal] = ACTIONS(5937),
    [anon_sym_if] = ACTIONS(5935),
    [anon_sym_IF] = ACTIONS(5935),
    [anon_sym_If] = ACTIONS(5935),
    [anon_sym_else] = ACTIONS(5935),
    [anon_sym_ELSE] = ACTIONS(5935),
    [anon_sym_Else] = ACTIONS(5935),
    [anon_sym_case] = ACTIONS(5935),
    [anon_sym_CASE] = ACTIONS(5935),
    [anon_sym_Case] = ACTIONS(5935),
    [anon_sym_for] = ACTIONS(5935),
    [anon_sym_FOR] = ACTIONS(5935),
    [anon_sym_For] = ACTIONS(5935),
    [anon_sym_foreach] = ACTIONS(5935),
    [anon_sym_FOREACH] = ACTIONS(5935),
    [anon_sym_Foreach] = ACTIONS(5935),
    [anon_sym_while] = ACTIONS(5935),
    [anon_sym_WHILE] = ACTIONS(5935),
    [anon_sym_While] = ACTIONS(5935),
    [anon_sym_repeat] = ACTIONS(5935),
    [anon_sym_REPEAT] = ACTIONS(5935),
    [anon_sym_Repeat] = ACTIONS(5935),
    [anon_sym_exit] = ACTIONS(5935),
    [anon_sym_EXIT] = ACTIONS(5935),
    [anon_sym_Exit] = ACTIONS(5935),
    [anon_sym_continue] = ACTIONS(5935),
    [anon_sym_CONTINUE] = ACTIONS(5935),
    [anon_sym_Continue] = ACTIONS(5935),
    [anon_sym_break] = ACTIONS(5935),
    [anon_sym_BREAK] = ACTIONS(5935),
    [anon_sym_Break] = ACTIONS(5935),
    [anon_sym_with] = ACTIONS(5935),
    [anon_sym_WITH] = ACTIONS(5935),
    [anon_sym_With] = ACTIONS(5935),
    [sym_asserterror_keyword] = ACTIONS(5937),
    [sym_page_keyword] = ACTIONS(5935),
    [anon_sym_codeunit] = ACTIONS(5935),
    [anon_sym_CODEUNIT] = ACTIONS(5935),
    [anon_sym_Codeunit] = ACTIONS(5935),
    [anon_sym_CodeUnit] = ACTIONS(5935),
    [anon_sym_COdeunit] = ACTIONS(5935),
    [anon_sym_codeUnit] = ACTIONS(5935),
    [sym_report_keyword] = ACTIONS(5935),
    [sym_query_keyword] = ACTIONS(5935),
    [anon_sym_xmlport] = ACTIONS(5935),
    [anon_sym_XMLPORT] = ACTIONS(5935),
    [anon_sym_Xmlport] = ACTIONS(5935),
    [anon_sym_XMLport] = ACTIONS(5935),
    [anon_sym_XMLPort] = ACTIONS(5935),
    [anon_sym_XmlPort] = ACTIONS(5935),
    [anon_sym_enum] = ACTIONS(5935),
    [anon_sym_ENUM] = ACTIONS(5935),
    [anon_sym_Enum] = ACTIONS(5935),
    [anon_sym_eNUM] = ACTIONS(5935),
    [anon_sym_eNum] = ACTIONS(5935),
    [anon_sym_ENum] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5937),
    [sym_verbatim_string] = ACTIONS(5937),
    [sym_integer] = ACTIONS(5935),
    [sym_continue_as_identifier] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
  },
  [STATE(2562)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_DASH] = ACTIONS(5937),
    [aux_sym_boolean_token1] = ACTIONS(5935),
    [aux_sym_boolean_token2] = ACTIONS(5935),
    [sym_decimal] = ACTIONS(5935),
    [anon_sym_LPAREN] = ACTIONS(5937),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_record_type_token1] = ACTIONS(5935),
    [aux_sym_basic_type_token21] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token48] = ACTIONS(5935),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_not] = ACTIONS(5935),
    [anon_sym_NOT] = ACTIONS(5935),
    [anon_sym_Not] = ACTIONS(5935),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5935),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5935),
    [anon_sym_PLUS] = ACTIONS(5937),
    [sym_datetime_literal] = ACTIONS(5937),
    [sym_date_literal] = ACTIONS(5935),
    [sym_time_literal] = ACTIONS(5935),
    [sym_biginteger_literal] = ACTIONS(5937),
    [anon_sym_if] = ACTIONS(5935),
    [anon_sym_IF] = ACTIONS(5935),
    [anon_sym_If] = ACTIONS(5935),
    [anon_sym_else] = ACTIONS(5935),
    [anon_sym_ELSE] = ACTIONS(5935),
    [anon_sym_Else] = ACTIONS(5935),
    [anon_sym_case] = ACTIONS(5935),
    [anon_sym_CASE] = ACTIONS(5935),
    [anon_sym_Case] = ACTIONS(5935),
    [anon_sym_for] = ACTIONS(5935),
    [anon_sym_FOR] = ACTIONS(5935),
    [anon_sym_For] = ACTIONS(5935),
    [anon_sym_foreach] = ACTIONS(5935),
    [anon_sym_FOREACH] = ACTIONS(5935),
    [anon_sym_Foreach] = ACTIONS(5935),
    [anon_sym_while] = ACTIONS(5935),
    [anon_sym_WHILE] = ACTIONS(5935),
    [anon_sym_While] = ACTIONS(5935),
    [anon_sym_repeat] = ACTIONS(5935),
    [anon_sym_REPEAT] = ACTIONS(5935),
    [anon_sym_Repeat] = ACTIONS(5935),
    [anon_sym_exit] = ACTIONS(5935),
    [anon_sym_EXIT] = ACTIONS(5935),
    [anon_sym_Exit] = ACTIONS(5935),
    [anon_sym_continue] = ACTIONS(5935),
    [anon_sym_CONTINUE] = ACTIONS(5935),
    [anon_sym_Continue] = ACTIONS(5935),
    [anon_sym_break] = ACTIONS(5935),
    [anon_sym_BREAK] = ACTIONS(5935),
    [anon_sym_Break] = ACTIONS(5935),
    [anon_sym_with] = ACTIONS(5935),
    [anon_sym_WITH] = ACTIONS(5935),
    [anon_sym_With] = ACTIONS(5935),
    [sym_asserterror_keyword] = ACTIONS(5937),
    [sym_page_keyword] = ACTIONS(5935),
    [anon_sym_codeunit] = ACTIONS(5935),
    [anon_sym_CODEUNIT] = ACTIONS(5935),
    [anon_sym_Codeunit] = ACTIONS(5935),
    [anon_sym_CodeUnit] = ACTIONS(5935),
    [anon_sym_COdeunit] = ACTIONS(5935),
    [anon_sym_codeUnit] = ACTIONS(5935),
    [sym_report_keyword] = ACTIONS(5935),
    [sym_query_keyword] = ACTIONS(5935),
    [anon_sym_xmlport] = ACTIONS(5935),
    [anon_sym_XMLPORT] = ACTIONS(5935),
    [anon_sym_Xmlport] = ACTIONS(5935),
    [anon_sym_XMLport] = ACTIONS(5935),
    [anon_sym_XMLPort] = ACTIONS(5935),
    [anon_sym_XmlPort] = ACTIONS(5935),
    [anon_sym_enum] = ACTIONS(5935),
    [anon_sym_ENUM] = ACTIONS(5935),
    [anon_sym_Enum] = ACTIONS(5935),
    [anon_sym_eNUM] = ACTIONS(5935),
    [anon_sym_eNum] = ACTIONS(5935),
    [anon_sym_ENum] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5937),
    [sym_verbatim_string] = ACTIONS(5937),
    [sym_integer] = ACTIONS(5935),
    [sym_continue_as_identifier] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
  },
  [STATE(2563)] = {
    [sym_identifier] = ACTIONS(6136),
    [anon_sym_SEMI] = ACTIONS(6138),
    [anon_sym_DASH] = ACTIONS(6138),
    [aux_sym_boolean_token1] = ACTIONS(6136),
    [aux_sym_boolean_token2] = ACTIONS(6136),
    [sym_decimal] = ACTIONS(6136),
    [anon_sym_LPAREN] = ACTIONS(6138),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6136),
    [anon_sym_LBRACK] = ACTIONS(6138),
    [aux_sym_record_type_token1] = ACTIONS(6136),
    [aux_sym_basic_type_token21] = ACTIONS(6136),
    [aux_sym_basic_type_token22] = ACTIONS(6136),
    [aux_sym_basic_type_token48] = ACTIONS(6136),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6136),
    [anon_sym_POUNDif] = ACTIONS(6138),
    [anon_sym_POUNDIF] = ACTIONS(6138),
    [anon_sym_POUNDIf] = ACTIONS(6138),
    [anon_sym_not] = ACTIONS(6136),
    [anon_sym_NOT] = ACTIONS(6136),
    [anon_sym_Not] = ACTIONS(6136),
    [anon_sym_POUNDelif] = ACTIONS(6138),
    [anon_sym_POUNDELIF] = ACTIONS(6138),
    [anon_sym_POUNDElif] = ACTIONS(6138),
    [anon_sym_POUNDelse] = ACTIONS(6138),
    [anon_sym_POUNDELSE] = ACTIONS(6138),
    [anon_sym_POUNDElse] = ACTIONS(6138),
    [anon_sym_POUNDelse2] = ACTIONS(6138),
    [anon_sym_POUNDELSE2] = ACTIONS(6138),
    [anon_sym_POUNDElse2] = ACTIONS(6138),
    [anon_sym_POUNDendif] = ACTIONS(6138),
    [anon_sym_POUNDENDIF] = ACTIONS(6138),
    [anon_sym_POUNDEndif] = ACTIONS(6138),
    [anon_sym_POUNDendif2] = ACTIONS(6138),
    [anon_sym_POUNDENDIF2] = ACTIONS(6138),
    [anon_sym_POUNDEndif2] = ACTIONS(6138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6136),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6136),
    [anon_sym_PLUS] = ACTIONS(6138),
    [sym_datetime_literal] = ACTIONS(6138),
    [sym_date_literal] = ACTIONS(6136),
    [sym_time_literal] = ACTIONS(6136),
    [sym_biginteger_literal] = ACTIONS(6138),
    [anon_sym_if] = ACTIONS(6136),
    [anon_sym_IF] = ACTIONS(6136),
    [anon_sym_If] = ACTIONS(6136),
    [anon_sym_else] = ACTIONS(6136),
    [anon_sym_ELSE] = ACTIONS(6136),
    [anon_sym_Else] = ACTIONS(6136),
    [anon_sym_case] = ACTIONS(6136),
    [anon_sym_CASE] = ACTIONS(6136),
    [anon_sym_Case] = ACTIONS(6136),
    [anon_sym_for] = ACTIONS(6136),
    [anon_sym_FOR] = ACTIONS(6136),
    [anon_sym_For] = ACTIONS(6136),
    [anon_sym_foreach] = ACTIONS(6136),
    [anon_sym_FOREACH] = ACTIONS(6136),
    [anon_sym_Foreach] = ACTIONS(6136),
    [anon_sym_while] = ACTIONS(6136),
    [anon_sym_WHILE] = ACTIONS(6136),
    [anon_sym_While] = ACTIONS(6136),
    [anon_sym_repeat] = ACTIONS(6136),
    [anon_sym_REPEAT] = ACTIONS(6136),
    [anon_sym_Repeat] = ACTIONS(6136),
    [anon_sym_exit] = ACTIONS(6136),
    [anon_sym_EXIT] = ACTIONS(6136),
    [anon_sym_Exit] = ACTIONS(6136),
    [anon_sym_continue] = ACTIONS(6136),
    [anon_sym_CONTINUE] = ACTIONS(6136),
    [anon_sym_Continue] = ACTIONS(6136),
    [anon_sym_break] = ACTIONS(6136),
    [anon_sym_BREAK] = ACTIONS(6136),
    [anon_sym_Break] = ACTIONS(6136),
    [anon_sym_with] = ACTIONS(6136),
    [anon_sym_WITH] = ACTIONS(6136),
    [anon_sym_With] = ACTIONS(6136),
    [sym_asserterror_keyword] = ACTIONS(6138),
    [sym_page_keyword] = ACTIONS(6136),
    [anon_sym_codeunit] = ACTIONS(6136),
    [anon_sym_CODEUNIT] = ACTIONS(6136),
    [anon_sym_Codeunit] = ACTIONS(6136),
    [anon_sym_CodeUnit] = ACTIONS(6136),
    [anon_sym_COdeunit] = ACTIONS(6136),
    [anon_sym_codeUnit] = ACTIONS(6136),
    [sym_report_keyword] = ACTIONS(6136),
    [sym_query_keyword] = ACTIONS(6136),
    [anon_sym_xmlport] = ACTIONS(6136),
    [anon_sym_XMLPORT] = ACTIONS(6136),
    [anon_sym_Xmlport] = ACTIONS(6136),
    [anon_sym_XMLport] = ACTIONS(6136),
    [anon_sym_XMLPort] = ACTIONS(6136),
    [anon_sym_XmlPort] = ACTIONS(6136),
    [anon_sym_enum] = ACTIONS(6136),
    [anon_sym_ENUM] = ACTIONS(6136),
    [anon_sym_Enum] = ACTIONS(6136),
    [anon_sym_eNUM] = ACTIONS(6136),
    [anon_sym_eNum] = ACTIONS(6136),
    [anon_sym_ENum] = ACTIONS(6136),
    [sym_quoted_identifier] = ACTIONS(6138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6138),
    [sym_verbatim_string] = ACTIONS(6138),
    [sym_integer] = ACTIONS(6136),
    [sym_continue_as_identifier] = ACTIONS(6138),
    [sym_preproc_open] = ACTIONS(6138),
    [sym_preproc_close] = ACTIONS(6138),
  },
  [STATE(2564)] = {
    [sym_identifier] = ACTIONS(6140),
    [anon_sym_SEMI] = ACTIONS(6142),
    [anon_sym_DASH] = ACTIONS(6142),
    [aux_sym_boolean_token1] = ACTIONS(6140),
    [aux_sym_boolean_token2] = ACTIONS(6140),
    [sym_decimal] = ACTIONS(6140),
    [anon_sym_LPAREN] = ACTIONS(6142),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6140),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [aux_sym_record_type_token1] = ACTIONS(6140),
    [aux_sym_basic_type_token21] = ACTIONS(6140),
    [aux_sym_basic_type_token22] = ACTIONS(6140),
    [aux_sym_basic_type_token48] = ACTIONS(6140),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6140),
    [anon_sym_POUNDif] = ACTIONS(6142),
    [anon_sym_POUNDIF] = ACTIONS(6142),
    [anon_sym_POUNDIf] = ACTIONS(6142),
    [anon_sym_not] = ACTIONS(6140),
    [anon_sym_NOT] = ACTIONS(6140),
    [anon_sym_Not] = ACTIONS(6140),
    [anon_sym_POUNDelif] = ACTIONS(6142),
    [anon_sym_POUNDELIF] = ACTIONS(6142),
    [anon_sym_POUNDElif] = ACTIONS(6142),
    [anon_sym_POUNDelse] = ACTIONS(6142),
    [anon_sym_POUNDELSE] = ACTIONS(6142),
    [anon_sym_POUNDElse] = ACTIONS(6142),
    [anon_sym_POUNDelse2] = ACTIONS(6142),
    [anon_sym_POUNDELSE2] = ACTIONS(6142),
    [anon_sym_POUNDElse2] = ACTIONS(6142),
    [anon_sym_POUNDendif] = ACTIONS(6142),
    [anon_sym_POUNDENDIF] = ACTIONS(6142),
    [anon_sym_POUNDEndif] = ACTIONS(6142),
    [anon_sym_POUNDendif2] = ACTIONS(6142),
    [anon_sym_POUNDENDIF2] = ACTIONS(6142),
    [anon_sym_POUNDEndif2] = ACTIONS(6142),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6140),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6140),
    [anon_sym_PLUS] = ACTIONS(6142),
    [sym_datetime_literal] = ACTIONS(6142),
    [sym_date_literal] = ACTIONS(6140),
    [sym_time_literal] = ACTIONS(6140),
    [sym_biginteger_literal] = ACTIONS(6142),
    [anon_sym_if] = ACTIONS(6140),
    [anon_sym_IF] = ACTIONS(6140),
    [anon_sym_If] = ACTIONS(6140),
    [anon_sym_else] = ACTIONS(6140),
    [anon_sym_ELSE] = ACTIONS(6140),
    [anon_sym_Else] = ACTIONS(6140),
    [anon_sym_case] = ACTIONS(6140),
    [anon_sym_CASE] = ACTIONS(6140),
    [anon_sym_Case] = ACTIONS(6140),
    [anon_sym_for] = ACTIONS(6140),
    [anon_sym_FOR] = ACTIONS(6140),
    [anon_sym_For] = ACTIONS(6140),
    [anon_sym_foreach] = ACTIONS(6140),
    [anon_sym_FOREACH] = ACTIONS(6140),
    [anon_sym_Foreach] = ACTIONS(6140),
    [anon_sym_while] = ACTIONS(6140),
    [anon_sym_WHILE] = ACTIONS(6140),
    [anon_sym_While] = ACTIONS(6140),
    [anon_sym_repeat] = ACTIONS(6140),
    [anon_sym_REPEAT] = ACTIONS(6140),
    [anon_sym_Repeat] = ACTIONS(6140),
    [anon_sym_exit] = ACTIONS(6140),
    [anon_sym_EXIT] = ACTIONS(6140),
    [anon_sym_Exit] = ACTIONS(6140),
    [anon_sym_continue] = ACTIONS(6140),
    [anon_sym_CONTINUE] = ACTIONS(6140),
    [anon_sym_Continue] = ACTIONS(6140),
    [anon_sym_break] = ACTIONS(6140),
    [anon_sym_BREAK] = ACTIONS(6140),
    [anon_sym_Break] = ACTIONS(6140),
    [anon_sym_with] = ACTIONS(6140),
    [anon_sym_WITH] = ACTIONS(6140),
    [anon_sym_With] = ACTIONS(6140),
    [sym_asserterror_keyword] = ACTIONS(6142),
    [sym_page_keyword] = ACTIONS(6140),
    [anon_sym_codeunit] = ACTIONS(6140),
    [anon_sym_CODEUNIT] = ACTIONS(6140),
    [anon_sym_Codeunit] = ACTIONS(6140),
    [anon_sym_CodeUnit] = ACTIONS(6140),
    [anon_sym_COdeunit] = ACTIONS(6140),
    [anon_sym_codeUnit] = ACTIONS(6140),
    [sym_report_keyword] = ACTIONS(6140),
    [sym_query_keyword] = ACTIONS(6140),
    [anon_sym_xmlport] = ACTIONS(6140),
    [anon_sym_XMLPORT] = ACTIONS(6140),
    [anon_sym_Xmlport] = ACTIONS(6140),
    [anon_sym_XMLport] = ACTIONS(6140),
    [anon_sym_XMLPort] = ACTIONS(6140),
    [anon_sym_XmlPort] = ACTIONS(6140),
    [anon_sym_enum] = ACTIONS(6140),
    [anon_sym_ENUM] = ACTIONS(6140),
    [anon_sym_Enum] = ACTIONS(6140),
    [anon_sym_eNUM] = ACTIONS(6140),
    [anon_sym_eNum] = ACTIONS(6140),
    [anon_sym_ENum] = ACTIONS(6140),
    [sym_quoted_identifier] = ACTIONS(6142),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6142),
    [sym_verbatim_string] = ACTIONS(6142),
    [sym_integer] = ACTIONS(6140),
    [sym_continue_as_identifier] = ACTIONS(6142),
    [sym_preproc_open] = ACTIONS(6142),
    [sym_preproc_close] = ACTIONS(6142),
  },
  [STATE(2565)] = {
    [sym_identifier] = ACTIONS(6144),
    [anon_sym_SEMI] = ACTIONS(6146),
    [anon_sym_DASH] = ACTIONS(6146),
    [aux_sym_boolean_token1] = ACTIONS(6144),
    [aux_sym_boolean_token2] = ACTIONS(6144),
    [sym_decimal] = ACTIONS(6144),
    [anon_sym_LPAREN] = ACTIONS(6146),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6144),
    [anon_sym_LBRACK] = ACTIONS(6146),
    [aux_sym_record_type_token1] = ACTIONS(6144),
    [aux_sym_basic_type_token21] = ACTIONS(6144),
    [aux_sym_basic_type_token22] = ACTIONS(6144),
    [aux_sym_basic_type_token48] = ACTIONS(6144),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6144),
    [anon_sym_POUNDif] = ACTIONS(6146),
    [anon_sym_POUNDIF] = ACTIONS(6146),
    [anon_sym_POUNDIf] = ACTIONS(6146),
    [anon_sym_not] = ACTIONS(6144),
    [anon_sym_NOT] = ACTIONS(6144),
    [anon_sym_Not] = ACTIONS(6144),
    [anon_sym_POUNDelif] = ACTIONS(6146),
    [anon_sym_POUNDELIF] = ACTIONS(6146),
    [anon_sym_POUNDElif] = ACTIONS(6146),
    [anon_sym_POUNDelse] = ACTIONS(6146),
    [anon_sym_POUNDELSE] = ACTIONS(6146),
    [anon_sym_POUNDElse] = ACTIONS(6146),
    [anon_sym_POUNDelse2] = ACTIONS(6146),
    [anon_sym_POUNDELSE2] = ACTIONS(6146),
    [anon_sym_POUNDElse2] = ACTIONS(6146),
    [anon_sym_POUNDendif] = ACTIONS(6146),
    [anon_sym_POUNDENDIF] = ACTIONS(6146),
    [anon_sym_POUNDEndif] = ACTIONS(6146),
    [anon_sym_POUNDendif2] = ACTIONS(6146),
    [anon_sym_POUNDENDIF2] = ACTIONS(6146),
    [anon_sym_POUNDEndif2] = ACTIONS(6146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6144),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6144),
    [anon_sym_PLUS] = ACTIONS(6146),
    [sym_datetime_literal] = ACTIONS(6146),
    [sym_date_literal] = ACTIONS(6144),
    [sym_time_literal] = ACTIONS(6144),
    [sym_biginteger_literal] = ACTIONS(6146),
    [anon_sym_if] = ACTIONS(6144),
    [anon_sym_IF] = ACTIONS(6144),
    [anon_sym_If] = ACTIONS(6144),
    [anon_sym_else] = ACTIONS(6144),
    [anon_sym_ELSE] = ACTIONS(6144),
    [anon_sym_Else] = ACTIONS(6144),
    [anon_sym_case] = ACTIONS(6144),
    [anon_sym_CASE] = ACTIONS(6144),
    [anon_sym_Case] = ACTIONS(6144),
    [anon_sym_for] = ACTIONS(6144),
    [anon_sym_FOR] = ACTIONS(6144),
    [anon_sym_For] = ACTIONS(6144),
    [anon_sym_foreach] = ACTIONS(6144),
    [anon_sym_FOREACH] = ACTIONS(6144),
    [anon_sym_Foreach] = ACTIONS(6144),
    [anon_sym_while] = ACTIONS(6144),
    [anon_sym_WHILE] = ACTIONS(6144),
    [anon_sym_While] = ACTIONS(6144),
    [anon_sym_repeat] = ACTIONS(6144),
    [anon_sym_REPEAT] = ACTIONS(6144),
    [anon_sym_Repeat] = ACTIONS(6144),
    [anon_sym_exit] = ACTIONS(6144),
    [anon_sym_EXIT] = ACTIONS(6144),
    [anon_sym_Exit] = ACTIONS(6144),
    [anon_sym_continue] = ACTIONS(6144),
    [anon_sym_CONTINUE] = ACTIONS(6144),
    [anon_sym_Continue] = ACTIONS(6144),
    [anon_sym_break] = ACTIONS(6144),
    [anon_sym_BREAK] = ACTIONS(6144),
    [anon_sym_Break] = ACTIONS(6144),
    [anon_sym_with] = ACTIONS(6144),
    [anon_sym_WITH] = ACTIONS(6144),
    [anon_sym_With] = ACTIONS(6144),
    [sym_asserterror_keyword] = ACTIONS(6146),
    [sym_page_keyword] = ACTIONS(6144),
    [anon_sym_codeunit] = ACTIONS(6144),
    [anon_sym_CODEUNIT] = ACTIONS(6144),
    [anon_sym_Codeunit] = ACTIONS(6144),
    [anon_sym_CodeUnit] = ACTIONS(6144),
    [anon_sym_COdeunit] = ACTIONS(6144),
    [anon_sym_codeUnit] = ACTIONS(6144),
    [sym_report_keyword] = ACTIONS(6144),
    [sym_query_keyword] = ACTIONS(6144),
    [anon_sym_xmlport] = ACTIONS(6144),
    [anon_sym_XMLPORT] = ACTIONS(6144),
    [anon_sym_Xmlport] = ACTIONS(6144),
    [anon_sym_XMLport] = ACTIONS(6144),
    [anon_sym_XMLPort] = ACTIONS(6144),
    [anon_sym_XmlPort] = ACTIONS(6144),
    [anon_sym_enum] = ACTIONS(6144),
    [anon_sym_ENUM] = ACTIONS(6144),
    [anon_sym_Enum] = ACTIONS(6144),
    [anon_sym_eNUM] = ACTIONS(6144),
    [anon_sym_eNum] = ACTIONS(6144),
    [anon_sym_ENum] = ACTIONS(6144),
    [sym_quoted_identifier] = ACTIONS(6146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6146),
    [sym_verbatim_string] = ACTIONS(6146),
    [sym_integer] = ACTIONS(6144),
    [sym_continue_as_identifier] = ACTIONS(6146),
    [sym_preproc_open] = ACTIONS(6146),
    [sym_preproc_close] = ACTIONS(6146),
  },
  [STATE(2566)] = {
    [sym_identifier] = ACTIONS(6148),
    [anon_sym_SEMI] = ACTIONS(6150),
    [anon_sym_DASH] = ACTIONS(6150),
    [aux_sym_boolean_token1] = ACTIONS(6148),
    [aux_sym_boolean_token2] = ACTIONS(6148),
    [sym_decimal] = ACTIONS(6148),
    [anon_sym_LPAREN] = ACTIONS(6150),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6148),
    [anon_sym_LBRACK] = ACTIONS(6150),
    [aux_sym_record_type_token1] = ACTIONS(6148),
    [aux_sym_basic_type_token21] = ACTIONS(6148),
    [aux_sym_basic_type_token22] = ACTIONS(6148),
    [aux_sym_basic_type_token48] = ACTIONS(6148),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6148),
    [anon_sym_POUNDif] = ACTIONS(6150),
    [anon_sym_POUNDIF] = ACTIONS(6150),
    [anon_sym_POUNDIf] = ACTIONS(6150),
    [anon_sym_not] = ACTIONS(6148),
    [anon_sym_NOT] = ACTIONS(6148),
    [anon_sym_Not] = ACTIONS(6148),
    [anon_sym_POUNDelif] = ACTIONS(6150),
    [anon_sym_POUNDELIF] = ACTIONS(6150),
    [anon_sym_POUNDElif] = ACTIONS(6150),
    [anon_sym_POUNDelse] = ACTIONS(6150),
    [anon_sym_POUNDELSE] = ACTIONS(6150),
    [anon_sym_POUNDElse] = ACTIONS(6150),
    [anon_sym_POUNDelse2] = ACTIONS(6150),
    [anon_sym_POUNDELSE2] = ACTIONS(6150),
    [anon_sym_POUNDElse2] = ACTIONS(6150),
    [anon_sym_POUNDendif] = ACTIONS(6150),
    [anon_sym_POUNDENDIF] = ACTIONS(6150),
    [anon_sym_POUNDEndif] = ACTIONS(6150),
    [anon_sym_POUNDendif2] = ACTIONS(6150),
    [anon_sym_POUNDENDIF2] = ACTIONS(6150),
    [anon_sym_POUNDEndif2] = ACTIONS(6150),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6148),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6148),
    [anon_sym_PLUS] = ACTIONS(6150),
    [sym_datetime_literal] = ACTIONS(6150),
    [sym_date_literal] = ACTIONS(6148),
    [sym_time_literal] = ACTIONS(6148),
    [sym_biginteger_literal] = ACTIONS(6150),
    [anon_sym_if] = ACTIONS(6148),
    [anon_sym_IF] = ACTIONS(6148),
    [anon_sym_If] = ACTIONS(6148),
    [anon_sym_else] = ACTIONS(6148),
    [anon_sym_ELSE] = ACTIONS(6148),
    [anon_sym_Else] = ACTIONS(6148),
    [anon_sym_case] = ACTIONS(6148),
    [anon_sym_CASE] = ACTIONS(6148),
    [anon_sym_Case] = ACTIONS(6148),
    [anon_sym_for] = ACTIONS(6148),
    [anon_sym_FOR] = ACTIONS(6148),
    [anon_sym_For] = ACTIONS(6148),
    [anon_sym_foreach] = ACTIONS(6148),
    [anon_sym_FOREACH] = ACTIONS(6148),
    [anon_sym_Foreach] = ACTIONS(6148),
    [anon_sym_while] = ACTIONS(6148),
    [anon_sym_WHILE] = ACTIONS(6148),
    [anon_sym_While] = ACTIONS(6148),
    [anon_sym_repeat] = ACTIONS(6148),
    [anon_sym_REPEAT] = ACTIONS(6148),
    [anon_sym_Repeat] = ACTIONS(6148),
    [anon_sym_exit] = ACTIONS(6148),
    [anon_sym_EXIT] = ACTIONS(6148),
    [anon_sym_Exit] = ACTIONS(6148),
    [anon_sym_continue] = ACTIONS(6148),
    [anon_sym_CONTINUE] = ACTIONS(6148),
    [anon_sym_Continue] = ACTIONS(6148),
    [anon_sym_break] = ACTIONS(6148),
    [anon_sym_BREAK] = ACTIONS(6148),
    [anon_sym_Break] = ACTIONS(6148),
    [anon_sym_with] = ACTIONS(6148),
    [anon_sym_WITH] = ACTIONS(6148),
    [anon_sym_With] = ACTIONS(6148),
    [sym_asserterror_keyword] = ACTIONS(6150),
    [sym_page_keyword] = ACTIONS(6148),
    [anon_sym_codeunit] = ACTIONS(6148),
    [anon_sym_CODEUNIT] = ACTIONS(6148),
    [anon_sym_Codeunit] = ACTIONS(6148),
    [anon_sym_CodeUnit] = ACTIONS(6148),
    [anon_sym_COdeunit] = ACTIONS(6148),
    [anon_sym_codeUnit] = ACTIONS(6148),
    [sym_report_keyword] = ACTIONS(6148),
    [sym_query_keyword] = ACTIONS(6148),
    [anon_sym_xmlport] = ACTIONS(6148),
    [anon_sym_XMLPORT] = ACTIONS(6148),
    [anon_sym_Xmlport] = ACTIONS(6148),
    [anon_sym_XMLport] = ACTIONS(6148),
    [anon_sym_XMLPort] = ACTIONS(6148),
    [anon_sym_XmlPort] = ACTIONS(6148),
    [anon_sym_enum] = ACTIONS(6148),
    [anon_sym_ENUM] = ACTIONS(6148),
    [anon_sym_Enum] = ACTIONS(6148),
    [anon_sym_eNUM] = ACTIONS(6148),
    [anon_sym_eNum] = ACTIONS(6148),
    [anon_sym_ENum] = ACTIONS(6148),
    [sym_quoted_identifier] = ACTIONS(6150),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6150),
    [sym_verbatim_string] = ACTIONS(6150),
    [sym_integer] = ACTIONS(6148),
    [sym_continue_as_identifier] = ACTIONS(6150),
    [sym_preproc_open] = ACTIONS(6150),
    [sym_preproc_close] = ACTIONS(6150),
  },
  [STATE(2567)] = {
    [sym_identifier] = ACTIONS(6152),
    [anon_sym_SEMI] = ACTIONS(6154),
    [anon_sym_DASH] = ACTIONS(6154),
    [aux_sym_boolean_token1] = ACTIONS(6152),
    [aux_sym_boolean_token2] = ACTIONS(6152),
    [sym_decimal] = ACTIONS(6152),
    [anon_sym_LPAREN] = ACTIONS(6154),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6152),
    [anon_sym_LBRACK] = ACTIONS(6154),
    [aux_sym_record_type_token1] = ACTIONS(6152),
    [aux_sym_basic_type_token21] = ACTIONS(6152),
    [aux_sym_basic_type_token22] = ACTIONS(6152),
    [aux_sym_basic_type_token48] = ACTIONS(6152),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6152),
    [anon_sym_POUNDif] = ACTIONS(6154),
    [anon_sym_POUNDIF] = ACTIONS(6154),
    [anon_sym_POUNDIf] = ACTIONS(6154),
    [anon_sym_not] = ACTIONS(6152),
    [anon_sym_NOT] = ACTIONS(6152),
    [anon_sym_Not] = ACTIONS(6152),
    [anon_sym_POUNDelif] = ACTIONS(6154),
    [anon_sym_POUNDELIF] = ACTIONS(6154),
    [anon_sym_POUNDElif] = ACTIONS(6154),
    [anon_sym_POUNDelse] = ACTIONS(6154),
    [anon_sym_POUNDELSE] = ACTIONS(6154),
    [anon_sym_POUNDElse] = ACTIONS(6154),
    [anon_sym_POUNDelse2] = ACTIONS(6154),
    [anon_sym_POUNDELSE2] = ACTIONS(6154),
    [anon_sym_POUNDElse2] = ACTIONS(6154),
    [anon_sym_POUNDendif] = ACTIONS(6154),
    [anon_sym_POUNDENDIF] = ACTIONS(6154),
    [anon_sym_POUNDEndif] = ACTIONS(6154),
    [anon_sym_POUNDendif2] = ACTIONS(6154),
    [anon_sym_POUNDENDIF2] = ACTIONS(6154),
    [anon_sym_POUNDEndif2] = ACTIONS(6154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6152),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6152),
    [anon_sym_PLUS] = ACTIONS(6154),
    [sym_datetime_literal] = ACTIONS(6154),
    [sym_date_literal] = ACTIONS(6152),
    [sym_time_literal] = ACTIONS(6152),
    [sym_biginteger_literal] = ACTIONS(6154),
    [anon_sym_if] = ACTIONS(6152),
    [anon_sym_IF] = ACTIONS(6152),
    [anon_sym_If] = ACTIONS(6152),
    [anon_sym_else] = ACTIONS(6152),
    [anon_sym_ELSE] = ACTIONS(6152),
    [anon_sym_Else] = ACTIONS(6152),
    [anon_sym_case] = ACTIONS(6152),
    [anon_sym_CASE] = ACTIONS(6152),
    [anon_sym_Case] = ACTIONS(6152),
    [anon_sym_for] = ACTIONS(6152),
    [anon_sym_FOR] = ACTIONS(6152),
    [anon_sym_For] = ACTIONS(6152),
    [anon_sym_foreach] = ACTIONS(6152),
    [anon_sym_FOREACH] = ACTIONS(6152),
    [anon_sym_Foreach] = ACTIONS(6152),
    [anon_sym_while] = ACTIONS(6152),
    [anon_sym_WHILE] = ACTIONS(6152),
    [anon_sym_While] = ACTIONS(6152),
    [anon_sym_repeat] = ACTIONS(6152),
    [anon_sym_REPEAT] = ACTIONS(6152),
    [anon_sym_Repeat] = ACTIONS(6152),
    [anon_sym_exit] = ACTIONS(6152),
    [anon_sym_EXIT] = ACTIONS(6152),
    [anon_sym_Exit] = ACTIONS(6152),
    [anon_sym_continue] = ACTIONS(6152),
    [anon_sym_CONTINUE] = ACTIONS(6152),
    [anon_sym_Continue] = ACTIONS(6152),
    [anon_sym_break] = ACTIONS(6152),
    [anon_sym_BREAK] = ACTIONS(6152),
    [anon_sym_Break] = ACTIONS(6152),
    [anon_sym_with] = ACTIONS(6152),
    [anon_sym_WITH] = ACTIONS(6152),
    [anon_sym_With] = ACTIONS(6152),
    [sym_asserterror_keyword] = ACTIONS(6154),
    [sym_page_keyword] = ACTIONS(6152),
    [anon_sym_codeunit] = ACTIONS(6152),
    [anon_sym_CODEUNIT] = ACTIONS(6152),
    [anon_sym_Codeunit] = ACTIONS(6152),
    [anon_sym_CodeUnit] = ACTIONS(6152),
    [anon_sym_COdeunit] = ACTIONS(6152),
    [anon_sym_codeUnit] = ACTIONS(6152),
    [sym_report_keyword] = ACTIONS(6152),
    [sym_query_keyword] = ACTIONS(6152),
    [anon_sym_xmlport] = ACTIONS(6152),
    [anon_sym_XMLPORT] = ACTIONS(6152),
    [anon_sym_Xmlport] = ACTIONS(6152),
    [anon_sym_XMLport] = ACTIONS(6152),
    [anon_sym_XMLPort] = ACTIONS(6152),
    [anon_sym_XmlPort] = ACTIONS(6152),
    [anon_sym_enum] = ACTIONS(6152),
    [anon_sym_ENUM] = ACTIONS(6152),
    [anon_sym_Enum] = ACTIONS(6152),
    [anon_sym_eNUM] = ACTIONS(6152),
    [anon_sym_eNum] = ACTIONS(6152),
    [anon_sym_ENum] = ACTIONS(6152),
    [sym_quoted_identifier] = ACTIONS(6154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6154),
    [sym_verbatim_string] = ACTIONS(6154),
    [sym_integer] = ACTIONS(6152),
    [sym_continue_as_identifier] = ACTIONS(6154),
    [sym_preproc_open] = ACTIONS(6154),
    [sym_preproc_close] = ACTIONS(6154),
  },
  [STATE(2568)] = {
    [sym_identifier] = ACTIONS(6156),
    [anon_sym_SEMI] = ACTIONS(6158),
    [anon_sym_DASH] = ACTIONS(6158),
    [aux_sym_boolean_token1] = ACTIONS(6156),
    [aux_sym_boolean_token2] = ACTIONS(6156),
    [sym_decimal] = ACTIONS(6156),
    [anon_sym_LPAREN] = ACTIONS(6158),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6156),
    [anon_sym_LBRACK] = ACTIONS(6158),
    [aux_sym_record_type_token1] = ACTIONS(6156),
    [aux_sym_basic_type_token21] = ACTIONS(6156),
    [aux_sym_basic_type_token22] = ACTIONS(6156),
    [aux_sym_basic_type_token48] = ACTIONS(6156),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6156),
    [anon_sym_POUNDif] = ACTIONS(6158),
    [anon_sym_POUNDIF] = ACTIONS(6158),
    [anon_sym_POUNDIf] = ACTIONS(6158),
    [anon_sym_not] = ACTIONS(6156),
    [anon_sym_NOT] = ACTIONS(6156),
    [anon_sym_Not] = ACTIONS(6156),
    [anon_sym_POUNDelif] = ACTIONS(6158),
    [anon_sym_POUNDELIF] = ACTIONS(6158),
    [anon_sym_POUNDElif] = ACTIONS(6158),
    [anon_sym_POUNDelse] = ACTIONS(6158),
    [anon_sym_POUNDELSE] = ACTIONS(6158),
    [anon_sym_POUNDElse] = ACTIONS(6158),
    [anon_sym_POUNDelse2] = ACTIONS(6158),
    [anon_sym_POUNDELSE2] = ACTIONS(6158),
    [anon_sym_POUNDElse2] = ACTIONS(6158),
    [anon_sym_POUNDendif] = ACTIONS(6158),
    [anon_sym_POUNDENDIF] = ACTIONS(6158),
    [anon_sym_POUNDEndif] = ACTIONS(6158),
    [anon_sym_POUNDendif2] = ACTIONS(6158),
    [anon_sym_POUNDENDIF2] = ACTIONS(6158),
    [anon_sym_POUNDEndif2] = ACTIONS(6158),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6156),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6156),
    [anon_sym_PLUS] = ACTIONS(6158),
    [sym_datetime_literal] = ACTIONS(6158),
    [sym_date_literal] = ACTIONS(6156),
    [sym_time_literal] = ACTIONS(6156),
    [sym_biginteger_literal] = ACTIONS(6158),
    [anon_sym_if] = ACTIONS(6156),
    [anon_sym_IF] = ACTIONS(6156),
    [anon_sym_If] = ACTIONS(6156),
    [anon_sym_else] = ACTIONS(6156),
    [anon_sym_ELSE] = ACTIONS(6156),
    [anon_sym_Else] = ACTIONS(6156),
    [anon_sym_case] = ACTIONS(6156),
    [anon_sym_CASE] = ACTIONS(6156),
    [anon_sym_Case] = ACTIONS(6156),
    [anon_sym_for] = ACTIONS(6156),
    [anon_sym_FOR] = ACTIONS(6156),
    [anon_sym_For] = ACTIONS(6156),
    [anon_sym_foreach] = ACTIONS(6156),
    [anon_sym_FOREACH] = ACTIONS(6156),
    [anon_sym_Foreach] = ACTIONS(6156),
    [anon_sym_while] = ACTIONS(6156),
    [anon_sym_WHILE] = ACTIONS(6156),
    [anon_sym_While] = ACTIONS(6156),
    [anon_sym_repeat] = ACTIONS(6156),
    [anon_sym_REPEAT] = ACTIONS(6156),
    [anon_sym_Repeat] = ACTIONS(6156),
    [anon_sym_exit] = ACTIONS(6156),
    [anon_sym_EXIT] = ACTIONS(6156),
    [anon_sym_Exit] = ACTIONS(6156),
    [anon_sym_continue] = ACTIONS(6156),
    [anon_sym_CONTINUE] = ACTIONS(6156),
    [anon_sym_Continue] = ACTIONS(6156),
    [anon_sym_break] = ACTIONS(6156),
    [anon_sym_BREAK] = ACTIONS(6156),
    [anon_sym_Break] = ACTIONS(6156),
    [anon_sym_with] = ACTIONS(6156),
    [anon_sym_WITH] = ACTIONS(6156),
    [anon_sym_With] = ACTIONS(6156),
    [sym_asserterror_keyword] = ACTIONS(6158),
    [sym_page_keyword] = ACTIONS(6156),
    [anon_sym_codeunit] = ACTIONS(6156),
    [anon_sym_CODEUNIT] = ACTIONS(6156),
    [anon_sym_Codeunit] = ACTIONS(6156),
    [anon_sym_CodeUnit] = ACTIONS(6156),
    [anon_sym_COdeunit] = ACTIONS(6156),
    [anon_sym_codeUnit] = ACTIONS(6156),
    [sym_report_keyword] = ACTIONS(6156),
    [sym_query_keyword] = ACTIONS(6156),
    [anon_sym_xmlport] = ACTIONS(6156),
    [anon_sym_XMLPORT] = ACTIONS(6156),
    [anon_sym_Xmlport] = ACTIONS(6156),
    [anon_sym_XMLport] = ACTIONS(6156),
    [anon_sym_XMLPort] = ACTIONS(6156),
    [anon_sym_XmlPort] = ACTIONS(6156),
    [anon_sym_enum] = ACTIONS(6156),
    [anon_sym_ENUM] = ACTIONS(6156),
    [anon_sym_Enum] = ACTIONS(6156),
    [anon_sym_eNUM] = ACTIONS(6156),
    [anon_sym_eNum] = ACTIONS(6156),
    [anon_sym_ENum] = ACTIONS(6156),
    [sym_quoted_identifier] = ACTIONS(6158),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6158),
    [sym_verbatim_string] = ACTIONS(6158),
    [sym_integer] = ACTIONS(6156),
    [sym_continue_as_identifier] = ACTIONS(6158),
    [sym_preproc_open] = ACTIONS(6158),
    [sym_preproc_close] = ACTIONS(6158),
  },
  [STATE(2569)] = {
    [sym_identifier] = ACTIONS(6160),
    [anon_sym_SEMI] = ACTIONS(6162),
    [anon_sym_DASH] = ACTIONS(6162),
    [aux_sym_boolean_token1] = ACTIONS(6160),
    [aux_sym_boolean_token2] = ACTIONS(6160),
    [sym_decimal] = ACTIONS(6160),
    [anon_sym_LPAREN] = ACTIONS(6162),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6160),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [aux_sym_record_type_token1] = ACTIONS(6160),
    [aux_sym_basic_type_token21] = ACTIONS(6160),
    [aux_sym_basic_type_token22] = ACTIONS(6160),
    [aux_sym_basic_type_token48] = ACTIONS(6160),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6160),
    [anon_sym_POUNDif] = ACTIONS(6162),
    [anon_sym_POUNDIF] = ACTIONS(6162),
    [anon_sym_POUNDIf] = ACTIONS(6162),
    [anon_sym_not] = ACTIONS(6160),
    [anon_sym_NOT] = ACTIONS(6160),
    [anon_sym_Not] = ACTIONS(6160),
    [anon_sym_POUNDelif] = ACTIONS(6162),
    [anon_sym_POUNDELIF] = ACTIONS(6162),
    [anon_sym_POUNDElif] = ACTIONS(6162),
    [anon_sym_POUNDelse] = ACTIONS(6162),
    [anon_sym_POUNDELSE] = ACTIONS(6162),
    [anon_sym_POUNDElse] = ACTIONS(6162),
    [anon_sym_POUNDelse2] = ACTIONS(6162),
    [anon_sym_POUNDELSE2] = ACTIONS(6162),
    [anon_sym_POUNDElse2] = ACTIONS(6162),
    [anon_sym_POUNDendif] = ACTIONS(6162),
    [anon_sym_POUNDENDIF] = ACTIONS(6162),
    [anon_sym_POUNDEndif] = ACTIONS(6162),
    [anon_sym_POUNDendif2] = ACTIONS(6162),
    [anon_sym_POUNDENDIF2] = ACTIONS(6162),
    [anon_sym_POUNDEndif2] = ACTIONS(6162),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6160),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6162),
    [sym_datetime_literal] = ACTIONS(6162),
    [sym_date_literal] = ACTIONS(6160),
    [sym_time_literal] = ACTIONS(6160),
    [sym_biginteger_literal] = ACTIONS(6162),
    [anon_sym_if] = ACTIONS(6160),
    [anon_sym_IF] = ACTIONS(6160),
    [anon_sym_If] = ACTIONS(6160),
    [anon_sym_else] = ACTIONS(6160),
    [anon_sym_ELSE] = ACTIONS(6160),
    [anon_sym_Else] = ACTIONS(6160),
    [anon_sym_case] = ACTIONS(6160),
    [anon_sym_CASE] = ACTIONS(6160),
    [anon_sym_Case] = ACTIONS(6160),
    [anon_sym_for] = ACTIONS(6160),
    [anon_sym_FOR] = ACTIONS(6160),
    [anon_sym_For] = ACTIONS(6160),
    [anon_sym_foreach] = ACTIONS(6160),
    [anon_sym_FOREACH] = ACTIONS(6160),
    [anon_sym_Foreach] = ACTIONS(6160),
    [anon_sym_while] = ACTIONS(6160),
    [anon_sym_WHILE] = ACTIONS(6160),
    [anon_sym_While] = ACTIONS(6160),
    [anon_sym_repeat] = ACTIONS(6160),
    [anon_sym_REPEAT] = ACTIONS(6160),
    [anon_sym_Repeat] = ACTIONS(6160),
    [anon_sym_exit] = ACTIONS(6160),
    [anon_sym_EXIT] = ACTIONS(6160),
    [anon_sym_Exit] = ACTIONS(6160),
    [anon_sym_continue] = ACTIONS(6160),
    [anon_sym_CONTINUE] = ACTIONS(6160),
    [anon_sym_Continue] = ACTIONS(6160),
    [anon_sym_break] = ACTIONS(6160),
    [anon_sym_BREAK] = ACTIONS(6160),
    [anon_sym_Break] = ACTIONS(6160),
    [anon_sym_with] = ACTIONS(6160),
    [anon_sym_WITH] = ACTIONS(6160),
    [anon_sym_With] = ACTIONS(6160),
    [sym_asserterror_keyword] = ACTIONS(6162),
    [sym_page_keyword] = ACTIONS(6160),
    [anon_sym_codeunit] = ACTIONS(6160),
    [anon_sym_CODEUNIT] = ACTIONS(6160),
    [anon_sym_Codeunit] = ACTIONS(6160),
    [anon_sym_CodeUnit] = ACTIONS(6160),
    [anon_sym_COdeunit] = ACTIONS(6160),
    [anon_sym_codeUnit] = ACTIONS(6160),
    [sym_report_keyword] = ACTIONS(6160),
    [sym_query_keyword] = ACTIONS(6160),
    [anon_sym_xmlport] = ACTIONS(6160),
    [anon_sym_XMLPORT] = ACTIONS(6160),
    [anon_sym_Xmlport] = ACTIONS(6160),
    [anon_sym_XMLport] = ACTIONS(6160),
    [anon_sym_XMLPort] = ACTIONS(6160),
    [anon_sym_XmlPort] = ACTIONS(6160),
    [anon_sym_enum] = ACTIONS(6160),
    [anon_sym_ENUM] = ACTIONS(6160),
    [anon_sym_Enum] = ACTIONS(6160),
    [anon_sym_eNUM] = ACTIONS(6160),
    [anon_sym_eNum] = ACTIONS(6160),
    [anon_sym_ENum] = ACTIONS(6160),
    [sym_quoted_identifier] = ACTIONS(6162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6162),
    [sym_verbatim_string] = ACTIONS(6162),
    [sym_integer] = ACTIONS(6160),
    [sym_continue_as_identifier] = ACTIONS(6162),
    [sym_preproc_open] = ACTIONS(6162),
    [sym_preproc_close] = ACTIONS(6162),
  },
  [STATE(2570)] = {
    [sym_identifier] = ACTIONS(6164),
    [anon_sym_SEMI] = ACTIONS(6166),
    [anon_sym_DASH] = ACTIONS(6166),
    [aux_sym_boolean_token1] = ACTIONS(6164),
    [aux_sym_boolean_token2] = ACTIONS(6164),
    [sym_decimal] = ACTIONS(6164),
    [anon_sym_LPAREN] = ACTIONS(6166),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6164),
    [anon_sym_LBRACK] = ACTIONS(6166),
    [aux_sym_record_type_token1] = ACTIONS(6164),
    [aux_sym_basic_type_token21] = ACTIONS(6164),
    [aux_sym_basic_type_token22] = ACTIONS(6164),
    [aux_sym_basic_type_token48] = ACTIONS(6164),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6164),
    [anon_sym_POUNDif] = ACTIONS(6166),
    [anon_sym_POUNDIF] = ACTIONS(6166),
    [anon_sym_POUNDIf] = ACTIONS(6166),
    [anon_sym_not] = ACTIONS(6164),
    [anon_sym_NOT] = ACTIONS(6164),
    [anon_sym_Not] = ACTIONS(6164),
    [anon_sym_POUNDelif] = ACTIONS(6166),
    [anon_sym_POUNDELIF] = ACTIONS(6166),
    [anon_sym_POUNDElif] = ACTIONS(6166),
    [anon_sym_POUNDelse] = ACTIONS(6166),
    [anon_sym_POUNDELSE] = ACTIONS(6166),
    [anon_sym_POUNDElse] = ACTIONS(6166),
    [anon_sym_POUNDelse2] = ACTIONS(6166),
    [anon_sym_POUNDELSE2] = ACTIONS(6166),
    [anon_sym_POUNDElse2] = ACTIONS(6166),
    [anon_sym_POUNDendif] = ACTIONS(6166),
    [anon_sym_POUNDENDIF] = ACTIONS(6166),
    [anon_sym_POUNDEndif] = ACTIONS(6166),
    [anon_sym_POUNDendif2] = ACTIONS(6166),
    [anon_sym_POUNDENDIF2] = ACTIONS(6166),
    [anon_sym_POUNDEndif2] = ACTIONS(6166),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6164),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6164),
    [anon_sym_PLUS] = ACTIONS(6166),
    [sym_datetime_literal] = ACTIONS(6166),
    [sym_date_literal] = ACTIONS(6164),
    [sym_time_literal] = ACTIONS(6164),
    [sym_biginteger_literal] = ACTIONS(6166),
    [anon_sym_if] = ACTIONS(6164),
    [anon_sym_IF] = ACTIONS(6164),
    [anon_sym_If] = ACTIONS(6164),
    [anon_sym_else] = ACTIONS(6164),
    [anon_sym_ELSE] = ACTIONS(6164),
    [anon_sym_Else] = ACTIONS(6164),
    [anon_sym_case] = ACTIONS(6164),
    [anon_sym_CASE] = ACTIONS(6164),
    [anon_sym_Case] = ACTIONS(6164),
    [anon_sym_for] = ACTIONS(6164),
    [anon_sym_FOR] = ACTIONS(6164),
    [anon_sym_For] = ACTIONS(6164),
    [anon_sym_foreach] = ACTIONS(6164),
    [anon_sym_FOREACH] = ACTIONS(6164),
    [anon_sym_Foreach] = ACTIONS(6164),
    [anon_sym_while] = ACTIONS(6164),
    [anon_sym_WHILE] = ACTIONS(6164),
    [anon_sym_While] = ACTIONS(6164),
    [anon_sym_repeat] = ACTIONS(6164),
    [anon_sym_REPEAT] = ACTIONS(6164),
    [anon_sym_Repeat] = ACTIONS(6164),
    [anon_sym_exit] = ACTIONS(6164),
    [anon_sym_EXIT] = ACTIONS(6164),
    [anon_sym_Exit] = ACTIONS(6164),
    [anon_sym_continue] = ACTIONS(6164),
    [anon_sym_CONTINUE] = ACTIONS(6164),
    [anon_sym_Continue] = ACTIONS(6164),
    [anon_sym_break] = ACTIONS(6164),
    [anon_sym_BREAK] = ACTIONS(6164),
    [anon_sym_Break] = ACTIONS(6164),
    [anon_sym_with] = ACTIONS(6164),
    [anon_sym_WITH] = ACTIONS(6164),
    [anon_sym_With] = ACTIONS(6164),
    [sym_asserterror_keyword] = ACTIONS(6166),
    [sym_page_keyword] = ACTIONS(6164),
    [anon_sym_codeunit] = ACTIONS(6164),
    [anon_sym_CODEUNIT] = ACTIONS(6164),
    [anon_sym_Codeunit] = ACTIONS(6164),
    [anon_sym_CodeUnit] = ACTIONS(6164),
    [anon_sym_COdeunit] = ACTIONS(6164),
    [anon_sym_codeUnit] = ACTIONS(6164),
    [sym_report_keyword] = ACTIONS(6164),
    [sym_query_keyword] = ACTIONS(6164),
    [anon_sym_xmlport] = ACTIONS(6164),
    [anon_sym_XMLPORT] = ACTIONS(6164),
    [anon_sym_Xmlport] = ACTIONS(6164),
    [anon_sym_XMLport] = ACTIONS(6164),
    [anon_sym_XMLPort] = ACTIONS(6164),
    [anon_sym_XmlPort] = ACTIONS(6164),
    [anon_sym_enum] = ACTIONS(6164),
    [anon_sym_ENUM] = ACTIONS(6164),
    [anon_sym_Enum] = ACTIONS(6164),
    [anon_sym_eNUM] = ACTIONS(6164),
    [anon_sym_eNum] = ACTIONS(6164),
    [anon_sym_ENum] = ACTIONS(6164),
    [sym_quoted_identifier] = ACTIONS(6166),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6166),
    [sym_verbatim_string] = ACTIONS(6166),
    [sym_integer] = ACTIONS(6164),
    [sym_continue_as_identifier] = ACTIONS(6166),
    [sym_preproc_open] = ACTIONS(6166),
    [sym_preproc_close] = ACTIONS(6166),
  },
  [STATE(2571)] = {
    [sym_identifier] = ACTIONS(6168),
    [anon_sym_SEMI] = ACTIONS(6170),
    [anon_sym_DASH] = ACTIONS(6170),
    [aux_sym_boolean_token1] = ACTIONS(6168),
    [aux_sym_boolean_token2] = ACTIONS(6168),
    [sym_decimal] = ACTIONS(6168),
    [anon_sym_LPAREN] = ACTIONS(6170),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6168),
    [anon_sym_LBRACK] = ACTIONS(6170),
    [aux_sym_record_type_token1] = ACTIONS(6168),
    [aux_sym_basic_type_token21] = ACTIONS(6168),
    [aux_sym_basic_type_token22] = ACTIONS(6168),
    [aux_sym_basic_type_token48] = ACTIONS(6168),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6168),
    [anon_sym_POUNDif] = ACTIONS(6170),
    [anon_sym_POUNDIF] = ACTIONS(6170),
    [anon_sym_POUNDIf] = ACTIONS(6170),
    [anon_sym_not] = ACTIONS(6168),
    [anon_sym_NOT] = ACTIONS(6168),
    [anon_sym_Not] = ACTIONS(6168),
    [anon_sym_POUNDelif] = ACTIONS(6170),
    [anon_sym_POUNDELIF] = ACTIONS(6170),
    [anon_sym_POUNDElif] = ACTIONS(6170),
    [anon_sym_POUNDelse] = ACTIONS(6170),
    [anon_sym_POUNDELSE] = ACTIONS(6170),
    [anon_sym_POUNDElse] = ACTIONS(6170),
    [anon_sym_POUNDelse2] = ACTIONS(6170),
    [anon_sym_POUNDELSE2] = ACTIONS(6170),
    [anon_sym_POUNDElse2] = ACTIONS(6170),
    [anon_sym_POUNDendif] = ACTIONS(6170),
    [anon_sym_POUNDENDIF] = ACTIONS(6170),
    [anon_sym_POUNDEndif] = ACTIONS(6170),
    [anon_sym_POUNDendif2] = ACTIONS(6170),
    [anon_sym_POUNDENDIF2] = ACTIONS(6170),
    [anon_sym_POUNDEndif2] = ACTIONS(6170),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6168),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6168),
    [anon_sym_PLUS] = ACTIONS(6170),
    [sym_datetime_literal] = ACTIONS(6170),
    [sym_date_literal] = ACTIONS(6168),
    [sym_time_literal] = ACTIONS(6168),
    [sym_biginteger_literal] = ACTIONS(6170),
    [anon_sym_if] = ACTIONS(6168),
    [anon_sym_IF] = ACTIONS(6168),
    [anon_sym_If] = ACTIONS(6168),
    [anon_sym_else] = ACTIONS(6168),
    [anon_sym_ELSE] = ACTIONS(6168),
    [anon_sym_Else] = ACTIONS(6168),
    [anon_sym_case] = ACTIONS(6168),
    [anon_sym_CASE] = ACTIONS(6168),
    [anon_sym_Case] = ACTIONS(6168),
    [anon_sym_for] = ACTIONS(6168),
    [anon_sym_FOR] = ACTIONS(6168),
    [anon_sym_For] = ACTIONS(6168),
    [anon_sym_foreach] = ACTIONS(6168),
    [anon_sym_FOREACH] = ACTIONS(6168),
    [anon_sym_Foreach] = ACTIONS(6168),
    [anon_sym_while] = ACTIONS(6168),
    [anon_sym_WHILE] = ACTIONS(6168),
    [anon_sym_While] = ACTIONS(6168),
    [anon_sym_repeat] = ACTIONS(6168),
    [anon_sym_REPEAT] = ACTIONS(6168),
    [anon_sym_Repeat] = ACTIONS(6168),
    [anon_sym_exit] = ACTIONS(6168),
    [anon_sym_EXIT] = ACTIONS(6168),
    [anon_sym_Exit] = ACTIONS(6168),
    [anon_sym_continue] = ACTIONS(6168),
    [anon_sym_CONTINUE] = ACTIONS(6168),
    [anon_sym_Continue] = ACTIONS(6168),
    [anon_sym_break] = ACTIONS(6168),
    [anon_sym_BREAK] = ACTIONS(6168),
    [anon_sym_Break] = ACTIONS(6168),
    [anon_sym_with] = ACTIONS(6168),
    [anon_sym_WITH] = ACTIONS(6168),
    [anon_sym_With] = ACTIONS(6168),
    [sym_asserterror_keyword] = ACTIONS(6170),
    [sym_page_keyword] = ACTIONS(6168),
    [anon_sym_codeunit] = ACTIONS(6168),
    [anon_sym_CODEUNIT] = ACTIONS(6168),
    [anon_sym_Codeunit] = ACTIONS(6168),
    [anon_sym_CodeUnit] = ACTIONS(6168),
    [anon_sym_COdeunit] = ACTIONS(6168),
    [anon_sym_codeUnit] = ACTIONS(6168),
    [sym_report_keyword] = ACTIONS(6168),
    [sym_query_keyword] = ACTIONS(6168),
    [anon_sym_xmlport] = ACTIONS(6168),
    [anon_sym_XMLPORT] = ACTIONS(6168),
    [anon_sym_Xmlport] = ACTIONS(6168),
    [anon_sym_XMLport] = ACTIONS(6168),
    [anon_sym_XMLPort] = ACTIONS(6168),
    [anon_sym_XmlPort] = ACTIONS(6168),
    [anon_sym_enum] = ACTIONS(6168),
    [anon_sym_ENUM] = ACTIONS(6168),
    [anon_sym_Enum] = ACTIONS(6168),
    [anon_sym_eNUM] = ACTIONS(6168),
    [anon_sym_eNum] = ACTIONS(6168),
    [anon_sym_ENum] = ACTIONS(6168),
    [sym_quoted_identifier] = ACTIONS(6170),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6170),
    [sym_verbatim_string] = ACTIONS(6170),
    [sym_integer] = ACTIONS(6168),
    [sym_continue_as_identifier] = ACTIONS(6170),
    [sym_preproc_open] = ACTIONS(6170),
    [sym_preproc_close] = ACTIONS(6170),
  },
  [STATE(2572)] = {
    [sym_identifier] = ACTIONS(6172),
    [anon_sym_SEMI] = ACTIONS(6174),
    [anon_sym_DASH] = ACTIONS(6174),
    [aux_sym_boolean_token1] = ACTIONS(6172),
    [aux_sym_boolean_token2] = ACTIONS(6172),
    [sym_decimal] = ACTIONS(6172),
    [anon_sym_LPAREN] = ACTIONS(6174),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6172),
    [anon_sym_LBRACK] = ACTIONS(6174),
    [aux_sym_record_type_token1] = ACTIONS(6172),
    [aux_sym_basic_type_token21] = ACTIONS(6172),
    [aux_sym_basic_type_token22] = ACTIONS(6172),
    [aux_sym_basic_type_token48] = ACTIONS(6172),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6172),
    [anon_sym_POUNDif] = ACTIONS(6174),
    [anon_sym_POUNDIF] = ACTIONS(6174),
    [anon_sym_POUNDIf] = ACTIONS(6174),
    [anon_sym_not] = ACTIONS(6172),
    [anon_sym_NOT] = ACTIONS(6172),
    [anon_sym_Not] = ACTIONS(6172),
    [anon_sym_POUNDelif] = ACTIONS(6174),
    [anon_sym_POUNDELIF] = ACTIONS(6174),
    [anon_sym_POUNDElif] = ACTIONS(6174),
    [anon_sym_POUNDelse] = ACTIONS(6174),
    [anon_sym_POUNDELSE] = ACTIONS(6174),
    [anon_sym_POUNDElse] = ACTIONS(6174),
    [anon_sym_POUNDelse2] = ACTIONS(6174),
    [anon_sym_POUNDELSE2] = ACTIONS(6174),
    [anon_sym_POUNDElse2] = ACTIONS(6174),
    [anon_sym_POUNDendif] = ACTIONS(6174),
    [anon_sym_POUNDENDIF] = ACTIONS(6174),
    [anon_sym_POUNDEndif] = ACTIONS(6174),
    [anon_sym_POUNDendif2] = ACTIONS(6174),
    [anon_sym_POUNDENDIF2] = ACTIONS(6174),
    [anon_sym_POUNDEndif2] = ACTIONS(6174),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6172),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6172),
    [anon_sym_PLUS] = ACTIONS(6174),
    [sym_datetime_literal] = ACTIONS(6174),
    [sym_date_literal] = ACTIONS(6172),
    [sym_time_literal] = ACTIONS(6172),
    [sym_biginteger_literal] = ACTIONS(6174),
    [anon_sym_if] = ACTIONS(6172),
    [anon_sym_IF] = ACTIONS(6172),
    [anon_sym_If] = ACTIONS(6172),
    [anon_sym_else] = ACTIONS(6172),
    [anon_sym_ELSE] = ACTIONS(6172),
    [anon_sym_Else] = ACTIONS(6172),
    [anon_sym_case] = ACTIONS(6172),
    [anon_sym_CASE] = ACTIONS(6172),
    [anon_sym_Case] = ACTIONS(6172),
    [anon_sym_for] = ACTIONS(6172),
    [anon_sym_FOR] = ACTIONS(6172),
    [anon_sym_For] = ACTIONS(6172),
    [anon_sym_foreach] = ACTIONS(6172),
    [anon_sym_FOREACH] = ACTIONS(6172),
    [anon_sym_Foreach] = ACTIONS(6172),
    [anon_sym_while] = ACTIONS(6172),
    [anon_sym_WHILE] = ACTIONS(6172),
    [anon_sym_While] = ACTIONS(6172),
    [anon_sym_repeat] = ACTIONS(6172),
    [anon_sym_REPEAT] = ACTIONS(6172),
    [anon_sym_Repeat] = ACTIONS(6172),
    [anon_sym_exit] = ACTIONS(6172),
    [anon_sym_EXIT] = ACTIONS(6172),
    [anon_sym_Exit] = ACTIONS(6172),
    [anon_sym_continue] = ACTIONS(6172),
    [anon_sym_CONTINUE] = ACTIONS(6172),
    [anon_sym_Continue] = ACTIONS(6172),
    [anon_sym_break] = ACTIONS(6172),
    [anon_sym_BREAK] = ACTIONS(6172),
    [anon_sym_Break] = ACTIONS(6172),
    [anon_sym_with] = ACTIONS(6172),
    [anon_sym_WITH] = ACTIONS(6172),
    [anon_sym_With] = ACTIONS(6172),
    [sym_asserterror_keyword] = ACTIONS(6174),
    [sym_page_keyword] = ACTIONS(6172),
    [anon_sym_codeunit] = ACTIONS(6172),
    [anon_sym_CODEUNIT] = ACTIONS(6172),
    [anon_sym_Codeunit] = ACTIONS(6172),
    [anon_sym_CodeUnit] = ACTIONS(6172),
    [anon_sym_COdeunit] = ACTIONS(6172),
    [anon_sym_codeUnit] = ACTIONS(6172),
    [sym_report_keyword] = ACTIONS(6172),
    [sym_query_keyword] = ACTIONS(6172),
    [anon_sym_xmlport] = ACTIONS(6172),
    [anon_sym_XMLPORT] = ACTIONS(6172),
    [anon_sym_Xmlport] = ACTIONS(6172),
    [anon_sym_XMLport] = ACTIONS(6172),
    [anon_sym_XMLPort] = ACTIONS(6172),
    [anon_sym_XmlPort] = ACTIONS(6172),
    [anon_sym_enum] = ACTIONS(6172),
    [anon_sym_ENUM] = ACTIONS(6172),
    [anon_sym_Enum] = ACTIONS(6172),
    [anon_sym_eNUM] = ACTIONS(6172),
    [anon_sym_eNum] = ACTIONS(6172),
    [anon_sym_ENum] = ACTIONS(6172),
    [sym_quoted_identifier] = ACTIONS(6174),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6174),
    [sym_verbatim_string] = ACTIONS(6174),
    [sym_integer] = ACTIONS(6172),
    [sym_continue_as_identifier] = ACTIONS(6174),
    [sym_preproc_open] = ACTIONS(6174),
    [sym_preproc_close] = ACTIONS(6174),
  },
  [STATE(2573)] = {
    [sym_identifier] = ACTIONS(6176),
    [anon_sym_SEMI] = ACTIONS(6178),
    [anon_sym_DASH] = ACTIONS(6178),
    [aux_sym_boolean_token1] = ACTIONS(6176),
    [aux_sym_boolean_token2] = ACTIONS(6176),
    [sym_decimal] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6178),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6176),
    [anon_sym_LBRACK] = ACTIONS(6178),
    [aux_sym_record_type_token1] = ACTIONS(6176),
    [aux_sym_basic_type_token21] = ACTIONS(6176),
    [aux_sym_basic_type_token22] = ACTIONS(6176),
    [aux_sym_basic_type_token48] = ACTIONS(6176),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6176),
    [anon_sym_POUNDif] = ACTIONS(6178),
    [anon_sym_POUNDIF] = ACTIONS(6178),
    [anon_sym_POUNDIf] = ACTIONS(6178),
    [anon_sym_not] = ACTIONS(6176),
    [anon_sym_NOT] = ACTIONS(6176),
    [anon_sym_Not] = ACTIONS(6176),
    [anon_sym_POUNDelif] = ACTIONS(6178),
    [anon_sym_POUNDELIF] = ACTIONS(6178),
    [anon_sym_POUNDElif] = ACTIONS(6178),
    [anon_sym_POUNDelse] = ACTIONS(6178),
    [anon_sym_POUNDELSE] = ACTIONS(6178),
    [anon_sym_POUNDElse] = ACTIONS(6178),
    [anon_sym_POUNDelse2] = ACTIONS(6178),
    [anon_sym_POUNDELSE2] = ACTIONS(6178),
    [anon_sym_POUNDElse2] = ACTIONS(6178),
    [anon_sym_POUNDendif] = ACTIONS(6178),
    [anon_sym_POUNDENDIF] = ACTIONS(6178),
    [anon_sym_POUNDEndif] = ACTIONS(6178),
    [anon_sym_POUNDendif2] = ACTIONS(6178),
    [anon_sym_POUNDENDIF2] = ACTIONS(6178),
    [anon_sym_POUNDEndif2] = ACTIONS(6178),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6176),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6176),
    [anon_sym_PLUS] = ACTIONS(6178),
    [sym_datetime_literal] = ACTIONS(6178),
    [sym_date_literal] = ACTIONS(6176),
    [sym_time_literal] = ACTIONS(6176),
    [sym_biginteger_literal] = ACTIONS(6178),
    [anon_sym_if] = ACTIONS(6176),
    [anon_sym_IF] = ACTIONS(6176),
    [anon_sym_If] = ACTIONS(6176),
    [anon_sym_else] = ACTIONS(6176),
    [anon_sym_ELSE] = ACTIONS(6176),
    [anon_sym_Else] = ACTIONS(6176),
    [anon_sym_case] = ACTIONS(6176),
    [anon_sym_CASE] = ACTIONS(6176),
    [anon_sym_Case] = ACTIONS(6176),
    [anon_sym_for] = ACTIONS(6176),
    [anon_sym_FOR] = ACTIONS(6176),
    [anon_sym_For] = ACTIONS(6176),
    [anon_sym_foreach] = ACTIONS(6176),
    [anon_sym_FOREACH] = ACTIONS(6176),
    [anon_sym_Foreach] = ACTIONS(6176),
    [anon_sym_while] = ACTIONS(6176),
    [anon_sym_WHILE] = ACTIONS(6176),
    [anon_sym_While] = ACTIONS(6176),
    [anon_sym_repeat] = ACTIONS(6176),
    [anon_sym_REPEAT] = ACTIONS(6176),
    [anon_sym_Repeat] = ACTIONS(6176),
    [anon_sym_exit] = ACTIONS(6176),
    [anon_sym_EXIT] = ACTIONS(6176),
    [anon_sym_Exit] = ACTIONS(6176),
    [anon_sym_continue] = ACTIONS(6176),
    [anon_sym_CONTINUE] = ACTIONS(6176),
    [anon_sym_Continue] = ACTIONS(6176),
    [anon_sym_break] = ACTIONS(6176),
    [anon_sym_BREAK] = ACTIONS(6176),
    [anon_sym_Break] = ACTIONS(6176),
    [anon_sym_with] = ACTIONS(6176),
    [anon_sym_WITH] = ACTIONS(6176),
    [anon_sym_With] = ACTIONS(6176),
    [sym_asserterror_keyword] = ACTIONS(6178),
    [sym_page_keyword] = ACTIONS(6176),
    [anon_sym_codeunit] = ACTIONS(6176),
    [anon_sym_CODEUNIT] = ACTIONS(6176),
    [anon_sym_Codeunit] = ACTIONS(6176),
    [anon_sym_CodeUnit] = ACTIONS(6176),
    [anon_sym_COdeunit] = ACTIONS(6176),
    [anon_sym_codeUnit] = ACTIONS(6176),
    [sym_report_keyword] = ACTIONS(6176),
    [sym_query_keyword] = ACTIONS(6176),
    [anon_sym_xmlport] = ACTIONS(6176),
    [anon_sym_XMLPORT] = ACTIONS(6176),
    [anon_sym_Xmlport] = ACTIONS(6176),
    [anon_sym_XMLport] = ACTIONS(6176),
    [anon_sym_XMLPort] = ACTIONS(6176),
    [anon_sym_XmlPort] = ACTIONS(6176),
    [anon_sym_enum] = ACTIONS(6176),
    [anon_sym_ENUM] = ACTIONS(6176),
    [anon_sym_Enum] = ACTIONS(6176),
    [anon_sym_eNUM] = ACTIONS(6176),
    [anon_sym_eNum] = ACTIONS(6176),
    [anon_sym_ENum] = ACTIONS(6176),
    [sym_quoted_identifier] = ACTIONS(6178),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6178),
    [sym_verbatim_string] = ACTIONS(6178),
    [sym_integer] = ACTIONS(6176),
    [sym_continue_as_identifier] = ACTIONS(6178),
    [sym_preproc_open] = ACTIONS(6178),
    [sym_preproc_close] = ACTIONS(6178),
  },
  [STATE(2574)] = {
    [sym_identifier] = ACTIONS(6180),
    [anon_sym_SEMI] = ACTIONS(6182),
    [anon_sym_DASH] = ACTIONS(6182),
    [aux_sym_boolean_token1] = ACTIONS(6180),
    [aux_sym_boolean_token2] = ACTIONS(6180),
    [sym_decimal] = ACTIONS(6180),
    [anon_sym_LPAREN] = ACTIONS(6182),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6180),
    [anon_sym_LBRACK] = ACTIONS(6182),
    [aux_sym_record_type_token1] = ACTIONS(6180),
    [aux_sym_basic_type_token21] = ACTIONS(6180),
    [aux_sym_basic_type_token22] = ACTIONS(6180),
    [aux_sym_basic_type_token48] = ACTIONS(6180),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6180),
    [anon_sym_POUNDif] = ACTIONS(6182),
    [anon_sym_POUNDIF] = ACTIONS(6182),
    [anon_sym_POUNDIf] = ACTIONS(6182),
    [anon_sym_not] = ACTIONS(6180),
    [anon_sym_NOT] = ACTIONS(6180),
    [anon_sym_Not] = ACTIONS(6180),
    [anon_sym_POUNDelif] = ACTIONS(6182),
    [anon_sym_POUNDELIF] = ACTIONS(6182),
    [anon_sym_POUNDElif] = ACTIONS(6182),
    [anon_sym_POUNDelse] = ACTIONS(6182),
    [anon_sym_POUNDELSE] = ACTIONS(6182),
    [anon_sym_POUNDElse] = ACTIONS(6182),
    [anon_sym_POUNDelse2] = ACTIONS(6182),
    [anon_sym_POUNDELSE2] = ACTIONS(6182),
    [anon_sym_POUNDElse2] = ACTIONS(6182),
    [anon_sym_POUNDendif] = ACTIONS(6182),
    [anon_sym_POUNDENDIF] = ACTIONS(6182),
    [anon_sym_POUNDEndif] = ACTIONS(6182),
    [anon_sym_POUNDendif2] = ACTIONS(6182),
    [anon_sym_POUNDENDIF2] = ACTIONS(6182),
    [anon_sym_POUNDEndif2] = ACTIONS(6182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6180),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6180),
    [anon_sym_PLUS] = ACTIONS(6182),
    [sym_datetime_literal] = ACTIONS(6182),
    [sym_date_literal] = ACTIONS(6180),
    [sym_time_literal] = ACTIONS(6180),
    [sym_biginteger_literal] = ACTIONS(6182),
    [anon_sym_if] = ACTIONS(6180),
    [anon_sym_IF] = ACTIONS(6180),
    [anon_sym_If] = ACTIONS(6180),
    [anon_sym_else] = ACTIONS(6180),
    [anon_sym_ELSE] = ACTIONS(6180),
    [anon_sym_Else] = ACTIONS(6180),
    [anon_sym_case] = ACTIONS(6180),
    [anon_sym_CASE] = ACTIONS(6180),
    [anon_sym_Case] = ACTIONS(6180),
    [anon_sym_for] = ACTIONS(6180),
    [anon_sym_FOR] = ACTIONS(6180),
    [anon_sym_For] = ACTIONS(6180),
    [anon_sym_foreach] = ACTIONS(6180),
    [anon_sym_FOREACH] = ACTIONS(6180),
    [anon_sym_Foreach] = ACTIONS(6180),
    [anon_sym_while] = ACTIONS(6180),
    [anon_sym_WHILE] = ACTIONS(6180),
    [anon_sym_While] = ACTIONS(6180),
    [anon_sym_repeat] = ACTIONS(6180),
    [anon_sym_REPEAT] = ACTIONS(6180),
    [anon_sym_Repeat] = ACTIONS(6180),
    [anon_sym_exit] = ACTIONS(6180),
    [anon_sym_EXIT] = ACTIONS(6180),
    [anon_sym_Exit] = ACTIONS(6180),
    [anon_sym_continue] = ACTIONS(6180),
    [anon_sym_CONTINUE] = ACTIONS(6180),
    [anon_sym_Continue] = ACTIONS(6180),
    [anon_sym_break] = ACTIONS(6180),
    [anon_sym_BREAK] = ACTIONS(6180),
    [anon_sym_Break] = ACTIONS(6180),
    [anon_sym_with] = ACTIONS(6180),
    [anon_sym_WITH] = ACTIONS(6180),
    [anon_sym_With] = ACTIONS(6180),
    [sym_asserterror_keyword] = ACTIONS(6182),
    [sym_page_keyword] = ACTIONS(6180),
    [anon_sym_codeunit] = ACTIONS(6180),
    [anon_sym_CODEUNIT] = ACTIONS(6180),
    [anon_sym_Codeunit] = ACTIONS(6180),
    [anon_sym_CodeUnit] = ACTIONS(6180),
    [anon_sym_COdeunit] = ACTIONS(6180),
    [anon_sym_codeUnit] = ACTIONS(6180),
    [sym_report_keyword] = ACTIONS(6180),
    [sym_query_keyword] = ACTIONS(6180),
    [anon_sym_xmlport] = ACTIONS(6180),
    [anon_sym_XMLPORT] = ACTIONS(6180),
    [anon_sym_Xmlport] = ACTIONS(6180),
    [anon_sym_XMLport] = ACTIONS(6180),
    [anon_sym_XMLPort] = ACTIONS(6180),
    [anon_sym_XmlPort] = ACTIONS(6180),
    [anon_sym_enum] = ACTIONS(6180),
    [anon_sym_ENUM] = ACTIONS(6180),
    [anon_sym_Enum] = ACTIONS(6180),
    [anon_sym_eNUM] = ACTIONS(6180),
    [anon_sym_eNum] = ACTIONS(6180),
    [anon_sym_ENum] = ACTIONS(6180),
    [sym_quoted_identifier] = ACTIONS(6182),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6182),
    [sym_verbatim_string] = ACTIONS(6182),
    [sym_integer] = ACTIONS(6180),
    [sym_continue_as_identifier] = ACTIONS(6182),
    [sym_preproc_open] = ACTIONS(6182),
    [sym_preproc_close] = ACTIONS(6182),
  },
  [STATE(2575)] = {
    [sym_identifier] = ACTIONS(6184),
    [anon_sym_SEMI] = ACTIONS(6186),
    [anon_sym_DASH] = ACTIONS(6186),
    [aux_sym_boolean_token1] = ACTIONS(6184),
    [aux_sym_boolean_token2] = ACTIONS(6184),
    [sym_decimal] = ACTIONS(6184),
    [anon_sym_LPAREN] = ACTIONS(6186),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6184),
    [anon_sym_LBRACK] = ACTIONS(6186),
    [aux_sym_record_type_token1] = ACTIONS(6184),
    [aux_sym_basic_type_token21] = ACTIONS(6184),
    [aux_sym_basic_type_token22] = ACTIONS(6184),
    [aux_sym_basic_type_token48] = ACTIONS(6184),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6184),
    [anon_sym_POUNDif] = ACTIONS(6186),
    [anon_sym_POUNDIF] = ACTIONS(6186),
    [anon_sym_POUNDIf] = ACTIONS(6186),
    [anon_sym_not] = ACTIONS(6184),
    [anon_sym_NOT] = ACTIONS(6184),
    [anon_sym_Not] = ACTIONS(6184),
    [anon_sym_POUNDelif] = ACTIONS(6186),
    [anon_sym_POUNDELIF] = ACTIONS(6186),
    [anon_sym_POUNDElif] = ACTIONS(6186),
    [anon_sym_POUNDelse] = ACTIONS(6186),
    [anon_sym_POUNDELSE] = ACTIONS(6186),
    [anon_sym_POUNDElse] = ACTIONS(6186),
    [anon_sym_POUNDelse2] = ACTIONS(6186),
    [anon_sym_POUNDELSE2] = ACTIONS(6186),
    [anon_sym_POUNDElse2] = ACTIONS(6186),
    [anon_sym_POUNDendif] = ACTIONS(6186),
    [anon_sym_POUNDENDIF] = ACTIONS(6186),
    [anon_sym_POUNDEndif] = ACTIONS(6186),
    [anon_sym_POUNDendif2] = ACTIONS(6186),
    [anon_sym_POUNDENDIF2] = ACTIONS(6186),
    [anon_sym_POUNDEndif2] = ACTIONS(6186),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6184),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6184),
    [anon_sym_PLUS] = ACTIONS(6186),
    [sym_datetime_literal] = ACTIONS(6186),
    [sym_date_literal] = ACTIONS(6184),
    [sym_time_literal] = ACTIONS(6184),
    [sym_biginteger_literal] = ACTIONS(6186),
    [anon_sym_if] = ACTIONS(6184),
    [anon_sym_IF] = ACTIONS(6184),
    [anon_sym_If] = ACTIONS(6184),
    [anon_sym_else] = ACTIONS(6184),
    [anon_sym_ELSE] = ACTIONS(6184),
    [anon_sym_Else] = ACTIONS(6184),
    [anon_sym_case] = ACTIONS(6184),
    [anon_sym_CASE] = ACTIONS(6184),
    [anon_sym_Case] = ACTIONS(6184),
    [anon_sym_for] = ACTIONS(6184),
    [anon_sym_FOR] = ACTIONS(6184),
    [anon_sym_For] = ACTIONS(6184),
    [anon_sym_foreach] = ACTIONS(6184),
    [anon_sym_FOREACH] = ACTIONS(6184),
    [anon_sym_Foreach] = ACTIONS(6184),
    [anon_sym_while] = ACTIONS(6184),
    [anon_sym_WHILE] = ACTIONS(6184),
    [anon_sym_While] = ACTIONS(6184),
    [anon_sym_repeat] = ACTIONS(6184),
    [anon_sym_REPEAT] = ACTIONS(6184),
    [anon_sym_Repeat] = ACTIONS(6184),
    [anon_sym_exit] = ACTIONS(6184),
    [anon_sym_EXIT] = ACTIONS(6184),
    [anon_sym_Exit] = ACTIONS(6184),
    [anon_sym_continue] = ACTIONS(6184),
    [anon_sym_CONTINUE] = ACTIONS(6184),
    [anon_sym_Continue] = ACTIONS(6184),
    [anon_sym_break] = ACTIONS(6184),
    [anon_sym_BREAK] = ACTIONS(6184),
    [anon_sym_Break] = ACTIONS(6184),
    [anon_sym_with] = ACTIONS(6184),
    [anon_sym_WITH] = ACTIONS(6184),
    [anon_sym_With] = ACTIONS(6184),
    [sym_asserterror_keyword] = ACTIONS(6186),
    [sym_page_keyword] = ACTIONS(6184),
    [anon_sym_codeunit] = ACTIONS(6184),
    [anon_sym_CODEUNIT] = ACTIONS(6184),
    [anon_sym_Codeunit] = ACTIONS(6184),
    [anon_sym_CodeUnit] = ACTIONS(6184),
    [anon_sym_COdeunit] = ACTIONS(6184),
    [anon_sym_codeUnit] = ACTIONS(6184),
    [sym_report_keyword] = ACTIONS(6184),
    [sym_query_keyword] = ACTIONS(6184),
    [anon_sym_xmlport] = ACTIONS(6184),
    [anon_sym_XMLPORT] = ACTIONS(6184),
    [anon_sym_Xmlport] = ACTIONS(6184),
    [anon_sym_XMLport] = ACTIONS(6184),
    [anon_sym_XMLPort] = ACTIONS(6184),
    [anon_sym_XmlPort] = ACTIONS(6184),
    [anon_sym_enum] = ACTIONS(6184),
    [anon_sym_ENUM] = ACTIONS(6184),
    [anon_sym_Enum] = ACTIONS(6184),
    [anon_sym_eNUM] = ACTIONS(6184),
    [anon_sym_eNum] = ACTIONS(6184),
    [anon_sym_ENum] = ACTIONS(6184),
    [sym_quoted_identifier] = ACTIONS(6186),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6186),
    [sym_verbatim_string] = ACTIONS(6186),
    [sym_integer] = ACTIONS(6184),
    [sym_continue_as_identifier] = ACTIONS(6186),
    [sym_preproc_open] = ACTIONS(6186),
    [sym_preproc_close] = ACTIONS(6186),
  },
  [STATE(2576)] = {
    [sym_identifier] = ACTIONS(6188),
    [anon_sym_SEMI] = ACTIONS(6190),
    [anon_sym_DASH] = ACTIONS(6190),
    [aux_sym_boolean_token1] = ACTIONS(6188),
    [aux_sym_boolean_token2] = ACTIONS(6188),
    [sym_decimal] = ACTIONS(6188),
    [anon_sym_LPAREN] = ACTIONS(6190),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6188),
    [anon_sym_LBRACK] = ACTIONS(6190),
    [aux_sym_record_type_token1] = ACTIONS(6188),
    [aux_sym_basic_type_token21] = ACTIONS(6188),
    [aux_sym_basic_type_token22] = ACTIONS(6188),
    [aux_sym_basic_type_token48] = ACTIONS(6188),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6188),
    [anon_sym_POUNDif] = ACTIONS(6190),
    [anon_sym_POUNDIF] = ACTIONS(6190),
    [anon_sym_POUNDIf] = ACTIONS(6190),
    [anon_sym_not] = ACTIONS(6188),
    [anon_sym_NOT] = ACTIONS(6188),
    [anon_sym_Not] = ACTIONS(6188),
    [anon_sym_POUNDelif] = ACTIONS(6190),
    [anon_sym_POUNDELIF] = ACTIONS(6190),
    [anon_sym_POUNDElif] = ACTIONS(6190),
    [anon_sym_POUNDelse] = ACTIONS(6190),
    [anon_sym_POUNDELSE] = ACTIONS(6190),
    [anon_sym_POUNDElse] = ACTIONS(6190),
    [anon_sym_POUNDelse2] = ACTIONS(6190),
    [anon_sym_POUNDELSE2] = ACTIONS(6190),
    [anon_sym_POUNDElse2] = ACTIONS(6190),
    [anon_sym_POUNDendif] = ACTIONS(6190),
    [anon_sym_POUNDENDIF] = ACTIONS(6190),
    [anon_sym_POUNDEndif] = ACTIONS(6190),
    [anon_sym_POUNDendif2] = ACTIONS(6190),
    [anon_sym_POUNDENDIF2] = ACTIONS(6190),
    [anon_sym_POUNDEndif2] = ACTIONS(6190),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6188),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6188),
    [anon_sym_PLUS] = ACTIONS(6190),
    [sym_datetime_literal] = ACTIONS(6190),
    [sym_date_literal] = ACTIONS(6188),
    [sym_time_literal] = ACTIONS(6188),
    [sym_biginteger_literal] = ACTIONS(6190),
    [anon_sym_if] = ACTIONS(6188),
    [anon_sym_IF] = ACTIONS(6188),
    [anon_sym_If] = ACTIONS(6188),
    [anon_sym_else] = ACTIONS(6188),
    [anon_sym_ELSE] = ACTIONS(6188),
    [anon_sym_Else] = ACTIONS(6188),
    [anon_sym_case] = ACTIONS(6188),
    [anon_sym_CASE] = ACTIONS(6188),
    [anon_sym_Case] = ACTIONS(6188),
    [anon_sym_for] = ACTIONS(6188),
    [anon_sym_FOR] = ACTIONS(6188),
    [anon_sym_For] = ACTIONS(6188),
    [anon_sym_foreach] = ACTIONS(6188),
    [anon_sym_FOREACH] = ACTIONS(6188),
    [anon_sym_Foreach] = ACTIONS(6188),
    [anon_sym_while] = ACTIONS(6188),
    [anon_sym_WHILE] = ACTIONS(6188),
    [anon_sym_While] = ACTIONS(6188),
    [anon_sym_repeat] = ACTIONS(6188),
    [anon_sym_REPEAT] = ACTIONS(6188),
    [anon_sym_Repeat] = ACTIONS(6188),
    [anon_sym_exit] = ACTIONS(6188),
    [anon_sym_EXIT] = ACTIONS(6188),
    [anon_sym_Exit] = ACTIONS(6188),
    [anon_sym_continue] = ACTIONS(6188),
    [anon_sym_CONTINUE] = ACTIONS(6188),
    [anon_sym_Continue] = ACTIONS(6188),
    [anon_sym_break] = ACTIONS(6188),
    [anon_sym_BREAK] = ACTIONS(6188),
    [anon_sym_Break] = ACTIONS(6188),
    [anon_sym_with] = ACTIONS(6188),
    [anon_sym_WITH] = ACTIONS(6188),
    [anon_sym_With] = ACTIONS(6188),
    [sym_asserterror_keyword] = ACTIONS(6190),
    [sym_page_keyword] = ACTIONS(6188),
    [anon_sym_codeunit] = ACTIONS(6188),
    [anon_sym_CODEUNIT] = ACTIONS(6188),
    [anon_sym_Codeunit] = ACTIONS(6188),
    [anon_sym_CodeUnit] = ACTIONS(6188),
    [anon_sym_COdeunit] = ACTIONS(6188),
    [anon_sym_codeUnit] = ACTIONS(6188),
    [sym_report_keyword] = ACTIONS(6188),
    [sym_query_keyword] = ACTIONS(6188),
    [anon_sym_xmlport] = ACTIONS(6188),
    [anon_sym_XMLPORT] = ACTIONS(6188),
    [anon_sym_Xmlport] = ACTIONS(6188),
    [anon_sym_XMLport] = ACTIONS(6188),
    [anon_sym_XMLPort] = ACTIONS(6188),
    [anon_sym_XmlPort] = ACTIONS(6188),
    [anon_sym_enum] = ACTIONS(6188),
    [anon_sym_ENUM] = ACTIONS(6188),
    [anon_sym_Enum] = ACTIONS(6188),
    [anon_sym_eNUM] = ACTIONS(6188),
    [anon_sym_eNum] = ACTIONS(6188),
    [anon_sym_ENum] = ACTIONS(6188),
    [sym_quoted_identifier] = ACTIONS(6190),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6190),
    [sym_verbatim_string] = ACTIONS(6190),
    [sym_integer] = ACTIONS(6188),
    [sym_continue_as_identifier] = ACTIONS(6190),
    [sym_preproc_open] = ACTIONS(6190),
    [sym_preproc_close] = ACTIONS(6190),
  },
  [STATE(2577)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [anon_sym_DASH] = ACTIONS(6194),
    [aux_sym_boolean_token1] = ACTIONS(6192),
    [aux_sym_boolean_token2] = ACTIONS(6192),
    [sym_decimal] = ACTIONS(6192),
    [anon_sym_LPAREN] = ACTIONS(6194),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [aux_sym_record_type_token1] = ACTIONS(6192),
    [aux_sym_basic_type_token21] = ACTIONS(6192),
    [aux_sym_basic_type_token22] = ACTIONS(6192),
    [aux_sym_basic_type_token48] = ACTIONS(6192),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6192),
    [anon_sym_POUNDif] = ACTIONS(6194),
    [anon_sym_POUNDIF] = ACTIONS(6194),
    [anon_sym_POUNDIf] = ACTIONS(6194),
    [anon_sym_not] = ACTIONS(6192),
    [anon_sym_NOT] = ACTIONS(6192),
    [anon_sym_Not] = ACTIONS(6192),
    [anon_sym_POUNDelif] = ACTIONS(6194),
    [anon_sym_POUNDELIF] = ACTIONS(6194),
    [anon_sym_POUNDElif] = ACTIONS(6194),
    [anon_sym_POUNDelse] = ACTIONS(6194),
    [anon_sym_POUNDELSE] = ACTIONS(6194),
    [anon_sym_POUNDElse] = ACTIONS(6194),
    [anon_sym_POUNDelse2] = ACTIONS(6194),
    [anon_sym_POUNDELSE2] = ACTIONS(6194),
    [anon_sym_POUNDElse2] = ACTIONS(6194),
    [anon_sym_POUNDendif] = ACTIONS(6194),
    [anon_sym_POUNDENDIF] = ACTIONS(6194),
    [anon_sym_POUNDEndif] = ACTIONS(6194),
    [anon_sym_POUNDendif2] = ACTIONS(6194),
    [anon_sym_POUNDENDIF2] = ACTIONS(6194),
    [anon_sym_POUNDEndif2] = ACTIONS(6194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6192),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6192),
    [anon_sym_PLUS] = ACTIONS(6194),
    [sym_datetime_literal] = ACTIONS(6194),
    [sym_date_literal] = ACTIONS(6192),
    [sym_time_literal] = ACTIONS(6192),
    [sym_biginteger_literal] = ACTIONS(6194),
    [anon_sym_if] = ACTIONS(6192),
    [anon_sym_IF] = ACTIONS(6192),
    [anon_sym_If] = ACTIONS(6192),
    [anon_sym_else] = ACTIONS(6192),
    [anon_sym_ELSE] = ACTIONS(6192),
    [anon_sym_Else] = ACTIONS(6192),
    [anon_sym_case] = ACTIONS(6192),
    [anon_sym_CASE] = ACTIONS(6192),
    [anon_sym_Case] = ACTIONS(6192),
    [anon_sym_for] = ACTIONS(6192),
    [anon_sym_FOR] = ACTIONS(6192),
    [anon_sym_For] = ACTIONS(6192),
    [anon_sym_foreach] = ACTIONS(6192),
    [anon_sym_FOREACH] = ACTIONS(6192),
    [anon_sym_Foreach] = ACTIONS(6192),
    [anon_sym_while] = ACTIONS(6192),
    [anon_sym_WHILE] = ACTIONS(6192),
    [anon_sym_While] = ACTIONS(6192),
    [anon_sym_repeat] = ACTIONS(6192),
    [anon_sym_REPEAT] = ACTIONS(6192),
    [anon_sym_Repeat] = ACTIONS(6192),
    [anon_sym_exit] = ACTIONS(6192),
    [anon_sym_EXIT] = ACTIONS(6192),
    [anon_sym_Exit] = ACTIONS(6192),
    [anon_sym_continue] = ACTIONS(6192),
    [anon_sym_CONTINUE] = ACTIONS(6192),
    [anon_sym_Continue] = ACTIONS(6192),
    [anon_sym_break] = ACTIONS(6192),
    [anon_sym_BREAK] = ACTIONS(6192),
    [anon_sym_Break] = ACTIONS(6192),
    [anon_sym_with] = ACTIONS(6192),
    [anon_sym_WITH] = ACTIONS(6192),
    [anon_sym_With] = ACTIONS(6192),
    [sym_asserterror_keyword] = ACTIONS(6194),
    [sym_page_keyword] = ACTIONS(6192),
    [anon_sym_codeunit] = ACTIONS(6192),
    [anon_sym_CODEUNIT] = ACTIONS(6192),
    [anon_sym_Codeunit] = ACTIONS(6192),
    [anon_sym_CodeUnit] = ACTIONS(6192),
    [anon_sym_COdeunit] = ACTIONS(6192),
    [anon_sym_codeUnit] = ACTIONS(6192),
    [sym_report_keyword] = ACTIONS(6192),
    [sym_query_keyword] = ACTIONS(6192),
    [anon_sym_xmlport] = ACTIONS(6192),
    [anon_sym_XMLPORT] = ACTIONS(6192),
    [anon_sym_Xmlport] = ACTIONS(6192),
    [anon_sym_XMLport] = ACTIONS(6192),
    [anon_sym_XMLPort] = ACTIONS(6192),
    [anon_sym_XmlPort] = ACTIONS(6192),
    [anon_sym_enum] = ACTIONS(6192),
    [anon_sym_ENUM] = ACTIONS(6192),
    [anon_sym_Enum] = ACTIONS(6192),
    [anon_sym_eNUM] = ACTIONS(6192),
    [anon_sym_eNum] = ACTIONS(6192),
    [anon_sym_ENum] = ACTIONS(6192),
    [sym_quoted_identifier] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6194),
    [sym_verbatim_string] = ACTIONS(6194),
    [sym_integer] = ACTIONS(6192),
    [sym_continue_as_identifier] = ACTIONS(6194),
    [sym_preproc_open] = ACTIONS(6194),
    [sym_preproc_close] = ACTIONS(6194),
  },
  [STATE(2578)] = {
    [sym_identifier] = ACTIONS(6114),
    [anon_sym_SEMI] = ACTIONS(6116),
    [anon_sym_DASH] = ACTIONS(6116),
    [aux_sym_boolean_token1] = ACTIONS(6114),
    [aux_sym_boolean_token2] = ACTIONS(6114),
    [sym_decimal] = ACTIONS(6114),
    [anon_sym_LPAREN] = ACTIONS(6116),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6114),
    [anon_sym_LBRACK] = ACTIONS(6116),
    [aux_sym_record_type_token1] = ACTIONS(6114),
    [aux_sym_basic_type_token21] = ACTIONS(6114),
    [aux_sym_basic_type_token22] = ACTIONS(6114),
    [aux_sym_basic_type_token48] = ACTIONS(6114),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6114),
    [anon_sym_POUNDif] = ACTIONS(6116),
    [anon_sym_POUNDIF] = ACTIONS(6116),
    [anon_sym_POUNDIf] = ACTIONS(6116),
    [anon_sym_not] = ACTIONS(6114),
    [anon_sym_NOT] = ACTIONS(6114),
    [anon_sym_Not] = ACTIONS(6114),
    [anon_sym_POUNDelif] = ACTIONS(6116),
    [anon_sym_POUNDELIF] = ACTIONS(6116),
    [anon_sym_POUNDElif] = ACTIONS(6116),
    [anon_sym_POUNDelse] = ACTIONS(6116),
    [anon_sym_POUNDELSE] = ACTIONS(6116),
    [anon_sym_POUNDElse] = ACTIONS(6116),
    [anon_sym_POUNDelse2] = ACTIONS(6116),
    [anon_sym_POUNDELSE2] = ACTIONS(6116),
    [anon_sym_POUNDElse2] = ACTIONS(6116),
    [anon_sym_POUNDendif] = ACTIONS(6116),
    [anon_sym_POUNDENDIF] = ACTIONS(6116),
    [anon_sym_POUNDEndif] = ACTIONS(6116),
    [anon_sym_POUNDendif2] = ACTIONS(6116),
    [anon_sym_POUNDENDIF2] = ACTIONS(6116),
    [anon_sym_POUNDEndif2] = ACTIONS(6116),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6114),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6114),
    [anon_sym_PLUS] = ACTIONS(6116),
    [sym_datetime_literal] = ACTIONS(6116),
    [sym_date_literal] = ACTIONS(6114),
    [sym_time_literal] = ACTIONS(6114),
    [sym_biginteger_literal] = ACTIONS(6116),
    [anon_sym_if] = ACTIONS(6114),
    [anon_sym_IF] = ACTIONS(6114),
    [anon_sym_If] = ACTIONS(6114),
    [anon_sym_else] = ACTIONS(6114),
    [anon_sym_ELSE] = ACTIONS(6114),
    [anon_sym_Else] = ACTIONS(6114),
    [anon_sym_case] = ACTIONS(6114),
    [anon_sym_CASE] = ACTIONS(6114),
    [anon_sym_Case] = ACTIONS(6114),
    [anon_sym_for] = ACTIONS(6114),
    [anon_sym_FOR] = ACTIONS(6114),
    [anon_sym_For] = ACTIONS(6114),
    [anon_sym_foreach] = ACTIONS(6114),
    [anon_sym_FOREACH] = ACTIONS(6114),
    [anon_sym_Foreach] = ACTIONS(6114),
    [anon_sym_while] = ACTIONS(6114),
    [anon_sym_WHILE] = ACTIONS(6114),
    [anon_sym_While] = ACTIONS(6114),
    [anon_sym_repeat] = ACTIONS(6114),
    [anon_sym_REPEAT] = ACTIONS(6114),
    [anon_sym_Repeat] = ACTIONS(6114),
    [anon_sym_exit] = ACTIONS(6114),
    [anon_sym_EXIT] = ACTIONS(6114),
    [anon_sym_Exit] = ACTIONS(6114),
    [anon_sym_continue] = ACTIONS(6114),
    [anon_sym_CONTINUE] = ACTIONS(6114),
    [anon_sym_Continue] = ACTIONS(6114),
    [anon_sym_break] = ACTIONS(6114),
    [anon_sym_BREAK] = ACTIONS(6114),
    [anon_sym_Break] = ACTIONS(6114),
    [anon_sym_with] = ACTIONS(6114),
    [anon_sym_WITH] = ACTIONS(6114),
    [anon_sym_With] = ACTIONS(6114),
    [sym_asserterror_keyword] = ACTIONS(6116),
    [sym_page_keyword] = ACTIONS(6114),
    [anon_sym_codeunit] = ACTIONS(6114),
    [anon_sym_CODEUNIT] = ACTIONS(6114),
    [anon_sym_Codeunit] = ACTIONS(6114),
    [anon_sym_CodeUnit] = ACTIONS(6114),
    [anon_sym_COdeunit] = ACTIONS(6114),
    [anon_sym_codeUnit] = ACTIONS(6114),
    [sym_report_keyword] = ACTIONS(6114),
    [sym_query_keyword] = ACTIONS(6114),
    [anon_sym_xmlport] = ACTIONS(6114),
    [anon_sym_XMLPORT] = ACTIONS(6114),
    [anon_sym_Xmlport] = ACTIONS(6114),
    [anon_sym_XMLport] = ACTIONS(6114),
    [anon_sym_XMLPort] = ACTIONS(6114),
    [anon_sym_XmlPort] = ACTIONS(6114),
    [anon_sym_enum] = ACTIONS(6114),
    [anon_sym_ENUM] = ACTIONS(6114),
    [anon_sym_Enum] = ACTIONS(6114),
    [anon_sym_eNUM] = ACTIONS(6114),
    [anon_sym_eNum] = ACTIONS(6114),
    [anon_sym_ENum] = ACTIONS(6114),
    [sym_quoted_identifier] = ACTIONS(6116),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6116),
    [sym_verbatim_string] = ACTIONS(6116),
    [sym_integer] = ACTIONS(6114),
    [sym_continue_as_identifier] = ACTIONS(6116),
    [sym_preproc_open] = ACTIONS(6116),
    [sym_preproc_close] = ACTIONS(6116),
  },
  [STATE(2579)] = {
    [sym_identifier] = ACTIONS(6196),
    [anon_sym_SEMI] = ACTIONS(6198),
    [anon_sym_DASH] = ACTIONS(6198),
    [aux_sym_boolean_token1] = ACTIONS(6196),
    [aux_sym_boolean_token2] = ACTIONS(6196),
    [sym_decimal] = ACTIONS(6196),
    [anon_sym_LPAREN] = ACTIONS(6198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6196),
    [anon_sym_LBRACK] = ACTIONS(6198),
    [aux_sym_record_type_token1] = ACTIONS(6196),
    [aux_sym_basic_type_token21] = ACTIONS(6196),
    [aux_sym_basic_type_token22] = ACTIONS(6196),
    [aux_sym_basic_type_token48] = ACTIONS(6196),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6196),
    [anon_sym_POUNDif] = ACTIONS(6198),
    [anon_sym_POUNDIF] = ACTIONS(6198),
    [anon_sym_POUNDIf] = ACTIONS(6198),
    [anon_sym_not] = ACTIONS(6196),
    [anon_sym_NOT] = ACTIONS(6196),
    [anon_sym_Not] = ACTIONS(6196),
    [anon_sym_POUNDelif] = ACTIONS(6198),
    [anon_sym_POUNDELIF] = ACTIONS(6198),
    [anon_sym_POUNDElif] = ACTIONS(6198),
    [anon_sym_POUNDelse] = ACTIONS(6198),
    [anon_sym_POUNDELSE] = ACTIONS(6198),
    [anon_sym_POUNDElse] = ACTIONS(6198),
    [anon_sym_POUNDelse2] = ACTIONS(6198),
    [anon_sym_POUNDELSE2] = ACTIONS(6198),
    [anon_sym_POUNDElse2] = ACTIONS(6198),
    [anon_sym_POUNDendif] = ACTIONS(6198),
    [anon_sym_POUNDENDIF] = ACTIONS(6198),
    [anon_sym_POUNDEndif] = ACTIONS(6198),
    [anon_sym_POUNDendif2] = ACTIONS(6198),
    [anon_sym_POUNDENDIF2] = ACTIONS(6198),
    [anon_sym_POUNDEndif2] = ACTIONS(6198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6196),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6196),
    [anon_sym_PLUS] = ACTIONS(6198),
    [sym_datetime_literal] = ACTIONS(6198),
    [sym_date_literal] = ACTIONS(6196),
    [sym_time_literal] = ACTIONS(6196),
    [sym_biginteger_literal] = ACTIONS(6198),
    [anon_sym_if] = ACTIONS(6196),
    [anon_sym_IF] = ACTIONS(6196),
    [anon_sym_If] = ACTIONS(6196),
    [anon_sym_else] = ACTIONS(6196),
    [anon_sym_ELSE] = ACTIONS(6196),
    [anon_sym_Else] = ACTIONS(6196),
    [anon_sym_case] = ACTIONS(6196),
    [anon_sym_CASE] = ACTIONS(6196),
    [anon_sym_Case] = ACTIONS(6196),
    [anon_sym_for] = ACTIONS(6196),
    [anon_sym_FOR] = ACTIONS(6196),
    [anon_sym_For] = ACTIONS(6196),
    [anon_sym_foreach] = ACTIONS(6196),
    [anon_sym_FOREACH] = ACTIONS(6196),
    [anon_sym_Foreach] = ACTIONS(6196),
    [anon_sym_while] = ACTIONS(6196),
    [anon_sym_WHILE] = ACTIONS(6196),
    [anon_sym_While] = ACTIONS(6196),
    [anon_sym_repeat] = ACTIONS(6196),
    [anon_sym_REPEAT] = ACTIONS(6196),
    [anon_sym_Repeat] = ACTIONS(6196),
    [anon_sym_exit] = ACTIONS(6196),
    [anon_sym_EXIT] = ACTIONS(6196),
    [anon_sym_Exit] = ACTIONS(6196),
    [anon_sym_continue] = ACTIONS(6196),
    [anon_sym_CONTINUE] = ACTIONS(6196),
    [anon_sym_Continue] = ACTIONS(6196),
    [anon_sym_break] = ACTIONS(6196),
    [anon_sym_BREAK] = ACTIONS(6196),
    [anon_sym_Break] = ACTIONS(6196),
    [anon_sym_with] = ACTIONS(6196),
    [anon_sym_WITH] = ACTIONS(6196),
    [anon_sym_With] = ACTIONS(6196),
    [sym_asserterror_keyword] = ACTIONS(6198),
    [sym_page_keyword] = ACTIONS(6196),
    [anon_sym_codeunit] = ACTIONS(6196),
    [anon_sym_CODEUNIT] = ACTIONS(6196),
    [anon_sym_Codeunit] = ACTIONS(6196),
    [anon_sym_CodeUnit] = ACTIONS(6196),
    [anon_sym_COdeunit] = ACTIONS(6196),
    [anon_sym_codeUnit] = ACTIONS(6196),
    [sym_report_keyword] = ACTIONS(6196),
    [sym_query_keyword] = ACTIONS(6196),
    [anon_sym_xmlport] = ACTIONS(6196),
    [anon_sym_XMLPORT] = ACTIONS(6196),
    [anon_sym_Xmlport] = ACTIONS(6196),
    [anon_sym_XMLport] = ACTIONS(6196),
    [anon_sym_XMLPort] = ACTIONS(6196),
    [anon_sym_XmlPort] = ACTIONS(6196),
    [anon_sym_enum] = ACTIONS(6196),
    [anon_sym_ENUM] = ACTIONS(6196),
    [anon_sym_Enum] = ACTIONS(6196),
    [anon_sym_eNUM] = ACTIONS(6196),
    [anon_sym_eNum] = ACTIONS(6196),
    [anon_sym_ENum] = ACTIONS(6196),
    [sym_quoted_identifier] = ACTIONS(6198),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6198),
    [sym_verbatim_string] = ACTIONS(6198),
    [sym_integer] = ACTIONS(6196),
    [sym_continue_as_identifier] = ACTIONS(6198),
    [sym_preproc_open] = ACTIONS(6198),
    [sym_preproc_close] = ACTIONS(6198),
  },
  [STATE(2580)] = {
    [sym_identifier] = ACTIONS(6200),
    [anon_sym_SEMI] = ACTIONS(6202),
    [anon_sym_DASH] = ACTIONS(6202),
    [aux_sym_boolean_token1] = ACTIONS(6200),
    [aux_sym_boolean_token2] = ACTIONS(6200),
    [sym_decimal] = ACTIONS(6200),
    [anon_sym_LPAREN] = ACTIONS(6202),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(6202),
    [aux_sym_record_type_token1] = ACTIONS(6200),
    [aux_sym_basic_type_token21] = ACTIONS(6200),
    [aux_sym_basic_type_token22] = ACTIONS(6200),
    [aux_sym_basic_type_token48] = ACTIONS(6200),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6200),
    [anon_sym_POUNDif] = ACTIONS(6202),
    [anon_sym_POUNDIF] = ACTIONS(6202),
    [anon_sym_POUNDIf] = ACTIONS(6202),
    [anon_sym_not] = ACTIONS(6200),
    [anon_sym_NOT] = ACTIONS(6200),
    [anon_sym_Not] = ACTIONS(6200),
    [anon_sym_POUNDelif] = ACTIONS(6202),
    [anon_sym_POUNDELIF] = ACTIONS(6202),
    [anon_sym_POUNDElif] = ACTIONS(6202),
    [anon_sym_POUNDelse] = ACTIONS(6202),
    [anon_sym_POUNDELSE] = ACTIONS(6202),
    [anon_sym_POUNDElse] = ACTIONS(6202),
    [anon_sym_POUNDelse2] = ACTIONS(6202),
    [anon_sym_POUNDELSE2] = ACTIONS(6202),
    [anon_sym_POUNDElse2] = ACTIONS(6202),
    [anon_sym_POUNDendif] = ACTIONS(6202),
    [anon_sym_POUNDENDIF] = ACTIONS(6202),
    [anon_sym_POUNDEndif] = ACTIONS(6202),
    [anon_sym_POUNDendif2] = ACTIONS(6202),
    [anon_sym_POUNDENDIF2] = ACTIONS(6202),
    [anon_sym_POUNDEndif2] = ACTIONS(6202),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6200),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6200),
    [anon_sym_PLUS] = ACTIONS(6202),
    [sym_datetime_literal] = ACTIONS(6202),
    [sym_date_literal] = ACTIONS(6200),
    [sym_time_literal] = ACTIONS(6200),
    [sym_biginteger_literal] = ACTIONS(6202),
    [anon_sym_if] = ACTIONS(6200),
    [anon_sym_IF] = ACTIONS(6200),
    [anon_sym_If] = ACTIONS(6200),
    [anon_sym_else] = ACTIONS(6200),
    [anon_sym_ELSE] = ACTIONS(6200),
    [anon_sym_Else] = ACTIONS(6200),
    [anon_sym_case] = ACTIONS(6200),
    [anon_sym_CASE] = ACTIONS(6200),
    [anon_sym_Case] = ACTIONS(6200),
    [anon_sym_for] = ACTIONS(6200),
    [anon_sym_FOR] = ACTIONS(6200),
    [anon_sym_For] = ACTIONS(6200),
    [anon_sym_foreach] = ACTIONS(6200),
    [anon_sym_FOREACH] = ACTIONS(6200),
    [anon_sym_Foreach] = ACTIONS(6200),
    [anon_sym_while] = ACTIONS(6200),
    [anon_sym_WHILE] = ACTIONS(6200),
    [anon_sym_While] = ACTIONS(6200),
    [anon_sym_repeat] = ACTIONS(6200),
    [anon_sym_REPEAT] = ACTIONS(6200),
    [anon_sym_Repeat] = ACTIONS(6200),
    [anon_sym_exit] = ACTIONS(6200),
    [anon_sym_EXIT] = ACTIONS(6200),
    [anon_sym_Exit] = ACTIONS(6200),
    [anon_sym_continue] = ACTIONS(6200),
    [anon_sym_CONTINUE] = ACTIONS(6200),
    [anon_sym_Continue] = ACTIONS(6200),
    [anon_sym_break] = ACTIONS(6200),
    [anon_sym_BREAK] = ACTIONS(6200),
    [anon_sym_Break] = ACTIONS(6200),
    [anon_sym_with] = ACTIONS(6200),
    [anon_sym_WITH] = ACTIONS(6200),
    [anon_sym_With] = ACTIONS(6200),
    [sym_asserterror_keyword] = ACTIONS(6202),
    [sym_page_keyword] = ACTIONS(6200),
    [anon_sym_codeunit] = ACTIONS(6200),
    [anon_sym_CODEUNIT] = ACTIONS(6200),
    [anon_sym_Codeunit] = ACTIONS(6200),
    [anon_sym_CodeUnit] = ACTIONS(6200),
    [anon_sym_COdeunit] = ACTIONS(6200),
    [anon_sym_codeUnit] = ACTIONS(6200),
    [sym_report_keyword] = ACTIONS(6200),
    [sym_query_keyword] = ACTIONS(6200),
    [anon_sym_xmlport] = ACTIONS(6200),
    [anon_sym_XMLPORT] = ACTIONS(6200),
    [anon_sym_Xmlport] = ACTIONS(6200),
    [anon_sym_XMLport] = ACTIONS(6200),
    [anon_sym_XMLPort] = ACTIONS(6200),
    [anon_sym_XmlPort] = ACTIONS(6200),
    [anon_sym_enum] = ACTIONS(6200),
    [anon_sym_ENUM] = ACTIONS(6200),
    [anon_sym_Enum] = ACTIONS(6200),
    [anon_sym_eNUM] = ACTIONS(6200),
    [anon_sym_eNum] = ACTIONS(6200),
    [anon_sym_ENum] = ACTIONS(6200),
    [sym_quoted_identifier] = ACTIONS(6202),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6202),
    [sym_verbatim_string] = ACTIONS(6202),
    [sym_integer] = ACTIONS(6200),
    [sym_continue_as_identifier] = ACTIONS(6202),
    [sym_preproc_open] = ACTIONS(6202),
    [sym_preproc_close] = ACTIONS(6202),
  },
  [STATE(2581)] = {
    [sym_identifier] = ACTIONS(6196),
    [anon_sym_SEMI] = ACTIONS(6198),
    [anon_sym_DASH] = ACTIONS(6198),
    [aux_sym_boolean_token1] = ACTIONS(6196),
    [aux_sym_boolean_token2] = ACTIONS(6196),
    [sym_decimal] = ACTIONS(6196),
    [anon_sym_LPAREN] = ACTIONS(6198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6196),
    [anon_sym_LBRACK] = ACTIONS(6198),
    [aux_sym_record_type_token1] = ACTIONS(6196),
    [aux_sym_basic_type_token21] = ACTIONS(6196),
    [aux_sym_basic_type_token22] = ACTIONS(6196),
    [aux_sym_basic_type_token48] = ACTIONS(6196),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6196),
    [anon_sym_POUNDif] = ACTIONS(6198),
    [anon_sym_POUNDIF] = ACTIONS(6198),
    [anon_sym_POUNDIf] = ACTIONS(6198),
    [anon_sym_not] = ACTIONS(6196),
    [anon_sym_NOT] = ACTIONS(6196),
    [anon_sym_Not] = ACTIONS(6196),
    [anon_sym_POUNDelif] = ACTIONS(6198),
    [anon_sym_POUNDELIF] = ACTIONS(6198),
    [anon_sym_POUNDElif] = ACTIONS(6198),
    [anon_sym_POUNDelse] = ACTIONS(6198),
    [anon_sym_POUNDELSE] = ACTIONS(6198),
    [anon_sym_POUNDElse] = ACTIONS(6198),
    [anon_sym_POUNDelse2] = ACTIONS(6198),
    [anon_sym_POUNDELSE2] = ACTIONS(6198),
    [anon_sym_POUNDElse2] = ACTIONS(6198),
    [anon_sym_POUNDendif] = ACTIONS(6198),
    [anon_sym_POUNDENDIF] = ACTIONS(6198),
    [anon_sym_POUNDEndif] = ACTIONS(6198),
    [anon_sym_POUNDendif2] = ACTIONS(6198),
    [anon_sym_POUNDENDIF2] = ACTIONS(6198),
    [anon_sym_POUNDEndif2] = ACTIONS(6198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6196),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6196),
    [anon_sym_PLUS] = ACTIONS(6198),
    [sym_datetime_literal] = ACTIONS(6198),
    [sym_date_literal] = ACTIONS(6196),
    [sym_time_literal] = ACTIONS(6196),
    [sym_biginteger_literal] = ACTIONS(6198),
    [anon_sym_if] = ACTIONS(6196),
    [anon_sym_IF] = ACTIONS(6196),
    [anon_sym_If] = ACTIONS(6196),
    [anon_sym_else] = ACTIONS(6196),
    [anon_sym_ELSE] = ACTIONS(6196),
    [anon_sym_Else] = ACTIONS(6196),
    [anon_sym_case] = ACTIONS(6196),
    [anon_sym_CASE] = ACTIONS(6196),
    [anon_sym_Case] = ACTIONS(6196),
    [anon_sym_for] = ACTIONS(6196),
    [anon_sym_FOR] = ACTIONS(6196),
    [anon_sym_For] = ACTIONS(6196),
    [anon_sym_foreach] = ACTIONS(6196),
    [anon_sym_FOREACH] = ACTIONS(6196),
    [anon_sym_Foreach] = ACTIONS(6196),
    [anon_sym_while] = ACTIONS(6196),
    [anon_sym_WHILE] = ACTIONS(6196),
    [anon_sym_While] = ACTIONS(6196),
    [anon_sym_repeat] = ACTIONS(6196),
    [anon_sym_REPEAT] = ACTIONS(6196),
    [anon_sym_Repeat] = ACTIONS(6196),
    [anon_sym_exit] = ACTIONS(6196),
    [anon_sym_EXIT] = ACTIONS(6196),
    [anon_sym_Exit] = ACTIONS(6196),
    [anon_sym_continue] = ACTIONS(6196),
    [anon_sym_CONTINUE] = ACTIONS(6196),
    [anon_sym_Continue] = ACTIONS(6196),
    [anon_sym_break] = ACTIONS(6196),
    [anon_sym_BREAK] = ACTIONS(6196),
    [anon_sym_Break] = ACTIONS(6196),
    [anon_sym_with] = ACTIONS(6196),
    [anon_sym_WITH] = ACTIONS(6196),
    [anon_sym_With] = ACTIONS(6196),
    [sym_asserterror_keyword] = ACTIONS(6198),
    [sym_page_keyword] = ACTIONS(6196),
    [anon_sym_codeunit] = ACTIONS(6196),
    [anon_sym_CODEUNIT] = ACTIONS(6196),
    [anon_sym_Codeunit] = ACTIONS(6196),
    [anon_sym_CodeUnit] = ACTIONS(6196),
    [anon_sym_COdeunit] = ACTIONS(6196),
    [anon_sym_codeUnit] = ACTIONS(6196),
    [sym_report_keyword] = ACTIONS(6196),
    [sym_query_keyword] = ACTIONS(6196),
    [anon_sym_xmlport] = ACTIONS(6196),
    [anon_sym_XMLPORT] = ACTIONS(6196),
    [anon_sym_Xmlport] = ACTIONS(6196),
    [anon_sym_XMLport] = ACTIONS(6196),
    [anon_sym_XMLPort] = ACTIONS(6196),
    [anon_sym_XmlPort] = ACTIONS(6196),
    [anon_sym_enum] = ACTIONS(6196),
    [anon_sym_ENUM] = ACTIONS(6196),
    [anon_sym_Enum] = ACTIONS(6196),
    [anon_sym_eNUM] = ACTIONS(6196),
    [anon_sym_eNum] = ACTIONS(6196),
    [anon_sym_ENum] = ACTIONS(6196),
    [sym_quoted_identifier] = ACTIONS(6198),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6198),
    [sym_verbatim_string] = ACTIONS(6198),
    [sym_integer] = ACTIONS(6196),
    [sym_continue_as_identifier] = ACTIONS(6198),
    [sym_preproc_open] = ACTIONS(6198),
    [sym_preproc_close] = ACTIONS(6198),
  },
  [STATE(2582)] = {
    [sym_identifier] = ACTIONS(6204),
    [anon_sym_SEMI] = ACTIONS(6206),
    [anon_sym_DASH] = ACTIONS(6206),
    [aux_sym_boolean_token1] = ACTIONS(6204),
    [aux_sym_boolean_token2] = ACTIONS(6204),
    [sym_decimal] = ACTIONS(6204),
    [anon_sym_LPAREN] = ACTIONS(6206),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6204),
    [anon_sym_LBRACK] = ACTIONS(6206),
    [aux_sym_record_type_token1] = ACTIONS(6204),
    [aux_sym_basic_type_token21] = ACTIONS(6204),
    [aux_sym_basic_type_token22] = ACTIONS(6204),
    [aux_sym_basic_type_token48] = ACTIONS(6204),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6204),
    [anon_sym_POUNDif] = ACTIONS(6206),
    [anon_sym_POUNDIF] = ACTIONS(6206),
    [anon_sym_POUNDIf] = ACTIONS(6206),
    [anon_sym_not] = ACTIONS(6204),
    [anon_sym_NOT] = ACTIONS(6204),
    [anon_sym_Not] = ACTIONS(6204),
    [anon_sym_POUNDelif] = ACTIONS(6206),
    [anon_sym_POUNDELIF] = ACTIONS(6206),
    [anon_sym_POUNDElif] = ACTIONS(6206),
    [anon_sym_POUNDelse] = ACTIONS(6206),
    [anon_sym_POUNDELSE] = ACTIONS(6206),
    [anon_sym_POUNDElse] = ACTIONS(6206),
    [anon_sym_POUNDelse2] = ACTIONS(6206),
    [anon_sym_POUNDELSE2] = ACTIONS(6206),
    [anon_sym_POUNDElse2] = ACTIONS(6206),
    [anon_sym_POUNDendif] = ACTIONS(6206),
    [anon_sym_POUNDENDIF] = ACTIONS(6206),
    [anon_sym_POUNDEndif] = ACTIONS(6206),
    [anon_sym_POUNDendif2] = ACTIONS(6206),
    [anon_sym_POUNDENDIF2] = ACTIONS(6206),
    [anon_sym_POUNDEndif2] = ACTIONS(6206),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6204),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6204),
    [anon_sym_PLUS] = ACTIONS(6206),
    [sym_datetime_literal] = ACTIONS(6206),
    [sym_date_literal] = ACTIONS(6204),
    [sym_time_literal] = ACTIONS(6204),
    [sym_biginteger_literal] = ACTIONS(6206),
    [anon_sym_if] = ACTIONS(6204),
    [anon_sym_IF] = ACTIONS(6204),
    [anon_sym_If] = ACTIONS(6204),
    [anon_sym_else] = ACTIONS(6204),
    [anon_sym_ELSE] = ACTIONS(6204),
    [anon_sym_Else] = ACTIONS(6204),
    [anon_sym_case] = ACTIONS(6204),
    [anon_sym_CASE] = ACTIONS(6204),
    [anon_sym_Case] = ACTIONS(6204),
    [anon_sym_for] = ACTIONS(6204),
    [anon_sym_FOR] = ACTIONS(6204),
    [anon_sym_For] = ACTIONS(6204),
    [anon_sym_foreach] = ACTIONS(6204),
    [anon_sym_FOREACH] = ACTIONS(6204),
    [anon_sym_Foreach] = ACTIONS(6204),
    [anon_sym_while] = ACTIONS(6204),
    [anon_sym_WHILE] = ACTIONS(6204),
    [anon_sym_While] = ACTIONS(6204),
    [anon_sym_repeat] = ACTIONS(6204),
    [anon_sym_REPEAT] = ACTIONS(6204),
    [anon_sym_Repeat] = ACTIONS(6204),
    [anon_sym_exit] = ACTIONS(6204),
    [anon_sym_EXIT] = ACTIONS(6204),
    [anon_sym_Exit] = ACTIONS(6204),
    [anon_sym_continue] = ACTIONS(6204),
    [anon_sym_CONTINUE] = ACTIONS(6204),
    [anon_sym_Continue] = ACTIONS(6204),
    [anon_sym_break] = ACTIONS(6204),
    [anon_sym_BREAK] = ACTIONS(6204),
    [anon_sym_Break] = ACTIONS(6204),
    [anon_sym_with] = ACTIONS(6204),
    [anon_sym_WITH] = ACTIONS(6204),
    [anon_sym_With] = ACTIONS(6204),
    [sym_asserterror_keyword] = ACTIONS(6206),
    [sym_page_keyword] = ACTIONS(6204),
    [anon_sym_codeunit] = ACTIONS(6204),
    [anon_sym_CODEUNIT] = ACTIONS(6204),
    [anon_sym_Codeunit] = ACTIONS(6204),
    [anon_sym_CodeUnit] = ACTIONS(6204),
    [anon_sym_COdeunit] = ACTIONS(6204),
    [anon_sym_codeUnit] = ACTIONS(6204),
    [sym_report_keyword] = ACTIONS(6204),
    [sym_query_keyword] = ACTIONS(6204),
    [anon_sym_xmlport] = ACTIONS(6204),
    [anon_sym_XMLPORT] = ACTIONS(6204),
    [anon_sym_Xmlport] = ACTIONS(6204),
    [anon_sym_XMLport] = ACTIONS(6204),
    [anon_sym_XMLPort] = ACTIONS(6204),
    [anon_sym_XmlPort] = ACTIONS(6204),
    [anon_sym_enum] = ACTIONS(6204),
    [anon_sym_ENUM] = ACTIONS(6204),
    [anon_sym_Enum] = ACTIONS(6204),
    [anon_sym_eNUM] = ACTIONS(6204),
    [anon_sym_eNum] = ACTIONS(6204),
    [anon_sym_ENum] = ACTIONS(6204),
    [sym_quoted_identifier] = ACTIONS(6206),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6206),
    [sym_verbatim_string] = ACTIONS(6206),
    [sym_integer] = ACTIONS(6204),
    [sym_continue_as_identifier] = ACTIONS(6206),
    [sym_preproc_open] = ACTIONS(6206),
    [sym_preproc_close] = ACTIONS(6206),
  },
  [STATE(2583)] = {
    [sym_identifier] = ACTIONS(6208),
    [anon_sym_SEMI] = ACTIONS(6210),
    [anon_sym_DASH] = ACTIONS(6210),
    [aux_sym_boolean_token1] = ACTIONS(6208),
    [aux_sym_boolean_token2] = ACTIONS(6208),
    [sym_decimal] = ACTIONS(6208),
    [anon_sym_LPAREN] = ACTIONS(6210),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6208),
    [anon_sym_LBRACK] = ACTIONS(6210),
    [aux_sym_record_type_token1] = ACTIONS(6208),
    [aux_sym_basic_type_token21] = ACTIONS(6208),
    [aux_sym_basic_type_token22] = ACTIONS(6208),
    [aux_sym_basic_type_token48] = ACTIONS(6208),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6208),
    [anon_sym_POUNDif] = ACTIONS(6210),
    [anon_sym_POUNDIF] = ACTIONS(6210),
    [anon_sym_POUNDIf] = ACTIONS(6210),
    [anon_sym_not] = ACTIONS(6208),
    [anon_sym_NOT] = ACTIONS(6208),
    [anon_sym_Not] = ACTIONS(6208),
    [anon_sym_POUNDelif] = ACTIONS(6210),
    [anon_sym_POUNDELIF] = ACTIONS(6210),
    [anon_sym_POUNDElif] = ACTIONS(6210),
    [anon_sym_POUNDelse] = ACTIONS(6210),
    [anon_sym_POUNDELSE] = ACTIONS(6210),
    [anon_sym_POUNDElse] = ACTIONS(6210),
    [anon_sym_POUNDelse2] = ACTIONS(6210),
    [anon_sym_POUNDELSE2] = ACTIONS(6210),
    [anon_sym_POUNDElse2] = ACTIONS(6210),
    [anon_sym_POUNDendif] = ACTIONS(6210),
    [anon_sym_POUNDENDIF] = ACTIONS(6210),
    [anon_sym_POUNDEndif] = ACTIONS(6210),
    [anon_sym_POUNDendif2] = ACTIONS(6210),
    [anon_sym_POUNDENDIF2] = ACTIONS(6210),
    [anon_sym_POUNDEndif2] = ACTIONS(6210),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6208),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6208),
    [anon_sym_PLUS] = ACTIONS(6210),
    [sym_datetime_literal] = ACTIONS(6210),
    [sym_date_literal] = ACTIONS(6208),
    [sym_time_literal] = ACTIONS(6208),
    [sym_biginteger_literal] = ACTIONS(6210),
    [anon_sym_if] = ACTIONS(6208),
    [anon_sym_IF] = ACTIONS(6208),
    [anon_sym_If] = ACTIONS(6208),
    [anon_sym_else] = ACTIONS(6208),
    [anon_sym_ELSE] = ACTIONS(6208),
    [anon_sym_Else] = ACTIONS(6208),
    [anon_sym_case] = ACTIONS(6208),
    [anon_sym_CASE] = ACTIONS(6208),
    [anon_sym_Case] = ACTIONS(6208),
    [anon_sym_for] = ACTIONS(6208),
    [anon_sym_FOR] = ACTIONS(6208),
    [anon_sym_For] = ACTIONS(6208),
    [anon_sym_foreach] = ACTIONS(6208),
    [anon_sym_FOREACH] = ACTIONS(6208),
    [anon_sym_Foreach] = ACTIONS(6208),
    [anon_sym_while] = ACTIONS(6208),
    [anon_sym_WHILE] = ACTIONS(6208),
    [anon_sym_While] = ACTIONS(6208),
    [anon_sym_repeat] = ACTIONS(6208),
    [anon_sym_REPEAT] = ACTIONS(6208),
    [anon_sym_Repeat] = ACTIONS(6208),
    [anon_sym_exit] = ACTIONS(6208),
    [anon_sym_EXIT] = ACTIONS(6208),
    [anon_sym_Exit] = ACTIONS(6208),
    [anon_sym_continue] = ACTIONS(6208),
    [anon_sym_CONTINUE] = ACTIONS(6208),
    [anon_sym_Continue] = ACTIONS(6208),
    [anon_sym_break] = ACTIONS(6208),
    [anon_sym_BREAK] = ACTIONS(6208),
    [anon_sym_Break] = ACTIONS(6208),
    [anon_sym_with] = ACTIONS(6208),
    [anon_sym_WITH] = ACTIONS(6208),
    [anon_sym_With] = ACTIONS(6208),
    [sym_asserterror_keyword] = ACTIONS(6210),
    [sym_page_keyword] = ACTIONS(6208),
    [anon_sym_codeunit] = ACTIONS(6208),
    [anon_sym_CODEUNIT] = ACTIONS(6208),
    [anon_sym_Codeunit] = ACTIONS(6208),
    [anon_sym_CodeUnit] = ACTIONS(6208),
    [anon_sym_COdeunit] = ACTIONS(6208),
    [anon_sym_codeUnit] = ACTIONS(6208),
    [sym_report_keyword] = ACTIONS(6208),
    [sym_query_keyword] = ACTIONS(6208),
    [anon_sym_xmlport] = ACTIONS(6208),
    [anon_sym_XMLPORT] = ACTIONS(6208),
    [anon_sym_Xmlport] = ACTIONS(6208),
    [anon_sym_XMLport] = ACTIONS(6208),
    [anon_sym_XMLPort] = ACTIONS(6208),
    [anon_sym_XmlPort] = ACTIONS(6208),
    [anon_sym_enum] = ACTIONS(6208),
    [anon_sym_ENUM] = ACTIONS(6208),
    [anon_sym_Enum] = ACTIONS(6208),
    [anon_sym_eNUM] = ACTIONS(6208),
    [anon_sym_eNum] = ACTIONS(6208),
    [anon_sym_ENum] = ACTIONS(6208),
    [sym_quoted_identifier] = ACTIONS(6210),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6210),
    [sym_verbatim_string] = ACTIONS(6210),
    [sym_integer] = ACTIONS(6208),
    [sym_continue_as_identifier] = ACTIONS(6210),
    [sym_preproc_open] = ACTIONS(6210),
    [sym_preproc_close] = ACTIONS(6210),
  },
  [STATE(2584)] = {
    [sym_identifier] = ACTIONS(6212),
    [anon_sym_SEMI] = ACTIONS(6214),
    [anon_sym_DASH] = ACTIONS(6214),
    [aux_sym_boolean_token1] = ACTIONS(6212),
    [aux_sym_boolean_token2] = ACTIONS(6212),
    [sym_decimal] = ACTIONS(6212),
    [anon_sym_LPAREN] = ACTIONS(6214),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6212),
    [anon_sym_LBRACK] = ACTIONS(6214),
    [aux_sym_record_type_token1] = ACTIONS(6212),
    [aux_sym_basic_type_token21] = ACTIONS(6212),
    [aux_sym_basic_type_token22] = ACTIONS(6212),
    [aux_sym_basic_type_token48] = ACTIONS(6212),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6212),
    [anon_sym_POUNDif] = ACTIONS(6214),
    [anon_sym_POUNDIF] = ACTIONS(6214),
    [anon_sym_POUNDIf] = ACTIONS(6214),
    [anon_sym_not] = ACTIONS(6212),
    [anon_sym_NOT] = ACTIONS(6212),
    [anon_sym_Not] = ACTIONS(6212),
    [anon_sym_POUNDelif] = ACTIONS(6214),
    [anon_sym_POUNDELIF] = ACTIONS(6214),
    [anon_sym_POUNDElif] = ACTIONS(6214),
    [anon_sym_POUNDelse] = ACTIONS(6214),
    [anon_sym_POUNDELSE] = ACTIONS(6214),
    [anon_sym_POUNDElse] = ACTIONS(6214),
    [anon_sym_POUNDelse2] = ACTIONS(6214),
    [anon_sym_POUNDELSE2] = ACTIONS(6214),
    [anon_sym_POUNDElse2] = ACTIONS(6214),
    [anon_sym_POUNDendif] = ACTIONS(6214),
    [anon_sym_POUNDENDIF] = ACTIONS(6214),
    [anon_sym_POUNDEndif] = ACTIONS(6214),
    [anon_sym_POUNDendif2] = ACTIONS(6214),
    [anon_sym_POUNDENDIF2] = ACTIONS(6214),
    [anon_sym_POUNDEndif2] = ACTIONS(6214),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6212),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6212),
    [anon_sym_PLUS] = ACTIONS(6214),
    [sym_datetime_literal] = ACTIONS(6214),
    [sym_date_literal] = ACTIONS(6212),
    [sym_time_literal] = ACTIONS(6212),
    [sym_biginteger_literal] = ACTIONS(6214),
    [anon_sym_if] = ACTIONS(6212),
    [anon_sym_IF] = ACTIONS(6212),
    [anon_sym_If] = ACTIONS(6212),
    [anon_sym_else] = ACTIONS(6212),
    [anon_sym_ELSE] = ACTIONS(6212),
    [anon_sym_Else] = ACTIONS(6212),
    [anon_sym_case] = ACTIONS(6212),
    [anon_sym_CASE] = ACTIONS(6212),
    [anon_sym_Case] = ACTIONS(6212),
    [anon_sym_for] = ACTIONS(6212),
    [anon_sym_FOR] = ACTIONS(6212),
    [anon_sym_For] = ACTIONS(6212),
    [anon_sym_foreach] = ACTIONS(6212),
    [anon_sym_FOREACH] = ACTIONS(6212),
    [anon_sym_Foreach] = ACTIONS(6212),
    [anon_sym_while] = ACTIONS(6212),
    [anon_sym_WHILE] = ACTIONS(6212),
    [anon_sym_While] = ACTIONS(6212),
    [anon_sym_repeat] = ACTIONS(6212),
    [anon_sym_REPEAT] = ACTIONS(6212),
    [anon_sym_Repeat] = ACTIONS(6212),
    [anon_sym_exit] = ACTIONS(6212),
    [anon_sym_EXIT] = ACTIONS(6212),
    [anon_sym_Exit] = ACTIONS(6212),
    [anon_sym_continue] = ACTIONS(6212),
    [anon_sym_CONTINUE] = ACTIONS(6212),
    [anon_sym_Continue] = ACTIONS(6212),
    [anon_sym_break] = ACTIONS(6212),
    [anon_sym_BREAK] = ACTIONS(6212),
    [anon_sym_Break] = ACTIONS(6212),
    [anon_sym_with] = ACTIONS(6212),
    [anon_sym_WITH] = ACTIONS(6212),
    [anon_sym_With] = ACTIONS(6212),
    [sym_asserterror_keyword] = ACTIONS(6214),
    [sym_page_keyword] = ACTIONS(6212),
    [anon_sym_codeunit] = ACTIONS(6212),
    [anon_sym_CODEUNIT] = ACTIONS(6212),
    [anon_sym_Codeunit] = ACTIONS(6212),
    [anon_sym_CodeUnit] = ACTIONS(6212),
    [anon_sym_COdeunit] = ACTIONS(6212),
    [anon_sym_codeUnit] = ACTIONS(6212),
    [sym_report_keyword] = ACTIONS(6212),
    [sym_query_keyword] = ACTIONS(6212),
    [anon_sym_xmlport] = ACTIONS(6212),
    [anon_sym_XMLPORT] = ACTIONS(6212),
    [anon_sym_Xmlport] = ACTIONS(6212),
    [anon_sym_XMLport] = ACTIONS(6212),
    [anon_sym_XMLPort] = ACTIONS(6212),
    [anon_sym_XmlPort] = ACTIONS(6212),
    [anon_sym_enum] = ACTIONS(6212),
    [anon_sym_ENUM] = ACTIONS(6212),
    [anon_sym_Enum] = ACTIONS(6212),
    [anon_sym_eNUM] = ACTIONS(6212),
    [anon_sym_eNum] = ACTIONS(6212),
    [anon_sym_ENum] = ACTIONS(6212),
    [sym_quoted_identifier] = ACTIONS(6214),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6214),
    [sym_verbatim_string] = ACTIONS(6214),
    [sym_integer] = ACTIONS(6212),
    [sym_continue_as_identifier] = ACTIONS(6214),
    [sym_preproc_open] = ACTIONS(6214),
    [sym_preproc_close] = ACTIONS(6214),
  },
  [STATE(2585)] = {
    [sym_identifier] = ACTIONS(6216),
    [anon_sym_SEMI] = ACTIONS(6218),
    [anon_sym_DASH] = ACTIONS(6220),
    [aux_sym_boolean_token1] = ACTIONS(6216),
    [aux_sym_boolean_token2] = ACTIONS(6216),
    [sym_decimal] = ACTIONS(6216),
    [anon_sym_LPAREN] = ACTIONS(6220),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6220),
    [aux_sym_record_type_token1] = ACTIONS(6216),
    [aux_sym_basic_type_token21] = ACTIONS(6216),
    [aux_sym_basic_type_token22] = ACTIONS(6216),
    [aux_sym_basic_type_token48] = ACTIONS(6216),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6216),
    [anon_sym_POUNDif] = ACTIONS(6220),
    [anon_sym_POUNDIF] = ACTIONS(6220),
    [anon_sym_POUNDIf] = ACTIONS(6220),
    [anon_sym_not] = ACTIONS(6216),
    [anon_sym_NOT] = ACTIONS(6216),
    [anon_sym_Not] = ACTIONS(6216),
    [anon_sym_POUNDelif] = ACTIONS(6220),
    [anon_sym_POUNDELIF] = ACTIONS(6220),
    [anon_sym_POUNDElif] = ACTIONS(6220),
    [anon_sym_POUNDelse] = ACTIONS(6220),
    [anon_sym_POUNDELSE] = ACTIONS(6220),
    [anon_sym_POUNDElse] = ACTIONS(6220),
    [anon_sym_POUNDelse2] = ACTIONS(6220),
    [anon_sym_POUNDELSE2] = ACTIONS(6220),
    [anon_sym_POUNDElse2] = ACTIONS(6220),
    [anon_sym_POUNDendif] = ACTIONS(6220),
    [anon_sym_POUNDENDIF] = ACTIONS(6220),
    [anon_sym_POUNDEndif] = ACTIONS(6220),
    [anon_sym_POUNDendif2] = ACTIONS(6220),
    [anon_sym_POUNDENDIF2] = ACTIONS(6220),
    [anon_sym_POUNDEndif2] = ACTIONS(6220),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6216),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6216),
    [anon_sym_PLUS] = ACTIONS(6220),
    [sym_datetime_literal] = ACTIONS(6220),
    [sym_date_literal] = ACTIONS(6216),
    [sym_time_literal] = ACTIONS(6216),
    [sym_biginteger_literal] = ACTIONS(6220),
    [anon_sym_if] = ACTIONS(6216),
    [anon_sym_IF] = ACTIONS(6216),
    [anon_sym_If] = ACTIONS(6216),
    [anon_sym_else] = ACTIONS(6216),
    [anon_sym_ELSE] = ACTIONS(6216),
    [anon_sym_Else] = ACTIONS(6216),
    [anon_sym_case] = ACTIONS(6216),
    [anon_sym_CASE] = ACTIONS(6216),
    [anon_sym_Case] = ACTIONS(6216),
    [anon_sym_for] = ACTIONS(6216),
    [anon_sym_FOR] = ACTIONS(6216),
    [anon_sym_For] = ACTIONS(6216),
    [anon_sym_foreach] = ACTIONS(6216),
    [anon_sym_FOREACH] = ACTIONS(6216),
    [anon_sym_Foreach] = ACTIONS(6216),
    [anon_sym_while] = ACTIONS(6216),
    [anon_sym_WHILE] = ACTIONS(6216),
    [anon_sym_While] = ACTIONS(6216),
    [anon_sym_repeat] = ACTIONS(6216),
    [anon_sym_REPEAT] = ACTIONS(6216),
    [anon_sym_Repeat] = ACTIONS(6216),
    [anon_sym_exit] = ACTIONS(6216),
    [anon_sym_EXIT] = ACTIONS(6216),
    [anon_sym_Exit] = ACTIONS(6216),
    [anon_sym_continue] = ACTIONS(6216),
    [anon_sym_CONTINUE] = ACTIONS(6216),
    [anon_sym_Continue] = ACTIONS(6216),
    [anon_sym_break] = ACTIONS(6216),
    [anon_sym_BREAK] = ACTIONS(6216),
    [anon_sym_Break] = ACTIONS(6216),
    [anon_sym_with] = ACTIONS(6216),
    [anon_sym_WITH] = ACTIONS(6216),
    [anon_sym_With] = ACTIONS(6216),
    [sym_asserterror_keyword] = ACTIONS(6220),
    [sym_page_keyword] = ACTIONS(6216),
    [anon_sym_codeunit] = ACTIONS(6216),
    [anon_sym_CODEUNIT] = ACTIONS(6216),
    [anon_sym_Codeunit] = ACTIONS(6216),
    [anon_sym_CodeUnit] = ACTIONS(6216),
    [anon_sym_COdeunit] = ACTIONS(6216),
    [anon_sym_codeUnit] = ACTIONS(6216),
    [sym_report_keyword] = ACTIONS(6216),
    [sym_query_keyword] = ACTIONS(6216),
    [anon_sym_xmlport] = ACTIONS(6216),
    [anon_sym_XMLPORT] = ACTIONS(6216),
    [anon_sym_Xmlport] = ACTIONS(6216),
    [anon_sym_XMLport] = ACTIONS(6216),
    [anon_sym_XMLPort] = ACTIONS(6216),
    [anon_sym_XmlPort] = ACTIONS(6216),
    [anon_sym_enum] = ACTIONS(6216),
    [anon_sym_ENUM] = ACTIONS(6216),
    [anon_sym_Enum] = ACTIONS(6216),
    [anon_sym_eNUM] = ACTIONS(6216),
    [anon_sym_eNum] = ACTIONS(6216),
    [anon_sym_ENum] = ACTIONS(6216),
    [sym_quoted_identifier] = ACTIONS(6220),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6220),
    [sym_verbatim_string] = ACTIONS(6220),
    [sym_integer] = ACTIONS(6216),
    [sym_continue_as_identifier] = ACTIONS(6220),
    [sym_preproc_open] = ACTIONS(6220),
    [sym_preproc_close] = ACTIONS(6220),
  },
  [STATE(2586)] = {
    [sym_identifier] = ACTIONS(6216),
    [anon_sym_SEMI] = ACTIONS(6222),
    [anon_sym_DASH] = ACTIONS(6220),
    [aux_sym_boolean_token1] = ACTIONS(6216),
    [aux_sym_boolean_token2] = ACTIONS(6216),
    [sym_decimal] = ACTIONS(6216),
    [anon_sym_LPAREN] = ACTIONS(6220),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6220),
    [aux_sym_record_type_token1] = ACTIONS(6216),
    [aux_sym_basic_type_token21] = ACTIONS(6216),
    [aux_sym_basic_type_token22] = ACTIONS(6216),
    [aux_sym_basic_type_token48] = ACTIONS(6216),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6216),
    [anon_sym_POUNDif] = ACTIONS(6220),
    [anon_sym_POUNDIF] = ACTIONS(6220),
    [anon_sym_POUNDIf] = ACTIONS(6220),
    [anon_sym_not] = ACTIONS(6216),
    [anon_sym_NOT] = ACTIONS(6216),
    [anon_sym_Not] = ACTIONS(6216),
    [anon_sym_POUNDelif] = ACTIONS(6220),
    [anon_sym_POUNDELIF] = ACTIONS(6220),
    [anon_sym_POUNDElif] = ACTIONS(6220),
    [anon_sym_POUNDelse] = ACTIONS(6220),
    [anon_sym_POUNDELSE] = ACTIONS(6220),
    [anon_sym_POUNDElse] = ACTIONS(6220),
    [anon_sym_POUNDelse2] = ACTIONS(6220),
    [anon_sym_POUNDELSE2] = ACTIONS(6220),
    [anon_sym_POUNDElse2] = ACTIONS(6220),
    [anon_sym_POUNDendif] = ACTIONS(6220),
    [anon_sym_POUNDENDIF] = ACTIONS(6220),
    [anon_sym_POUNDEndif] = ACTIONS(6220),
    [anon_sym_POUNDendif2] = ACTIONS(6220),
    [anon_sym_POUNDENDIF2] = ACTIONS(6220),
    [anon_sym_POUNDEndif2] = ACTIONS(6220),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6216),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6216),
    [anon_sym_PLUS] = ACTIONS(6220),
    [sym_datetime_literal] = ACTIONS(6220),
    [sym_date_literal] = ACTIONS(6216),
    [sym_time_literal] = ACTIONS(6216),
    [sym_biginteger_literal] = ACTIONS(6220),
    [anon_sym_if] = ACTIONS(6216),
    [anon_sym_IF] = ACTIONS(6216),
    [anon_sym_If] = ACTIONS(6216),
    [anon_sym_else] = ACTIONS(6216),
    [anon_sym_ELSE] = ACTIONS(6216),
    [anon_sym_Else] = ACTIONS(6216),
    [anon_sym_case] = ACTIONS(6216),
    [anon_sym_CASE] = ACTIONS(6216),
    [anon_sym_Case] = ACTIONS(6216),
    [anon_sym_for] = ACTIONS(6216),
    [anon_sym_FOR] = ACTIONS(6216),
    [anon_sym_For] = ACTIONS(6216),
    [anon_sym_foreach] = ACTIONS(6216),
    [anon_sym_FOREACH] = ACTIONS(6216),
    [anon_sym_Foreach] = ACTIONS(6216),
    [anon_sym_while] = ACTIONS(6216),
    [anon_sym_WHILE] = ACTIONS(6216),
    [anon_sym_While] = ACTIONS(6216),
    [anon_sym_repeat] = ACTIONS(6216),
    [anon_sym_REPEAT] = ACTIONS(6216),
    [anon_sym_Repeat] = ACTIONS(6216),
    [anon_sym_exit] = ACTIONS(6216),
    [anon_sym_EXIT] = ACTIONS(6216),
    [anon_sym_Exit] = ACTIONS(6216),
    [anon_sym_continue] = ACTIONS(6216),
    [anon_sym_CONTINUE] = ACTIONS(6216),
    [anon_sym_Continue] = ACTIONS(6216),
    [anon_sym_break] = ACTIONS(6216),
    [anon_sym_BREAK] = ACTIONS(6216),
    [anon_sym_Break] = ACTIONS(6216),
    [anon_sym_with] = ACTIONS(6216),
    [anon_sym_WITH] = ACTIONS(6216),
    [anon_sym_With] = ACTIONS(6216),
    [sym_asserterror_keyword] = ACTIONS(6220),
    [sym_page_keyword] = ACTIONS(6216),
    [anon_sym_codeunit] = ACTIONS(6216),
    [anon_sym_CODEUNIT] = ACTIONS(6216),
    [anon_sym_Codeunit] = ACTIONS(6216),
    [anon_sym_CodeUnit] = ACTIONS(6216),
    [anon_sym_COdeunit] = ACTIONS(6216),
    [anon_sym_codeUnit] = ACTIONS(6216),
    [sym_report_keyword] = ACTIONS(6216),
    [sym_query_keyword] = ACTIONS(6216),
    [anon_sym_xmlport] = ACTIONS(6216),
    [anon_sym_XMLPORT] = ACTIONS(6216),
    [anon_sym_Xmlport] = ACTIONS(6216),
    [anon_sym_XMLport] = ACTIONS(6216),
    [anon_sym_XMLPort] = ACTIONS(6216),
    [anon_sym_XmlPort] = ACTIONS(6216),
    [anon_sym_enum] = ACTIONS(6216),
    [anon_sym_ENUM] = ACTIONS(6216),
    [anon_sym_Enum] = ACTIONS(6216),
    [anon_sym_eNUM] = ACTIONS(6216),
    [anon_sym_eNum] = ACTIONS(6216),
    [anon_sym_ENum] = ACTIONS(6216),
    [sym_quoted_identifier] = ACTIONS(6220),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6220),
    [sym_verbatim_string] = ACTIONS(6220),
    [sym_integer] = ACTIONS(6216),
    [sym_continue_as_identifier] = ACTIONS(6220),
    [sym_preproc_open] = ACTIONS(6220),
    [sym_preproc_close] = ACTIONS(6220),
  },
  [STATE(2587)] = {
    [sym_identifier] = ACTIONS(6224),
    [anon_sym_SEMI] = ACTIONS(6226),
    [anon_sym_DASH] = ACTIONS(6226),
    [aux_sym_boolean_token1] = ACTIONS(6224),
    [aux_sym_boolean_token2] = ACTIONS(6224),
    [sym_decimal] = ACTIONS(6224),
    [anon_sym_LPAREN] = ACTIONS(6226),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6224),
    [anon_sym_LBRACK] = ACTIONS(6226),
    [aux_sym_record_type_token1] = ACTIONS(6224),
    [aux_sym_basic_type_token21] = ACTIONS(6224),
    [aux_sym_basic_type_token22] = ACTIONS(6224),
    [aux_sym_basic_type_token48] = ACTIONS(6224),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6224),
    [anon_sym_POUNDif] = ACTIONS(6226),
    [anon_sym_POUNDIF] = ACTIONS(6226),
    [anon_sym_POUNDIf] = ACTIONS(6226),
    [anon_sym_not] = ACTIONS(6224),
    [anon_sym_NOT] = ACTIONS(6224),
    [anon_sym_Not] = ACTIONS(6224),
    [anon_sym_POUNDelif] = ACTIONS(6226),
    [anon_sym_POUNDELIF] = ACTIONS(6226),
    [anon_sym_POUNDElif] = ACTIONS(6226),
    [anon_sym_POUNDelse] = ACTIONS(6226),
    [anon_sym_POUNDELSE] = ACTIONS(6226),
    [anon_sym_POUNDElse] = ACTIONS(6226),
    [anon_sym_POUNDelse2] = ACTIONS(6226),
    [anon_sym_POUNDELSE2] = ACTIONS(6226),
    [anon_sym_POUNDElse2] = ACTIONS(6226),
    [anon_sym_POUNDendif] = ACTIONS(6226),
    [anon_sym_POUNDENDIF] = ACTIONS(6226),
    [anon_sym_POUNDEndif] = ACTIONS(6226),
    [anon_sym_POUNDendif2] = ACTIONS(6226),
    [anon_sym_POUNDENDIF2] = ACTIONS(6226),
    [anon_sym_POUNDEndif2] = ACTIONS(6226),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6224),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6224),
    [anon_sym_PLUS] = ACTIONS(6226),
    [sym_datetime_literal] = ACTIONS(6226),
    [sym_date_literal] = ACTIONS(6224),
    [sym_time_literal] = ACTIONS(6224),
    [sym_biginteger_literal] = ACTIONS(6226),
    [anon_sym_if] = ACTIONS(6224),
    [anon_sym_IF] = ACTIONS(6224),
    [anon_sym_If] = ACTIONS(6224),
    [anon_sym_else] = ACTIONS(6224),
    [anon_sym_ELSE] = ACTIONS(6224),
    [anon_sym_Else] = ACTIONS(6224),
    [anon_sym_case] = ACTIONS(6224),
    [anon_sym_CASE] = ACTIONS(6224),
    [anon_sym_Case] = ACTIONS(6224),
    [anon_sym_for] = ACTIONS(6224),
    [anon_sym_FOR] = ACTIONS(6224),
    [anon_sym_For] = ACTIONS(6224),
    [anon_sym_foreach] = ACTIONS(6224),
    [anon_sym_FOREACH] = ACTIONS(6224),
    [anon_sym_Foreach] = ACTIONS(6224),
    [anon_sym_while] = ACTIONS(6224),
    [anon_sym_WHILE] = ACTIONS(6224),
    [anon_sym_While] = ACTIONS(6224),
    [anon_sym_repeat] = ACTIONS(6224),
    [anon_sym_REPEAT] = ACTIONS(6224),
    [anon_sym_Repeat] = ACTIONS(6224),
    [anon_sym_exit] = ACTIONS(6224),
    [anon_sym_EXIT] = ACTIONS(6224),
    [anon_sym_Exit] = ACTIONS(6224),
    [anon_sym_continue] = ACTIONS(6224),
    [anon_sym_CONTINUE] = ACTIONS(6224),
    [anon_sym_Continue] = ACTIONS(6224),
    [anon_sym_break] = ACTIONS(6224),
    [anon_sym_BREAK] = ACTIONS(6224),
    [anon_sym_Break] = ACTIONS(6224),
    [anon_sym_with] = ACTIONS(6224),
    [anon_sym_WITH] = ACTIONS(6224),
    [anon_sym_With] = ACTIONS(6224),
    [sym_asserterror_keyword] = ACTIONS(6226),
    [sym_page_keyword] = ACTIONS(6224),
    [anon_sym_codeunit] = ACTIONS(6224),
    [anon_sym_CODEUNIT] = ACTIONS(6224),
    [anon_sym_Codeunit] = ACTIONS(6224),
    [anon_sym_CodeUnit] = ACTIONS(6224),
    [anon_sym_COdeunit] = ACTIONS(6224),
    [anon_sym_codeUnit] = ACTIONS(6224),
    [sym_report_keyword] = ACTIONS(6224),
    [sym_query_keyword] = ACTIONS(6224),
    [anon_sym_xmlport] = ACTIONS(6224),
    [anon_sym_XMLPORT] = ACTIONS(6224),
    [anon_sym_Xmlport] = ACTIONS(6224),
    [anon_sym_XMLport] = ACTIONS(6224),
    [anon_sym_XMLPort] = ACTIONS(6224),
    [anon_sym_XmlPort] = ACTIONS(6224),
    [anon_sym_enum] = ACTIONS(6224),
    [anon_sym_ENUM] = ACTIONS(6224),
    [anon_sym_Enum] = ACTIONS(6224),
    [anon_sym_eNUM] = ACTIONS(6224),
    [anon_sym_eNum] = ACTIONS(6224),
    [anon_sym_ENum] = ACTIONS(6224),
    [sym_quoted_identifier] = ACTIONS(6226),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6226),
    [sym_verbatim_string] = ACTIONS(6226),
    [sym_integer] = ACTIONS(6224),
    [sym_continue_as_identifier] = ACTIONS(6226),
    [sym_preproc_open] = ACTIONS(6226),
    [sym_preproc_close] = ACTIONS(6226),
  },
  [STATE(2588)] = {
    [sym_identifier] = ACTIONS(6228),
    [anon_sym_SEMI] = ACTIONS(6230),
    [anon_sym_DASH] = ACTIONS(6230),
    [aux_sym_boolean_token1] = ACTIONS(6228),
    [aux_sym_boolean_token2] = ACTIONS(6228),
    [sym_decimal] = ACTIONS(6228),
    [anon_sym_LPAREN] = ACTIONS(6230),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6228),
    [anon_sym_LBRACK] = ACTIONS(6230),
    [aux_sym_record_type_token1] = ACTIONS(6228),
    [aux_sym_basic_type_token21] = ACTIONS(6228),
    [aux_sym_basic_type_token22] = ACTIONS(6228),
    [aux_sym_basic_type_token48] = ACTIONS(6228),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6228),
    [anon_sym_POUNDif] = ACTIONS(6230),
    [anon_sym_POUNDIF] = ACTIONS(6230),
    [anon_sym_POUNDIf] = ACTIONS(6230),
    [anon_sym_not] = ACTIONS(6228),
    [anon_sym_NOT] = ACTIONS(6228),
    [anon_sym_Not] = ACTIONS(6228),
    [anon_sym_POUNDelif] = ACTIONS(6230),
    [anon_sym_POUNDELIF] = ACTIONS(6230),
    [anon_sym_POUNDElif] = ACTIONS(6230),
    [anon_sym_POUNDelse] = ACTIONS(6230),
    [anon_sym_POUNDELSE] = ACTIONS(6230),
    [anon_sym_POUNDElse] = ACTIONS(6230),
    [anon_sym_POUNDelse2] = ACTIONS(6230),
    [anon_sym_POUNDELSE2] = ACTIONS(6230),
    [anon_sym_POUNDElse2] = ACTIONS(6230),
    [anon_sym_POUNDendif] = ACTIONS(6230),
    [anon_sym_POUNDENDIF] = ACTIONS(6230),
    [anon_sym_POUNDEndif] = ACTIONS(6230),
    [anon_sym_POUNDendif2] = ACTIONS(6230),
    [anon_sym_POUNDENDIF2] = ACTIONS(6230),
    [anon_sym_POUNDEndif2] = ACTIONS(6230),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6228),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6228),
    [anon_sym_PLUS] = ACTIONS(6230),
    [sym_datetime_literal] = ACTIONS(6230),
    [sym_date_literal] = ACTIONS(6228),
    [sym_time_literal] = ACTIONS(6228),
    [sym_biginteger_literal] = ACTIONS(6230),
    [anon_sym_if] = ACTIONS(6228),
    [anon_sym_IF] = ACTIONS(6228),
    [anon_sym_If] = ACTIONS(6228),
    [anon_sym_else] = ACTIONS(6228),
    [anon_sym_ELSE] = ACTIONS(6228),
    [anon_sym_Else] = ACTIONS(6228),
    [anon_sym_case] = ACTIONS(6228),
    [anon_sym_CASE] = ACTIONS(6228),
    [anon_sym_Case] = ACTIONS(6228),
    [anon_sym_for] = ACTIONS(6228),
    [anon_sym_FOR] = ACTIONS(6228),
    [anon_sym_For] = ACTIONS(6228),
    [anon_sym_foreach] = ACTIONS(6228),
    [anon_sym_FOREACH] = ACTIONS(6228),
    [anon_sym_Foreach] = ACTIONS(6228),
    [anon_sym_while] = ACTIONS(6228),
    [anon_sym_WHILE] = ACTIONS(6228),
    [anon_sym_While] = ACTIONS(6228),
    [anon_sym_repeat] = ACTIONS(6228),
    [anon_sym_REPEAT] = ACTIONS(6228),
    [anon_sym_Repeat] = ACTIONS(6228),
    [anon_sym_exit] = ACTIONS(6228),
    [anon_sym_EXIT] = ACTIONS(6228),
    [anon_sym_Exit] = ACTIONS(6228),
    [anon_sym_continue] = ACTIONS(6228),
    [anon_sym_CONTINUE] = ACTIONS(6228),
    [anon_sym_Continue] = ACTIONS(6228),
    [anon_sym_break] = ACTIONS(6228),
    [anon_sym_BREAK] = ACTIONS(6228),
    [anon_sym_Break] = ACTIONS(6228),
    [anon_sym_with] = ACTIONS(6228),
    [anon_sym_WITH] = ACTIONS(6228),
    [anon_sym_With] = ACTIONS(6228),
    [sym_asserterror_keyword] = ACTIONS(6230),
    [sym_page_keyword] = ACTIONS(6228),
    [anon_sym_codeunit] = ACTIONS(6228),
    [anon_sym_CODEUNIT] = ACTIONS(6228),
    [anon_sym_Codeunit] = ACTIONS(6228),
    [anon_sym_CodeUnit] = ACTIONS(6228),
    [anon_sym_COdeunit] = ACTIONS(6228),
    [anon_sym_codeUnit] = ACTIONS(6228),
    [sym_report_keyword] = ACTIONS(6228),
    [sym_query_keyword] = ACTIONS(6228),
    [anon_sym_xmlport] = ACTIONS(6228),
    [anon_sym_XMLPORT] = ACTIONS(6228),
    [anon_sym_Xmlport] = ACTIONS(6228),
    [anon_sym_XMLport] = ACTIONS(6228),
    [anon_sym_XMLPort] = ACTIONS(6228),
    [anon_sym_XmlPort] = ACTIONS(6228),
    [anon_sym_enum] = ACTIONS(6228),
    [anon_sym_ENUM] = ACTIONS(6228),
    [anon_sym_Enum] = ACTIONS(6228),
    [anon_sym_eNUM] = ACTIONS(6228),
    [anon_sym_eNum] = ACTIONS(6228),
    [anon_sym_ENum] = ACTIONS(6228),
    [sym_quoted_identifier] = ACTIONS(6230),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6230),
    [sym_verbatim_string] = ACTIONS(6230),
    [sym_integer] = ACTIONS(6228),
    [sym_continue_as_identifier] = ACTIONS(6230),
    [sym_preproc_open] = ACTIONS(6230),
    [sym_preproc_close] = ACTIONS(6230),
  },
  [STATE(2589)] = {
    [sym_identifier] = ACTIONS(6232),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6234),
    [aux_sym_boolean_token1] = ACTIONS(6232),
    [aux_sym_boolean_token2] = ACTIONS(6232),
    [sym_decimal] = ACTIONS(6232),
    [anon_sym_LPAREN] = ACTIONS(6234),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6232),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [aux_sym_record_type_token1] = ACTIONS(6232),
    [aux_sym_basic_type_token21] = ACTIONS(6232),
    [aux_sym_basic_type_token22] = ACTIONS(6232),
    [aux_sym_basic_type_token48] = ACTIONS(6232),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6232),
    [anon_sym_POUNDif] = ACTIONS(6234),
    [anon_sym_POUNDIF] = ACTIONS(6234),
    [anon_sym_POUNDIf] = ACTIONS(6234),
    [anon_sym_not] = ACTIONS(6232),
    [anon_sym_NOT] = ACTIONS(6232),
    [anon_sym_Not] = ACTIONS(6232),
    [anon_sym_POUNDelif] = ACTIONS(6234),
    [anon_sym_POUNDELIF] = ACTIONS(6234),
    [anon_sym_POUNDElif] = ACTIONS(6234),
    [anon_sym_POUNDelse] = ACTIONS(6234),
    [anon_sym_POUNDELSE] = ACTIONS(6234),
    [anon_sym_POUNDElse] = ACTIONS(6234),
    [anon_sym_POUNDelse2] = ACTIONS(6234),
    [anon_sym_POUNDELSE2] = ACTIONS(6234),
    [anon_sym_POUNDElse2] = ACTIONS(6234),
    [anon_sym_POUNDendif] = ACTIONS(6234),
    [anon_sym_POUNDENDIF] = ACTIONS(6234),
    [anon_sym_POUNDEndif] = ACTIONS(6234),
    [anon_sym_POUNDendif2] = ACTIONS(6234),
    [anon_sym_POUNDENDIF2] = ACTIONS(6234),
    [anon_sym_POUNDEndif2] = ACTIONS(6234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6232),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6232),
    [anon_sym_PLUS] = ACTIONS(6234),
    [sym_datetime_literal] = ACTIONS(6234),
    [sym_date_literal] = ACTIONS(6232),
    [sym_time_literal] = ACTIONS(6232),
    [sym_biginteger_literal] = ACTIONS(6234),
    [anon_sym_if] = ACTIONS(6232),
    [anon_sym_IF] = ACTIONS(6232),
    [anon_sym_If] = ACTIONS(6232),
    [anon_sym_else] = ACTIONS(6232),
    [anon_sym_ELSE] = ACTIONS(6232),
    [anon_sym_Else] = ACTIONS(6232),
    [anon_sym_case] = ACTIONS(6232),
    [anon_sym_CASE] = ACTIONS(6232),
    [anon_sym_Case] = ACTIONS(6232),
    [anon_sym_for] = ACTIONS(6232),
    [anon_sym_FOR] = ACTIONS(6232),
    [anon_sym_For] = ACTIONS(6232),
    [anon_sym_foreach] = ACTIONS(6232),
    [anon_sym_FOREACH] = ACTIONS(6232),
    [anon_sym_Foreach] = ACTIONS(6232),
    [anon_sym_while] = ACTIONS(6232),
    [anon_sym_WHILE] = ACTIONS(6232),
    [anon_sym_While] = ACTIONS(6232),
    [anon_sym_repeat] = ACTIONS(6232),
    [anon_sym_REPEAT] = ACTIONS(6232),
    [anon_sym_Repeat] = ACTIONS(6232),
    [anon_sym_exit] = ACTIONS(6232),
    [anon_sym_EXIT] = ACTIONS(6232),
    [anon_sym_Exit] = ACTIONS(6232),
    [anon_sym_continue] = ACTIONS(6232),
    [anon_sym_CONTINUE] = ACTIONS(6232),
    [anon_sym_Continue] = ACTIONS(6232),
    [anon_sym_break] = ACTIONS(6232),
    [anon_sym_BREAK] = ACTIONS(6232),
    [anon_sym_Break] = ACTIONS(6232),
    [anon_sym_with] = ACTIONS(6232),
    [anon_sym_WITH] = ACTIONS(6232),
    [anon_sym_With] = ACTIONS(6232),
    [sym_asserterror_keyword] = ACTIONS(6234),
    [sym_page_keyword] = ACTIONS(6232),
    [anon_sym_codeunit] = ACTIONS(6232),
    [anon_sym_CODEUNIT] = ACTIONS(6232),
    [anon_sym_Codeunit] = ACTIONS(6232),
    [anon_sym_CodeUnit] = ACTIONS(6232),
    [anon_sym_COdeunit] = ACTIONS(6232),
    [anon_sym_codeUnit] = ACTIONS(6232),
    [sym_report_keyword] = ACTIONS(6232),
    [sym_query_keyword] = ACTIONS(6232),
    [anon_sym_xmlport] = ACTIONS(6232),
    [anon_sym_XMLPORT] = ACTIONS(6232),
    [anon_sym_Xmlport] = ACTIONS(6232),
    [anon_sym_XMLport] = ACTIONS(6232),
    [anon_sym_XMLPort] = ACTIONS(6232),
    [anon_sym_XmlPort] = ACTIONS(6232),
    [anon_sym_enum] = ACTIONS(6232),
    [anon_sym_ENUM] = ACTIONS(6232),
    [anon_sym_Enum] = ACTIONS(6232),
    [anon_sym_eNUM] = ACTIONS(6232),
    [anon_sym_eNum] = ACTIONS(6232),
    [anon_sym_ENum] = ACTIONS(6232),
    [sym_quoted_identifier] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6234),
    [sym_verbatim_string] = ACTIONS(6234),
    [sym_integer] = ACTIONS(6232),
    [sym_continue_as_identifier] = ACTIONS(6234),
    [sym_preproc_open] = ACTIONS(6234),
    [sym_preproc_close] = ACTIONS(6234),
  },
  [STATE(2590)] = {
    [sym_identifier] = ACTIONS(6236),
    [anon_sym_SEMI] = ACTIONS(6238),
    [anon_sym_DASH] = ACTIONS(6238),
    [aux_sym_boolean_token1] = ACTIONS(6236),
    [aux_sym_boolean_token2] = ACTIONS(6236),
    [sym_decimal] = ACTIONS(6236),
    [anon_sym_LPAREN] = ACTIONS(6238),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6236),
    [anon_sym_LBRACK] = ACTIONS(6238),
    [aux_sym_record_type_token1] = ACTIONS(6236),
    [aux_sym_basic_type_token21] = ACTIONS(6236),
    [aux_sym_basic_type_token22] = ACTIONS(6236),
    [aux_sym_basic_type_token48] = ACTIONS(6236),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6236),
    [anon_sym_POUNDif] = ACTIONS(6238),
    [anon_sym_POUNDIF] = ACTIONS(6238),
    [anon_sym_POUNDIf] = ACTIONS(6238),
    [anon_sym_not] = ACTIONS(6236),
    [anon_sym_NOT] = ACTIONS(6236),
    [anon_sym_Not] = ACTIONS(6236),
    [anon_sym_POUNDelif] = ACTIONS(6238),
    [anon_sym_POUNDELIF] = ACTIONS(6238),
    [anon_sym_POUNDElif] = ACTIONS(6238),
    [anon_sym_POUNDelse] = ACTIONS(6238),
    [anon_sym_POUNDELSE] = ACTIONS(6238),
    [anon_sym_POUNDElse] = ACTIONS(6238),
    [anon_sym_POUNDelse2] = ACTIONS(6238),
    [anon_sym_POUNDELSE2] = ACTIONS(6238),
    [anon_sym_POUNDElse2] = ACTIONS(6238),
    [anon_sym_POUNDendif] = ACTIONS(6238),
    [anon_sym_POUNDENDIF] = ACTIONS(6238),
    [anon_sym_POUNDEndif] = ACTIONS(6238),
    [anon_sym_POUNDendif2] = ACTIONS(6238),
    [anon_sym_POUNDENDIF2] = ACTIONS(6238),
    [anon_sym_POUNDEndif2] = ACTIONS(6238),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6236),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6236),
    [anon_sym_PLUS] = ACTIONS(6238),
    [sym_datetime_literal] = ACTIONS(6238),
    [sym_date_literal] = ACTIONS(6236),
    [sym_time_literal] = ACTIONS(6236),
    [sym_biginteger_literal] = ACTIONS(6238),
    [anon_sym_if] = ACTIONS(6236),
    [anon_sym_IF] = ACTIONS(6236),
    [anon_sym_If] = ACTIONS(6236),
    [anon_sym_else] = ACTIONS(6236),
    [anon_sym_ELSE] = ACTIONS(6236),
    [anon_sym_Else] = ACTIONS(6236),
    [anon_sym_case] = ACTIONS(6236),
    [anon_sym_CASE] = ACTIONS(6236),
    [anon_sym_Case] = ACTIONS(6236),
    [anon_sym_for] = ACTIONS(6236),
    [anon_sym_FOR] = ACTIONS(6236),
    [anon_sym_For] = ACTIONS(6236),
    [anon_sym_foreach] = ACTIONS(6236),
    [anon_sym_FOREACH] = ACTIONS(6236),
    [anon_sym_Foreach] = ACTIONS(6236),
    [anon_sym_while] = ACTIONS(6236),
    [anon_sym_WHILE] = ACTIONS(6236),
    [anon_sym_While] = ACTIONS(6236),
    [anon_sym_repeat] = ACTIONS(6236),
    [anon_sym_REPEAT] = ACTIONS(6236),
    [anon_sym_Repeat] = ACTIONS(6236),
    [anon_sym_exit] = ACTIONS(6236),
    [anon_sym_EXIT] = ACTIONS(6236),
    [anon_sym_Exit] = ACTIONS(6236),
    [anon_sym_continue] = ACTIONS(6236),
    [anon_sym_CONTINUE] = ACTIONS(6236),
    [anon_sym_Continue] = ACTIONS(6236),
    [anon_sym_break] = ACTIONS(6236),
    [anon_sym_BREAK] = ACTIONS(6236),
    [anon_sym_Break] = ACTIONS(6236),
    [anon_sym_with] = ACTIONS(6236),
    [anon_sym_WITH] = ACTIONS(6236),
    [anon_sym_With] = ACTIONS(6236),
    [sym_asserterror_keyword] = ACTIONS(6238),
    [sym_page_keyword] = ACTIONS(6236),
    [anon_sym_codeunit] = ACTIONS(6236),
    [anon_sym_CODEUNIT] = ACTIONS(6236),
    [anon_sym_Codeunit] = ACTIONS(6236),
    [anon_sym_CodeUnit] = ACTIONS(6236),
    [anon_sym_COdeunit] = ACTIONS(6236),
    [anon_sym_codeUnit] = ACTIONS(6236),
    [sym_report_keyword] = ACTIONS(6236),
    [sym_query_keyword] = ACTIONS(6236),
    [anon_sym_xmlport] = ACTIONS(6236),
    [anon_sym_XMLPORT] = ACTIONS(6236),
    [anon_sym_Xmlport] = ACTIONS(6236),
    [anon_sym_XMLport] = ACTIONS(6236),
    [anon_sym_XMLPort] = ACTIONS(6236),
    [anon_sym_XmlPort] = ACTIONS(6236),
    [anon_sym_enum] = ACTIONS(6236),
    [anon_sym_ENUM] = ACTIONS(6236),
    [anon_sym_Enum] = ACTIONS(6236),
    [anon_sym_eNUM] = ACTIONS(6236),
    [anon_sym_eNum] = ACTIONS(6236),
    [anon_sym_ENum] = ACTIONS(6236),
    [sym_quoted_identifier] = ACTIONS(6238),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6238),
    [sym_verbatim_string] = ACTIONS(6238),
    [sym_integer] = ACTIONS(6236),
    [sym_continue_as_identifier] = ACTIONS(6238),
    [sym_preproc_open] = ACTIONS(6238),
    [sym_preproc_close] = ACTIONS(6238),
  },
  [STATE(2591)] = {
    [sym_identifier] = ACTIONS(6232),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6234),
    [aux_sym_boolean_token1] = ACTIONS(6232),
    [aux_sym_boolean_token2] = ACTIONS(6232),
    [sym_decimal] = ACTIONS(6232),
    [anon_sym_LPAREN] = ACTIONS(6234),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6232),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [aux_sym_record_type_token1] = ACTIONS(6232),
    [aux_sym_basic_type_token21] = ACTIONS(6232),
    [aux_sym_basic_type_token22] = ACTIONS(6232),
    [aux_sym_basic_type_token48] = ACTIONS(6232),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6232),
    [anon_sym_POUNDif] = ACTIONS(6234),
    [anon_sym_POUNDIF] = ACTIONS(6234),
    [anon_sym_POUNDIf] = ACTIONS(6234),
    [anon_sym_not] = ACTIONS(6232),
    [anon_sym_NOT] = ACTIONS(6232),
    [anon_sym_Not] = ACTIONS(6232),
    [anon_sym_POUNDelif] = ACTIONS(6234),
    [anon_sym_POUNDELIF] = ACTIONS(6234),
    [anon_sym_POUNDElif] = ACTIONS(6234),
    [anon_sym_POUNDelse] = ACTIONS(6234),
    [anon_sym_POUNDELSE] = ACTIONS(6234),
    [anon_sym_POUNDElse] = ACTIONS(6234),
    [anon_sym_POUNDelse2] = ACTIONS(6234),
    [anon_sym_POUNDELSE2] = ACTIONS(6234),
    [anon_sym_POUNDElse2] = ACTIONS(6234),
    [anon_sym_POUNDendif] = ACTIONS(6234),
    [anon_sym_POUNDENDIF] = ACTIONS(6234),
    [anon_sym_POUNDEndif] = ACTIONS(6234),
    [anon_sym_POUNDendif2] = ACTIONS(6234),
    [anon_sym_POUNDENDIF2] = ACTIONS(6234),
    [anon_sym_POUNDEndif2] = ACTIONS(6234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6232),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6232),
    [anon_sym_PLUS] = ACTIONS(6234),
    [sym_datetime_literal] = ACTIONS(6234),
    [sym_date_literal] = ACTIONS(6232),
    [sym_time_literal] = ACTIONS(6232),
    [sym_biginteger_literal] = ACTIONS(6234),
    [anon_sym_if] = ACTIONS(6232),
    [anon_sym_IF] = ACTIONS(6232),
    [anon_sym_If] = ACTIONS(6232),
    [anon_sym_else] = ACTIONS(6232),
    [anon_sym_ELSE] = ACTIONS(6232),
    [anon_sym_Else] = ACTIONS(6232),
    [anon_sym_case] = ACTIONS(6232),
    [anon_sym_CASE] = ACTIONS(6232),
    [anon_sym_Case] = ACTIONS(6232),
    [anon_sym_for] = ACTIONS(6232),
    [anon_sym_FOR] = ACTIONS(6232),
    [anon_sym_For] = ACTIONS(6232),
    [anon_sym_foreach] = ACTIONS(6232),
    [anon_sym_FOREACH] = ACTIONS(6232),
    [anon_sym_Foreach] = ACTIONS(6232),
    [anon_sym_while] = ACTIONS(6232),
    [anon_sym_WHILE] = ACTIONS(6232),
    [anon_sym_While] = ACTIONS(6232),
    [anon_sym_repeat] = ACTIONS(6232),
    [anon_sym_REPEAT] = ACTIONS(6232),
    [anon_sym_Repeat] = ACTIONS(6232),
    [anon_sym_exit] = ACTIONS(6232),
    [anon_sym_EXIT] = ACTIONS(6232),
    [anon_sym_Exit] = ACTIONS(6232),
    [anon_sym_continue] = ACTIONS(6232),
    [anon_sym_CONTINUE] = ACTIONS(6232),
    [anon_sym_Continue] = ACTIONS(6232),
    [anon_sym_break] = ACTIONS(6232),
    [anon_sym_BREAK] = ACTIONS(6232),
    [anon_sym_Break] = ACTIONS(6232),
    [anon_sym_with] = ACTIONS(6232),
    [anon_sym_WITH] = ACTIONS(6232),
    [anon_sym_With] = ACTIONS(6232),
    [sym_asserterror_keyword] = ACTIONS(6234),
    [sym_page_keyword] = ACTIONS(6232),
    [anon_sym_codeunit] = ACTIONS(6232),
    [anon_sym_CODEUNIT] = ACTIONS(6232),
    [anon_sym_Codeunit] = ACTIONS(6232),
    [anon_sym_CodeUnit] = ACTIONS(6232),
    [anon_sym_COdeunit] = ACTIONS(6232),
    [anon_sym_codeUnit] = ACTIONS(6232),
    [sym_report_keyword] = ACTIONS(6232),
    [sym_query_keyword] = ACTIONS(6232),
    [anon_sym_xmlport] = ACTIONS(6232),
    [anon_sym_XMLPORT] = ACTIONS(6232),
    [anon_sym_Xmlport] = ACTIONS(6232),
    [anon_sym_XMLport] = ACTIONS(6232),
    [anon_sym_XMLPort] = ACTIONS(6232),
    [anon_sym_XmlPort] = ACTIONS(6232),
    [anon_sym_enum] = ACTIONS(6232),
    [anon_sym_ENUM] = ACTIONS(6232),
    [anon_sym_Enum] = ACTIONS(6232),
    [anon_sym_eNUM] = ACTIONS(6232),
    [anon_sym_eNum] = ACTIONS(6232),
    [anon_sym_ENum] = ACTIONS(6232),
    [sym_quoted_identifier] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6234),
    [sym_verbatim_string] = ACTIONS(6234),
    [sym_integer] = ACTIONS(6232),
    [sym_continue_as_identifier] = ACTIONS(6234),
    [sym_preproc_open] = ACTIONS(6234),
    [sym_preproc_close] = ACTIONS(6234),
  },
  [STATE(2592)] = {
    [sym_identifier] = ACTIONS(6240),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6242),
    [aux_sym_boolean_token1] = ACTIONS(6240),
    [aux_sym_boolean_token2] = ACTIONS(6240),
    [sym_decimal] = ACTIONS(6240),
    [anon_sym_LPAREN] = ACTIONS(6242),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6240),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [aux_sym_record_type_token1] = ACTIONS(6240),
    [aux_sym_basic_type_token21] = ACTIONS(6240),
    [aux_sym_basic_type_token22] = ACTIONS(6240),
    [aux_sym_basic_type_token48] = ACTIONS(6240),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6240),
    [anon_sym_POUNDif] = ACTIONS(6242),
    [anon_sym_POUNDIF] = ACTIONS(6242),
    [anon_sym_POUNDIf] = ACTIONS(6242),
    [anon_sym_not] = ACTIONS(6240),
    [anon_sym_NOT] = ACTIONS(6240),
    [anon_sym_Not] = ACTIONS(6240),
    [anon_sym_POUNDelif] = ACTIONS(6242),
    [anon_sym_POUNDELIF] = ACTIONS(6242),
    [anon_sym_POUNDElif] = ACTIONS(6242),
    [anon_sym_POUNDelse] = ACTIONS(6242),
    [anon_sym_POUNDELSE] = ACTIONS(6242),
    [anon_sym_POUNDElse] = ACTIONS(6242),
    [anon_sym_POUNDelse2] = ACTIONS(6242),
    [anon_sym_POUNDELSE2] = ACTIONS(6242),
    [anon_sym_POUNDElse2] = ACTIONS(6242),
    [anon_sym_POUNDendif] = ACTIONS(6242),
    [anon_sym_POUNDENDIF] = ACTIONS(6242),
    [anon_sym_POUNDEndif] = ACTIONS(6242),
    [anon_sym_POUNDendif2] = ACTIONS(6242),
    [anon_sym_POUNDENDIF2] = ACTIONS(6242),
    [anon_sym_POUNDEndif2] = ACTIONS(6242),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6240),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6242),
    [sym_datetime_literal] = ACTIONS(6242),
    [sym_date_literal] = ACTIONS(6240),
    [sym_time_literal] = ACTIONS(6240),
    [sym_biginteger_literal] = ACTIONS(6242),
    [anon_sym_if] = ACTIONS(6240),
    [anon_sym_IF] = ACTIONS(6240),
    [anon_sym_If] = ACTIONS(6240),
    [anon_sym_else] = ACTIONS(6240),
    [anon_sym_ELSE] = ACTIONS(6240),
    [anon_sym_Else] = ACTIONS(6240),
    [anon_sym_case] = ACTIONS(6240),
    [anon_sym_CASE] = ACTIONS(6240),
    [anon_sym_Case] = ACTIONS(6240),
    [anon_sym_for] = ACTIONS(6240),
    [anon_sym_FOR] = ACTIONS(6240),
    [anon_sym_For] = ACTIONS(6240),
    [anon_sym_foreach] = ACTIONS(6240),
    [anon_sym_FOREACH] = ACTIONS(6240),
    [anon_sym_Foreach] = ACTIONS(6240),
    [anon_sym_while] = ACTIONS(6240),
    [anon_sym_WHILE] = ACTIONS(6240),
    [anon_sym_While] = ACTIONS(6240),
    [anon_sym_repeat] = ACTIONS(6240),
    [anon_sym_REPEAT] = ACTIONS(6240),
    [anon_sym_Repeat] = ACTIONS(6240),
    [anon_sym_exit] = ACTIONS(6240),
    [anon_sym_EXIT] = ACTIONS(6240),
    [anon_sym_Exit] = ACTIONS(6240),
    [anon_sym_continue] = ACTIONS(6240),
    [anon_sym_CONTINUE] = ACTIONS(6240),
    [anon_sym_Continue] = ACTIONS(6240),
    [anon_sym_break] = ACTIONS(6240),
    [anon_sym_BREAK] = ACTIONS(6240),
    [anon_sym_Break] = ACTIONS(6240),
    [anon_sym_with] = ACTIONS(6240),
    [anon_sym_WITH] = ACTIONS(6240),
    [anon_sym_With] = ACTIONS(6240),
    [sym_asserterror_keyword] = ACTIONS(6242),
    [sym_page_keyword] = ACTIONS(6240),
    [anon_sym_codeunit] = ACTIONS(6240),
    [anon_sym_CODEUNIT] = ACTIONS(6240),
    [anon_sym_Codeunit] = ACTIONS(6240),
    [anon_sym_CodeUnit] = ACTIONS(6240),
    [anon_sym_COdeunit] = ACTIONS(6240),
    [anon_sym_codeUnit] = ACTIONS(6240),
    [sym_report_keyword] = ACTIONS(6240),
    [sym_query_keyword] = ACTIONS(6240),
    [anon_sym_xmlport] = ACTIONS(6240),
    [anon_sym_XMLPORT] = ACTIONS(6240),
    [anon_sym_Xmlport] = ACTIONS(6240),
    [anon_sym_XMLport] = ACTIONS(6240),
    [anon_sym_XMLPort] = ACTIONS(6240),
    [anon_sym_XmlPort] = ACTIONS(6240),
    [anon_sym_enum] = ACTIONS(6240),
    [anon_sym_ENUM] = ACTIONS(6240),
    [anon_sym_Enum] = ACTIONS(6240),
    [anon_sym_eNUM] = ACTIONS(6240),
    [anon_sym_eNum] = ACTIONS(6240),
    [anon_sym_ENum] = ACTIONS(6240),
    [sym_quoted_identifier] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6242),
    [sym_verbatim_string] = ACTIONS(6242),
    [sym_integer] = ACTIONS(6240),
    [sym_continue_as_identifier] = ACTIONS(6242),
    [sym_preproc_open] = ACTIONS(6242),
    [sym_preproc_close] = ACTIONS(6242),
  },
  [STATE(2593)] = {
    [sym_identifier] = ACTIONS(6244),
    [anon_sym_SEMI] = ACTIONS(6246),
    [anon_sym_DASH] = ACTIONS(6246),
    [aux_sym_boolean_token1] = ACTIONS(6244),
    [aux_sym_boolean_token2] = ACTIONS(6244),
    [sym_decimal] = ACTIONS(6244),
    [anon_sym_LPAREN] = ACTIONS(6246),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6244),
    [anon_sym_LBRACK] = ACTIONS(6246),
    [aux_sym_record_type_token1] = ACTIONS(6244),
    [aux_sym_basic_type_token21] = ACTIONS(6244),
    [aux_sym_basic_type_token22] = ACTIONS(6244),
    [aux_sym_basic_type_token48] = ACTIONS(6244),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6244),
    [anon_sym_POUNDif] = ACTIONS(6246),
    [anon_sym_POUNDIF] = ACTIONS(6246),
    [anon_sym_POUNDIf] = ACTIONS(6246),
    [anon_sym_not] = ACTIONS(6244),
    [anon_sym_NOT] = ACTIONS(6244),
    [anon_sym_Not] = ACTIONS(6244),
    [anon_sym_POUNDelif] = ACTIONS(6246),
    [anon_sym_POUNDELIF] = ACTIONS(6246),
    [anon_sym_POUNDElif] = ACTIONS(6246),
    [anon_sym_POUNDelse] = ACTIONS(6246),
    [anon_sym_POUNDELSE] = ACTIONS(6246),
    [anon_sym_POUNDElse] = ACTIONS(6246),
    [anon_sym_POUNDelse2] = ACTIONS(6246),
    [anon_sym_POUNDELSE2] = ACTIONS(6246),
    [anon_sym_POUNDElse2] = ACTIONS(6246),
    [anon_sym_POUNDendif] = ACTIONS(6246),
    [anon_sym_POUNDENDIF] = ACTIONS(6246),
    [anon_sym_POUNDEndif] = ACTIONS(6246),
    [anon_sym_POUNDendif2] = ACTIONS(6246),
    [anon_sym_POUNDENDIF2] = ACTIONS(6246),
    [anon_sym_POUNDEndif2] = ACTIONS(6246),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6244),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6244),
    [anon_sym_PLUS] = ACTIONS(6246),
    [sym_datetime_literal] = ACTIONS(6246),
    [sym_date_literal] = ACTIONS(6244),
    [sym_time_literal] = ACTIONS(6244),
    [sym_biginteger_literal] = ACTIONS(6246),
    [anon_sym_if] = ACTIONS(6244),
    [anon_sym_IF] = ACTIONS(6244),
    [anon_sym_If] = ACTIONS(6244),
    [anon_sym_else] = ACTIONS(6244),
    [anon_sym_ELSE] = ACTIONS(6244),
    [anon_sym_Else] = ACTIONS(6244),
    [anon_sym_case] = ACTIONS(6244),
    [anon_sym_CASE] = ACTIONS(6244),
    [anon_sym_Case] = ACTIONS(6244),
    [anon_sym_for] = ACTIONS(6244),
    [anon_sym_FOR] = ACTIONS(6244),
    [anon_sym_For] = ACTIONS(6244),
    [anon_sym_foreach] = ACTIONS(6244),
    [anon_sym_FOREACH] = ACTIONS(6244),
    [anon_sym_Foreach] = ACTIONS(6244),
    [anon_sym_while] = ACTIONS(6244),
    [anon_sym_WHILE] = ACTIONS(6244),
    [anon_sym_While] = ACTIONS(6244),
    [anon_sym_repeat] = ACTIONS(6244),
    [anon_sym_REPEAT] = ACTIONS(6244),
    [anon_sym_Repeat] = ACTIONS(6244),
    [anon_sym_exit] = ACTIONS(6244),
    [anon_sym_EXIT] = ACTIONS(6244),
    [anon_sym_Exit] = ACTIONS(6244),
    [anon_sym_continue] = ACTIONS(6244),
    [anon_sym_CONTINUE] = ACTIONS(6244),
    [anon_sym_Continue] = ACTIONS(6244),
    [anon_sym_break] = ACTIONS(6244),
    [anon_sym_BREAK] = ACTIONS(6244),
    [anon_sym_Break] = ACTIONS(6244),
    [anon_sym_with] = ACTIONS(6244),
    [anon_sym_WITH] = ACTIONS(6244),
    [anon_sym_With] = ACTIONS(6244),
    [sym_asserterror_keyword] = ACTIONS(6246),
    [sym_page_keyword] = ACTIONS(6244),
    [anon_sym_codeunit] = ACTIONS(6244),
    [anon_sym_CODEUNIT] = ACTIONS(6244),
    [anon_sym_Codeunit] = ACTIONS(6244),
    [anon_sym_CodeUnit] = ACTIONS(6244),
    [anon_sym_COdeunit] = ACTIONS(6244),
    [anon_sym_codeUnit] = ACTIONS(6244),
    [sym_report_keyword] = ACTIONS(6244),
    [sym_query_keyword] = ACTIONS(6244),
    [anon_sym_xmlport] = ACTIONS(6244),
    [anon_sym_XMLPORT] = ACTIONS(6244),
    [anon_sym_Xmlport] = ACTIONS(6244),
    [anon_sym_XMLport] = ACTIONS(6244),
    [anon_sym_XMLPort] = ACTIONS(6244),
    [anon_sym_XmlPort] = ACTIONS(6244),
    [anon_sym_enum] = ACTIONS(6244),
    [anon_sym_ENUM] = ACTIONS(6244),
    [anon_sym_Enum] = ACTIONS(6244),
    [anon_sym_eNUM] = ACTIONS(6244),
    [anon_sym_eNum] = ACTIONS(6244),
    [anon_sym_ENum] = ACTIONS(6244),
    [sym_quoted_identifier] = ACTIONS(6246),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6246),
    [sym_verbatim_string] = ACTIONS(6246),
    [sym_integer] = ACTIONS(6244),
    [sym_continue_as_identifier] = ACTIONS(6246),
    [sym_preproc_open] = ACTIONS(6246),
    [sym_preproc_close] = ACTIONS(6246),
  },
  [STATE(2594)] = {
    [sym_identifier] = ACTIONS(6240),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6242),
    [aux_sym_boolean_token1] = ACTIONS(6240),
    [aux_sym_boolean_token2] = ACTIONS(6240),
    [sym_decimal] = ACTIONS(6240),
    [anon_sym_LPAREN] = ACTIONS(6242),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6240),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [aux_sym_record_type_token1] = ACTIONS(6240),
    [aux_sym_basic_type_token21] = ACTIONS(6240),
    [aux_sym_basic_type_token22] = ACTIONS(6240),
    [aux_sym_basic_type_token48] = ACTIONS(6240),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6240),
    [anon_sym_POUNDif] = ACTIONS(6242),
    [anon_sym_POUNDIF] = ACTIONS(6242),
    [anon_sym_POUNDIf] = ACTIONS(6242),
    [anon_sym_not] = ACTIONS(6240),
    [anon_sym_NOT] = ACTIONS(6240),
    [anon_sym_Not] = ACTIONS(6240),
    [anon_sym_POUNDelif] = ACTIONS(6242),
    [anon_sym_POUNDELIF] = ACTIONS(6242),
    [anon_sym_POUNDElif] = ACTIONS(6242),
    [anon_sym_POUNDelse] = ACTIONS(6242),
    [anon_sym_POUNDELSE] = ACTIONS(6242),
    [anon_sym_POUNDElse] = ACTIONS(6242),
    [anon_sym_POUNDelse2] = ACTIONS(6242),
    [anon_sym_POUNDELSE2] = ACTIONS(6242),
    [anon_sym_POUNDElse2] = ACTIONS(6242),
    [anon_sym_POUNDendif] = ACTIONS(6242),
    [anon_sym_POUNDENDIF] = ACTIONS(6242),
    [anon_sym_POUNDEndif] = ACTIONS(6242),
    [anon_sym_POUNDendif2] = ACTIONS(6242),
    [anon_sym_POUNDENDIF2] = ACTIONS(6242),
    [anon_sym_POUNDEndif2] = ACTIONS(6242),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6240),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6242),
    [sym_datetime_literal] = ACTIONS(6242),
    [sym_date_literal] = ACTIONS(6240),
    [sym_time_literal] = ACTIONS(6240),
    [sym_biginteger_literal] = ACTIONS(6242),
    [anon_sym_if] = ACTIONS(6240),
    [anon_sym_IF] = ACTIONS(6240),
    [anon_sym_If] = ACTIONS(6240),
    [anon_sym_else] = ACTIONS(6240),
    [anon_sym_ELSE] = ACTIONS(6240),
    [anon_sym_Else] = ACTIONS(6240),
    [anon_sym_case] = ACTIONS(6240),
    [anon_sym_CASE] = ACTIONS(6240),
    [anon_sym_Case] = ACTIONS(6240),
    [anon_sym_for] = ACTIONS(6240),
    [anon_sym_FOR] = ACTIONS(6240),
    [anon_sym_For] = ACTIONS(6240),
    [anon_sym_foreach] = ACTIONS(6240),
    [anon_sym_FOREACH] = ACTIONS(6240),
    [anon_sym_Foreach] = ACTIONS(6240),
    [anon_sym_while] = ACTIONS(6240),
    [anon_sym_WHILE] = ACTIONS(6240),
    [anon_sym_While] = ACTIONS(6240),
    [anon_sym_repeat] = ACTIONS(6240),
    [anon_sym_REPEAT] = ACTIONS(6240),
    [anon_sym_Repeat] = ACTIONS(6240),
    [anon_sym_exit] = ACTIONS(6240),
    [anon_sym_EXIT] = ACTIONS(6240),
    [anon_sym_Exit] = ACTIONS(6240),
    [anon_sym_continue] = ACTIONS(6240),
    [anon_sym_CONTINUE] = ACTIONS(6240),
    [anon_sym_Continue] = ACTIONS(6240),
    [anon_sym_break] = ACTIONS(6240),
    [anon_sym_BREAK] = ACTIONS(6240),
    [anon_sym_Break] = ACTIONS(6240),
    [anon_sym_with] = ACTIONS(6240),
    [anon_sym_WITH] = ACTIONS(6240),
    [anon_sym_With] = ACTIONS(6240),
    [sym_asserterror_keyword] = ACTIONS(6242),
    [sym_page_keyword] = ACTIONS(6240),
    [anon_sym_codeunit] = ACTIONS(6240),
    [anon_sym_CODEUNIT] = ACTIONS(6240),
    [anon_sym_Codeunit] = ACTIONS(6240),
    [anon_sym_CodeUnit] = ACTIONS(6240),
    [anon_sym_COdeunit] = ACTIONS(6240),
    [anon_sym_codeUnit] = ACTIONS(6240),
    [sym_report_keyword] = ACTIONS(6240),
    [sym_query_keyword] = ACTIONS(6240),
    [anon_sym_xmlport] = ACTIONS(6240),
    [anon_sym_XMLPORT] = ACTIONS(6240),
    [anon_sym_Xmlport] = ACTIONS(6240),
    [anon_sym_XMLport] = ACTIONS(6240),
    [anon_sym_XMLPort] = ACTIONS(6240),
    [anon_sym_XmlPort] = ACTIONS(6240),
    [anon_sym_enum] = ACTIONS(6240),
    [anon_sym_ENUM] = ACTIONS(6240),
    [anon_sym_Enum] = ACTIONS(6240),
    [anon_sym_eNUM] = ACTIONS(6240),
    [anon_sym_eNum] = ACTIONS(6240),
    [anon_sym_ENum] = ACTIONS(6240),
    [sym_quoted_identifier] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6242),
    [sym_verbatim_string] = ACTIONS(6242),
    [sym_integer] = ACTIONS(6240),
    [sym_continue_as_identifier] = ACTIONS(6242),
    [sym_preproc_open] = ACTIONS(6242),
    [sym_preproc_close] = ACTIONS(6242),
  },
  [STATE(2595)] = {
    [sym_identifier] = ACTIONS(6248),
    [anon_sym_SEMI] = ACTIONS(6250),
    [anon_sym_DASH] = ACTIONS(6250),
    [aux_sym_boolean_token1] = ACTIONS(6248),
    [aux_sym_boolean_token2] = ACTIONS(6248),
    [sym_decimal] = ACTIONS(6248),
    [anon_sym_LPAREN] = ACTIONS(6250),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6248),
    [anon_sym_LBRACK] = ACTIONS(6250),
    [aux_sym_record_type_token1] = ACTIONS(6248),
    [aux_sym_basic_type_token21] = ACTIONS(6248),
    [aux_sym_basic_type_token22] = ACTIONS(6248),
    [aux_sym_basic_type_token48] = ACTIONS(6248),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6248),
    [anon_sym_POUNDif] = ACTIONS(6250),
    [anon_sym_POUNDIF] = ACTIONS(6250),
    [anon_sym_POUNDIf] = ACTIONS(6250),
    [anon_sym_not] = ACTIONS(6248),
    [anon_sym_NOT] = ACTIONS(6248),
    [anon_sym_Not] = ACTIONS(6248),
    [anon_sym_POUNDelif] = ACTIONS(6250),
    [anon_sym_POUNDELIF] = ACTIONS(6250),
    [anon_sym_POUNDElif] = ACTIONS(6250),
    [anon_sym_POUNDelse] = ACTIONS(6250),
    [anon_sym_POUNDELSE] = ACTIONS(6250),
    [anon_sym_POUNDElse] = ACTIONS(6250),
    [anon_sym_POUNDelse2] = ACTIONS(6250),
    [anon_sym_POUNDELSE2] = ACTIONS(6250),
    [anon_sym_POUNDElse2] = ACTIONS(6250),
    [anon_sym_POUNDendif] = ACTIONS(6250),
    [anon_sym_POUNDENDIF] = ACTIONS(6250),
    [anon_sym_POUNDEndif] = ACTIONS(6250),
    [anon_sym_POUNDendif2] = ACTIONS(6250),
    [anon_sym_POUNDENDIF2] = ACTIONS(6250),
    [anon_sym_POUNDEndif2] = ACTIONS(6250),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6248),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6248),
    [anon_sym_PLUS] = ACTIONS(6250),
    [sym_datetime_literal] = ACTIONS(6250),
    [sym_date_literal] = ACTIONS(6248),
    [sym_time_literal] = ACTIONS(6248),
    [sym_biginteger_literal] = ACTIONS(6250),
    [anon_sym_if] = ACTIONS(6248),
    [anon_sym_IF] = ACTIONS(6248),
    [anon_sym_If] = ACTIONS(6248),
    [anon_sym_else] = ACTIONS(6248),
    [anon_sym_ELSE] = ACTIONS(6248),
    [anon_sym_Else] = ACTIONS(6248),
    [anon_sym_case] = ACTIONS(6248),
    [anon_sym_CASE] = ACTIONS(6248),
    [anon_sym_Case] = ACTIONS(6248),
    [anon_sym_for] = ACTIONS(6248),
    [anon_sym_FOR] = ACTIONS(6248),
    [anon_sym_For] = ACTIONS(6248),
    [anon_sym_foreach] = ACTIONS(6248),
    [anon_sym_FOREACH] = ACTIONS(6248),
    [anon_sym_Foreach] = ACTIONS(6248),
    [anon_sym_while] = ACTIONS(6248),
    [anon_sym_WHILE] = ACTIONS(6248),
    [anon_sym_While] = ACTIONS(6248),
    [anon_sym_repeat] = ACTIONS(6248),
    [anon_sym_REPEAT] = ACTIONS(6248),
    [anon_sym_Repeat] = ACTIONS(6248),
    [anon_sym_exit] = ACTIONS(6248),
    [anon_sym_EXIT] = ACTIONS(6248),
    [anon_sym_Exit] = ACTIONS(6248),
    [anon_sym_continue] = ACTIONS(6248),
    [anon_sym_CONTINUE] = ACTIONS(6248),
    [anon_sym_Continue] = ACTIONS(6248),
    [anon_sym_break] = ACTIONS(6248),
    [anon_sym_BREAK] = ACTIONS(6248),
    [anon_sym_Break] = ACTIONS(6248),
    [anon_sym_with] = ACTIONS(6248),
    [anon_sym_WITH] = ACTIONS(6248),
    [anon_sym_With] = ACTIONS(6248),
    [sym_asserterror_keyword] = ACTIONS(6250),
    [sym_page_keyword] = ACTIONS(6248),
    [anon_sym_codeunit] = ACTIONS(6248),
    [anon_sym_CODEUNIT] = ACTIONS(6248),
    [anon_sym_Codeunit] = ACTIONS(6248),
    [anon_sym_CodeUnit] = ACTIONS(6248),
    [anon_sym_COdeunit] = ACTIONS(6248),
    [anon_sym_codeUnit] = ACTIONS(6248),
    [sym_report_keyword] = ACTIONS(6248),
    [sym_query_keyword] = ACTIONS(6248),
    [anon_sym_xmlport] = ACTIONS(6248),
    [anon_sym_XMLPORT] = ACTIONS(6248),
    [anon_sym_Xmlport] = ACTIONS(6248),
    [anon_sym_XMLport] = ACTIONS(6248),
    [anon_sym_XMLPort] = ACTIONS(6248),
    [anon_sym_XmlPort] = ACTIONS(6248),
    [anon_sym_enum] = ACTIONS(6248),
    [anon_sym_ENUM] = ACTIONS(6248),
    [anon_sym_Enum] = ACTIONS(6248),
    [anon_sym_eNUM] = ACTIONS(6248),
    [anon_sym_eNum] = ACTIONS(6248),
    [anon_sym_ENum] = ACTIONS(6248),
    [sym_quoted_identifier] = ACTIONS(6250),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6250),
    [sym_verbatim_string] = ACTIONS(6250),
    [sym_integer] = ACTIONS(6248),
    [sym_continue_as_identifier] = ACTIONS(6250),
    [sym_preproc_open] = ACTIONS(6250),
    [sym_preproc_close] = ACTIONS(6250),
  },
  [STATE(2596)] = {
    [sym_identifier] = ACTIONS(6252),
    [anon_sym_SEMI] = ACTIONS(6254),
    [anon_sym_DASH] = ACTIONS(6254),
    [aux_sym_boolean_token1] = ACTIONS(6252),
    [aux_sym_boolean_token2] = ACTIONS(6252),
    [sym_decimal] = ACTIONS(6252),
    [anon_sym_LPAREN] = ACTIONS(6254),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6252),
    [anon_sym_LBRACK] = ACTIONS(6254),
    [aux_sym_record_type_token1] = ACTIONS(6252),
    [aux_sym_basic_type_token21] = ACTIONS(6252),
    [aux_sym_basic_type_token22] = ACTIONS(6252),
    [aux_sym_basic_type_token48] = ACTIONS(6252),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6252),
    [anon_sym_POUNDif] = ACTIONS(6254),
    [anon_sym_POUNDIF] = ACTIONS(6254),
    [anon_sym_POUNDIf] = ACTIONS(6254),
    [anon_sym_not] = ACTIONS(6252),
    [anon_sym_NOT] = ACTIONS(6252),
    [anon_sym_Not] = ACTIONS(6252),
    [anon_sym_POUNDelif] = ACTIONS(6254),
    [anon_sym_POUNDELIF] = ACTIONS(6254),
    [anon_sym_POUNDElif] = ACTIONS(6254),
    [anon_sym_POUNDelse] = ACTIONS(6254),
    [anon_sym_POUNDELSE] = ACTIONS(6254),
    [anon_sym_POUNDElse] = ACTIONS(6254),
    [anon_sym_POUNDelse2] = ACTIONS(6254),
    [anon_sym_POUNDELSE2] = ACTIONS(6254),
    [anon_sym_POUNDElse2] = ACTIONS(6254),
    [anon_sym_POUNDendif] = ACTIONS(6254),
    [anon_sym_POUNDENDIF] = ACTIONS(6254),
    [anon_sym_POUNDEndif] = ACTIONS(6254),
    [anon_sym_POUNDendif2] = ACTIONS(6254),
    [anon_sym_POUNDENDIF2] = ACTIONS(6254),
    [anon_sym_POUNDEndif2] = ACTIONS(6254),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6252),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6252),
    [anon_sym_PLUS] = ACTIONS(6254),
    [sym_datetime_literal] = ACTIONS(6254),
    [sym_date_literal] = ACTIONS(6252),
    [sym_time_literal] = ACTIONS(6252),
    [sym_biginteger_literal] = ACTIONS(6254),
    [anon_sym_if] = ACTIONS(6252),
    [anon_sym_IF] = ACTIONS(6252),
    [anon_sym_If] = ACTIONS(6252),
    [anon_sym_else] = ACTIONS(6252),
    [anon_sym_ELSE] = ACTIONS(6252),
    [anon_sym_Else] = ACTIONS(6252),
    [anon_sym_case] = ACTIONS(6252),
    [anon_sym_CASE] = ACTIONS(6252),
    [anon_sym_Case] = ACTIONS(6252),
    [anon_sym_for] = ACTIONS(6252),
    [anon_sym_FOR] = ACTIONS(6252),
    [anon_sym_For] = ACTIONS(6252),
    [anon_sym_foreach] = ACTIONS(6252),
    [anon_sym_FOREACH] = ACTIONS(6252),
    [anon_sym_Foreach] = ACTIONS(6252),
    [anon_sym_while] = ACTIONS(6252),
    [anon_sym_WHILE] = ACTIONS(6252),
    [anon_sym_While] = ACTIONS(6252),
    [anon_sym_repeat] = ACTIONS(6252),
    [anon_sym_REPEAT] = ACTIONS(6252),
    [anon_sym_Repeat] = ACTIONS(6252),
    [anon_sym_exit] = ACTIONS(6252),
    [anon_sym_EXIT] = ACTIONS(6252),
    [anon_sym_Exit] = ACTIONS(6252),
    [anon_sym_continue] = ACTIONS(6252),
    [anon_sym_CONTINUE] = ACTIONS(6252),
    [anon_sym_Continue] = ACTIONS(6252),
    [anon_sym_break] = ACTIONS(6252),
    [anon_sym_BREAK] = ACTIONS(6252),
    [anon_sym_Break] = ACTIONS(6252),
    [anon_sym_with] = ACTIONS(6252),
    [anon_sym_WITH] = ACTIONS(6252),
    [anon_sym_With] = ACTIONS(6252),
    [sym_asserterror_keyword] = ACTIONS(6254),
    [sym_page_keyword] = ACTIONS(6252),
    [anon_sym_codeunit] = ACTIONS(6252),
    [anon_sym_CODEUNIT] = ACTIONS(6252),
    [anon_sym_Codeunit] = ACTIONS(6252),
    [anon_sym_CodeUnit] = ACTIONS(6252),
    [anon_sym_COdeunit] = ACTIONS(6252),
    [anon_sym_codeUnit] = ACTIONS(6252),
    [sym_report_keyword] = ACTIONS(6252),
    [sym_query_keyword] = ACTIONS(6252),
    [anon_sym_xmlport] = ACTIONS(6252),
    [anon_sym_XMLPORT] = ACTIONS(6252),
    [anon_sym_Xmlport] = ACTIONS(6252),
    [anon_sym_XMLport] = ACTIONS(6252),
    [anon_sym_XMLPort] = ACTIONS(6252),
    [anon_sym_XmlPort] = ACTIONS(6252),
    [anon_sym_enum] = ACTIONS(6252),
    [anon_sym_ENUM] = ACTIONS(6252),
    [anon_sym_Enum] = ACTIONS(6252),
    [anon_sym_eNUM] = ACTIONS(6252),
    [anon_sym_eNum] = ACTIONS(6252),
    [anon_sym_ENum] = ACTIONS(6252),
    [sym_quoted_identifier] = ACTIONS(6254),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6254),
    [sym_verbatim_string] = ACTIONS(6254),
    [sym_integer] = ACTIONS(6252),
    [sym_continue_as_identifier] = ACTIONS(6254),
    [sym_preproc_open] = ACTIONS(6254),
    [sym_preproc_close] = ACTIONS(6254),
  },
  [STATE(2597)] = {
    [sym_identifier] = ACTIONS(6256),
    [anon_sym_SEMI] = ACTIONS(6258),
    [anon_sym_DASH] = ACTIONS(6258),
    [aux_sym_boolean_token1] = ACTIONS(6256),
    [aux_sym_boolean_token2] = ACTIONS(6256),
    [sym_decimal] = ACTIONS(6256),
    [anon_sym_LPAREN] = ACTIONS(6258),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(6258),
    [aux_sym_record_type_token1] = ACTIONS(6256),
    [aux_sym_basic_type_token21] = ACTIONS(6256),
    [aux_sym_basic_type_token22] = ACTIONS(6256),
    [aux_sym_basic_type_token48] = ACTIONS(6256),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6256),
    [anon_sym_POUNDif] = ACTIONS(6258),
    [anon_sym_POUNDIF] = ACTIONS(6258),
    [anon_sym_POUNDIf] = ACTIONS(6258),
    [anon_sym_not] = ACTIONS(6256),
    [anon_sym_NOT] = ACTIONS(6256),
    [anon_sym_Not] = ACTIONS(6256),
    [anon_sym_POUNDelif] = ACTIONS(6258),
    [anon_sym_POUNDELIF] = ACTIONS(6258),
    [anon_sym_POUNDElif] = ACTIONS(6258),
    [anon_sym_POUNDelse] = ACTIONS(6258),
    [anon_sym_POUNDELSE] = ACTIONS(6258),
    [anon_sym_POUNDElse] = ACTIONS(6258),
    [anon_sym_POUNDelse2] = ACTIONS(6258),
    [anon_sym_POUNDELSE2] = ACTIONS(6258),
    [anon_sym_POUNDElse2] = ACTIONS(6258),
    [anon_sym_POUNDendif] = ACTIONS(6258),
    [anon_sym_POUNDENDIF] = ACTIONS(6258),
    [anon_sym_POUNDEndif] = ACTIONS(6258),
    [anon_sym_POUNDendif2] = ACTIONS(6258),
    [anon_sym_POUNDENDIF2] = ACTIONS(6258),
    [anon_sym_POUNDEndif2] = ACTIONS(6258),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6256),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6256),
    [anon_sym_PLUS] = ACTIONS(6258),
    [sym_datetime_literal] = ACTIONS(6258),
    [sym_date_literal] = ACTIONS(6256),
    [sym_time_literal] = ACTIONS(6256),
    [sym_biginteger_literal] = ACTIONS(6258),
    [anon_sym_if] = ACTIONS(6256),
    [anon_sym_IF] = ACTIONS(6256),
    [anon_sym_If] = ACTIONS(6256),
    [anon_sym_else] = ACTIONS(6256),
    [anon_sym_ELSE] = ACTIONS(6256),
    [anon_sym_Else] = ACTIONS(6256),
    [anon_sym_case] = ACTIONS(6256),
    [anon_sym_CASE] = ACTIONS(6256),
    [anon_sym_Case] = ACTIONS(6256),
    [anon_sym_for] = ACTIONS(6256),
    [anon_sym_FOR] = ACTIONS(6256),
    [anon_sym_For] = ACTIONS(6256),
    [anon_sym_foreach] = ACTIONS(6256),
    [anon_sym_FOREACH] = ACTIONS(6256),
    [anon_sym_Foreach] = ACTIONS(6256),
    [anon_sym_while] = ACTIONS(6256),
    [anon_sym_WHILE] = ACTIONS(6256),
    [anon_sym_While] = ACTIONS(6256),
    [anon_sym_repeat] = ACTIONS(6256),
    [anon_sym_REPEAT] = ACTIONS(6256),
    [anon_sym_Repeat] = ACTIONS(6256),
    [anon_sym_exit] = ACTIONS(6256),
    [anon_sym_EXIT] = ACTIONS(6256),
    [anon_sym_Exit] = ACTIONS(6256),
    [anon_sym_continue] = ACTIONS(6256),
    [anon_sym_CONTINUE] = ACTIONS(6256),
    [anon_sym_Continue] = ACTIONS(6256),
    [anon_sym_break] = ACTIONS(6256),
    [anon_sym_BREAK] = ACTIONS(6256),
    [anon_sym_Break] = ACTIONS(6256),
    [anon_sym_with] = ACTIONS(6256),
    [anon_sym_WITH] = ACTIONS(6256),
    [anon_sym_With] = ACTIONS(6256),
    [sym_asserterror_keyword] = ACTIONS(6258),
    [sym_page_keyword] = ACTIONS(6256),
    [anon_sym_codeunit] = ACTIONS(6256),
    [anon_sym_CODEUNIT] = ACTIONS(6256),
    [anon_sym_Codeunit] = ACTIONS(6256),
    [anon_sym_CodeUnit] = ACTIONS(6256),
    [anon_sym_COdeunit] = ACTIONS(6256),
    [anon_sym_codeUnit] = ACTIONS(6256),
    [sym_report_keyword] = ACTIONS(6256),
    [sym_query_keyword] = ACTIONS(6256),
    [anon_sym_xmlport] = ACTIONS(6256),
    [anon_sym_XMLPORT] = ACTIONS(6256),
    [anon_sym_Xmlport] = ACTIONS(6256),
    [anon_sym_XMLport] = ACTIONS(6256),
    [anon_sym_XMLPort] = ACTIONS(6256),
    [anon_sym_XmlPort] = ACTIONS(6256),
    [anon_sym_enum] = ACTIONS(6256),
    [anon_sym_ENUM] = ACTIONS(6256),
    [anon_sym_Enum] = ACTIONS(6256),
    [anon_sym_eNUM] = ACTIONS(6256),
    [anon_sym_eNum] = ACTIONS(6256),
    [anon_sym_ENum] = ACTIONS(6256),
    [sym_quoted_identifier] = ACTIONS(6258),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6258),
    [sym_verbatim_string] = ACTIONS(6258),
    [sym_integer] = ACTIONS(6256),
    [sym_continue_as_identifier] = ACTIONS(6258),
    [sym_preproc_open] = ACTIONS(6258),
    [sym_preproc_close] = ACTIONS(6258),
  },
  [STATE(2598)] = {
    [sym_identifier] = ACTIONS(6260),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6262),
    [aux_sym_boolean_token1] = ACTIONS(6260),
    [aux_sym_boolean_token2] = ACTIONS(6260),
    [sym_decimal] = ACTIONS(6260),
    [anon_sym_LPAREN] = ACTIONS(6262),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6260),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [aux_sym_record_type_token1] = ACTIONS(6260),
    [aux_sym_basic_type_token21] = ACTIONS(6260),
    [aux_sym_basic_type_token22] = ACTIONS(6260),
    [aux_sym_basic_type_token48] = ACTIONS(6260),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6260),
    [anon_sym_POUNDif] = ACTIONS(6262),
    [anon_sym_POUNDIF] = ACTIONS(6262),
    [anon_sym_POUNDIf] = ACTIONS(6262),
    [anon_sym_not] = ACTIONS(6260),
    [anon_sym_NOT] = ACTIONS(6260),
    [anon_sym_Not] = ACTIONS(6260),
    [anon_sym_POUNDelif] = ACTIONS(6262),
    [anon_sym_POUNDELIF] = ACTIONS(6262),
    [anon_sym_POUNDElif] = ACTIONS(6262),
    [anon_sym_POUNDelse] = ACTIONS(6262),
    [anon_sym_POUNDELSE] = ACTIONS(6262),
    [anon_sym_POUNDElse] = ACTIONS(6262),
    [anon_sym_POUNDelse2] = ACTIONS(6262),
    [anon_sym_POUNDELSE2] = ACTIONS(6262),
    [anon_sym_POUNDElse2] = ACTIONS(6262),
    [anon_sym_POUNDendif] = ACTIONS(6262),
    [anon_sym_POUNDENDIF] = ACTIONS(6262),
    [anon_sym_POUNDEndif] = ACTIONS(6262),
    [anon_sym_POUNDendif2] = ACTIONS(6262),
    [anon_sym_POUNDENDIF2] = ACTIONS(6262),
    [anon_sym_POUNDEndif2] = ACTIONS(6262),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6260),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6262),
    [sym_datetime_literal] = ACTIONS(6262),
    [sym_date_literal] = ACTIONS(6260),
    [sym_time_literal] = ACTIONS(6260),
    [sym_biginteger_literal] = ACTIONS(6262),
    [anon_sym_if] = ACTIONS(6260),
    [anon_sym_IF] = ACTIONS(6260),
    [anon_sym_If] = ACTIONS(6260),
    [anon_sym_else] = ACTIONS(6260),
    [anon_sym_ELSE] = ACTIONS(6260),
    [anon_sym_Else] = ACTIONS(6260),
    [anon_sym_case] = ACTIONS(6260),
    [anon_sym_CASE] = ACTIONS(6260),
    [anon_sym_Case] = ACTIONS(6260),
    [anon_sym_for] = ACTIONS(6260),
    [anon_sym_FOR] = ACTIONS(6260),
    [anon_sym_For] = ACTIONS(6260),
    [anon_sym_foreach] = ACTIONS(6260),
    [anon_sym_FOREACH] = ACTIONS(6260),
    [anon_sym_Foreach] = ACTIONS(6260),
    [anon_sym_while] = ACTIONS(6260),
    [anon_sym_WHILE] = ACTIONS(6260),
    [anon_sym_While] = ACTIONS(6260),
    [anon_sym_repeat] = ACTIONS(6260),
    [anon_sym_REPEAT] = ACTIONS(6260),
    [anon_sym_Repeat] = ACTIONS(6260),
    [anon_sym_exit] = ACTIONS(6260),
    [anon_sym_EXIT] = ACTIONS(6260),
    [anon_sym_Exit] = ACTIONS(6260),
    [anon_sym_continue] = ACTIONS(6260),
    [anon_sym_CONTINUE] = ACTIONS(6260),
    [anon_sym_Continue] = ACTIONS(6260),
    [anon_sym_break] = ACTIONS(6260),
    [anon_sym_BREAK] = ACTIONS(6260),
    [anon_sym_Break] = ACTIONS(6260),
    [anon_sym_with] = ACTIONS(6260),
    [anon_sym_WITH] = ACTIONS(6260),
    [anon_sym_With] = ACTIONS(6260),
    [sym_asserterror_keyword] = ACTIONS(6262),
    [sym_page_keyword] = ACTIONS(6260),
    [anon_sym_codeunit] = ACTIONS(6260),
    [anon_sym_CODEUNIT] = ACTIONS(6260),
    [anon_sym_Codeunit] = ACTIONS(6260),
    [anon_sym_CodeUnit] = ACTIONS(6260),
    [anon_sym_COdeunit] = ACTIONS(6260),
    [anon_sym_codeUnit] = ACTIONS(6260),
    [sym_report_keyword] = ACTIONS(6260),
    [sym_query_keyword] = ACTIONS(6260),
    [anon_sym_xmlport] = ACTIONS(6260),
    [anon_sym_XMLPORT] = ACTIONS(6260),
    [anon_sym_Xmlport] = ACTIONS(6260),
    [anon_sym_XMLport] = ACTIONS(6260),
    [anon_sym_XMLPort] = ACTIONS(6260),
    [anon_sym_XmlPort] = ACTIONS(6260),
    [anon_sym_enum] = ACTIONS(6260),
    [anon_sym_ENUM] = ACTIONS(6260),
    [anon_sym_Enum] = ACTIONS(6260),
    [anon_sym_eNUM] = ACTIONS(6260),
    [anon_sym_eNum] = ACTIONS(6260),
    [anon_sym_ENum] = ACTIONS(6260),
    [sym_quoted_identifier] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6262),
    [sym_verbatim_string] = ACTIONS(6262),
    [sym_integer] = ACTIONS(6260),
    [sym_continue_as_identifier] = ACTIONS(6262),
    [sym_preproc_open] = ACTIONS(6262),
    [sym_preproc_close] = ACTIONS(6262),
  },
  [STATE(2599)] = {
    [sym_identifier] = ACTIONS(6260),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6262),
    [aux_sym_boolean_token1] = ACTIONS(6260),
    [aux_sym_boolean_token2] = ACTIONS(6260),
    [sym_decimal] = ACTIONS(6260),
    [anon_sym_LPAREN] = ACTIONS(6262),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6260),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [aux_sym_record_type_token1] = ACTIONS(6260),
    [aux_sym_basic_type_token21] = ACTIONS(6260),
    [aux_sym_basic_type_token22] = ACTIONS(6260),
    [aux_sym_basic_type_token48] = ACTIONS(6260),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6260),
    [anon_sym_POUNDif] = ACTIONS(6262),
    [anon_sym_POUNDIF] = ACTIONS(6262),
    [anon_sym_POUNDIf] = ACTIONS(6262),
    [anon_sym_not] = ACTIONS(6260),
    [anon_sym_NOT] = ACTIONS(6260),
    [anon_sym_Not] = ACTIONS(6260),
    [anon_sym_POUNDelif] = ACTIONS(6262),
    [anon_sym_POUNDELIF] = ACTIONS(6262),
    [anon_sym_POUNDElif] = ACTIONS(6262),
    [anon_sym_POUNDelse] = ACTIONS(6262),
    [anon_sym_POUNDELSE] = ACTIONS(6262),
    [anon_sym_POUNDElse] = ACTIONS(6262),
    [anon_sym_POUNDelse2] = ACTIONS(6262),
    [anon_sym_POUNDELSE2] = ACTIONS(6262),
    [anon_sym_POUNDElse2] = ACTIONS(6262),
    [anon_sym_POUNDendif] = ACTIONS(6262),
    [anon_sym_POUNDENDIF] = ACTIONS(6262),
    [anon_sym_POUNDEndif] = ACTIONS(6262),
    [anon_sym_POUNDendif2] = ACTIONS(6262),
    [anon_sym_POUNDENDIF2] = ACTIONS(6262),
    [anon_sym_POUNDEndif2] = ACTIONS(6262),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6260),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6262),
    [sym_datetime_literal] = ACTIONS(6262),
    [sym_date_literal] = ACTIONS(6260),
    [sym_time_literal] = ACTIONS(6260),
    [sym_biginteger_literal] = ACTIONS(6262),
    [anon_sym_if] = ACTIONS(6260),
    [anon_sym_IF] = ACTIONS(6260),
    [anon_sym_If] = ACTIONS(6260),
    [anon_sym_else] = ACTIONS(6260),
    [anon_sym_ELSE] = ACTIONS(6260),
    [anon_sym_Else] = ACTIONS(6260),
    [anon_sym_case] = ACTIONS(6260),
    [anon_sym_CASE] = ACTIONS(6260),
    [anon_sym_Case] = ACTIONS(6260),
    [anon_sym_for] = ACTIONS(6260),
    [anon_sym_FOR] = ACTIONS(6260),
    [anon_sym_For] = ACTIONS(6260),
    [anon_sym_foreach] = ACTIONS(6260),
    [anon_sym_FOREACH] = ACTIONS(6260),
    [anon_sym_Foreach] = ACTIONS(6260),
    [anon_sym_while] = ACTIONS(6260),
    [anon_sym_WHILE] = ACTIONS(6260),
    [anon_sym_While] = ACTIONS(6260),
    [anon_sym_repeat] = ACTIONS(6260),
    [anon_sym_REPEAT] = ACTIONS(6260),
    [anon_sym_Repeat] = ACTIONS(6260),
    [anon_sym_exit] = ACTIONS(6260),
    [anon_sym_EXIT] = ACTIONS(6260),
    [anon_sym_Exit] = ACTIONS(6260),
    [anon_sym_continue] = ACTIONS(6260),
    [anon_sym_CONTINUE] = ACTIONS(6260),
    [anon_sym_Continue] = ACTIONS(6260),
    [anon_sym_break] = ACTIONS(6260),
    [anon_sym_BREAK] = ACTIONS(6260),
    [anon_sym_Break] = ACTIONS(6260),
    [anon_sym_with] = ACTIONS(6260),
    [anon_sym_WITH] = ACTIONS(6260),
    [anon_sym_With] = ACTIONS(6260),
    [sym_asserterror_keyword] = ACTIONS(6262),
    [sym_page_keyword] = ACTIONS(6260),
    [anon_sym_codeunit] = ACTIONS(6260),
    [anon_sym_CODEUNIT] = ACTIONS(6260),
    [anon_sym_Codeunit] = ACTIONS(6260),
    [anon_sym_CodeUnit] = ACTIONS(6260),
    [anon_sym_COdeunit] = ACTIONS(6260),
    [anon_sym_codeUnit] = ACTIONS(6260),
    [sym_report_keyword] = ACTIONS(6260),
    [sym_query_keyword] = ACTIONS(6260),
    [anon_sym_xmlport] = ACTIONS(6260),
    [anon_sym_XMLPORT] = ACTIONS(6260),
    [anon_sym_Xmlport] = ACTIONS(6260),
    [anon_sym_XMLport] = ACTIONS(6260),
    [anon_sym_XMLPort] = ACTIONS(6260),
    [anon_sym_XmlPort] = ACTIONS(6260),
    [anon_sym_enum] = ACTIONS(6260),
    [anon_sym_ENUM] = ACTIONS(6260),
    [anon_sym_Enum] = ACTIONS(6260),
    [anon_sym_eNUM] = ACTIONS(6260),
    [anon_sym_eNum] = ACTIONS(6260),
    [anon_sym_ENum] = ACTIONS(6260),
    [sym_quoted_identifier] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6262),
    [sym_verbatim_string] = ACTIONS(6262),
    [sym_integer] = ACTIONS(6260),
    [sym_continue_as_identifier] = ACTIONS(6262),
    [sym_preproc_open] = ACTIONS(6262),
    [sym_preproc_close] = ACTIONS(6262),
  },
  [STATE(2600)] = {
    [sym_identifier] = ACTIONS(6264),
    [anon_sym_SEMI] = ACTIONS(6266),
    [anon_sym_DASH] = ACTIONS(6268),
    [aux_sym_boolean_token1] = ACTIONS(6264),
    [aux_sym_boolean_token2] = ACTIONS(6264),
    [sym_decimal] = ACTIONS(6264),
    [anon_sym_LPAREN] = ACTIONS(6268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6264),
    [anon_sym_LBRACK] = ACTIONS(6268),
    [aux_sym_record_type_token1] = ACTIONS(6264),
    [aux_sym_basic_type_token21] = ACTIONS(6264),
    [aux_sym_basic_type_token22] = ACTIONS(6264),
    [aux_sym_basic_type_token48] = ACTIONS(6264),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6264),
    [anon_sym_POUNDif] = ACTIONS(6268),
    [anon_sym_POUNDIF] = ACTIONS(6268),
    [anon_sym_POUNDIf] = ACTIONS(6268),
    [anon_sym_not] = ACTIONS(6264),
    [anon_sym_NOT] = ACTIONS(6264),
    [anon_sym_Not] = ACTIONS(6264),
    [anon_sym_POUNDelif] = ACTIONS(6268),
    [anon_sym_POUNDELIF] = ACTIONS(6268),
    [anon_sym_POUNDElif] = ACTIONS(6268),
    [anon_sym_POUNDelse] = ACTIONS(6268),
    [anon_sym_POUNDELSE] = ACTIONS(6268),
    [anon_sym_POUNDElse] = ACTIONS(6268),
    [anon_sym_POUNDelse2] = ACTIONS(6268),
    [anon_sym_POUNDELSE2] = ACTIONS(6268),
    [anon_sym_POUNDElse2] = ACTIONS(6268),
    [anon_sym_POUNDendif] = ACTIONS(6268),
    [anon_sym_POUNDENDIF] = ACTIONS(6268),
    [anon_sym_POUNDEndif] = ACTIONS(6268),
    [anon_sym_POUNDendif2] = ACTIONS(6268),
    [anon_sym_POUNDENDIF2] = ACTIONS(6268),
    [anon_sym_POUNDEndif2] = ACTIONS(6268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6264),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6268),
    [sym_datetime_literal] = ACTIONS(6268),
    [sym_date_literal] = ACTIONS(6264),
    [sym_time_literal] = ACTIONS(6264),
    [sym_biginteger_literal] = ACTIONS(6268),
    [anon_sym_if] = ACTIONS(6264),
    [anon_sym_IF] = ACTIONS(6264),
    [anon_sym_If] = ACTIONS(6264),
    [anon_sym_else] = ACTIONS(6264),
    [anon_sym_ELSE] = ACTIONS(6264),
    [anon_sym_Else] = ACTIONS(6264),
    [anon_sym_case] = ACTIONS(6264),
    [anon_sym_CASE] = ACTIONS(6264),
    [anon_sym_Case] = ACTIONS(6264),
    [anon_sym_for] = ACTIONS(6264),
    [anon_sym_FOR] = ACTIONS(6264),
    [anon_sym_For] = ACTIONS(6264),
    [anon_sym_foreach] = ACTIONS(6264),
    [anon_sym_FOREACH] = ACTIONS(6264),
    [anon_sym_Foreach] = ACTIONS(6264),
    [anon_sym_while] = ACTIONS(6264),
    [anon_sym_WHILE] = ACTIONS(6264),
    [anon_sym_While] = ACTIONS(6264),
    [anon_sym_repeat] = ACTIONS(6264),
    [anon_sym_REPEAT] = ACTIONS(6264),
    [anon_sym_Repeat] = ACTIONS(6264),
    [anon_sym_exit] = ACTIONS(6264),
    [anon_sym_EXIT] = ACTIONS(6264),
    [anon_sym_Exit] = ACTIONS(6264),
    [anon_sym_continue] = ACTIONS(6264),
    [anon_sym_CONTINUE] = ACTIONS(6264),
    [anon_sym_Continue] = ACTIONS(6264),
    [anon_sym_break] = ACTIONS(6264),
    [anon_sym_BREAK] = ACTIONS(6264),
    [anon_sym_Break] = ACTIONS(6264),
    [anon_sym_with] = ACTIONS(6264),
    [anon_sym_WITH] = ACTIONS(6264),
    [anon_sym_With] = ACTIONS(6264),
    [sym_asserterror_keyword] = ACTIONS(6268),
    [sym_page_keyword] = ACTIONS(6264),
    [anon_sym_codeunit] = ACTIONS(6264),
    [anon_sym_CODEUNIT] = ACTIONS(6264),
    [anon_sym_Codeunit] = ACTIONS(6264),
    [anon_sym_CodeUnit] = ACTIONS(6264),
    [anon_sym_COdeunit] = ACTIONS(6264),
    [anon_sym_codeUnit] = ACTIONS(6264),
    [sym_report_keyword] = ACTIONS(6264),
    [sym_query_keyword] = ACTIONS(6264),
    [anon_sym_xmlport] = ACTIONS(6264),
    [anon_sym_XMLPORT] = ACTIONS(6264),
    [anon_sym_Xmlport] = ACTIONS(6264),
    [anon_sym_XMLport] = ACTIONS(6264),
    [anon_sym_XMLPort] = ACTIONS(6264),
    [anon_sym_XmlPort] = ACTIONS(6264),
    [anon_sym_enum] = ACTIONS(6264),
    [anon_sym_ENUM] = ACTIONS(6264),
    [anon_sym_Enum] = ACTIONS(6264),
    [anon_sym_eNUM] = ACTIONS(6264),
    [anon_sym_eNum] = ACTIONS(6264),
    [anon_sym_ENum] = ACTIONS(6264),
    [sym_quoted_identifier] = ACTIONS(6268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6268),
    [sym_verbatim_string] = ACTIONS(6268),
    [sym_integer] = ACTIONS(6264),
    [sym_continue_as_identifier] = ACTIONS(6268),
    [sym_preproc_open] = ACTIONS(6268),
    [sym_preproc_close] = ACTIONS(6268),
  },
  [STATE(2601)] = {
    [sym_identifier] = ACTIONS(6264),
    [anon_sym_SEMI] = ACTIONS(6270),
    [anon_sym_DASH] = ACTIONS(6268),
    [aux_sym_boolean_token1] = ACTIONS(6264),
    [aux_sym_boolean_token2] = ACTIONS(6264),
    [sym_decimal] = ACTIONS(6264),
    [anon_sym_LPAREN] = ACTIONS(6268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6264),
    [anon_sym_LBRACK] = ACTIONS(6268),
    [aux_sym_record_type_token1] = ACTIONS(6264),
    [aux_sym_basic_type_token21] = ACTIONS(6264),
    [aux_sym_basic_type_token22] = ACTIONS(6264),
    [aux_sym_basic_type_token48] = ACTIONS(6264),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6264),
    [anon_sym_POUNDif] = ACTIONS(6268),
    [anon_sym_POUNDIF] = ACTIONS(6268),
    [anon_sym_POUNDIf] = ACTIONS(6268),
    [anon_sym_not] = ACTIONS(6264),
    [anon_sym_NOT] = ACTIONS(6264),
    [anon_sym_Not] = ACTIONS(6264),
    [anon_sym_POUNDelif] = ACTIONS(6268),
    [anon_sym_POUNDELIF] = ACTIONS(6268),
    [anon_sym_POUNDElif] = ACTIONS(6268),
    [anon_sym_POUNDelse] = ACTIONS(6268),
    [anon_sym_POUNDELSE] = ACTIONS(6268),
    [anon_sym_POUNDElse] = ACTIONS(6268),
    [anon_sym_POUNDelse2] = ACTIONS(6268),
    [anon_sym_POUNDELSE2] = ACTIONS(6268),
    [anon_sym_POUNDElse2] = ACTIONS(6268),
    [anon_sym_POUNDendif] = ACTIONS(6268),
    [anon_sym_POUNDENDIF] = ACTIONS(6268),
    [anon_sym_POUNDEndif] = ACTIONS(6268),
    [anon_sym_POUNDendif2] = ACTIONS(6268),
    [anon_sym_POUNDENDIF2] = ACTIONS(6268),
    [anon_sym_POUNDEndif2] = ACTIONS(6268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6264),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6268),
    [sym_datetime_literal] = ACTIONS(6268),
    [sym_date_literal] = ACTIONS(6264),
    [sym_time_literal] = ACTIONS(6264),
    [sym_biginteger_literal] = ACTIONS(6268),
    [anon_sym_if] = ACTIONS(6264),
    [anon_sym_IF] = ACTIONS(6264),
    [anon_sym_If] = ACTIONS(6264),
    [anon_sym_else] = ACTIONS(6264),
    [anon_sym_ELSE] = ACTIONS(6264),
    [anon_sym_Else] = ACTIONS(6264),
    [anon_sym_case] = ACTIONS(6264),
    [anon_sym_CASE] = ACTIONS(6264),
    [anon_sym_Case] = ACTIONS(6264),
    [anon_sym_for] = ACTIONS(6264),
    [anon_sym_FOR] = ACTIONS(6264),
    [anon_sym_For] = ACTIONS(6264),
    [anon_sym_foreach] = ACTIONS(6264),
    [anon_sym_FOREACH] = ACTIONS(6264),
    [anon_sym_Foreach] = ACTIONS(6264),
    [anon_sym_while] = ACTIONS(6264),
    [anon_sym_WHILE] = ACTIONS(6264),
    [anon_sym_While] = ACTIONS(6264),
    [anon_sym_repeat] = ACTIONS(6264),
    [anon_sym_REPEAT] = ACTIONS(6264),
    [anon_sym_Repeat] = ACTIONS(6264),
    [anon_sym_exit] = ACTIONS(6264),
    [anon_sym_EXIT] = ACTIONS(6264),
    [anon_sym_Exit] = ACTIONS(6264),
    [anon_sym_continue] = ACTIONS(6264),
    [anon_sym_CONTINUE] = ACTIONS(6264),
    [anon_sym_Continue] = ACTIONS(6264),
    [anon_sym_break] = ACTIONS(6264),
    [anon_sym_BREAK] = ACTIONS(6264),
    [anon_sym_Break] = ACTIONS(6264),
    [anon_sym_with] = ACTIONS(6264),
    [anon_sym_WITH] = ACTIONS(6264),
    [anon_sym_With] = ACTIONS(6264),
    [sym_asserterror_keyword] = ACTIONS(6268),
    [sym_page_keyword] = ACTIONS(6264),
    [anon_sym_codeunit] = ACTIONS(6264),
    [anon_sym_CODEUNIT] = ACTIONS(6264),
    [anon_sym_Codeunit] = ACTIONS(6264),
    [anon_sym_CodeUnit] = ACTIONS(6264),
    [anon_sym_COdeunit] = ACTIONS(6264),
    [anon_sym_codeUnit] = ACTIONS(6264),
    [sym_report_keyword] = ACTIONS(6264),
    [sym_query_keyword] = ACTIONS(6264),
    [anon_sym_xmlport] = ACTIONS(6264),
    [anon_sym_XMLPORT] = ACTIONS(6264),
    [anon_sym_Xmlport] = ACTIONS(6264),
    [anon_sym_XMLport] = ACTIONS(6264),
    [anon_sym_XMLPort] = ACTIONS(6264),
    [anon_sym_XmlPort] = ACTIONS(6264),
    [anon_sym_enum] = ACTIONS(6264),
    [anon_sym_ENUM] = ACTIONS(6264),
    [anon_sym_Enum] = ACTIONS(6264),
    [anon_sym_eNUM] = ACTIONS(6264),
    [anon_sym_eNum] = ACTIONS(6264),
    [anon_sym_ENum] = ACTIONS(6264),
    [sym_quoted_identifier] = ACTIONS(6268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6268),
    [sym_verbatim_string] = ACTIONS(6268),
    [sym_integer] = ACTIONS(6264),
    [sym_continue_as_identifier] = ACTIONS(6268),
    [sym_preproc_open] = ACTIONS(6268),
    [sym_preproc_close] = ACTIONS(6268),
  },
  [STATE(2602)] = {
    [sym_identifier] = ACTIONS(6272),
    [anon_sym_SEMI] = ACTIONS(6274),
    [anon_sym_DASH] = ACTIONS(6274),
    [aux_sym_boolean_token1] = ACTIONS(6272),
    [aux_sym_boolean_token2] = ACTIONS(6272),
    [sym_decimal] = ACTIONS(6272),
    [anon_sym_LPAREN] = ACTIONS(6274),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6272),
    [anon_sym_LBRACK] = ACTIONS(6274),
    [aux_sym_record_type_token1] = ACTIONS(6272),
    [aux_sym_basic_type_token21] = ACTIONS(6272),
    [aux_sym_basic_type_token22] = ACTIONS(6272),
    [aux_sym_basic_type_token48] = ACTIONS(6272),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6272),
    [anon_sym_POUNDif] = ACTIONS(6274),
    [anon_sym_POUNDIF] = ACTIONS(6274),
    [anon_sym_POUNDIf] = ACTIONS(6274),
    [anon_sym_not] = ACTIONS(6272),
    [anon_sym_NOT] = ACTIONS(6272),
    [anon_sym_Not] = ACTIONS(6272),
    [anon_sym_POUNDelif] = ACTIONS(6274),
    [anon_sym_POUNDELIF] = ACTIONS(6274),
    [anon_sym_POUNDElif] = ACTIONS(6274),
    [anon_sym_POUNDelse] = ACTIONS(6274),
    [anon_sym_POUNDELSE] = ACTIONS(6274),
    [anon_sym_POUNDElse] = ACTIONS(6274),
    [anon_sym_POUNDelse2] = ACTIONS(6274),
    [anon_sym_POUNDELSE2] = ACTIONS(6274),
    [anon_sym_POUNDElse2] = ACTIONS(6274),
    [anon_sym_POUNDendif] = ACTIONS(6274),
    [anon_sym_POUNDENDIF] = ACTIONS(6274),
    [anon_sym_POUNDEndif] = ACTIONS(6274),
    [anon_sym_POUNDendif2] = ACTIONS(6274),
    [anon_sym_POUNDENDIF2] = ACTIONS(6274),
    [anon_sym_POUNDEndif2] = ACTIONS(6274),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6272),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6272),
    [anon_sym_PLUS] = ACTIONS(6274),
    [sym_datetime_literal] = ACTIONS(6274),
    [sym_date_literal] = ACTIONS(6272),
    [sym_time_literal] = ACTIONS(6272),
    [sym_biginteger_literal] = ACTIONS(6274),
    [anon_sym_if] = ACTIONS(6272),
    [anon_sym_IF] = ACTIONS(6272),
    [anon_sym_If] = ACTIONS(6272),
    [anon_sym_else] = ACTIONS(6272),
    [anon_sym_ELSE] = ACTIONS(6272),
    [anon_sym_Else] = ACTIONS(6272),
    [anon_sym_case] = ACTIONS(6272),
    [anon_sym_CASE] = ACTIONS(6272),
    [anon_sym_Case] = ACTIONS(6272),
    [anon_sym_for] = ACTIONS(6272),
    [anon_sym_FOR] = ACTIONS(6272),
    [anon_sym_For] = ACTIONS(6272),
    [anon_sym_foreach] = ACTIONS(6272),
    [anon_sym_FOREACH] = ACTIONS(6272),
    [anon_sym_Foreach] = ACTIONS(6272),
    [anon_sym_while] = ACTIONS(6272),
    [anon_sym_WHILE] = ACTIONS(6272),
    [anon_sym_While] = ACTIONS(6272),
    [anon_sym_repeat] = ACTIONS(6272),
    [anon_sym_REPEAT] = ACTIONS(6272),
    [anon_sym_Repeat] = ACTIONS(6272),
    [anon_sym_exit] = ACTIONS(6272),
    [anon_sym_EXIT] = ACTIONS(6272),
    [anon_sym_Exit] = ACTIONS(6272),
    [anon_sym_continue] = ACTIONS(6272),
    [anon_sym_CONTINUE] = ACTIONS(6272),
    [anon_sym_Continue] = ACTIONS(6272),
    [anon_sym_break] = ACTIONS(6272),
    [anon_sym_BREAK] = ACTIONS(6272),
    [anon_sym_Break] = ACTIONS(6272),
    [anon_sym_with] = ACTIONS(6272),
    [anon_sym_WITH] = ACTIONS(6272),
    [anon_sym_With] = ACTIONS(6272),
    [sym_asserterror_keyword] = ACTIONS(6274),
    [sym_page_keyword] = ACTIONS(6272),
    [anon_sym_codeunit] = ACTIONS(6272),
    [anon_sym_CODEUNIT] = ACTIONS(6272),
    [anon_sym_Codeunit] = ACTIONS(6272),
    [anon_sym_CodeUnit] = ACTIONS(6272),
    [anon_sym_COdeunit] = ACTIONS(6272),
    [anon_sym_codeUnit] = ACTIONS(6272),
    [sym_report_keyword] = ACTIONS(6272),
    [sym_query_keyword] = ACTIONS(6272),
    [anon_sym_xmlport] = ACTIONS(6272),
    [anon_sym_XMLPORT] = ACTIONS(6272),
    [anon_sym_Xmlport] = ACTIONS(6272),
    [anon_sym_XMLport] = ACTIONS(6272),
    [anon_sym_XMLPort] = ACTIONS(6272),
    [anon_sym_XmlPort] = ACTIONS(6272),
    [anon_sym_enum] = ACTIONS(6272),
    [anon_sym_ENUM] = ACTIONS(6272),
    [anon_sym_Enum] = ACTIONS(6272),
    [anon_sym_eNUM] = ACTIONS(6272),
    [anon_sym_eNum] = ACTIONS(6272),
    [anon_sym_ENum] = ACTIONS(6272),
    [sym_quoted_identifier] = ACTIONS(6274),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6274),
    [sym_verbatim_string] = ACTIONS(6274),
    [sym_integer] = ACTIONS(6272),
    [sym_continue_as_identifier] = ACTIONS(6274),
    [sym_preproc_open] = ACTIONS(6274),
    [sym_preproc_close] = ACTIONS(6274),
  },
  [STATE(2603)] = {
    [sym_identifier] = ACTIONS(6276),
    [anon_sym_SEMI] = ACTIONS(6278),
    [anon_sym_DASH] = ACTIONS(6278),
    [aux_sym_boolean_token1] = ACTIONS(6276),
    [aux_sym_boolean_token2] = ACTIONS(6276),
    [sym_decimal] = ACTIONS(6276),
    [anon_sym_LPAREN] = ACTIONS(6278),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6276),
    [anon_sym_LBRACK] = ACTIONS(6278),
    [aux_sym_record_type_token1] = ACTIONS(6276),
    [aux_sym_basic_type_token21] = ACTIONS(6276),
    [aux_sym_basic_type_token22] = ACTIONS(6276),
    [aux_sym_basic_type_token48] = ACTIONS(6276),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6276),
    [anon_sym_POUNDif] = ACTIONS(6278),
    [anon_sym_POUNDIF] = ACTIONS(6278),
    [anon_sym_POUNDIf] = ACTIONS(6278),
    [anon_sym_not] = ACTIONS(6276),
    [anon_sym_NOT] = ACTIONS(6276),
    [anon_sym_Not] = ACTIONS(6276),
    [anon_sym_POUNDelif] = ACTIONS(6278),
    [anon_sym_POUNDELIF] = ACTIONS(6278),
    [anon_sym_POUNDElif] = ACTIONS(6278),
    [anon_sym_POUNDelse] = ACTIONS(6278),
    [anon_sym_POUNDELSE] = ACTIONS(6278),
    [anon_sym_POUNDElse] = ACTIONS(6278),
    [anon_sym_POUNDelse2] = ACTIONS(6278),
    [anon_sym_POUNDELSE2] = ACTIONS(6278),
    [anon_sym_POUNDElse2] = ACTIONS(6278),
    [anon_sym_POUNDendif] = ACTIONS(6278),
    [anon_sym_POUNDENDIF] = ACTIONS(6278),
    [anon_sym_POUNDEndif] = ACTIONS(6278),
    [anon_sym_POUNDendif2] = ACTIONS(6278),
    [anon_sym_POUNDENDIF2] = ACTIONS(6278),
    [anon_sym_POUNDEndif2] = ACTIONS(6278),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6276),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6276),
    [anon_sym_PLUS] = ACTIONS(6278),
    [sym_datetime_literal] = ACTIONS(6278),
    [sym_date_literal] = ACTIONS(6276),
    [sym_time_literal] = ACTIONS(6276),
    [sym_biginteger_literal] = ACTIONS(6278),
    [anon_sym_if] = ACTIONS(6276),
    [anon_sym_IF] = ACTIONS(6276),
    [anon_sym_If] = ACTIONS(6276),
    [anon_sym_else] = ACTIONS(6276),
    [anon_sym_ELSE] = ACTIONS(6276),
    [anon_sym_Else] = ACTIONS(6276),
    [anon_sym_case] = ACTIONS(6276),
    [anon_sym_CASE] = ACTIONS(6276),
    [anon_sym_Case] = ACTIONS(6276),
    [anon_sym_for] = ACTIONS(6276),
    [anon_sym_FOR] = ACTIONS(6276),
    [anon_sym_For] = ACTIONS(6276),
    [anon_sym_foreach] = ACTIONS(6276),
    [anon_sym_FOREACH] = ACTIONS(6276),
    [anon_sym_Foreach] = ACTIONS(6276),
    [anon_sym_while] = ACTIONS(6276),
    [anon_sym_WHILE] = ACTIONS(6276),
    [anon_sym_While] = ACTIONS(6276),
    [anon_sym_repeat] = ACTIONS(6276),
    [anon_sym_REPEAT] = ACTIONS(6276),
    [anon_sym_Repeat] = ACTIONS(6276),
    [anon_sym_exit] = ACTIONS(6276),
    [anon_sym_EXIT] = ACTIONS(6276),
    [anon_sym_Exit] = ACTIONS(6276),
    [anon_sym_continue] = ACTIONS(6276),
    [anon_sym_CONTINUE] = ACTIONS(6276),
    [anon_sym_Continue] = ACTIONS(6276),
    [anon_sym_break] = ACTIONS(6276),
    [anon_sym_BREAK] = ACTIONS(6276),
    [anon_sym_Break] = ACTIONS(6276),
    [anon_sym_with] = ACTIONS(6276),
    [anon_sym_WITH] = ACTIONS(6276),
    [anon_sym_With] = ACTIONS(6276),
    [sym_asserterror_keyword] = ACTIONS(6278),
    [sym_page_keyword] = ACTIONS(6276),
    [anon_sym_codeunit] = ACTIONS(6276),
    [anon_sym_CODEUNIT] = ACTIONS(6276),
    [anon_sym_Codeunit] = ACTIONS(6276),
    [anon_sym_CodeUnit] = ACTIONS(6276),
    [anon_sym_COdeunit] = ACTIONS(6276),
    [anon_sym_codeUnit] = ACTIONS(6276),
    [sym_report_keyword] = ACTIONS(6276),
    [sym_query_keyword] = ACTIONS(6276),
    [anon_sym_xmlport] = ACTIONS(6276),
    [anon_sym_XMLPORT] = ACTIONS(6276),
    [anon_sym_Xmlport] = ACTIONS(6276),
    [anon_sym_XMLport] = ACTIONS(6276),
    [anon_sym_XMLPort] = ACTIONS(6276),
    [anon_sym_XmlPort] = ACTIONS(6276),
    [anon_sym_enum] = ACTIONS(6276),
    [anon_sym_ENUM] = ACTIONS(6276),
    [anon_sym_Enum] = ACTIONS(6276),
    [anon_sym_eNUM] = ACTIONS(6276),
    [anon_sym_eNum] = ACTIONS(6276),
    [anon_sym_ENum] = ACTIONS(6276),
    [sym_quoted_identifier] = ACTIONS(6278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6278),
    [sym_verbatim_string] = ACTIONS(6278),
    [sym_integer] = ACTIONS(6276),
    [sym_continue_as_identifier] = ACTIONS(6278),
    [sym_preproc_open] = ACTIONS(6278),
    [sym_preproc_close] = ACTIONS(6278),
  },
  [STATE(2604)] = {
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_SEMI] = ACTIONS(6282),
    [anon_sym_DASH] = ACTIONS(6282),
    [aux_sym_boolean_token1] = ACTIONS(6280),
    [aux_sym_boolean_token2] = ACTIONS(6280),
    [sym_decimal] = ACTIONS(6280),
    [anon_sym_LPAREN] = ACTIONS(6282),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6280),
    [anon_sym_LBRACK] = ACTIONS(6282),
    [aux_sym_record_type_token1] = ACTIONS(6280),
    [aux_sym_basic_type_token21] = ACTIONS(6280),
    [aux_sym_basic_type_token22] = ACTIONS(6280),
    [aux_sym_basic_type_token48] = ACTIONS(6280),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6280),
    [anon_sym_POUNDif] = ACTIONS(6282),
    [anon_sym_POUNDIF] = ACTIONS(6282),
    [anon_sym_POUNDIf] = ACTIONS(6282),
    [anon_sym_not] = ACTIONS(6280),
    [anon_sym_NOT] = ACTIONS(6280),
    [anon_sym_Not] = ACTIONS(6280),
    [anon_sym_POUNDelif] = ACTIONS(6282),
    [anon_sym_POUNDELIF] = ACTIONS(6282),
    [anon_sym_POUNDElif] = ACTIONS(6282),
    [anon_sym_POUNDelse] = ACTIONS(6282),
    [anon_sym_POUNDELSE] = ACTIONS(6282),
    [anon_sym_POUNDElse] = ACTIONS(6282),
    [anon_sym_POUNDelse2] = ACTIONS(6282),
    [anon_sym_POUNDELSE2] = ACTIONS(6282),
    [anon_sym_POUNDElse2] = ACTIONS(6282),
    [anon_sym_POUNDendif] = ACTIONS(6282),
    [anon_sym_POUNDENDIF] = ACTIONS(6282),
    [anon_sym_POUNDEndif] = ACTIONS(6282),
    [anon_sym_POUNDendif2] = ACTIONS(6282),
    [anon_sym_POUNDENDIF2] = ACTIONS(6282),
    [anon_sym_POUNDEndif2] = ACTIONS(6282),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6280),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6280),
    [anon_sym_PLUS] = ACTIONS(6282),
    [sym_datetime_literal] = ACTIONS(6282),
    [sym_date_literal] = ACTIONS(6280),
    [sym_time_literal] = ACTIONS(6280),
    [sym_biginteger_literal] = ACTIONS(6282),
    [anon_sym_if] = ACTIONS(6280),
    [anon_sym_IF] = ACTIONS(6280),
    [anon_sym_If] = ACTIONS(6280),
    [anon_sym_else] = ACTIONS(6280),
    [anon_sym_ELSE] = ACTIONS(6280),
    [anon_sym_Else] = ACTIONS(6280),
    [anon_sym_case] = ACTIONS(6280),
    [anon_sym_CASE] = ACTIONS(6280),
    [anon_sym_Case] = ACTIONS(6280),
    [anon_sym_for] = ACTIONS(6280),
    [anon_sym_FOR] = ACTIONS(6280),
    [anon_sym_For] = ACTIONS(6280),
    [anon_sym_foreach] = ACTIONS(6280),
    [anon_sym_FOREACH] = ACTIONS(6280),
    [anon_sym_Foreach] = ACTIONS(6280),
    [anon_sym_while] = ACTIONS(6280),
    [anon_sym_WHILE] = ACTIONS(6280),
    [anon_sym_While] = ACTIONS(6280),
    [anon_sym_repeat] = ACTIONS(6280),
    [anon_sym_REPEAT] = ACTIONS(6280),
    [anon_sym_Repeat] = ACTIONS(6280),
    [anon_sym_exit] = ACTIONS(6280),
    [anon_sym_EXIT] = ACTIONS(6280),
    [anon_sym_Exit] = ACTIONS(6280),
    [anon_sym_continue] = ACTIONS(6280),
    [anon_sym_CONTINUE] = ACTIONS(6280),
    [anon_sym_Continue] = ACTIONS(6280),
    [anon_sym_break] = ACTIONS(6280),
    [anon_sym_BREAK] = ACTIONS(6280),
    [anon_sym_Break] = ACTIONS(6280),
    [anon_sym_with] = ACTIONS(6280),
    [anon_sym_WITH] = ACTIONS(6280),
    [anon_sym_With] = ACTIONS(6280),
    [sym_asserterror_keyword] = ACTIONS(6282),
    [sym_page_keyword] = ACTIONS(6280),
    [anon_sym_codeunit] = ACTIONS(6280),
    [anon_sym_CODEUNIT] = ACTIONS(6280),
    [anon_sym_Codeunit] = ACTIONS(6280),
    [anon_sym_CodeUnit] = ACTIONS(6280),
    [anon_sym_COdeunit] = ACTIONS(6280),
    [anon_sym_codeUnit] = ACTIONS(6280),
    [sym_report_keyword] = ACTIONS(6280),
    [sym_query_keyword] = ACTIONS(6280),
    [anon_sym_xmlport] = ACTIONS(6280),
    [anon_sym_XMLPORT] = ACTIONS(6280),
    [anon_sym_Xmlport] = ACTIONS(6280),
    [anon_sym_XMLport] = ACTIONS(6280),
    [anon_sym_XMLPort] = ACTIONS(6280),
    [anon_sym_XmlPort] = ACTIONS(6280),
    [anon_sym_enum] = ACTIONS(6280),
    [anon_sym_ENUM] = ACTIONS(6280),
    [anon_sym_Enum] = ACTIONS(6280),
    [anon_sym_eNUM] = ACTIONS(6280),
    [anon_sym_eNum] = ACTIONS(6280),
    [anon_sym_ENum] = ACTIONS(6280),
    [sym_quoted_identifier] = ACTIONS(6282),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6282),
    [sym_verbatim_string] = ACTIONS(6282),
    [sym_integer] = ACTIONS(6280),
    [sym_continue_as_identifier] = ACTIONS(6282),
    [sym_preproc_open] = ACTIONS(6282),
    [sym_preproc_close] = ACTIONS(6282),
  },
  [STATE(2605)] = {
    [sym_else_keyword] = STATE(113),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelif] = ACTIONS(5487),
    [anon_sym_POUNDELIF] = ACTIONS(5487),
    [anon_sym_POUNDElif] = ACTIONS(5487),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [anon_sym_POUNDendif] = ACTIONS(5487),
    [anon_sym_POUNDENDIF] = ACTIONS(5487),
    [anon_sym_POUNDEndif] = ACTIONS(5487),
    [anon_sym_POUNDendif2] = ACTIONS(5487),
    [anon_sym_POUNDENDIF2] = ACTIONS(5487),
    [anon_sym_POUNDEndif2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_preproc_close] = ACTIONS(5487),
  },
  [STATE(2606)] = {
    [sym_else_keyword] = STATE(116),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelif] = ACTIONS(5455),
    [anon_sym_POUNDELIF] = ACTIONS(5455),
    [anon_sym_POUNDElif] = ACTIONS(5455),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [anon_sym_POUNDendif] = ACTIONS(5455),
    [anon_sym_POUNDENDIF] = ACTIONS(5455),
    [anon_sym_POUNDEndif] = ACTIONS(5455),
    [anon_sym_POUNDendif2] = ACTIONS(5455),
    [anon_sym_POUNDENDIF2] = ACTIONS(5455),
    [anon_sym_POUNDEndif2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5467),
    [anon_sym_ELSE] = ACTIONS(5467),
    [anon_sym_Else] = ACTIONS(5467),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_preproc_close] = ACTIONS(5455),
  },
  [STATE(2607)] = {
    [sym_identifier] = ACTIONS(6284),
    [anon_sym_SEMI] = ACTIONS(6286),
    [anon_sym_DASH] = ACTIONS(6286),
    [aux_sym_boolean_token1] = ACTIONS(6284),
    [aux_sym_boolean_token2] = ACTIONS(6284),
    [sym_decimal] = ACTIONS(6284),
    [anon_sym_LPAREN] = ACTIONS(6286),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6284),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [aux_sym_record_type_token1] = ACTIONS(6284),
    [aux_sym_basic_type_token21] = ACTIONS(6284),
    [aux_sym_basic_type_token22] = ACTIONS(6284),
    [aux_sym_basic_type_token48] = ACTIONS(6284),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6284),
    [anon_sym_POUNDif] = ACTIONS(6286),
    [anon_sym_POUNDIF] = ACTIONS(6286),
    [anon_sym_POUNDIf] = ACTIONS(6286),
    [anon_sym_not] = ACTIONS(6284),
    [anon_sym_NOT] = ACTIONS(6284),
    [anon_sym_Not] = ACTIONS(6284),
    [anon_sym_POUNDelif] = ACTIONS(6286),
    [anon_sym_POUNDELIF] = ACTIONS(6286),
    [anon_sym_POUNDElif] = ACTIONS(6286),
    [anon_sym_POUNDelse] = ACTIONS(6286),
    [anon_sym_POUNDELSE] = ACTIONS(6286),
    [anon_sym_POUNDElse] = ACTIONS(6286),
    [anon_sym_POUNDelse2] = ACTIONS(6286),
    [anon_sym_POUNDELSE2] = ACTIONS(6286),
    [anon_sym_POUNDElse2] = ACTIONS(6286),
    [anon_sym_POUNDendif] = ACTIONS(6286),
    [anon_sym_POUNDENDIF] = ACTIONS(6286),
    [anon_sym_POUNDEndif] = ACTIONS(6286),
    [anon_sym_POUNDendif2] = ACTIONS(6286),
    [anon_sym_POUNDENDIF2] = ACTIONS(6286),
    [anon_sym_POUNDEndif2] = ACTIONS(6286),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6284),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6284),
    [anon_sym_PLUS] = ACTIONS(6286),
    [sym_datetime_literal] = ACTIONS(6286),
    [sym_date_literal] = ACTIONS(6284),
    [sym_time_literal] = ACTIONS(6284),
    [sym_biginteger_literal] = ACTIONS(6286),
    [anon_sym_if] = ACTIONS(6284),
    [anon_sym_IF] = ACTIONS(6284),
    [anon_sym_If] = ACTIONS(6284),
    [anon_sym_else] = ACTIONS(6284),
    [anon_sym_ELSE] = ACTIONS(6284),
    [anon_sym_Else] = ACTIONS(6284),
    [anon_sym_case] = ACTIONS(6284),
    [anon_sym_CASE] = ACTIONS(6284),
    [anon_sym_Case] = ACTIONS(6284),
    [anon_sym_for] = ACTIONS(6284),
    [anon_sym_FOR] = ACTIONS(6284),
    [anon_sym_For] = ACTIONS(6284),
    [anon_sym_foreach] = ACTIONS(6284),
    [anon_sym_FOREACH] = ACTIONS(6284),
    [anon_sym_Foreach] = ACTIONS(6284),
    [anon_sym_while] = ACTIONS(6284),
    [anon_sym_WHILE] = ACTIONS(6284),
    [anon_sym_While] = ACTIONS(6284),
    [anon_sym_repeat] = ACTIONS(6284),
    [anon_sym_REPEAT] = ACTIONS(6284),
    [anon_sym_Repeat] = ACTIONS(6284),
    [anon_sym_exit] = ACTIONS(6284),
    [anon_sym_EXIT] = ACTIONS(6284),
    [anon_sym_Exit] = ACTIONS(6284),
    [anon_sym_continue] = ACTIONS(6284),
    [anon_sym_CONTINUE] = ACTIONS(6284),
    [anon_sym_Continue] = ACTIONS(6284),
    [anon_sym_break] = ACTIONS(6284),
    [anon_sym_BREAK] = ACTIONS(6284),
    [anon_sym_Break] = ACTIONS(6284),
    [anon_sym_with] = ACTIONS(6284),
    [anon_sym_WITH] = ACTIONS(6284),
    [anon_sym_With] = ACTIONS(6284),
    [sym_asserterror_keyword] = ACTIONS(6286),
    [sym_page_keyword] = ACTIONS(6284),
    [anon_sym_codeunit] = ACTIONS(6284),
    [anon_sym_CODEUNIT] = ACTIONS(6284),
    [anon_sym_Codeunit] = ACTIONS(6284),
    [anon_sym_CodeUnit] = ACTIONS(6284),
    [anon_sym_COdeunit] = ACTIONS(6284),
    [anon_sym_codeUnit] = ACTIONS(6284),
    [sym_report_keyword] = ACTIONS(6284),
    [sym_query_keyword] = ACTIONS(6284),
    [anon_sym_xmlport] = ACTIONS(6284),
    [anon_sym_XMLPORT] = ACTIONS(6284),
    [anon_sym_Xmlport] = ACTIONS(6284),
    [anon_sym_XMLport] = ACTIONS(6284),
    [anon_sym_XMLPort] = ACTIONS(6284),
    [anon_sym_XmlPort] = ACTIONS(6284),
    [anon_sym_enum] = ACTIONS(6284),
    [anon_sym_ENUM] = ACTIONS(6284),
    [anon_sym_Enum] = ACTIONS(6284),
    [anon_sym_eNUM] = ACTIONS(6284),
    [anon_sym_eNum] = ACTIONS(6284),
    [anon_sym_ENum] = ACTIONS(6284),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6286),
    [sym_verbatim_string] = ACTIONS(6286),
    [sym_integer] = ACTIONS(6284),
    [sym_continue_as_identifier] = ACTIONS(6286),
    [sym_preproc_open] = ACTIONS(6286),
    [sym_preproc_close] = ACTIONS(6286),
  },
  [STATE(2608)] = {
    [sym_identifier] = ACTIONS(6288),
    [anon_sym_SEMI] = ACTIONS(6290),
    [anon_sym_DASH] = ACTIONS(6290),
    [aux_sym_boolean_token1] = ACTIONS(6288),
    [aux_sym_boolean_token2] = ACTIONS(6288),
    [sym_decimal] = ACTIONS(6288),
    [anon_sym_LPAREN] = ACTIONS(6290),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6288),
    [anon_sym_LBRACK] = ACTIONS(6290),
    [aux_sym_record_type_token1] = ACTIONS(6288),
    [aux_sym_basic_type_token21] = ACTIONS(6288),
    [aux_sym_basic_type_token22] = ACTIONS(6288),
    [aux_sym_basic_type_token48] = ACTIONS(6288),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6288),
    [anon_sym_POUNDif] = ACTIONS(6290),
    [anon_sym_POUNDIF] = ACTIONS(6290),
    [anon_sym_POUNDIf] = ACTIONS(6290),
    [anon_sym_not] = ACTIONS(6288),
    [anon_sym_NOT] = ACTIONS(6288),
    [anon_sym_Not] = ACTIONS(6288),
    [anon_sym_POUNDelif] = ACTIONS(6290),
    [anon_sym_POUNDELIF] = ACTIONS(6290),
    [anon_sym_POUNDElif] = ACTIONS(6290),
    [anon_sym_POUNDelse] = ACTIONS(6290),
    [anon_sym_POUNDELSE] = ACTIONS(6290),
    [anon_sym_POUNDElse] = ACTIONS(6290),
    [anon_sym_POUNDelse2] = ACTIONS(6290),
    [anon_sym_POUNDELSE2] = ACTIONS(6290),
    [anon_sym_POUNDElse2] = ACTIONS(6290),
    [anon_sym_POUNDendif] = ACTIONS(6290),
    [anon_sym_POUNDENDIF] = ACTIONS(6290),
    [anon_sym_POUNDEndif] = ACTIONS(6290),
    [anon_sym_POUNDendif2] = ACTIONS(6290),
    [anon_sym_POUNDENDIF2] = ACTIONS(6290),
    [anon_sym_POUNDEndif2] = ACTIONS(6290),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6288),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6288),
    [anon_sym_PLUS] = ACTIONS(6290),
    [sym_datetime_literal] = ACTIONS(6290),
    [sym_date_literal] = ACTIONS(6288),
    [sym_time_literal] = ACTIONS(6288),
    [sym_biginteger_literal] = ACTIONS(6290),
    [anon_sym_if] = ACTIONS(6288),
    [anon_sym_IF] = ACTIONS(6288),
    [anon_sym_If] = ACTIONS(6288),
    [anon_sym_else] = ACTIONS(6288),
    [anon_sym_ELSE] = ACTIONS(6288),
    [anon_sym_Else] = ACTIONS(6288),
    [anon_sym_case] = ACTIONS(6288),
    [anon_sym_CASE] = ACTIONS(6288),
    [anon_sym_Case] = ACTIONS(6288),
    [anon_sym_for] = ACTIONS(6288),
    [anon_sym_FOR] = ACTIONS(6288),
    [anon_sym_For] = ACTIONS(6288),
    [anon_sym_foreach] = ACTIONS(6288),
    [anon_sym_FOREACH] = ACTIONS(6288),
    [anon_sym_Foreach] = ACTIONS(6288),
    [anon_sym_while] = ACTIONS(6288),
    [anon_sym_WHILE] = ACTIONS(6288),
    [anon_sym_While] = ACTIONS(6288),
    [anon_sym_repeat] = ACTIONS(6288),
    [anon_sym_REPEAT] = ACTIONS(6288),
    [anon_sym_Repeat] = ACTIONS(6288),
    [anon_sym_exit] = ACTIONS(6288),
    [anon_sym_EXIT] = ACTIONS(6288),
    [anon_sym_Exit] = ACTIONS(6288),
    [anon_sym_continue] = ACTIONS(6288),
    [anon_sym_CONTINUE] = ACTIONS(6288),
    [anon_sym_Continue] = ACTIONS(6288),
    [anon_sym_break] = ACTIONS(6288),
    [anon_sym_BREAK] = ACTIONS(6288),
    [anon_sym_Break] = ACTIONS(6288),
    [anon_sym_with] = ACTIONS(6288),
    [anon_sym_WITH] = ACTIONS(6288),
    [anon_sym_With] = ACTIONS(6288),
    [sym_asserterror_keyword] = ACTIONS(6290),
    [sym_page_keyword] = ACTIONS(6288),
    [anon_sym_codeunit] = ACTIONS(6288),
    [anon_sym_CODEUNIT] = ACTIONS(6288),
    [anon_sym_Codeunit] = ACTIONS(6288),
    [anon_sym_CodeUnit] = ACTIONS(6288),
    [anon_sym_COdeunit] = ACTIONS(6288),
    [anon_sym_codeUnit] = ACTIONS(6288),
    [sym_report_keyword] = ACTIONS(6288),
    [sym_query_keyword] = ACTIONS(6288),
    [anon_sym_xmlport] = ACTIONS(6288),
    [anon_sym_XMLPORT] = ACTIONS(6288),
    [anon_sym_Xmlport] = ACTIONS(6288),
    [anon_sym_XMLport] = ACTIONS(6288),
    [anon_sym_XMLPort] = ACTIONS(6288),
    [anon_sym_XmlPort] = ACTIONS(6288),
    [anon_sym_enum] = ACTIONS(6288),
    [anon_sym_ENUM] = ACTIONS(6288),
    [anon_sym_Enum] = ACTIONS(6288),
    [anon_sym_eNUM] = ACTIONS(6288),
    [anon_sym_eNum] = ACTIONS(6288),
    [anon_sym_ENum] = ACTIONS(6288),
    [sym_quoted_identifier] = ACTIONS(6290),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6290),
    [sym_verbatim_string] = ACTIONS(6290),
    [sym_integer] = ACTIONS(6288),
    [sym_continue_as_identifier] = ACTIONS(6290),
    [sym_preproc_open] = ACTIONS(6290),
    [sym_preproc_close] = ACTIONS(6290),
  },
  [STATE(2609)] = {
    [anon_sym_POUNDif] = ACTIONS(5360),
    [anon_sym_POUNDIF] = ACTIONS(5360),
    [anon_sym_POUNDIf] = ACTIONS(5360),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5693),
    [anon_sym_PIPE_PIPE] = ACTIONS(5693),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5695),
    [anon_sym_AMP_AMP] = ACTIONS(5695),
    [anon_sym_POUNDelif] = ACTIONS(5360),
    [anon_sym_POUNDELIF] = ACTIONS(5360),
    [anon_sym_POUNDElif] = ACTIONS(5360),
    [anon_sym_POUNDelse] = ACTIONS(5360),
    [anon_sym_POUNDELSE] = ACTIONS(5360),
    [anon_sym_POUNDElse] = ACTIONS(5360),
    [anon_sym_POUNDelse2] = ACTIONS(5360),
    [anon_sym_POUNDELSE2] = ACTIONS(5360),
    [anon_sym_POUNDElse2] = ACTIONS(5360),
    [anon_sym_POUNDendif] = ACTIONS(5360),
    [anon_sym_POUNDENDIF] = ACTIONS(5360),
    [anon_sym_POUNDEndif] = ACTIONS(5360),
    [anon_sym_POUNDendif2] = ACTIONS(5360),
    [anon_sym_POUNDENDIF2] = ACTIONS(5360),
    [anon_sym_POUNDEndif2] = ACTIONS(5360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5358),
    [anon_sym_tableextension] = ACTIONS(5360),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5360),
    [anon_sym_Tableextension] = ACTIONS(5360),
    [anon_sym_TableExtension] = ACTIONS(5360),
    [anon_sym_tableExtension] = ACTIONS(5360),
    [sym_page_keyword] = ACTIONS(5358),
    [anon_sym_pageextension] = ACTIONS(5360),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5360),
    [anon_sym_Pageextension] = ACTIONS(5360),
    [anon_sym_PageExtension] = ACTIONS(5360),
    [anon_sym_pageExtension] = ACTIONS(5360),
    [anon_sym_codeunit] = ACTIONS(5360),
    [anon_sym_CODEUNIT] = ACTIONS(5360),
    [anon_sym_Codeunit] = ACTIONS(5360),
    [anon_sym_CodeUnit] = ACTIONS(5360),
    [anon_sym_COdeunit] = ACTIONS(5360),
    [anon_sym_codeUnit] = ACTIONS(5360),
    [sym_report_keyword] = ACTIONS(5358),
    [anon_sym_reportextension] = ACTIONS(5360),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5360),
    [anon_sym_Reportextension] = ACTIONS(5360),
    [anon_sym_ReportExtension] = ACTIONS(5360),
    [anon_sym_reportExtension] = ACTIONS(5360),
    [sym_query_keyword] = ACTIONS(5360),
    [anon_sym_xmlport] = ACTIONS(5360),
    [anon_sym_XMLPORT] = ACTIONS(5360),
    [anon_sym_Xmlport] = ACTIONS(5360),
    [anon_sym_XMLport] = ACTIONS(5360),
    [anon_sym_XMLPort] = ACTIONS(5360),
    [anon_sym_XmlPort] = ACTIONS(5360),
    [anon_sym_enum] = ACTIONS(5358),
    [anon_sym_ENUM] = ACTIONS(5358),
    [anon_sym_Enum] = ACTIONS(5358),
    [anon_sym_eNUM] = ACTIONS(5360),
    [anon_sym_eNum] = ACTIONS(5360),
    [anon_sym_ENum] = ACTIONS(5360),
    [anon_sym_enumextension] = ACTIONS(5360),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5360),
    [anon_sym_Enumextension] = ACTIONS(5360),
    [anon_sym_EnumExtension] = ACTIONS(5360),
    [anon_sym_enumExtension] = ACTIONS(5360),
    [sym_interface_keyword] = ACTIONS(5360),
    [anon_sym_controladdin] = ACTIONS(5360),
    [anon_sym_CONTROLADDIN] = ACTIONS(5360),
    [anon_sym_Controladdin] = ACTIONS(5360),
    [anon_sym_ControlAddIn] = ACTIONS(5360),
    [anon_sym_ControlAddin] = ACTIONS(5360),
    [anon_sym_controlAddIn] = ACTIONS(5360),
    [anon_sym_controlAddin] = ACTIONS(5360),
    [anon_sym_dotnet] = ACTIONS(5360),
    [anon_sym_DOTNET] = ACTIONS(5360),
    [anon_sym_Dotnet] = ACTIONS(5360),
    [anon_sym_DotNet] = ACTIONS(5360),
    [anon_sym_dotNet] = ACTIONS(5360),
    [sym_profile_keyword] = ACTIONS(5358),
    [anon_sym_profileextension] = ACTIONS(5360),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5360),
    [anon_sym_Profileextension] = ACTIONS(5360),
    [anon_sym_ProfileExtension] = ACTIONS(5360),
    [anon_sym_profileExtension] = ACTIONS(5360),
    [anon_sym_permissionset] = ACTIONS(5358),
    [anon_sym_PERMISSIONSET] = ACTIONS(5358),
    [anon_sym_Permissionset] = ACTIONS(5358),
    [anon_sym_PermissionSet] = ACTIONS(5358),
    [anon_sym_permissionSet] = ACTIONS(5358),
    [anon_sym_permissionsetextension] = ACTIONS(5360),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5360),
    [anon_sym_Permissionsetextension] = ACTIONS(5360),
    [anon_sym_PermissionSetExtension] = ACTIONS(5360),
    [anon_sym_permissionSetExtension] = ACTIONS(5360),
    [sym_entitlement_keyword] = ACTIONS(5360),
    [anon_sym_pagecustomization] = ACTIONS(5360),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5360),
    [anon_sym_Pagecustomization] = ACTIONS(5360),
    [anon_sym_PageCustomization] = ACTIONS(5360),
    [anon_sym_pageCustomization] = ACTIONS(5360),
    [sym_namespace_keyword] = ACTIONS(5360),
    [sym_using_keyword] = ACTIONS(5360),
    [sym_fieldgroup_keyword] = ACTIONS(5360),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5360),
    [sym_preproc_close] = ACTIONS(5360),
  },
  [STATE(2610)] = {
    [sym_identifier] = ACTIONS(6292),
    [anon_sym_SEMI] = ACTIONS(6294),
    [anon_sym_DASH] = ACTIONS(6296),
    [aux_sym_boolean_token1] = ACTIONS(6292),
    [aux_sym_boolean_token2] = ACTIONS(6292),
    [sym_decimal] = ACTIONS(6292),
    [anon_sym_LPAREN] = ACTIONS(6296),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6292),
    [anon_sym_LBRACK] = ACTIONS(6296),
    [aux_sym_record_type_token1] = ACTIONS(6292),
    [aux_sym_basic_type_token21] = ACTIONS(6292),
    [aux_sym_basic_type_token22] = ACTIONS(6292),
    [aux_sym_basic_type_token48] = ACTIONS(6292),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6292),
    [anon_sym_POUNDif] = ACTIONS(6296),
    [anon_sym_POUNDIF] = ACTIONS(6296),
    [anon_sym_POUNDIf] = ACTIONS(6296),
    [anon_sym_not] = ACTIONS(6292),
    [anon_sym_NOT] = ACTIONS(6292),
    [anon_sym_Not] = ACTIONS(6292),
    [anon_sym_POUNDelif] = ACTIONS(6296),
    [anon_sym_POUNDELIF] = ACTIONS(6296),
    [anon_sym_POUNDElif] = ACTIONS(6296),
    [anon_sym_POUNDelse] = ACTIONS(6296),
    [anon_sym_POUNDELSE] = ACTIONS(6296),
    [anon_sym_POUNDElse] = ACTIONS(6296),
    [anon_sym_POUNDelse2] = ACTIONS(6296),
    [anon_sym_POUNDELSE2] = ACTIONS(6296),
    [anon_sym_POUNDElse2] = ACTIONS(6296),
    [anon_sym_POUNDendif] = ACTIONS(6296),
    [anon_sym_POUNDENDIF] = ACTIONS(6296),
    [anon_sym_POUNDEndif] = ACTIONS(6296),
    [anon_sym_POUNDendif2] = ACTIONS(6296),
    [anon_sym_POUNDENDIF2] = ACTIONS(6296),
    [anon_sym_POUNDEndif2] = ACTIONS(6296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6292),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6292),
    [anon_sym_PLUS] = ACTIONS(6296),
    [sym_datetime_literal] = ACTIONS(6296),
    [sym_date_literal] = ACTIONS(6292),
    [sym_time_literal] = ACTIONS(6292),
    [sym_biginteger_literal] = ACTIONS(6296),
    [anon_sym_if] = ACTIONS(6292),
    [anon_sym_IF] = ACTIONS(6292),
    [anon_sym_If] = ACTIONS(6292),
    [anon_sym_else] = ACTIONS(6292),
    [anon_sym_ELSE] = ACTIONS(6292),
    [anon_sym_Else] = ACTIONS(6292),
    [anon_sym_case] = ACTIONS(6292),
    [anon_sym_CASE] = ACTIONS(6292),
    [anon_sym_Case] = ACTIONS(6292),
    [anon_sym_for] = ACTIONS(6292),
    [anon_sym_FOR] = ACTIONS(6292),
    [anon_sym_For] = ACTIONS(6292),
    [anon_sym_foreach] = ACTIONS(6292),
    [anon_sym_FOREACH] = ACTIONS(6292),
    [anon_sym_Foreach] = ACTIONS(6292),
    [anon_sym_while] = ACTIONS(6292),
    [anon_sym_WHILE] = ACTIONS(6292),
    [anon_sym_While] = ACTIONS(6292),
    [anon_sym_repeat] = ACTIONS(6292),
    [anon_sym_REPEAT] = ACTIONS(6292),
    [anon_sym_Repeat] = ACTIONS(6292),
    [anon_sym_exit] = ACTIONS(6292),
    [anon_sym_EXIT] = ACTIONS(6292),
    [anon_sym_Exit] = ACTIONS(6292),
    [anon_sym_continue] = ACTIONS(6292),
    [anon_sym_CONTINUE] = ACTIONS(6292),
    [anon_sym_Continue] = ACTIONS(6292),
    [anon_sym_break] = ACTIONS(6292),
    [anon_sym_BREAK] = ACTIONS(6292),
    [anon_sym_Break] = ACTIONS(6292),
    [anon_sym_with] = ACTIONS(6292),
    [anon_sym_WITH] = ACTIONS(6292),
    [anon_sym_With] = ACTIONS(6292),
    [sym_asserterror_keyword] = ACTIONS(6296),
    [sym_page_keyword] = ACTIONS(6292),
    [anon_sym_codeunit] = ACTIONS(6292),
    [anon_sym_CODEUNIT] = ACTIONS(6292),
    [anon_sym_Codeunit] = ACTIONS(6292),
    [anon_sym_CodeUnit] = ACTIONS(6292),
    [anon_sym_COdeunit] = ACTIONS(6292),
    [anon_sym_codeUnit] = ACTIONS(6292),
    [sym_report_keyword] = ACTIONS(6292),
    [sym_query_keyword] = ACTIONS(6292),
    [anon_sym_xmlport] = ACTIONS(6292),
    [anon_sym_XMLPORT] = ACTIONS(6292),
    [anon_sym_Xmlport] = ACTIONS(6292),
    [anon_sym_XMLport] = ACTIONS(6292),
    [anon_sym_XMLPort] = ACTIONS(6292),
    [anon_sym_XmlPort] = ACTIONS(6292),
    [anon_sym_enum] = ACTIONS(6292),
    [anon_sym_ENUM] = ACTIONS(6292),
    [anon_sym_Enum] = ACTIONS(6292),
    [anon_sym_eNUM] = ACTIONS(6292),
    [anon_sym_eNum] = ACTIONS(6292),
    [anon_sym_ENum] = ACTIONS(6292),
    [sym_quoted_identifier] = ACTIONS(6296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6296),
    [sym_verbatim_string] = ACTIONS(6296),
    [sym_integer] = ACTIONS(6292),
    [sym_continue_as_identifier] = ACTIONS(6296),
    [sym_preproc_open] = ACTIONS(6296),
    [sym_preproc_close] = ACTIONS(6296),
  },
  [STATE(2611)] = {
    [sym_identifier] = ACTIONS(6292),
    [anon_sym_SEMI] = ACTIONS(6298),
    [anon_sym_DASH] = ACTIONS(6296),
    [aux_sym_boolean_token1] = ACTIONS(6292),
    [aux_sym_boolean_token2] = ACTIONS(6292),
    [sym_decimal] = ACTIONS(6292),
    [anon_sym_LPAREN] = ACTIONS(6296),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6292),
    [anon_sym_LBRACK] = ACTIONS(6296),
    [aux_sym_record_type_token1] = ACTIONS(6292),
    [aux_sym_basic_type_token21] = ACTIONS(6292),
    [aux_sym_basic_type_token22] = ACTIONS(6292),
    [aux_sym_basic_type_token48] = ACTIONS(6292),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6292),
    [anon_sym_POUNDif] = ACTIONS(6296),
    [anon_sym_POUNDIF] = ACTIONS(6296),
    [anon_sym_POUNDIf] = ACTIONS(6296),
    [anon_sym_not] = ACTIONS(6292),
    [anon_sym_NOT] = ACTIONS(6292),
    [anon_sym_Not] = ACTIONS(6292),
    [anon_sym_POUNDelif] = ACTIONS(6296),
    [anon_sym_POUNDELIF] = ACTIONS(6296),
    [anon_sym_POUNDElif] = ACTIONS(6296),
    [anon_sym_POUNDelse] = ACTIONS(6296),
    [anon_sym_POUNDELSE] = ACTIONS(6296),
    [anon_sym_POUNDElse] = ACTIONS(6296),
    [anon_sym_POUNDelse2] = ACTIONS(6296),
    [anon_sym_POUNDELSE2] = ACTIONS(6296),
    [anon_sym_POUNDElse2] = ACTIONS(6296),
    [anon_sym_POUNDendif] = ACTIONS(6296),
    [anon_sym_POUNDENDIF] = ACTIONS(6296),
    [anon_sym_POUNDEndif] = ACTIONS(6296),
    [anon_sym_POUNDendif2] = ACTIONS(6296),
    [anon_sym_POUNDENDIF2] = ACTIONS(6296),
    [anon_sym_POUNDEndif2] = ACTIONS(6296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6292),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6292),
    [anon_sym_PLUS] = ACTIONS(6296),
    [sym_datetime_literal] = ACTIONS(6296),
    [sym_date_literal] = ACTIONS(6292),
    [sym_time_literal] = ACTIONS(6292),
    [sym_biginteger_literal] = ACTIONS(6296),
    [anon_sym_if] = ACTIONS(6292),
    [anon_sym_IF] = ACTIONS(6292),
    [anon_sym_If] = ACTIONS(6292),
    [anon_sym_else] = ACTIONS(6292),
    [anon_sym_ELSE] = ACTIONS(6292),
    [anon_sym_Else] = ACTIONS(6292),
    [anon_sym_case] = ACTIONS(6292),
    [anon_sym_CASE] = ACTIONS(6292),
    [anon_sym_Case] = ACTIONS(6292),
    [anon_sym_for] = ACTIONS(6292),
    [anon_sym_FOR] = ACTIONS(6292),
    [anon_sym_For] = ACTIONS(6292),
    [anon_sym_foreach] = ACTIONS(6292),
    [anon_sym_FOREACH] = ACTIONS(6292),
    [anon_sym_Foreach] = ACTIONS(6292),
    [anon_sym_while] = ACTIONS(6292),
    [anon_sym_WHILE] = ACTIONS(6292),
    [anon_sym_While] = ACTIONS(6292),
    [anon_sym_repeat] = ACTIONS(6292),
    [anon_sym_REPEAT] = ACTIONS(6292),
    [anon_sym_Repeat] = ACTIONS(6292),
    [anon_sym_exit] = ACTIONS(6292),
    [anon_sym_EXIT] = ACTIONS(6292),
    [anon_sym_Exit] = ACTIONS(6292),
    [anon_sym_continue] = ACTIONS(6292),
    [anon_sym_CONTINUE] = ACTIONS(6292),
    [anon_sym_Continue] = ACTIONS(6292),
    [anon_sym_break] = ACTIONS(6292),
    [anon_sym_BREAK] = ACTIONS(6292),
    [anon_sym_Break] = ACTIONS(6292),
    [anon_sym_with] = ACTIONS(6292),
    [anon_sym_WITH] = ACTIONS(6292),
    [anon_sym_With] = ACTIONS(6292),
    [sym_asserterror_keyword] = ACTIONS(6296),
    [sym_page_keyword] = ACTIONS(6292),
    [anon_sym_codeunit] = ACTIONS(6292),
    [anon_sym_CODEUNIT] = ACTIONS(6292),
    [anon_sym_Codeunit] = ACTIONS(6292),
    [anon_sym_CodeUnit] = ACTIONS(6292),
    [anon_sym_COdeunit] = ACTIONS(6292),
    [anon_sym_codeUnit] = ACTIONS(6292),
    [sym_report_keyword] = ACTIONS(6292),
    [sym_query_keyword] = ACTIONS(6292),
    [anon_sym_xmlport] = ACTIONS(6292),
    [anon_sym_XMLPORT] = ACTIONS(6292),
    [anon_sym_Xmlport] = ACTIONS(6292),
    [anon_sym_XMLport] = ACTIONS(6292),
    [anon_sym_XMLPort] = ACTIONS(6292),
    [anon_sym_XmlPort] = ACTIONS(6292),
    [anon_sym_enum] = ACTIONS(6292),
    [anon_sym_ENUM] = ACTIONS(6292),
    [anon_sym_Enum] = ACTIONS(6292),
    [anon_sym_eNUM] = ACTIONS(6292),
    [anon_sym_eNum] = ACTIONS(6292),
    [anon_sym_ENum] = ACTIONS(6292),
    [sym_quoted_identifier] = ACTIONS(6296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6296),
    [sym_verbatim_string] = ACTIONS(6296),
    [sym_integer] = ACTIONS(6292),
    [sym_continue_as_identifier] = ACTIONS(6296),
    [sym_preproc_open] = ACTIONS(6296),
    [sym_preproc_close] = ACTIONS(6296),
  },
  [STATE(2612)] = {
    [sym_identifier] = ACTIONS(6300),
    [anon_sym_SEMI] = ACTIONS(6302),
    [anon_sym_DASH] = ACTIONS(6302),
    [aux_sym_boolean_token1] = ACTIONS(6300),
    [aux_sym_boolean_token2] = ACTIONS(6300),
    [sym_decimal] = ACTIONS(6300),
    [anon_sym_LPAREN] = ACTIONS(6302),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6300),
    [anon_sym_LBRACK] = ACTIONS(6302),
    [aux_sym_record_type_token1] = ACTIONS(6300),
    [aux_sym_basic_type_token21] = ACTIONS(6300),
    [aux_sym_basic_type_token22] = ACTIONS(6300),
    [aux_sym_basic_type_token48] = ACTIONS(6300),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6300),
    [anon_sym_POUNDif] = ACTIONS(6302),
    [anon_sym_POUNDIF] = ACTIONS(6302),
    [anon_sym_POUNDIf] = ACTIONS(6302),
    [anon_sym_not] = ACTIONS(6300),
    [anon_sym_NOT] = ACTIONS(6300),
    [anon_sym_Not] = ACTIONS(6300),
    [anon_sym_POUNDelif] = ACTIONS(6302),
    [anon_sym_POUNDELIF] = ACTIONS(6302),
    [anon_sym_POUNDElif] = ACTIONS(6302),
    [anon_sym_POUNDelse] = ACTIONS(6302),
    [anon_sym_POUNDELSE] = ACTIONS(6302),
    [anon_sym_POUNDElse] = ACTIONS(6302),
    [anon_sym_POUNDelse2] = ACTIONS(6302),
    [anon_sym_POUNDELSE2] = ACTIONS(6302),
    [anon_sym_POUNDElse2] = ACTIONS(6302),
    [anon_sym_POUNDendif] = ACTIONS(6302),
    [anon_sym_POUNDENDIF] = ACTIONS(6302),
    [anon_sym_POUNDEndif] = ACTIONS(6302),
    [anon_sym_POUNDendif2] = ACTIONS(6302),
    [anon_sym_POUNDENDIF2] = ACTIONS(6302),
    [anon_sym_POUNDEndif2] = ACTIONS(6302),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6300),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6300),
    [anon_sym_PLUS] = ACTIONS(6302),
    [sym_datetime_literal] = ACTIONS(6302),
    [sym_date_literal] = ACTIONS(6300),
    [sym_time_literal] = ACTIONS(6300),
    [sym_biginteger_literal] = ACTIONS(6302),
    [anon_sym_if] = ACTIONS(6300),
    [anon_sym_IF] = ACTIONS(6300),
    [anon_sym_If] = ACTIONS(6300),
    [anon_sym_else] = ACTIONS(6300),
    [anon_sym_ELSE] = ACTIONS(6300),
    [anon_sym_Else] = ACTIONS(6300),
    [anon_sym_case] = ACTIONS(6300),
    [anon_sym_CASE] = ACTIONS(6300),
    [anon_sym_Case] = ACTIONS(6300),
    [anon_sym_for] = ACTIONS(6300),
    [anon_sym_FOR] = ACTIONS(6300),
    [anon_sym_For] = ACTIONS(6300),
    [anon_sym_foreach] = ACTIONS(6300),
    [anon_sym_FOREACH] = ACTIONS(6300),
    [anon_sym_Foreach] = ACTIONS(6300),
    [anon_sym_while] = ACTIONS(6300),
    [anon_sym_WHILE] = ACTIONS(6300),
    [anon_sym_While] = ACTIONS(6300),
    [anon_sym_repeat] = ACTIONS(6300),
    [anon_sym_REPEAT] = ACTIONS(6300),
    [anon_sym_Repeat] = ACTIONS(6300),
    [anon_sym_exit] = ACTIONS(6300),
    [anon_sym_EXIT] = ACTIONS(6300),
    [anon_sym_Exit] = ACTIONS(6300),
    [anon_sym_continue] = ACTIONS(6300),
    [anon_sym_CONTINUE] = ACTIONS(6300),
    [anon_sym_Continue] = ACTIONS(6300),
    [anon_sym_break] = ACTIONS(6300),
    [anon_sym_BREAK] = ACTIONS(6300),
    [anon_sym_Break] = ACTIONS(6300),
    [anon_sym_with] = ACTIONS(6300),
    [anon_sym_WITH] = ACTIONS(6300),
    [anon_sym_With] = ACTIONS(6300),
    [sym_asserterror_keyword] = ACTIONS(6302),
    [sym_page_keyword] = ACTIONS(6300),
    [anon_sym_codeunit] = ACTIONS(6300),
    [anon_sym_CODEUNIT] = ACTIONS(6300),
    [anon_sym_Codeunit] = ACTIONS(6300),
    [anon_sym_CodeUnit] = ACTIONS(6300),
    [anon_sym_COdeunit] = ACTIONS(6300),
    [anon_sym_codeUnit] = ACTIONS(6300),
    [sym_report_keyword] = ACTIONS(6300),
    [sym_query_keyword] = ACTIONS(6300),
    [anon_sym_xmlport] = ACTIONS(6300),
    [anon_sym_XMLPORT] = ACTIONS(6300),
    [anon_sym_Xmlport] = ACTIONS(6300),
    [anon_sym_XMLport] = ACTIONS(6300),
    [anon_sym_XMLPort] = ACTIONS(6300),
    [anon_sym_XmlPort] = ACTIONS(6300),
    [anon_sym_enum] = ACTIONS(6300),
    [anon_sym_ENUM] = ACTIONS(6300),
    [anon_sym_Enum] = ACTIONS(6300),
    [anon_sym_eNUM] = ACTIONS(6300),
    [anon_sym_eNum] = ACTIONS(6300),
    [anon_sym_ENum] = ACTIONS(6300),
    [sym_quoted_identifier] = ACTIONS(6302),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6302),
    [sym_verbatim_string] = ACTIONS(6302),
    [sym_integer] = ACTIONS(6300),
    [sym_continue_as_identifier] = ACTIONS(6302),
    [sym_preproc_open] = ACTIONS(6302),
    [sym_preproc_close] = ACTIONS(6302),
  },
  [STATE(2613)] = {
    [sym_identifier] = ACTIONS(6304),
    [anon_sym_SEMI] = ACTIONS(6306),
    [anon_sym_DASH] = ACTIONS(6306),
    [aux_sym_boolean_token1] = ACTIONS(6304),
    [aux_sym_boolean_token2] = ACTIONS(6304),
    [sym_decimal] = ACTIONS(6304),
    [anon_sym_LPAREN] = ACTIONS(6306),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6304),
    [anon_sym_LBRACK] = ACTIONS(6306),
    [aux_sym_record_type_token1] = ACTIONS(6304),
    [aux_sym_basic_type_token21] = ACTIONS(6304),
    [aux_sym_basic_type_token22] = ACTIONS(6304),
    [aux_sym_basic_type_token48] = ACTIONS(6304),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6304),
    [anon_sym_POUNDif] = ACTIONS(6306),
    [anon_sym_POUNDIF] = ACTIONS(6306),
    [anon_sym_POUNDIf] = ACTIONS(6306),
    [anon_sym_not] = ACTIONS(6304),
    [anon_sym_NOT] = ACTIONS(6304),
    [anon_sym_Not] = ACTIONS(6304),
    [anon_sym_POUNDelif] = ACTIONS(6306),
    [anon_sym_POUNDELIF] = ACTIONS(6306),
    [anon_sym_POUNDElif] = ACTIONS(6306),
    [anon_sym_POUNDelse] = ACTIONS(6306),
    [anon_sym_POUNDELSE] = ACTIONS(6306),
    [anon_sym_POUNDElse] = ACTIONS(6306),
    [anon_sym_POUNDelse2] = ACTIONS(6306),
    [anon_sym_POUNDELSE2] = ACTIONS(6306),
    [anon_sym_POUNDElse2] = ACTIONS(6306),
    [anon_sym_POUNDendif] = ACTIONS(6306),
    [anon_sym_POUNDENDIF] = ACTIONS(6306),
    [anon_sym_POUNDEndif] = ACTIONS(6306),
    [anon_sym_POUNDendif2] = ACTIONS(6306),
    [anon_sym_POUNDENDIF2] = ACTIONS(6306),
    [anon_sym_POUNDEndif2] = ACTIONS(6306),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6304),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6304),
    [anon_sym_PLUS] = ACTIONS(6306),
    [sym_datetime_literal] = ACTIONS(6306),
    [sym_date_literal] = ACTIONS(6304),
    [sym_time_literal] = ACTIONS(6304),
    [sym_biginteger_literal] = ACTIONS(6306),
    [anon_sym_if] = ACTIONS(6304),
    [anon_sym_IF] = ACTIONS(6304),
    [anon_sym_If] = ACTIONS(6304),
    [anon_sym_else] = ACTIONS(6304),
    [anon_sym_ELSE] = ACTIONS(6304),
    [anon_sym_Else] = ACTIONS(6304),
    [anon_sym_case] = ACTIONS(6304),
    [anon_sym_CASE] = ACTIONS(6304),
    [anon_sym_Case] = ACTIONS(6304),
    [anon_sym_for] = ACTIONS(6304),
    [anon_sym_FOR] = ACTIONS(6304),
    [anon_sym_For] = ACTIONS(6304),
    [anon_sym_foreach] = ACTIONS(6304),
    [anon_sym_FOREACH] = ACTIONS(6304),
    [anon_sym_Foreach] = ACTIONS(6304),
    [anon_sym_while] = ACTIONS(6304),
    [anon_sym_WHILE] = ACTIONS(6304),
    [anon_sym_While] = ACTIONS(6304),
    [anon_sym_repeat] = ACTIONS(6304),
    [anon_sym_REPEAT] = ACTIONS(6304),
    [anon_sym_Repeat] = ACTIONS(6304),
    [anon_sym_exit] = ACTIONS(6304),
    [anon_sym_EXIT] = ACTIONS(6304),
    [anon_sym_Exit] = ACTIONS(6304),
    [anon_sym_continue] = ACTIONS(6304),
    [anon_sym_CONTINUE] = ACTIONS(6304),
    [anon_sym_Continue] = ACTIONS(6304),
    [anon_sym_break] = ACTIONS(6304),
    [anon_sym_BREAK] = ACTIONS(6304),
    [anon_sym_Break] = ACTIONS(6304),
    [anon_sym_with] = ACTIONS(6304),
    [anon_sym_WITH] = ACTIONS(6304),
    [anon_sym_With] = ACTIONS(6304),
    [sym_asserterror_keyword] = ACTIONS(6306),
    [sym_page_keyword] = ACTIONS(6304),
    [anon_sym_codeunit] = ACTIONS(6304),
    [anon_sym_CODEUNIT] = ACTIONS(6304),
    [anon_sym_Codeunit] = ACTIONS(6304),
    [anon_sym_CodeUnit] = ACTIONS(6304),
    [anon_sym_COdeunit] = ACTIONS(6304),
    [anon_sym_codeUnit] = ACTIONS(6304),
    [sym_report_keyword] = ACTIONS(6304),
    [sym_query_keyword] = ACTIONS(6304),
    [anon_sym_xmlport] = ACTIONS(6304),
    [anon_sym_XMLPORT] = ACTIONS(6304),
    [anon_sym_Xmlport] = ACTIONS(6304),
    [anon_sym_XMLport] = ACTIONS(6304),
    [anon_sym_XMLPort] = ACTIONS(6304),
    [anon_sym_XmlPort] = ACTIONS(6304),
    [anon_sym_enum] = ACTIONS(6304),
    [anon_sym_ENUM] = ACTIONS(6304),
    [anon_sym_Enum] = ACTIONS(6304),
    [anon_sym_eNUM] = ACTIONS(6304),
    [anon_sym_eNum] = ACTIONS(6304),
    [anon_sym_ENum] = ACTIONS(6304),
    [sym_quoted_identifier] = ACTIONS(6306),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6306),
    [sym_verbatim_string] = ACTIONS(6306),
    [sym_integer] = ACTIONS(6304),
    [sym_continue_as_identifier] = ACTIONS(6306),
    [sym_preproc_open] = ACTIONS(6306),
    [sym_preproc_close] = ACTIONS(6306),
  },
  [STATE(2614)] = {
    [sym_identifier] = ACTIONS(6300),
    [anon_sym_SEMI] = ACTIONS(6302),
    [anon_sym_DASH] = ACTIONS(6302),
    [aux_sym_boolean_token1] = ACTIONS(6300),
    [aux_sym_boolean_token2] = ACTIONS(6300),
    [sym_decimal] = ACTIONS(6300),
    [anon_sym_LPAREN] = ACTIONS(6302),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6300),
    [anon_sym_LBRACK] = ACTIONS(6302),
    [aux_sym_record_type_token1] = ACTIONS(6300),
    [aux_sym_basic_type_token21] = ACTIONS(6300),
    [aux_sym_basic_type_token22] = ACTIONS(6300),
    [aux_sym_basic_type_token48] = ACTIONS(6300),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6300),
    [anon_sym_POUNDif] = ACTIONS(6302),
    [anon_sym_POUNDIF] = ACTIONS(6302),
    [anon_sym_POUNDIf] = ACTIONS(6302),
    [anon_sym_not] = ACTIONS(6300),
    [anon_sym_NOT] = ACTIONS(6300),
    [anon_sym_Not] = ACTIONS(6300),
    [anon_sym_POUNDelif] = ACTIONS(6302),
    [anon_sym_POUNDELIF] = ACTIONS(6302),
    [anon_sym_POUNDElif] = ACTIONS(6302),
    [anon_sym_POUNDelse] = ACTIONS(6302),
    [anon_sym_POUNDELSE] = ACTIONS(6302),
    [anon_sym_POUNDElse] = ACTIONS(6302),
    [anon_sym_POUNDelse2] = ACTIONS(6302),
    [anon_sym_POUNDELSE2] = ACTIONS(6302),
    [anon_sym_POUNDElse2] = ACTIONS(6302),
    [anon_sym_POUNDendif] = ACTIONS(6302),
    [anon_sym_POUNDENDIF] = ACTIONS(6302),
    [anon_sym_POUNDEndif] = ACTIONS(6302),
    [anon_sym_POUNDendif2] = ACTIONS(6302),
    [anon_sym_POUNDENDIF2] = ACTIONS(6302),
    [anon_sym_POUNDEndif2] = ACTIONS(6302),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6300),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6300),
    [anon_sym_PLUS] = ACTIONS(6302),
    [sym_datetime_literal] = ACTIONS(6302),
    [sym_date_literal] = ACTIONS(6300),
    [sym_time_literal] = ACTIONS(6300),
    [sym_biginteger_literal] = ACTIONS(6302),
    [anon_sym_if] = ACTIONS(6300),
    [anon_sym_IF] = ACTIONS(6300),
    [anon_sym_If] = ACTIONS(6300),
    [anon_sym_else] = ACTIONS(6300),
    [anon_sym_ELSE] = ACTIONS(6300),
    [anon_sym_Else] = ACTIONS(6300),
    [anon_sym_case] = ACTIONS(6300),
    [anon_sym_CASE] = ACTIONS(6300),
    [anon_sym_Case] = ACTIONS(6300),
    [anon_sym_for] = ACTIONS(6300),
    [anon_sym_FOR] = ACTIONS(6300),
    [anon_sym_For] = ACTIONS(6300),
    [anon_sym_foreach] = ACTIONS(6300),
    [anon_sym_FOREACH] = ACTIONS(6300),
    [anon_sym_Foreach] = ACTIONS(6300),
    [anon_sym_while] = ACTIONS(6300),
    [anon_sym_WHILE] = ACTIONS(6300),
    [anon_sym_While] = ACTIONS(6300),
    [anon_sym_repeat] = ACTIONS(6300),
    [anon_sym_REPEAT] = ACTIONS(6300),
    [anon_sym_Repeat] = ACTIONS(6300),
    [anon_sym_exit] = ACTIONS(6300),
    [anon_sym_EXIT] = ACTIONS(6300),
    [anon_sym_Exit] = ACTIONS(6300),
    [anon_sym_continue] = ACTIONS(6300),
    [anon_sym_CONTINUE] = ACTIONS(6300),
    [anon_sym_Continue] = ACTIONS(6300),
    [anon_sym_break] = ACTIONS(6300),
    [anon_sym_BREAK] = ACTIONS(6300),
    [anon_sym_Break] = ACTIONS(6300),
    [anon_sym_with] = ACTIONS(6300),
    [anon_sym_WITH] = ACTIONS(6300),
    [anon_sym_With] = ACTIONS(6300),
    [sym_asserterror_keyword] = ACTIONS(6302),
    [sym_page_keyword] = ACTIONS(6300),
    [anon_sym_codeunit] = ACTIONS(6300),
    [anon_sym_CODEUNIT] = ACTIONS(6300),
    [anon_sym_Codeunit] = ACTIONS(6300),
    [anon_sym_CodeUnit] = ACTIONS(6300),
    [anon_sym_COdeunit] = ACTIONS(6300),
    [anon_sym_codeUnit] = ACTIONS(6300),
    [sym_report_keyword] = ACTIONS(6300),
    [sym_query_keyword] = ACTIONS(6300),
    [anon_sym_xmlport] = ACTIONS(6300),
    [anon_sym_XMLPORT] = ACTIONS(6300),
    [anon_sym_Xmlport] = ACTIONS(6300),
    [anon_sym_XMLport] = ACTIONS(6300),
    [anon_sym_XMLPort] = ACTIONS(6300),
    [anon_sym_XmlPort] = ACTIONS(6300),
    [anon_sym_enum] = ACTIONS(6300),
    [anon_sym_ENUM] = ACTIONS(6300),
    [anon_sym_Enum] = ACTIONS(6300),
    [anon_sym_eNUM] = ACTIONS(6300),
    [anon_sym_eNum] = ACTIONS(6300),
    [anon_sym_ENum] = ACTIONS(6300),
    [sym_quoted_identifier] = ACTIONS(6302),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6302),
    [sym_verbatim_string] = ACTIONS(6302),
    [sym_integer] = ACTIONS(6300),
    [sym_continue_as_identifier] = ACTIONS(6302),
    [sym_preproc_open] = ACTIONS(6302),
    [sym_preproc_close] = ACTIONS(6302),
  },
  [STATE(2615)] = {
    [sym_identifier] = ACTIONS(6304),
    [anon_sym_SEMI] = ACTIONS(6306),
    [anon_sym_DASH] = ACTIONS(6306),
    [aux_sym_boolean_token1] = ACTIONS(6304),
    [aux_sym_boolean_token2] = ACTIONS(6304),
    [sym_decimal] = ACTIONS(6304),
    [anon_sym_LPAREN] = ACTIONS(6306),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6304),
    [anon_sym_LBRACK] = ACTIONS(6306),
    [aux_sym_record_type_token1] = ACTIONS(6304),
    [aux_sym_basic_type_token21] = ACTIONS(6304),
    [aux_sym_basic_type_token22] = ACTIONS(6304),
    [aux_sym_basic_type_token48] = ACTIONS(6304),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6304),
    [anon_sym_POUNDif] = ACTIONS(6306),
    [anon_sym_POUNDIF] = ACTIONS(6306),
    [anon_sym_POUNDIf] = ACTIONS(6306),
    [anon_sym_not] = ACTIONS(6304),
    [anon_sym_NOT] = ACTIONS(6304),
    [anon_sym_Not] = ACTIONS(6304),
    [anon_sym_POUNDelif] = ACTIONS(6306),
    [anon_sym_POUNDELIF] = ACTIONS(6306),
    [anon_sym_POUNDElif] = ACTIONS(6306),
    [anon_sym_POUNDelse] = ACTIONS(6306),
    [anon_sym_POUNDELSE] = ACTIONS(6306),
    [anon_sym_POUNDElse] = ACTIONS(6306),
    [anon_sym_POUNDelse2] = ACTIONS(6306),
    [anon_sym_POUNDELSE2] = ACTIONS(6306),
    [anon_sym_POUNDElse2] = ACTIONS(6306),
    [anon_sym_POUNDendif] = ACTIONS(6306),
    [anon_sym_POUNDENDIF] = ACTIONS(6306),
    [anon_sym_POUNDEndif] = ACTIONS(6306),
    [anon_sym_POUNDendif2] = ACTIONS(6306),
    [anon_sym_POUNDENDIF2] = ACTIONS(6306),
    [anon_sym_POUNDEndif2] = ACTIONS(6306),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6304),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6304),
    [anon_sym_PLUS] = ACTIONS(6306),
    [sym_datetime_literal] = ACTIONS(6306),
    [sym_date_literal] = ACTIONS(6304),
    [sym_time_literal] = ACTIONS(6304),
    [sym_biginteger_literal] = ACTIONS(6306),
    [anon_sym_if] = ACTIONS(6304),
    [anon_sym_IF] = ACTIONS(6304),
    [anon_sym_If] = ACTIONS(6304),
    [anon_sym_else] = ACTIONS(6304),
    [anon_sym_ELSE] = ACTIONS(6304),
    [anon_sym_Else] = ACTIONS(6304),
    [anon_sym_case] = ACTIONS(6304),
    [anon_sym_CASE] = ACTIONS(6304),
    [anon_sym_Case] = ACTIONS(6304),
    [anon_sym_for] = ACTIONS(6304),
    [anon_sym_FOR] = ACTIONS(6304),
    [anon_sym_For] = ACTIONS(6304),
    [anon_sym_foreach] = ACTIONS(6304),
    [anon_sym_FOREACH] = ACTIONS(6304),
    [anon_sym_Foreach] = ACTIONS(6304),
    [anon_sym_while] = ACTIONS(6304),
    [anon_sym_WHILE] = ACTIONS(6304),
    [anon_sym_While] = ACTIONS(6304),
    [anon_sym_repeat] = ACTIONS(6304),
    [anon_sym_REPEAT] = ACTIONS(6304),
    [anon_sym_Repeat] = ACTIONS(6304),
    [anon_sym_exit] = ACTIONS(6304),
    [anon_sym_EXIT] = ACTIONS(6304),
    [anon_sym_Exit] = ACTIONS(6304),
    [anon_sym_continue] = ACTIONS(6304),
    [anon_sym_CONTINUE] = ACTIONS(6304),
    [anon_sym_Continue] = ACTIONS(6304),
    [anon_sym_break] = ACTIONS(6304),
    [anon_sym_BREAK] = ACTIONS(6304),
    [anon_sym_Break] = ACTIONS(6304),
    [anon_sym_with] = ACTIONS(6304),
    [anon_sym_WITH] = ACTIONS(6304),
    [anon_sym_With] = ACTIONS(6304),
    [sym_asserterror_keyword] = ACTIONS(6306),
    [sym_page_keyword] = ACTIONS(6304),
    [anon_sym_codeunit] = ACTIONS(6304),
    [anon_sym_CODEUNIT] = ACTIONS(6304),
    [anon_sym_Codeunit] = ACTIONS(6304),
    [anon_sym_CodeUnit] = ACTIONS(6304),
    [anon_sym_COdeunit] = ACTIONS(6304),
    [anon_sym_codeUnit] = ACTIONS(6304),
    [sym_report_keyword] = ACTIONS(6304),
    [sym_query_keyword] = ACTIONS(6304),
    [anon_sym_xmlport] = ACTIONS(6304),
    [anon_sym_XMLPORT] = ACTIONS(6304),
    [anon_sym_Xmlport] = ACTIONS(6304),
    [anon_sym_XMLport] = ACTIONS(6304),
    [anon_sym_XMLPort] = ACTIONS(6304),
    [anon_sym_XmlPort] = ACTIONS(6304),
    [anon_sym_enum] = ACTIONS(6304),
    [anon_sym_ENUM] = ACTIONS(6304),
    [anon_sym_Enum] = ACTIONS(6304),
    [anon_sym_eNUM] = ACTIONS(6304),
    [anon_sym_eNum] = ACTIONS(6304),
    [anon_sym_ENum] = ACTIONS(6304),
    [sym_quoted_identifier] = ACTIONS(6306),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6306),
    [sym_verbatim_string] = ACTIONS(6306),
    [sym_integer] = ACTIONS(6304),
    [sym_continue_as_identifier] = ACTIONS(6306),
    [sym_preproc_open] = ACTIONS(6306),
    [sym_preproc_close] = ACTIONS(6306),
  },
  [STATE(2616)] = {
    [sym_identifier] = ACTIONS(6308),
    [anon_sym_SEMI] = ACTIONS(6310),
    [anon_sym_DASH] = ACTIONS(6310),
    [aux_sym_boolean_token1] = ACTIONS(6308),
    [aux_sym_boolean_token2] = ACTIONS(6308),
    [sym_decimal] = ACTIONS(6308),
    [anon_sym_LPAREN] = ACTIONS(6310),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6308),
    [anon_sym_LBRACK] = ACTIONS(6310),
    [aux_sym_record_type_token1] = ACTIONS(6308),
    [aux_sym_basic_type_token21] = ACTIONS(6308),
    [aux_sym_basic_type_token22] = ACTIONS(6308),
    [aux_sym_basic_type_token48] = ACTIONS(6308),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6308),
    [anon_sym_POUNDif] = ACTIONS(6310),
    [anon_sym_POUNDIF] = ACTIONS(6310),
    [anon_sym_POUNDIf] = ACTIONS(6310),
    [anon_sym_not] = ACTIONS(6308),
    [anon_sym_NOT] = ACTIONS(6308),
    [anon_sym_Not] = ACTIONS(6308),
    [anon_sym_POUNDelif] = ACTIONS(6310),
    [anon_sym_POUNDELIF] = ACTIONS(6310),
    [anon_sym_POUNDElif] = ACTIONS(6310),
    [anon_sym_POUNDelse] = ACTIONS(6310),
    [anon_sym_POUNDELSE] = ACTIONS(6310),
    [anon_sym_POUNDElse] = ACTIONS(6310),
    [anon_sym_POUNDelse2] = ACTIONS(6310),
    [anon_sym_POUNDELSE2] = ACTIONS(6310),
    [anon_sym_POUNDElse2] = ACTIONS(6310),
    [anon_sym_POUNDendif] = ACTIONS(6310),
    [anon_sym_POUNDENDIF] = ACTIONS(6310),
    [anon_sym_POUNDEndif] = ACTIONS(6310),
    [anon_sym_POUNDendif2] = ACTIONS(6310),
    [anon_sym_POUNDENDIF2] = ACTIONS(6310),
    [anon_sym_POUNDEndif2] = ACTIONS(6310),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6308),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6308),
    [anon_sym_PLUS] = ACTIONS(6310),
    [sym_datetime_literal] = ACTIONS(6310),
    [sym_date_literal] = ACTIONS(6308),
    [sym_time_literal] = ACTIONS(6308),
    [sym_biginteger_literal] = ACTIONS(6310),
    [anon_sym_if] = ACTIONS(6308),
    [anon_sym_IF] = ACTIONS(6308),
    [anon_sym_If] = ACTIONS(6308),
    [anon_sym_else] = ACTIONS(6308),
    [anon_sym_ELSE] = ACTIONS(6308),
    [anon_sym_Else] = ACTIONS(6308),
    [anon_sym_case] = ACTIONS(6308),
    [anon_sym_CASE] = ACTIONS(6308),
    [anon_sym_Case] = ACTIONS(6308),
    [anon_sym_for] = ACTIONS(6308),
    [anon_sym_FOR] = ACTIONS(6308),
    [anon_sym_For] = ACTIONS(6308),
    [anon_sym_foreach] = ACTIONS(6308),
    [anon_sym_FOREACH] = ACTIONS(6308),
    [anon_sym_Foreach] = ACTIONS(6308),
    [anon_sym_while] = ACTIONS(6308),
    [anon_sym_WHILE] = ACTIONS(6308),
    [anon_sym_While] = ACTIONS(6308),
    [anon_sym_repeat] = ACTIONS(6308),
    [anon_sym_REPEAT] = ACTIONS(6308),
    [anon_sym_Repeat] = ACTIONS(6308),
    [anon_sym_exit] = ACTIONS(6308),
    [anon_sym_EXIT] = ACTIONS(6308),
    [anon_sym_Exit] = ACTIONS(6308),
    [anon_sym_continue] = ACTIONS(6308),
    [anon_sym_CONTINUE] = ACTIONS(6308),
    [anon_sym_Continue] = ACTIONS(6308),
    [anon_sym_break] = ACTIONS(6308),
    [anon_sym_BREAK] = ACTIONS(6308),
    [anon_sym_Break] = ACTIONS(6308),
    [anon_sym_with] = ACTIONS(6308),
    [anon_sym_WITH] = ACTIONS(6308),
    [anon_sym_With] = ACTIONS(6308),
    [sym_asserterror_keyword] = ACTIONS(6310),
    [sym_page_keyword] = ACTIONS(6308),
    [anon_sym_codeunit] = ACTIONS(6308),
    [anon_sym_CODEUNIT] = ACTIONS(6308),
    [anon_sym_Codeunit] = ACTIONS(6308),
    [anon_sym_CodeUnit] = ACTIONS(6308),
    [anon_sym_COdeunit] = ACTIONS(6308),
    [anon_sym_codeUnit] = ACTIONS(6308),
    [sym_report_keyword] = ACTIONS(6308),
    [sym_query_keyword] = ACTIONS(6308),
    [anon_sym_xmlport] = ACTIONS(6308),
    [anon_sym_XMLPORT] = ACTIONS(6308),
    [anon_sym_Xmlport] = ACTIONS(6308),
    [anon_sym_XMLport] = ACTIONS(6308),
    [anon_sym_XMLPort] = ACTIONS(6308),
    [anon_sym_XmlPort] = ACTIONS(6308),
    [anon_sym_enum] = ACTIONS(6308),
    [anon_sym_ENUM] = ACTIONS(6308),
    [anon_sym_Enum] = ACTIONS(6308),
    [anon_sym_eNUM] = ACTIONS(6308),
    [anon_sym_eNum] = ACTIONS(6308),
    [anon_sym_ENum] = ACTIONS(6308),
    [sym_quoted_identifier] = ACTIONS(6310),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6310),
    [sym_verbatim_string] = ACTIONS(6310),
    [sym_integer] = ACTIONS(6308),
    [sym_continue_as_identifier] = ACTIONS(6310),
    [sym_preproc_open] = ACTIONS(6310),
    [sym_preproc_close] = ACTIONS(6310),
  },
  [STATE(2617)] = {
    [sym_identifier] = ACTIONS(6312),
    [anon_sym_SEMI] = ACTIONS(6314),
    [anon_sym_DASH] = ACTIONS(6314),
    [aux_sym_boolean_token1] = ACTIONS(6312),
    [aux_sym_boolean_token2] = ACTIONS(6312),
    [sym_decimal] = ACTIONS(6312),
    [anon_sym_LPAREN] = ACTIONS(6314),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6312),
    [anon_sym_LBRACK] = ACTIONS(6314),
    [aux_sym_record_type_token1] = ACTIONS(6312),
    [aux_sym_basic_type_token21] = ACTIONS(6312),
    [aux_sym_basic_type_token22] = ACTIONS(6312),
    [aux_sym_basic_type_token48] = ACTIONS(6312),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6312),
    [anon_sym_POUNDif] = ACTIONS(6314),
    [anon_sym_POUNDIF] = ACTIONS(6314),
    [anon_sym_POUNDIf] = ACTIONS(6314),
    [anon_sym_not] = ACTIONS(6312),
    [anon_sym_NOT] = ACTIONS(6312),
    [anon_sym_Not] = ACTIONS(6312),
    [anon_sym_POUNDelif] = ACTIONS(6314),
    [anon_sym_POUNDELIF] = ACTIONS(6314),
    [anon_sym_POUNDElif] = ACTIONS(6314),
    [anon_sym_POUNDelse] = ACTIONS(6314),
    [anon_sym_POUNDELSE] = ACTIONS(6314),
    [anon_sym_POUNDElse] = ACTIONS(6314),
    [anon_sym_POUNDelse2] = ACTIONS(6314),
    [anon_sym_POUNDELSE2] = ACTIONS(6314),
    [anon_sym_POUNDElse2] = ACTIONS(6314),
    [anon_sym_POUNDendif] = ACTIONS(6314),
    [anon_sym_POUNDENDIF] = ACTIONS(6314),
    [anon_sym_POUNDEndif] = ACTIONS(6314),
    [anon_sym_POUNDendif2] = ACTIONS(6314),
    [anon_sym_POUNDENDIF2] = ACTIONS(6314),
    [anon_sym_POUNDEndif2] = ACTIONS(6314),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6312),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6312),
    [anon_sym_PLUS] = ACTIONS(6314),
    [sym_datetime_literal] = ACTIONS(6314),
    [sym_date_literal] = ACTIONS(6312),
    [sym_time_literal] = ACTIONS(6312),
    [sym_biginteger_literal] = ACTIONS(6314),
    [anon_sym_if] = ACTIONS(6312),
    [anon_sym_IF] = ACTIONS(6312),
    [anon_sym_If] = ACTIONS(6312),
    [anon_sym_else] = ACTIONS(6312),
    [anon_sym_ELSE] = ACTIONS(6312),
    [anon_sym_Else] = ACTIONS(6312),
    [anon_sym_case] = ACTIONS(6312),
    [anon_sym_CASE] = ACTIONS(6312),
    [anon_sym_Case] = ACTIONS(6312),
    [anon_sym_for] = ACTIONS(6312),
    [anon_sym_FOR] = ACTIONS(6312),
    [anon_sym_For] = ACTIONS(6312),
    [anon_sym_foreach] = ACTIONS(6312),
    [anon_sym_FOREACH] = ACTIONS(6312),
    [anon_sym_Foreach] = ACTIONS(6312),
    [anon_sym_while] = ACTIONS(6312),
    [anon_sym_WHILE] = ACTIONS(6312),
    [anon_sym_While] = ACTIONS(6312),
    [anon_sym_repeat] = ACTIONS(6312),
    [anon_sym_REPEAT] = ACTIONS(6312),
    [anon_sym_Repeat] = ACTIONS(6312),
    [anon_sym_exit] = ACTIONS(6312),
    [anon_sym_EXIT] = ACTIONS(6312),
    [anon_sym_Exit] = ACTIONS(6312),
    [anon_sym_continue] = ACTIONS(6312),
    [anon_sym_CONTINUE] = ACTIONS(6312),
    [anon_sym_Continue] = ACTIONS(6312),
    [anon_sym_break] = ACTIONS(6312),
    [anon_sym_BREAK] = ACTIONS(6312),
    [anon_sym_Break] = ACTIONS(6312),
    [anon_sym_with] = ACTIONS(6312),
    [anon_sym_WITH] = ACTIONS(6312),
    [anon_sym_With] = ACTIONS(6312),
    [sym_asserterror_keyword] = ACTIONS(6314),
    [sym_page_keyword] = ACTIONS(6312),
    [anon_sym_codeunit] = ACTIONS(6312),
    [anon_sym_CODEUNIT] = ACTIONS(6312),
    [anon_sym_Codeunit] = ACTIONS(6312),
    [anon_sym_CodeUnit] = ACTIONS(6312),
    [anon_sym_COdeunit] = ACTIONS(6312),
    [anon_sym_codeUnit] = ACTIONS(6312),
    [sym_report_keyword] = ACTIONS(6312),
    [sym_query_keyword] = ACTIONS(6312),
    [anon_sym_xmlport] = ACTIONS(6312),
    [anon_sym_XMLPORT] = ACTIONS(6312),
    [anon_sym_Xmlport] = ACTIONS(6312),
    [anon_sym_XMLport] = ACTIONS(6312),
    [anon_sym_XMLPort] = ACTIONS(6312),
    [anon_sym_XmlPort] = ACTIONS(6312),
    [anon_sym_enum] = ACTIONS(6312),
    [anon_sym_ENUM] = ACTIONS(6312),
    [anon_sym_Enum] = ACTIONS(6312),
    [anon_sym_eNUM] = ACTIONS(6312),
    [anon_sym_eNum] = ACTIONS(6312),
    [anon_sym_ENum] = ACTIONS(6312),
    [sym_quoted_identifier] = ACTIONS(6314),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6314),
    [sym_verbatim_string] = ACTIONS(6314),
    [sym_integer] = ACTIONS(6312),
    [sym_continue_as_identifier] = ACTIONS(6314),
    [sym_preproc_open] = ACTIONS(6314),
    [sym_preproc_close] = ACTIONS(6314),
  },
  [STATE(2618)] = {
    [sym_identifier] = ACTIONS(6308),
    [anon_sym_SEMI] = ACTIONS(6310),
    [anon_sym_DASH] = ACTIONS(6310),
    [aux_sym_boolean_token1] = ACTIONS(6308),
    [aux_sym_boolean_token2] = ACTIONS(6308),
    [sym_decimal] = ACTIONS(6308),
    [anon_sym_LPAREN] = ACTIONS(6310),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6308),
    [anon_sym_LBRACK] = ACTIONS(6310),
    [aux_sym_record_type_token1] = ACTIONS(6308),
    [aux_sym_basic_type_token21] = ACTIONS(6308),
    [aux_sym_basic_type_token22] = ACTIONS(6308),
    [aux_sym_basic_type_token48] = ACTIONS(6308),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6308),
    [anon_sym_POUNDif] = ACTIONS(6310),
    [anon_sym_POUNDIF] = ACTIONS(6310),
    [anon_sym_POUNDIf] = ACTIONS(6310),
    [anon_sym_not] = ACTIONS(6308),
    [anon_sym_NOT] = ACTIONS(6308),
    [anon_sym_Not] = ACTIONS(6308),
    [anon_sym_POUNDelif] = ACTIONS(6310),
    [anon_sym_POUNDELIF] = ACTIONS(6310),
    [anon_sym_POUNDElif] = ACTIONS(6310),
    [anon_sym_POUNDelse] = ACTIONS(6310),
    [anon_sym_POUNDELSE] = ACTIONS(6310),
    [anon_sym_POUNDElse] = ACTIONS(6310),
    [anon_sym_POUNDelse2] = ACTIONS(6310),
    [anon_sym_POUNDELSE2] = ACTIONS(6310),
    [anon_sym_POUNDElse2] = ACTIONS(6310),
    [anon_sym_POUNDendif] = ACTIONS(6310),
    [anon_sym_POUNDENDIF] = ACTIONS(6310),
    [anon_sym_POUNDEndif] = ACTIONS(6310),
    [anon_sym_POUNDendif2] = ACTIONS(6310),
    [anon_sym_POUNDENDIF2] = ACTIONS(6310),
    [anon_sym_POUNDEndif2] = ACTIONS(6310),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6308),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6308),
    [anon_sym_PLUS] = ACTIONS(6310),
    [sym_datetime_literal] = ACTIONS(6310),
    [sym_date_literal] = ACTIONS(6308),
    [sym_time_literal] = ACTIONS(6308),
    [sym_biginteger_literal] = ACTIONS(6310),
    [anon_sym_if] = ACTIONS(6308),
    [anon_sym_IF] = ACTIONS(6308),
    [anon_sym_If] = ACTIONS(6308),
    [anon_sym_else] = ACTIONS(6308),
    [anon_sym_ELSE] = ACTIONS(6308),
    [anon_sym_Else] = ACTIONS(6308),
    [anon_sym_case] = ACTIONS(6308),
    [anon_sym_CASE] = ACTIONS(6308),
    [anon_sym_Case] = ACTIONS(6308),
    [anon_sym_for] = ACTIONS(6308),
    [anon_sym_FOR] = ACTIONS(6308),
    [anon_sym_For] = ACTIONS(6308),
    [anon_sym_foreach] = ACTIONS(6308),
    [anon_sym_FOREACH] = ACTIONS(6308),
    [anon_sym_Foreach] = ACTIONS(6308),
    [anon_sym_while] = ACTIONS(6308),
    [anon_sym_WHILE] = ACTIONS(6308),
    [anon_sym_While] = ACTIONS(6308),
    [anon_sym_repeat] = ACTIONS(6308),
    [anon_sym_REPEAT] = ACTIONS(6308),
    [anon_sym_Repeat] = ACTIONS(6308),
    [anon_sym_exit] = ACTIONS(6308),
    [anon_sym_EXIT] = ACTIONS(6308),
    [anon_sym_Exit] = ACTIONS(6308),
    [anon_sym_continue] = ACTIONS(6308),
    [anon_sym_CONTINUE] = ACTIONS(6308),
    [anon_sym_Continue] = ACTIONS(6308),
    [anon_sym_break] = ACTIONS(6308),
    [anon_sym_BREAK] = ACTIONS(6308),
    [anon_sym_Break] = ACTIONS(6308),
    [anon_sym_with] = ACTIONS(6308),
    [anon_sym_WITH] = ACTIONS(6308),
    [anon_sym_With] = ACTIONS(6308),
    [sym_asserterror_keyword] = ACTIONS(6310),
    [sym_page_keyword] = ACTIONS(6308),
    [anon_sym_codeunit] = ACTIONS(6308),
    [anon_sym_CODEUNIT] = ACTIONS(6308),
    [anon_sym_Codeunit] = ACTIONS(6308),
    [anon_sym_CodeUnit] = ACTIONS(6308),
    [anon_sym_COdeunit] = ACTIONS(6308),
    [anon_sym_codeUnit] = ACTIONS(6308),
    [sym_report_keyword] = ACTIONS(6308),
    [sym_query_keyword] = ACTIONS(6308),
    [anon_sym_xmlport] = ACTIONS(6308),
    [anon_sym_XMLPORT] = ACTIONS(6308),
    [anon_sym_Xmlport] = ACTIONS(6308),
    [anon_sym_XMLport] = ACTIONS(6308),
    [anon_sym_XMLPort] = ACTIONS(6308),
    [anon_sym_XmlPort] = ACTIONS(6308),
    [anon_sym_enum] = ACTIONS(6308),
    [anon_sym_ENUM] = ACTIONS(6308),
    [anon_sym_Enum] = ACTIONS(6308),
    [anon_sym_eNUM] = ACTIONS(6308),
    [anon_sym_eNum] = ACTIONS(6308),
    [anon_sym_ENum] = ACTIONS(6308),
    [sym_quoted_identifier] = ACTIONS(6310),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6310),
    [sym_verbatim_string] = ACTIONS(6310),
    [sym_integer] = ACTIONS(6308),
    [sym_continue_as_identifier] = ACTIONS(6310),
    [sym_preproc_open] = ACTIONS(6310),
    [sym_preproc_close] = ACTIONS(6310),
  },
  [STATE(2619)] = {
    [sym_identifier] = ACTIONS(6316),
    [anon_sym_SEMI] = ACTIONS(6318),
    [anon_sym_DASH] = ACTIONS(6318),
    [aux_sym_boolean_token1] = ACTIONS(6316),
    [aux_sym_boolean_token2] = ACTIONS(6316),
    [sym_decimal] = ACTIONS(6316),
    [anon_sym_LPAREN] = ACTIONS(6318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6316),
    [anon_sym_LBRACK] = ACTIONS(6318),
    [aux_sym_record_type_token1] = ACTIONS(6316),
    [aux_sym_basic_type_token21] = ACTIONS(6316),
    [aux_sym_basic_type_token22] = ACTIONS(6316),
    [aux_sym_basic_type_token48] = ACTIONS(6316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6316),
    [anon_sym_POUNDif] = ACTIONS(6318),
    [anon_sym_POUNDIF] = ACTIONS(6318),
    [anon_sym_POUNDIf] = ACTIONS(6318),
    [anon_sym_not] = ACTIONS(6316),
    [anon_sym_NOT] = ACTIONS(6316),
    [anon_sym_Not] = ACTIONS(6316),
    [anon_sym_POUNDelif] = ACTIONS(6318),
    [anon_sym_POUNDELIF] = ACTIONS(6318),
    [anon_sym_POUNDElif] = ACTIONS(6318),
    [anon_sym_POUNDelse] = ACTIONS(6318),
    [anon_sym_POUNDELSE] = ACTIONS(6318),
    [anon_sym_POUNDElse] = ACTIONS(6318),
    [anon_sym_POUNDelse2] = ACTIONS(6318),
    [anon_sym_POUNDELSE2] = ACTIONS(6318),
    [anon_sym_POUNDElse2] = ACTIONS(6318),
    [anon_sym_POUNDendif] = ACTIONS(6318),
    [anon_sym_POUNDENDIF] = ACTIONS(6318),
    [anon_sym_POUNDEndif] = ACTIONS(6318),
    [anon_sym_POUNDendif2] = ACTIONS(6318),
    [anon_sym_POUNDENDIF2] = ACTIONS(6318),
    [anon_sym_POUNDEndif2] = ACTIONS(6318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6316),
    [anon_sym_PLUS] = ACTIONS(6318),
    [sym_datetime_literal] = ACTIONS(6318),
    [sym_date_literal] = ACTIONS(6316),
    [sym_time_literal] = ACTIONS(6316),
    [sym_biginteger_literal] = ACTIONS(6318),
    [anon_sym_if] = ACTIONS(6316),
    [anon_sym_IF] = ACTIONS(6316),
    [anon_sym_If] = ACTIONS(6316),
    [anon_sym_else] = ACTIONS(6316),
    [anon_sym_ELSE] = ACTIONS(6316),
    [anon_sym_Else] = ACTIONS(6316),
    [anon_sym_case] = ACTIONS(6316),
    [anon_sym_CASE] = ACTIONS(6316),
    [anon_sym_Case] = ACTIONS(6316),
    [anon_sym_for] = ACTIONS(6316),
    [anon_sym_FOR] = ACTIONS(6316),
    [anon_sym_For] = ACTIONS(6316),
    [anon_sym_foreach] = ACTIONS(6316),
    [anon_sym_FOREACH] = ACTIONS(6316),
    [anon_sym_Foreach] = ACTIONS(6316),
    [anon_sym_while] = ACTIONS(6316),
    [anon_sym_WHILE] = ACTIONS(6316),
    [anon_sym_While] = ACTIONS(6316),
    [anon_sym_repeat] = ACTIONS(6316),
    [anon_sym_REPEAT] = ACTIONS(6316),
    [anon_sym_Repeat] = ACTIONS(6316),
    [anon_sym_exit] = ACTIONS(6316),
    [anon_sym_EXIT] = ACTIONS(6316),
    [anon_sym_Exit] = ACTIONS(6316),
    [anon_sym_continue] = ACTIONS(6316),
    [anon_sym_CONTINUE] = ACTIONS(6316),
    [anon_sym_Continue] = ACTIONS(6316),
    [anon_sym_break] = ACTIONS(6316),
    [anon_sym_BREAK] = ACTIONS(6316),
    [anon_sym_Break] = ACTIONS(6316),
    [anon_sym_with] = ACTIONS(6316),
    [anon_sym_WITH] = ACTIONS(6316),
    [anon_sym_With] = ACTIONS(6316),
    [sym_asserterror_keyword] = ACTIONS(6318),
    [sym_page_keyword] = ACTIONS(6316),
    [anon_sym_codeunit] = ACTIONS(6316),
    [anon_sym_CODEUNIT] = ACTIONS(6316),
    [anon_sym_Codeunit] = ACTIONS(6316),
    [anon_sym_CodeUnit] = ACTIONS(6316),
    [anon_sym_COdeunit] = ACTIONS(6316),
    [anon_sym_codeUnit] = ACTIONS(6316),
    [sym_report_keyword] = ACTIONS(6316),
    [sym_query_keyword] = ACTIONS(6316),
    [anon_sym_xmlport] = ACTIONS(6316),
    [anon_sym_XMLPORT] = ACTIONS(6316),
    [anon_sym_Xmlport] = ACTIONS(6316),
    [anon_sym_XMLport] = ACTIONS(6316),
    [anon_sym_XMLPort] = ACTIONS(6316),
    [anon_sym_XmlPort] = ACTIONS(6316),
    [anon_sym_enum] = ACTIONS(6316),
    [anon_sym_ENUM] = ACTIONS(6316),
    [anon_sym_Enum] = ACTIONS(6316),
    [anon_sym_eNUM] = ACTIONS(6316),
    [anon_sym_eNum] = ACTIONS(6316),
    [anon_sym_ENum] = ACTIONS(6316),
    [sym_quoted_identifier] = ACTIONS(6318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6318),
    [sym_verbatim_string] = ACTIONS(6318),
    [sym_integer] = ACTIONS(6316),
    [sym_continue_as_identifier] = ACTIONS(6318),
    [sym_preproc_open] = ACTIONS(6318),
    [sym_preproc_close] = ACTIONS(6318),
  },
  [STATE(2620)] = {
    [sym_identifier] = ACTIONS(6320),
    [anon_sym_SEMI] = ACTIONS(6322),
    [anon_sym_DASH] = ACTIONS(6322),
    [aux_sym_boolean_token1] = ACTIONS(6320),
    [aux_sym_boolean_token2] = ACTIONS(6320),
    [sym_decimal] = ACTIONS(6320),
    [anon_sym_LPAREN] = ACTIONS(6322),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6320),
    [anon_sym_LBRACK] = ACTIONS(6322),
    [aux_sym_record_type_token1] = ACTIONS(6320),
    [aux_sym_basic_type_token21] = ACTIONS(6320),
    [aux_sym_basic_type_token22] = ACTIONS(6320),
    [aux_sym_basic_type_token48] = ACTIONS(6320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6320),
    [anon_sym_POUNDif] = ACTIONS(6322),
    [anon_sym_POUNDIF] = ACTIONS(6322),
    [anon_sym_POUNDIf] = ACTIONS(6322),
    [anon_sym_not] = ACTIONS(6320),
    [anon_sym_NOT] = ACTIONS(6320),
    [anon_sym_Not] = ACTIONS(6320),
    [anon_sym_POUNDelif] = ACTIONS(6322),
    [anon_sym_POUNDELIF] = ACTIONS(6322),
    [anon_sym_POUNDElif] = ACTIONS(6322),
    [anon_sym_POUNDelse] = ACTIONS(6322),
    [anon_sym_POUNDELSE] = ACTIONS(6322),
    [anon_sym_POUNDElse] = ACTIONS(6322),
    [anon_sym_POUNDelse2] = ACTIONS(6322),
    [anon_sym_POUNDELSE2] = ACTIONS(6322),
    [anon_sym_POUNDElse2] = ACTIONS(6322),
    [anon_sym_POUNDendif] = ACTIONS(6322),
    [anon_sym_POUNDENDIF] = ACTIONS(6322),
    [anon_sym_POUNDEndif] = ACTIONS(6322),
    [anon_sym_POUNDendif2] = ACTIONS(6322),
    [anon_sym_POUNDENDIF2] = ACTIONS(6322),
    [anon_sym_POUNDEndif2] = ACTIONS(6322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6320),
    [anon_sym_PLUS] = ACTIONS(6322),
    [sym_datetime_literal] = ACTIONS(6322),
    [sym_date_literal] = ACTIONS(6320),
    [sym_time_literal] = ACTIONS(6320),
    [sym_biginteger_literal] = ACTIONS(6322),
    [anon_sym_if] = ACTIONS(6320),
    [anon_sym_IF] = ACTIONS(6320),
    [anon_sym_If] = ACTIONS(6320),
    [anon_sym_else] = ACTIONS(6320),
    [anon_sym_ELSE] = ACTIONS(6320),
    [anon_sym_Else] = ACTIONS(6320),
    [anon_sym_case] = ACTIONS(6320),
    [anon_sym_CASE] = ACTIONS(6320),
    [anon_sym_Case] = ACTIONS(6320),
    [anon_sym_for] = ACTIONS(6320),
    [anon_sym_FOR] = ACTIONS(6320),
    [anon_sym_For] = ACTIONS(6320),
    [anon_sym_foreach] = ACTIONS(6320),
    [anon_sym_FOREACH] = ACTIONS(6320),
    [anon_sym_Foreach] = ACTIONS(6320),
    [anon_sym_while] = ACTIONS(6320),
    [anon_sym_WHILE] = ACTIONS(6320),
    [anon_sym_While] = ACTIONS(6320),
    [anon_sym_repeat] = ACTIONS(6320),
    [anon_sym_REPEAT] = ACTIONS(6320),
    [anon_sym_Repeat] = ACTIONS(6320),
    [anon_sym_exit] = ACTIONS(6320),
    [anon_sym_EXIT] = ACTIONS(6320),
    [anon_sym_Exit] = ACTIONS(6320),
    [anon_sym_continue] = ACTIONS(6320),
    [anon_sym_CONTINUE] = ACTIONS(6320),
    [anon_sym_Continue] = ACTIONS(6320),
    [anon_sym_break] = ACTIONS(6320),
    [anon_sym_BREAK] = ACTIONS(6320),
    [anon_sym_Break] = ACTIONS(6320),
    [anon_sym_with] = ACTIONS(6320),
    [anon_sym_WITH] = ACTIONS(6320),
    [anon_sym_With] = ACTIONS(6320),
    [sym_asserterror_keyword] = ACTIONS(6322),
    [sym_page_keyword] = ACTIONS(6320),
    [anon_sym_codeunit] = ACTIONS(6320),
    [anon_sym_CODEUNIT] = ACTIONS(6320),
    [anon_sym_Codeunit] = ACTIONS(6320),
    [anon_sym_CodeUnit] = ACTIONS(6320),
    [anon_sym_COdeunit] = ACTIONS(6320),
    [anon_sym_codeUnit] = ACTIONS(6320),
    [sym_report_keyword] = ACTIONS(6320),
    [sym_query_keyword] = ACTIONS(6320),
    [anon_sym_xmlport] = ACTIONS(6320),
    [anon_sym_XMLPORT] = ACTIONS(6320),
    [anon_sym_Xmlport] = ACTIONS(6320),
    [anon_sym_XMLport] = ACTIONS(6320),
    [anon_sym_XMLPort] = ACTIONS(6320),
    [anon_sym_XmlPort] = ACTIONS(6320),
    [anon_sym_enum] = ACTIONS(6320),
    [anon_sym_ENUM] = ACTIONS(6320),
    [anon_sym_Enum] = ACTIONS(6320),
    [anon_sym_eNUM] = ACTIONS(6320),
    [anon_sym_eNum] = ACTIONS(6320),
    [anon_sym_ENum] = ACTIONS(6320),
    [sym_quoted_identifier] = ACTIONS(6322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6322),
    [sym_verbatim_string] = ACTIONS(6322),
    [sym_integer] = ACTIONS(6320),
    [sym_continue_as_identifier] = ACTIONS(6322),
    [sym_preproc_open] = ACTIONS(6322),
    [sym_preproc_close] = ACTIONS(6322),
  },
  [STATE(2621)] = {
    [sym_identifier] = ACTIONS(6316),
    [anon_sym_SEMI] = ACTIONS(6318),
    [anon_sym_DASH] = ACTIONS(6318),
    [aux_sym_boolean_token1] = ACTIONS(6316),
    [aux_sym_boolean_token2] = ACTIONS(6316),
    [sym_decimal] = ACTIONS(6316),
    [anon_sym_LPAREN] = ACTIONS(6318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6316),
    [anon_sym_LBRACK] = ACTIONS(6318),
    [aux_sym_record_type_token1] = ACTIONS(6316),
    [aux_sym_basic_type_token21] = ACTIONS(6316),
    [aux_sym_basic_type_token22] = ACTIONS(6316),
    [aux_sym_basic_type_token48] = ACTIONS(6316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6316),
    [anon_sym_POUNDif] = ACTIONS(6318),
    [anon_sym_POUNDIF] = ACTIONS(6318),
    [anon_sym_POUNDIf] = ACTIONS(6318),
    [anon_sym_not] = ACTIONS(6316),
    [anon_sym_NOT] = ACTIONS(6316),
    [anon_sym_Not] = ACTIONS(6316),
    [anon_sym_POUNDelif] = ACTIONS(6318),
    [anon_sym_POUNDELIF] = ACTIONS(6318),
    [anon_sym_POUNDElif] = ACTIONS(6318),
    [anon_sym_POUNDelse] = ACTIONS(6318),
    [anon_sym_POUNDELSE] = ACTIONS(6318),
    [anon_sym_POUNDElse] = ACTIONS(6318),
    [anon_sym_POUNDelse2] = ACTIONS(6318),
    [anon_sym_POUNDELSE2] = ACTIONS(6318),
    [anon_sym_POUNDElse2] = ACTIONS(6318),
    [anon_sym_POUNDendif] = ACTIONS(6318),
    [anon_sym_POUNDENDIF] = ACTIONS(6318),
    [anon_sym_POUNDEndif] = ACTIONS(6318),
    [anon_sym_POUNDendif2] = ACTIONS(6318),
    [anon_sym_POUNDENDIF2] = ACTIONS(6318),
    [anon_sym_POUNDEndif2] = ACTIONS(6318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6316),
    [anon_sym_PLUS] = ACTIONS(6318),
    [sym_datetime_literal] = ACTIONS(6318),
    [sym_date_literal] = ACTIONS(6316),
    [sym_time_literal] = ACTIONS(6316),
    [sym_biginteger_literal] = ACTIONS(6318),
    [anon_sym_if] = ACTIONS(6316),
    [anon_sym_IF] = ACTIONS(6316),
    [anon_sym_If] = ACTIONS(6316),
    [anon_sym_else] = ACTIONS(6316),
    [anon_sym_ELSE] = ACTIONS(6316),
    [anon_sym_Else] = ACTIONS(6316),
    [anon_sym_case] = ACTIONS(6316),
    [anon_sym_CASE] = ACTIONS(6316),
    [anon_sym_Case] = ACTIONS(6316),
    [anon_sym_for] = ACTIONS(6316),
    [anon_sym_FOR] = ACTIONS(6316),
    [anon_sym_For] = ACTIONS(6316),
    [anon_sym_foreach] = ACTIONS(6316),
    [anon_sym_FOREACH] = ACTIONS(6316),
    [anon_sym_Foreach] = ACTIONS(6316),
    [anon_sym_while] = ACTIONS(6316),
    [anon_sym_WHILE] = ACTIONS(6316),
    [anon_sym_While] = ACTIONS(6316),
    [anon_sym_repeat] = ACTIONS(6316),
    [anon_sym_REPEAT] = ACTIONS(6316),
    [anon_sym_Repeat] = ACTIONS(6316),
    [anon_sym_exit] = ACTIONS(6316),
    [anon_sym_EXIT] = ACTIONS(6316),
    [anon_sym_Exit] = ACTIONS(6316),
    [anon_sym_continue] = ACTIONS(6316),
    [anon_sym_CONTINUE] = ACTIONS(6316),
    [anon_sym_Continue] = ACTIONS(6316),
    [anon_sym_break] = ACTIONS(6316),
    [anon_sym_BREAK] = ACTIONS(6316),
    [anon_sym_Break] = ACTIONS(6316),
    [anon_sym_with] = ACTIONS(6316),
    [anon_sym_WITH] = ACTIONS(6316),
    [anon_sym_With] = ACTIONS(6316),
    [sym_asserterror_keyword] = ACTIONS(6318),
    [sym_page_keyword] = ACTIONS(6316),
    [anon_sym_codeunit] = ACTIONS(6316),
    [anon_sym_CODEUNIT] = ACTIONS(6316),
    [anon_sym_Codeunit] = ACTIONS(6316),
    [anon_sym_CodeUnit] = ACTIONS(6316),
    [anon_sym_COdeunit] = ACTIONS(6316),
    [anon_sym_codeUnit] = ACTIONS(6316),
    [sym_report_keyword] = ACTIONS(6316),
    [sym_query_keyword] = ACTIONS(6316),
    [anon_sym_xmlport] = ACTIONS(6316),
    [anon_sym_XMLPORT] = ACTIONS(6316),
    [anon_sym_Xmlport] = ACTIONS(6316),
    [anon_sym_XMLport] = ACTIONS(6316),
    [anon_sym_XMLPort] = ACTIONS(6316),
    [anon_sym_XmlPort] = ACTIONS(6316),
    [anon_sym_enum] = ACTIONS(6316),
    [anon_sym_ENUM] = ACTIONS(6316),
    [anon_sym_Enum] = ACTIONS(6316),
    [anon_sym_eNUM] = ACTIONS(6316),
    [anon_sym_eNum] = ACTIONS(6316),
    [anon_sym_ENum] = ACTIONS(6316),
    [sym_quoted_identifier] = ACTIONS(6318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6318),
    [sym_verbatim_string] = ACTIONS(6318),
    [sym_integer] = ACTIONS(6316),
    [sym_continue_as_identifier] = ACTIONS(6318),
    [sym_preproc_open] = ACTIONS(6318),
    [sym_preproc_close] = ACTIONS(6318),
  },
  [STATE(2622)] = {
    [sym_identifier] = ACTIONS(6324),
    [anon_sym_SEMI] = ACTIONS(6326),
    [anon_sym_DASH] = ACTIONS(6326),
    [aux_sym_boolean_token1] = ACTIONS(6324),
    [aux_sym_boolean_token2] = ACTIONS(6324),
    [sym_decimal] = ACTIONS(6324),
    [anon_sym_LPAREN] = ACTIONS(6326),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6324),
    [anon_sym_LBRACK] = ACTIONS(6326),
    [aux_sym_record_type_token1] = ACTIONS(6324),
    [aux_sym_basic_type_token21] = ACTIONS(6324),
    [aux_sym_basic_type_token22] = ACTIONS(6324),
    [aux_sym_basic_type_token48] = ACTIONS(6324),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6324),
    [anon_sym_POUNDif] = ACTIONS(6326),
    [anon_sym_POUNDIF] = ACTIONS(6326),
    [anon_sym_POUNDIf] = ACTIONS(6326),
    [anon_sym_not] = ACTIONS(6324),
    [anon_sym_NOT] = ACTIONS(6324),
    [anon_sym_Not] = ACTIONS(6324),
    [anon_sym_POUNDelif] = ACTIONS(6326),
    [anon_sym_POUNDELIF] = ACTIONS(6326),
    [anon_sym_POUNDElif] = ACTIONS(6326),
    [anon_sym_POUNDelse] = ACTIONS(6326),
    [anon_sym_POUNDELSE] = ACTIONS(6326),
    [anon_sym_POUNDElse] = ACTIONS(6326),
    [anon_sym_POUNDelse2] = ACTIONS(6326),
    [anon_sym_POUNDELSE2] = ACTIONS(6326),
    [anon_sym_POUNDElse2] = ACTIONS(6326),
    [anon_sym_POUNDendif] = ACTIONS(6326),
    [anon_sym_POUNDENDIF] = ACTIONS(6326),
    [anon_sym_POUNDEndif] = ACTIONS(6326),
    [anon_sym_POUNDendif2] = ACTIONS(6326),
    [anon_sym_POUNDENDIF2] = ACTIONS(6326),
    [anon_sym_POUNDEndif2] = ACTIONS(6326),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6324),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6324),
    [anon_sym_PLUS] = ACTIONS(6326),
    [sym_datetime_literal] = ACTIONS(6326),
    [sym_date_literal] = ACTIONS(6324),
    [sym_time_literal] = ACTIONS(6324),
    [sym_biginteger_literal] = ACTIONS(6326),
    [anon_sym_if] = ACTIONS(6324),
    [anon_sym_IF] = ACTIONS(6324),
    [anon_sym_If] = ACTIONS(6324),
    [anon_sym_else] = ACTIONS(6324),
    [anon_sym_ELSE] = ACTIONS(6324),
    [anon_sym_Else] = ACTIONS(6324),
    [anon_sym_case] = ACTIONS(6324),
    [anon_sym_CASE] = ACTIONS(6324),
    [anon_sym_Case] = ACTIONS(6324),
    [anon_sym_for] = ACTIONS(6324),
    [anon_sym_FOR] = ACTIONS(6324),
    [anon_sym_For] = ACTIONS(6324),
    [anon_sym_foreach] = ACTIONS(6324),
    [anon_sym_FOREACH] = ACTIONS(6324),
    [anon_sym_Foreach] = ACTIONS(6324),
    [anon_sym_while] = ACTIONS(6324),
    [anon_sym_WHILE] = ACTIONS(6324),
    [anon_sym_While] = ACTIONS(6324),
    [anon_sym_repeat] = ACTIONS(6324),
    [anon_sym_REPEAT] = ACTIONS(6324),
    [anon_sym_Repeat] = ACTIONS(6324),
    [anon_sym_exit] = ACTIONS(6324),
    [anon_sym_EXIT] = ACTIONS(6324),
    [anon_sym_Exit] = ACTIONS(6324),
    [anon_sym_continue] = ACTIONS(6324),
    [anon_sym_CONTINUE] = ACTIONS(6324),
    [anon_sym_Continue] = ACTIONS(6324),
    [anon_sym_break] = ACTIONS(6324),
    [anon_sym_BREAK] = ACTIONS(6324),
    [anon_sym_Break] = ACTIONS(6324),
    [anon_sym_with] = ACTIONS(6324),
    [anon_sym_WITH] = ACTIONS(6324),
    [anon_sym_With] = ACTIONS(6324),
    [sym_asserterror_keyword] = ACTIONS(6326),
    [sym_page_keyword] = ACTIONS(6324),
    [anon_sym_codeunit] = ACTIONS(6324),
    [anon_sym_CODEUNIT] = ACTIONS(6324),
    [anon_sym_Codeunit] = ACTIONS(6324),
    [anon_sym_CodeUnit] = ACTIONS(6324),
    [anon_sym_COdeunit] = ACTIONS(6324),
    [anon_sym_codeUnit] = ACTIONS(6324),
    [sym_report_keyword] = ACTIONS(6324),
    [sym_query_keyword] = ACTIONS(6324),
    [anon_sym_xmlport] = ACTIONS(6324),
    [anon_sym_XMLPORT] = ACTIONS(6324),
    [anon_sym_Xmlport] = ACTIONS(6324),
    [anon_sym_XMLport] = ACTIONS(6324),
    [anon_sym_XMLPort] = ACTIONS(6324),
    [anon_sym_XmlPort] = ACTIONS(6324),
    [anon_sym_enum] = ACTIONS(6324),
    [anon_sym_ENUM] = ACTIONS(6324),
    [anon_sym_Enum] = ACTIONS(6324),
    [anon_sym_eNUM] = ACTIONS(6324),
    [anon_sym_eNum] = ACTIONS(6324),
    [anon_sym_ENum] = ACTIONS(6324),
    [sym_quoted_identifier] = ACTIONS(6326),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6326),
    [sym_verbatim_string] = ACTIONS(6326),
    [sym_integer] = ACTIONS(6324),
    [sym_continue_as_identifier] = ACTIONS(6326),
    [sym_preproc_open] = ACTIONS(6326),
    [sym_preproc_close] = ACTIONS(6326),
  },
  [STATE(2623)] = {
    [sym_identifier] = ACTIONS(6328),
    [anon_sym_SEMI] = ACTIONS(6330),
    [anon_sym_DASH] = ACTIONS(6330),
    [aux_sym_boolean_token1] = ACTIONS(6328),
    [aux_sym_boolean_token2] = ACTIONS(6328),
    [sym_decimal] = ACTIONS(6328),
    [anon_sym_LPAREN] = ACTIONS(6330),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6328),
    [anon_sym_LBRACK] = ACTIONS(6330),
    [aux_sym_record_type_token1] = ACTIONS(6328),
    [aux_sym_basic_type_token21] = ACTIONS(6328),
    [aux_sym_basic_type_token22] = ACTIONS(6328),
    [aux_sym_basic_type_token48] = ACTIONS(6328),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6328),
    [anon_sym_POUNDif] = ACTIONS(6330),
    [anon_sym_POUNDIF] = ACTIONS(6330),
    [anon_sym_POUNDIf] = ACTIONS(6330),
    [anon_sym_not] = ACTIONS(6328),
    [anon_sym_NOT] = ACTIONS(6328),
    [anon_sym_Not] = ACTIONS(6328),
    [anon_sym_POUNDelif] = ACTIONS(6330),
    [anon_sym_POUNDELIF] = ACTIONS(6330),
    [anon_sym_POUNDElif] = ACTIONS(6330),
    [anon_sym_POUNDelse] = ACTIONS(6330),
    [anon_sym_POUNDELSE] = ACTIONS(6330),
    [anon_sym_POUNDElse] = ACTIONS(6330),
    [anon_sym_POUNDelse2] = ACTIONS(6330),
    [anon_sym_POUNDELSE2] = ACTIONS(6330),
    [anon_sym_POUNDElse2] = ACTIONS(6330),
    [anon_sym_POUNDendif] = ACTIONS(6330),
    [anon_sym_POUNDENDIF] = ACTIONS(6330),
    [anon_sym_POUNDEndif] = ACTIONS(6330),
    [anon_sym_POUNDendif2] = ACTIONS(6330),
    [anon_sym_POUNDENDIF2] = ACTIONS(6330),
    [anon_sym_POUNDEndif2] = ACTIONS(6330),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6328),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6328),
    [anon_sym_PLUS] = ACTIONS(6330),
    [sym_datetime_literal] = ACTIONS(6330),
    [sym_date_literal] = ACTIONS(6328),
    [sym_time_literal] = ACTIONS(6328),
    [sym_biginteger_literal] = ACTIONS(6330),
    [anon_sym_if] = ACTIONS(6328),
    [anon_sym_IF] = ACTIONS(6328),
    [anon_sym_If] = ACTIONS(6328),
    [anon_sym_else] = ACTIONS(6328),
    [anon_sym_ELSE] = ACTIONS(6328),
    [anon_sym_Else] = ACTIONS(6328),
    [anon_sym_case] = ACTIONS(6328),
    [anon_sym_CASE] = ACTIONS(6328),
    [anon_sym_Case] = ACTIONS(6328),
    [anon_sym_for] = ACTIONS(6328),
    [anon_sym_FOR] = ACTIONS(6328),
    [anon_sym_For] = ACTIONS(6328),
    [anon_sym_foreach] = ACTIONS(6328),
    [anon_sym_FOREACH] = ACTIONS(6328),
    [anon_sym_Foreach] = ACTIONS(6328),
    [anon_sym_while] = ACTIONS(6328),
    [anon_sym_WHILE] = ACTIONS(6328),
    [anon_sym_While] = ACTIONS(6328),
    [anon_sym_repeat] = ACTIONS(6328),
    [anon_sym_REPEAT] = ACTIONS(6328),
    [anon_sym_Repeat] = ACTIONS(6328),
    [anon_sym_exit] = ACTIONS(6328),
    [anon_sym_EXIT] = ACTIONS(6328),
    [anon_sym_Exit] = ACTIONS(6328),
    [anon_sym_continue] = ACTIONS(6328),
    [anon_sym_CONTINUE] = ACTIONS(6328),
    [anon_sym_Continue] = ACTIONS(6328),
    [anon_sym_break] = ACTIONS(6328),
    [anon_sym_BREAK] = ACTIONS(6328),
    [anon_sym_Break] = ACTIONS(6328),
    [anon_sym_with] = ACTIONS(6328),
    [anon_sym_WITH] = ACTIONS(6328),
    [anon_sym_With] = ACTIONS(6328),
    [sym_asserterror_keyword] = ACTIONS(6330),
    [sym_page_keyword] = ACTIONS(6328),
    [anon_sym_codeunit] = ACTIONS(6328),
    [anon_sym_CODEUNIT] = ACTIONS(6328),
    [anon_sym_Codeunit] = ACTIONS(6328),
    [anon_sym_CodeUnit] = ACTIONS(6328),
    [anon_sym_COdeunit] = ACTIONS(6328),
    [anon_sym_codeUnit] = ACTIONS(6328),
    [sym_report_keyword] = ACTIONS(6328),
    [sym_query_keyword] = ACTIONS(6328),
    [anon_sym_xmlport] = ACTIONS(6328),
    [anon_sym_XMLPORT] = ACTIONS(6328),
    [anon_sym_Xmlport] = ACTIONS(6328),
    [anon_sym_XMLport] = ACTIONS(6328),
    [anon_sym_XMLPort] = ACTIONS(6328),
    [anon_sym_XmlPort] = ACTIONS(6328),
    [anon_sym_enum] = ACTIONS(6328),
    [anon_sym_ENUM] = ACTIONS(6328),
    [anon_sym_Enum] = ACTIONS(6328),
    [anon_sym_eNUM] = ACTIONS(6328),
    [anon_sym_eNum] = ACTIONS(6328),
    [anon_sym_ENum] = ACTIONS(6328),
    [sym_quoted_identifier] = ACTIONS(6330),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6330),
    [sym_verbatim_string] = ACTIONS(6330),
    [sym_integer] = ACTIONS(6328),
    [sym_continue_as_identifier] = ACTIONS(6330),
    [sym_preproc_open] = ACTIONS(6330),
    [sym_preproc_close] = ACTIONS(6330),
  },
  [STATE(2624)] = {
    [sym_identifier] = ACTIONS(6332),
    [anon_sym_SEMI] = ACTIONS(6334),
    [anon_sym_DASH] = ACTIONS(6334),
    [aux_sym_boolean_token1] = ACTIONS(6332),
    [aux_sym_boolean_token2] = ACTIONS(6332),
    [sym_decimal] = ACTIONS(6332),
    [anon_sym_LPAREN] = ACTIONS(6334),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6332),
    [anon_sym_LBRACK] = ACTIONS(6334),
    [aux_sym_record_type_token1] = ACTIONS(6332),
    [aux_sym_basic_type_token21] = ACTIONS(6332),
    [aux_sym_basic_type_token22] = ACTIONS(6332),
    [aux_sym_basic_type_token48] = ACTIONS(6332),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6332),
    [anon_sym_POUNDif] = ACTIONS(6334),
    [anon_sym_POUNDIF] = ACTIONS(6334),
    [anon_sym_POUNDIf] = ACTIONS(6334),
    [anon_sym_not] = ACTIONS(6332),
    [anon_sym_NOT] = ACTIONS(6332),
    [anon_sym_Not] = ACTIONS(6332),
    [anon_sym_POUNDelif] = ACTIONS(6334),
    [anon_sym_POUNDELIF] = ACTIONS(6334),
    [anon_sym_POUNDElif] = ACTIONS(6334),
    [anon_sym_POUNDelse] = ACTIONS(6334),
    [anon_sym_POUNDELSE] = ACTIONS(6334),
    [anon_sym_POUNDElse] = ACTIONS(6334),
    [anon_sym_POUNDelse2] = ACTIONS(6334),
    [anon_sym_POUNDELSE2] = ACTIONS(6334),
    [anon_sym_POUNDElse2] = ACTIONS(6334),
    [anon_sym_POUNDendif] = ACTIONS(6334),
    [anon_sym_POUNDENDIF] = ACTIONS(6334),
    [anon_sym_POUNDEndif] = ACTIONS(6334),
    [anon_sym_POUNDendif2] = ACTIONS(6334),
    [anon_sym_POUNDENDIF2] = ACTIONS(6334),
    [anon_sym_POUNDEndif2] = ACTIONS(6334),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6332),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6332),
    [anon_sym_PLUS] = ACTIONS(6334),
    [sym_datetime_literal] = ACTIONS(6334),
    [sym_date_literal] = ACTIONS(6332),
    [sym_time_literal] = ACTIONS(6332),
    [sym_biginteger_literal] = ACTIONS(6334),
    [anon_sym_if] = ACTIONS(6332),
    [anon_sym_IF] = ACTIONS(6332),
    [anon_sym_If] = ACTIONS(6332),
    [anon_sym_else] = ACTIONS(6332),
    [anon_sym_ELSE] = ACTIONS(6332),
    [anon_sym_Else] = ACTIONS(6332),
    [anon_sym_case] = ACTIONS(6332),
    [anon_sym_CASE] = ACTIONS(6332),
    [anon_sym_Case] = ACTIONS(6332),
    [anon_sym_for] = ACTIONS(6332),
    [anon_sym_FOR] = ACTIONS(6332),
    [anon_sym_For] = ACTIONS(6332),
    [anon_sym_foreach] = ACTIONS(6332),
    [anon_sym_FOREACH] = ACTIONS(6332),
    [anon_sym_Foreach] = ACTIONS(6332),
    [anon_sym_while] = ACTIONS(6332),
    [anon_sym_WHILE] = ACTIONS(6332),
    [anon_sym_While] = ACTIONS(6332),
    [anon_sym_repeat] = ACTIONS(6332),
    [anon_sym_REPEAT] = ACTIONS(6332),
    [anon_sym_Repeat] = ACTIONS(6332),
    [anon_sym_exit] = ACTIONS(6332),
    [anon_sym_EXIT] = ACTIONS(6332),
    [anon_sym_Exit] = ACTIONS(6332),
    [anon_sym_continue] = ACTIONS(6332),
    [anon_sym_CONTINUE] = ACTIONS(6332),
    [anon_sym_Continue] = ACTIONS(6332),
    [anon_sym_break] = ACTIONS(6332),
    [anon_sym_BREAK] = ACTIONS(6332),
    [anon_sym_Break] = ACTIONS(6332),
    [anon_sym_with] = ACTIONS(6332),
    [anon_sym_WITH] = ACTIONS(6332),
    [anon_sym_With] = ACTIONS(6332),
    [sym_asserterror_keyword] = ACTIONS(6334),
    [sym_page_keyword] = ACTIONS(6332),
    [anon_sym_codeunit] = ACTIONS(6332),
    [anon_sym_CODEUNIT] = ACTIONS(6332),
    [anon_sym_Codeunit] = ACTIONS(6332),
    [anon_sym_CodeUnit] = ACTIONS(6332),
    [anon_sym_COdeunit] = ACTIONS(6332),
    [anon_sym_codeUnit] = ACTIONS(6332),
    [sym_report_keyword] = ACTIONS(6332),
    [sym_query_keyword] = ACTIONS(6332),
    [anon_sym_xmlport] = ACTIONS(6332),
    [anon_sym_XMLPORT] = ACTIONS(6332),
    [anon_sym_Xmlport] = ACTIONS(6332),
    [anon_sym_XMLport] = ACTIONS(6332),
    [anon_sym_XMLPort] = ACTIONS(6332),
    [anon_sym_XmlPort] = ACTIONS(6332),
    [anon_sym_enum] = ACTIONS(6332),
    [anon_sym_ENUM] = ACTIONS(6332),
    [anon_sym_Enum] = ACTIONS(6332),
    [anon_sym_eNUM] = ACTIONS(6332),
    [anon_sym_eNum] = ACTIONS(6332),
    [anon_sym_ENum] = ACTIONS(6332),
    [sym_quoted_identifier] = ACTIONS(6334),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6334),
    [sym_verbatim_string] = ACTIONS(6334),
    [sym_integer] = ACTIONS(6332),
    [sym_continue_as_identifier] = ACTIONS(6334),
    [sym_preproc_open] = ACTIONS(6334),
    [sym_preproc_close] = ACTIONS(6334),
  },
  [STATE(2625)] = {
    [sym_identifier] = ACTIONS(6336),
    [anon_sym_SEMI] = ACTIONS(6338),
    [anon_sym_DASH] = ACTIONS(6338),
    [aux_sym_boolean_token1] = ACTIONS(6336),
    [aux_sym_boolean_token2] = ACTIONS(6336),
    [sym_decimal] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6338),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6336),
    [anon_sym_LBRACK] = ACTIONS(6338),
    [aux_sym_record_type_token1] = ACTIONS(6336),
    [aux_sym_basic_type_token21] = ACTIONS(6336),
    [aux_sym_basic_type_token22] = ACTIONS(6336),
    [aux_sym_basic_type_token48] = ACTIONS(6336),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6336),
    [anon_sym_POUNDif] = ACTIONS(6338),
    [anon_sym_POUNDIF] = ACTIONS(6338),
    [anon_sym_POUNDIf] = ACTIONS(6338),
    [anon_sym_not] = ACTIONS(6336),
    [anon_sym_NOT] = ACTIONS(6336),
    [anon_sym_Not] = ACTIONS(6336),
    [anon_sym_POUNDelif] = ACTIONS(6338),
    [anon_sym_POUNDELIF] = ACTIONS(6338),
    [anon_sym_POUNDElif] = ACTIONS(6338),
    [anon_sym_POUNDelse] = ACTIONS(6338),
    [anon_sym_POUNDELSE] = ACTIONS(6338),
    [anon_sym_POUNDElse] = ACTIONS(6338),
    [anon_sym_POUNDelse2] = ACTIONS(6338),
    [anon_sym_POUNDELSE2] = ACTIONS(6338),
    [anon_sym_POUNDElse2] = ACTIONS(6338),
    [anon_sym_POUNDendif] = ACTIONS(6338),
    [anon_sym_POUNDENDIF] = ACTIONS(6338),
    [anon_sym_POUNDEndif] = ACTIONS(6338),
    [anon_sym_POUNDendif2] = ACTIONS(6338),
    [anon_sym_POUNDENDIF2] = ACTIONS(6338),
    [anon_sym_POUNDEndif2] = ACTIONS(6338),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6336),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6336),
    [anon_sym_PLUS] = ACTIONS(6338),
    [sym_datetime_literal] = ACTIONS(6338),
    [sym_date_literal] = ACTIONS(6336),
    [sym_time_literal] = ACTIONS(6336),
    [sym_biginteger_literal] = ACTIONS(6338),
    [anon_sym_if] = ACTIONS(6336),
    [anon_sym_IF] = ACTIONS(6336),
    [anon_sym_If] = ACTIONS(6336),
    [anon_sym_else] = ACTIONS(6336),
    [anon_sym_ELSE] = ACTIONS(6336),
    [anon_sym_Else] = ACTIONS(6336),
    [anon_sym_case] = ACTIONS(6336),
    [anon_sym_CASE] = ACTIONS(6336),
    [anon_sym_Case] = ACTIONS(6336),
    [anon_sym_for] = ACTIONS(6336),
    [anon_sym_FOR] = ACTIONS(6336),
    [anon_sym_For] = ACTIONS(6336),
    [anon_sym_foreach] = ACTIONS(6336),
    [anon_sym_FOREACH] = ACTIONS(6336),
    [anon_sym_Foreach] = ACTIONS(6336),
    [anon_sym_while] = ACTIONS(6336),
    [anon_sym_WHILE] = ACTIONS(6336),
    [anon_sym_While] = ACTIONS(6336),
    [anon_sym_repeat] = ACTIONS(6336),
    [anon_sym_REPEAT] = ACTIONS(6336),
    [anon_sym_Repeat] = ACTIONS(6336),
    [anon_sym_exit] = ACTIONS(6336),
    [anon_sym_EXIT] = ACTIONS(6336),
    [anon_sym_Exit] = ACTIONS(6336),
    [anon_sym_continue] = ACTIONS(6336),
    [anon_sym_CONTINUE] = ACTIONS(6336),
    [anon_sym_Continue] = ACTIONS(6336),
    [anon_sym_break] = ACTIONS(6336),
    [anon_sym_BREAK] = ACTIONS(6336),
    [anon_sym_Break] = ACTIONS(6336),
    [anon_sym_with] = ACTIONS(6336),
    [anon_sym_WITH] = ACTIONS(6336),
    [anon_sym_With] = ACTIONS(6336),
    [sym_asserterror_keyword] = ACTIONS(6338),
    [sym_page_keyword] = ACTIONS(6336),
    [anon_sym_codeunit] = ACTIONS(6336),
    [anon_sym_CODEUNIT] = ACTIONS(6336),
    [anon_sym_Codeunit] = ACTIONS(6336),
    [anon_sym_CodeUnit] = ACTIONS(6336),
    [anon_sym_COdeunit] = ACTIONS(6336),
    [anon_sym_codeUnit] = ACTIONS(6336),
    [sym_report_keyword] = ACTIONS(6336),
    [sym_query_keyword] = ACTIONS(6336),
    [anon_sym_xmlport] = ACTIONS(6336),
    [anon_sym_XMLPORT] = ACTIONS(6336),
    [anon_sym_Xmlport] = ACTIONS(6336),
    [anon_sym_XMLport] = ACTIONS(6336),
    [anon_sym_XMLPort] = ACTIONS(6336),
    [anon_sym_XmlPort] = ACTIONS(6336),
    [anon_sym_enum] = ACTIONS(6336),
    [anon_sym_ENUM] = ACTIONS(6336),
    [anon_sym_Enum] = ACTIONS(6336),
    [anon_sym_eNUM] = ACTIONS(6336),
    [anon_sym_eNum] = ACTIONS(6336),
    [anon_sym_ENum] = ACTIONS(6336),
    [sym_quoted_identifier] = ACTIONS(6338),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6338),
    [sym_verbatim_string] = ACTIONS(6338),
    [sym_integer] = ACTIONS(6336),
    [sym_continue_as_identifier] = ACTIONS(6338),
    [sym_preproc_open] = ACTIONS(6338),
    [sym_preproc_close] = ACTIONS(6338),
  },
  [STATE(2626)] = {
    [sym_identifier] = ACTIONS(6336),
    [anon_sym_SEMI] = ACTIONS(6338),
    [anon_sym_DASH] = ACTIONS(6338),
    [aux_sym_boolean_token1] = ACTIONS(6336),
    [aux_sym_boolean_token2] = ACTIONS(6336),
    [sym_decimal] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6338),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6336),
    [anon_sym_LBRACK] = ACTIONS(6338),
    [aux_sym_record_type_token1] = ACTIONS(6336),
    [aux_sym_basic_type_token21] = ACTIONS(6336),
    [aux_sym_basic_type_token22] = ACTIONS(6336),
    [aux_sym_basic_type_token48] = ACTIONS(6336),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6336),
    [anon_sym_POUNDif] = ACTIONS(6338),
    [anon_sym_POUNDIF] = ACTIONS(6338),
    [anon_sym_POUNDIf] = ACTIONS(6338),
    [anon_sym_not] = ACTIONS(6336),
    [anon_sym_NOT] = ACTIONS(6336),
    [anon_sym_Not] = ACTIONS(6336),
    [anon_sym_POUNDelif] = ACTIONS(6338),
    [anon_sym_POUNDELIF] = ACTIONS(6338),
    [anon_sym_POUNDElif] = ACTIONS(6338),
    [anon_sym_POUNDelse] = ACTIONS(6338),
    [anon_sym_POUNDELSE] = ACTIONS(6338),
    [anon_sym_POUNDElse] = ACTIONS(6338),
    [anon_sym_POUNDelse2] = ACTIONS(6338),
    [anon_sym_POUNDELSE2] = ACTIONS(6338),
    [anon_sym_POUNDElse2] = ACTIONS(6338),
    [anon_sym_POUNDendif] = ACTIONS(6338),
    [anon_sym_POUNDENDIF] = ACTIONS(6338),
    [anon_sym_POUNDEndif] = ACTIONS(6338),
    [anon_sym_POUNDendif2] = ACTIONS(6338),
    [anon_sym_POUNDENDIF2] = ACTIONS(6338),
    [anon_sym_POUNDEndif2] = ACTIONS(6338),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6336),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6336),
    [anon_sym_PLUS] = ACTIONS(6338),
    [sym_datetime_literal] = ACTIONS(6338),
    [sym_date_literal] = ACTIONS(6336),
    [sym_time_literal] = ACTIONS(6336),
    [sym_biginteger_literal] = ACTIONS(6338),
    [anon_sym_if] = ACTIONS(6336),
    [anon_sym_IF] = ACTIONS(6336),
    [anon_sym_If] = ACTIONS(6336),
    [anon_sym_else] = ACTIONS(6336),
    [anon_sym_ELSE] = ACTIONS(6336),
    [anon_sym_Else] = ACTIONS(6336),
    [anon_sym_case] = ACTIONS(6336),
    [anon_sym_CASE] = ACTIONS(6336),
    [anon_sym_Case] = ACTIONS(6336),
    [anon_sym_for] = ACTIONS(6336),
    [anon_sym_FOR] = ACTIONS(6336),
    [anon_sym_For] = ACTIONS(6336),
    [anon_sym_foreach] = ACTIONS(6336),
    [anon_sym_FOREACH] = ACTIONS(6336),
    [anon_sym_Foreach] = ACTIONS(6336),
    [anon_sym_while] = ACTIONS(6336),
    [anon_sym_WHILE] = ACTIONS(6336),
    [anon_sym_While] = ACTIONS(6336),
    [anon_sym_repeat] = ACTIONS(6336),
    [anon_sym_REPEAT] = ACTIONS(6336),
    [anon_sym_Repeat] = ACTIONS(6336),
    [anon_sym_exit] = ACTIONS(6336),
    [anon_sym_EXIT] = ACTIONS(6336),
    [anon_sym_Exit] = ACTIONS(6336),
    [anon_sym_continue] = ACTIONS(6336),
    [anon_sym_CONTINUE] = ACTIONS(6336),
    [anon_sym_Continue] = ACTIONS(6336),
    [anon_sym_break] = ACTIONS(6336),
    [anon_sym_BREAK] = ACTIONS(6336),
    [anon_sym_Break] = ACTIONS(6336),
    [anon_sym_with] = ACTIONS(6336),
    [anon_sym_WITH] = ACTIONS(6336),
    [anon_sym_With] = ACTIONS(6336),
    [sym_asserterror_keyword] = ACTIONS(6338),
    [sym_page_keyword] = ACTIONS(6336),
    [anon_sym_codeunit] = ACTIONS(6336),
    [anon_sym_CODEUNIT] = ACTIONS(6336),
    [anon_sym_Codeunit] = ACTIONS(6336),
    [anon_sym_CodeUnit] = ACTIONS(6336),
    [anon_sym_COdeunit] = ACTIONS(6336),
    [anon_sym_codeUnit] = ACTIONS(6336),
    [sym_report_keyword] = ACTIONS(6336),
    [sym_query_keyword] = ACTIONS(6336),
    [anon_sym_xmlport] = ACTIONS(6336),
    [anon_sym_XMLPORT] = ACTIONS(6336),
    [anon_sym_Xmlport] = ACTIONS(6336),
    [anon_sym_XMLport] = ACTIONS(6336),
    [anon_sym_XMLPort] = ACTIONS(6336),
    [anon_sym_XmlPort] = ACTIONS(6336),
    [anon_sym_enum] = ACTIONS(6336),
    [anon_sym_ENUM] = ACTIONS(6336),
    [anon_sym_Enum] = ACTIONS(6336),
    [anon_sym_eNUM] = ACTIONS(6336),
    [anon_sym_eNum] = ACTIONS(6336),
    [anon_sym_ENum] = ACTIONS(6336),
    [sym_quoted_identifier] = ACTIONS(6338),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6338),
    [sym_verbatim_string] = ACTIONS(6338),
    [sym_integer] = ACTIONS(6336),
    [sym_continue_as_identifier] = ACTIONS(6338),
    [sym_preproc_open] = ACTIONS(6338),
    [sym_preproc_close] = ACTIONS(6338),
  },
  [STATE(2627)] = {
    [sym_identifier] = ACTIONS(6340),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_DASH] = ACTIONS(6342),
    [aux_sym_boolean_token1] = ACTIONS(6340),
    [aux_sym_boolean_token2] = ACTIONS(6340),
    [sym_decimal] = ACTIONS(6340),
    [anon_sym_LPAREN] = ACTIONS(6342),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6340),
    [anon_sym_LBRACK] = ACTIONS(6342),
    [aux_sym_record_type_token1] = ACTIONS(6340),
    [aux_sym_basic_type_token21] = ACTIONS(6340),
    [aux_sym_basic_type_token22] = ACTIONS(6340),
    [aux_sym_basic_type_token48] = ACTIONS(6340),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6340),
    [anon_sym_POUNDif] = ACTIONS(6342),
    [anon_sym_POUNDIF] = ACTIONS(6342),
    [anon_sym_POUNDIf] = ACTIONS(6342),
    [anon_sym_not] = ACTIONS(6340),
    [anon_sym_NOT] = ACTIONS(6340),
    [anon_sym_Not] = ACTIONS(6340),
    [anon_sym_POUNDelif] = ACTIONS(6342),
    [anon_sym_POUNDELIF] = ACTIONS(6342),
    [anon_sym_POUNDElif] = ACTIONS(6342),
    [anon_sym_POUNDelse] = ACTIONS(6342),
    [anon_sym_POUNDELSE] = ACTIONS(6342),
    [anon_sym_POUNDElse] = ACTIONS(6342),
    [anon_sym_POUNDelse2] = ACTIONS(6342),
    [anon_sym_POUNDELSE2] = ACTIONS(6342),
    [anon_sym_POUNDElse2] = ACTIONS(6342),
    [anon_sym_POUNDendif] = ACTIONS(6342),
    [anon_sym_POUNDENDIF] = ACTIONS(6342),
    [anon_sym_POUNDEndif] = ACTIONS(6342),
    [anon_sym_POUNDendif2] = ACTIONS(6342),
    [anon_sym_POUNDENDIF2] = ACTIONS(6342),
    [anon_sym_POUNDEndif2] = ACTIONS(6342),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6340),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6340),
    [anon_sym_PLUS] = ACTIONS(6342),
    [sym_datetime_literal] = ACTIONS(6342),
    [sym_date_literal] = ACTIONS(6340),
    [sym_time_literal] = ACTIONS(6340),
    [sym_biginteger_literal] = ACTIONS(6342),
    [anon_sym_if] = ACTIONS(6340),
    [anon_sym_IF] = ACTIONS(6340),
    [anon_sym_If] = ACTIONS(6340),
    [anon_sym_else] = ACTIONS(6340),
    [anon_sym_ELSE] = ACTIONS(6340),
    [anon_sym_Else] = ACTIONS(6340),
    [anon_sym_case] = ACTIONS(6340),
    [anon_sym_CASE] = ACTIONS(6340),
    [anon_sym_Case] = ACTIONS(6340),
    [anon_sym_for] = ACTIONS(6340),
    [anon_sym_FOR] = ACTIONS(6340),
    [anon_sym_For] = ACTIONS(6340),
    [anon_sym_foreach] = ACTIONS(6340),
    [anon_sym_FOREACH] = ACTIONS(6340),
    [anon_sym_Foreach] = ACTIONS(6340),
    [anon_sym_while] = ACTIONS(6340),
    [anon_sym_WHILE] = ACTIONS(6340),
    [anon_sym_While] = ACTIONS(6340),
    [anon_sym_repeat] = ACTIONS(6340),
    [anon_sym_REPEAT] = ACTIONS(6340),
    [anon_sym_Repeat] = ACTIONS(6340),
    [anon_sym_exit] = ACTIONS(6340),
    [anon_sym_EXIT] = ACTIONS(6340),
    [anon_sym_Exit] = ACTIONS(6340),
    [anon_sym_continue] = ACTIONS(6340),
    [anon_sym_CONTINUE] = ACTIONS(6340),
    [anon_sym_Continue] = ACTIONS(6340),
    [anon_sym_break] = ACTIONS(6340),
    [anon_sym_BREAK] = ACTIONS(6340),
    [anon_sym_Break] = ACTIONS(6340),
    [anon_sym_with] = ACTIONS(6340),
    [anon_sym_WITH] = ACTIONS(6340),
    [anon_sym_With] = ACTIONS(6340),
    [sym_asserterror_keyword] = ACTIONS(6342),
    [sym_page_keyword] = ACTIONS(6340),
    [anon_sym_codeunit] = ACTIONS(6340),
    [anon_sym_CODEUNIT] = ACTIONS(6340),
    [anon_sym_Codeunit] = ACTIONS(6340),
    [anon_sym_CodeUnit] = ACTIONS(6340),
    [anon_sym_COdeunit] = ACTIONS(6340),
    [anon_sym_codeUnit] = ACTIONS(6340),
    [sym_report_keyword] = ACTIONS(6340),
    [sym_query_keyword] = ACTIONS(6340),
    [anon_sym_xmlport] = ACTIONS(6340),
    [anon_sym_XMLPORT] = ACTIONS(6340),
    [anon_sym_Xmlport] = ACTIONS(6340),
    [anon_sym_XMLport] = ACTIONS(6340),
    [anon_sym_XMLPort] = ACTIONS(6340),
    [anon_sym_XmlPort] = ACTIONS(6340),
    [anon_sym_enum] = ACTIONS(6340),
    [anon_sym_ENUM] = ACTIONS(6340),
    [anon_sym_Enum] = ACTIONS(6340),
    [anon_sym_eNUM] = ACTIONS(6340),
    [anon_sym_eNum] = ACTIONS(6340),
    [anon_sym_ENum] = ACTIONS(6340),
    [sym_quoted_identifier] = ACTIONS(6342),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6342),
    [sym_verbatim_string] = ACTIONS(6342),
    [sym_integer] = ACTIONS(6340),
    [sym_continue_as_identifier] = ACTIONS(6342),
    [sym_preproc_open] = ACTIONS(6342),
    [sym_preproc_close] = ACTIONS(6342),
  },
  [STATE(2628)] = {
    [sym_identifier] = ACTIONS(6344),
    [anon_sym_SEMI] = ACTIONS(6346),
    [anon_sym_DASH] = ACTIONS(6346),
    [aux_sym_boolean_token1] = ACTIONS(6344),
    [aux_sym_boolean_token2] = ACTIONS(6344),
    [sym_decimal] = ACTIONS(6344),
    [anon_sym_LPAREN] = ACTIONS(6346),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6344),
    [anon_sym_LBRACK] = ACTIONS(6346),
    [aux_sym_record_type_token1] = ACTIONS(6344),
    [aux_sym_basic_type_token21] = ACTIONS(6344),
    [aux_sym_basic_type_token22] = ACTIONS(6344),
    [aux_sym_basic_type_token48] = ACTIONS(6344),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6344),
    [anon_sym_POUNDif] = ACTIONS(6346),
    [anon_sym_POUNDIF] = ACTIONS(6346),
    [anon_sym_POUNDIf] = ACTIONS(6346),
    [anon_sym_not] = ACTIONS(6344),
    [anon_sym_NOT] = ACTIONS(6344),
    [anon_sym_Not] = ACTIONS(6344),
    [anon_sym_POUNDelif] = ACTIONS(6346),
    [anon_sym_POUNDELIF] = ACTIONS(6346),
    [anon_sym_POUNDElif] = ACTIONS(6346),
    [anon_sym_POUNDelse] = ACTIONS(6346),
    [anon_sym_POUNDELSE] = ACTIONS(6346),
    [anon_sym_POUNDElse] = ACTIONS(6346),
    [anon_sym_POUNDelse2] = ACTIONS(6346),
    [anon_sym_POUNDELSE2] = ACTIONS(6346),
    [anon_sym_POUNDElse2] = ACTIONS(6346),
    [anon_sym_POUNDendif] = ACTIONS(6346),
    [anon_sym_POUNDENDIF] = ACTIONS(6346),
    [anon_sym_POUNDEndif] = ACTIONS(6346),
    [anon_sym_POUNDendif2] = ACTIONS(6346),
    [anon_sym_POUNDENDIF2] = ACTIONS(6346),
    [anon_sym_POUNDEndif2] = ACTIONS(6346),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6344),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6344),
    [anon_sym_PLUS] = ACTIONS(6346),
    [sym_datetime_literal] = ACTIONS(6346),
    [sym_date_literal] = ACTIONS(6344),
    [sym_time_literal] = ACTIONS(6344),
    [sym_biginteger_literal] = ACTIONS(6346),
    [anon_sym_if] = ACTIONS(6344),
    [anon_sym_IF] = ACTIONS(6344),
    [anon_sym_If] = ACTIONS(6344),
    [anon_sym_else] = ACTIONS(6344),
    [anon_sym_ELSE] = ACTIONS(6344),
    [anon_sym_Else] = ACTIONS(6344),
    [anon_sym_case] = ACTIONS(6344),
    [anon_sym_CASE] = ACTIONS(6344),
    [anon_sym_Case] = ACTIONS(6344),
    [anon_sym_for] = ACTIONS(6344),
    [anon_sym_FOR] = ACTIONS(6344),
    [anon_sym_For] = ACTIONS(6344),
    [anon_sym_foreach] = ACTIONS(6344),
    [anon_sym_FOREACH] = ACTIONS(6344),
    [anon_sym_Foreach] = ACTIONS(6344),
    [anon_sym_while] = ACTIONS(6344),
    [anon_sym_WHILE] = ACTIONS(6344),
    [anon_sym_While] = ACTIONS(6344),
    [anon_sym_repeat] = ACTIONS(6344),
    [anon_sym_REPEAT] = ACTIONS(6344),
    [anon_sym_Repeat] = ACTIONS(6344),
    [anon_sym_exit] = ACTIONS(6344),
    [anon_sym_EXIT] = ACTIONS(6344),
    [anon_sym_Exit] = ACTIONS(6344),
    [anon_sym_continue] = ACTIONS(6344),
    [anon_sym_CONTINUE] = ACTIONS(6344),
    [anon_sym_Continue] = ACTIONS(6344),
    [anon_sym_break] = ACTIONS(6344),
    [anon_sym_BREAK] = ACTIONS(6344),
    [anon_sym_Break] = ACTIONS(6344),
    [anon_sym_with] = ACTIONS(6344),
    [anon_sym_WITH] = ACTIONS(6344),
    [anon_sym_With] = ACTIONS(6344),
    [sym_asserterror_keyword] = ACTIONS(6346),
    [sym_page_keyword] = ACTIONS(6344),
    [anon_sym_codeunit] = ACTIONS(6344),
    [anon_sym_CODEUNIT] = ACTIONS(6344),
    [anon_sym_Codeunit] = ACTIONS(6344),
    [anon_sym_CodeUnit] = ACTIONS(6344),
    [anon_sym_COdeunit] = ACTIONS(6344),
    [anon_sym_codeUnit] = ACTIONS(6344),
    [sym_report_keyword] = ACTIONS(6344),
    [sym_query_keyword] = ACTIONS(6344),
    [anon_sym_xmlport] = ACTIONS(6344),
    [anon_sym_XMLPORT] = ACTIONS(6344),
    [anon_sym_Xmlport] = ACTIONS(6344),
    [anon_sym_XMLport] = ACTIONS(6344),
    [anon_sym_XMLPort] = ACTIONS(6344),
    [anon_sym_XmlPort] = ACTIONS(6344),
    [anon_sym_enum] = ACTIONS(6344),
    [anon_sym_ENUM] = ACTIONS(6344),
    [anon_sym_Enum] = ACTIONS(6344),
    [anon_sym_eNUM] = ACTIONS(6344),
    [anon_sym_eNum] = ACTIONS(6344),
    [anon_sym_ENum] = ACTIONS(6344),
    [sym_quoted_identifier] = ACTIONS(6346),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6346),
    [sym_verbatim_string] = ACTIONS(6346),
    [sym_integer] = ACTIONS(6344),
    [sym_continue_as_identifier] = ACTIONS(6346),
    [sym_preproc_open] = ACTIONS(6346),
    [sym_preproc_close] = ACTIONS(6346),
  },
  [STATE(2629)] = {
    [sym_identifier] = ACTIONS(6348),
    [anon_sym_SEMI] = ACTIONS(6350),
    [anon_sym_DASH] = ACTIONS(6350),
    [aux_sym_boolean_token1] = ACTIONS(6348),
    [aux_sym_boolean_token2] = ACTIONS(6348),
    [sym_decimal] = ACTIONS(6348),
    [anon_sym_LPAREN] = ACTIONS(6350),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6348),
    [anon_sym_LBRACK] = ACTIONS(6350),
    [aux_sym_record_type_token1] = ACTIONS(6348),
    [aux_sym_basic_type_token21] = ACTIONS(6348),
    [aux_sym_basic_type_token22] = ACTIONS(6348),
    [aux_sym_basic_type_token48] = ACTIONS(6348),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6348),
    [anon_sym_POUNDif] = ACTIONS(6350),
    [anon_sym_POUNDIF] = ACTIONS(6350),
    [anon_sym_POUNDIf] = ACTIONS(6350),
    [anon_sym_not] = ACTIONS(6348),
    [anon_sym_NOT] = ACTIONS(6348),
    [anon_sym_Not] = ACTIONS(6348),
    [anon_sym_POUNDelif] = ACTIONS(6350),
    [anon_sym_POUNDELIF] = ACTIONS(6350),
    [anon_sym_POUNDElif] = ACTIONS(6350),
    [anon_sym_POUNDelse] = ACTIONS(6350),
    [anon_sym_POUNDELSE] = ACTIONS(6350),
    [anon_sym_POUNDElse] = ACTIONS(6350),
    [anon_sym_POUNDelse2] = ACTIONS(6350),
    [anon_sym_POUNDELSE2] = ACTIONS(6350),
    [anon_sym_POUNDElse2] = ACTIONS(6350),
    [anon_sym_POUNDendif] = ACTIONS(6350),
    [anon_sym_POUNDENDIF] = ACTIONS(6350),
    [anon_sym_POUNDEndif] = ACTIONS(6350),
    [anon_sym_POUNDendif2] = ACTIONS(6350),
    [anon_sym_POUNDENDIF2] = ACTIONS(6350),
    [anon_sym_POUNDEndif2] = ACTIONS(6350),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6348),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6348),
    [anon_sym_PLUS] = ACTIONS(6350),
    [sym_datetime_literal] = ACTIONS(6350),
    [sym_date_literal] = ACTIONS(6348),
    [sym_time_literal] = ACTIONS(6348),
    [sym_biginteger_literal] = ACTIONS(6350),
    [anon_sym_if] = ACTIONS(6348),
    [anon_sym_IF] = ACTIONS(6348),
    [anon_sym_If] = ACTIONS(6348),
    [anon_sym_else] = ACTIONS(6348),
    [anon_sym_ELSE] = ACTIONS(6348),
    [anon_sym_Else] = ACTIONS(6348),
    [anon_sym_case] = ACTIONS(6348),
    [anon_sym_CASE] = ACTIONS(6348),
    [anon_sym_Case] = ACTIONS(6348),
    [anon_sym_for] = ACTIONS(6348),
    [anon_sym_FOR] = ACTIONS(6348),
    [anon_sym_For] = ACTIONS(6348),
    [anon_sym_foreach] = ACTIONS(6348),
    [anon_sym_FOREACH] = ACTIONS(6348),
    [anon_sym_Foreach] = ACTIONS(6348),
    [anon_sym_while] = ACTIONS(6348),
    [anon_sym_WHILE] = ACTIONS(6348),
    [anon_sym_While] = ACTIONS(6348),
    [anon_sym_repeat] = ACTIONS(6348),
    [anon_sym_REPEAT] = ACTIONS(6348),
    [anon_sym_Repeat] = ACTIONS(6348),
    [anon_sym_exit] = ACTIONS(6348),
    [anon_sym_EXIT] = ACTIONS(6348),
    [anon_sym_Exit] = ACTIONS(6348),
    [anon_sym_continue] = ACTIONS(6348),
    [anon_sym_CONTINUE] = ACTIONS(6348),
    [anon_sym_Continue] = ACTIONS(6348),
    [anon_sym_break] = ACTIONS(6348),
    [anon_sym_BREAK] = ACTIONS(6348),
    [anon_sym_Break] = ACTIONS(6348),
    [anon_sym_with] = ACTIONS(6348),
    [anon_sym_WITH] = ACTIONS(6348),
    [anon_sym_With] = ACTIONS(6348),
    [sym_asserterror_keyword] = ACTIONS(6350),
    [sym_page_keyword] = ACTIONS(6348),
    [anon_sym_codeunit] = ACTIONS(6348),
    [anon_sym_CODEUNIT] = ACTIONS(6348),
    [anon_sym_Codeunit] = ACTIONS(6348),
    [anon_sym_CodeUnit] = ACTIONS(6348),
    [anon_sym_COdeunit] = ACTIONS(6348),
    [anon_sym_codeUnit] = ACTIONS(6348),
    [sym_report_keyword] = ACTIONS(6348),
    [sym_query_keyword] = ACTIONS(6348),
    [anon_sym_xmlport] = ACTIONS(6348),
    [anon_sym_XMLPORT] = ACTIONS(6348),
    [anon_sym_Xmlport] = ACTIONS(6348),
    [anon_sym_XMLport] = ACTIONS(6348),
    [anon_sym_XMLPort] = ACTIONS(6348),
    [anon_sym_XmlPort] = ACTIONS(6348),
    [anon_sym_enum] = ACTIONS(6348),
    [anon_sym_ENUM] = ACTIONS(6348),
    [anon_sym_Enum] = ACTIONS(6348),
    [anon_sym_eNUM] = ACTIONS(6348),
    [anon_sym_eNum] = ACTIONS(6348),
    [anon_sym_ENum] = ACTIONS(6348),
    [sym_quoted_identifier] = ACTIONS(6350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6350),
    [sym_verbatim_string] = ACTIONS(6350),
    [sym_integer] = ACTIONS(6348),
    [sym_continue_as_identifier] = ACTIONS(6350),
    [sym_preproc_open] = ACTIONS(6350),
    [sym_preproc_close] = ACTIONS(6350),
  },
  [STATE(2630)] = {
    [sym_identifier] = ACTIONS(6352),
    [anon_sym_SEMI] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6354),
    [aux_sym_boolean_token1] = ACTIONS(6352),
    [aux_sym_boolean_token2] = ACTIONS(6352),
    [sym_decimal] = ACTIONS(6352),
    [anon_sym_LPAREN] = ACTIONS(6354),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6352),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [aux_sym_record_type_token1] = ACTIONS(6352),
    [aux_sym_basic_type_token21] = ACTIONS(6352),
    [aux_sym_basic_type_token22] = ACTIONS(6352),
    [aux_sym_basic_type_token48] = ACTIONS(6352),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6352),
    [anon_sym_POUNDif] = ACTIONS(6354),
    [anon_sym_POUNDIF] = ACTIONS(6354),
    [anon_sym_POUNDIf] = ACTIONS(6354),
    [anon_sym_not] = ACTIONS(6352),
    [anon_sym_NOT] = ACTIONS(6352),
    [anon_sym_Not] = ACTIONS(6352),
    [anon_sym_POUNDelif] = ACTIONS(6354),
    [anon_sym_POUNDELIF] = ACTIONS(6354),
    [anon_sym_POUNDElif] = ACTIONS(6354),
    [anon_sym_POUNDelse] = ACTIONS(6354),
    [anon_sym_POUNDELSE] = ACTIONS(6354),
    [anon_sym_POUNDElse] = ACTIONS(6354),
    [anon_sym_POUNDelse2] = ACTIONS(6354),
    [anon_sym_POUNDELSE2] = ACTIONS(6354),
    [anon_sym_POUNDElse2] = ACTIONS(6354),
    [anon_sym_POUNDendif] = ACTIONS(6354),
    [anon_sym_POUNDENDIF] = ACTIONS(6354),
    [anon_sym_POUNDEndif] = ACTIONS(6354),
    [anon_sym_POUNDendif2] = ACTIONS(6354),
    [anon_sym_POUNDENDIF2] = ACTIONS(6354),
    [anon_sym_POUNDEndif2] = ACTIONS(6354),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6352),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6354),
    [sym_datetime_literal] = ACTIONS(6354),
    [sym_date_literal] = ACTIONS(6352),
    [sym_time_literal] = ACTIONS(6352),
    [sym_biginteger_literal] = ACTIONS(6354),
    [anon_sym_if] = ACTIONS(6352),
    [anon_sym_IF] = ACTIONS(6352),
    [anon_sym_If] = ACTIONS(6352),
    [anon_sym_else] = ACTIONS(6352),
    [anon_sym_ELSE] = ACTIONS(6352),
    [anon_sym_Else] = ACTIONS(6352),
    [anon_sym_case] = ACTIONS(6352),
    [anon_sym_CASE] = ACTIONS(6352),
    [anon_sym_Case] = ACTIONS(6352),
    [anon_sym_for] = ACTIONS(6352),
    [anon_sym_FOR] = ACTIONS(6352),
    [anon_sym_For] = ACTIONS(6352),
    [anon_sym_foreach] = ACTIONS(6352),
    [anon_sym_FOREACH] = ACTIONS(6352),
    [anon_sym_Foreach] = ACTIONS(6352),
    [anon_sym_while] = ACTIONS(6352),
    [anon_sym_WHILE] = ACTIONS(6352),
    [anon_sym_While] = ACTIONS(6352),
    [anon_sym_repeat] = ACTIONS(6352),
    [anon_sym_REPEAT] = ACTIONS(6352),
    [anon_sym_Repeat] = ACTIONS(6352),
    [anon_sym_exit] = ACTIONS(6352),
    [anon_sym_EXIT] = ACTIONS(6352),
    [anon_sym_Exit] = ACTIONS(6352),
    [anon_sym_continue] = ACTIONS(6352),
    [anon_sym_CONTINUE] = ACTIONS(6352),
    [anon_sym_Continue] = ACTIONS(6352),
    [anon_sym_break] = ACTIONS(6352),
    [anon_sym_BREAK] = ACTIONS(6352),
    [anon_sym_Break] = ACTIONS(6352),
    [anon_sym_with] = ACTIONS(6352),
    [anon_sym_WITH] = ACTIONS(6352),
    [anon_sym_With] = ACTIONS(6352),
    [sym_asserterror_keyword] = ACTIONS(6354),
    [sym_page_keyword] = ACTIONS(6352),
    [anon_sym_codeunit] = ACTIONS(6352),
    [anon_sym_CODEUNIT] = ACTIONS(6352),
    [anon_sym_Codeunit] = ACTIONS(6352),
    [anon_sym_CodeUnit] = ACTIONS(6352),
    [anon_sym_COdeunit] = ACTIONS(6352),
    [anon_sym_codeUnit] = ACTIONS(6352),
    [sym_report_keyword] = ACTIONS(6352),
    [sym_query_keyword] = ACTIONS(6352),
    [anon_sym_xmlport] = ACTIONS(6352),
    [anon_sym_XMLPORT] = ACTIONS(6352),
    [anon_sym_Xmlport] = ACTIONS(6352),
    [anon_sym_XMLport] = ACTIONS(6352),
    [anon_sym_XMLPort] = ACTIONS(6352),
    [anon_sym_XmlPort] = ACTIONS(6352),
    [anon_sym_enum] = ACTIONS(6352),
    [anon_sym_ENUM] = ACTIONS(6352),
    [anon_sym_Enum] = ACTIONS(6352),
    [anon_sym_eNUM] = ACTIONS(6352),
    [anon_sym_eNum] = ACTIONS(6352),
    [anon_sym_ENum] = ACTIONS(6352),
    [sym_quoted_identifier] = ACTIONS(6354),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6354),
    [sym_verbatim_string] = ACTIONS(6354),
    [sym_integer] = ACTIONS(6352),
    [sym_continue_as_identifier] = ACTIONS(6354),
    [sym_preproc_open] = ACTIONS(6354),
    [sym_preproc_close] = ACTIONS(6354),
  },
  [STATE(2631)] = {
    [sym_identifier] = ACTIONS(6042),
    [anon_sym_SEMI] = ACTIONS(6044),
    [anon_sym_DASH] = ACTIONS(6044),
    [aux_sym_boolean_token1] = ACTIONS(6042),
    [aux_sym_boolean_token2] = ACTIONS(6042),
    [sym_decimal] = ACTIONS(6042),
    [anon_sym_LPAREN] = ACTIONS(6044),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6042),
    [anon_sym_LBRACK] = ACTIONS(6044),
    [aux_sym_record_type_token1] = ACTIONS(6042),
    [aux_sym_basic_type_token21] = ACTIONS(6042),
    [aux_sym_basic_type_token22] = ACTIONS(6042),
    [aux_sym_basic_type_token48] = ACTIONS(6042),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6042),
    [anon_sym_POUNDif] = ACTIONS(6044),
    [anon_sym_POUNDIF] = ACTIONS(6044),
    [anon_sym_POUNDIf] = ACTIONS(6044),
    [anon_sym_not] = ACTIONS(6042),
    [anon_sym_NOT] = ACTIONS(6042),
    [anon_sym_Not] = ACTIONS(6042),
    [anon_sym_POUNDelif] = ACTIONS(6044),
    [anon_sym_POUNDELIF] = ACTIONS(6044),
    [anon_sym_POUNDElif] = ACTIONS(6044),
    [anon_sym_POUNDelse] = ACTIONS(6044),
    [anon_sym_POUNDELSE] = ACTIONS(6044),
    [anon_sym_POUNDElse] = ACTIONS(6044),
    [anon_sym_POUNDelse2] = ACTIONS(6044),
    [anon_sym_POUNDELSE2] = ACTIONS(6044),
    [anon_sym_POUNDElse2] = ACTIONS(6044),
    [anon_sym_POUNDendif] = ACTIONS(6044),
    [anon_sym_POUNDENDIF] = ACTIONS(6044),
    [anon_sym_POUNDEndif] = ACTIONS(6044),
    [anon_sym_POUNDendif2] = ACTIONS(6044),
    [anon_sym_POUNDENDIF2] = ACTIONS(6044),
    [anon_sym_POUNDEndif2] = ACTIONS(6044),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6042),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6042),
    [anon_sym_PLUS] = ACTIONS(6044),
    [sym_datetime_literal] = ACTIONS(6044),
    [sym_date_literal] = ACTIONS(6042),
    [sym_time_literal] = ACTIONS(6042),
    [sym_biginteger_literal] = ACTIONS(6044),
    [anon_sym_if] = ACTIONS(6042),
    [anon_sym_IF] = ACTIONS(6042),
    [anon_sym_If] = ACTIONS(6042),
    [anon_sym_else] = ACTIONS(6042),
    [anon_sym_ELSE] = ACTIONS(6042),
    [anon_sym_Else] = ACTIONS(6042),
    [anon_sym_case] = ACTIONS(6042),
    [anon_sym_CASE] = ACTIONS(6042),
    [anon_sym_Case] = ACTIONS(6042),
    [anon_sym_for] = ACTIONS(6042),
    [anon_sym_FOR] = ACTIONS(6042),
    [anon_sym_For] = ACTIONS(6042),
    [anon_sym_foreach] = ACTIONS(6042),
    [anon_sym_FOREACH] = ACTIONS(6042),
    [anon_sym_Foreach] = ACTIONS(6042),
    [anon_sym_while] = ACTIONS(6042),
    [anon_sym_WHILE] = ACTIONS(6042),
    [anon_sym_While] = ACTIONS(6042),
    [anon_sym_repeat] = ACTIONS(6042),
    [anon_sym_REPEAT] = ACTIONS(6042),
    [anon_sym_Repeat] = ACTIONS(6042),
    [anon_sym_exit] = ACTIONS(6042),
    [anon_sym_EXIT] = ACTIONS(6042),
    [anon_sym_Exit] = ACTIONS(6042),
    [anon_sym_continue] = ACTIONS(6042),
    [anon_sym_CONTINUE] = ACTIONS(6042),
    [anon_sym_Continue] = ACTIONS(6042),
    [anon_sym_break] = ACTIONS(6042),
    [anon_sym_BREAK] = ACTIONS(6042),
    [anon_sym_Break] = ACTIONS(6042),
    [anon_sym_with] = ACTIONS(6042),
    [anon_sym_WITH] = ACTIONS(6042),
    [anon_sym_With] = ACTIONS(6042),
    [sym_asserterror_keyword] = ACTIONS(6044),
    [sym_page_keyword] = ACTIONS(6042),
    [anon_sym_codeunit] = ACTIONS(6042),
    [anon_sym_CODEUNIT] = ACTIONS(6042),
    [anon_sym_Codeunit] = ACTIONS(6042),
    [anon_sym_CodeUnit] = ACTIONS(6042),
    [anon_sym_COdeunit] = ACTIONS(6042),
    [anon_sym_codeUnit] = ACTIONS(6042),
    [sym_report_keyword] = ACTIONS(6042),
    [sym_query_keyword] = ACTIONS(6042),
    [anon_sym_xmlport] = ACTIONS(6042),
    [anon_sym_XMLPORT] = ACTIONS(6042),
    [anon_sym_Xmlport] = ACTIONS(6042),
    [anon_sym_XMLport] = ACTIONS(6042),
    [anon_sym_XMLPort] = ACTIONS(6042),
    [anon_sym_XmlPort] = ACTIONS(6042),
    [anon_sym_enum] = ACTIONS(6042),
    [anon_sym_ENUM] = ACTIONS(6042),
    [anon_sym_Enum] = ACTIONS(6042),
    [anon_sym_eNUM] = ACTIONS(6042),
    [anon_sym_eNum] = ACTIONS(6042),
    [anon_sym_ENum] = ACTIONS(6042),
    [sym_quoted_identifier] = ACTIONS(6044),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6044),
    [sym_verbatim_string] = ACTIONS(6044),
    [sym_integer] = ACTIONS(6042),
    [sym_continue_as_identifier] = ACTIONS(6044),
    [sym_preproc_open] = ACTIONS(6044),
    [sym_preproc_close] = ACTIONS(6044),
  },
  [STATE(2632)] = {
    [aux_sym_option_member_list_repeat2] = STATE(2632),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_EQ] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(6356),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [sym_decimal] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(838),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(838),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [anon_sym_not] = ACTIONS(836),
    [anon_sym_NOT] = ACTIONS(836),
    [anon_sym_Not] = ACTIONS(836),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(838),
    [aux_sym__expression_token1] = ACTIONS(838),
    [aux_sym__expression_token2] = ACTIONS(838),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_div] = ACTIONS(836),
    [anon_sym_DIV] = ACTIONS(836),
    [anon_sym_Div] = ACTIONS(836),
    [anon_sym_mod] = ACTIONS(836),
    [anon_sym_MOD] = ACTIONS(836),
    [anon_sym_Mod] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_LT_GT] = ACTIONS(838),
    [anon_sym_and] = ACTIONS(836),
    [anon_sym_AND] = ACTIONS(836),
    [anon_sym_And] = ACTIONS(836),
    [anon_sym_or] = ACTIONS(836),
    [anon_sym_OR] = ACTIONS(836),
    [anon_sym_Or] = ACTIONS(836),
    [anon_sym_xor] = ACTIONS(836),
    [anon_sym_XOR] = ACTIONS(836),
    [anon_sym_Xor] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(838),
    [sym_datetime_literal] = ACTIONS(838),
    [sym_date_literal] = ACTIONS(836),
    [sym_time_literal] = ACTIONS(836),
    [sym_biginteger_literal] = ACTIONS(838),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_ELSE] = ACTIONS(836),
    [anon_sym_Else] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_IN] = ACTIONS(836),
    [anon_sym_In] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_verbatim_string] = ACTIONS(838),
    [sym_integer] = ACTIONS(836),
    [sym_continue_as_identifier] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
  },
  [STATE(2633)] = {
    [sym_identifier] = ACTIONS(6359),
    [anon_sym_SEMI] = ACTIONS(6361),
    [anon_sym_DASH] = ACTIONS(6361),
    [aux_sym_boolean_token1] = ACTIONS(6359),
    [aux_sym_boolean_token2] = ACTIONS(6359),
    [sym_decimal] = ACTIONS(6359),
    [anon_sym_LPAREN] = ACTIONS(6361),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6359),
    [anon_sym_LBRACK] = ACTIONS(6361),
    [aux_sym_record_type_token1] = ACTIONS(6359),
    [aux_sym_basic_type_token21] = ACTIONS(6359),
    [aux_sym_basic_type_token22] = ACTIONS(6359),
    [aux_sym_basic_type_token48] = ACTIONS(6359),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6359),
    [anon_sym_POUNDif] = ACTIONS(6361),
    [anon_sym_POUNDIF] = ACTIONS(6361),
    [anon_sym_POUNDIf] = ACTIONS(6361),
    [anon_sym_not] = ACTIONS(6359),
    [anon_sym_NOT] = ACTIONS(6359),
    [anon_sym_Not] = ACTIONS(6359),
    [anon_sym_POUNDelif] = ACTIONS(6361),
    [anon_sym_POUNDELIF] = ACTIONS(6361),
    [anon_sym_POUNDElif] = ACTIONS(6361),
    [anon_sym_POUNDelse] = ACTIONS(6361),
    [anon_sym_POUNDELSE] = ACTIONS(6361),
    [anon_sym_POUNDElse] = ACTIONS(6361),
    [anon_sym_POUNDelse2] = ACTIONS(6361),
    [anon_sym_POUNDELSE2] = ACTIONS(6361),
    [anon_sym_POUNDElse2] = ACTIONS(6361),
    [anon_sym_POUNDendif] = ACTIONS(6361),
    [anon_sym_POUNDENDIF] = ACTIONS(6361),
    [anon_sym_POUNDEndif] = ACTIONS(6361),
    [anon_sym_POUNDendif2] = ACTIONS(6361),
    [anon_sym_POUNDENDIF2] = ACTIONS(6361),
    [anon_sym_POUNDEndif2] = ACTIONS(6361),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6359),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6359),
    [anon_sym_PLUS] = ACTIONS(6361),
    [sym_datetime_literal] = ACTIONS(6361),
    [sym_date_literal] = ACTIONS(6359),
    [sym_time_literal] = ACTIONS(6359),
    [sym_biginteger_literal] = ACTIONS(6361),
    [anon_sym_if] = ACTIONS(6359),
    [anon_sym_IF] = ACTIONS(6359),
    [anon_sym_If] = ACTIONS(6359),
    [anon_sym_else] = ACTIONS(6359),
    [anon_sym_ELSE] = ACTIONS(6359),
    [anon_sym_Else] = ACTIONS(6359),
    [anon_sym_case] = ACTIONS(6359),
    [anon_sym_CASE] = ACTIONS(6359),
    [anon_sym_Case] = ACTIONS(6359),
    [anon_sym_for] = ACTIONS(6359),
    [anon_sym_FOR] = ACTIONS(6359),
    [anon_sym_For] = ACTIONS(6359),
    [anon_sym_foreach] = ACTIONS(6359),
    [anon_sym_FOREACH] = ACTIONS(6359),
    [anon_sym_Foreach] = ACTIONS(6359),
    [anon_sym_while] = ACTIONS(6359),
    [anon_sym_WHILE] = ACTIONS(6359),
    [anon_sym_While] = ACTIONS(6359),
    [anon_sym_repeat] = ACTIONS(6359),
    [anon_sym_REPEAT] = ACTIONS(6359),
    [anon_sym_Repeat] = ACTIONS(6359),
    [anon_sym_exit] = ACTIONS(6359),
    [anon_sym_EXIT] = ACTIONS(6359),
    [anon_sym_Exit] = ACTIONS(6359),
    [anon_sym_continue] = ACTIONS(6359),
    [anon_sym_CONTINUE] = ACTIONS(6359),
    [anon_sym_Continue] = ACTIONS(6359),
    [anon_sym_break] = ACTIONS(6359),
    [anon_sym_BREAK] = ACTIONS(6359),
    [anon_sym_Break] = ACTIONS(6359),
    [anon_sym_with] = ACTIONS(6359),
    [anon_sym_WITH] = ACTIONS(6359),
    [anon_sym_With] = ACTIONS(6359),
    [sym_asserterror_keyword] = ACTIONS(6361),
    [sym_page_keyword] = ACTIONS(6359),
    [anon_sym_codeunit] = ACTIONS(6359),
    [anon_sym_CODEUNIT] = ACTIONS(6359),
    [anon_sym_Codeunit] = ACTIONS(6359),
    [anon_sym_CodeUnit] = ACTIONS(6359),
    [anon_sym_COdeunit] = ACTIONS(6359),
    [anon_sym_codeUnit] = ACTIONS(6359),
    [sym_report_keyword] = ACTIONS(6359),
    [sym_query_keyword] = ACTIONS(6359),
    [anon_sym_xmlport] = ACTIONS(6359),
    [anon_sym_XMLPORT] = ACTIONS(6359),
    [anon_sym_Xmlport] = ACTIONS(6359),
    [anon_sym_XMLport] = ACTIONS(6359),
    [anon_sym_XMLPort] = ACTIONS(6359),
    [anon_sym_XmlPort] = ACTIONS(6359),
    [anon_sym_enum] = ACTIONS(6359),
    [anon_sym_ENUM] = ACTIONS(6359),
    [anon_sym_Enum] = ACTIONS(6359),
    [anon_sym_eNUM] = ACTIONS(6359),
    [anon_sym_eNum] = ACTIONS(6359),
    [anon_sym_ENum] = ACTIONS(6359),
    [sym_quoted_identifier] = ACTIONS(6361),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6361),
    [sym_verbatim_string] = ACTIONS(6361),
    [sym_integer] = ACTIONS(6359),
    [sym_continue_as_identifier] = ACTIONS(6361),
    [sym_preproc_open] = ACTIONS(6361),
    [sym_preproc_close] = ACTIONS(6361),
  },
  [STATE(2634)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12968),
    [sym_else_table_relation_fragment] = STATE(12968),
    [sym_table_relation_expression] = STATE(12968),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(17194),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(2635)] = {
    [sym__body_element] = STATE(2660),
    [sym_empty_statement] = STATE(2660),
    [sym_property] = STATE(2660),
    [sym_permissions_property] = STATE(2660),
    [sym_table_relation_property] = STATE(2660),
    [sym_fields_section] = STATE(2660),
    [sym_keys_section] = STATE(2660),
    [sym_fieldgroups_section] = STATE(2660),
    [sym_enum_value_declaration] = STATE(2660),
    [sym_labels_section] = STATE(2660),
    [sym_layout_section] = STATE(2660),
    [sym__layout_element] = STATE(2660),
    [sym_area_section] = STATE(2660),
    [sym_group_section] = STATE(2660),
    [sym_repeater_section] = STATE(2660),
    [sym_cuegroup_section] = STATE(2660),
    [sym_fixed_section] = STATE(2660),
    [sym_grid_section] = STATE(2660),
    [sym_page_field] = STATE(2660),
    [sym_part_section] = STATE(2660),
    [sym_systempart_section] = STATE(2660),
    [sym_usercontrol_section] = STATE(2660),
    [sym_preproc_split_field] = STATE(2660),
    [sym_label_section] = STATE(2660),
    [sym_addfirst_modification] = STATE(2660),
    [sym_addlast_modification] = STATE(2660),
    [sym_addafter_modification] = STATE(2660),
    [sym_addbefore_modification] = STATE(2660),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2660),
    [sym_movelast_modification] = STATE(2660),
    [sym_moveafter_modification] = STATE(2660),
    [sym_movebefore_modification] = STATE(2660),
    [sym_actions_section] = STATE(2660),
    [sym_views_section] = STATE(2660),
    [sym_dataset_section] = STATE(2660),
    [sym_requestpage_section] = STATE(2660),
    [sym_rendering_section] = STATE(2660),
    [sym_elements_section] = STATE(2660),
    [sym_schema_section] = STATE(2660),
    [sym_assembly_declaration] = STATE(2660),
    [sym_event_declaration] = STATE(2660),
    [sym_procedure] = STATE(2660),
    [sym_preproc_split_procedure] = STATE(2660),
    [sym_preproc_split_procedure_preamble] = STATE(2660),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2660),
    [sym_var_section] = STATE(2660),
    [sym_attribute_item] = STATE(2660),
    [sym_preproc_conditional] = STATE(2660),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2660),
    [sym_preproc_conditional_layout_mixed] = STATE(2660),
    [aux_sym_group_section_repeat1] = STATE(2660),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6365),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2636)] = {
    [sym__body_element] = STATE(2661),
    [sym_empty_statement] = STATE(2661),
    [sym_property] = STATE(2661),
    [sym_permissions_property] = STATE(2661),
    [sym_table_relation_property] = STATE(2661),
    [sym_fields_section] = STATE(2661),
    [sym_keys_section] = STATE(2661),
    [sym_fieldgroups_section] = STATE(2661),
    [sym_enum_value_declaration] = STATE(2661),
    [sym_labels_section] = STATE(2661),
    [sym_layout_section] = STATE(2661),
    [sym__layout_element] = STATE(2661),
    [sym_area_section] = STATE(2661),
    [sym_group_section] = STATE(2661),
    [sym_repeater_section] = STATE(2661),
    [sym_cuegroup_section] = STATE(2661),
    [sym_fixed_section] = STATE(2661),
    [sym_grid_section] = STATE(2661),
    [sym_page_field] = STATE(2661),
    [sym_part_section] = STATE(2661),
    [sym_systempart_section] = STATE(2661),
    [sym_usercontrol_section] = STATE(2661),
    [sym_preproc_split_field] = STATE(2661),
    [sym_label_section] = STATE(2661),
    [sym_addfirst_modification] = STATE(2661),
    [sym_addlast_modification] = STATE(2661),
    [sym_addafter_modification] = STATE(2661),
    [sym_addbefore_modification] = STATE(2661),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2661),
    [sym_movelast_modification] = STATE(2661),
    [sym_moveafter_modification] = STATE(2661),
    [sym_movebefore_modification] = STATE(2661),
    [sym_actions_section] = STATE(2661),
    [sym_views_section] = STATE(2661),
    [sym_dataset_section] = STATE(2661),
    [sym_requestpage_section] = STATE(2661),
    [sym_rendering_section] = STATE(2661),
    [sym_elements_section] = STATE(2661),
    [sym_schema_section] = STATE(2661),
    [sym_assembly_declaration] = STATE(2661),
    [sym_event_declaration] = STATE(2661),
    [sym_procedure] = STATE(2661),
    [sym_preproc_split_procedure] = STATE(2661),
    [sym_preproc_split_procedure_preamble] = STATE(2661),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2661),
    [sym_var_section] = STATE(2661),
    [sym_attribute_item] = STATE(2661),
    [sym_preproc_conditional] = STATE(2661),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2661),
    [sym_preproc_conditional_layout_mixed] = STATE(2661),
    [aux_sym_group_section_repeat1] = STATE(2661),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6449),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2637)] = {
    [sym__body_element] = STATE(2682),
    [sym_empty_statement] = STATE(2682),
    [sym_property] = STATE(2682),
    [sym_permissions_property] = STATE(2682),
    [sym_table_relation_property] = STATE(2682),
    [sym_fields_section] = STATE(2682),
    [sym_keys_section] = STATE(2682),
    [sym_fieldgroups_section] = STATE(2682),
    [sym_enum_value_declaration] = STATE(2682),
    [sym_labels_section] = STATE(2682),
    [sym_layout_section] = STATE(2682),
    [sym__layout_element] = STATE(2682),
    [sym_area_section] = STATE(2682),
    [sym_group_section] = STATE(2682),
    [sym_repeater_section] = STATE(2682),
    [sym_cuegroup_section] = STATE(2682),
    [sym_fixed_section] = STATE(2682),
    [sym_grid_section] = STATE(2682),
    [sym_page_field] = STATE(2682),
    [sym_part_section] = STATE(2682),
    [sym_systempart_section] = STATE(2682),
    [sym_usercontrol_section] = STATE(2682),
    [sym_preproc_split_field] = STATE(2682),
    [sym_label_section] = STATE(2682),
    [sym_addfirst_modification] = STATE(2682),
    [sym_addlast_modification] = STATE(2682),
    [sym_addafter_modification] = STATE(2682),
    [sym_addbefore_modification] = STATE(2682),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2682),
    [sym_movelast_modification] = STATE(2682),
    [sym_moveafter_modification] = STATE(2682),
    [sym_movebefore_modification] = STATE(2682),
    [sym_actions_section] = STATE(2682),
    [sym_views_section] = STATE(2682),
    [sym_dataset_section] = STATE(2682),
    [sym_requestpage_section] = STATE(2682),
    [sym_rendering_section] = STATE(2682),
    [sym_elements_section] = STATE(2682),
    [sym_schema_section] = STATE(2682),
    [sym_assembly_declaration] = STATE(2682),
    [sym_event_declaration] = STATE(2682),
    [sym_procedure] = STATE(2682),
    [sym_preproc_split_procedure] = STATE(2682),
    [sym_preproc_split_procedure_preamble] = STATE(2682),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2682),
    [sym_var_section] = STATE(2682),
    [sym_attribute_item] = STATE(2682),
    [sym_preproc_conditional] = STATE(2682),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2682),
    [sym_preproc_conditional_layout_mixed] = STATE(2682),
    [aux_sym_group_section_repeat1] = STATE(2682),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6451),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2638)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12692),
    [sym_else_table_relation_fragment] = STATE(12692),
    [sym_table_relation_expression] = STATE(12692),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(5216),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2639)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12695),
    [sym_else_table_relation_fragment] = STATE(12695),
    [sym_table_relation_expression] = STATE(12695),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(5227),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2640)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6453),
    [anon_sym_RBRACE] = ACTIONS(6456),
    [aux_sym_where_condition_token1] = ACTIONS(6458),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6461),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6464),
    [anon_sym_LBRACK] = ACTIONS(6467),
    [aux_sym_basic_type_token6] = ACTIONS(6470),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6473),
    [aux_sym_addafter_modification_token1] = ACTIONS(6476),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6479),
    [aux_sym_modify_modification_token1] = ACTIONS(6482),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6485),
    [aux_sym_movelast_modification_token1] = ACTIONS(6488),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6491),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6494),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6497),
    [anon_sym_POUNDif] = ACTIONS(6500),
    [anon_sym_POUNDIF] = ACTIONS(6500),
    [anon_sym_POUNDIf] = ACTIONS(6500),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6503),
    [sym_trigger_keyword] = ACTIONS(6506),
    [sym_var_keyword] = ACTIONS(6509),
    [sym_local_keyword] = ACTIONS(6512),
    [sym_internal_keyword] = ACTIONS(6515),
    [sym_protected_keyword] = ACTIONS(6512),
    [sym_event_keyword] = ACTIONS(6518),
    [sym_fields_keyword] = ACTIONS(6521),
    [sym_keys_keyword] = ACTIONS(6524),
    [sym_fieldgroups_keyword] = ACTIONS(6527),
    [sym_actions_keyword] = ACTIONS(6530),
    [sym_layout_keyword] = ACTIONS(6533),
    [sym_area_keyword] = ACTIONS(6536),
    [sym_group_keyword] = ACTIONS(6539),
    [sym_repeater_keyword] = ACTIONS(6542),
    [sym_cuegroup_keyword] = ACTIONS(6545),
    [sym_fixed_keyword] = ACTIONS(6548),
    [sym_grid_keyword] = ACTIONS(6551),
    [sym_part_keyword] = ACTIONS(6554),
    [sym_systempart_keyword] = ACTIONS(6557),
    [sym_usercontrol_keyword] = ACTIONS(6560),
    [sym_dataset_keyword] = ACTIONS(6563),
    [sym_elements_keyword] = ACTIONS(6566),
    [sym_labels_keyword] = ACTIONS(6569),
    [sym_rendering_keyword] = ACTIONS(6572),
    [sym_requestpage_keyword] = ACTIONS(6575),
    [sym_schema_keyword] = ACTIONS(6578),
    [sym_views_keyword] = ACTIONS(6581),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6584),
    [sym_preproc_open] = ACTIONS(6500),
  },
  [STATE(2641)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12698),
    [sym_else_table_relation_fragment] = STATE(12698),
    [sym_table_relation_expression] = STATE(12698),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(5240),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2642)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6587),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2643)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13337),
    [sym_else_table_relation_fragment] = STATE(13337),
    [sym_table_relation_expression] = STATE(13337),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6744),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(2644)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12700),
    [sym_else_table_relation_fragment] = STATE(12700),
    [sym_table_relation_expression] = STATE(12700),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(5251),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(2645)] = {
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(6589),
    [anon_sym_EQ] = ACTIONS(6591),
    [anon_sym_DASH] = ACTIONS(6589),
    [aux_sym_where_clause_token1] = ACTIONS(3695),
    [aux_sym_where_condition_token1] = ACTIONS(3693),
    [anon_sym_DOT_DOT] = ACTIONS(6591),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3695),
    [anon_sym_STAR] = ACTIONS(6589),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3695),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3695),
    [anon_sym_LBRACK] = ACTIONS(6593),
    [aux_sym_basic_type_token6] = ACTIONS(3693),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3695),
    [aux_sym_addafter_modification_token1] = ACTIONS(3695),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3695),
    [aux_sym_modify_modification_token1] = ACTIONS(3695),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3695),
    [aux_sym_movelast_modification_token1] = ACTIONS(3695),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3695),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3695),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_POUNDelif] = ACTIONS(3695),
    [anon_sym_POUNDELIF] = ACTIONS(3695),
    [anon_sym_POUNDElif] = ACTIONS(3695),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [anon_sym_POUNDendif] = ACTIONS(3695),
    [anon_sym_POUNDENDIF] = ACTIONS(3695),
    [anon_sym_POUNDEndif] = ACTIONS(3695),
    [anon_sym_POUNDendif2] = ACTIONS(3695),
    [anon_sym_POUNDENDIF2] = ACTIONS(3695),
    [anon_sym_POUNDEndif2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6591),
    [aux_sym__expression_token1] = ACTIONS(6591),
    [aux_sym__expression_token2] = ACTIONS(6591),
    [anon_sym_SLASH] = ACTIONS(6589),
    [anon_sym_div] = ACTIONS(6591),
    [anon_sym_DIV] = ACTIONS(6591),
    [anon_sym_Div] = ACTIONS(6591),
    [anon_sym_mod] = ACTIONS(6589),
    [anon_sym_MOD] = ACTIONS(6589),
    [anon_sym_Mod] = ACTIONS(6589),
    [anon_sym_PLUS] = ACTIONS(6589),
    [anon_sym_GT_EQ] = ACTIONS(6591),
    [anon_sym_LT_EQ] = ACTIONS(6591),
    [anon_sym_GT] = ACTIONS(6589),
    [anon_sym_LT] = ACTIONS(6589),
    [anon_sym_LT_GT] = ACTIONS(6591),
    [anon_sym_and] = ACTIONS(6591),
    [anon_sym_AND] = ACTIONS(6591),
    [anon_sym_And] = ACTIONS(6591),
    [anon_sym_or] = ACTIONS(6591),
    [anon_sym_OR] = ACTIONS(6591),
    [anon_sym_Or] = ACTIONS(6591),
    [anon_sym_xor] = ACTIONS(6591),
    [anon_sym_XOR] = ACTIONS(6591),
    [anon_sym_Xor] = ACTIONS(6591),
    [anon_sym_QMARK] = ACTIONS(6591),
    [anon_sym_in] = ACTIONS(6589),
    [anon_sym_IN] = ACTIONS(6589),
    [anon_sym_In] = ACTIONS(6589),
    [sym_procedure_keyword] = ACTIONS(3695),
    [sym_trigger_keyword] = ACTIONS(3695),
    [sym_var_keyword] = ACTIONS(3695),
    [sym_local_keyword] = ACTIONS(3695),
    [sym_internal_keyword] = ACTIONS(3695),
    [sym_protected_keyword] = ACTIONS(3695),
    [sym_event_keyword] = ACTIONS(3695),
    [sym_fields_keyword] = ACTIONS(3695),
    [sym_keys_keyword] = ACTIONS(3695),
    [sym_fieldgroups_keyword] = ACTIONS(3695),
    [sym_actions_keyword] = ACTIONS(3695),
    [sym_layout_keyword] = ACTIONS(3695),
    [sym_area_keyword] = ACTIONS(3695),
    [sym_group_keyword] = ACTIONS(3695),
    [sym_repeater_keyword] = ACTIONS(3695),
    [sym_cuegroup_keyword] = ACTIONS(3695),
    [sym_fixed_keyword] = ACTIONS(3695),
    [sym_grid_keyword] = ACTIONS(3695),
    [sym_part_keyword] = ACTIONS(3695),
    [sym_systempart_keyword] = ACTIONS(3695),
    [sym_usercontrol_keyword] = ACTIONS(3695),
    [sym_dataset_keyword] = ACTIONS(3695),
    [sym_elements_keyword] = ACTIONS(3695),
    [sym_dataitem_keyword] = ACTIONS(3695),
    [sym_column_keyword] = ACTIONS(3695),
    [sym_filter_keyword] = ACTIONS(3695),
    [sym_labels_keyword] = ACTIONS(3695),
    [sym_rendering_keyword] = ACTIONS(3695),
    [sym_requestpage_keyword] = ACTIONS(3695),
    [sym_schema_keyword] = ACTIONS(3695),
    [sym_views_keyword] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
    [sym_preproc_close] = ACTIONS(3695),
  },
  [STATE(2646)] = {
    [sym__body_element] = STATE(2651),
    [sym_empty_statement] = STATE(2651),
    [sym_property] = STATE(2651),
    [sym_permissions_property] = STATE(2651),
    [sym_table_relation_property] = STATE(2651),
    [sym_fields_section] = STATE(2651),
    [sym_keys_section] = STATE(2651),
    [sym_fieldgroups_section] = STATE(2651),
    [sym_enum_value_declaration] = STATE(2651),
    [sym_labels_section] = STATE(2651),
    [sym_layout_section] = STATE(2651),
    [sym__layout_element] = STATE(2651),
    [sym_area_section] = STATE(2651),
    [sym_group_section] = STATE(2651),
    [sym_repeater_section] = STATE(2651),
    [sym_cuegroup_section] = STATE(2651),
    [sym_fixed_section] = STATE(2651),
    [sym_grid_section] = STATE(2651),
    [sym_page_field] = STATE(2651),
    [sym_part_section] = STATE(2651),
    [sym_systempart_section] = STATE(2651),
    [sym_usercontrol_section] = STATE(2651),
    [sym_preproc_split_field] = STATE(2651),
    [sym_label_section] = STATE(2651),
    [sym_addfirst_modification] = STATE(2651),
    [sym_addlast_modification] = STATE(2651),
    [sym_addafter_modification] = STATE(2651),
    [sym_addbefore_modification] = STATE(2651),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2651),
    [sym_movelast_modification] = STATE(2651),
    [sym_moveafter_modification] = STATE(2651),
    [sym_movebefore_modification] = STATE(2651),
    [sym_actions_section] = STATE(2651),
    [sym_views_section] = STATE(2651),
    [sym_dataset_section] = STATE(2651),
    [sym_requestpage_section] = STATE(2651),
    [sym_rendering_section] = STATE(2651),
    [sym_elements_section] = STATE(2651),
    [sym_schema_section] = STATE(2651),
    [sym_assembly_declaration] = STATE(2651),
    [sym_event_declaration] = STATE(2651),
    [sym_procedure] = STATE(2651),
    [sym_preproc_split_procedure] = STATE(2651),
    [sym_preproc_split_procedure_preamble] = STATE(2651),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2651),
    [sym_var_section] = STATE(2651),
    [sym_attribute_item] = STATE(2651),
    [sym_preproc_conditional] = STATE(2651),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2651),
    [sym_preproc_conditional_layout_mixed] = STATE(2651),
    [aux_sym_group_section_repeat1] = STATE(2651),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6596),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2647)] = {
    [sym__body_element] = STATE(2654),
    [sym_empty_statement] = STATE(2654),
    [sym_property] = STATE(2654),
    [sym_permissions_property] = STATE(2654),
    [sym_table_relation_property] = STATE(2654),
    [sym_fields_section] = STATE(2654),
    [sym_keys_section] = STATE(2654),
    [sym_fieldgroups_section] = STATE(2654),
    [sym_enum_value_declaration] = STATE(2654),
    [sym_labels_section] = STATE(2654),
    [sym_layout_section] = STATE(2654),
    [sym__layout_element] = STATE(2654),
    [sym_area_section] = STATE(2654),
    [sym_group_section] = STATE(2654),
    [sym_repeater_section] = STATE(2654),
    [sym_cuegroup_section] = STATE(2654),
    [sym_fixed_section] = STATE(2654),
    [sym_grid_section] = STATE(2654),
    [sym_page_field] = STATE(2654),
    [sym_part_section] = STATE(2654),
    [sym_systempart_section] = STATE(2654),
    [sym_usercontrol_section] = STATE(2654),
    [sym_preproc_split_field] = STATE(2654),
    [sym_label_section] = STATE(2654),
    [sym_addfirst_modification] = STATE(2654),
    [sym_addlast_modification] = STATE(2654),
    [sym_addafter_modification] = STATE(2654),
    [sym_addbefore_modification] = STATE(2654),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2654),
    [sym_movelast_modification] = STATE(2654),
    [sym_moveafter_modification] = STATE(2654),
    [sym_movebefore_modification] = STATE(2654),
    [sym_actions_section] = STATE(2654),
    [sym_views_section] = STATE(2654),
    [sym_dataset_section] = STATE(2654),
    [sym_requestpage_section] = STATE(2654),
    [sym_rendering_section] = STATE(2654),
    [sym_elements_section] = STATE(2654),
    [sym_schema_section] = STATE(2654),
    [sym_assembly_declaration] = STATE(2654),
    [sym_event_declaration] = STATE(2654),
    [sym_procedure] = STATE(2654),
    [sym_preproc_split_procedure] = STATE(2654),
    [sym_preproc_split_procedure_preamble] = STATE(2654),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2654),
    [sym_var_section] = STATE(2654),
    [sym_attribute_item] = STATE(2654),
    [sym_preproc_conditional] = STATE(2654),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2654),
    [sym_preproc_conditional_layout_mixed] = STATE(2654),
    [aux_sym_group_section_repeat1] = STATE(2654),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6598),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2648)] = {
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_COLON] = ACTIONS(6000),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(6002),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_COLON_COLON] = ACTIONS(5356),
    [anon_sym_POUNDif] = ACTIONS(6002),
    [anon_sym_POUNDIF] = ACTIONS(6002),
    [anon_sym_POUNDIf] = ACTIONS(6002),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [anon_sym_POUNDelif] = ACTIONS(6002),
    [anon_sym_POUNDELIF] = ACTIONS(6002),
    [anon_sym_POUNDElif] = ACTIONS(6002),
    [anon_sym_POUNDelse] = ACTIONS(6002),
    [anon_sym_POUNDELSE] = ACTIONS(6002),
    [anon_sym_POUNDElse] = ACTIONS(6002),
    [anon_sym_POUNDelse2] = ACTIONS(6002),
    [anon_sym_POUNDELSE2] = ACTIONS(6002),
    [anon_sym_POUNDElse2] = ACTIONS(6002),
    [anon_sym_POUNDendif] = ACTIONS(6002),
    [anon_sym_POUNDENDIF] = ACTIONS(6002),
    [anon_sym_POUNDEndif] = ACTIONS(6002),
    [anon_sym_POUNDendif2] = ACTIONS(6002),
    [anon_sym_POUNDENDIF2] = ACTIONS(6002),
    [anon_sym_POUNDEndif2] = ACTIONS(6002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_open] = ACTIONS(6002),
    [sym_preproc_close] = ACTIONS(6002),
  },
  [STATE(2649)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6600),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2650)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6602),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2651)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6604),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2652)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13343),
    [sym_else_table_relation_fragment] = STATE(13343),
    [sym_table_relation_expression] = STATE(13343),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6853),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(2653)] = {
    [sym_boolean] = STATE(2717),
    [sym_preproc_if] = STATE(3509),
    [sym_assignment_expression] = STATE(8840),
    [sym_case_branch] = STATE(2722),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(4801),
    [sym_case_else_branch] = STATE(11455),
    [sym__expression] = STATE(8840),
    [sym_keyword_identifier] = STATE(2518),
    [sym_range_expression] = STATE(2717),
    [sym_multiplicative_expression] = STATE(2717),
    [sym_additive_expression] = STATE(2717),
    [sym_comparison_expression] = STATE(2717),
    [sym_logical_expression] = STATE(2717),
    [sym_ternary_expression] = STATE(8840),
    [sym_unary_expression] = STATE(2717),
    [sym_call_expression] = STATE(2648),
    [sym_member_expression] = STATE(2518),
    [sym_subscript_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2717),
    [sym_list_literal] = STATE(8840),
    [sym_qualified_enum_value] = STATE(2518),
    [sym_database_reference] = STATE(2717),
    [sym__literal_value] = STATE(2717),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2722),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3585),
    [sym_identifier] = ACTIONS(5340),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(5342),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [anon_sym_POUNDelif] = ACTIONS(6606),
    [anon_sym_POUNDELIF] = ACTIONS(6606),
    [anon_sym_POUNDElif] = ACTIONS(6606),
    [anon_sym_POUNDelse] = ACTIONS(6606),
    [anon_sym_POUNDELSE] = ACTIONS(6606),
    [anon_sym_POUNDElse] = ACTIONS(6606),
    [anon_sym_POUNDelse2] = ACTIONS(6606),
    [anon_sym_POUNDELSE2] = ACTIONS(6606),
    [anon_sym_POUNDElse2] = ACTIONS(6606),
    [anon_sym_POUNDendif] = ACTIONS(6606),
    [anon_sym_POUNDENDIF] = ACTIONS(6606),
    [anon_sym_POUNDEndif] = ACTIONS(6606),
    [anon_sym_POUNDendif2] = ACTIONS(6606),
    [anon_sym_POUNDENDIF2] = ACTIONS(6606),
    [anon_sym_POUNDEndif2] = ACTIONS(6606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(5346),
    [sym_date_literal] = ACTIONS(5342),
    [sym_time_literal] = ACTIONS(5342),
    [sym_biginteger_literal] = ACTIONS(5346),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(5350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5346),
    [sym_verbatim_string] = ACTIONS(5346),
    [sym_integer] = ACTIONS(5342),
    [sym_continue_as_identifier] = ACTIONS(5352),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(6606),
  },
  [STATE(2654)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6609),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2655)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6611),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2656)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6613),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2657)] = {
    [sym_boolean] = STATE(7226),
    [sym_option_member] = STATE(7774),
    [sym_keyword_identifier] = STATE(7226),
    [sym_codeunit_keyword] = STATE(6858),
    [sym_xmlport_keyword] = STATE(6858),
    [sym_enum_keyword] = STATE(6858),
    [sym_keyword_as_identifier] = STATE(7226),
    [aux_sym_option_member_list_repeat2] = STATE(2727),
    [sym_identifier] = ACTIONS(3993),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(6615),
    [anon_sym_COLON] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(6032),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [anon_sym_RPAREN] = ACTIONS(600),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [anon_sym_RBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(6034),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1382),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [anon_sym_then] = ACTIONS(602),
    [anon_sym_THEN] = ACTIONS(602),
    [anon_sym_Then] = ACTIONS(602),
    [anon_sym_of] = ACTIONS(602),
    [anon_sym_OF] = ACTIONS(602),
    [anon_sym_Of] = ACTIONS(602),
    [anon_sym_do] = ACTIONS(602),
    [anon_sym_DO] = ACTIONS(602),
    [anon_sym_Do] = ACTIONS(602),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_page_keyword] = ACTIONS(1382),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1382),
    [sym_query_keyword] = ACTIONS(1382),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6036),
    [sym_integer] = ACTIONS(6036),
  },
  [STATE(2658)] = {
    [sym__body_element] = STATE(2694),
    [sym_empty_statement] = STATE(2694),
    [sym_property] = STATE(2694),
    [sym_permissions_property] = STATE(2694),
    [sym_table_relation_property] = STATE(2694),
    [sym_fields_section] = STATE(2694),
    [sym_keys_section] = STATE(2694),
    [sym_fieldgroups_section] = STATE(2694),
    [sym_enum_value_declaration] = STATE(2694),
    [sym_labels_section] = STATE(2694),
    [sym_layout_section] = STATE(2694),
    [sym__layout_element] = STATE(2694),
    [sym_area_section] = STATE(2694),
    [sym_group_section] = STATE(2694),
    [sym_repeater_section] = STATE(2694),
    [sym_cuegroup_section] = STATE(2694),
    [sym_fixed_section] = STATE(2694),
    [sym_grid_section] = STATE(2694),
    [sym_page_field] = STATE(2694),
    [sym_part_section] = STATE(2694),
    [sym_systempart_section] = STATE(2694),
    [sym_usercontrol_section] = STATE(2694),
    [sym_preproc_split_field] = STATE(2694),
    [sym_label_section] = STATE(2694),
    [sym_addfirst_modification] = STATE(2694),
    [sym_addlast_modification] = STATE(2694),
    [sym_addafter_modification] = STATE(2694),
    [sym_addbefore_modification] = STATE(2694),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2694),
    [sym_movelast_modification] = STATE(2694),
    [sym_moveafter_modification] = STATE(2694),
    [sym_movebefore_modification] = STATE(2694),
    [sym_actions_section] = STATE(2694),
    [sym_views_section] = STATE(2694),
    [sym_dataset_section] = STATE(2694),
    [sym_requestpage_section] = STATE(2694),
    [sym_rendering_section] = STATE(2694),
    [sym_elements_section] = STATE(2694),
    [sym_schema_section] = STATE(2694),
    [sym_assembly_declaration] = STATE(2694),
    [sym_event_declaration] = STATE(2694),
    [sym_procedure] = STATE(2694),
    [sym_preproc_split_procedure] = STATE(2694),
    [sym_preproc_split_procedure_preamble] = STATE(2694),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2694),
    [sym_var_section] = STATE(2694),
    [sym_attribute_item] = STATE(2694),
    [sym_preproc_conditional] = STATE(2694),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2694),
    [sym_preproc_conditional_layout_mixed] = STATE(2694),
    [aux_sym_group_section_repeat1] = STATE(2694),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6617),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2659)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12881),
    [sym_else_table_relation_fragment] = STATE(12881),
    [sym_table_relation_expression] = STATE(12881),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(17498),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(2660)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6619),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2661)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6621),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2662)] = {
    [sym__body_element] = STATE(2649),
    [sym_empty_statement] = STATE(2649),
    [sym_property] = STATE(2649),
    [sym_permissions_property] = STATE(2649),
    [sym_table_relation_property] = STATE(2649),
    [sym_fields_section] = STATE(2649),
    [sym_keys_section] = STATE(2649),
    [sym_fieldgroups_section] = STATE(2649),
    [sym_enum_value_declaration] = STATE(2649),
    [sym_labels_section] = STATE(2649),
    [sym_layout_section] = STATE(2649),
    [sym__layout_element] = STATE(2649),
    [sym_area_section] = STATE(2649),
    [sym_group_section] = STATE(2649),
    [sym_repeater_section] = STATE(2649),
    [sym_cuegroup_section] = STATE(2649),
    [sym_fixed_section] = STATE(2649),
    [sym_grid_section] = STATE(2649),
    [sym_page_field] = STATE(2649),
    [sym_part_section] = STATE(2649),
    [sym_systempart_section] = STATE(2649),
    [sym_usercontrol_section] = STATE(2649),
    [sym_preproc_split_field] = STATE(2649),
    [sym_label_section] = STATE(2649),
    [sym_addfirst_modification] = STATE(2649),
    [sym_addlast_modification] = STATE(2649),
    [sym_addafter_modification] = STATE(2649),
    [sym_addbefore_modification] = STATE(2649),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2649),
    [sym_movelast_modification] = STATE(2649),
    [sym_moveafter_modification] = STATE(2649),
    [sym_movebefore_modification] = STATE(2649),
    [sym_actions_section] = STATE(2649),
    [sym_views_section] = STATE(2649),
    [sym_dataset_section] = STATE(2649),
    [sym_requestpage_section] = STATE(2649),
    [sym_rendering_section] = STATE(2649),
    [sym_elements_section] = STATE(2649),
    [sym_schema_section] = STATE(2649),
    [sym_assembly_declaration] = STATE(2649),
    [sym_event_declaration] = STATE(2649),
    [sym_procedure] = STATE(2649),
    [sym_preproc_split_procedure] = STATE(2649),
    [sym_preproc_split_procedure_preamble] = STATE(2649),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2649),
    [sym_var_section] = STATE(2649),
    [sym_attribute_item] = STATE(2649),
    [sym_preproc_conditional] = STATE(2649),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2649),
    [sym_preproc_conditional_layout_mixed] = STATE(2649),
    [aux_sym_group_section_repeat1] = STATE(2649),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6623),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2663)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12774),
    [sym_else_table_relation_fragment] = STATE(12774),
    [sym_table_relation_expression] = STATE(12774),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(7903),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(2664)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12778),
    [sym_else_table_relation_fragment] = STATE(12778),
    [sym_table_relation_expression] = STATE(12778),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(7907),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(2665)] = {
    [sym__body_element] = STATE(2650),
    [sym_empty_statement] = STATE(2650),
    [sym_property] = STATE(2650),
    [sym_permissions_property] = STATE(2650),
    [sym_table_relation_property] = STATE(2650),
    [sym_fields_section] = STATE(2650),
    [sym_keys_section] = STATE(2650),
    [sym_fieldgroups_section] = STATE(2650),
    [sym_enum_value_declaration] = STATE(2650),
    [sym_labels_section] = STATE(2650),
    [sym_layout_section] = STATE(2650),
    [sym__layout_element] = STATE(2650),
    [sym_area_section] = STATE(2650),
    [sym_group_section] = STATE(2650),
    [sym_repeater_section] = STATE(2650),
    [sym_cuegroup_section] = STATE(2650),
    [sym_fixed_section] = STATE(2650),
    [sym_grid_section] = STATE(2650),
    [sym_page_field] = STATE(2650),
    [sym_part_section] = STATE(2650),
    [sym_systempart_section] = STATE(2650),
    [sym_usercontrol_section] = STATE(2650),
    [sym_preproc_split_field] = STATE(2650),
    [sym_label_section] = STATE(2650),
    [sym_addfirst_modification] = STATE(2650),
    [sym_addlast_modification] = STATE(2650),
    [sym_addafter_modification] = STATE(2650),
    [sym_addbefore_modification] = STATE(2650),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2650),
    [sym_movelast_modification] = STATE(2650),
    [sym_moveafter_modification] = STATE(2650),
    [sym_movebefore_modification] = STATE(2650),
    [sym_actions_section] = STATE(2650),
    [sym_views_section] = STATE(2650),
    [sym_dataset_section] = STATE(2650),
    [sym_requestpage_section] = STATE(2650),
    [sym_rendering_section] = STATE(2650),
    [sym_elements_section] = STATE(2650),
    [sym_schema_section] = STATE(2650),
    [sym_assembly_declaration] = STATE(2650),
    [sym_event_declaration] = STATE(2650),
    [sym_procedure] = STATE(2650),
    [sym_preproc_split_procedure] = STATE(2650),
    [sym_preproc_split_procedure_preamble] = STATE(2650),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2650),
    [sym_var_section] = STATE(2650),
    [sym_attribute_item] = STATE(2650),
    [sym_preproc_conditional] = STATE(2650),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2650),
    [sym_preproc_conditional_layout_mixed] = STATE(2650),
    [aux_sym_group_section_repeat1] = STATE(2650),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6625),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2666)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12782),
    [sym_else_table_relation_fragment] = STATE(12782),
    [sym_table_relation_expression] = STATE(12782),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(7928),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(2667)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13007),
    [sym_else_table_relation_fragment] = STATE(13007),
    [sym_table_relation_expression] = STATE(13007),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6088),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(2668)] = {
    [sym__body_element] = STATE(2684),
    [sym_empty_statement] = STATE(2684),
    [sym_property] = STATE(2684),
    [sym_permissions_property] = STATE(2684),
    [sym_table_relation_property] = STATE(2684),
    [sym_fields_section] = STATE(2684),
    [sym_keys_section] = STATE(2684),
    [sym_fieldgroups_section] = STATE(2684),
    [sym_enum_value_declaration] = STATE(2684),
    [sym_labels_section] = STATE(2684),
    [sym_layout_section] = STATE(2684),
    [sym__layout_element] = STATE(2684),
    [sym_area_section] = STATE(2684),
    [sym_group_section] = STATE(2684),
    [sym_repeater_section] = STATE(2684),
    [sym_cuegroup_section] = STATE(2684),
    [sym_fixed_section] = STATE(2684),
    [sym_grid_section] = STATE(2684),
    [sym_page_field] = STATE(2684),
    [sym_part_section] = STATE(2684),
    [sym_systempart_section] = STATE(2684),
    [sym_usercontrol_section] = STATE(2684),
    [sym_preproc_split_field] = STATE(2684),
    [sym_label_section] = STATE(2684),
    [sym_addfirst_modification] = STATE(2684),
    [sym_addlast_modification] = STATE(2684),
    [sym_addafter_modification] = STATE(2684),
    [sym_addbefore_modification] = STATE(2684),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2684),
    [sym_movelast_modification] = STATE(2684),
    [sym_moveafter_modification] = STATE(2684),
    [sym_movebefore_modification] = STATE(2684),
    [sym_actions_section] = STATE(2684),
    [sym_views_section] = STATE(2684),
    [sym_dataset_section] = STATE(2684),
    [sym_requestpage_section] = STATE(2684),
    [sym_rendering_section] = STATE(2684),
    [sym_elements_section] = STATE(2684),
    [sym_schema_section] = STATE(2684),
    [sym_assembly_declaration] = STATE(2684),
    [sym_event_declaration] = STATE(2684),
    [sym_procedure] = STATE(2684),
    [sym_preproc_split_procedure] = STATE(2684),
    [sym_preproc_split_procedure_preamble] = STATE(2684),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2684),
    [sym_var_section] = STATE(2684),
    [sym_attribute_item] = STATE(2684),
    [sym_preproc_conditional] = STATE(2684),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2684),
    [sym_preproc_conditional_layout_mixed] = STATE(2684),
    [aux_sym_group_section_repeat1] = STATE(2684),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6627),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2669)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12531),
    [sym_else_table_relation_fragment] = STATE(12531),
    [sym_table_relation_expression] = STATE(12531),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6070),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(2670)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12989),
    [sym_else_table_relation_fragment] = STATE(12989),
    [sym_table_relation_expression] = STATE(12989),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(17432),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(2671)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12997),
    [sym_else_table_relation_fragment] = STATE(12997),
    [sym_table_relation_expression] = STATE(12997),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(18026),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(355),
    [anon_sym_POUNDENDIF] = ACTIONS(355),
    [anon_sym_POUNDEndif] = ACTIONS(355),
    [anon_sym_POUNDendif2] = ACTIONS(355),
    [anon_sym_POUNDENDIF2] = ACTIONS(355),
    [anon_sym_POUNDEndif2] = ACTIONS(355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(355),
  },
  [STATE(2672)] = {
    [sym__body_element] = STATE(2686),
    [sym_empty_statement] = STATE(2686),
    [sym_property] = STATE(2686),
    [sym_permissions_property] = STATE(2686),
    [sym_table_relation_property] = STATE(2686),
    [sym_fields_section] = STATE(2686),
    [sym_keys_section] = STATE(2686),
    [sym_fieldgroups_section] = STATE(2686),
    [sym_enum_value_declaration] = STATE(2686),
    [sym_labels_section] = STATE(2686),
    [sym_layout_section] = STATE(2686),
    [sym__layout_element] = STATE(2686),
    [sym_area_section] = STATE(2686),
    [sym_group_section] = STATE(2686),
    [sym_repeater_section] = STATE(2686),
    [sym_cuegroup_section] = STATE(2686),
    [sym_fixed_section] = STATE(2686),
    [sym_grid_section] = STATE(2686),
    [sym_page_field] = STATE(2686),
    [sym_part_section] = STATE(2686),
    [sym_systempart_section] = STATE(2686),
    [sym_usercontrol_section] = STATE(2686),
    [sym_preproc_split_field] = STATE(2686),
    [sym_label_section] = STATE(2686),
    [sym_addfirst_modification] = STATE(2686),
    [sym_addlast_modification] = STATE(2686),
    [sym_addafter_modification] = STATE(2686),
    [sym_addbefore_modification] = STATE(2686),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2686),
    [sym_movelast_modification] = STATE(2686),
    [sym_moveafter_modification] = STATE(2686),
    [sym_movebefore_modification] = STATE(2686),
    [sym_actions_section] = STATE(2686),
    [sym_views_section] = STATE(2686),
    [sym_dataset_section] = STATE(2686),
    [sym_requestpage_section] = STATE(2686),
    [sym_rendering_section] = STATE(2686),
    [sym_elements_section] = STATE(2686),
    [sym_schema_section] = STATE(2686),
    [sym_assembly_declaration] = STATE(2686),
    [sym_event_declaration] = STATE(2686),
    [sym_procedure] = STATE(2686),
    [sym_preproc_split_procedure] = STATE(2686),
    [sym_preproc_split_procedure_preamble] = STATE(2686),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2686),
    [sym_var_section] = STATE(2686),
    [sym_attribute_item] = STATE(2686),
    [sym_preproc_conditional] = STATE(2686),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2686),
    [sym_preproc_conditional_layout_mixed] = STATE(2686),
    [aux_sym_group_section_repeat1] = STATE(2686),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6629),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2673)] = {
    [sym__body_element] = STATE(2688),
    [sym_empty_statement] = STATE(2688),
    [sym_property] = STATE(2688),
    [sym_permissions_property] = STATE(2688),
    [sym_table_relation_property] = STATE(2688),
    [sym_fields_section] = STATE(2688),
    [sym_keys_section] = STATE(2688),
    [sym_fieldgroups_section] = STATE(2688),
    [sym_enum_value_declaration] = STATE(2688),
    [sym_labels_section] = STATE(2688),
    [sym_layout_section] = STATE(2688),
    [sym__layout_element] = STATE(2688),
    [sym_area_section] = STATE(2688),
    [sym_group_section] = STATE(2688),
    [sym_repeater_section] = STATE(2688),
    [sym_cuegroup_section] = STATE(2688),
    [sym_fixed_section] = STATE(2688),
    [sym_grid_section] = STATE(2688),
    [sym_page_field] = STATE(2688),
    [sym_part_section] = STATE(2688),
    [sym_systempart_section] = STATE(2688),
    [sym_usercontrol_section] = STATE(2688),
    [sym_preproc_split_field] = STATE(2688),
    [sym_label_section] = STATE(2688),
    [sym_addfirst_modification] = STATE(2688),
    [sym_addlast_modification] = STATE(2688),
    [sym_addafter_modification] = STATE(2688),
    [sym_addbefore_modification] = STATE(2688),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2688),
    [sym_movelast_modification] = STATE(2688),
    [sym_moveafter_modification] = STATE(2688),
    [sym_movebefore_modification] = STATE(2688),
    [sym_actions_section] = STATE(2688),
    [sym_views_section] = STATE(2688),
    [sym_dataset_section] = STATE(2688),
    [sym_requestpage_section] = STATE(2688),
    [sym_rendering_section] = STATE(2688),
    [sym_elements_section] = STATE(2688),
    [sym_schema_section] = STATE(2688),
    [sym_assembly_declaration] = STATE(2688),
    [sym_event_declaration] = STATE(2688),
    [sym_procedure] = STATE(2688),
    [sym_preproc_split_procedure] = STATE(2688),
    [sym_preproc_split_procedure_preamble] = STATE(2688),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2688),
    [sym_var_section] = STATE(2688),
    [sym_attribute_item] = STATE(2688),
    [sym_preproc_conditional] = STATE(2688),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2688),
    [sym_preproc_conditional_layout_mixed] = STATE(2688),
    [aux_sym_group_section_repeat1] = STATE(2688),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6631),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2674)] = {
    [sym__body_element] = STATE(2689),
    [sym_empty_statement] = STATE(2689),
    [sym_property] = STATE(2689),
    [sym_permissions_property] = STATE(2689),
    [sym_table_relation_property] = STATE(2689),
    [sym_fields_section] = STATE(2689),
    [sym_keys_section] = STATE(2689),
    [sym_fieldgroups_section] = STATE(2689),
    [sym_enum_value_declaration] = STATE(2689),
    [sym_labels_section] = STATE(2689),
    [sym_layout_section] = STATE(2689),
    [sym__layout_element] = STATE(2689),
    [sym_area_section] = STATE(2689),
    [sym_group_section] = STATE(2689),
    [sym_repeater_section] = STATE(2689),
    [sym_cuegroup_section] = STATE(2689),
    [sym_fixed_section] = STATE(2689),
    [sym_grid_section] = STATE(2689),
    [sym_page_field] = STATE(2689),
    [sym_part_section] = STATE(2689),
    [sym_systempart_section] = STATE(2689),
    [sym_usercontrol_section] = STATE(2689),
    [sym_preproc_split_field] = STATE(2689),
    [sym_label_section] = STATE(2689),
    [sym_addfirst_modification] = STATE(2689),
    [sym_addlast_modification] = STATE(2689),
    [sym_addafter_modification] = STATE(2689),
    [sym_addbefore_modification] = STATE(2689),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2689),
    [sym_movelast_modification] = STATE(2689),
    [sym_moveafter_modification] = STATE(2689),
    [sym_movebefore_modification] = STATE(2689),
    [sym_actions_section] = STATE(2689),
    [sym_views_section] = STATE(2689),
    [sym_dataset_section] = STATE(2689),
    [sym_requestpage_section] = STATE(2689),
    [sym_rendering_section] = STATE(2689),
    [sym_elements_section] = STATE(2689),
    [sym_schema_section] = STATE(2689),
    [sym_assembly_declaration] = STATE(2689),
    [sym_event_declaration] = STATE(2689),
    [sym_procedure] = STATE(2689),
    [sym_preproc_split_procedure] = STATE(2689),
    [sym_preproc_split_procedure_preamble] = STATE(2689),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2689),
    [sym_var_section] = STATE(2689),
    [sym_attribute_item] = STATE(2689),
    [sym_preproc_conditional] = STATE(2689),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2689),
    [sym_preproc_conditional_layout_mixed] = STATE(2689),
    [aux_sym_group_section_repeat1] = STATE(2689),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6633),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2675)] = {
    [sym__body_element] = STATE(2655),
    [sym_empty_statement] = STATE(2655),
    [sym_property] = STATE(2655),
    [sym_permissions_property] = STATE(2655),
    [sym_table_relation_property] = STATE(2655),
    [sym_fields_section] = STATE(2655),
    [sym_keys_section] = STATE(2655),
    [sym_fieldgroups_section] = STATE(2655),
    [sym_enum_value_declaration] = STATE(2655),
    [sym_labels_section] = STATE(2655),
    [sym_layout_section] = STATE(2655),
    [sym__layout_element] = STATE(2655),
    [sym_area_section] = STATE(2655),
    [sym_group_section] = STATE(2655),
    [sym_repeater_section] = STATE(2655),
    [sym_cuegroup_section] = STATE(2655),
    [sym_fixed_section] = STATE(2655),
    [sym_grid_section] = STATE(2655),
    [sym_page_field] = STATE(2655),
    [sym_part_section] = STATE(2655),
    [sym_systempart_section] = STATE(2655),
    [sym_usercontrol_section] = STATE(2655),
    [sym_preproc_split_field] = STATE(2655),
    [sym_label_section] = STATE(2655),
    [sym_addfirst_modification] = STATE(2655),
    [sym_addlast_modification] = STATE(2655),
    [sym_addafter_modification] = STATE(2655),
    [sym_addbefore_modification] = STATE(2655),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2655),
    [sym_movelast_modification] = STATE(2655),
    [sym_moveafter_modification] = STATE(2655),
    [sym_movebefore_modification] = STATE(2655),
    [sym_actions_section] = STATE(2655),
    [sym_views_section] = STATE(2655),
    [sym_dataset_section] = STATE(2655),
    [sym_requestpage_section] = STATE(2655),
    [sym_rendering_section] = STATE(2655),
    [sym_elements_section] = STATE(2655),
    [sym_schema_section] = STATE(2655),
    [sym_assembly_declaration] = STATE(2655),
    [sym_event_declaration] = STATE(2655),
    [sym_procedure] = STATE(2655),
    [sym_preproc_split_procedure] = STATE(2655),
    [sym_preproc_split_procedure_preamble] = STATE(2655),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2655),
    [sym_var_section] = STATE(2655),
    [sym_attribute_item] = STATE(2655),
    [sym_preproc_conditional] = STATE(2655),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2655),
    [sym_preproc_conditional_layout_mixed] = STATE(2655),
    [aux_sym_group_section_repeat1] = STATE(2655),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6635),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2676)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12990),
    [sym_else_table_relation_fragment] = STATE(12990),
    [sym_table_relation_expression] = STATE(12990),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6258),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(2677)] = {
    [sym__body_element] = STATE(2656),
    [sym_empty_statement] = STATE(2656),
    [sym_property] = STATE(2656),
    [sym_permissions_property] = STATE(2656),
    [sym_table_relation_property] = STATE(2656),
    [sym_fields_section] = STATE(2656),
    [sym_keys_section] = STATE(2656),
    [sym_fieldgroups_section] = STATE(2656),
    [sym_enum_value_declaration] = STATE(2656),
    [sym_labels_section] = STATE(2656),
    [sym_layout_section] = STATE(2656),
    [sym__layout_element] = STATE(2656),
    [sym_area_section] = STATE(2656),
    [sym_group_section] = STATE(2656),
    [sym_repeater_section] = STATE(2656),
    [sym_cuegroup_section] = STATE(2656),
    [sym_fixed_section] = STATE(2656),
    [sym_grid_section] = STATE(2656),
    [sym_page_field] = STATE(2656),
    [sym_part_section] = STATE(2656),
    [sym_systempart_section] = STATE(2656),
    [sym_usercontrol_section] = STATE(2656),
    [sym_preproc_split_field] = STATE(2656),
    [sym_label_section] = STATE(2656),
    [sym_addfirst_modification] = STATE(2656),
    [sym_addlast_modification] = STATE(2656),
    [sym_addafter_modification] = STATE(2656),
    [sym_addbefore_modification] = STATE(2656),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2656),
    [sym_movelast_modification] = STATE(2656),
    [sym_moveafter_modification] = STATE(2656),
    [sym_movebefore_modification] = STATE(2656),
    [sym_actions_section] = STATE(2656),
    [sym_views_section] = STATE(2656),
    [sym_dataset_section] = STATE(2656),
    [sym_requestpage_section] = STATE(2656),
    [sym_rendering_section] = STATE(2656),
    [sym_elements_section] = STATE(2656),
    [sym_schema_section] = STATE(2656),
    [sym_assembly_declaration] = STATE(2656),
    [sym_event_declaration] = STATE(2656),
    [sym_procedure] = STATE(2656),
    [sym_preproc_split_procedure] = STATE(2656),
    [sym_preproc_split_procedure_preamble] = STATE(2656),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2656),
    [sym_var_section] = STATE(2656),
    [sym_attribute_item] = STATE(2656),
    [sym_preproc_conditional] = STATE(2656),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2656),
    [sym_preproc_conditional_layout_mixed] = STATE(2656),
    [aux_sym_group_section_repeat1] = STATE(2656),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6637),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2678)] = {
    [sym__body_element] = STATE(2690),
    [sym_empty_statement] = STATE(2690),
    [sym_property] = STATE(2690),
    [sym_permissions_property] = STATE(2690),
    [sym_table_relation_property] = STATE(2690),
    [sym_fields_section] = STATE(2690),
    [sym_keys_section] = STATE(2690),
    [sym_fieldgroups_section] = STATE(2690),
    [sym_enum_value_declaration] = STATE(2690),
    [sym_labels_section] = STATE(2690),
    [sym_layout_section] = STATE(2690),
    [sym__layout_element] = STATE(2690),
    [sym_area_section] = STATE(2690),
    [sym_group_section] = STATE(2690),
    [sym_repeater_section] = STATE(2690),
    [sym_cuegroup_section] = STATE(2690),
    [sym_fixed_section] = STATE(2690),
    [sym_grid_section] = STATE(2690),
    [sym_page_field] = STATE(2690),
    [sym_part_section] = STATE(2690),
    [sym_systempart_section] = STATE(2690),
    [sym_usercontrol_section] = STATE(2690),
    [sym_preproc_split_field] = STATE(2690),
    [sym_label_section] = STATE(2690),
    [sym_addfirst_modification] = STATE(2690),
    [sym_addlast_modification] = STATE(2690),
    [sym_addafter_modification] = STATE(2690),
    [sym_addbefore_modification] = STATE(2690),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2690),
    [sym_movelast_modification] = STATE(2690),
    [sym_moveafter_modification] = STATE(2690),
    [sym_movebefore_modification] = STATE(2690),
    [sym_actions_section] = STATE(2690),
    [sym_views_section] = STATE(2690),
    [sym_dataset_section] = STATE(2690),
    [sym_requestpage_section] = STATE(2690),
    [sym_rendering_section] = STATE(2690),
    [sym_elements_section] = STATE(2690),
    [sym_schema_section] = STATE(2690),
    [sym_assembly_declaration] = STATE(2690),
    [sym_event_declaration] = STATE(2690),
    [sym_procedure] = STATE(2690),
    [sym_preproc_split_procedure] = STATE(2690),
    [sym_preproc_split_procedure_preamble] = STATE(2690),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2690),
    [sym_var_section] = STATE(2690),
    [sym_attribute_item] = STATE(2690),
    [sym_preproc_conditional] = STATE(2690),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2690),
    [sym_preproc_conditional_layout_mixed] = STATE(2690),
    [aux_sym_group_section_repeat1] = STATE(2690),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6639),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2679)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12773),
    [sym_else_table_relation_fragment] = STATE(12773),
    [sym_table_relation_expression] = STATE(12773),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(11325),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4895),
    [anon_sym_POUNDENDIF] = ACTIONS(4895),
    [anon_sym_POUNDEndif] = ACTIONS(4895),
    [anon_sym_POUNDendif2] = ACTIONS(4895),
    [anon_sym_POUNDENDIF2] = ACTIONS(4895),
    [anon_sym_POUNDEndif2] = ACTIONS(4895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4895),
  },
  [STATE(2680)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12891),
    [sym_else_table_relation_fragment] = STATE(12891),
    [sym_table_relation_expression] = STATE(12891),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(11346),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4895),
    [anon_sym_POUNDENDIF] = ACTIONS(4895),
    [anon_sym_POUNDEndif] = ACTIONS(4895),
    [anon_sym_POUNDendif2] = ACTIONS(4895),
    [anon_sym_POUNDENDIF2] = ACTIONS(4895),
    [anon_sym_POUNDEndif2] = ACTIONS(4895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4895),
  },
  [STATE(2681)] = {
    [sym_identifier] = ACTIONS(6641),
    [anon_sym_SEMI] = ACTIONS(6643),
    [anon_sym_DASH] = ACTIONS(6643),
    [aux_sym_boolean_token1] = ACTIONS(6641),
    [aux_sym_boolean_token2] = ACTIONS(6641),
    [sym_decimal] = ACTIONS(6641),
    [anon_sym_LPAREN] = ACTIONS(6643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6641),
    [anon_sym_LBRACK] = ACTIONS(6643),
    [aux_sym_record_type_token1] = ACTIONS(6641),
    [aux_sym_basic_type_token21] = ACTIONS(6641),
    [aux_sym_basic_type_token22] = ACTIONS(6641),
    [aux_sym_basic_type_token48] = ACTIONS(6641),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(6641),
    [anon_sym_POUNDif] = ACTIONS(6643),
    [anon_sym_POUNDIF] = ACTIONS(6643),
    [anon_sym_POUNDIf] = ACTIONS(6643),
    [anon_sym_not] = ACTIONS(6641),
    [anon_sym_NOT] = ACTIONS(6641),
    [anon_sym_Not] = ACTIONS(6641),
    [anon_sym_POUNDelif] = ACTIONS(6643),
    [anon_sym_POUNDELIF] = ACTIONS(6643),
    [anon_sym_POUNDElif] = ACTIONS(6643),
    [anon_sym_POUNDelse] = ACTIONS(6643),
    [anon_sym_POUNDELSE] = ACTIONS(6643),
    [anon_sym_POUNDElse] = ACTIONS(6643),
    [anon_sym_POUNDelse2] = ACTIONS(6643),
    [anon_sym_POUNDELSE2] = ACTIONS(6643),
    [anon_sym_POUNDElse2] = ACTIONS(6643),
    [anon_sym_POUNDendif] = ACTIONS(6643),
    [anon_sym_POUNDENDIF] = ACTIONS(6643),
    [anon_sym_POUNDEndif] = ACTIONS(6643),
    [anon_sym_POUNDendif2] = ACTIONS(6643),
    [anon_sym_POUNDENDIF2] = ACTIONS(6643),
    [anon_sym_POUNDEndif2] = ACTIONS(6643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6641),
    [anon_sym_PLUS] = ACTIONS(6643),
    [sym_datetime_literal] = ACTIONS(6643),
    [sym_date_literal] = ACTIONS(6641),
    [sym_time_literal] = ACTIONS(6641),
    [sym_biginteger_literal] = ACTIONS(6643),
    [anon_sym_if] = ACTIONS(6641),
    [anon_sym_IF] = ACTIONS(6641),
    [anon_sym_If] = ACTIONS(6641),
    [anon_sym_case] = ACTIONS(6641),
    [anon_sym_CASE] = ACTIONS(6641),
    [anon_sym_Case] = ACTIONS(6641),
    [anon_sym_for] = ACTIONS(6641),
    [anon_sym_FOR] = ACTIONS(6641),
    [anon_sym_For] = ACTIONS(6641),
    [anon_sym_foreach] = ACTIONS(6641),
    [anon_sym_FOREACH] = ACTIONS(6641),
    [anon_sym_Foreach] = ACTIONS(6641),
    [anon_sym_while] = ACTIONS(6641),
    [anon_sym_WHILE] = ACTIONS(6641),
    [anon_sym_While] = ACTIONS(6641),
    [anon_sym_repeat] = ACTIONS(6641),
    [anon_sym_REPEAT] = ACTIONS(6641),
    [anon_sym_Repeat] = ACTIONS(6641),
    [anon_sym_exit] = ACTIONS(6641),
    [anon_sym_EXIT] = ACTIONS(6641),
    [anon_sym_Exit] = ACTIONS(6641),
    [anon_sym_continue] = ACTIONS(6641),
    [anon_sym_CONTINUE] = ACTIONS(6641),
    [anon_sym_Continue] = ACTIONS(6641),
    [anon_sym_break] = ACTIONS(6641),
    [anon_sym_BREAK] = ACTIONS(6641),
    [anon_sym_Break] = ACTIONS(6641),
    [anon_sym_with] = ACTIONS(6641),
    [anon_sym_WITH] = ACTIONS(6641),
    [anon_sym_With] = ACTIONS(6641),
    [sym_asserterror_keyword] = ACTIONS(6643),
    [sym_page_keyword] = ACTIONS(6641),
    [anon_sym_codeunit] = ACTIONS(6641),
    [anon_sym_CODEUNIT] = ACTIONS(6641),
    [anon_sym_Codeunit] = ACTIONS(6641),
    [anon_sym_CodeUnit] = ACTIONS(6641),
    [anon_sym_COdeunit] = ACTIONS(6641),
    [anon_sym_codeUnit] = ACTIONS(6641),
    [sym_report_keyword] = ACTIONS(6641),
    [sym_query_keyword] = ACTIONS(6641),
    [anon_sym_xmlport] = ACTIONS(6641),
    [anon_sym_XMLPORT] = ACTIONS(6641),
    [anon_sym_Xmlport] = ACTIONS(6641),
    [anon_sym_XMLport] = ACTIONS(6641),
    [anon_sym_XMLPort] = ACTIONS(6641),
    [anon_sym_XmlPort] = ACTIONS(6641),
    [anon_sym_enum] = ACTIONS(6641),
    [anon_sym_ENUM] = ACTIONS(6641),
    [anon_sym_Enum] = ACTIONS(6641),
    [anon_sym_eNUM] = ACTIONS(6641),
    [anon_sym_eNum] = ACTIONS(6641),
    [anon_sym_ENum] = ACTIONS(6641),
    [sym_quoted_identifier] = ACTIONS(6643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6643),
    [sym_verbatim_string] = ACTIONS(6643),
    [sym_integer] = ACTIONS(6641),
    [sym_continue_as_identifier] = ACTIONS(6643),
    [sym_preproc_open] = ACTIONS(6643),
    [sym_preproc_close] = ACTIONS(6643),
    [sym_begin_keyword] = ACTIONS(6643),
    [sym_preproc_split_begin] = ACTIONS(6643),
  },
  [STATE(2682)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6645),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2683)] = {
    [sym__body_element] = STATE(2693),
    [sym_empty_statement] = STATE(2693),
    [sym_property] = STATE(2693),
    [sym_permissions_property] = STATE(2693),
    [sym_table_relation_property] = STATE(2693),
    [sym_fields_section] = STATE(2693),
    [sym_keys_section] = STATE(2693),
    [sym_fieldgroups_section] = STATE(2693),
    [sym_enum_value_declaration] = STATE(2693),
    [sym_labels_section] = STATE(2693),
    [sym_layout_section] = STATE(2693),
    [sym__layout_element] = STATE(2693),
    [sym_area_section] = STATE(2693),
    [sym_group_section] = STATE(2693),
    [sym_repeater_section] = STATE(2693),
    [sym_cuegroup_section] = STATE(2693),
    [sym_fixed_section] = STATE(2693),
    [sym_grid_section] = STATE(2693),
    [sym_page_field] = STATE(2693),
    [sym_part_section] = STATE(2693),
    [sym_systempart_section] = STATE(2693),
    [sym_usercontrol_section] = STATE(2693),
    [sym_preproc_split_field] = STATE(2693),
    [sym_label_section] = STATE(2693),
    [sym_addfirst_modification] = STATE(2693),
    [sym_addlast_modification] = STATE(2693),
    [sym_addafter_modification] = STATE(2693),
    [sym_addbefore_modification] = STATE(2693),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2693),
    [sym_movelast_modification] = STATE(2693),
    [sym_moveafter_modification] = STATE(2693),
    [sym_movebefore_modification] = STATE(2693),
    [sym_actions_section] = STATE(2693),
    [sym_views_section] = STATE(2693),
    [sym_dataset_section] = STATE(2693),
    [sym_requestpage_section] = STATE(2693),
    [sym_rendering_section] = STATE(2693),
    [sym_elements_section] = STATE(2693),
    [sym_schema_section] = STATE(2693),
    [sym_assembly_declaration] = STATE(2693),
    [sym_event_declaration] = STATE(2693),
    [sym_procedure] = STATE(2693),
    [sym_preproc_split_procedure] = STATE(2693),
    [sym_preproc_split_procedure_preamble] = STATE(2693),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2693),
    [sym_var_section] = STATE(2693),
    [sym_attribute_item] = STATE(2693),
    [sym_preproc_conditional] = STATE(2693),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2693),
    [sym_preproc_conditional_layout_mixed] = STATE(2693),
    [aux_sym_group_section_repeat1] = STATE(2693),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6647),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2684)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6649),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2685)] = {
    [sym__body_element] = STATE(2695),
    [sym_empty_statement] = STATE(2695),
    [sym_property] = STATE(2695),
    [sym_permissions_property] = STATE(2695),
    [sym_table_relation_property] = STATE(2695),
    [sym_fields_section] = STATE(2695),
    [sym_keys_section] = STATE(2695),
    [sym_fieldgroups_section] = STATE(2695),
    [sym_enum_value_declaration] = STATE(2695),
    [sym_labels_section] = STATE(2695),
    [sym_layout_section] = STATE(2695),
    [sym__layout_element] = STATE(2695),
    [sym_area_section] = STATE(2695),
    [sym_group_section] = STATE(2695),
    [sym_repeater_section] = STATE(2695),
    [sym_cuegroup_section] = STATE(2695),
    [sym_fixed_section] = STATE(2695),
    [sym_grid_section] = STATE(2695),
    [sym_page_field] = STATE(2695),
    [sym_part_section] = STATE(2695),
    [sym_systempart_section] = STATE(2695),
    [sym_usercontrol_section] = STATE(2695),
    [sym_preproc_split_field] = STATE(2695),
    [sym_label_section] = STATE(2695),
    [sym_addfirst_modification] = STATE(2695),
    [sym_addlast_modification] = STATE(2695),
    [sym_addafter_modification] = STATE(2695),
    [sym_addbefore_modification] = STATE(2695),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2695),
    [sym_movelast_modification] = STATE(2695),
    [sym_moveafter_modification] = STATE(2695),
    [sym_movebefore_modification] = STATE(2695),
    [sym_actions_section] = STATE(2695),
    [sym_views_section] = STATE(2695),
    [sym_dataset_section] = STATE(2695),
    [sym_requestpage_section] = STATE(2695),
    [sym_rendering_section] = STATE(2695),
    [sym_elements_section] = STATE(2695),
    [sym_schema_section] = STATE(2695),
    [sym_assembly_declaration] = STATE(2695),
    [sym_event_declaration] = STATE(2695),
    [sym_procedure] = STATE(2695),
    [sym_preproc_split_procedure] = STATE(2695),
    [sym_preproc_split_procedure_preamble] = STATE(2695),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2695),
    [sym_var_section] = STATE(2695),
    [sym_attribute_item] = STATE(2695),
    [sym_preproc_conditional] = STATE(2695),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2695),
    [sym_preproc_conditional_layout_mixed] = STATE(2695),
    [aux_sym_group_section_repeat1] = STATE(2695),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6651),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2686)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6653),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2687)] = {
    [sym__body_element] = STATE(2707),
    [sym_empty_statement] = STATE(2707),
    [sym_property] = STATE(2707),
    [sym_permissions_property] = STATE(2707),
    [sym_table_relation_property] = STATE(2707),
    [sym_fields_section] = STATE(2707),
    [sym_keys_section] = STATE(2707),
    [sym_fieldgroups_section] = STATE(2707),
    [sym_enum_value_declaration] = STATE(2707),
    [sym_labels_section] = STATE(2707),
    [sym_layout_section] = STATE(2707),
    [sym__layout_element] = STATE(2707),
    [sym_area_section] = STATE(2707),
    [sym_group_section] = STATE(2707),
    [sym_repeater_section] = STATE(2707),
    [sym_cuegroup_section] = STATE(2707),
    [sym_fixed_section] = STATE(2707),
    [sym_grid_section] = STATE(2707),
    [sym_page_field] = STATE(2707),
    [sym_part_section] = STATE(2707),
    [sym_systempart_section] = STATE(2707),
    [sym_usercontrol_section] = STATE(2707),
    [sym_preproc_split_field] = STATE(2707),
    [sym_label_section] = STATE(2707),
    [sym_addfirst_modification] = STATE(2707),
    [sym_addlast_modification] = STATE(2707),
    [sym_addafter_modification] = STATE(2707),
    [sym_addbefore_modification] = STATE(2707),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2707),
    [sym_movelast_modification] = STATE(2707),
    [sym_moveafter_modification] = STATE(2707),
    [sym_movebefore_modification] = STATE(2707),
    [sym_actions_section] = STATE(2707),
    [sym_views_section] = STATE(2707),
    [sym_dataset_section] = STATE(2707),
    [sym_requestpage_section] = STATE(2707),
    [sym_rendering_section] = STATE(2707),
    [sym_elements_section] = STATE(2707),
    [sym_schema_section] = STATE(2707),
    [sym_assembly_declaration] = STATE(2707),
    [sym_event_declaration] = STATE(2707),
    [sym_procedure] = STATE(2707),
    [sym_preproc_split_procedure] = STATE(2707),
    [sym_preproc_split_procedure_preamble] = STATE(2707),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2707),
    [sym_var_section] = STATE(2707),
    [sym_attribute_item] = STATE(2707),
    [sym_preproc_conditional] = STATE(2707),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2707),
    [sym_preproc_conditional_layout_mixed] = STATE(2707),
    [aux_sym_group_section_repeat1] = STATE(2707),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6655),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2688)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6657),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2689)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6659),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2690)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6661),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2691)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6663),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2692)] = {
    [sym__body_element] = STATE(2642),
    [sym_empty_statement] = STATE(2642),
    [sym_property] = STATE(2642),
    [sym_permissions_property] = STATE(2642),
    [sym_table_relation_property] = STATE(2642),
    [sym_fields_section] = STATE(2642),
    [sym_keys_section] = STATE(2642),
    [sym_fieldgroups_section] = STATE(2642),
    [sym_enum_value_declaration] = STATE(2642),
    [sym_labels_section] = STATE(2642),
    [sym_layout_section] = STATE(2642),
    [sym__layout_element] = STATE(2642),
    [sym_area_section] = STATE(2642),
    [sym_group_section] = STATE(2642),
    [sym_repeater_section] = STATE(2642),
    [sym_cuegroup_section] = STATE(2642),
    [sym_fixed_section] = STATE(2642),
    [sym_grid_section] = STATE(2642),
    [sym_page_field] = STATE(2642),
    [sym_part_section] = STATE(2642),
    [sym_systempart_section] = STATE(2642),
    [sym_usercontrol_section] = STATE(2642),
    [sym_preproc_split_field] = STATE(2642),
    [sym_label_section] = STATE(2642),
    [sym_addfirst_modification] = STATE(2642),
    [sym_addlast_modification] = STATE(2642),
    [sym_addafter_modification] = STATE(2642),
    [sym_addbefore_modification] = STATE(2642),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2642),
    [sym_movelast_modification] = STATE(2642),
    [sym_moveafter_modification] = STATE(2642),
    [sym_movebefore_modification] = STATE(2642),
    [sym_actions_section] = STATE(2642),
    [sym_views_section] = STATE(2642),
    [sym_dataset_section] = STATE(2642),
    [sym_requestpage_section] = STATE(2642),
    [sym_rendering_section] = STATE(2642),
    [sym_elements_section] = STATE(2642),
    [sym_schema_section] = STATE(2642),
    [sym_assembly_declaration] = STATE(2642),
    [sym_event_declaration] = STATE(2642),
    [sym_procedure] = STATE(2642),
    [sym_preproc_split_procedure] = STATE(2642),
    [sym_preproc_split_procedure_preamble] = STATE(2642),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2642),
    [sym_var_section] = STATE(2642),
    [sym_attribute_item] = STATE(2642),
    [sym_preproc_conditional] = STATE(2642),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2642),
    [sym_preproc_conditional_layout_mixed] = STATE(2642),
    [aux_sym_group_section_repeat1] = STATE(2642),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6665),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2693)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6667),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2694)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6669),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2695)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6671),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2696)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13320),
    [sym_else_table_relation_fragment] = STATE(13320),
    [sym_table_relation_expression] = STATE(13320),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6880),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(2697)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13147),
    [sym_else_table_relation_fragment] = STATE(13147),
    [sym_table_relation_expression] = STATE(13147),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6211),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(2698)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13141),
    [sym_else_table_relation_fragment] = STATE(13141),
    [sym_table_relation_expression] = STATE(13141),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(5216),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(2699)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13146),
    [sym_else_table_relation_fragment] = STATE(13146),
    [sym_table_relation_expression] = STATE(13146),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(5227),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(2700)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13328),
    [sym_else_table_relation_fragment] = STATE(13328),
    [sym_table_relation_expression] = STATE(13328),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6684),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(2701)] = {
    [sym_identifier] = ACTIONS(6673),
    [anon_sym_SEMI] = ACTIONS(6675),
    [anon_sym_DASH] = ACTIONS(6675),
    [aux_sym_boolean_token1] = ACTIONS(6673),
    [aux_sym_boolean_token2] = ACTIONS(6673),
    [sym_decimal] = ACTIONS(6673),
    [anon_sym_LPAREN] = ACTIONS(6675),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6673),
    [anon_sym_LBRACK] = ACTIONS(6675),
    [aux_sym_record_type_token1] = ACTIONS(6673),
    [aux_sym_basic_type_token21] = ACTIONS(6673),
    [aux_sym_basic_type_token22] = ACTIONS(6673),
    [aux_sym_basic_type_token48] = ACTIONS(6673),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(6673),
    [anon_sym_POUNDif] = ACTIONS(6675),
    [anon_sym_POUNDIF] = ACTIONS(6675),
    [anon_sym_POUNDIf] = ACTIONS(6675),
    [anon_sym_not] = ACTIONS(6673),
    [anon_sym_NOT] = ACTIONS(6673),
    [anon_sym_Not] = ACTIONS(6673),
    [anon_sym_POUNDelif] = ACTIONS(6675),
    [anon_sym_POUNDELIF] = ACTIONS(6675),
    [anon_sym_POUNDElif] = ACTIONS(6675),
    [anon_sym_POUNDelse] = ACTIONS(6675),
    [anon_sym_POUNDELSE] = ACTIONS(6675),
    [anon_sym_POUNDElse] = ACTIONS(6675),
    [anon_sym_POUNDelse2] = ACTIONS(6675),
    [anon_sym_POUNDELSE2] = ACTIONS(6675),
    [anon_sym_POUNDElse2] = ACTIONS(6675),
    [anon_sym_POUNDendif] = ACTIONS(6675),
    [anon_sym_POUNDENDIF] = ACTIONS(6675),
    [anon_sym_POUNDEndif] = ACTIONS(6675),
    [anon_sym_POUNDendif2] = ACTIONS(6675),
    [anon_sym_POUNDENDIF2] = ACTIONS(6675),
    [anon_sym_POUNDEndif2] = ACTIONS(6675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6673),
    [anon_sym_PLUS] = ACTIONS(6675),
    [sym_datetime_literal] = ACTIONS(6675),
    [sym_date_literal] = ACTIONS(6673),
    [sym_time_literal] = ACTIONS(6673),
    [sym_biginteger_literal] = ACTIONS(6675),
    [anon_sym_if] = ACTIONS(6673),
    [anon_sym_IF] = ACTIONS(6673),
    [anon_sym_If] = ACTIONS(6673),
    [anon_sym_case] = ACTIONS(6673),
    [anon_sym_CASE] = ACTIONS(6673),
    [anon_sym_Case] = ACTIONS(6673),
    [anon_sym_for] = ACTIONS(6673),
    [anon_sym_FOR] = ACTIONS(6673),
    [anon_sym_For] = ACTIONS(6673),
    [anon_sym_foreach] = ACTIONS(6673),
    [anon_sym_FOREACH] = ACTIONS(6673),
    [anon_sym_Foreach] = ACTIONS(6673),
    [anon_sym_while] = ACTIONS(6673),
    [anon_sym_WHILE] = ACTIONS(6673),
    [anon_sym_While] = ACTIONS(6673),
    [anon_sym_repeat] = ACTIONS(6673),
    [anon_sym_REPEAT] = ACTIONS(6673),
    [anon_sym_Repeat] = ACTIONS(6673),
    [anon_sym_exit] = ACTIONS(6673),
    [anon_sym_EXIT] = ACTIONS(6673),
    [anon_sym_Exit] = ACTIONS(6673),
    [anon_sym_continue] = ACTIONS(6673),
    [anon_sym_CONTINUE] = ACTIONS(6673),
    [anon_sym_Continue] = ACTIONS(6673),
    [anon_sym_break] = ACTIONS(6673),
    [anon_sym_BREAK] = ACTIONS(6673),
    [anon_sym_Break] = ACTIONS(6673),
    [anon_sym_with] = ACTIONS(6673),
    [anon_sym_WITH] = ACTIONS(6673),
    [anon_sym_With] = ACTIONS(6673),
    [sym_asserterror_keyword] = ACTIONS(6675),
    [sym_page_keyword] = ACTIONS(6673),
    [anon_sym_codeunit] = ACTIONS(6673),
    [anon_sym_CODEUNIT] = ACTIONS(6673),
    [anon_sym_Codeunit] = ACTIONS(6673),
    [anon_sym_CodeUnit] = ACTIONS(6673),
    [anon_sym_COdeunit] = ACTIONS(6673),
    [anon_sym_codeUnit] = ACTIONS(6673),
    [sym_report_keyword] = ACTIONS(6673),
    [sym_query_keyword] = ACTIONS(6673),
    [anon_sym_xmlport] = ACTIONS(6673),
    [anon_sym_XMLPORT] = ACTIONS(6673),
    [anon_sym_Xmlport] = ACTIONS(6673),
    [anon_sym_XMLport] = ACTIONS(6673),
    [anon_sym_XMLPort] = ACTIONS(6673),
    [anon_sym_XmlPort] = ACTIONS(6673),
    [anon_sym_enum] = ACTIONS(6673),
    [anon_sym_ENUM] = ACTIONS(6673),
    [anon_sym_Enum] = ACTIONS(6673),
    [anon_sym_eNUM] = ACTIONS(6673),
    [anon_sym_eNum] = ACTIONS(6673),
    [anon_sym_ENum] = ACTIONS(6673),
    [sym_quoted_identifier] = ACTIONS(6675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6675),
    [sym_verbatim_string] = ACTIONS(6675),
    [sym_integer] = ACTIONS(6673),
    [sym_continue_as_identifier] = ACTIONS(6675),
    [sym_preproc_open] = ACTIONS(6675),
    [sym_preproc_close] = ACTIONS(6675),
    [sym_begin_keyword] = ACTIONS(6675),
    [sym_preproc_split_begin] = ACTIONS(6675),
  },
  [STATE(2702)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12505),
    [sym_else_table_relation_fragment] = STATE(12505),
    [sym_table_relation_expression] = STATE(12505),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6088),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2703)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12517),
    [sym_else_table_relation_fragment] = STATE(12517),
    [sym_table_relation_expression] = STATE(12517),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6070),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2704)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12973),
    [sym_else_table_relation_fragment] = STATE(12973),
    [sym_table_relation_expression] = STATE(12973),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(11347),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4895),
    [anon_sym_POUNDENDIF] = ACTIONS(4895),
    [anon_sym_POUNDEndif] = ACTIONS(4895),
    [anon_sym_POUNDendif2] = ACTIONS(4895),
    [anon_sym_POUNDENDIF2] = ACTIONS(4895),
    [anon_sym_POUNDEndif2] = ACTIONS(4895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4895),
  },
  [STATE(2705)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12525),
    [sym_else_table_relation_fragment] = STATE(12525),
    [sym_table_relation_expression] = STATE(12525),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6211),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2706)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12529),
    [sym_else_table_relation_fragment] = STATE(12529),
    [sym_table_relation_expression] = STATE(12529),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(6258),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(2707)] = {
    [sym__body_element] = STATE(2640),
    [sym_empty_statement] = STATE(2640),
    [sym_property] = STATE(2640),
    [sym_permissions_property] = STATE(2640),
    [sym_table_relation_property] = STATE(2640),
    [sym_fields_section] = STATE(2640),
    [sym_keys_section] = STATE(2640),
    [sym_fieldgroups_section] = STATE(2640),
    [sym_enum_value_declaration] = STATE(2640),
    [sym_labels_section] = STATE(2640),
    [sym_layout_section] = STATE(2640),
    [sym__layout_element] = STATE(2640),
    [sym_area_section] = STATE(2640),
    [sym_group_section] = STATE(2640),
    [sym_repeater_section] = STATE(2640),
    [sym_cuegroup_section] = STATE(2640),
    [sym_fixed_section] = STATE(2640),
    [sym_grid_section] = STATE(2640),
    [sym_page_field] = STATE(2640),
    [sym_part_section] = STATE(2640),
    [sym_systempart_section] = STATE(2640),
    [sym_usercontrol_section] = STATE(2640),
    [sym_preproc_split_field] = STATE(2640),
    [sym_label_section] = STATE(2640),
    [sym_addfirst_modification] = STATE(2640),
    [sym_addlast_modification] = STATE(2640),
    [sym_addafter_modification] = STATE(2640),
    [sym_addbefore_modification] = STATE(2640),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2640),
    [sym_movelast_modification] = STATE(2640),
    [sym_moveafter_modification] = STATE(2640),
    [sym_movebefore_modification] = STATE(2640),
    [sym_actions_section] = STATE(2640),
    [sym_views_section] = STATE(2640),
    [sym_dataset_section] = STATE(2640),
    [sym_requestpage_section] = STATE(2640),
    [sym_rendering_section] = STATE(2640),
    [sym_elements_section] = STATE(2640),
    [sym_schema_section] = STATE(2640),
    [sym_assembly_declaration] = STATE(2640),
    [sym_event_declaration] = STATE(2640),
    [sym_procedure] = STATE(2640),
    [sym_preproc_split_procedure] = STATE(2640),
    [sym_preproc_split_procedure_preamble] = STATE(2640),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2640),
    [sym_var_section] = STATE(2640),
    [sym_attribute_item] = STATE(2640),
    [sym_preproc_conditional] = STATE(2640),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2640),
    [sym_preproc_conditional_layout_mixed] = STATE(2640),
    [aux_sym_group_section_repeat1] = STATE(2640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6677),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2708)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13149),
    [sym_else_table_relation_fragment] = STATE(13149),
    [sym_table_relation_expression] = STATE(13149),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(5240),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(2709)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12986),
    [sym_else_table_relation_fragment] = STATE(12986),
    [sym_table_relation_expression] = STATE(12986),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(11385),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4895),
    [anon_sym_POUNDENDIF] = ACTIONS(4895),
    [anon_sym_POUNDEndif] = ACTIONS(4895),
    [anon_sym_POUNDendif2] = ACTIONS(4895),
    [anon_sym_POUNDENDIF2] = ACTIONS(4895),
    [anon_sym_POUNDEndif2] = ACTIONS(4895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4895),
  },
  [STATE(2710)] = {
    [sym__body_element] = STATE(2691),
    [sym_empty_statement] = STATE(2691),
    [sym_property] = STATE(2691),
    [sym_permissions_property] = STATE(2691),
    [sym_table_relation_property] = STATE(2691),
    [sym_fields_section] = STATE(2691),
    [sym_keys_section] = STATE(2691),
    [sym_fieldgroups_section] = STATE(2691),
    [sym_enum_value_declaration] = STATE(2691),
    [sym_labels_section] = STATE(2691),
    [sym_layout_section] = STATE(2691),
    [sym__layout_element] = STATE(2691),
    [sym_area_section] = STATE(2691),
    [sym_group_section] = STATE(2691),
    [sym_repeater_section] = STATE(2691),
    [sym_cuegroup_section] = STATE(2691),
    [sym_fixed_section] = STATE(2691),
    [sym_grid_section] = STATE(2691),
    [sym_page_field] = STATE(2691),
    [sym_part_section] = STATE(2691),
    [sym_systempart_section] = STATE(2691),
    [sym_usercontrol_section] = STATE(2691),
    [sym_preproc_split_field] = STATE(2691),
    [sym_label_section] = STATE(2691),
    [sym_addfirst_modification] = STATE(2691),
    [sym_addlast_modification] = STATE(2691),
    [sym_addafter_modification] = STATE(2691),
    [sym_addbefore_modification] = STATE(2691),
    [sym_modify_modification] = STATE(7987),
    [sym_movefirst_modification] = STATE(2691),
    [sym_movelast_modification] = STATE(2691),
    [sym_moveafter_modification] = STATE(2691),
    [sym_movebefore_modification] = STATE(2691),
    [sym_actions_section] = STATE(2691),
    [sym_views_section] = STATE(2691),
    [sym_dataset_section] = STATE(2691),
    [sym_requestpage_section] = STATE(2691),
    [sym_rendering_section] = STATE(2691),
    [sym_elements_section] = STATE(2691),
    [sym_schema_section] = STATE(2691),
    [sym_assembly_declaration] = STATE(2691),
    [sym_event_declaration] = STATE(2691),
    [sym_procedure] = STATE(2691),
    [sym_preproc_split_procedure] = STATE(2691),
    [sym_preproc_split_procedure_preamble] = STATE(2691),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(2691),
    [sym_var_section] = STATE(2691),
    [sym_attribute_item] = STATE(2691),
    [sym_preproc_conditional] = STATE(2691),
    [sym_preproc_if] = STATE(1949),
    [sym_preproc_conditional_layout] = STATE(2691),
    [sym_preproc_conditional_layout_mixed] = STATE(2691),
    [aux_sym_group_section_repeat1] = STATE(2691),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(6679),
    [aux_sym_where_condition_token1] = ACTIONS(6367),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6369),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token6] = ACTIONS(6375),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(6379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6381),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6385),
    [aux_sym_movelast_modification_token1] = ACTIONS(6387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6389),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(6415),
    [sym_group_keyword] = ACTIONS(6417),
    [sym_repeater_keyword] = ACTIONS(6419),
    [sym_cuegroup_keyword] = ACTIONS(6421),
    [sym_fixed_keyword] = ACTIONS(6423),
    [sym_grid_keyword] = ACTIONS(6425),
    [sym_part_keyword] = ACTIONS(6427),
    [sym_systempart_keyword] = ACTIONS(6429),
    [sym_usercontrol_keyword] = ACTIONS(6431),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6447),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(2711)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12603),
    [sym_else_table_relation_fragment] = STATE(12603),
    [sym_table_relation_expression] = STATE(12603),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(9498),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(2712)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12610),
    [sym_else_table_relation_fragment] = STATE(12610),
    [sym_table_relation_expression] = STATE(12610),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(9510),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(2713)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12616),
    [sym_else_table_relation_fragment] = STATE(12616),
    [sym_table_relation_expression] = STATE(12616),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(9517),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(2714)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12619),
    [sym_else_table_relation_fragment] = STATE(12619),
    [sym_table_relation_expression] = STATE(12619),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(9531),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(2715)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(13156),
    [sym_else_table_relation_fragment] = STATE(13156),
    [sym_table_relation_expression] = STATE(13156),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(5251),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(2716)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym__table_relation_branch_content] = STATE(12780),
    [sym_else_table_relation_fragment] = STATE(12780),
    [sym_table_relation_expression] = STATE(12780),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_preproc_endif] = STATE(7914),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(4369),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(2717)] = {
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_COLON] = ACTIONS(6000),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(6002),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_POUNDif] = ACTIONS(6002),
    [anon_sym_POUNDIF] = ACTIONS(6002),
    [anon_sym_POUNDIf] = ACTIONS(6002),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [anon_sym_POUNDelif] = ACTIONS(6002),
    [anon_sym_POUNDELIF] = ACTIONS(6002),
    [anon_sym_POUNDElif] = ACTIONS(6002),
    [anon_sym_POUNDelse] = ACTIONS(6002),
    [anon_sym_POUNDELSE] = ACTIONS(6002),
    [anon_sym_POUNDElse] = ACTIONS(6002),
    [anon_sym_POUNDelse2] = ACTIONS(6002),
    [anon_sym_POUNDELSE2] = ACTIONS(6002),
    [anon_sym_POUNDElse2] = ACTIONS(6002),
    [anon_sym_POUNDendif] = ACTIONS(6002),
    [anon_sym_POUNDENDIF] = ACTIONS(6002),
    [anon_sym_POUNDEndif] = ACTIONS(6002),
    [anon_sym_POUNDendif2] = ACTIONS(6002),
    [anon_sym_POUNDENDIF2] = ACTIONS(6002),
    [anon_sym_POUNDEndif2] = ACTIONS(6002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_open] = ACTIONS(6002),
    [sym_preproc_close] = ACTIONS(6002),
  },
  [STATE(2718)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(2722),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(11455),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2722),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDelif] = ACTIONS(6681),
    [anon_sym_POUNDELIF] = ACTIONS(6681),
    [anon_sym_POUNDElif] = ACTIONS(6681),
    [anon_sym_POUNDelse] = ACTIONS(6681),
    [anon_sym_POUNDELSE] = ACTIONS(6681),
    [anon_sym_POUNDElse] = ACTIONS(6681),
    [anon_sym_POUNDelse2] = ACTIONS(6681),
    [anon_sym_POUNDELSE2] = ACTIONS(6681),
    [anon_sym_POUNDElse2] = ACTIONS(6681),
    [anon_sym_POUNDendif] = ACTIONS(6681),
    [anon_sym_POUNDENDIF] = ACTIONS(6681),
    [anon_sym_POUNDEndif] = ACTIONS(6681),
    [anon_sym_POUNDendif2] = ACTIONS(6681),
    [anon_sym_POUNDENDIF2] = ACTIONS(6681),
    [anon_sym_POUNDEndif2] = ACTIONS(6681),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(6681),
  },
  [STATE(2719)] = {
    [sym_identifier] = ACTIONS(6683),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(6685),
    [anon_sym_COLON] = ACTIONS(6683),
    [anon_sym_DASH] = ACTIONS(6687),
    [aux_sym_boolean_token1] = ACTIONS(6683),
    [aux_sym_boolean_token2] = ACTIONS(6683),
    [sym_decimal] = ACTIONS(6683),
    [anon_sym_LPAREN] = ACTIONS(6685),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6683),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(6690),
    [aux_sym_record_type_token1] = ACTIONS(6683),
    [aux_sym_basic_type_token21] = ACTIONS(6683),
    [aux_sym_basic_type_token22] = ACTIONS(6683),
    [aux_sym_basic_type_token48] = ACTIONS(6683),
    [anon_sym_POUNDif] = ACTIONS(6685),
    [anon_sym_POUNDIF] = ACTIONS(6685),
    [anon_sym_POUNDIf] = ACTIONS(6685),
    [anon_sym_not] = ACTIONS(6683),
    [anon_sym_NOT] = ACTIONS(6683),
    [anon_sym_Not] = ACTIONS(6683),
    [anon_sym_POUNDelif] = ACTIONS(6685),
    [anon_sym_POUNDELIF] = ACTIONS(6685),
    [anon_sym_POUNDElif] = ACTIONS(6685),
    [anon_sym_POUNDelse] = ACTIONS(6685),
    [anon_sym_POUNDELSE] = ACTIONS(6685),
    [anon_sym_POUNDElse] = ACTIONS(6685),
    [anon_sym_POUNDelse2] = ACTIONS(6685),
    [anon_sym_POUNDELSE2] = ACTIONS(6685),
    [anon_sym_POUNDElse2] = ACTIONS(6685),
    [anon_sym_POUNDendif] = ACTIONS(6685),
    [anon_sym_POUNDENDIF] = ACTIONS(6685),
    [anon_sym_POUNDEndif] = ACTIONS(6685),
    [anon_sym_POUNDendif2] = ACTIONS(6685),
    [anon_sym_POUNDENDIF2] = ACTIONS(6685),
    [anon_sym_POUNDEndif2] = ACTIONS(6685),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6683),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6683),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(6687),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(6685),
    [sym_date_literal] = ACTIONS(6683),
    [sym_time_literal] = ACTIONS(6683),
    [sym_biginteger_literal] = ACTIONS(6685),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(6683),
    [anon_sym_codeunit] = ACTIONS(6683),
    [anon_sym_CODEUNIT] = ACTIONS(6683),
    [anon_sym_Codeunit] = ACTIONS(6683),
    [anon_sym_CodeUnit] = ACTIONS(6683),
    [anon_sym_COdeunit] = ACTIONS(6683),
    [anon_sym_codeUnit] = ACTIONS(6683),
    [sym_report_keyword] = ACTIONS(6683),
    [sym_query_keyword] = ACTIONS(6683),
    [anon_sym_xmlport] = ACTIONS(6683),
    [anon_sym_XMLPORT] = ACTIONS(6683),
    [anon_sym_Xmlport] = ACTIONS(6683),
    [anon_sym_XMLport] = ACTIONS(6683),
    [anon_sym_XMLPort] = ACTIONS(6683),
    [anon_sym_XmlPort] = ACTIONS(6683),
    [anon_sym_enum] = ACTIONS(6683),
    [anon_sym_ENUM] = ACTIONS(6683),
    [anon_sym_Enum] = ACTIONS(6683),
    [anon_sym_eNUM] = ACTIONS(6683),
    [anon_sym_eNum] = ACTIONS(6683),
    [anon_sym_ENum] = ACTIONS(6683),
    [sym_quoted_identifier] = ACTIONS(6685),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6685),
    [sym_verbatim_string] = ACTIONS(6685),
    [sym_integer] = ACTIONS(6683),
    [sym_continue_as_identifier] = ACTIONS(6685),
    [sym_preproc_open] = ACTIONS(6685),
    [sym_preproc_close] = ACTIONS(6685),
  },
  [STATE(2720)] = {
    [sym_identifier] = ACTIONS(6673),
    [anon_sym_SEMI] = ACTIONS(6675),
    [anon_sym_DASH] = ACTIONS(6675),
    [aux_sym_boolean_token1] = ACTIONS(6673),
    [aux_sym_boolean_token2] = ACTIONS(6673),
    [sym_decimal] = ACTIONS(6673),
    [anon_sym_LPAREN] = ACTIONS(6675),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6673),
    [anon_sym_LBRACK] = ACTIONS(6675),
    [aux_sym_record_type_token1] = ACTIONS(6673),
    [aux_sym_basic_type_token21] = ACTIONS(6673),
    [aux_sym_basic_type_token22] = ACTIONS(6673),
    [aux_sym_basic_type_token48] = ACTIONS(6673),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(6673),
    [anon_sym_POUNDif] = ACTIONS(6675),
    [anon_sym_POUNDIF] = ACTIONS(6675),
    [anon_sym_POUNDIf] = ACTIONS(6675),
    [anon_sym_not] = ACTIONS(6673),
    [anon_sym_NOT] = ACTIONS(6673),
    [anon_sym_Not] = ACTIONS(6673),
    [anon_sym_POUNDelif] = ACTIONS(6675),
    [anon_sym_POUNDELIF] = ACTIONS(6675),
    [anon_sym_POUNDElif] = ACTIONS(6675),
    [anon_sym_POUNDelse] = ACTIONS(6675),
    [anon_sym_POUNDELSE] = ACTIONS(6675),
    [anon_sym_POUNDElse] = ACTIONS(6675),
    [anon_sym_POUNDelse2] = ACTIONS(6675),
    [anon_sym_POUNDELSE2] = ACTIONS(6675),
    [anon_sym_POUNDElse2] = ACTIONS(6675),
    [anon_sym_POUNDendif] = ACTIONS(6675),
    [anon_sym_POUNDENDIF] = ACTIONS(6675),
    [anon_sym_POUNDEndif] = ACTIONS(6675),
    [anon_sym_POUNDendif2] = ACTIONS(6675),
    [anon_sym_POUNDENDIF2] = ACTIONS(6675),
    [anon_sym_POUNDEndif2] = ACTIONS(6675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6673),
    [anon_sym_PLUS] = ACTIONS(6675),
    [sym_datetime_literal] = ACTIONS(6675),
    [sym_date_literal] = ACTIONS(6673),
    [sym_time_literal] = ACTIONS(6673),
    [sym_biginteger_literal] = ACTIONS(6675),
    [anon_sym_if] = ACTIONS(6673),
    [anon_sym_IF] = ACTIONS(6673),
    [anon_sym_If] = ACTIONS(6673),
    [anon_sym_case] = ACTIONS(6673),
    [anon_sym_CASE] = ACTIONS(6673),
    [anon_sym_Case] = ACTIONS(6673),
    [anon_sym_for] = ACTIONS(6673),
    [anon_sym_FOR] = ACTIONS(6673),
    [anon_sym_For] = ACTIONS(6673),
    [anon_sym_foreach] = ACTIONS(6673),
    [anon_sym_FOREACH] = ACTIONS(6673),
    [anon_sym_Foreach] = ACTIONS(6673),
    [anon_sym_while] = ACTIONS(6673),
    [anon_sym_WHILE] = ACTIONS(6673),
    [anon_sym_While] = ACTIONS(6673),
    [anon_sym_repeat] = ACTIONS(6673),
    [anon_sym_REPEAT] = ACTIONS(6673),
    [anon_sym_Repeat] = ACTIONS(6673),
    [anon_sym_exit] = ACTIONS(6673),
    [anon_sym_EXIT] = ACTIONS(6673),
    [anon_sym_Exit] = ACTIONS(6673),
    [anon_sym_continue] = ACTIONS(6673),
    [anon_sym_CONTINUE] = ACTIONS(6673),
    [anon_sym_Continue] = ACTIONS(6673),
    [anon_sym_break] = ACTIONS(6673),
    [anon_sym_BREAK] = ACTIONS(6673),
    [anon_sym_Break] = ACTIONS(6673),
    [anon_sym_with] = ACTIONS(6673),
    [anon_sym_WITH] = ACTIONS(6673),
    [anon_sym_With] = ACTIONS(6673),
    [sym_asserterror_keyword] = ACTIONS(6675),
    [sym_page_keyword] = ACTIONS(6673),
    [anon_sym_codeunit] = ACTIONS(6673),
    [anon_sym_CODEUNIT] = ACTIONS(6673),
    [anon_sym_Codeunit] = ACTIONS(6673),
    [anon_sym_CodeUnit] = ACTIONS(6673),
    [anon_sym_COdeunit] = ACTIONS(6673),
    [anon_sym_codeUnit] = ACTIONS(6673),
    [sym_report_keyword] = ACTIONS(6673),
    [sym_query_keyword] = ACTIONS(6673),
    [anon_sym_xmlport] = ACTIONS(6673),
    [anon_sym_XMLPORT] = ACTIONS(6673),
    [anon_sym_Xmlport] = ACTIONS(6673),
    [anon_sym_XMLport] = ACTIONS(6673),
    [anon_sym_XMLPort] = ACTIONS(6673),
    [anon_sym_XmlPort] = ACTIONS(6673),
    [anon_sym_enum] = ACTIONS(6673),
    [anon_sym_ENUM] = ACTIONS(6673),
    [anon_sym_Enum] = ACTIONS(6673),
    [anon_sym_eNUM] = ACTIONS(6673),
    [anon_sym_eNum] = ACTIONS(6673),
    [anon_sym_ENum] = ACTIONS(6673),
    [sym_quoted_identifier] = ACTIONS(6675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6675),
    [sym_verbatim_string] = ACTIONS(6675),
    [sym_integer] = ACTIONS(6673),
    [sym_continue_as_identifier] = ACTIONS(6675),
    [sym_preproc_open] = ACTIONS(6675),
    [sym_preproc_close] = ACTIONS(6675),
    [sym_begin_keyword] = ACTIONS(6675),
  },
  [STATE(2721)] = {
    [sym_boolean] = STATE(7226),
    [sym_option_member] = STATE(7227),
    [sym_keyword_identifier] = STATE(7226),
    [sym_codeunit_keyword] = STATE(6858),
    [sym_xmlport_keyword] = STATE(6858),
    [sym_enum_keyword] = STATE(6858),
    [sym_keyword_as_identifier] = STATE(7226),
    [sym_identifier] = ACTIONS(3993),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(6693),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [anon_sym_RPAREN] = ACTIONS(611),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [anon_sym_RBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(6034),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1382),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [anon_sym_then] = ACTIONS(613),
    [anon_sym_THEN] = ACTIONS(613),
    [anon_sym_Then] = ACTIONS(613),
    [anon_sym_of] = ACTIONS(613),
    [anon_sym_OF] = ACTIONS(613),
    [anon_sym_Of] = ACTIONS(613),
    [anon_sym_do] = ACTIONS(613),
    [anon_sym_DO] = ACTIONS(613),
    [anon_sym_Do] = ACTIONS(613),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_page_keyword] = ACTIONS(1382),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1382),
    [sym_query_keyword] = ACTIONS(1382),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6036),
    [sym_integer] = ACTIONS(6036),
  },
  [STATE(2722)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(2726),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(11456),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2726),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDelif] = ACTIONS(6696),
    [anon_sym_POUNDELIF] = ACTIONS(6696),
    [anon_sym_POUNDElif] = ACTIONS(6696),
    [anon_sym_POUNDelse] = ACTIONS(6696),
    [anon_sym_POUNDELSE] = ACTIONS(6696),
    [anon_sym_POUNDElse] = ACTIONS(6696),
    [anon_sym_POUNDelse2] = ACTIONS(6696),
    [anon_sym_POUNDELSE2] = ACTIONS(6696),
    [anon_sym_POUNDElse2] = ACTIONS(6696),
    [anon_sym_POUNDendif] = ACTIONS(6696),
    [anon_sym_POUNDENDIF] = ACTIONS(6696),
    [anon_sym_POUNDEndif] = ACTIONS(6696),
    [anon_sym_POUNDendif2] = ACTIONS(6696),
    [anon_sym_POUNDENDIF2] = ACTIONS(6696),
    [anon_sym_POUNDEndif2] = ACTIONS(6696),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(6696),
  },
  [STATE(2723)] = {
    [sym_identifier] = ACTIONS(6698),
    [anon_sym_SEMI] = ACTIONS(6700),
    [anon_sym_DASH] = ACTIONS(6700),
    [aux_sym_boolean_token1] = ACTIONS(6698),
    [aux_sym_boolean_token2] = ACTIONS(6698),
    [sym_decimal] = ACTIONS(6698),
    [anon_sym_LPAREN] = ACTIONS(6700),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6698),
    [anon_sym_LBRACK] = ACTIONS(6700),
    [aux_sym_record_type_token1] = ACTIONS(6698),
    [aux_sym_basic_type_token21] = ACTIONS(6698),
    [aux_sym_basic_type_token22] = ACTIONS(6698),
    [aux_sym_basic_type_token48] = ACTIONS(6698),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6698),
    [anon_sym_POUNDif] = ACTIONS(6700),
    [anon_sym_POUNDIF] = ACTIONS(6700),
    [anon_sym_POUNDIf] = ACTIONS(6700),
    [anon_sym_not] = ACTIONS(6698),
    [anon_sym_NOT] = ACTIONS(6698),
    [anon_sym_Not] = ACTIONS(6698),
    [anon_sym_POUNDelif] = ACTIONS(6700),
    [anon_sym_POUNDELIF] = ACTIONS(6700),
    [anon_sym_POUNDElif] = ACTIONS(6700),
    [anon_sym_POUNDelse] = ACTIONS(6700),
    [anon_sym_POUNDELSE] = ACTIONS(6700),
    [anon_sym_POUNDElse] = ACTIONS(6700),
    [anon_sym_POUNDelse2] = ACTIONS(6700),
    [anon_sym_POUNDELSE2] = ACTIONS(6700),
    [anon_sym_POUNDElse2] = ACTIONS(6700),
    [anon_sym_POUNDendif] = ACTIONS(6700),
    [anon_sym_POUNDENDIF] = ACTIONS(6700),
    [anon_sym_POUNDEndif] = ACTIONS(6700),
    [anon_sym_POUNDendif2] = ACTIONS(6700),
    [anon_sym_POUNDENDIF2] = ACTIONS(6700),
    [anon_sym_POUNDEndif2] = ACTIONS(6700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6698),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6698),
    [anon_sym_PLUS] = ACTIONS(6700),
    [sym_datetime_literal] = ACTIONS(6700),
    [sym_date_literal] = ACTIONS(6698),
    [sym_time_literal] = ACTIONS(6698),
    [sym_biginteger_literal] = ACTIONS(6700),
    [anon_sym_if] = ACTIONS(6698),
    [anon_sym_IF] = ACTIONS(6698),
    [anon_sym_If] = ACTIONS(6698),
    [anon_sym_case] = ACTIONS(6698),
    [anon_sym_CASE] = ACTIONS(6698),
    [anon_sym_Case] = ACTIONS(6698),
    [anon_sym_for] = ACTIONS(6698),
    [anon_sym_FOR] = ACTIONS(6698),
    [anon_sym_For] = ACTIONS(6698),
    [anon_sym_foreach] = ACTIONS(6698),
    [anon_sym_FOREACH] = ACTIONS(6698),
    [anon_sym_Foreach] = ACTIONS(6698),
    [anon_sym_while] = ACTIONS(6698),
    [anon_sym_WHILE] = ACTIONS(6698),
    [anon_sym_While] = ACTIONS(6698),
    [anon_sym_repeat] = ACTIONS(6698),
    [anon_sym_REPEAT] = ACTIONS(6698),
    [anon_sym_Repeat] = ACTIONS(6698),
    [anon_sym_exit] = ACTIONS(6698),
    [anon_sym_EXIT] = ACTIONS(6698),
    [anon_sym_Exit] = ACTIONS(6698),
    [anon_sym_continue] = ACTIONS(6698),
    [anon_sym_CONTINUE] = ACTIONS(6698),
    [anon_sym_Continue] = ACTIONS(6698),
    [anon_sym_break] = ACTIONS(6698),
    [anon_sym_BREAK] = ACTIONS(6698),
    [anon_sym_Break] = ACTIONS(6698),
    [anon_sym_with] = ACTIONS(6698),
    [anon_sym_WITH] = ACTIONS(6698),
    [anon_sym_With] = ACTIONS(6698),
    [sym_asserterror_keyword] = ACTIONS(6700),
    [sym_page_keyword] = ACTIONS(6698),
    [anon_sym_codeunit] = ACTIONS(6698),
    [anon_sym_CODEUNIT] = ACTIONS(6698),
    [anon_sym_Codeunit] = ACTIONS(6698),
    [anon_sym_CodeUnit] = ACTIONS(6698),
    [anon_sym_COdeunit] = ACTIONS(6698),
    [anon_sym_codeUnit] = ACTIONS(6698),
    [sym_report_keyword] = ACTIONS(6698),
    [sym_query_keyword] = ACTIONS(6698),
    [anon_sym_xmlport] = ACTIONS(6698),
    [anon_sym_XMLPORT] = ACTIONS(6698),
    [anon_sym_Xmlport] = ACTIONS(6698),
    [anon_sym_XMLport] = ACTIONS(6698),
    [anon_sym_XMLPort] = ACTIONS(6698),
    [anon_sym_XmlPort] = ACTIONS(6698),
    [anon_sym_enum] = ACTIONS(6698),
    [anon_sym_ENUM] = ACTIONS(6698),
    [anon_sym_Enum] = ACTIONS(6698),
    [anon_sym_eNUM] = ACTIONS(6698),
    [anon_sym_eNum] = ACTIONS(6698),
    [anon_sym_ENum] = ACTIONS(6698),
    [sym_quoted_identifier] = ACTIONS(6700),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6700),
    [sym_verbatim_string] = ACTIONS(6700),
    [sym_integer] = ACTIONS(6698),
    [sym_continue_as_identifier] = ACTIONS(6700),
    [sym_preproc_open] = ACTIONS(6700),
    [sym_preproc_close] = ACTIONS(6700),
  },
  [STATE(2724)] = {
    [sym_identifier] = ACTIONS(5939),
    [anon_sym_SEMI] = ACTIONS(6702),
    [anon_sym_DASH] = ACTIONS(5943),
    [aux_sym_boolean_token1] = ACTIONS(5939),
    [aux_sym_boolean_token2] = ACTIONS(5939),
    [sym_decimal] = ACTIONS(5939),
    [anon_sym_LPAREN] = ACTIONS(5943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5939),
    [anon_sym_LBRACK] = ACTIONS(5943),
    [aux_sym_record_type_token1] = ACTIONS(5939),
    [aux_sym_basic_type_token21] = ACTIONS(5939),
    [aux_sym_basic_type_token22] = ACTIONS(5939),
    [aux_sym_basic_type_token48] = ACTIONS(5939),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5939),
    [anon_sym_POUNDif] = ACTIONS(5943),
    [anon_sym_POUNDIF] = ACTIONS(5943),
    [anon_sym_POUNDIf] = ACTIONS(5943),
    [anon_sym_not] = ACTIONS(5939),
    [anon_sym_NOT] = ACTIONS(5939),
    [anon_sym_Not] = ACTIONS(5939),
    [anon_sym_POUNDelif] = ACTIONS(5943),
    [anon_sym_POUNDELIF] = ACTIONS(5943),
    [anon_sym_POUNDElif] = ACTIONS(5943),
    [anon_sym_POUNDelse] = ACTIONS(5943),
    [anon_sym_POUNDELSE] = ACTIONS(5943),
    [anon_sym_POUNDElse] = ACTIONS(5943),
    [anon_sym_POUNDelse2] = ACTIONS(5943),
    [anon_sym_POUNDELSE2] = ACTIONS(5943),
    [anon_sym_POUNDElse2] = ACTIONS(5943),
    [anon_sym_POUNDendif] = ACTIONS(5943),
    [anon_sym_POUNDENDIF] = ACTIONS(5943),
    [anon_sym_POUNDEndif] = ACTIONS(5943),
    [anon_sym_POUNDendif2] = ACTIONS(5943),
    [anon_sym_POUNDENDIF2] = ACTIONS(5943),
    [anon_sym_POUNDEndif2] = ACTIONS(5943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5939),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5939),
    [anon_sym_PLUS] = ACTIONS(5943),
    [sym_datetime_literal] = ACTIONS(5943),
    [sym_date_literal] = ACTIONS(5939),
    [sym_time_literal] = ACTIONS(5939),
    [sym_biginteger_literal] = ACTIONS(5943),
    [anon_sym_if] = ACTIONS(5939),
    [anon_sym_IF] = ACTIONS(5939),
    [anon_sym_If] = ACTIONS(5939),
    [anon_sym_case] = ACTIONS(5939),
    [anon_sym_CASE] = ACTIONS(5939),
    [anon_sym_Case] = ACTIONS(5939),
    [anon_sym_for] = ACTIONS(5939),
    [anon_sym_FOR] = ACTIONS(5939),
    [anon_sym_For] = ACTIONS(5939),
    [anon_sym_foreach] = ACTIONS(5939),
    [anon_sym_FOREACH] = ACTIONS(5939),
    [anon_sym_Foreach] = ACTIONS(5939),
    [anon_sym_while] = ACTIONS(5939),
    [anon_sym_WHILE] = ACTIONS(5939),
    [anon_sym_While] = ACTIONS(5939),
    [anon_sym_repeat] = ACTIONS(5939),
    [anon_sym_REPEAT] = ACTIONS(5939),
    [anon_sym_Repeat] = ACTIONS(5939),
    [anon_sym_exit] = ACTIONS(5939),
    [anon_sym_EXIT] = ACTIONS(5939),
    [anon_sym_Exit] = ACTIONS(5939),
    [anon_sym_continue] = ACTIONS(5939),
    [anon_sym_CONTINUE] = ACTIONS(5939),
    [anon_sym_Continue] = ACTIONS(5939),
    [anon_sym_break] = ACTIONS(5939),
    [anon_sym_BREAK] = ACTIONS(5939),
    [anon_sym_Break] = ACTIONS(5939),
    [anon_sym_with] = ACTIONS(5939),
    [anon_sym_WITH] = ACTIONS(5939),
    [anon_sym_With] = ACTIONS(5939),
    [sym_asserterror_keyword] = ACTIONS(5943),
    [sym_page_keyword] = ACTIONS(5939),
    [anon_sym_codeunit] = ACTIONS(5939),
    [anon_sym_CODEUNIT] = ACTIONS(5939),
    [anon_sym_Codeunit] = ACTIONS(5939),
    [anon_sym_CodeUnit] = ACTIONS(5939),
    [anon_sym_COdeunit] = ACTIONS(5939),
    [anon_sym_codeUnit] = ACTIONS(5939),
    [sym_report_keyword] = ACTIONS(5939),
    [sym_query_keyword] = ACTIONS(5939),
    [anon_sym_xmlport] = ACTIONS(5939),
    [anon_sym_XMLPORT] = ACTIONS(5939),
    [anon_sym_Xmlport] = ACTIONS(5939),
    [anon_sym_XMLport] = ACTIONS(5939),
    [anon_sym_XMLPort] = ACTIONS(5939),
    [anon_sym_XmlPort] = ACTIONS(5939),
    [anon_sym_enum] = ACTIONS(5939),
    [anon_sym_ENUM] = ACTIONS(5939),
    [anon_sym_Enum] = ACTIONS(5939),
    [anon_sym_eNUM] = ACTIONS(5939),
    [anon_sym_eNum] = ACTIONS(5939),
    [anon_sym_ENum] = ACTIONS(5939),
    [sym_quoted_identifier] = ACTIONS(5943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5943),
    [sym_verbatim_string] = ACTIONS(5943),
    [sym_integer] = ACTIONS(5939),
    [sym_continue_as_identifier] = ACTIONS(5943),
    [sym_preproc_open] = ACTIONS(5943),
    [sym_preproc_close] = ACTIONS(5943),
  },
  [STATE(2725)] = {
    [sym_identifier] = ACTIONS(6704),
    [anon_sym_SEMI] = ACTIONS(5947),
    [anon_sym_DASH] = ACTIONS(6707),
    [aux_sym_boolean_token1] = ACTIONS(6704),
    [aux_sym_boolean_token2] = ACTIONS(6704),
    [sym_decimal] = ACTIONS(6704),
    [anon_sym_LPAREN] = ACTIONS(6707),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6704),
    [anon_sym_LBRACK] = ACTIONS(6707),
    [aux_sym_record_type_token1] = ACTIONS(6704),
    [aux_sym_basic_type_token21] = ACTIONS(6704),
    [aux_sym_basic_type_token22] = ACTIONS(6704),
    [aux_sym_basic_type_token48] = ACTIONS(6704),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5945),
    [anon_sym_POUNDif] = ACTIONS(5947),
    [anon_sym_POUNDIF] = ACTIONS(5947),
    [anon_sym_POUNDIf] = ACTIONS(5947),
    [anon_sym_not] = ACTIONS(6704),
    [anon_sym_NOT] = ACTIONS(6704),
    [anon_sym_Not] = ACTIONS(6704),
    [anon_sym_POUNDelif] = ACTIONS(5947),
    [anon_sym_POUNDELIF] = ACTIONS(5947),
    [anon_sym_POUNDElif] = ACTIONS(5947),
    [anon_sym_POUNDelse] = ACTIONS(5947),
    [anon_sym_POUNDELSE] = ACTIONS(5947),
    [anon_sym_POUNDElse] = ACTIONS(5947),
    [anon_sym_POUNDelse2] = ACTIONS(5947),
    [anon_sym_POUNDELSE2] = ACTIONS(5947),
    [anon_sym_POUNDElse2] = ACTIONS(5947),
    [anon_sym_POUNDendif] = ACTIONS(5947),
    [anon_sym_POUNDENDIF] = ACTIONS(5947),
    [anon_sym_POUNDEndif] = ACTIONS(5947),
    [anon_sym_POUNDendif2] = ACTIONS(5947),
    [anon_sym_POUNDENDIF2] = ACTIONS(5947),
    [anon_sym_POUNDEndif2] = ACTIONS(5947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6704),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6704),
    [anon_sym_PLUS] = ACTIONS(6707),
    [sym_datetime_literal] = ACTIONS(6707),
    [sym_date_literal] = ACTIONS(6704),
    [sym_time_literal] = ACTIONS(6704),
    [sym_biginteger_literal] = ACTIONS(6707),
    [anon_sym_if] = ACTIONS(6704),
    [anon_sym_IF] = ACTIONS(6704),
    [anon_sym_If] = ACTIONS(6704),
    [anon_sym_case] = ACTIONS(5945),
    [anon_sym_CASE] = ACTIONS(5945),
    [anon_sym_Case] = ACTIONS(5945),
    [anon_sym_for] = ACTIONS(5945),
    [anon_sym_FOR] = ACTIONS(5945),
    [anon_sym_For] = ACTIONS(5945),
    [anon_sym_foreach] = ACTIONS(5945),
    [anon_sym_FOREACH] = ACTIONS(5945),
    [anon_sym_Foreach] = ACTIONS(5945),
    [anon_sym_while] = ACTIONS(5945),
    [anon_sym_WHILE] = ACTIONS(5945),
    [anon_sym_While] = ACTIONS(5945),
    [anon_sym_repeat] = ACTIONS(5945),
    [anon_sym_REPEAT] = ACTIONS(5945),
    [anon_sym_Repeat] = ACTIONS(5945),
    [anon_sym_exit] = ACTIONS(5945),
    [anon_sym_EXIT] = ACTIONS(5945),
    [anon_sym_Exit] = ACTIONS(5945),
    [anon_sym_continue] = ACTIONS(5945),
    [anon_sym_CONTINUE] = ACTIONS(5945),
    [anon_sym_Continue] = ACTIONS(5945),
    [anon_sym_break] = ACTIONS(5945),
    [anon_sym_BREAK] = ACTIONS(5945),
    [anon_sym_Break] = ACTIONS(5945),
    [anon_sym_with] = ACTIONS(5945),
    [anon_sym_WITH] = ACTIONS(5945),
    [anon_sym_With] = ACTIONS(5945),
    [sym_asserterror_keyword] = ACTIONS(5947),
    [sym_page_keyword] = ACTIONS(6704),
    [anon_sym_codeunit] = ACTIONS(6704),
    [anon_sym_CODEUNIT] = ACTIONS(6704),
    [anon_sym_Codeunit] = ACTIONS(6704),
    [anon_sym_CodeUnit] = ACTIONS(6704),
    [anon_sym_COdeunit] = ACTIONS(6704),
    [anon_sym_codeUnit] = ACTIONS(6704),
    [sym_report_keyword] = ACTIONS(6704),
    [sym_query_keyword] = ACTIONS(6704),
    [anon_sym_xmlport] = ACTIONS(6704),
    [anon_sym_XMLPORT] = ACTIONS(6704),
    [anon_sym_Xmlport] = ACTIONS(6704),
    [anon_sym_XMLport] = ACTIONS(6704),
    [anon_sym_XMLPort] = ACTIONS(6704),
    [anon_sym_XmlPort] = ACTIONS(6704),
    [anon_sym_enum] = ACTIONS(6704),
    [anon_sym_ENUM] = ACTIONS(6704),
    [anon_sym_Enum] = ACTIONS(6704),
    [anon_sym_eNUM] = ACTIONS(6704),
    [anon_sym_eNum] = ACTIONS(6704),
    [anon_sym_ENum] = ACTIONS(6704),
    [sym_quoted_identifier] = ACTIONS(6707),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6707),
    [sym_verbatim_string] = ACTIONS(6707),
    [sym_integer] = ACTIONS(6704),
    [sym_continue_as_identifier] = ACTIONS(6707),
    [sym_preproc_open] = ACTIONS(5947),
    [sym_preproc_close] = ACTIONS(5947),
  },
  [STATE(2726)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(2726),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2726),
    [sym_identifier] = ACTIONS(6710),
    [anon_sym_DASH] = ACTIONS(6713),
    [aux_sym_boolean_token1] = ACTIONS(6716),
    [aux_sym_boolean_token2] = ACTIONS(6716),
    [sym_decimal] = ACTIONS(6719),
    [anon_sym_LPAREN] = ACTIONS(6722),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6725),
    [anon_sym_LBRACK] = ACTIONS(6728),
    [aux_sym_record_type_token1] = ACTIONS(6725),
    [aux_sym_basic_type_token21] = ACTIONS(6725),
    [aux_sym_basic_type_token22] = ACTIONS(6725),
    [aux_sym_basic_type_token48] = ACTIONS(6725),
    [anon_sym_POUNDif] = ACTIONS(6731),
    [anon_sym_POUNDIF] = ACTIONS(6731),
    [anon_sym_POUNDIf] = ACTIONS(6731),
    [anon_sym_not] = ACTIONS(6734),
    [anon_sym_NOT] = ACTIONS(6734),
    [anon_sym_Not] = ACTIONS(6734),
    [anon_sym_POUNDelif] = ACTIONS(6737),
    [anon_sym_POUNDELIF] = ACTIONS(6737),
    [anon_sym_POUNDElif] = ACTIONS(6737),
    [anon_sym_POUNDelse] = ACTIONS(6737),
    [anon_sym_POUNDELSE] = ACTIONS(6737),
    [anon_sym_POUNDElse] = ACTIONS(6737),
    [anon_sym_POUNDelse2] = ACTIONS(6737),
    [anon_sym_POUNDELSE2] = ACTIONS(6737),
    [anon_sym_POUNDElse2] = ACTIONS(6737),
    [anon_sym_POUNDendif] = ACTIONS(6737),
    [anon_sym_POUNDENDIF] = ACTIONS(6737),
    [anon_sym_POUNDEndif] = ACTIONS(6737),
    [anon_sym_POUNDendif2] = ACTIONS(6737),
    [anon_sym_POUNDENDIF2] = ACTIONS(6737),
    [anon_sym_POUNDEndif2] = ACTIONS(6737),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6725),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6739),
    [anon_sym_PLUS] = ACTIONS(6713),
    [sym_datetime_literal] = ACTIONS(6742),
    [sym_date_literal] = ACTIONS(6719),
    [sym_time_literal] = ACTIONS(6719),
    [sym_biginteger_literal] = ACTIONS(6742),
    [anon_sym_else] = ACTIONS(6745),
    [anon_sym_ELSE] = ACTIONS(6745),
    [anon_sym_Else] = ACTIONS(6745),
    [sym_page_keyword] = ACTIONS(6739),
    [anon_sym_codeunit] = ACTIONS(6747),
    [anon_sym_CODEUNIT] = ACTIONS(6747),
    [anon_sym_Codeunit] = ACTIONS(6747),
    [anon_sym_CodeUnit] = ACTIONS(6747),
    [anon_sym_COdeunit] = ACTIONS(6747),
    [anon_sym_codeUnit] = ACTIONS(6747),
    [sym_report_keyword] = ACTIONS(6739),
    [sym_query_keyword] = ACTIONS(6739),
    [anon_sym_xmlport] = ACTIONS(6750),
    [anon_sym_XMLPORT] = ACTIONS(6750),
    [anon_sym_Xmlport] = ACTIONS(6750),
    [anon_sym_XMLport] = ACTIONS(6750),
    [anon_sym_XMLPort] = ACTIONS(6750),
    [anon_sym_XmlPort] = ACTIONS(6750),
    [anon_sym_enum] = ACTIONS(6753),
    [anon_sym_ENUM] = ACTIONS(6753),
    [anon_sym_Enum] = ACTIONS(6753),
    [anon_sym_eNUM] = ACTIONS(6753),
    [anon_sym_eNum] = ACTIONS(6753),
    [anon_sym_ENum] = ACTIONS(6753),
    [sym_quoted_identifier] = ACTIONS(6756),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6742),
    [sym_verbatim_string] = ACTIONS(6742),
    [sym_integer] = ACTIONS(6719),
    [sym_continue_as_identifier] = ACTIONS(6759),
    [sym_preproc_open] = ACTIONS(6731),
    [sym_preproc_close] = ACTIONS(6737),
  },
  [STATE(2727)] = {
    [aux_sym_option_member_list_repeat2] = STATE(2727),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_EQ] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(6762),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [anon_sym_RPAREN] = ACTIONS(838),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(838),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [anon_sym_RBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(838),
    [aux_sym__expression_token1] = ACTIONS(838),
    [aux_sym__expression_token2] = ACTIONS(838),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_div] = ACTIONS(836),
    [anon_sym_DIV] = ACTIONS(836),
    [anon_sym_Div] = ACTIONS(836),
    [anon_sym_mod] = ACTIONS(836),
    [anon_sym_MOD] = ACTIONS(836),
    [anon_sym_Mod] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_LT_GT] = ACTIONS(838),
    [anon_sym_and] = ACTIONS(836),
    [anon_sym_AND] = ACTIONS(836),
    [anon_sym_And] = ACTIONS(836),
    [anon_sym_or] = ACTIONS(836),
    [anon_sym_OR] = ACTIONS(836),
    [anon_sym_Or] = ACTIONS(836),
    [anon_sym_xor] = ACTIONS(836),
    [anon_sym_XOR] = ACTIONS(836),
    [anon_sym_Xor] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(838),
    [anon_sym_then] = ACTIONS(836),
    [anon_sym_THEN] = ACTIONS(836),
    [anon_sym_Then] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_ELSE] = ACTIONS(836),
    [anon_sym_Else] = ACTIONS(836),
    [anon_sym_of] = ACTIONS(836),
    [anon_sym_OF] = ACTIONS(836),
    [anon_sym_Of] = ACTIONS(836),
    [anon_sym_do] = ACTIONS(836),
    [anon_sym_DO] = ACTIONS(836),
    [anon_sym_Do] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_IN] = ACTIONS(836),
    [anon_sym_In] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(838),
  },
  [STATE(2728)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2729)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3647),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3649),
    [anon_sym_COMMA] = ACTIONS(3649),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3647),
    [aux_sym_boolean_token2] = ACTIONS(3647),
    [sym_decimal] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3649),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3647),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3647),
    [aux_sym_basic_type_token21] = ACTIONS(3647),
    [aux_sym_basic_type_token22] = ACTIONS(3647),
    [aux_sym_basic_type_token48] = ACTIONS(3647),
    [anon_sym_not] = ACTIONS(3647),
    [anon_sym_NOT] = ACTIONS(3647),
    [anon_sym_Not] = ACTIONS(3647),
    [anon_sym_POUNDelif] = ACTIONS(3649),
    [anon_sym_POUNDELIF] = ACTIONS(3649),
    [anon_sym_POUNDElif] = ACTIONS(3649),
    [anon_sym_POUNDelse] = ACTIONS(3649),
    [anon_sym_POUNDELSE] = ACTIONS(3649),
    [anon_sym_POUNDElse] = ACTIONS(3649),
    [anon_sym_POUNDelse2] = ACTIONS(3649),
    [anon_sym_POUNDELSE2] = ACTIONS(3649),
    [anon_sym_POUNDElse2] = ACTIONS(3649),
    [anon_sym_POUNDendif] = ACTIONS(3649),
    [anon_sym_POUNDENDIF] = ACTIONS(3649),
    [anon_sym_POUNDEndif] = ACTIONS(3649),
    [anon_sym_POUNDendif2] = ACTIONS(3649),
    [anon_sym_POUNDENDIF2] = ACTIONS(3649),
    [anon_sym_POUNDEndif2] = ACTIONS(3649),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3649),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3647),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3647),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3649),
    [anon_sym_LT_EQ] = ACTIONS(3649),
    [anon_sym_GT] = ACTIONS(3647),
    [anon_sym_LT] = ACTIONS(3647),
    [anon_sym_LT_GT] = ACTIONS(3649),
    [anon_sym_and] = ACTIONS(3647),
    [anon_sym_AND] = ACTIONS(3647),
    [anon_sym_And] = ACTIONS(3647),
    [anon_sym_or] = ACTIONS(3647),
    [anon_sym_OR] = ACTIONS(3647),
    [anon_sym_Or] = ACTIONS(3647),
    [anon_sym_xor] = ACTIONS(3647),
    [anon_sym_XOR] = ACTIONS(3647),
    [anon_sym_Xor] = ACTIONS(3647),
    [anon_sym_QMARK] = ACTIONS(3649),
    [sym_datetime_literal] = ACTIONS(3649),
    [sym_date_literal] = ACTIONS(3647),
    [sym_time_literal] = ACTIONS(3647),
    [sym_biginteger_literal] = ACTIONS(3649),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3647),
    [anon_sym_codeunit] = ACTIONS(3647),
    [anon_sym_CODEUNIT] = ACTIONS(3647),
    [anon_sym_Codeunit] = ACTIONS(3647),
    [anon_sym_CodeUnit] = ACTIONS(3647),
    [anon_sym_COdeunit] = ACTIONS(3647),
    [anon_sym_codeUnit] = ACTIONS(3647),
    [sym_report_keyword] = ACTIONS(3647),
    [sym_query_keyword] = ACTIONS(3647),
    [anon_sym_xmlport] = ACTIONS(3647),
    [anon_sym_XMLPORT] = ACTIONS(3647),
    [anon_sym_Xmlport] = ACTIONS(3647),
    [anon_sym_XMLport] = ACTIONS(3647),
    [anon_sym_XMLPort] = ACTIONS(3647),
    [anon_sym_XmlPort] = ACTIONS(3647),
    [anon_sym_enum] = ACTIONS(3647),
    [anon_sym_ENUM] = ACTIONS(3647),
    [anon_sym_Enum] = ACTIONS(3647),
    [anon_sym_eNUM] = ACTIONS(3647),
    [anon_sym_eNum] = ACTIONS(3647),
    [anon_sym_ENum] = ACTIONS(3647),
    [sym_quoted_identifier] = ACTIONS(3649),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3649),
    [sym_verbatim_string] = ACTIONS(3649),
    [sym_integer] = ACTIONS(3647),
    [sym_continue_as_identifier] = ACTIONS(3649),
    [sym_preproc_close] = ACTIONS(3649),
  },
  [STATE(2730)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(6795),
    [anon_sym_AND] = ACTIONS(6797),
    [anon_sym_And] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2731)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3673),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3675),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3673),
    [aux_sym_boolean_token2] = ACTIONS(3673),
    [sym_decimal] = ACTIONS(3673),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3673),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3673),
    [aux_sym_basic_type_token21] = ACTIONS(3673),
    [aux_sym_basic_type_token22] = ACTIONS(3673),
    [aux_sym_basic_type_token48] = ACTIONS(3673),
    [anon_sym_not] = ACTIONS(3673),
    [anon_sym_NOT] = ACTIONS(3673),
    [anon_sym_Not] = ACTIONS(3673),
    [anon_sym_POUNDelif] = ACTIONS(3675),
    [anon_sym_POUNDELIF] = ACTIONS(3675),
    [anon_sym_POUNDElif] = ACTIONS(3675),
    [anon_sym_POUNDelse] = ACTIONS(3675),
    [anon_sym_POUNDELSE] = ACTIONS(3675),
    [anon_sym_POUNDElse] = ACTIONS(3675),
    [anon_sym_POUNDelse2] = ACTIONS(3675),
    [anon_sym_POUNDELSE2] = ACTIONS(3675),
    [anon_sym_POUNDElse2] = ACTIONS(3675),
    [anon_sym_POUNDendif] = ACTIONS(3675),
    [anon_sym_POUNDENDIF] = ACTIONS(3675),
    [anon_sym_POUNDEndif] = ACTIONS(3675),
    [anon_sym_POUNDendif2] = ACTIONS(3675),
    [anon_sym_POUNDENDIF2] = ACTIONS(3675),
    [anon_sym_POUNDEndif2] = ACTIONS(3675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3675),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3673),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(6795),
    [anon_sym_AND] = ACTIONS(6797),
    [anon_sym_And] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(6801),
    [anon_sym_OR] = ACTIONS(6803),
    [anon_sym_Or] = ACTIONS(6805),
    [anon_sym_xor] = ACTIONS(6807),
    [anon_sym_XOR] = ACTIONS(6809),
    [anon_sym_Xor] = ACTIONS(6811),
    [anon_sym_QMARK] = ACTIONS(6813),
    [sym_datetime_literal] = ACTIONS(3675),
    [sym_date_literal] = ACTIONS(3673),
    [sym_time_literal] = ACTIONS(3673),
    [sym_biginteger_literal] = ACTIONS(3675),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3673),
    [anon_sym_codeunit] = ACTIONS(3673),
    [anon_sym_CODEUNIT] = ACTIONS(3673),
    [anon_sym_Codeunit] = ACTIONS(3673),
    [anon_sym_CodeUnit] = ACTIONS(3673),
    [anon_sym_COdeunit] = ACTIONS(3673),
    [anon_sym_codeUnit] = ACTIONS(3673),
    [sym_report_keyword] = ACTIONS(3673),
    [sym_query_keyword] = ACTIONS(3673),
    [anon_sym_xmlport] = ACTIONS(3673),
    [anon_sym_XMLPORT] = ACTIONS(3673),
    [anon_sym_Xmlport] = ACTIONS(3673),
    [anon_sym_XMLport] = ACTIONS(3673),
    [anon_sym_XMLPort] = ACTIONS(3673),
    [anon_sym_XmlPort] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_ENUM] = ACTIONS(3673),
    [anon_sym_Enum] = ACTIONS(3673),
    [anon_sym_eNUM] = ACTIONS(3673),
    [anon_sym_eNum] = ACTIONS(3673),
    [anon_sym_ENum] = ACTIONS(3673),
    [sym_quoted_identifier] = ACTIONS(3675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3675),
    [sym_verbatim_string] = ACTIONS(3675),
    [sym_integer] = ACTIONS(3673),
    [sym_continue_as_identifier] = ACTIONS(3675),
    [sym_preproc_close] = ACTIONS(3675),
  },
  [STATE(2732)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(6795),
    [anon_sym_AND] = ACTIONS(6797),
    [anon_sym_And] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2733)] = {
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [anon_sym_tableextension] = ACTIONS(5277),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5277),
    [anon_sym_Tableextension] = ACTIONS(5277),
    [anon_sym_TableExtension] = ACTIONS(5277),
    [anon_sym_tableExtension] = ACTIONS(5277),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_pageextension] = ACTIONS(5277),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5277),
    [anon_sym_Pageextension] = ACTIONS(5277),
    [anon_sym_PageExtension] = ACTIONS(5277),
    [anon_sym_pageExtension] = ACTIONS(5277),
    [anon_sym_codeunit] = ACTIONS(5277),
    [anon_sym_CODEUNIT] = ACTIONS(5277),
    [anon_sym_Codeunit] = ACTIONS(5277),
    [anon_sym_CodeUnit] = ACTIONS(5277),
    [anon_sym_COdeunit] = ACTIONS(5277),
    [anon_sym_codeUnit] = ACTIONS(5277),
    [sym_report_keyword] = ACTIONS(5279),
    [anon_sym_reportextension] = ACTIONS(5277),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5277),
    [anon_sym_Reportextension] = ACTIONS(5277),
    [anon_sym_ReportExtension] = ACTIONS(5277),
    [anon_sym_reportExtension] = ACTIONS(5277),
    [sym_query_keyword] = ACTIONS(5277),
    [anon_sym_xmlport] = ACTIONS(5277),
    [anon_sym_XMLPORT] = ACTIONS(5277),
    [anon_sym_Xmlport] = ACTIONS(5277),
    [anon_sym_XMLport] = ACTIONS(5277),
    [anon_sym_XMLPort] = ACTIONS(5277),
    [anon_sym_XmlPort] = ACTIONS(5277),
    [anon_sym_enum] = ACTIONS(5279),
    [anon_sym_ENUM] = ACTIONS(5279),
    [anon_sym_Enum] = ACTIONS(5279),
    [anon_sym_eNUM] = ACTIONS(5277),
    [anon_sym_eNum] = ACTIONS(5277),
    [anon_sym_ENum] = ACTIONS(5277),
    [anon_sym_enumextension] = ACTIONS(5277),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5277),
    [anon_sym_Enumextension] = ACTIONS(5277),
    [anon_sym_EnumExtension] = ACTIONS(5277),
    [anon_sym_enumExtension] = ACTIONS(5277),
    [sym_interface_keyword] = ACTIONS(5277),
    [anon_sym_controladdin] = ACTIONS(5277),
    [anon_sym_CONTROLADDIN] = ACTIONS(5277),
    [anon_sym_Controladdin] = ACTIONS(5277),
    [anon_sym_ControlAddIn] = ACTIONS(5277),
    [anon_sym_ControlAddin] = ACTIONS(5277),
    [anon_sym_controlAddIn] = ACTIONS(5277),
    [anon_sym_controlAddin] = ACTIONS(5277),
    [anon_sym_dotnet] = ACTIONS(5277),
    [anon_sym_DOTNET] = ACTIONS(5277),
    [anon_sym_Dotnet] = ACTIONS(5277),
    [anon_sym_DotNet] = ACTIONS(5277),
    [anon_sym_dotNet] = ACTIONS(5277),
    [sym_profile_keyword] = ACTIONS(5279),
    [anon_sym_profileextension] = ACTIONS(5277),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(5277),
    [anon_sym_Profileextension] = ACTIONS(5277),
    [anon_sym_ProfileExtension] = ACTIONS(5277),
    [anon_sym_profileExtension] = ACTIONS(5277),
    [anon_sym_permissionset] = ACTIONS(5279),
    [anon_sym_PERMISSIONSET] = ACTIONS(5279),
    [anon_sym_Permissionset] = ACTIONS(5279),
    [anon_sym_PermissionSet] = ACTIONS(5279),
    [anon_sym_permissionSet] = ACTIONS(5279),
    [anon_sym_permissionsetextension] = ACTIONS(5277),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5277),
    [anon_sym_Permissionsetextension] = ACTIONS(5277),
    [anon_sym_PermissionSetExtension] = ACTIONS(5277),
    [anon_sym_permissionSetExtension] = ACTIONS(5277),
    [sym_entitlement_keyword] = ACTIONS(5277),
    [anon_sym_pagecustomization] = ACTIONS(5277),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(5277),
    [anon_sym_Pagecustomization] = ACTIONS(5277),
    [anon_sym_PageCustomization] = ACTIONS(5277),
    [anon_sym_pageCustomization] = ACTIONS(5277),
    [sym_using_keyword] = ACTIONS(5277),
    [sym_fieldgroup_keyword] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
  },
  [STATE(2734)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2735)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(6795),
    [anon_sym_AND] = ACTIONS(6797),
    [anon_sym_And] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2736)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2736),
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_DOT] = ACTIONS(6815),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_COMMA] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelif] = ACTIONS(3705),
    [anon_sym_POUNDELIF] = ACTIONS(3705),
    [anon_sym_POUNDElif] = ACTIONS(3705),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [anon_sym_POUNDendif] = ACTIONS(3705),
    [anon_sym_POUNDENDIF] = ACTIONS(3705),
    [anon_sym_POUNDEndif] = ACTIONS(3705),
    [anon_sym_POUNDendif2] = ACTIONS(3705),
    [anon_sym_POUNDENDIF2] = ACTIONS(3705),
    [anon_sym_POUNDEndif2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3705),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_close] = ACTIONS(3705),
  },
  [STATE(2737)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2738)] = {
    [sym_argument_list] = STATE(2831),
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(6818),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_COLON_COLON] = ACTIONS(6820),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [anon_sym_POUNDelif] = ACTIONS(6002),
    [anon_sym_POUNDELIF] = ACTIONS(6002),
    [anon_sym_POUNDElif] = ACTIONS(6002),
    [anon_sym_POUNDelse] = ACTIONS(6002),
    [anon_sym_POUNDELSE] = ACTIONS(6002),
    [anon_sym_POUNDElse] = ACTIONS(6002),
    [anon_sym_POUNDelse2] = ACTIONS(6002),
    [anon_sym_POUNDELSE2] = ACTIONS(6002),
    [anon_sym_POUNDElse2] = ACTIONS(6002),
    [anon_sym_POUNDendif] = ACTIONS(6002),
    [anon_sym_POUNDENDIF] = ACTIONS(6002),
    [anon_sym_POUNDEndif] = ACTIONS(6002),
    [anon_sym_POUNDendif2] = ACTIONS(6002),
    [anon_sym_POUNDENDIF2] = ACTIONS(6002),
    [anon_sym_POUNDEndif2] = ACTIONS(6002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_close] = ACTIONS(6002),
  },
  [STATE(2739)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2736),
    [sym_identifier] = ACTIONS(3699),
    [anon_sym_DOT] = ACTIONS(6822),
    [anon_sym_EQ] = ACTIONS(3701),
    [anon_sym_COMMA] = ACTIONS(3701),
    [anon_sym_DASH] = ACTIONS(3699),
    [aux_sym_boolean_token1] = ACTIONS(3699),
    [aux_sym_boolean_token2] = ACTIONS(3699),
    [sym_decimal] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_DOT_DOT] = ACTIONS(3701),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3699),
    [anon_sym_STAR] = ACTIONS(3699),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [aux_sym_record_type_token1] = ACTIONS(3699),
    [aux_sym_basic_type_token21] = ACTIONS(3699),
    [aux_sym_basic_type_token22] = ACTIONS(3699),
    [aux_sym_basic_type_token48] = ACTIONS(3699),
    [anon_sym_not] = ACTIONS(3699),
    [anon_sym_NOT] = ACTIONS(3699),
    [anon_sym_Not] = ACTIONS(3699),
    [anon_sym_POUNDelif] = ACTIONS(3701),
    [anon_sym_POUNDELIF] = ACTIONS(3701),
    [anon_sym_POUNDElif] = ACTIONS(3701),
    [anon_sym_POUNDelse] = ACTIONS(3701),
    [anon_sym_POUNDELSE] = ACTIONS(3701),
    [anon_sym_POUNDElse] = ACTIONS(3701),
    [anon_sym_POUNDelse2] = ACTIONS(3701),
    [anon_sym_POUNDELSE2] = ACTIONS(3701),
    [anon_sym_POUNDElse2] = ACTIONS(3701),
    [anon_sym_POUNDendif] = ACTIONS(3701),
    [anon_sym_POUNDENDIF] = ACTIONS(3701),
    [anon_sym_POUNDEndif] = ACTIONS(3701),
    [anon_sym_POUNDendif2] = ACTIONS(3701),
    [anon_sym_POUNDENDIF2] = ACTIONS(3701),
    [anon_sym_POUNDEndif2] = ACTIONS(3701),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3701),
    [aux_sym__expression_token1] = ACTIONS(3701),
    [aux_sym__expression_token2] = ACTIONS(3701),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3699),
    [anon_sym_SLASH] = ACTIONS(3699),
    [anon_sym_div] = ACTIONS(3699),
    [anon_sym_DIV] = ACTIONS(3699),
    [anon_sym_Div] = ACTIONS(3699),
    [anon_sym_mod] = ACTIONS(3699),
    [anon_sym_MOD] = ACTIONS(3699),
    [anon_sym_Mod] = ACTIONS(3699),
    [anon_sym_PLUS] = ACTIONS(3699),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT] = ACTIONS(3699),
    [anon_sym_LT] = ACTIONS(3699),
    [anon_sym_LT_GT] = ACTIONS(3701),
    [anon_sym_and] = ACTIONS(3699),
    [anon_sym_AND] = ACTIONS(3699),
    [anon_sym_And] = ACTIONS(3699),
    [anon_sym_or] = ACTIONS(3699),
    [anon_sym_OR] = ACTIONS(3699),
    [anon_sym_Or] = ACTIONS(3699),
    [anon_sym_xor] = ACTIONS(3699),
    [anon_sym_XOR] = ACTIONS(3699),
    [anon_sym_Xor] = ACTIONS(3699),
    [anon_sym_QMARK] = ACTIONS(3701),
    [sym_datetime_literal] = ACTIONS(3701),
    [sym_date_literal] = ACTIONS(3699),
    [sym_time_literal] = ACTIONS(3699),
    [sym_biginteger_literal] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3699),
    [anon_sym_IN] = ACTIONS(3699),
    [anon_sym_In] = ACTIONS(3699),
    [sym_page_keyword] = ACTIONS(3699),
    [anon_sym_codeunit] = ACTIONS(3699),
    [anon_sym_CODEUNIT] = ACTIONS(3699),
    [anon_sym_Codeunit] = ACTIONS(3699),
    [anon_sym_CodeUnit] = ACTIONS(3699),
    [anon_sym_COdeunit] = ACTIONS(3699),
    [anon_sym_codeUnit] = ACTIONS(3699),
    [sym_report_keyword] = ACTIONS(3699),
    [sym_query_keyword] = ACTIONS(3699),
    [anon_sym_xmlport] = ACTIONS(3699),
    [anon_sym_XMLPORT] = ACTIONS(3699),
    [anon_sym_Xmlport] = ACTIONS(3699),
    [anon_sym_XMLport] = ACTIONS(3699),
    [anon_sym_XMLPort] = ACTIONS(3699),
    [anon_sym_XmlPort] = ACTIONS(3699),
    [anon_sym_enum] = ACTIONS(3699),
    [anon_sym_ENUM] = ACTIONS(3699),
    [anon_sym_Enum] = ACTIONS(3699),
    [anon_sym_eNUM] = ACTIONS(3699),
    [anon_sym_eNum] = ACTIONS(3699),
    [anon_sym_ENum] = ACTIONS(3699),
    [sym_temporary_keyword] = ACTIONS(3699),
    [sym_quoted_identifier] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3701),
    [sym_verbatim_string] = ACTIONS(3701),
    [sym_integer] = ACTIONS(3699),
    [sym_continue_as_identifier] = ACTIONS(3701),
    [sym_preproc_close] = ACTIONS(3701),
  },
  [STATE(2740)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(6795),
    [anon_sym_AND] = ACTIONS(6797),
    [anon_sym_And] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2741)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3726),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3728),
    [anon_sym_COMMA] = ACTIONS(3728),
    [anon_sym_DASH] = ACTIONS(3726),
    [aux_sym_boolean_token1] = ACTIONS(3726),
    [aux_sym_boolean_token2] = ACTIONS(3726),
    [sym_decimal] = ACTIONS(3726),
    [anon_sym_LPAREN] = ACTIONS(3728),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3726),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3726),
    [aux_sym_basic_type_token21] = ACTIONS(3726),
    [aux_sym_basic_type_token22] = ACTIONS(3726),
    [aux_sym_basic_type_token48] = ACTIONS(3726),
    [anon_sym_not] = ACTIONS(3726),
    [anon_sym_NOT] = ACTIONS(3726),
    [anon_sym_Not] = ACTIONS(3726),
    [anon_sym_POUNDelif] = ACTIONS(3728),
    [anon_sym_POUNDELIF] = ACTIONS(3728),
    [anon_sym_POUNDElif] = ACTIONS(3728),
    [anon_sym_POUNDelse] = ACTIONS(3728),
    [anon_sym_POUNDELSE] = ACTIONS(3728),
    [anon_sym_POUNDElse] = ACTIONS(3728),
    [anon_sym_POUNDelse2] = ACTIONS(3728),
    [anon_sym_POUNDELSE2] = ACTIONS(3728),
    [anon_sym_POUNDElse2] = ACTIONS(3728),
    [anon_sym_POUNDendif] = ACTIONS(3728),
    [anon_sym_POUNDENDIF] = ACTIONS(3728),
    [anon_sym_POUNDEndif] = ACTIONS(3728),
    [anon_sym_POUNDendif2] = ACTIONS(3728),
    [anon_sym_POUNDENDIF2] = ACTIONS(3728),
    [anon_sym_POUNDEndif2] = ACTIONS(3728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3728),
    [aux_sym__expression_token1] = ACTIONS(3728),
    [aux_sym__expression_token2] = ACTIONS(3728),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3726),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(3726),
    [anon_sym_GT_EQ] = ACTIONS(3728),
    [anon_sym_LT_EQ] = ACTIONS(3728),
    [anon_sym_GT] = ACTIONS(3726),
    [anon_sym_LT] = ACTIONS(3726),
    [anon_sym_LT_GT] = ACTIONS(3728),
    [anon_sym_and] = ACTIONS(3726),
    [anon_sym_AND] = ACTIONS(3726),
    [anon_sym_And] = ACTIONS(3726),
    [anon_sym_or] = ACTIONS(3726),
    [anon_sym_OR] = ACTIONS(3726),
    [anon_sym_Or] = ACTIONS(3726),
    [anon_sym_xor] = ACTIONS(3726),
    [anon_sym_XOR] = ACTIONS(3726),
    [anon_sym_Xor] = ACTIONS(3726),
    [anon_sym_QMARK] = ACTIONS(3728),
    [sym_datetime_literal] = ACTIONS(3728),
    [sym_date_literal] = ACTIONS(3726),
    [sym_time_literal] = ACTIONS(3726),
    [sym_biginteger_literal] = ACTIONS(3728),
    [anon_sym_in] = ACTIONS(3726),
    [anon_sym_IN] = ACTIONS(3726),
    [anon_sym_In] = ACTIONS(3726),
    [sym_page_keyword] = ACTIONS(3726),
    [anon_sym_codeunit] = ACTIONS(3726),
    [anon_sym_CODEUNIT] = ACTIONS(3726),
    [anon_sym_Codeunit] = ACTIONS(3726),
    [anon_sym_CodeUnit] = ACTIONS(3726),
    [anon_sym_COdeunit] = ACTIONS(3726),
    [anon_sym_codeUnit] = ACTIONS(3726),
    [sym_report_keyword] = ACTIONS(3726),
    [sym_query_keyword] = ACTIONS(3726),
    [anon_sym_xmlport] = ACTIONS(3726),
    [anon_sym_XMLPORT] = ACTIONS(3726),
    [anon_sym_Xmlport] = ACTIONS(3726),
    [anon_sym_XMLport] = ACTIONS(3726),
    [anon_sym_XMLPort] = ACTIONS(3726),
    [anon_sym_XmlPort] = ACTIONS(3726),
    [anon_sym_enum] = ACTIONS(3726),
    [anon_sym_ENUM] = ACTIONS(3726),
    [anon_sym_Enum] = ACTIONS(3726),
    [anon_sym_eNUM] = ACTIONS(3726),
    [anon_sym_eNum] = ACTIONS(3726),
    [anon_sym_ENum] = ACTIONS(3726),
    [sym_quoted_identifier] = ACTIONS(3728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3728),
    [sym_verbatim_string] = ACTIONS(3728),
    [sym_integer] = ACTIONS(3726),
    [sym_continue_as_identifier] = ACTIONS(3728),
    [sym_preproc_close] = ACTIONS(3728),
  },
  [STATE(2742)] = {
    [sym_argument_list] = STATE(2831),
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(6818),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(6820),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelif] = ACTIONS(3683),
    [anon_sym_POUNDELIF] = ACTIONS(3683),
    [anon_sym_POUNDElif] = ACTIONS(3683),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [anon_sym_POUNDendif] = ACTIONS(3683),
    [anon_sym_POUNDENDIF] = ACTIONS(3683),
    [anon_sym_POUNDEndif] = ACTIONS(3683),
    [anon_sym_POUNDendif2] = ACTIONS(3683),
    [anon_sym_POUNDENDIF2] = ACTIONS(3683),
    [anon_sym_POUNDEndif2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_close] = ACTIONS(3683),
  },
  [STATE(2743)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(2739),
    [sym_identifier] = ACTIONS(3693),
    [anon_sym_DOT] = ACTIONS(6822),
    [anon_sym_EQ] = ACTIONS(3695),
    [anon_sym_COMMA] = ACTIONS(3695),
    [anon_sym_DASH] = ACTIONS(3693),
    [aux_sym_boolean_token1] = ACTIONS(3693),
    [aux_sym_boolean_token2] = ACTIONS(3693),
    [sym_decimal] = ACTIONS(3693),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_DOT_DOT] = ACTIONS(3695),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [aux_sym_record_type_token1] = ACTIONS(3693),
    [aux_sym_basic_type_token21] = ACTIONS(3693),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_basic_type_token48] = ACTIONS(3693),
    [anon_sym_not] = ACTIONS(3693),
    [anon_sym_NOT] = ACTIONS(3693),
    [anon_sym_Not] = ACTIONS(3693),
    [anon_sym_POUNDelif] = ACTIONS(3695),
    [anon_sym_POUNDELIF] = ACTIONS(3695),
    [anon_sym_POUNDElif] = ACTIONS(3695),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [anon_sym_POUNDendif] = ACTIONS(3695),
    [anon_sym_POUNDENDIF] = ACTIONS(3695),
    [anon_sym_POUNDEndif] = ACTIONS(3695),
    [anon_sym_POUNDendif2] = ACTIONS(3695),
    [anon_sym_POUNDENDIF2] = ACTIONS(3695),
    [anon_sym_POUNDEndif2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3695),
    [aux_sym__expression_token1] = ACTIONS(3695),
    [aux_sym__expression_token2] = ACTIONS(3695),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3693),
    [anon_sym_SLASH] = ACTIONS(3693),
    [anon_sym_div] = ACTIONS(3693),
    [anon_sym_DIV] = ACTIONS(3693),
    [anon_sym_Div] = ACTIONS(3693),
    [anon_sym_mod] = ACTIONS(3693),
    [anon_sym_MOD] = ACTIONS(3693),
    [anon_sym_Mod] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(3693),
    [anon_sym_GT_EQ] = ACTIONS(3695),
    [anon_sym_LT_EQ] = ACTIONS(3695),
    [anon_sym_GT] = ACTIONS(3693),
    [anon_sym_LT] = ACTIONS(3693),
    [anon_sym_LT_GT] = ACTIONS(3695),
    [anon_sym_and] = ACTIONS(3693),
    [anon_sym_AND] = ACTIONS(3693),
    [anon_sym_And] = ACTIONS(3693),
    [anon_sym_or] = ACTIONS(3693),
    [anon_sym_OR] = ACTIONS(3693),
    [anon_sym_Or] = ACTIONS(3693),
    [anon_sym_xor] = ACTIONS(3693),
    [anon_sym_XOR] = ACTIONS(3693),
    [anon_sym_Xor] = ACTIONS(3693),
    [anon_sym_QMARK] = ACTIONS(3695),
    [sym_datetime_literal] = ACTIONS(3695),
    [sym_date_literal] = ACTIONS(3693),
    [sym_time_literal] = ACTIONS(3693),
    [sym_biginteger_literal] = ACTIONS(3695),
    [anon_sym_in] = ACTIONS(3693),
    [anon_sym_IN] = ACTIONS(3693),
    [anon_sym_In] = ACTIONS(3693),
    [sym_page_keyword] = ACTIONS(3693),
    [anon_sym_codeunit] = ACTIONS(3693),
    [anon_sym_CODEUNIT] = ACTIONS(3693),
    [anon_sym_Codeunit] = ACTIONS(3693),
    [anon_sym_CodeUnit] = ACTIONS(3693),
    [anon_sym_COdeunit] = ACTIONS(3693),
    [anon_sym_codeUnit] = ACTIONS(3693),
    [sym_report_keyword] = ACTIONS(3693),
    [sym_query_keyword] = ACTIONS(3693),
    [anon_sym_xmlport] = ACTIONS(3693),
    [anon_sym_XMLPORT] = ACTIONS(3693),
    [anon_sym_Xmlport] = ACTIONS(3693),
    [anon_sym_XMLport] = ACTIONS(3693),
    [anon_sym_XMLPort] = ACTIONS(3693),
    [anon_sym_XmlPort] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_ENUM] = ACTIONS(3693),
    [anon_sym_Enum] = ACTIONS(3693),
    [anon_sym_eNUM] = ACTIONS(3693),
    [anon_sym_eNum] = ACTIONS(3693),
    [anon_sym_ENum] = ACTIONS(3693),
    [sym_temporary_keyword] = ACTIONS(3693),
    [sym_quoted_identifier] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3695),
    [sym_verbatim_string] = ACTIONS(3695),
    [sym_integer] = ACTIONS(3693),
    [sym_continue_as_identifier] = ACTIONS(3695),
    [sym_preproc_close] = ACTIONS(3695),
  },
  [STATE(2744)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_COMMA] = ACTIONS(3679),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelif] = ACTIONS(3679),
    [anon_sym_POUNDELIF] = ACTIONS(3679),
    [anon_sym_POUNDElif] = ACTIONS(3679),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [anon_sym_POUNDendif] = ACTIONS(3679),
    [anon_sym_POUNDENDIF] = ACTIONS(3679),
    [anon_sym_POUNDEndif] = ACTIONS(3679),
    [anon_sym_POUNDendif2] = ACTIONS(3679),
    [anon_sym_POUNDENDIF2] = ACTIONS(3679),
    [anon_sym_POUNDEndif2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_close] = ACTIONS(3679),
  },
  [STATE(2745)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3639),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3641),
    [anon_sym_COMMA] = ACTIONS(3641),
    [anon_sym_DASH] = ACTIONS(3639),
    [aux_sym_boolean_token1] = ACTIONS(3639),
    [aux_sym_boolean_token2] = ACTIONS(3639),
    [sym_decimal] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3641),
    [anon_sym_DOT_DOT] = ACTIONS(3641),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3639),
    [anon_sym_STAR] = ACTIONS(3639),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3639),
    [aux_sym_basic_type_token21] = ACTIONS(3639),
    [aux_sym_basic_type_token22] = ACTIONS(3639),
    [aux_sym_basic_type_token48] = ACTIONS(3639),
    [anon_sym_not] = ACTIONS(3639),
    [anon_sym_NOT] = ACTIONS(3639),
    [anon_sym_Not] = ACTIONS(3639),
    [anon_sym_POUNDelif] = ACTIONS(3641),
    [anon_sym_POUNDELIF] = ACTIONS(3641),
    [anon_sym_POUNDElif] = ACTIONS(3641),
    [anon_sym_POUNDelse] = ACTIONS(3641),
    [anon_sym_POUNDELSE] = ACTIONS(3641),
    [anon_sym_POUNDElse] = ACTIONS(3641),
    [anon_sym_POUNDelse2] = ACTIONS(3641),
    [anon_sym_POUNDELSE2] = ACTIONS(3641),
    [anon_sym_POUNDElse2] = ACTIONS(3641),
    [anon_sym_POUNDendif] = ACTIONS(3641),
    [anon_sym_POUNDENDIF] = ACTIONS(3641),
    [anon_sym_POUNDEndif] = ACTIONS(3641),
    [anon_sym_POUNDendif2] = ACTIONS(3641),
    [anon_sym_POUNDENDIF2] = ACTIONS(3641),
    [anon_sym_POUNDEndif2] = ACTIONS(3641),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3641),
    [aux_sym__expression_token1] = ACTIONS(3641),
    [aux_sym__expression_token2] = ACTIONS(3641),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3639),
    [anon_sym_SLASH] = ACTIONS(3639),
    [anon_sym_div] = ACTIONS(3639),
    [anon_sym_DIV] = ACTIONS(3639),
    [anon_sym_Div] = ACTIONS(3639),
    [anon_sym_mod] = ACTIONS(3639),
    [anon_sym_MOD] = ACTIONS(3639),
    [anon_sym_Mod] = ACTIONS(3639),
    [anon_sym_PLUS] = ACTIONS(3639),
    [anon_sym_GT_EQ] = ACTIONS(3641),
    [anon_sym_LT_EQ] = ACTIONS(3641),
    [anon_sym_GT] = ACTIONS(3639),
    [anon_sym_LT] = ACTIONS(3639),
    [anon_sym_LT_GT] = ACTIONS(3641),
    [anon_sym_and] = ACTIONS(3639),
    [anon_sym_AND] = ACTIONS(3639),
    [anon_sym_And] = ACTIONS(3639),
    [anon_sym_or] = ACTIONS(3639),
    [anon_sym_OR] = ACTIONS(3639),
    [anon_sym_Or] = ACTIONS(3639),
    [anon_sym_xor] = ACTIONS(3639),
    [anon_sym_XOR] = ACTIONS(3639),
    [anon_sym_Xor] = ACTIONS(3639),
    [anon_sym_QMARK] = ACTIONS(3641),
    [sym_datetime_literal] = ACTIONS(3641),
    [sym_date_literal] = ACTIONS(3639),
    [sym_time_literal] = ACTIONS(3639),
    [sym_biginteger_literal] = ACTIONS(3641),
    [anon_sym_in] = ACTIONS(3639),
    [anon_sym_IN] = ACTIONS(3639),
    [anon_sym_In] = ACTIONS(3639),
    [sym_page_keyword] = ACTIONS(3639),
    [anon_sym_codeunit] = ACTIONS(3639),
    [anon_sym_CODEUNIT] = ACTIONS(3639),
    [anon_sym_Codeunit] = ACTIONS(3639),
    [anon_sym_CodeUnit] = ACTIONS(3639),
    [anon_sym_COdeunit] = ACTIONS(3639),
    [anon_sym_codeUnit] = ACTIONS(3639),
    [sym_report_keyword] = ACTIONS(3639),
    [sym_query_keyword] = ACTIONS(3639),
    [anon_sym_xmlport] = ACTIONS(3639),
    [anon_sym_XMLPORT] = ACTIONS(3639),
    [anon_sym_Xmlport] = ACTIONS(3639),
    [anon_sym_XMLport] = ACTIONS(3639),
    [anon_sym_XMLPort] = ACTIONS(3639),
    [anon_sym_XmlPort] = ACTIONS(3639),
    [anon_sym_enum] = ACTIONS(3639),
    [anon_sym_ENUM] = ACTIONS(3639),
    [anon_sym_Enum] = ACTIONS(3639),
    [anon_sym_eNUM] = ACTIONS(3639),
    [anon_sym_eNum] = ACTIONS(3639),
    [anon_sym_ENum] = ACTIONS(3639),
    [sym_quoted_identifier] = ACTIONS(3641),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3641),
    [sym_verbatim_string] = ACTIONS(3641),
    [sym_integer] = ACTIONS(3639),
    [sym_continue_as_identifier] = ACTIONS(3641),
    [sym_preproc_close] = ACTIONS(3641),
  },
  [STATE(2746)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(6795),
    [anon_sym_AND] = ACTIONS(6797),
    [anon_sym_And] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2747)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2748)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3576),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3578),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3576),
    [aux_sym_boolean_token2] = ACTIONS(3576),
    [sym_decimal] = ACTIONS(3576),
    [anon_sym_LPAREN] = ACTIONS(3578),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3576),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3576),
    [aux_sym_basic_type_token21] = ACTIONS(3576),
    [aux_sym_basic_type_token22] = ACTIONS(3576),
    [aux_sym_basic_type_token48] = ACTIONS(3576),
    [anon_sym_not] = ACTIONS(3576),
    [anon_sym_NOT] = ACTIONS(3576),
    [anon_sym_Not] = ACTIONS(3576),
    [anon_sym_POUNDelif] = ACTIONS(3578),
    [anon_sym_POUNDELIF] = ACTIONS(3578),
    [anon_sym_POUNDElif] = ACTIONS(3578),
    [anon_sym_POUNDelse] = ACTIONS(3578),
    [anon_sym_POUNDELSE] = ACTIONS(3578),
    [anon_sym_POUNDElse] = ACTIONS(3578),
    [anon_sym_POUNDelse2] = ACTIONS(3578),
    [anon_sym_POUNDELSE2] = ACTIONS(3578),
    [anon_sym_POUNDElse2] = ACTIONS(3578),
    [anon_sym_POUNDendif] = ACTIONS(3578),
    [anon_sym_POUNDENDIF] = ACTIONS(3578),
    [anon_sym_POUNDEndif] = ACTIONS(3578),
    [anon_sym_POUNDendif2] = ACTIONS(3578),
    [anon_sym_POUNDENDIF2] = ACTIONS(3578),
    [anon_sym_POUNDEndif2] = ACTIONS(3578),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6824),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3576),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3576),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(6795),
    [anon_sym_AND] = ACTIONS(6797),
    [anon_sym_And] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(6801),
    [anon_sym_OR] = ACTIONS(6803),
    [anon_sym_Or] = ACTIONS(6805),
    [anon_sym_xor] = ACTIONS(6807),
    [anon_sym_XOR] = ACTIONS(6809),
    [anon_sym_Xor] = ACTIONS(6811),
    [anon_sym_QMARK] = ACTIONS(6813),
    [sym_datetime_literal] = ACTIONS(3578),
    [sym_date_literal] = ACTIONS(3576),
    [sym_time_literal] = ACTIONS(3576),
    [sym_biginteger_literal] = ACTIONS(3578),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3576),
    [anon_sym_codeunit] = ACTIONS(3576),
    [anon_sym_CODEUNIT] = ACTIONS(3576),
    [anon_sym_Codeunit] = ACTIONS(3576),
    [anon_sym_CodeUnit] = ACTIONS(3576),
    [anon_sym_COdeunit] = ACTIONS(3576),
    [anon_sym_codeUnit] = ACTIONS(3576),
    [sym_report_keyword] = ACTIONS(3576),
    [sym_query_keyword] = ACTIONS(3576),
    [anon_sym_xmlport] = ACTIONS(3576),
    [anon_sym_XMLPORT] = ACTIONS(3576),
    [anon_sym_Xmlport] = ACTIONS(3576),
    [anon_sym_XMLport] = ACTIONS(3576),
    [anon_sym_XMLPort] = ACTIONS(3576),
    [anon_sym_XmlPort] = ACTIONS(3576),
    [anon_sym_enum] = ACTIONS(3576),
    [anon_sym_ENUM] = ACTIONS(3576),
    [anon_sym_Enum] = ACTIONS(3576),
    [anon_sym_eNUM] = ACTIONS(3576),
    [anon_sym_eNum] = ACTIONS(3576),
    [anon_sym_ENum] = ACTIONS(3576),
    [sym_quoted_identifier] = ACTIONS(3578),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3578),
    [sym_verbatim_string] = ACTIONS(3578),
    [sym_integer] = ACTIONS(3576),
    [sym_continue_as_identifier] = ACTIONS(3578),
    [sym_preproc_close] = ACTIONS(3578),
  },
  [STATE(2749)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2750)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2751)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_COMMA] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [aux_sym_boolean_token1] = ACTIONS(3562),
    [aux_sym_boolean_token2] = ACTIONS(3562),
    [sym_decimal] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_record_type_token1] = ACTIONS(3562),
    [aux_sym_basic_type_token21] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token48] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_not] = ACTIONS(3562),
    [anon_sym_NOT] = ACTIONS(3562),
    [anon_sym_Not] = ACTIONS(3562),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3562),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [sym_datetime_literal] = ACTIONS(3564),
    [sym_date_literal] = ACTIONS(3562),
    [sym_time_literal] = ACTIONS(3562),
    [sym_biginteger_literal] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_page_keyword] = ACTIONS(3562),
    [anon_sym_codeunit] = ACTIONS(3562),
    [anon_sym_CODEUNIT] = ACTIONS(3562),
    [anon_sym_Codeunit] = ACTIONS(3562),
    [anon_sym_CodeUnit] = ACTIONS(3562),
    [anon_sym_COdeunit] = ACTIONS(3562),
    [anon_sym_codeUnit] = ACTIONS(3562),
    [sym_report_keyword] = ACTIONS(3562),
    [sym_query_keyword] = ACTIONS(3562),
    [anon_sym_xmlport] = ACTIONS(3562),
    [anon_sym_XMLPORT] = ACTIONS(3562),
    [anon_sym_Xmlport] = ACTIONS(3562),
    [anon_sym_XMLport] = ACTIONS(3562),
    [anon_sym_XMLPort] = ACTIONS(3562),
    [anon_sym_XmlPort] = ACTIONS(3562),
    [anon_sym_enum] = ACTIONS(3562),
    [anon_sym_ENUM] = ACTIONS(3562),
    [anon_sym_Enum] = ACTIONS(3562),
    [anon_sym_eNUM] = ACTIONS(3562),
    [anon_sym_eNum] = ACTIONS(3562),
    [anon_sym_ENum] = ACTIONS(3562),
    [sym_temporary_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3564),
    [sym_verbatim_string] = ACTIONS(3564),
    [sym_integer] = ACTIONS(3562),
    [sym_continue_as_identifier] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
  },
  [STATE(2752)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2753)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(6767),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [anon_sym_POUNDelif] = ACTIONS(3645),
    [anon_sym_POUNDELIF] = ACTIONS(3645),
    [anon_sym_POUNDElif] = ACTIONS(3645),
    [anon_sym_POUNDelse] = ACTIONS(3645),
    [anon_sym_POUNDELSE] = ACTIONS(3645),
    [anon_sym_POUNDElse] = ACTIONS(3645),
    [anon_sym_POUNDelse2] = ACTIONS(3645),
    [anon_sym_POUNDELSE2] = ACTIONS(3645),
    [anon_sym_POUNDElse2] = ACTIONS(3645),
    [anon_sym_POUNDendif] = ACTIONS(3645),
    [anon_sym_POUNDENDIF] = ACTIONS(3645),
    [anon_sym_POUNDEndif] = ACTIONS(3645),
    [anon_sym_POUNDendif2] = ACTIONS(3645),
    [anon_sym_POUNDENDIF2] = ACTIONS(3645),
    [anon_sym_POUNDEndif2] = ACTIONS(3645),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(6775),
    [aux_sym__expression_token2] = ACTIONS(6777),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(6793),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(6795),
    [anon_sym_AND] = ACTIONS(6797),
    [anon_sym_And] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_close] = ACTIONS(3645),
  },
  [STATE(2754)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2755)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2756)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2757)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [anon_sym_POUNDelif] = ACTIONS(3568),
    [anon_sym_POUNDELIF] = ACTIONS(3568),
    [anon_sym_POUNDElif] = ACTIONS(3568),
    [anon_sym_POUNDelse] = ACTIONS(3568),
    [anon_sym_POUNDELSE] = ACTIONS(3568),
    [anon_sym_POUNDElse] = ACTIONS(3568),
    [anon_sym_POUNDelse2] = ACTIONS(3568),
    [anon_sym_POUNDELSE2] = ACTIONS(3568),
    [anon_sym_POUNDElse2] = ACTIONS(3568),
    [anon_sym_POUNDendif] = ACTIONS(3568),
    [anon_sym_POUNDENDIF] = ACTIONS(3568),
    [anon_sym_POUNDEndif] = ACTIONS(3568),
    [anon_sym_POUNDendif2] = ACTIONS(3568),
    [anon_sym_POUNDENDIF2] = ACTIONS(3568),
    [anon_sym_POUNDEndif2] = ACTIONS(3568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_close] = ACTIONS(3568),
  },
  [STATE(2758)] = {
    [sym_comparison_operator] = STATE(4533),
    [sym_in_keyword] = STATE(16470),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_DOT] = ACTIONS(6765),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_COMMA] = ACTIONS(3679),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(6769),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(6771),
    [anon_sym_LBRACK] = ACTIONS(6773),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [anon_sym_POUNDelif] = ACTIONS(3679),
    [anon_sym_POUNDELIF] = ACTIONS(3679),
    [anon_sym_POUNDElif] = ACTIONS(3679),
    [anon_sym_POUNDelse] = ACTIONS(3679),
    [anon_sym_POUNDELSE] = ACTIONS(3679),
    [anon_sym_POUNDElse] = ACTIONS(3679),
    [anon_sym_POUNDelse2] = ACTIONS(3679),
    [anon_sym_POUNDELSE2] = ACTIONS(3679),
    [anon_sym_POUNDElse2] = ACTIONS(3679),
    [anon_sym_POUNDendif] = ACTIONS(3679),
    [anon_sym_POUNDENDIF] = ACTIONS(3679),
    [anon_sym_POUNDEndif] = ACTIONS(3679),
    [anon_sym_POUNDendif2] = ACTIONS(3679),
    [anon_sym_POUNDENDIF2] = ACTIONS(3679),
    [anon_sym_POUNDEndif2] = ACTIONS(3679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(6779),
    [anon_sym_div] = ACTIONS(6781),
    [anon_sym_DIV] = ACTIONS(6783),
    [anon_sym_Div] = ACTIONS(6785),
    [anon_sym_mod] = ACTIONS(6787),
    [anon_sym_MOD] = ACTIONS(6789),
    [anon_sym_Mod] = ACTIONS(6791),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_close] = ACTIONS(3679),
  },
  [STATE(2759)] = {
    [anon_sym_POUNDif] = ACTIONS(6826),
    [anon_sym_POUNDIF] = ACTIONS(6826),
    [anon_sym_POUNDIf] = ACTIONS(6826),
    [anon_sym_POUNDelif] = ACTIONS(6826),
    [anon_sym_POUNDELIF] = ACTIONS(6826),
    [anon_sym_POUNDElif] = ACTIONS(6826),
    [anon_sym_POUNDelse] = ACTIONS(6826),
    [anon_sym_POUNDELSE] = ACTIONS(6826),
    [anon_sym_POUNDElse] = ACTIONS(6826),
    [anon_sym_POUNDelse2] = ACTIONS(6826),
    [anon_sym_POUNDELSE2] = ACTIONS(6826),
    [anon_sym_POUNDElse2] = ACTIONS(6826),
    [anon_sym_POUNDendif] = ACTIONS(6826),
    [anon_sym_POUNDENDIF] = ACTIONS(6826),
    [anon_sym_POUNDEndif] = ACTIONS(6826),
    [anon_sym_POUNDendif2] = ACTIONS(6826),
    [anon_sym_POUNDENDIF2] = ACTIONS(6826),
    [anon_sym_POUNDEndif2] = ACTIONS(6826),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6828),
    [anon_sym_tableextension] = ACTIONS(6826),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6826),
    [anon_sym_Tableextension] = ACTIONS(6826),
    [anon_sym_TableExtension] = ACTIONS(6826),
    [anon_sym_tableExtension] = ACTIONS(6826),
    [sym_page_keyword] = ACTIONS(6828),
    [anon_sym_pageextension] = ACTIONS(6826),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6826),
    [anon_sym_Pageextension] = ACTIONS(6826),
    [anon_sym_PageExtension] = ACTIONS(6826),
    [anon_sym_pageExtension] = ACTIONS(6826),
    [anon_sym_codeunit] = ACTIONS(6826),
    [anon_sym_CODEUNIT] = ACTIONS(6826),
    [anon_sym_Codeunit] = ACTIONS(6826),
    [anon_sym_CodeUnit] = ACTIONS(6826),
    [anon_sym_COdeunit] = ACTIONS(6826),
    [anon_sym_codeUnit] = ACTIONS(6826),
    [sym_report_keyword] = ACTIONS(6828),
    [anon_sym_reportextension] = ACTIONS(6826),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6826),
    [anon_sym_Reportextension] = ACTIONS(6826),
    [anon_sym_ReportExtension] = ACTIONS(6826),
    [anon_sym_reportExtension] = ACTIONS(6826),
    [sym_query_keyword] = ACTIONS(6826),
    [anon_sym_xmlport] = ACTIONS(6826),
    [anon_sym_XMLPORT] = ACTIONS(6826),
    [anon_sym_Xmlport] = ACTIONS(6826),
    [anon_sym_XMLport] = ACTIONS(6826),
    [anon_sym_XMLPort] = ACTIONS(6826),
    [anon_sym_XmlPort] = ACTIONS(6826),
    [anon_sym_enum] = ACTIONS(6828),
    [anon_sym_ENUM] = ACTIONS(6828),
    [anon_sym_Enum] = ACTIONS(6828),
    [anon_sym_eNUM] = ACTIONS(6826),
    [anon_sym_eNum] = ACTIONS(6826),
    [anon_sym_ENum] = ACTIONS(6826),
    [anon_sym_enumextension] = ACTIONS(6826),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6826),
    [anon_sym_Enumextension] = ACTIONS(6826),
    [anon_sym_EnumExtension] = ACTIONS(6826),
    [anon_sym_enumExtension] = ACTIONS(6826),
    [sym_interface_keyword] = ACTIONS(6826),
    [anon_sym_controladdin] = ACTIONS(6826),
    [anon_sym_CONTROLADDIN] = ACTIONS(6826),
    [anon_sym_Controladdin] = ACTIONS(6826),
    [anon_sym_ControlAddIn] = ACTIONS(6826),
    [anon_sym_ControlAddin] = ACTIONS(6826),
    [anon_sym_controlAddIn] = ACTIONS(6826),
    [anon_sym_controlAddin] = ACTIONS(6826),
    [anon_sym_dotnet] = ACTIONS(6826),
    [anon_sym_DOTNET] = ACTIONS(6826),
    [anon_sym_Dotnet] = ACTIONS(6826),
    [anon_sym_DotNet] = ACTIONS(6826),
    [anon_sym_dotNet] = ACTIONS(6826),
    [sym_profile_keyword] = ACTIONS(6828),
    [anon_sym_profileextension] = ACTIONS(6826),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6826),
    [anon_sym_Profileextension] = ACTIONS(6826),
    [anon_sym_ProfileExtension] = ACTIONS(6826),
    [anon_sym_profileExtension] = ACTIONS(6826),
    [anon_sym_permissionset] = ACTIONS(6828),
    [anon_sym_PERMISSIONSET] = ACTIONS(6828),
    [anon_sym_Permissionset] = ACTIONS(6828),
    [anon_sym_PermissionSet] = ACTIONS(6828),
    [anon_sym_permissionSet] = ACTIONS(6828),
    [anon_sym_permissionsetextension] = ACTIONS(6826),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6826),
    [anon_sym_Permissionsetextension] = ACTIONS(6826),
    [anon_sym_PermissionSetExtension] = ACTIONS(6826),
    [anon_sym_permissionSetExtension] = ACTIONS(6826),
    [sym_entitlement_keyword] = ACTIONS(6826),
    [anon_sym_pagecustomization] = ACTIONS(6826),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6826),
    [anon_sym_Pagecustomization] = ACTIONS(6826),
    [anon_sym_PageCustomization] = ACTIONS(6826),
    [anon_sym_pageCustomization] = ACTIONS(6826),
    [sym_using_keyword] = ACTIONS(6826),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6826),
    [sym_preproc_close] = ACTIONS(6826),
  },
  [STATE(2760)] = {
    [anon_sym_POUNDif] = ACTIONS(6830),
    [anon_sym_POUNDIF] = ACTIONS(6830),
    [anon_sym_POUNDIf] = ACTIONS(6830),
    [anon_sym_POUNDelif] = ACTIONS(6830),
    [anon_sym_POUNDELIF] = ACTIONS(6830),
    [anon_sym_POUNDElif] = ACTIONS(6830),
    [anon_sym_POUNDelse] = ACTIONS(6830),
    [anon_sym_POUNDELSE] = ACTIONS(6830),
    [anon_sym_POUNDElse] = ACTIONS(6830),
    [anon_sym_POUNDelse2] = ACTIONS(6830),
    [anon_sym_POUNDELSE2] = ACTIONS(6830),
    [anon_sym_POUNDElse2] = ACTIONS(6830),
    [anon_sym_POUNDendif] = ACTIONS(6830),
    [anon_sym_POUNDENDIF] = ACTIONS(6830),
    [anon_sym_POUNDEndif] = ACTIONS(6830),
    [anon_sym_POUNDendif2] = ACTIONS(6830),
    [anon_sym_POUNDENDIF2] = ACTIONS(6830),
    [anon_sym_POUNDEndif2] = ACTIONS(6830),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6832),
    [anon_sym_tableextension] = ACTIONS(6830),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6830),
    [anon_sym_Tableextension] = ACTIONS(6830),
    [anon_sym_TableExtension] = ACTIONS(6830),
    [anon_sym_tableExtension] = ACTIONS(6830),
    [sym_page_keyword] = ACTIONS(6832),
    [anon_sym_pageextension] = ACTIONS(6830),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6830),
    [anon_sym_Pageextension] = ACTIONS(6830),
    [anon_sym_PageExtension] = ACTIONS(6830),
    [anon_sym_pageExtension] = ACTIONS(6830),
    [anon_sym_codeunit] = ACTIONS(6830),
    [anon_sym_CODEUNIT] = ACTIONS(6830),
    [anon_sym_Codeunit] = ACTIONS(6830),
    [anon_sym_CodeUnit] = ACTIONS(6830),
    [anon_sym_COdeunit] = ACTIONS(6830),
    [anon_sym_codeUnit] = ACTIONS(6830),
    [sym_report_keyword] = ACTIONS(6832),
    [anon_sym_reportextension] = ACTIONS(6830),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6830),
    [anon_sym_Reportextension] = ACTIONS(6830),
    [anon_sym_ReportExtension] = ACTIONS(6830),
    [anon_sym_reportExtension] = ACTIONS(6830),
    [sym_query_keyword] = ACTIONS(6830),
    [anon_sym_xmlport] = ACTIONS(6830),
    [anon_sym_XMLPORT] = ACTIONS(6830),
    [anon_sym_Xmlport] = ACTIONS(6830),
    [anon_sym_XMLport] = ACTIONS(6830),
    [anon_sym_XMLPort] = ACTIONS(6830),
    [anon_sym_XmlPort] = ACTIONS(6830),
    [anon_sym_enum] = ACTIONS(6832),
    [anon_sym_ENUM] = ACTIONS(6832),
    [anon_sym_Enum] = ACTIONS(6832),
    [anon_sym_eNUM] = ACTIONS(6830),
    [anon_sym_eNum] = ACTIONS(6830),
    [anon_sym_ENum] = ACTIONS(6830),
    [anon_sym_enumextension] = ACTIONS(6830),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6830),
    [anon_sym_Enumextension] = ACTIONS(6830),
    [anon_sym_EnumExtension] = ACTIONS(6830),
    [anon_sym_enumExtension] = ACTIONS(6830),
    [sym_interface_keyword] = ACTIONS(6830),
    [anon_sym_controladdin] = ACTIONS(6830),
    [anon_sym_CONTROLADDIN] = ACTIONS(6830),
    [anon_sym_Controladdin] = ACTIONS(6830),
    [anon_sym_ControlAddIn] = ACTIONS(6830),
    [anon_sym_ControlAddin] = ACTIONS(6830),
    [anon_sym_controlAddIn] = ACTIONS(6830),
    [anon_sym_controlAddin] = ACTIONS(6830),
    [anon_sym_dotnet] = ACTIONS(6830),
    [anon_sym_DOTNET] = ACTIONS(6830),
    [anon_sym_Dotnet] = ACTIONS(6830),
    [anon_sym_DotNet] = ACTIONS(6830),
    [anon_sym_dotNet] = ACTIONS(6830),
    [sym_profile_keyword] = ACTIONS(6832),
    [anon_sym_profileextension] = ACTIONS(6830),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6830),
    [anon_sym_Profileextension] = ACTIONS(6830),
    [anon_sym_ProfileExtension] = ACTIONS(6830),
    [anon_sym_profileExtension] = ACTIONS(6830),
    [anon_sym_permissionset] = ACTIONS(6832),
    [anon_sym_PERMISSIONSET] = ACTIONS(6832),
    [anon_sym_Permissionset] = ACTIONS(6832),
    [anon_sym_PermissionSet] = ACTIONS(6832),
    [anon_sym_permissionSet] = ACTIONS(6832),
    [anon_sym_permissionsetextension] = ACTIONS(6830),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6830),
    [anon_sym_Permissionsetextension] = ACTIONS(6830),
    [anon_sym_PermissionSetExtension] = ACTIONS(6830),
    [anon_sym_permissionSetExtension] = ACTIONS(6830),
    [sym_entitlement_keyword] = ACTIONS(6830),
    [anon_sym_pagecustomization] = ACTIONS(6830),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6830),
    [anon_sym_Pagecustomization] = ACTIONS(6830),
    [anon_sym_PageCustomization] = ACTIONS(6830),
    [anon_sym_pageCustomization] = ACTIONS(6830),
    [sym_using_keyword] = ACTIONS(6830),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6830),
    [sym_preproc_close] = ACTIONS(6830),
  },
  [STATE(2761)] = {
    [anon_sym_POUNDif] = ACTIONS(6834),
    [anon_sym_POUNDIF] = ACTIONS(6834),
    [anon_sym_POUNDIf] = ACTIONS(6834),
    [anon_sym_POUNDelif] = ACTIONS(6834),
    [anon_sym_POUNDELIF] = ACTIONS(6834),
    [anon_sym_POUNDElif] = ACTIONS(6834),
    [anon_sym_POUNDelse] = ACTIONS(6834),
    [anon_sym_POUNDELSE] = ACTIONS(6834),
    [anon_sym_POUNDElse] = ACTIONS(6834),
    [anon_sym_POUNDelse2] = ACTIONS(6834),
    [anon_sym_POUNDELSE2] = ACTIONS(6834),
    [anon_sym_POUNDElse2] = ACTIONS(6834),
    [anon_sym_POUNDendif] = ACTIONS(6834),
    [anon_sym_POUNDENDIF] = ACTIONS(6834),
    [anon_sym_POUNDEndif] = ACTIONS(6834),
    [anon_sym_POUNDendif2] = ACTIONS(6834),
    [anon_sym_POUNDENDIF2] = ACTIONS(6834),
    [anon_sym_POUNDEndif2] = ACTIONS(6834),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6836),
    [anon_sym_tableextension] = ACTIONS(6834),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6834),
    [anon_sym_Tableextension] = ACTIONS(6834),
    [anon_sym_TableExtension] = ACTIONS(6834),
    [anon_sym_tableExtension] = ACTIONS(6834),
    [sym_page_keyword] = ACTIONS(6836),
    [anon_sym_pageextension] = ACTIONS(6834),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6834),
    [anon_sym_Pageextension] = ACTIONS(6834),
    [anon_sym_PageExtension] = ACTIONS(6834),
    [anon_sym_pageExtension] = ACTIONS(6834),
    [anon_sym_codeunit] = ACTIONS(6834),
    [anon_sym_CODEUNIT] = ACTIONS(6834),
    [anon_sym_Codeunit] = ACTIONS(6834),
    [anon_sym_CodeUnit] = ACTIONS(6834),
    [anon_sym_COdeunit] = ACTIONS(6834),
    [anon_sym_codeUnit] = ACTIONS(6834),
    [sym_report_keyword] = ACTIONS(6836),
    [anon_sym_reportextension] = ACTIONS(6834),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6834),
    [anon_sym_Reportextension] = ACTIONS(6834),
    [anon_sym_ReportExtension] = ACTIONS(6834),
    [anon_sym_reportExtension] = ACTIONS(6834),
    [sym_query_keyword] = ACTIONS(6834),
    [anon_sym_xmlport] = ACTIONS(6834),
    [anon_sym_XMLPORT] = ACTIONS(6834),
    [anon_sym_Xmlport] = ACTIONS(6834),
    [anon_sym_XMLport] = ACTIONS(6834),
    [anon_sym_XMLPort] = ACTIONS(6834),
    [anon_sym_XmlPort] = ACTIONS(6834),
    [anon_sym_enum] = ACTIONS(6836),
    [anon_sym_ENUM] = ACTIONS(6836),
    [anon_sym_Enum] = ACTIONS(6836),
    [anon_sym_eNUM] = ACTIONS(6834),
    [anon_sym_eNum] = ACTIONS(6834),
    [anon_sym_ENum] = ACTIONS(6834),
    [anon_sym_enumextension] = ACTIONS(6834),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6834),
    [anon_sym_Enumextension] = ACTIONS(6834),
    [anon_sym_EnumExtension] = ACTIONS(6834),
    [anon_sym_enumExtension] = ACTIONS(6834),
    [sym_interface_keyword] = ACTIONS(6834),
    [anon_sym_controladdin] = ACTIONS(6834),
    [anon_sym_CONTROLADDIN] = ACTIONS(6834),
    [anon_sym_Controladdin] = ACTIONS(6834),
    [anon_sym_ControlAddIn] = ACTIONS(6834),
    [anon_sym_ControlAddin] = ACTIONS(6834),
    [anon_sym_controlAddIn] = ACTIONS(6834),
    [anon_sym_controlAddin] = ACTIONS(6834),
    [anon_sym_dotnet] = ACTIONS(6834),
    [anon_sym_DOTNET] = ACTIONS(6834),
    [anon_sym_Dotnet] = ACTIONS(6834),
    [anon_sym_DotNet] = ACTIONS(6834),
    [anon_sym_dotNet] = ACTIONS(6834),
    [sym_profile_keyword] = ACTIONS(6836),
    [anon_sym_profileextension] = ACTIONS(6834),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6834),
    [anon_sym_Profileextension] = ACTIONS(6834),
    [anon_sym_ProfileExtension] = ACTIONS(6834),
    [anon_sym_profileExtension] = ACTIONS(6834),
    [anon_sym_permissionset] = ACTIONS(6836),
    [anon_sym_PERMISSIONSET] = ACTIONS(6836),
    [anon_sym_Permissionset] = ACTIONS(6836),
    [anon_sym_PermissionSet] = ACTIONS(6836),
    [anon_sym_permissionSet] = ACTIONS(6836),
    [anon_sym_permissionsetextension] = ACTIONS(6834),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6834),
    [anon_sym_Permissionsetextension] = ACTIONS(6834),
    [anon_sym_PermissionSetExtension] = ACTIONS(6834),
    [anon_sym_permissionSetExtension] = ACTIONS(6834),
    [sym_entitlement_keyword] = ACTIONS(6834),
    [anon_sym_pagecustomization] = ACTIONS(6834),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6834),
    [anon_sym_Pagecustomization] = ACTIONS(6834),
    [anon_sym_PageCustomization] = ACTIONS(6834),
    [anon_sym_pageCustomization] = ACTIONS(6834),
    [sym_using_keyword] = ACTIONS(6834),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6834),
    [sym_preproc_close] = ACTIONS(6834),
  },
  [STATE(2762)] = {
    [anon_sym_POUNDif] = ACTIONS(6838),
    [anon_sym_POUNDIF] = ACTIONS(6838),
    [anon_sym_POUNDIf] = ACTIONS(6838),
    [anon_sym_POUNDelif] = ACTIONS(6838),
    [anon_sym_POUNDELIF] = ACTIONS(6838),
    [anon_sym_POUNDElif] = ACTIONS(6838),
    [anon_sym_POUNDelse] = ACTIONS(6838),
    [anon_sym_POUNDELSE] = ACTIONS(6838),
    [anon_sym_POUNDElse] = ACTIONS(6838),
    [anon_sym_POUNDelse2] = ACTIONS(6838),
    [anon_sym_POUNDELSE2] = ACTIONS(6838),
    [anon_sym_POUNDElse2] = ACTIONS(6838),
    [anon_sym_POUNDendif] = ACTIONS(6838),
    [anon_sym_POUNDENDIF] = ACTIONS(6838),
    [anon_sym_POUNDEndif] = ACTIONS(6838),
    [anon_sym_POUNDendif2] = ACTIONS(6838),
    [anon_sym_POUNDENDIF2] = ACTIONS(6838),
    [anon_sym_POUNDEndif2] = ACTIONS(6838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6840),
    [anon_sym_tableextension] = ACTIONS(6838),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6838),
    [anon_sym_Tableextension] = ACTIONS(6838),
    [anon_sym_TableExtension] = ACTIONS(6838),
    [anon_sym_tableExtension] = ACTIONS(6838),
    [sym_page_keyword] = ACTIONS(6840),
    [anon_sym_pageextension] = ACTIONS(6838),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6838),
    [anon_sym_Pageextension] = ACTIONS(6838),
    [anon_sym_PageExtension] = ACTIONS(6838),
    [anon_sym_pageExtension] = ACTIONS(6838),
    [anon_sym_codeunit] = ACTIONS(6838),
    [anon_sym_CODEUNIT] = ACTIONS(6838),
    [anon_sym_Codeunit] = ACTIONS(6838),
    [anon_sym_CodeUnit] = ACTIONS(6838),
    [anon_sym_COdeunit] = ACTIONS(6838),
    [anon_sym_codeUnit] = ACTIONS(6838),
    [sym_report_keyword] = ACTIONS(6840),
    [anon_sym_reportextension] = ACTIONS(6838),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6838),
    [anon_sym_Reportextension] = ACTIONS(6838),
    [anon_sym_ReportExtension] = ACTIONS(6838),
    [anon_sym_reportExtension] = ACTIONS(6838),
    [sym_query_keyword] = ACTIONS(6838),
    [anon_sym_xmlport] = ACTIONS(6838),
    [anon_sym_XMLPORT] = ACTIONS(6838),
    [anon_sym_Xmlport] = ACTIONS(6838),
    [anon_sym_XMLport] = ACTIONS(6838),
    [anon_sym_XMLPort] = ACTIONS(6838),
    [anon_sym_XmlPort] = ACTIONS(6838),
    [anon_sym_enum] = ACTIONS(6840),
    [anon_sym_ENUM] = ACTIONS(6840),
    [anon_sym_Enum] = ACTIONS(6840),
    [anon_sym_eNUM] = ACTIONS(6838),
    [anon_sym_eNum] = ACTIONS(6838),
    [anon_sym_ENum] = ACTIONS(6838),
    [anon_sym_enumextension] = ACTIONS(6838),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6838),
    [anon_sym_Enumextension] = ACTIONS(6838),
    [anon_sym_EnumExtension] = ACTIONS(6838),
    [anon_sym_enumExtension] = ACTIONS(6838),
    [sym_interface_keyword] = ACTIONS(6838),
    [anon_sym_controladdin] = ACTIONS(6838),
    [anon_sym_CONTROLADDIN] = ACTIONS(6838),
    [anon_sym_Controladdin] = ACTIONS(6838),
    [anon_sym_ControlAddIn] = ACTIONS(6838),
    [anon_sym_ControlAddin] = ACTIONS(6838),
    [anon_sym_controlAddIn] = ACTIONS(6838),
    [anon_sym_controlAddin] = ACTIONS(6838),
    [anon_sym_dotnet] = ACTIONS(6838),
    [anon_sym_DOTNET] = ACTIONS(6838),
    [anon_sym_Dotnet] = ACTIONS(6838),
    [anon_sym_DotNet] = ACTIONS(6838),
    [anon_sym_dotNet] = ACTIONS(6838),
    [sym_profile_keyword] = ACTIONS(6840),
    [anon_sym_profileextension] = ACTIONS(6838),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6838),
    [anon_sym_Profileextension] = ACTIONS(6838),
    [anon_sym_ProfileExtension] = ACTIONS(6838),
    [anon_sym_profileExtension] = ACTIONS(6838),
    [anon_sym_permissionset] = ACTIONS(6840),
    [anon_sym_PERMISSIONSET] = ACTIONS(6840),
    [anon_sym_Permissionset] = ACTIONS(6840),
    [anon_sym_PermissionSet] = ACTIONS(6840),
    [anon_sym_permissionSet] = ACTIONS(6840),
    [anon_sym_permissionsetextension] = ACTIONS(6838),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6838),
    [anon_sym_Permissionsetextension] = ACTIONS(6838),
    [anon_sym_PermissionSetExtension] = ACTIONS(6838),
    [anon_sym_permissionSetExtension] = ACTIONS(6838),
    [sym_entitlement_keyword] = ACTIONS(6838),
    [anon_sym_pagecustomization] = ACTIONS(6838),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6838),
    [anon_sym_Pagecustomization] = ACTIONS(6838),
    [anon_sym_PageCustomization] = ACTIONS(6838),
    [anon_sym_pageCustomization] = ACTIONS(6838),
    [sym_using_keyword] = ACTIONS(6838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6838),
    [sym_preproc_close] = ACTIONS(6838),
  },
  [STATE(2763)] = {
    [anon_sym_POUNDif] = ACTIONS(6842),
    [anon_sym_POUNDIF] = ACTIONS(6842),
    [anon_sym_POUNDIf] = ACTIONS(6842),
    [anon_sym_POUNDelif] = ACTIONS(6842),
    [anon_sym_POUNDELIF] = ACTIONS(6842),
    [anon_sym_POUNDElif] = ACTIONS(6842),
    [anon_sym_POUNDelse] = ACTIONS(6842),
    [anon_sym_POUNDELSE] = ACTIONS(6842),
    [anon_sym_POUNDElse] = ACTIONS(6842),
    [anon_sym_POUNDelse2] = ACTIONS(6842),
    [anon_sym_POUNDELSE2] = ACTIONS(6842),
    [anon_sym_POUNDElse2] = ACTIONS(6842),
    [anon_sym_POUNDendif] = ACTIONS(6842),
    [anon_sym_POUNDENDIF] = ACTIONS(6842),
    [anon_sym_POUNDEndif] = ACTIONS(6842),
    [anon_sym_POUNDendif2] = ACTIONS(6842),
    [anon_sym_POUNDENDIF2] = ACTIONS(6842),
    [anon_sym_POUNDEndif2] = ACTIONS(6842),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6844),
    [anon_sym_tableextension] = ACTIONS(6842),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6842),
    [anon_sym_Tableextension] = ACTIONS(6842),
    [anon_sym_TableExtension] = ACTIONS(6842),
    [anon_sym_tableExtension] = ACTIONS(6842),
    [sym_page_keyword] = ACTIONS(6844),
    [anon_sym_pageextension] = ACTIONS(6842),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6842),
    [anon_sym_Pageextension] = ACTIONS(6842),
    [anon_sym_PageExtension] = ACTIONS(6842),
    [anon_sym_pageExtension] = ACTIONS(6842),
    [anon_sym_codeunit] = ACTIONS(6842),
    [anon_sym_CODEUNIT] = ACTIONS(6842),
    [anon_sym_Codeunit] = ACTIONS(6842),
    [anon_sym_CodeUnit] = ACTIONS(6842),
    [anon_sym_COdeunit] = ACTIONS(6842),
    [anon_sym_codeUnit] = ACTIONS(6842),
    [sym_report_keyword] = ACTIONS(6844),
    [anon_sym_reportextension] = ACTIONS(6842),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6842),
    [anon_sym_Reportextension] = ACTIONS(6842),
    [anon_sym_ReportExtension] = ACTIONS(6842),
    [anon_sym_reportExtension] = ACTIONS(6842),
    [sym_query_keyword] = ACTIONS(6842),
    [anon_sym_xmlport] = ACTIONS(6842),
    [anon_sym_XMLPORT] = ACTIONS(6842),
    [anon_sym_Xmlport] = ACTIONS(6842),
    [anon_sym_XMLport] = ACTIONS(6842),
    [anon_sym_XMLPort] = ACTIONS(6842),
    [anon_sym_XmlPort] = ACTIONS(6842),
    [anon_sym_enum] = ACTIONS(6844),
    [anon_sym_ENUM] = ACTIONS(6844),
    [anon_sym_Enum] = ACTIONS(6844),
    [anon_sym_eNUM] = ACTIONS(6842),
    [anon_sym_eNum] = ACTIONS(6842),
    [anon_sym_ENum] = ACTIONS(6842),
    [anon_sym_enumextension] = ACTIONS(6842),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6842),
    [anon_sym_Enumextension] = ACTIONS(6842),
    [anon_sym_EnumExtension] = ACTIONS(6842),
    [anon_sym_enumExtension] = ACTIONS(6842),
    [sym_interface_keyword] = ACTIONS(6842),
    [anon_sym_controladdin] = ACTIONS(6842),
    [anon_sym_CONTROLADDIN] = ACTIONS(6842),
    [anon_sym_Controladdin] = ACTIONS(6842),
    [anon_sym_ControlAddIn] = ACTIONS(6842),
    [anon_sym_ControlAddin] = ACTIONS(6842),
    [anon_sym_controlAddIn] = ACTIONS(6842),
    [anon_sym_controlAddin] = ACTIONS(6842),
    [anon_sym_dotnet] = ACTIONS(6842),
    [anon_sym_DOTNET] = ACTIONS(6842),
    [anon_sym_Dotnet] = ACTIONS(6842),
    [anon_sym_DotNet] = ACTIONS(6842),
    [anon_sym_dotNet] = ACTIONS(6842),
    [sym_profile_keyword] = ACTIONS(6844),
    [anon_sym_profileextension] = ACTIONS(6842),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6842),
    [anon_sym_Profileextension] = ACTIONS(6842),
    [anon_sym_ProfileExtension] = ACTIONS(6842),
    [anon_sym_profileExtension] = ACTIONS(6842),
    [anon_sym_permissionset] = ACTIONS(6844),
    [anon_sym_PERMISSIONSET] = ACTIONS(6844),
    [anon_sym_Permissionset] = ACTIONS(6844),
    [anon_sym_PermissionSet] = ACTIONS(6844),
    [anon_sym_permissionSet] = ACTIONS(6844),
    [anon_sym_permissionsetextension] = ACTIONS(6842),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6842),
    [anon_sym_Permissionsetextension] = ACTIONS(6842),
    [anon_sym_PermissionSetExtension] = ACTIONS(6842),
    [anon_sym_permissionSetExtension] = ACTIONS(6842),
    [sym_entitlement_keyword] = ACTIONS(6842),
    [anon_sym_pagecustomization] = ACTIONS(6842),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6842),
    [anon_sym_Pagecustomization] = ACTIONS(6842),
    [anon_sym_PageCustomization] = ACTIONS(6842),
    [anon_sym_pageCustomization] = ACTIONS(6842),
    [sym_using_keyword] = ACTIONS(6842),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6842),
    [sym_preproc_close] = ACTIONS(6842),
  },
  [STATE(2764)] = {
    [anon_sym_POUNDif] = ACTIONS(6846),
    [anon_sym_POUNDIF] = ACTIONS(6846),
    [anon_sym_POUNDIf] = ACTIONS(6846),
    [anon_sym_POUNDelif] = ACTIONS(6846),
    [anon_sym_POUNDELIF] = ACTIONS(6846),
    [anon_sym_POUNDElif] = ACTIONS(6846),
    [anon_sym_POUNDelse] = ACTIONS(6846),
    [anon_sym_POUNDELSE] = ACTIONS(6846),
    [anon_sym_POUNDElse] = ACTIONS(6846),
    [anon_sym_POUNDelse2] = ACTIONS(6846),
    [anon_sym_POUNDELSE2] = ACTIONS(6846),
    [anon_sym_POUNDElse2] = ACTIONS(6846),
    [anon_sym_POUNDendif] = ACTIONS(6846),
    [anon_sym_POUNDENDIF] = ACTIONS(6846),
    [anon_sym_POUNDEndif] = ACTIONS(6846),
    [anon_sym_POUNDendif2] = ACTIONS(6846),
    [anon_sym_POUNDENDIF2] = ACTIONS(6846),
    [anon_sym_POUNDEndif2] = ACTIONS(6846),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6848),
    [anon_sym_tableextension] = ACTIONS(6846),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6846),
    [anon_sym_Tableextension] = ACTIONS(6846),
    [anon_sym_TableExtension] = ACTIONS(6846),
    [anon_sym_tableExtension] = ACTIONS(6846),
    [sym_page_keyword] = ACTIONS(6848),
    [anon_sym_pageextension] = ACTIONS(6846),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6846),
    [anon_sym_Pageextension] = ACTIONS(6846),
    [anon_sym_PageExtension] = ACTIONS(6846),
    [anon_sym_pageExtension] = ACTIONS(6846),
    [anon_sym_codeunit] = ACTIONS(6846),
    [anon_sym_CODEUNIT] = ACTIONS(6846),
    [anon_sym_Codeunit] = ACTIONS(6846),
    [anon_sym_CodeUnit] = ACTIONS(6846),
    [anon_sym_COdeunit] = ACTIONS(6846),
    [anon_sym_codeUnit] = ACTIONS(6846),
    [sym_report_keyword] = ACTIONS(6848),
    [anon_sym_reportextension] = ACTIONS(6846),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6846),
    [anon_sym_Reportextension] = ACTIONS(6846),
    [anon_sym_ReportExtension] = ACTIONS(6846),
    [anon_sym_reportExtension] = ACTIONS(6846),
    [sym_query_keyword] = ACTIONS(6846),
    [anon_sym_xmlport] = ACTIONS(6846),
    [anon_sym_XMLPORT] = ACTIONS(6846),
    [anon_sym_Xmlport] = ACTIONS(6846),
    [anon_sym_XMLport] = ACTIONS(6846),
    [anon_sym_XMLPort] = ACTIONS(6846),
    [anon_sym_XmlPort] = ACTIONS(6846),
    [anon_sym_enum] = ACTIONS(6848),
    [anon_sym_ENUM] = ACTIONS(6848),
    [anon_sym_Enum] = ACTIONS(6848),
    [anon_sym_eNUM] = ACTIONS(6846),
    [anon_sym_eNum] = ACTIONS(6846),
    [anon_sym_ENum] = ACTIONS(6846),
    [anon_sym_enumextension] = ACTIONS(6846),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6846),
    [anon_sym_Enumextension] = ACTIONS(6846),
    [anon_sym_EnumExtension] = ACTIONS(6846),
    [anon_sym_enumExtension] = ACTIONS(6846),
    [sym_interface_keyword] = ACTIONS(6846),
    [anon_sym_controladdin] = ACTIONS(6846),
    [anon_sym_CONTROLADDIN] = ACTIONS(6846),
    [anon_sym_Controladdin] = ACTIONS(6846),
    [anon_sym_ControlAddIn] = ACTIONS(6846),
    [anon_sym_ControlAddin] = ACTIONS(6846),
    [anon_sym_controlAddIn] = ACTIONS(6846),
    [anon_sym_controlAddin] = ACTIONS(6846),
    [anon_sym_dotnet] = ACTIONS(6846),
    [anon_sym_DOTNET] = ACTIONS(6846),
    [anon_sym_Dotnet] = ACTIONS(6846),
    [anon_sym_DotNet] = ACTIONS(6846),
    [anon_sym_dotNet] = ACTIONS(6846),
    [sym_profile_keyword] = ACTIONS(6848),
    [anon_sym_profileextension] = ACTIONS(6846),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6846),
    [anon_sym_Profileextension] = ACTIONS(6846),
    [anon_sym_ProfileExtension] = ACTIONS(6846),
    [anon_sym_profileExtension] = ACTIONS(6846),
    [anon_sym_permissionset] = ACTIONS(6848),
    [anon_sym_PERMISSIONSET] = ACTIONS(6848),
    [anon_sym_Permissionset] = ACTIONS(6848),
    [anon_sym_PermissionSet] = ACTIONS(6848),
    [anon_sym_permissionSet] = ACTIONS(6848),
    [anon_sym_permissionsetextension] = ACTIONS(6846),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6846),
    [anon_sym_Permissionsetextension] = ACTIONS(6846),
    [anon_sym_PermissionSetExtension] = ACTIONS(6846),
    [anon_sym_permissionSetExtension] = ACTIONS(6846),
    [sym_entitlement_keyword] = ACTIONS(6846),
    [anon_sym_pagecustomization] = ACTIONS(6846),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6846),
    [anon_sym_Pagecustomization] = ACTIONS(6846),
    [anon_sym_PageCustomization] = ACTIONS(6846),
    [anon_sym_pageCustomization] = ACTIONS(6846),
    [sym_using_keyword] = ACTIONS(6846),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6846),
    [sym_preproc_close] = ACTIONS(6846),
  },
  [STATE(2765)] = {
    [anon_sym_POUNDif] = ACTIONS(6850),
    [anon_sym_POUNDIF] = ACTIONS(6850),
    [anon_sym_POUNDIf] = ACTIONS(6850),
    [anon_sym_POUNDelif] = ACTIONS(6850),
    [anon_sym_POUNDELIF] = ACTIONS(6850),
    [anon_sym_POUNDElif] = ACTIONS(6850),
    [anon_sym_POUNDelse] = ACTIONS(6850),
    [anon_sym_POUNDELSE] = ACTIONS(6850),
    [anon_sym_POUNDElse] = ACTIONS(6850),
    [anon_sym_POUNDelse2] = ACTIONS(6850),
    [anon_sym_POUNDELSE2] = ACTIONS(6850),
    [anon_sym_POUNDElse2] = ACTIONS(6850),
    [anon_sym_POUNDendif] = ACTIONS(6850),
    [anon_sym_POUNDENDIF] = ACTIONS(6850),
    [anon_sym_POUNDEndif] = ACTIONS(6850),
    [anon_sym_POUNDendif2] = ACTIONS(6850),
    [anon_sym_POUNDENDIF2] = ACTIONS(6850),
    [anon_sym_POUNDEndif2] = ACTIONS(6850),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6852),
    [anon_sym_tableextension] = ACTIONS(6850),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6850),
    [anon_sym_Tableextension] = ACTIONS(6850),
    [anon_sym_TableExtension] = ACTIONS(6850),
    [anon_sym_tableExtension] = ACTIONS(6850),
    [sym_page_keyword] = ACTIONS(6852),
    [anon_sym_pageextension] = ACTIONS(6850),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6850),
    [anon_sym_Pageextension] = ACTIONS(6850),
    [anon_sym_PageExtension] = ACTIONS(6850),
    [anon_sym_pageExtension] = ACTIONS(6850),
    [anon_sym_codeunit] = ACTIONS(6850),
    [anon_sym_CODEUNIT] = ACTIONS(6850),
    [anon_sym_Codeunit] = ACTIONS(6850),
    [anon_sym_CodeUnit] = ACTIONS(6850),
    [anon_sym_COdeunit] = ACTIONS(6850),
    [anon_sym_codeUnit] = ACTIONS(6850),
    [sym_report_keyword] = ACTIONS(6852),
    [anon_sym_reportextension] = ACTIONS(6850),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6850),
    [anon_sym_Reportextension] = ACTIONS(6850),
    [anon_sym_ReportExtension] = ACTIONS(6850),
    [anon_sym_reportExtension] = ACTIONS(6850),
    [sym_query_keyword] = ACTIONS(6850),
    [anon_sym_xmlport] = ACTIONS(6850),
    [anon_sym_XMLPORT] = ACTIONS(6850),
    [anon_sym_Xmlport] = ACTIONS(6850),
    [anon_sym_XMLport] = ACTIONS(6850),
    [anon_sym_XMLPort] = ACTIONS(6850),
    [anon_sym_XmlPort] = ACTIONS(6850),
    [anon_sym_enum] = ACTIONS(6852),
    [anon_sym_ENUM] = ACTIONS(6852),
    [anon_sym_Enum] = ACTIONS(6852),
    [anon_sym_eNUM] = ACTIONS(6850),
    [anon_sym_eNum] = ACTIONS(6850),
    [anon_sym_ENum] = ACTIONS(6850),
    [anon_sym_enumextension] = ACTIONS(6850),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6850),
    [anon_sym_Enumextension] = ACTIONS(6850),
    [anon_sym_EnumExtension] = ACTIONS(6850),
    [anon_sym_enumExtension] = ACTIONS(6850),
    [sym_interface_keyword] = ACTIONS(6850),
    [anon_sym_controladdin] = ACTIONS(6850),
    [anon_sym_CONTROLADDIN] = ACTIONS(6850),
    [anon_sym_Controladdin] = ACTIONS(6850),
    [anon_sym_ControlAddIn] = ACTIONS(6850),
    [anon_sym_ControlAddin] = ACTIONS(6850),
    [anon_sym_controlAddIn] = ACTIONS(6850),
    [anon_sym_controlAddin] = ACTIONS(6850),
    [anon_sym_dotnet] = ACTIONS(6850),
    [anon_sym_DOTNET] = ACTIONS(6850),
    [anon_sym_Dotnet] = ACTIONS(6850),
    [anon_sym_DotNet] = ACTIONS(6850),
    [anon_sym_dotNet] = ACTIONS(6850),
    [sym_profile_keyword] = ACTIONS(6852),
    [anon_sym_profileextension] = ACTIONS(6850),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6850),
    [anon_sym_Profileextension] = ACTIONS(6850),
    [anon_sym_ProfileExtension] = ACTIONS(6850),
    [anon_sym_profileExtension] = ACTIONS(6850),
    [anon_sym_permissionset] = ACTIONS(6852),
    [anon_sym_PERMISSIONSET] = ACTIONS(6852),
    [anon_sym_Permissionset] = ACTIONS(6852),
    [anon_sym_PermissionSet] = ACTIONS(6852),
    [anon_sym_permissionSet] = ACTIONS(6852),
    [anon_sym_permissionsetextension] = ACTIONS(6850),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6850),
    [anon_sym_Permissionsetextension] = ACTIONS(6850),
    [anon_sym_PermissionSetExtension] = ACTIONS(6850),
    [anon_sym_permissionSetExtension] = ACTIONS(6850),
    [sym_entitlement_keyword] = ACTIONS(6850),
    [anon_sym_pagecustomization] = ACTIONS(6850),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6850),
    [anon_sym_Pagecustomization] = ACTIONS(6850),
    [anon_sym_PageCustomization] = ACTIONS(6850),
    [anon_sym_pageCustomization] = ACTIONS(6850),
    [sym_using_keyword] = ACTIONS(6850),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6850),
    [sym_preproc_close] = ACTIONS(6850),
  },
  [STATE(2766)] = {
    [anon_sym_POUNDif] = ACTIONS(6854),
    [anon_sym_POUNDIF] = ACTIONS(6854),
    [anon_sym_POUNDIf] = ACTIONS(6854),
    [anon_sym_POUNDelif] = ACTIONS(6854),
    [anon_sym_POUNDELIF] = ACTIONS(6854),
    [anon_sym_POUNDElif] = ACTIONS(6854),
    [anon_sym_POUNDelse] = ACTIONS(6854),
    [anon_sym_POUNDELSE] = ACTIONS(6854),
    [anon_sym_POUNDElse] = ACTIONS(6854),
    [anon_sym_POUNDelse2] = ACTIONS(6854),
    [anon_sym_POUNDELSE2] = ACTIONS(6854),
    [anon_sym_POUNDElse2] = ACTIONS(6854),
    [anon_sym_POUNDendif] = ACTIONS(6854),
    [anon_sym_POUNDENDIF] = ACTIONS(6854),
    [anon_sym_POUNDEndif] = ACTIONS(6854),
    [anon_sym_POUNDendif2] = ACTIONS(6854),
    [anon_sym_POUNDENDIF2] = ACTIONS(6854),
    [anon_sym_POUNDEndif2] = ACTIONS(6854),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6856),
    [anon_sym_tableextension] = ACTIONS(6854),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6854),
    [anon_sym_Tableextension] = ACTIONS(6854),
    [anon_sym_TableExtension] = ACTIONS(6854),
    [anon_sym_tableExtension] = ACTIONS(6854),
    [sym_page_keyword] = ACTIONS(6856),
    [anon_sym_pageextension] = ACTIONS(6854),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6854),
    [anon_sym_Pageextension] = ACTIONS(6854),
    [anon_sym_PageExtension] = ACTIONS(6854),
    [anon_sym_pageExtension] = ACTIONS(6854),
    [anon_sym_codeunit] = ACTIONS(6854),
    [anon_sym_CODEUNIT] = ACTIONS(6854),
    [anon_sym_Codeunit] = ACTIONS(6854),
    [anon_sym_CodeUnit] = ACTIONS(6854),
    [anon_sym_COdeunit] = ACTIONS(6854),
    [anon_sym_codeUnit] = ACTIONS(6854),
    [sym_report_keyword] = ACTIONS(6856),
    [anon_sym_reportextension] = ACTIONS(6854),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6854),
    [anon_sym_Reportextension] = ACTIONS(6854),
    [anon_sym_ReportExtension] = ACTIONS(6854),
    [anon_sym_reportExtension] = ACTIONS(6854),
    [sym_query_keyword] = ACTIONS(6854),
    [anon_sym_xmlport] = ACTIONS(6854),
    [anon_sym_XMLPORT] = ACTIONS(6854),
    [anon_sym_Xmlport] = ACTIONS(6854),
    [anon_sym_XMLport] = ACTIONS(6854),
    [anon_sym_XMLPort] = ACTIONS(6854),
    [anon_sym_XmlPort] = ACTIONS(6854),
    [anon_sym_enum] = ACTIONS(6856),
    [anon_sym_ENUM] = ACTIONS(6856),
    [anon_sym_Enum] = ACTIONS(6856),
    [anon_sym_eNUM] = ACTIONS(6854),
    [anon_sym_eNum] = ACTIONS(6854),
    [anon_sym_ENum] = ACTIONS(6854),
    [anon_sym_enumextension] = ACTIONS(6854),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6854),
    [anon_sym_Enumextension] = ACTIONS(6854),
    [anon_sym_EnumExtension] = ACTIONS(6854),
    [anon_sym_enumExtension] = ACTIONS(6854),
    [sym_interface_keyword] = ACTIONS(6854),
    [anon_sym_controladdin] = ACTIONS(6854),
    [anon_sym_CONTROLADDIN] = ACTIONS(6854),
    [anon_sym_Controladdin] = ACTIONS(6854),
    [anon_sym_ControlAddIn] = ACTIONS(6854),
    [anon_sym_ControlAddin] = ACTIONS(6854),
    [anon_sym_controlAddIn] = ACTIONS(6854),
    [anon_sym_controlAddin] = ACTIONS(6854),
    [anon_sym_dotnet] = ACTIONS(6854),
    [anon_sym_DOTNET] = ACTIONS(6854),
    [anon_sym_Dotnet] = ACTIONS(6854),
    [anon_sym_DotNet] = ACTIONS(6854),
    [anon_sym_dotNet] = ACTIONS(6854),
    [sym_profile_keyword] = ACTIONS(6856),
    [anon_sym_profileextension] = ACTIONS(6854),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6854),
    [anon_sym_Profileextension] = ACTIONS(6854),
    [anon_sym_ProfileExtension] = ACTIONS(6854),
    [anon_sym_profileExtension] = ACTIONS(6854),
    [anon_sym_permissionset] = ACTIONS(6856),
    [anon_sym_PERMISSIONSET] = ACTIONS(6856),
    [anon_sym_Permissionset] = ACTIONS(6856),
    [anon_sym_PermissionSet] = ACTIONS(6856),
    [anon_sym_permissionSet] = ACTIONS(6856),
    [anon_sym_permissionsetextension] = ACTIONS(6854),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6854),
    [anon_sym_Permissionsetextension] = ACTIONS(6854),
    [anon_sym_PermissionSetExtension] = ACTIONS(6854),
    [anon_sym_permissionSetExtension] = ACTIONS(6854),
    [sym_entitlement_keyword] = ACTIONS(6854),
    [anon_sym_pagecustomization] = ACTIONS(6854),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6854),
    [anon_sym_Pagecustomization] = ACTIONS(6854),
    [anon_sym_PageCustomization] = ACTIONS(6854),
    [anon_sym_pageCustomization] = ACTIONS(6854),
    [sym_using_keyword] = ACTIONS(6854),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6854),
    [sym_preproc_close] = ACTIONS(6854),
  },
  [STATE(2767)] = {
    [anon_sym_POUNDif] = ACTIONS(6858),
    [anon_sym_POUNDIF] = ACTIONS(6858),
    [anon_sym_POUNDIf] = ACTIONS(6858),
    [anon_sym_POUNDelif] = ACTIONS(6858),
    [anon_sym_POUNDELIF] = ACTIONS(6858),
    [anon_sym_POUNDElif] = ACTIONS(6858),
    [anon_sym_POUNDelse] = ACTIONS(6858),
    [anon_sym_POUNDELSE] = ACTIONS(6858),
    [anon_sym_POUNDElse] = ACTIONS(6858),
    [anon_sym_POUNDelse2] = ACTIONS(6858),
    [anon_sym_POUNDELSE2] = ACTIONS(6858),
    [anon_sym_POUNDElse2] = ACTIONS(6858),
    [anon_sym_POUNDendif] = ACTIONS(6858),
    [anon_sym_POUNDENDIF] = ACTIONS(6858),
    [anon_sym_POUNDEndif] = ACTIONS(6858),
    [anon_sym_POUNDendif2] = ACTIONS(6858),
    [anon_sym_POUNDENDIF2] = ACTIONS(6858),
    [anon_sym_POUNDEndif2] = ACTIONS(6858),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6860),
    [anon_sym_tableextension] = ACTIONS(6858),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6858),
    [anon_sym_Tableextension] = ACTIONS(6858),
    [anon_sym_TableExtension] = ACTIONS(6858),
    [anon_sym_tableExtension] = ACTIONS(6858),
    [sym_page_keyword] = ACTIONS(6860),
    [anon_sym_pageextension] = ACTIONS(6858),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6858),
    [anon_sym_Pageextension] = ACTIONS(6858),
    [anon_sym_PageExtension] = ACTIONS(6858),
    [anon_sym_pageExtension] = ACTIONS(6858),
    [anon_sym_codeunit] = ACTIONS(6858),
    [anon_sym_CODEUNIT] = ACTIONS(6858),
    [anon_sym_Codeunit] = ACTIONS(6858),
    [anon_sym_CodeUnit] = ACTIONS(6858),
    [anon_sym_COdeunit] = ACTIONS(6858),
    [anon_sym_codeUnit] = ACTIONS(6858),
    [sym_report_keyword] = ACTIONS(6860),
    [anon_sym_reportextension] = ACTIONS(6858),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6858),
    [anon_sym_Reportextension] = ACTIONS(6858),
    [anon_sym_ReportExtension] = ACTIONS(6858),
    [anon_sym_reportExtension] = ACTIONS(6858),
    [sym_query_keyword] = ACTIONS(6858),
    [anon_sym_xmlport] = ACTIONS(6858),
    [anon_sym_XMLPORT] = ACTIONS(6858),
    [anon_sym_Xmlport] = ACTIONS(6858),
    [anon_sym_XMLport] = ACTIONS(6858),
    [anon_sym_XMLPort] = ACTIONS(6858),
    [anon_sym_XmlPort] = ACTIONS(6858),
    [anon_sym_enum] = ACTIONS(6860),
    [anon_sym_ENUM] = ACTIONS(6860),
    [anon_sym_Enum] = ACTIONS(6860),
    [anon_sym_eNUM] = ACTIONS(6858),
    [anon_sym_eNum] = ACTIONS(6858),
    [anon_sym_ENum] = ACTIONS(6858),
    [anon_sym_enumextension] = ACTIONS(6858),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6858),
    [anon_sym_Enumextension] = ACTIONS(6858),
    [anon_sym_EnumExtension] = ACTIONS(6858),
    [anon_sym_enumExtension] = ACTIONS(6858),
    [sym_interface_keyword] = ACTIONS(6858),
    [anon_sym_controladdin] = ACTIONS(6858),
    [anon_sym_CONTROLADDIN] = ACTIONS(6858),
    [anon_sym_Controladdin] = ACTIONS(6858),
    [anon_sym_ControlAddIn] = ACTIONS(6858),
    [anon_sym_ControlAddin] = ACTIONS(6858),
    [anon_sym_controlAddIn] = ACTIONS(6858),
    [anon_sym_controlAddin] = ACTIONS(6858),
    [anon_sym_dotnet] = ACTIONS(6858),
    [anon_sym_DOTNET] = ACTIONS(6858),
    [anon_sym_Dotnet] = ACTIONS(6858),
    [anon_sym_DotNet] = ACTIONS(6858),
    [anon_sym_dotNet] = ACTIONS(6858),
    [sym_profile_keyword] = ACTIONS(6860),
    [anon_sym_profileextension] = ACTIONS(6858),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6858),
    [anon_sym_Profileextension] = ACTIONS(6858),
    [anon_sym_ProfileExtension] = ACTIONS(6858),
    [anon_sym_profileExtension] = ACTIONS(6858),
    [anon_sym_permissionset] = ACTIONS(6860),
    [anon_sym_PERMISSIONSET] = ACTIONS(6860),
    [anon_sym_Permissionset] = ACTIONS(6860),
    [anon_sym_PermissionSet] = ACTIONS(6860),
    [anon_sym_permissionSet] = ACTIONS(6860),
    [anon_sym_permissionsetextension] = ACTIONS(6858),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6858),
    [anon_sym_Permissionsetextension] = ACTIONS(6858),
    [anon_sym_PermissionSetExtension] = ACTIONS(6858),
    [anon_sym_permissionSetExtension] = ACTIONS(6858),
    [sym_entitlement_keyword] = ACTIONS(6858),
    [anon_sym_pagecustomization] = ACTIONS(6858),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6858),
    [anon_sym_Pagecustomization] = ACTIONS(6858),
    [anon_sym_PageCustomization] = ACTIONS(6858),
    [anon_sym_pageCustomization] = ACTIONS(6858),
    [sym_using_keyword] = ACTIONS(6858),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6858),
    [sym_preproc_close] = ACTIONS(6858),
  },
  [STATE(2768)] = {
    [anon_sym_POUNDif] = ACTIONS(6862),
    [anon_sym_POUNDIF] = ACTIONS(6862),
    [anon_sym_POUNDIf] = ACTIONS(6862),
    [anon_sym_POUNDelif] = ACTIONS(6862),
    [anon_sym_POUNDELIF] = ACTIONS(6862),
    [anon_sym_POUNDElif] = ACTIONS(6862),
    [anon_sym_POUNDelse] = ACTIONS(6862),
    [anon_sym_POUNDELSE] = ACTIONS(6862),
    [anon_sym_POUNDElse] = ACTIONS(6862),
    [anon_sym_POUNDelse2] = ACTIONS(6862),
    [anon_sym_POUNDELSE2] = ACTIONS(6862),
    [anon_sym_POUNDElse2] = ACTIONS(6862),
    [anon_sym_POUNDendif] = ACTIONS(6862),
    [anon_sym_POUNDENDIF] = ACTIONS(6862),
    [anon_sym_POUNDEndif] = ACTIONS(6862),
    [anon_sym_POUNDendif2] = ACTIONS(6862),
    [anon_sym_POUNDENDIF2] = ACTIONS(6862),
    [anon_sym_POUNDEndif2] = ACTIONS(6862),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6864),
    [anon_sym_tableextension] = ACTIONS(6862),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6862),
    [anon_sym_Tableextension] = ACTIONS(6862),
    [anon_sym_TableExtension] = ACTIONS(6862),
    [anon_sym_tableExtension] = ACTIONS(6862),
    [sym_page_keyword] = ACTIONS(6864),
    [anon_sym_pageextension] = ACTIONS(6862),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6862),
    [anon_sym_Pageextension] = ACTIONS(6862),
    [anon_sym_PageExtension] = ACTIONS(6862),
    [anon_sym_pageExtension] = ACTIONS(6862),
    [anon_sym_codeunit] = ACTIONS(6862),
    [anon_sym_CODEUNIT] = ACTIONS(6862),
    [anon_sym_Codeunit] = ACTIONS(6862),
    [anon_sym_CodeUnit] = ACTIONS(6862),
    [anon_sym_COdeunit] = ACTIONS(6862),
    [anon_sym_codeUnit] = ACTIONS(6862),
    [sym_report_keyword] = ACTIONS(6864),
    [anon_sym_reportextension] = ACTIONS(6862),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6862),
    [anon_sym_Reportextension] = ACTIONS(6862),
    [anon_sym_ReportExtension] = ACTIONS(6862),
    [anon_sym_reportExtension] = ACTIONS(6862),
    [sym_query_keyword] = ACTIONS(6862),
    [anon_sym_xmlport] = ACTIONS(6862),
    [anon_sym_XMLPORT] = ACTIONS(6862),
    [anon_sym_Xmlport] = ACTIONS(6862),
    [anon_sym_XMLport] = ACTIONS(6862),
    [anon_sym_XMLPort] = ACTIONS(6862),
    [anon_sym_XmlPort] = ACTIONS(6862),
    [anon_sym_enum] = ACTIONS(6864),
    [anon_sym_ENUM] = ACTIONS(6864),
    [anon_sym_Enum] = ACTIONS(6864),
    [anon_sym_eNUM] = ACTIONS(6862),
    [anon_sym_eNum] = ACTIONS(6862),
    [anon_sym_ENum] = ACTIONS(6862),
    [anon_sym_enumextension] = ACTIONS(6862),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6862),
    [anon_sym_Enumextension] = ACTIONS(6862),
    [anon_sym_EnumExtension] = ACTIONS(6862),
    [anon_sym_enumExtension] = ACTIONS(6862),
    [sym_interface_keyword] = ACTIONS(6862),
    [anon_sym_controladdin] = ACTIONS(6862),
    [anon_sym_CONTROLADDIN] = ACTIONS(6862),
    [anon_sym_Controladdin] = ACTIONS(6862),
    [anon_sym_ControlAddIn] = ACTIONS(6862),
    [anon_sym_ControlAddin] = ACTIONS(6862),
    [anon_sym_controlAddIn] = ACTIONS(6862),
    [anon_sym_controlAddin] = ACTIONS(6862),
    [anon_sym_dotnet] = ACTIONS(6862),
    [anon_sym_DOTNET] = ACTIONS(6862),
    [anon_sym_Dotnet] = ACTIONS(6862),
    [anon_sym_DotNet] = ACTIONS(6862),
    [anon_sym_dotNet] = ACTIONS(6862),
    [sym_profile_keyword] = ACTIONS(6864),
    [anon_sym_profileextension] = ACTIONS(6862),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6862),
    [anon_sym_Profileextension] = ACTIONS(6862),
    [anon_sym_ProfileExtension] = ACTIONS(6862),
    [anon_sym_profileExtension] = ACTIONS(6862),
    [anon_sym_permissionset] = ACTIONS(6864),
    [anon_sym_PERMISSIONSET] = ACTIONS(6864),
    [anon_sym_Permissionset] = ACTIONS(6864),
    [anon_sym_PermissionSet] = ACTIONS(6864),
    [anon_sym_permissionSet] = ACTIONS(6864),
    [anon_sym_permissionsetextension] = ACTIONS(6862),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6862),
    [anon_sym_Permissionsetextension] = ACTIONS(6862),
    [anon_sym_PermissionSetExtension] = ACTIONS(6862),
    [anon_sym_permissionSetExtension] = ACTIONS(6862),
    [sym_entitlement_keyword] = ACTIONS(6862),
    [anon_sym_pagecustomization] = ACTIONS(6862),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6862),
    [anon_sym_Pagecustomization] = ACTIONS(6862),
    [anon_sym_PageCustomization] = ACTIONS(6862),
    [anon_sym_pageCustomization] = ACTIONS(6862),
    [sym_using_keyword] = ACTIONS(6862),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6862),
    [sym_preproc_close] = ACTIONS(6862),
  },
  [STATE(2769)] = {
    [anon_sym_POUNDif] = ACTIONS(6866),
    [anon_sym_POUNDIF] = ACTIONS(6866),
    [anon_sym_POUNDIf] = ACTIONS(6866),
    [anon_sym_POUNDelif] = ACTIONS(6866),
    [anon_sym_POUNDELIF] = ACTIONS(6866),
    [anon_sym_POUNDElif] = ACTIONS(6866),
    [anon_sym_POUNDelse] = ACTIONS(6866),
    [anon_sym_POUNDELSE] = ACTIONS(6866),
    [anon_sym_POUNDElse] = ACTIONS(6866),
    [anon_sym_POUNDelse2] = ACTIONS(6866),
    [anon_sym_POUNDELSE2] = ACTIONS(6866),
    [anon_sym_POUNDElse2] = ACTIONS(6866),
    [anon_sym_POUNDendif] = ACTIONS(6866),
    [anon_sym_POUNDENDIF] = ACTIONS(6866),
    [anon_sym_POUNDEndif] = ACTIONS(6866),
    [anon_sym_POUNDendif2] = ACTIONS(6866),
    [anon_sym_POUNDENDIF2] = ACTIONS(6866),
    [anon_sym_POUNDEndif2] = ACTIONS(6866),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6868),
    [anon_sym_tableextension] = ACTIONS(6866),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6866),
    [anon_sym_Tableextension] = ACTIONS(6866),
    [anon_sym_TableExtension] = ACTIONS(6866),
    [anon_sym_tableExtension] = ACTIONS(6866),
    [sym_page_keyword] = ACTIONS(6868),
    [anon_sym_pageextension] = ACTIONS(6866),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6866),
    [anon_sym_Pageextension] = ACTIONS(6866),
    [anon_sym_PageExtension] = ACTIONS(6866),
    [anon_sym_pageExtension] = ACTIONS(6866),
    [anon_sym_codeunit] = ACTIONS(6866),
    [anon_sym_CODEUNIT] = ACTIONS(6866),
    [anon_sym_Codeunit] = ACTIONS(6866),
    [anon_sym_CodeUnit] = ACTIONS(6866),
    [anon_sym_COdeunit] = ACTIONS(6866),
    [anon_sym_codeUnit] = ACTIONS(6866),
    [sym_report_keyword] = ACTIONS(6868),
    [anon_sym_reportextension] = ACTIONS(6866),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6866),
    [anon_sym_Reportextension] = ACTIONS(6866),
    [anon_sym_ReportExtension] = ACTIONS(6866),
    [anon_sym_reportExtension] = ACTIONS(6866),
    [sym_query_keyword] = ACTIONS(6866),
    [anon_sym_xmlport] = ACTIONS(6866),
    [anon_sym_XMLPORT] = ACTIONS(6866),
    [anon_sym_Xmlport] = ACTIONS(6866),
    [anon_sym_XMLport] = ACTIONS(6866),
    [anon_sym_XMLPort] = ACTIONS(6866),
    [anon_sym_XmlPort] = ACTIONS(6866),
    [anon_sym_enum] = ACTIONS(6868),
    [anon_sym_ENUM] = ACTIONS(6868),
    [anon_sym_Enum] = ACTIONS(6868),
    [anon_sym_eNUM] = ACTIONS(6866),
    [anon_sym_eNum] = ACTIONS(6866),
    [anon_sym_ENum] = ACTIONS(6866),
    [anon_sym_enumextension] = ACTIONS(6866),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6866),
    [anon_sym_Enumextension] = ACTIONS(6866),
    [anon_sym_EnumExtension] = ACTIONS(6866),
    [anon_sym_enumExtension] = ACTIONS(6866),
    [sym_interface_keyword] = ACTIONS(6866),
    [anon_sym_controladdin] = ACTIONS(6866),
    [anon_sym_CONTROLADDIN] = ACTIONS(6866),
    [anon_sym_Controladdin] = ACTIONS(6866),
    [anon_sym_ControlAddIn] = ACTIONS(6866),
    [anon_sym_ControlAddin] = ACTIONS(6866),
    [anon_sym_controlAddIn] = ACTIONS(6866),
    [anon_sym_controlAddin] = ACTIONS(6866),
    [anon_sym_dotnet] = ACTIONS(6866),
    [anon_sym_DOTNET] = ACTIONS(6866),
    [anon_sym_Dotnet] = ACTIONS(6866),
    [anon_sym_DotNet] = ACTIONS(6866),
    [anon_sym_dotNet] = ACTIONS(6866),
    [sym_profile_keyword] = ACTIONS(6868),
    [anon_sym_profileextension] = ACTIONS(6866),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6866),
    [anon_sym_Profileextension] = ACTIONS(6866),
    [anon_sym_ProfileExtension] = ACTIONS(6866),
    [anon_sym_profileExtension] = ACTIONS(6866),
    [anon_sym_permissionset] = ACTIONS(6868),
    [anon_sym_PERMISSIONSET] = ACTIONS(6868),
    [anon_sym_Permissionset] = ACTIONS(6868),
    [anon_sym_PermissionSet] = ACTIONS(6868),
    [anon_sym_permissionSet] = ACTIONS(6868),
    [anon_sym_permissionsetextension] = ACTIONS(6866),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6866),
    [anon_sym_Permissionsetextension] = ACTIONS(6866),
    [anon_sym_PermissionSetExtension] = ACTIONS(6866),
    [anon_sym_permissionSetExtension] = ACTIONS(6866),
    [sym_entitlement_keyword] = ACTIONS(6866),
    [anon_sym_pagecustomization] = ACTIONS(6866),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6866),
    [anon_sym_Pagecustomization] = ACTIONS(6866),
    [anon_sym_PageCustomization] = ACTIONS(6866),
    [anon_sym_pageCustomization] = ACTIONS(6866),
    [sym_using_keyword] = ACTIONS(6866),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6866),
    [sym_preproc_close] = ACTIONS(6866),
  },
  [STATE(2770)] = {
    [sym_identifier] = ACTIONS(5445),
    [anon_sym_SEMI] = ACTIONS(5447),
    [anon_sym_DASH] = ACTIONS(5447),
    [aux_sym_boolean_token1] = ACTIONS(5445),
    [aux_sym_boolean_token2] = ACTIONS(5445),
    [sym_decimal] = ACTIONS(5445),
    [anon_sym_LPAREN] = ACTIONS(5445),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5445),
    [anon_sym_LBRACK] = ACTIONS(5447),
    [aux_sym_record_type_token1] = ACTIONS(5445),
    [aux_sym_basic_type_token21] = ACTIONS(5445),
    [aux_sym_basic_type_token22] = ACTIONS(5445),
    [aux_sym_basic_type_token48] = ACTIONS(5445),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5445),
    [anon_sym_POUNDif] = ACTIONS(5447),
    [anon_sym_POUNDIF] = ACTIONS(5447),
    [anon_sym_POUNDIf] = ACTIONS(5447),
    [anon_sym_not] = ACTIONS(5445),
    [anon_sym_NOT] = ACTIONS(5445),
    [anon_sym_Not] = ACTIONS(5445),
    [anon_sym_POUNDelse] = ACTIONS(5447),
    [anon_sym_POUNDELSE] = ACTIONS(5447),
    [anon_sym_POUNDElse] = ACTIONS(5447),
    [anon_sym_POUNDelse2] = ACTIONS(5447),
    [anon_sym_POUNDELSE2] = ACTIONS(5447),
    [anon_sym_POUNDElse2] = ACTIONS(5447),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(5447),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5445),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5445),
    [anon_sym_PLUS] = ACTIONS(5447),
    [sym_datetime_literal] = ACTIONS(5447),
    [sym_date_literal] = ACTIONS(5445),
    [sym_time_literal] = ACTIONS(5445),
    [sym_biginteger_literal] = ACTIONS(5447),
    [anon_sym_if] = ACTIONS(5445),
    [anon_sym_IF] = ACTIONS(5445),
    [anon_sym_If] = ACTIONS(5445),
    [anon_sym_else] = ACTIONS(5445),
    [anon_sym_ELSE] = ACTIONS(5445),
    [anon_sym_Else] = ACTIONS(5445),
    [anon_sym_case] = ACTIONS(5445),
    [anon_sym_CASE] = ACTIONS(5445),
    [anon_sym_Case] = ACTIONS(5445),
    [anon_sym_for] = ACTIONS(5445),
    [anon_sym_FOR] = ACTIONS(5445),
    [anon_sym_For] = ACTIONS(5445),
    [anon_sym_foreach] = ACTIONS(5445),
    [anon_sym_FOREACH] = ACTIONS(5445),
    [anon_sym_Foreach] = ACTIONS(5445),
    [anon_sym_while] = ACTIONS(5445),
    [anon_sym_WHILE] = ACTIONS(5445),
    [anon_sym_While] = ACTIONS(5445),
    [anon_sym_repeat] = ACTIONS(5445),
    [anon_sym_REPEAT] = ACTIONS(5445),
    [anon_sym_Repeat] = ACTIONS(5445),
    [anon_sym_until] = ACTIONS(5445),
    [anon_sym_UNTIL] = ACTIONS(5445),
    [anon_sym_Until] = ACTIONS(5445),
    [anon_sym_exit] = ACTIONS(5445),
    [anon_sym_EXIT] = ACTIONS(5445),
    [anon_sym_Exit] = ACTIONS(5445),
    [anon_sym_continue] = ACTIONS(5445),
    [anon_sym_CONTINUE] = ACTIONS(5445),
    [anon_sym_Continue] = ACTIONS(5445),
    [anon_sym_break] = ACTIONS(5445),
    [anon_sym_BREAK] = ACTIONS(5445),
    [anon_sym_Break] = ACTIONS(5445),
    [anon_sym_with] = ACTIONS(5445),
    [anon_sym_WITH] = ACTIONS(5445),
    [anon_sym_With] = ACTIONS(5445),
    [sym_asserterror_keyword] = ACTIONS(5447),
    [sym_page_keyword] = ACTIONS(5445),
    [anon_sym_codeunit] = ACTIONS(5445),
    [anon_sym_CODEUNIT] = ACTIONS(5445),
    [anon_sym_Codeunit] = ACTIONS(5445),
    [anon_sym_CodeUnit] = ACTIONS(5445),
    [anon_sym_COdeunit] = ACTIONS(5445),
    [anon_sym_codeUnit] = ACTIONS(5445),
    [sym_report_keyword] = ACTIONS(5445),
    [sym_query_keyword] = ACTIONS(5445),
    [anon_sym_xmlport] = ACTIONS(5445),
    [anon_sym_XMLPORT] = ACTIONS(5445),
    [anon_sym_Xmlport] = ACTIONS(5445),
    [anon_sym_XMLport] = ACTIONS(5445),
    [anon_sym_XMLPort] = ACTIONS(5445),
    [anon_sym_XmlPort] = ACTIONS(5445),
    [anon_sym_enum] = ACTIONS(5445),
    [anon_sym_ENUM] = ACTIONS(5445),
    [anon_sym_Enum] = ACTIONS(5445),
    [anon_sym_eNUM] = ACTIONS(5445),
    [anon_sym_eNum] = ACTIONS(5445),
    [anon_sym_ENum] = ACTIONS(5445),
    [sym_quoted_identifier] = ACTIONS(5447),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5447),
    [sym_verbatim_string] = ACTIONS(5447),
    [sym_integer] = ACTIONS(5445),
    [sym_continue_as_identifier] = ACTIONS(5447),
    [sym_preproc_open] = ACTIONS(5447),
  },
  [STATE(2771)] = {
    [sym_identifier] = ACTIONS(5461),
    [anon_sym_SEMI] = ACTIONS(5463),
    [anon_sym_DASH] = ACTIONS(5463),
    [aux_sym_boolean_token1] = ACTIONS(5461),
    [aux_sym_boolean_token2] = ACTIONS(5461),
    [sym_decimal] = ACTIONS(5461),
    [anon_sym_LPAREN] = ACTIONS(5461),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5461),
    [anon_sym_LBRACK] = ACTIONS(5463),
    [aux_sym_record_type_token1] = ACTIONS(5461),
    [aux_sym_basic_type_token21] = ACTIONS(5461),
    [aux_sym_basic_type_token22] = ACTIONS(5461),
    [aux_sym_basic_type_token48] = ACTIONS(5461),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5461),
    [anon_sym_POUNDif] = ACTIONS(5463),
    [anon_sym_POUNDIF] = ACTIONS(5463),
    [anon_sym_POUNDIf] = ACTIONS(5463),
    [anon_sym_not] = ACTIONS(5461),
    [anon_sym_NOT] = ACTIONS(5461),
    [anon_sym_Not] = ACTIONS(5461),
    [anon_sym_POUNDelse] = ACTIONS(5463),
    [anon_sym_POUNDELSE] = ACTIONS(5463),
    [anon_sym_POUNDElse] = ACTIONS(5463),
    [anon_sym_POUNDelse2] = ACTIONS(5463),
    [anon_sym_POUNDELSE2] = ACTIONS(5463),
    [anon_sym_POUNDElse2] = ACTIONS(5463),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(6870),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5461),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5461),
    [anon_sym_PLUS] = ACTIONS(5463),
    [sym_datetime_literal] = ACTIONS(5463),
    [sym_date_literal] = ACTIONS(5461),
    [sym_time_literal] = ACTIONS(5461),
    [sym_biginteger_literal] = ACTIONS(5463),
    [anon_sym_if] = ACTIONS(5461),
    [anon_sym_IF] = ACTIONS(5461),
    [anon_sym_If] = ACTIONS(5461),
    [anon_sym_else] = ACTIONS(5461),
    [anon_sym_ELSE] = ACTIONS(5461),
    [anon_sym_Else] = ACTIONS(5461),
    [anon_sym_case] = ACTIONS(5461),
    [anon_sym_CASE] = ACTIONS(5461),
    [anon_sym_Case] = ACTIONS(5461),
    [anon_sym_for] = ACTIONS(5461),
    [anon_sym_FOR] = ACTIONS(5461),
    [anon_sym_For] = ACTIONS(5461),
    [anon_sym_foreach] = ACTIONS(5461),
    [anon_sym_FOREACH] = ACTIONS(5461),
    [anon_sym_Foreach] = ACTIONS(5461),
    [anon_sym_while] = ACTIONS(5461),
    [anon_sym_WHILE] = ACTIONS(5461),
    [anon_sym_While] = ACTIONS(5461),
    [anon_sym_repeat] = ACTIONS(5461),
    [anon_sym_REPEAT] = ACTIONS(5461),
    [anon_sym_Repeat] = ACTIONS(5461),
    [anon_sym_until] = ACTIONS(5461),
    [anon_sym_UNTIL] = ACTIONS(5461),
    [anon_sym_Until] = ACTIONS(5461),
    [anon_sym_exit] = ACTIONS(5461),
    [anon_sym_EXIT] = ACTIONS(5461),
    [anon_sym_Exit] = ACTIONS(5461),
    [anon_sym_continue] = ACTIONS(5461),
    [anon_sym_CONTINUE] = ACTIONS(5461),
    [anon_sym_Continue] = ACTIONS(5461),
    [anon_sym_break] = ACTIONS(5461),
    [anon_sym_BREAK] = ACTIONS(5461),
    [anon_sym_Break] = ACTIONS(5461),
    [anon_sym_with] = ACTIONS(5461),
    [anon_sym_WITH] = ACTIONS(5461),
    [anon_sym_With] = ACTIONS(5461),
    [sym_asserterror_keyword] = ACTIONS(5463),
    [sym_page_keyword] = ACTIONS(5461),
    [anon_sym_codeunit] = ACTIONS(5461),
    [anon_sym_CODEUNIT] = ACTIONS(5461),
    [anon_sym_Codeunit] = ACTIONS(5461),
    [anon_sym_CodeUnit] = ACTIONS(5461),
    [anon_sym_COdeunit] = ACTIONS(5461),
    [anon_sym_codeUnit] = ACTIONS(5461),
    [sym_report_keyword] = ACTIONS(5461),
    [sym_query_keyword] = ACTIONS(5461),
    [anon_sym_xmlport] = ACTIONS(5461),
    [anon_sym_XMLPORT] = ACTIONS(5461),
    [anon_sym_Xmlport] = ACTIONS(5461),
    [anon_sym_XMLport] = ACTIONS(5461),
    [anon_sym_XMLPort] = ACTIONS(5461),
    [anon_sym_XmlPort] = ACTIONS(5461),
    [anon_sym_enum] = ACTIONS(5461),
    [anon_sym_ENUM] = ACTIONS(5461),
    [anon_sym_Enum] = ACTIONS(5461),
    [anon_sym_eNUM] = ACTIONS(5461),
    [anon_sym_eNum] = ACTIONS(5461),
    [anon_sym_ENum] = ACTIONS(5461),
    [sym_quoted_identifier] = ACTIONS(5463),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5463),
    [sym_verbatim_string] = ACTIONS(5463),
    [sym_integer] = ACTIONS(5461),
    [sym_continue_as_identifier] = ACTIONS(5463),
    [sym_preproc_open] = ACTIONS(5463),
  },
  [STATE(2772)] = {
    [anon_sym_POUNDif] = ACTIONS(6872),
    [anon_sym_POUNDIF] = ACTIONS(6872),
    [anon_sym_POUNDIf] = ACTIONS(6872),
    [anon_sym_POUNDelif] = ACTIONS(6872),
    [anon_sym_POUNDELIF] = ACTIONS(6872),
    [anon_sym_POUNDElif] = ACTIONS(6872),
    [anon_sym_POUNDelse] = ACTIONS(6872),
    [anon_sym_POUNDELSE] = ACTIONS(6872),
    [anon_sym_POUNDElse] = ACTIONS(6872),
    [anon_sym_POUNDelse2] = ACTIONS(6872),
    [anon_sym_POUNDELSE2] = ACTIONS(6872),
    [anon_sym_POUNDElse2] = ACTIONS(6872),
    [anon_sym_POUNDendif] = ACTIONS(6872),
    [anon_sym_POUNDENDIF] = ACTIONS(6872),
    [anon_sym_POUNDEndif] = ACTIONS(6872),
    [anon_sym_POUNDendif2] = ACTIONS(6872),
    [anon_sym_POUNDENDIF2] = ACTIONS(6872),
    [anon_sym_POUNDEndif2] = ACTIONS(6872),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6874),
    [anon_sym_tableextension] = ACTIONS(6872),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6872),
    [anon_sym_Tableextension] = ACTIONS(6872),
    [anon_sym_TableExtension] = ACTIONS(6872),
    [anon_sym_tableExtension] = ACTIONS(6872),
    [sym_page_keyword] = ACTIONS(6874),
    [anon_sym_pageextension] = ACTIONS(6872),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6872),
    [anon_sym_Pageextension] = ACTIONS(6872),
    [anon_sym_PageExtension] = ACTIONS(6872),
    [anon_sym_pageExtension] = ACTIONS(6872),
    [anon_sym_codeunit] = ACTIONS(6872),
    [anon_sym_CODEUNIT] = ACTIONS(6872),
    [anon_sym_Codeunit] = ACTIONS(6872),
    [anon_sym_CodeUnit] = ACTIONS(6872),
    [anon_sym_COdeunit] = ACTIONS(6872),
    [anon_sym_codeUnit] = ACTIONS(6872),
    [sym_report_keyword] = ACTIONS(6874),
    [anon_sym_reportextension] = ACTIONS(6872),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6872),
    [anon_sym_Reportextension] = ACTIONS(6872),
    [anon_sym_ReportExtension] = ACTIONS(6872),
    [anon_sym_reportExtension] = ACTIONS(6872),
    [sym_query_keyword] = ACTIONS(6872),
    [anon_sym_xmlport] = ACTIONS(6872),
    [anon_sym_XMLPORT] = ACTIONS(6872),
    [anon_sym_Xmlport] = ACTIONS(6872),
    [anon_sym_XMLport] = ACTIONS(6872),
    [anon_sym_XMLPort] = ACTIONS(6872),
    [anon_sym_XmlPort] = ACTIONS(6872),
    [anon_sym_enum] = ACTIONS(6874),
    [anon_sym_ENUM] = ACTIONS(6874),
    [anon_sym_Enum] = ACTIONS(6874),
    [anon_sym_eNUM] = ACTIONS(6872),
    [anon_sym_eNum] = ACTIONS(6872),
    [anon_sym_ENum] = ACTIONS(6872),
    [anon_sym_enumextension] = ACTIONS(6872),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6872),
    [anon_sym_Enumextension] = ACTIONS(6872),
    [anon_sym_EnumExtension] = ACTIONS(6872),
    [anon_sym_enumExtension] = ACTIONS(6872),
    [sym_interface_keyword] = ACTIONS(6872),
    [anon_sym_controladdin] = ACTIONS(6872),
    [anon_sym_CONTROLADDIN] = ACTIONS(6872),
    [anon_sym_Controladdin] = ACTIONS(6872),
    [anon_sym_ControlAddIn] = ACTIONS(6872),
    [anon_sym_ControlAddin] = ACTIONS(6872),
    [anon_sym_controlAddIn] = ACTIONS(6872),
    [anon_sym_controlAddin] = ACTIONS(6872),
    [anon_sym_dotnet] = ACTIONS(6872),
    [anon_sym_DOTNET] = ACTIONS(6872),
    [anon_sym_Dotnet] = ACTIONS(6872),
    [anon_sym_DotNet] = ACTIONS(6872),
    [anon_sym_dotNet] = ACTIONS(6872),
    [sym_profile_keyword] = ACTIONS(6874),
    [anon_sym_profileextension] = ACTIONS(6872),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6872),
    [anon_sym_Profileextension] = ACTIONS(6872),
    [anon_sym_ProfileExtension] = ACTIONS(6872),
    [anon_sym_profileExtension] = ACTIONS(6872),
    [anon_sym_permissionset] = ACTIONS(6874),
    [anon_sym_PERMISSIONSET] = ACTIONS(6874),
    [anon_sym_Permissionset] = ACTIONS(6874),
    [anon_sym_PermissionSet] = ACTIONS(6874),
    [anon_sym_permissionSet] = ACTIONS(6874),
    [anon_sym_permissionsetextension] = ACTIONS(6872),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6872),
    [anon_sym_Permissionsetextension] = ACTIONS(6872),
    [anon_sym_PermissionSetExtension] = ACTIONS(6872),
    [anon_sym_permissionSetExtension] = ACTIONS(6872),
    [sym_entitlement_keyword] = ACTIONS(6872),
    [anon_sym_pagecustomization] = ACTIONS(6872),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6872),
    [anon_sym_Pagecustomization] = ACTIONS(6872),
    [anon_sym_PageCustomization] = ACTIONS(6872),
    [anon_sym_pageCustomization] = ACTIONS(6872),
    [sym_using_keyword] = ACTIONS(6872),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6872),
    [sym_preproc_close] = ACTIONS(6872),
  },
  [STATE(2773)] = {
    [anon_sym_POUNDif] = ACTIONS(6876),
    [anon_sym_POUNDIF] = ACTIONS(6876),
    [anon_sym_POUNDIf] = ACTIONS(6876),
    [anon_sym_POUNDelif] = ACTIONS(6876),
    [anon_sym_POUNDELIF] = ACTIONS(6876),
    [anon_sym_POUNDElif] = ACTIONS(6876),
    [anon_sym_POUNDelse] = ACTIONS(6876),
    [anon_sym_POUNDELSE] = ACTIONS(6876),
    [anon_sym_POUNDElse] = ACTIONS(6876),
    [anon_sym_POUNDelse2] = ACTIONS(6876),
    [anon_sym_POUNDELSE2] = ACTIONS(6876),
    [anon_sym_POUNDElse2] = ACTIONS(6876),
    [anon_sym_POUNDendif] = ACTIONS(6876),
    [anon_sym_POUNDENDIF] = ACTIONS(6876),
    [anon_sym_POUNDEndif] = ACTIONS(6876),
    [anon_sym_POUNDendif2] = ACTIONS(6876),
    [anon_sym_POUNDENDIF2] = ACTIONS(6876),
    [anon_sym_POUNDEndif2] = ACTIONS(6876),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6878),
    [anon_sym_tableextension] = ACTIONS(6876),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6876),
    [anon_sym_Tableextension] = ACTIONS(6876),
    [anon_sym_TableExtension] = ACTIONS(6876),
    [anon_sym_tableExtension] = ACTIONS(6876),
    [sym_page_keyword] = ACTIONS(6878),
    [anon_sym_pageextension] = ACTIONS(6876),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6876),
    [anon_sym_Pageextension] = ACTIONS(6876),
    [anon_sym_PageExtension] = ACTIONS(6876),
    [anon_sym_pageExtension] = ACTIONS(6876),
    [anon_sym_codeunit] = ACTIONS(6876),
    [anon_sym_CODEUNIT] = ACTIONS(6876),
    [anon_sym_Codeunit] = ACTIONS(6876),
    [anon_sym_CodeUnit] = ACTIONS(6876),
    [anon_sym_COdeunit] = ACTIONS(6876),
    [anon_sym_codeUnit] = ACTIONS(6876),
    [sym_report_keyword] = ACTIONS(6878),
    [anon_sym_reportextension] = ACTIONS(6876),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6876),
    [anon_sym_Reportextension] = ACTIONS(6876),
    [anon_sym_ReportExtension] = ACTIONS(6876),
    [anon_sym_reportExtension] = ACTIONS(6876),
    [sym_query_keyword] = ACTIONS(6876),
    [anon_sym_xmlport] = ACTIONS(6876),
    [anon_sym_XMLPORT] = ACTIONS(6876),
    [anon_sym_Xmlport] = ACTIONS(6876),
    [anon_sym_XMLport] = ACTIONS(6876),
    [anon_sym_XMLPort] = ACTIONS(6876),
    [anon_sym_XmlPort] = ACTIONS(6876),
    [anon_sym_enum] = ACTIONS(6878),
    [anon_sym_ENUM] = ACTIONS(6878),
    [anon_sym_Enum] = ACTIONS(6878),
    [anon_sym_eNUM] = ACTIONS(6876),
    [anon_sym_eNum] = ACTIONS(6876),
    [anon_sym_ENum] = ACTIONS(6876),
    [anon_sym_enumextension] = ACTIONS(6876),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6876),
    [anon_sym_Enumextension] = ACTIONS(6876),
    [anon_sym_EnumExtension] = ACTIONS(6876),
    [anon_sym_enumExtension] = ACTIONS(6876),
    [sym_interface_keyword] = ACTIONS(6876),
    [anon_sym_controladdin] = ACTIONS(6876),
    [anon_sym_CONTROLADDIN] = ACTIONS(6876),
    [anon_sym_Controladdin] = ACTIONS(6876),
    [anon_sym_ControlAddIn] = ACTIONS(6876),
    [anon_sym_ControlAddin] = ACTIONS(6876),
    [anon_sym_controlAddIn] = ACTIONS(6876),
    [anon_sym_controlAddin] = ACTIONS(6876),
    [anon_sym_dotnet] = ACTIONS(6876),
    [anon_sym_DOTNET] = ACTIONS(6876),
    [anon_sym_Dotnet] = ACTIONS(6876),
    [anon_sym_DotNet] = ACTIONS(6876),
    [anon_sym_dotNet] = ACTIONS(6876),
    [sym_profile_keyword] = ACTIONS(6878),
    [anon_sym_profileextension] = ACTIONS(6876),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6876),
    [anon_sym_Profileextension] = ACTIONS(6876),
    [anon_sym_ProfileExtension] = ACTIONS(6876),
    [anon_sym_profileExtension] = ACTIONS(6876),
    [anon_sym_permissionset] = ACTIONS(6878),
    [anon_sym_PERMISSIONSET] = ACTIONS(6878),
    [anon_sym_Permissionset] = ACTIONS(6878),
    [anon_sym_PermissionSet] = ACTIONS(6878),
    [anon_sym_permissionSet] = ACTIONS(6878),
    [anon_sym_permissionsetextension] = ACTIONS(6876),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6876),
    [anon_sym_Permissionsetextension] = ACTIONS(6876),
    [anon_sym_PermissionSetExtension] = ACTIONS(6876),
    [anon_sym_permissionSetExtension] = ACTIONS(6876),
    [sym_entitlement_keyword] = ACTIONS(6876),
    [anon_sym_pagecustomization] = ACTIONS(6876),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6876),
    [anon_sym_Pagecustomization] = ACTIONS(6876),
    [anon_sym_PageCustomization] = ACTIONS(6876),
    [anon_sym_pageCustomization] = ACTIONS(6876),
    [sym_using_keyword] = ACTIONS(6876),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6876),
    [sym_preproc_close] = ACTIONS(6876),
  },
  [STATE(2774)] = {
    [anon_sym_POUNDif] = ACTIONS(6880),
    [anon_sym_POUNDIF] = ACTIONS(6880),
    [anon_sym_POUNDIf] = ACTIONS(6880),
    [anon_sym_POUNDelif] = ACTIONS(6880),
    [anon_sym_POUNDELIF] = ACTIONS(6880),
    [anon_sym_POUNDElif] = ACTIONS(6880),
    [anon_sym_POUNDelse] = ACTIONS(6880),
    [anon_sym_POUNDELSE] = ACTIONS(6880),
    [anon_sym_POUNDElse] = ACTIONS(6880),
    [anon_sym_POUNDelse2] = ACTIONS(6880),
    [anon_sym_POUNDELSE2] = ACTIONS(6880),
    [anon_sym_POUNDElse2] = ACTIONS(6880),
    [anon_sym_POUNDendif] = ACTIONS(6880),
    [anon_sym_POUNDENDIF] = ACTIONS(6880),
    [anon_sym_POUNDEndif] = ACTIONS(6880),
    [anon_sym_POUNDendif2] = ACTIONS(6880),
    [anon_sym_POUNDENDIF2] = ACTIONS(6880),
    [anon_sym_POUNDEndif2] = ACTIONS(6880),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6882),
    [anon_sym_tableextension] = ACTIONS(6880),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6880),
    [anon_sym_Tableextension] = ACTIONS(6880),
    [anon_sym_TableExtension] = ACTIONS(6880),
    [anon_sym_tableExtension] = ACTIONS(6880),
    [sym_page_keyword] = ACTIONS(6882),
    [anon_sym_pageextension] = ACTIONS(6880),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6880),
    [anon_sym_Pageextension] = ACTIONS(6880),
    [anon_sym_PageExtension] = ACTIONS(6880),
    [anon_sym_pageExtension] = ACTIONS(6880),
    [anon_sym_codeunit] = ACTIONS(6880),
    [anon_sym_CODEUNIT] = ACTIONS(6880),
    [anon_sym_Codeunit] = ACTIONS(6880),
    [anon_sym_CodeUnit] = ACTIONS(6880),
    [anon_sym_COdeunit] = ACTIONS(6880),
    [anon_sym_codeUnit] = ACTIONS(6880),
    [sym_report_keyword] = ACTIONS(6882),
    [anon_sym_reportextension] = ACTIONS(6880),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6880),
    [anon_sym_Reportextension] = ACTIONS(6880),
    [anon_sym_ReportExtension] = ACTIONS(6880),
    [anon_sym_reportExtension] = ACTIONS(6880),
    [sym_query_keyword] = ACTIONS(6880),
    [anon_sym_xmlport] = ACTIONS(6880),
    [anon_sym_XMLPORT] = ACTIONS(6880),
    [anon_sym_Xmlport] = ACTIONS(6880),
    [anon_sym_XMLport] = ACTIONS(6880),
    [anon_sym_XMLPort] = ACTIONS(6880),
    [anon_sym_XmlPort] = ACTIONS(6880),
    [anon_sym_enum] = ACTIONS(6882),
    [anon_sym_ENUM] = ACTIONS(6882),
    [anon_sym_Enum] = ACTIONS(6882),
    [anon_sym_eNUM] = ACTIONS(6880),
    [anon_sym_eNum] = ACTIONS(6880),
    [anon_sym_ENum] = ACTIONS(6880),
    [anon_sym_enumextension] = ACTIONS(6880),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6880),
    [anon_sym_Enumextension] = ACTIONS(6880),
    [anon_sym_EnumExtension] = ACTIONS(6880),
    [anon_sym_enumExtension] = ACTIONS(6880),
    [sym_interface_keyword] = ACTIONS(6880),
    [anon_sym_controladdin] = ACTIONS(6880),
    [anon_sym_CONTROLADDIN] = ACTIONS(6880),
    [anon_sym_Controladdin] = ACTIONS(6880),
    [anon_sym_ControlAddIn] = ACTIONS(6880),
    [anon_sym_ControlAddin] = ACTIONS(6880),
    [anon_sym_controlAddIn] = ACTIONS(6880),
    [anon_sym_controlAddin] = ACTIONS(6880),
    [anon_sym_dotnet] = ACTIONS(6880),
    [anon_sym_DOTNET] = ACTIONS(6880),
    [anon_sym_Dotnet] = ACTIONS(6880),
    [anon_sym_DotNet] = ACTIONS(6880),
    [anon_sym_dotNet] = ACTIONS(6880),
    [sym_profile_keyword] = ACTIONS(6882),
    [anon_sym_profileextension] = ACTIONS(6880),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6880),
    [anon_sym_Profileextension] = ACTIONS(6880),
    [anon_sym_ProfileExtension] = ACTIONS(6880),
    [anon_sym_profileExtension] = ACTIONS(6880),
    [anon_sym_permissionset] = ACTIONS(6882),
    [anon_sym_PERMISSIONSET] = ACTIONS(6882),
    [anon_sym_Permissionset] = ACTIONS(6882),
    [anon_sym_PermissionSet] = ACTIONS(6882),
    [anon_sym_permissionSet] = ACTIONS(6882),
    [anon_sym_permissionsetextension] = ACTIONS(6880),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6880),
    [anon_sym_Permissionsetextension] = ACTIONS(6880),
    [anon_sym_PermissionSetExtension] = ACTIONS(6880),
    [anon_sym_permissionSetExtension] = ACTIONS(6880),
    [sym_entitlement_keyword] = ACTIONS(6880),
    [anon_sym_pagecustomization] = ACTIONS(6880),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6880),
    [anon_sym_Pagecustomization] = ACTIONS(6880),
    [anon_sym_PageCustomization] = ACTIONS(6880),
    [anon_sym_pageCustomization] = ACTIONS(6880),
    [sym_using_keyword] = ACTIONS(6880),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6880),
    [sym_preproc_close] = ACTIONS(6880),
  },
  [STATE(2775)] = {
    [anon_sym_POUNDif] = ACTIONS(6884),
    [anon_sym_POUNDIF] = ACTIONS(6884),
    [anon_sym_POUNDIf] = ACTIONS(6884),
    [anon_sym_POUNDelif] = ACTIONS(6884),
    [anon_sym_POUNDELIF] = ACTIONS(6884),
    [anon_sym_POUNDElif] = ACTIONS(6884),
    [anon_sym_POUNDelse] = ACTIONS(6884),
    [anon_sym_POUNDELSE] = ACTIONS(6884),
    [anon_sym_POUNDElse] = ACTIONS(6884),
    [anon_sym_POUNDelse2] = ACTIONS(6884),
    [anon_sym_POUNDELSE2] = ACTIONS(6884),
    [anon_sym_POUNDElse2] = ACTIONS(6884),
    [anon_sym_POUNDendif] = ACTIONS(6884),
    [anon_sym_POUNDENDIF] = ACTIONS(6884),
    [anon_sym_POUNDEndif] = ACTIONS(6884),
    [anon_sym_POUNDendif2] = ACTIONS(6884),
    [anon_sym_POUNDENDIF2] = ACTIONS(6884),
    [anon_sym_POUNDEndif2] = ACTIONS(6884),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6886),
    [anon_sym_tableextension] = ACTIONS(6884),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6884),
    [anon_sym_Tableextension] = ACTIONS(6884),
    [anon_sym_TableExtension] = ACTIONS(6884),
    [anon_sym_tableExtension] = ACTIONS(6884),
    [sym_page_keyword] = ACTIONS(6886),
    [anon_sym_pageextension] = ACTIONS(6884),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6884),
    [anon_sym_Pageextension] = ACTIONS(6884),
    [anon_sym_PageExtension] = ACTIONS(6884),
    [anon_sym_pageExtension] = ACTIONS(6884),
    [anon_sym_codeunit] = ACTIONS(6884),
    [anon_sym_CODEUNIT] = ACTIONS(6884),
    [anon_sym_Codeunit] = ACTIONS(6884),
    [anon_sym_CodeUnit] = ACTIONS(6884),
    [anon_sym_COdeunit] = ACTIONS(6884),
    [anon_sym_codeUnit] = ACTIONS(6884),
    [sym_report_keyword] = ACTIONS(6886),
    [anon_sym_reportextension] = ACTIONS(6884),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6884),
    [anon_sym_Reportextension] = ACTIONS(6884),
    [anon_sym_ReportExtension] = ACTIONS(6884),
    [anon_sym_reportExtension] = ACTIONS(6884),
    [sym_query_keyword] = ACTIONS(6884),
    [anon_sym_xmlport] = ACTIONS(6884),
    [anon_sym_XMLPORT] = ACTIONS(6884),
    [anon_sym_Xmlport] = ACTIONS(6884),
    [anon_sym_XMLport] = ACTIONS(6884),
    [anon_sym_XMLPort] = ACTIONS(6884),
    [anon_sym_XmlPort] = ACTIONS(6884),
    [anon_sym_enum] = ACTIONS(6886),
    [anon_sym_ENUM] = ACTIONS(6886),
    [anon_sym_Enum] = ACTIONS(6886),
    [anon_sym_eNUM] = ACTIONS(6884),
    [anon_sym_eNum] = ACTIONS(6884),
    [anon_sym_ENum] = ACTIONS(6884),
    [anon_sym_enumextension] = ACTIONS(6884),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6884),
    [anon_sym_Enumextension] = ACTIONS(6884),
    [anon_sym_EnumExtension] = ACTIONS(6884),
    [anon_sym_enumExtension] = ACTIONS(6884),
    [sym_interface_keyword] = ACTIONS(6884),
    [anon_sym_controladdin] = ACTIONS(6884),
    [anon_sym_CONTROLADDIN] = ACTIONS(6884),
    [anon_sym_Controladdin] = ACTIONS(6884),
    [anon_sym_ControlAddIn] = ACTIONS(6884),
    [anon_sym_ControlAddin] = ACTIONS(6884),
    [anon_sym_controlAddIn] = ACTIONS(6884),
    [anon_sym_controlAddin] = ACTIONS(6884),
    [anon_sym_dotnet] = ACTIONS(6884),
    [anon_sym_DOTNET] = ACTIONS(6884),
    [anon_sym_Dotnet] = ACTIONS(6884),
    [anon_sym_DotNet] = ACTIONS(6884),
    [anon_sym_dotNet] = ACTIONS(6884),
    [sym_profile_keyword] = ACTIONS(6886),
    [anon_sym_profileextension] = ACTIONS(6884),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6884),
    [anon_sym_Profileextension] = ACTIONS(6884),
    [anon_sym_ProfileExtension] = ACTIONS(6884),
    [anon_sym_profileExtension] = ACTIONS(6884),
    [anon_sym_permissionset] = ACTIONS(6886),
    [anon_sym_PERMISSIONSET] = ACTIONS(6886),
    [anon_sym_Permissionset] = ACTIONS(6886),
    [anon_sym_PermissionSet] = ACTIONS(6886),
    [anon_sym_permissionSet] = ACTIONS(6886),
    [anon_sym_permissionsetextension] = ACTIONS(6884),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6884),
    [anon_sym_Permissionsetextension] = ACTIONS(6884),
    [anon_sym_PermissionSetExtension] = ACTIONS(6884),
    [anon_sym_permissionSetExtension] = ACTIONS(6884),
    [sym_entitlement_keyword] = ACTIONS(6884),
    [anon_sym_pagecustomization] = ACTIONS(6884),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6884),
    [anon_sym_Pagecustomization] = ACTIONS(6884),
    [anon_sym_PageCustomization] = ACTIONS(6884),
    [anon_sym_pageCustomization] = ACTIONS(6884),
    [sym_using_keyword] = ACTIONS(6884),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6884),
    [sym_preproc_close] = ACTIONS(6884),
  },
  [STATE(2776)] = {
    [sym_else_keyword] = STATE(671),
    [sym_identifier] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5471),
    [anon_sym_DASH] = ACTIONS(5471),
    [aux_sym_boolean_token1] = ACTIONS(5469),
    [aux_sym_boolean_token2] = ACTIONS(5469),
    [sym_decimal] = ACTIONS(5469),
    [anon_sym_LPAREN] = ACTIONS(5471),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5469),
    [anon_sym_LBRACK] = ACTIONS(5471),
    [aux_sym_record_type_token1] = ACTIONS(5469),
    [aux_sym_basic_type_token21] = ACTIONS(5469),
    [aux_sym_basic_type_token22] = ACTIONS(5469),
    [aux_sym_basic_type_token48] = ACTIONS(5469),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5469),
    [anon_sym_POUNDif] = ACTIONS(5471),
    [anon_sym_POUNDIF] = ACTIONS(5471),
    [anon_sym_POUNDIf] = ACTIONS(5471),
    [anon_sym_not] = ACTIONS(5469),
    [anon_sym_NOT] = ACTIONS(5469),
    [anon_sym_Not] = ACTIONS(5469),
    [anon_sym_POUNDelse] = ACTIONS(5471),
    [anon_sym_POUNDELSE] = ACTIONS(5471),
    [anon_sym_POUNDElse] = ACTIONS(5471),
    [anon_sym_POUNDelse2] = ACTIONS(5471),
    [anon_sym_POUNDELSE2] = ACTIONS(5471),
    [anon_sym_POUNDElse2] = ACTIONS(5471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5469),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5469),
    [anon_sym_PLUS] = ACTIONS(5471),
    [sym_datetime_literal] = ACTIONS(5471),
    [sym_date_literal] = ACTIONS(5469),
    [sym_time_literal] = ACTIONS(5469),
    [sym_biginteger_literal] = ACTIONS(5471),
    [anon_sym_if] = ACTIONS(5469),
    [anon_sym_IF] = ACTIONS(5469),
    [anon_sym_If] = ACTIONS(5469),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5469),
    [anon_sym_CASE] = ACTIONS(5469),
    [anon_sym_Case] = ACTIONS(5469),
    [anon_sym_for] = ACTIONS(5469),
    [anon_sym_FOR] = ACTIONS(5469),
    [anon_sym_For] = ACTIONS(5469),
    [anon_sym_foreach] = ACTIONS(5469),
    [anon_sym_FOREACH] = ACTIONS(5469),
    [anon_sym_Foreach] = ACTIONS(5469),
    [anon_sym_while] = ACTIONS(5469),
    [anon_sym_WHILE] = ACTIONS(5469),
    [anon_sym_While] = ACTIONS(5469),
    [anon_sym_repeat] = ACTIONS(5469),
    [anon_sym_REPEAT] = ACTIONS(5469),
    [anon_sym_Repeat] = ACTIONS(5469),
    [anon_sym_until] = ACTIONS(5469),
    [anon_sym_UNTIL] = ACTIONS(5469),
    [anon_sym_Until] = ACTIONS(5469),
    [anon_sym_exit] = ACTIONS(5469),
    [anon_sym_EXIT] = ACTIONS(5469),
    [anon_sym_Exit] = ACTIONS(5469),
    [anon_sym_continue] = ACTIONS(5469),
    [anon_sym_CONTINUE] = ACTIONS(5469),
    [anon_sym_Continue] = ACTIONS(5469),
    [anon_sym_break] = ACTIONS(5469),
    [anon_sym_BREAK] = ACTIONS(5469),
    [anon_sym_Break] = ACTIONS(5469),
    [anon_sym_with] = ACTIONS(5469),
    [anon_sym_WITH] = ACTIONS(5469),
    [anon_sym_With] = ACTIONS(5469),
    [sym_asserterror_keyword] = ACTIONS(5471),
    [sym_page_keyword] = ACTIONS(5469),
    [anon_sym_codeunit] = ACTIONS(5469),
    [anon_sym_CODEUNIT] = ACTIONS(5469),
    [anon_sym_Codeunit] = ACTIONS(5469),
    [anon_sym_CodeUnit] = ACTIONS(5469),
    [anon_sym_COdeunit] = ACTIONS(5469),
    [anon_sym_codeUnit] = ACTIONS(5469),
    [sym_report_keyword] = ACTIONS(5469),
    [sym_query_keyword] = ACTIONS(5469),
    [anon_sym_xmlport] = ACTIONS(5469),
    [anon_sym_XMLPORT] = ACTIONS(5469),
    [anon_sym_Xmlport] = ACTIONS(5469),
    [anon_sym_XMLport] = ACTIONS(5469),
    [anon_sym_XMLPort] = ACTIONS(5469),
    [anon_sym_XmlPort] = ACTIONS(5469),
    [anon_sym_enum] = ACTIONS(5469),
    [anon_sym_ENUM] = ACTIONS(5469),
    [anon_sym_Enum] = ACTIONS(5469),
    [anon_sym_eNUM] = ACTIONS(5469),
    [anon_sym_eNum] = ACTIONS(5469),
    [anon_sym_ENum] = ACTIONS(5469),
    [sym_quoted_identifier] = ACTIONS(5471),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5471),
    [sym_verbatim_string] = ACTIONS(5471),
    [sym_integer] = ACTIONS(5469),
    [sym_continue_as_identifier] = ACTIONS(5471),
    [sym_preproc_open] = ACTIONS(5471),
  },
  [STATE(2777)] = {
    [sym_else_keyword] = STATE(672),
    [sym_identifier] = ACTIONS(5449),
    [anon_sym_SEMI] = ACTIONS(5451),
    [anon_sym_DASH] = ACTIONS(5451),
    [aux_sym_boolean_token1] = ACTIONS(5449),
    [aux_sym_boolean_token2] = ACTIONS(5449),
    [sym_decimal] = ACTIONS(5449),
    [anon_sym_LPAREN] = ACTIONS(5451),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5449),
    [anon_sym_LBRACK] = ACTIONS(5451),
    [aux_sym_record_type_token1] = ACTIONS(5449),
    [aux_sym_basic_type_token21] = ACTIONS(5449),
    [aux_sym_basic_type_token22] = ACTIONS(5449),
    [aux_sym_basic_type_token48] = ACTIONS(5449),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5449),
    [anon_sym_POUNDif] = ACTIONS(5451),
    [anon_sym_POUNDIF] = ACTIONS(5451),
    [anon_sym_POUNDIf] = ACTIONS(5451),
    [anon_sym_not] = ACTIONS(5449),
    [anon_sym_NOT] = ACTIONS(5449),
    [anon_sym_Not] = ACTIONS(5449),
    [anon_sym_POUNDelse] = ACTIONS(5451),
    [anon_sym_POUNDELSE] = ACTIONS(5451),
    [anon_sym_POUNDElse] = ACTIONS(5451),
    [anon_sym_POUNDelse2] = ACTIONS(5451),
    [anon_sym_POUNDELSE2] = ACTIONS(5451),
    [anon_sym_POUNDElse2] = ACTIONS(5451),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5449),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5449),
    [anon_sym_PLUS] = ACTIONS(5451),
    [sym_datetime_literal] = ACTIONS(5451),
    [sym_date_literal] = ACTIONS(5449),
    [sym_time_literal] = ACTIONS(5449),
    [sym_biginteger_literal] = ACTIONS(5451),
    [anon_sym_if] = ACTIONS(5449),
    [anon_sym_IF] = ACTIONS(5449),
    [anon_sym_If] = ACTIONS(5449),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5449),
    [anon_sym_CASE] = ACTIONS(5449),
    [anon_sym_Case] = ACTIONS(5449),
    [anon_sym_for] = ACTIONS(5449),
    [anon_sym_FOR] = ACTIONS(5449),
    [anon_sym_For] = ACTIONS(5449),
    [anon_sym_foreach] = ACTIONS(5449),
    [anon_sym_FOREACH] = ACTIONS(5449),
    [anon_sym_Foreach] = ACTIONS(5449),
    [anon_sym_while] = ACTIONS(5449),
    [anon_sym_WHILE] = ACTIONS(5449),
    [anon_sym_While] = ACTIONS(5449),
    [anon_sym_repeat] = ACTIONS(5449),
    [anon_sym_REPEAT] = ACTIONS(5449),
    [anon_sym_Repeat] = ACTIONS(5449),
    [anon_sym_until] = ACTIONS(5449),
    [anon_sym_UNTIL] = ACTIONS(5449),
    [anon_sym_Until] = ACTIONS(5449),
    [anon_sym_exit] = ACTIONS(5449),
    [anon_sym_EXIT] = ACTIONS(5449),
    [anon_sym_Exit] = ACTIONS(5449),
    [anon_sym_continue] = ACTIONS(5449),
    [anon_sym_CONTINUE] = ACTIONS(5449),
    [anon_sym_Continue] = ACTIONS(5449),
    [anon_sym_break] = ACTIONS(5449),
    [anon_sym_BREAK] = ACTIONS(5449),
    [anon_sym_Break] = ACTIONS(5449),
    [anon_sym_with] = ACTIONS(5449),
    [anon_sym_WITH] = ACTIONS(5449),
    [anon_sym_With] = ACTIONS(5449),
    [sym_asserterror_keyword] = ACTIONS(5451),
    [sym_page_keyword] = ACTIONS(5449),
    [anon_sym_codeunit] = ACTIONS(5449),
    [anon_sym_CODEUNIT] = ACTIONS(5449),
    [anon_sym_Codeunit] = ACTIONS(5449),
    [anon_sym_CodeUnit] = ACTIONS(5449),
    [anon_sym_COdeunit] = ACTIONS(5449),
    [anon_sym_codeUnit] = ACTIONS(5449),
    [sym_report_keyword] = ACTIONS(5449),
    [sym_query_keyword] = ACTIONS(5449),
    [anon_sym_xmlport] = ACTIONS(5449),
    [anon_sym_XMLPORT] = ACTIONS(5449),
    [anon_sym_Xmlport] = ACTIONS(5449),
    [anon_sym_XMLport] = ACTIONS(5449),
    [anon_sym_XMLPort] = ACTIONS(5449),
    [anon_sym_XmlPort] = ACTIONS(5449),
    [anon_sym_enum] = ACTIONS(5449),
    [anon_sym_ENUM] = ACTIONS(5449),
    [anon_sym_Enum] = ACTIONS(5449),
    [anon_sym_eNUM] = ACTIONS(5449),
    [anon_sym_eNum] = ACTIONS(5449),
    [anon_sym_ENum] = ACTIONS(5449),
    [sym_quoted_identifier] = ACTIONS(5451),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5451),
    [sym_verbatim_string] = ACTIONS(5451),
    [sym_integer] = ACTIONS(5449),
    [sym_continue_as_identifier] = ACTIONS(5451),
    [sym_preproc_open] = ACTIONS(5451),
  },
  [STATE(2778)] = {
    [anon_sym_POUNDif] = ACTIONS(6888),
    [anon_sym_POUNDIF] = ACTIONS(6888),
    [anon_sym_POUNDIf] = ACTIONS(6888),
    [anon_sym_POUNDelif] = ACTIONS(6888),
    [anon_sym_POUNDELIF] = ACTIONS(6888),
    [anon_sym_POUNDElif] = ACTIONS(6888),
    [anon_sym_POUNDelse] = ACTIONS(6888),
    [anon_sym_POUNDELSE] = ACTIONS(6888),
    [anon_sym_POUNDElse] = ACTIONS(6888),
    [anon_sym_POUNDelse2] = ACTIONS(6888),
    [anon_sym_POUNDELSE2] = ACTIONS(6888),
    [anon_sym_POUNDElse2] = ACTIONS(6888),
    [anon_sym_POUNDendif] = ACTIONS(6888),
    [anon_sym_POUNDENDIF] = ACTIONS(6888),
    [anon_sym_POUNDEndif] = ACTIONS(6888),
    [anon_sym_POUNDendif2] = ACTIONS(6888),
    [anon_sym_POUNDENDIF2] = ACTIONS(6888),
    [anon_sym_POUNDEndif2] = ACTIONS(6888),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6890),
    [anon_sym_tableextension] = ACTIONS(6888),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6888),
    [anon_sym_Tableextension] = ACTIONS(6888),
    [anon_sym_TableExtension] = ACTIONS(6888),
    [anon_sym_tableExtension] = ACTIONS(6888),
    [sym_page_keyword] = ACTIONS(6890),
    [anon_sym_pageextension] = ACTIONS(6888),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6888),
    [anon_sym_Pageextension] = ACTIONS(6888),
    [anon_sym_PageExtension] = ACTIONS(6888),
    [anon_sym_pageExtension] = ACTIONS(6888),
    [anon_sym_codeunit] = ACTIONS(6888),
    [anon_sym_CODEUNIT] = ACTIONS(6888),
    [anon_sym_Codeunit] = ACTIONS(6888),
    [anon_sym_CodeUnit] = ACTIONS(6888),
    [anon_sym_COdeunit] = ACTIONS(6888),
    [anon_sym_codeUnit] = ACTIONS(6888),
    [sym_report_keyword] = ACTIONS(6890),
    [anon_sym_reportextension] = ACTIONS(6888),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6888),
    [anon_sym_Reportextension] = ACTIONS(6888),
    [anon_sym_ReportExtension] = ACTIONS(6888),
    [anon_sym_reportExtension] = ACTIONS(6888),
    [sym_query_keyword] = ACTIONS(6888),
    [anon_sym_xmlport] = ACTIONS(6888),
    [anon_sym_XMLPORT] = ACTIONS(6888),
    [anon_sym_Xmlport] = ACTIONS(6888),
    [anon_sym_XMLport] = ACTIONS(6888),
    [anon_sym_XMLPort] = ACTIONS(6888),
    [anon_sym_XmlPort] = ACTIONS(6888),
    [anon_sym_enum] = ACTIONS(6890),
    [anon_sym_ENUM] = ACTIONS(6890),
    [anon_sym_Enum] = ACTIONS(6890),
    [anon_sym_eNUM] = ACTIONS(6888),
    [anon_sym_eNum] = ACTIONS(6888),
    [anon_sym_ENum] = ACTIONS(6888),
    [anon_sym_enumextension] = ACTIONS(6888),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6888),
    [anon_sym_Enumextension] = ACTIONS(6888),
    [anon_sym_EnumExtension] = ACTIONS(6888),
    [anon_sym_enumExtension] = ACTIONS(6888),
    [sym_interface_keyword] = ACTIONS(6888),
    [anon_sym_controladdin] = ACTIONS(6888),
    [anon_sym_CONTROLADDIN] = ACTIONS(6888),
    [anon_sym_Controladdin] = ACTIONS(6888),
    [anon_sym_ControlAddIn] = ACTIONS(6888),
    [anon_sym_ControlAddin] = ACTIONS(6888),
    [anon_sym_controlAddIn] = ACTIONS(6888),
    [anon_sym_controlAddin] = ACTIONS(6888),
    [anon_sym_dotnet] = ACTIONS(6888),
    [anon_sym_DOTNET] = ACTIONS(6888),
    [anon_sym_Dotnet] = ACTIONS(6888),
    [anon_sym_DotNet] = ACTIONS(6888),
    [anon_sym_dotNet] = ACTIONS(6888),
    [sym_profile_keyword] = ACTIONS(6890),
    [anon_sym_profileextension] = ACTIONS(6888),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6888),
    [anon_sym_Profileextension] = ACTIONS(6888),
    [anon_sym_ProfileExtension] = ACTIONS(6888),
    [anon_sym_profileExtension] = ACTIONS(6888),
    [anon_sym_permissionset] = ACTIONS(6890),
    [anon_sym_PERMISSIONSET] = ACTIONS(6890),
    [anon_sym_Permissionset] = ACTIONS(6890),
    [anon_sym_PermissionSet] = ACTIONS(6890),
    [anon_sym_permissionSet] = ACTIONS(6890),
    [anon_sym_permissionsetextension] = ACTIONS(6888),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6888),
    [anon_sym_Permissionsetextension] = ACTIONS(6888),
    [anon_sym_PermissionSetExtension] = ACTIONS(6888),
    [anon_sym_permissionSetExtension] = ACTIONS(6888),
    [sym_entitlement_keyword] = ACTIONS(6888),
    [anon_sym_pagecustomization] = ACTIONS(6888),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6888),
    [anon_sym_Pagecustomization] = ACTIONS(6888),
    [anon_sym_PageCustomization] = ACTIONS(6888),
    [anon_sym_pageCustomization] = ACTIONS(6888),
    [sym_using_keyword] = ACTIONS(6888),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6888),
    [sym_preproc_close] = ACTIONS(6888),
  },
  [STATE(2779)] = {
    [anon_sym_POUNDif] = ACTIONS(6892),
    [anon_sym_POUNDIF] = ACTIONS(6892),
    [anon_sym_POUNDIf] = ACTIONS(6892),
    [anon_sym_POUNDelif] = ACTIONS(6892),
    [anon_sym_POUNDELIF] = ACTIONS(6892),
    [anon_sym_POUNDElif] = ACTIONS(6892),
    [anon_sym_POUNDelse] = ACTIONS(6892),
    [anon_sym_POUNDELSE] = ACTIONS(6892),
    [anon_sym_POUNDElse] = ACTIONS(6892),
    [anon_sym_POUNDelse2] = ACTIONS(6892),
    [anon_sym_POUNDELSE2] = ACTIONS(6892),
    [anon_sym_POUNDElse2] = ACTIONS(6892),
    [anon_sym_POUNDendif] = ACTIONS(6892),
    [anon_sym_POUNDENDIF] = ACTIONS(6892),
    [anon_sym_POUNDEndif] = ACTIONS(6892),
    [anon_sym_POUNDendif2] = ACTIONS(6892),
    [anon_sym_POUNDENDIF2] = ACTIONS(6892),
    [anon_sym_POUNDEndif2] = ACTIONS(6892),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6894),
    [anon_sym_tableextension] = ACTIONS(6892),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6892),
    [anon_sym_Tableextension] = ACTIONS(6892),
    [anon_sym_TableExtension] = ACTIONS(6892),
    [anon_sym_tableExtension] = ACTIONS(6892),
    [sym_page_keyword] = ACTIONS(6894),
    [anon_sym_pageextension] = ACTIONS(6892),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6892),
    [anon_sym_Pageextension] = ACTIONS(6892),
    [anon_sym_PageExtension] = ACTIONS(6892),
    [anon_sym_pageExtension] = ACTIONS(6892),
    [anon_sym_codeunit] = ACTIONS(6892),
    [anon_sym_CODEUNIT] = ACTIONS(6892),
    [anon_sym_Codeunit] = ACTIONS(6892),
    [anon_sym_CodeUnit] = ACTIONS(6892),
    [anon_sym_COdeunit] = ACTIONS(6892),
    [anon_sym_codeUnit] = ACTIONS(6892),
    [sym_report_keyword] = ACTIONS(6894),
    [anon_sym_reportextension] = ACTIONS(6892),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6892),
    [anon_sym_Reportextension] = ACTIONS(6892),
    [anon_sym_ReportExtension] = ACTIONS(6892),
    [anon_sym_reportExtension] = ACTIONS(6892),
    [sym_query_keyword] = ACTIONS(6892),
    [anon_sym_xmlport] = ACTIONS(6892),
    [anon_sym_XMLPORT] = ACTIONS(6892),
    [anon_sym_Xmlport] = ACTIONS(6892),
    [anon_sym_XMLport] = ACTIONS(6892),
    [anon_sym_XMLPort] = ACTIONS(6892),
    [anon_sym_XmlPort] = ACTIONS(6892),
    [anon_sym_enum] = ACTIONS(6894),
    [anon_sym_ENUM] = ACTIONS(6894),
    [anon_sym_Enum] = ACTIONS(6894),
    [anon_sym_eNUM] = ACTIONS(6892),
    [anon_sym_eNum] = ACTIONS(6892),
    [anon_sym_ENum] = ACTIONS(6892),
    [anon_sym_enumextension] = ACTIONS(6892),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6892),
    [anon_sym_Enumextension] = ACTIONS(6892),
    [anon_sym_EnumExtension] = ACTIONS(6892),
    [anon_sym_enumExtension] = ACTIONS(6892),
    [sym_interface_keyword] = ACTIONS(6892),
    [anon_sym_controladdin] = ACTIONS(6892),
    [anon_sym_CONTROLADDIN] = ACTIONS(6892),
    [anon_sym_Controladdin] = ACTIONS(6892),
    [anon_sym_ControlAddIn] = ACTIONS(6892),
    [anon_sym_ControlAddin] = ACTIONS(6892),
    [anon_sym_controlAddIn] = ACTIONS(6892),
    [anon_sym_controlAddin] = ACTIONS(6892),
    [anon_sym_dotnet] = ACTIONS(6892),
    [anon_sym_DOTNET] = ACTIONS(6892),
    [anon_sym_Dotnet] = ACTIONS(6892),
    [anon_sym_DotNet] = ACTIONS(6892),
    [anon_sym_dotNet] = ACTIONS(6892),
    [sym_profile_keyword] = ACTIONS(6894),
    [anon_sym_profileextension] = ACTIONS(6892),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6892),
    [anon_sym_Profileextension] = ACTIONS(6892),
    [anon_sym_ProfileExtension] = ACTIONS(6892),
    [anon_sym_profileExtension] = ACTIONS(6892),
    [anon_sym_permissionset] = ACTIONS(6894),
    [anon_sym_PERMISSIONSET] = ACTIONS(6894),
    [anon_sym_Permissionset] = ACTIONS(6894),
    [anon_sym_PermissionSet] = ACTIONS(6894),
    [anon_sym_permissionSet] = ACTIONS(6894),
    [anon_sym_permissionsetextension] = ACTIONS(6892),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6892),
    [anon_sym_Permissionsetextension] = ACTIONS(6892),
    [anon_sym_PermissionSetExtension] = ACTIONS(6892),
    [anon_sym_permissionSetExtension] = ACTIONS(6892),
    [sym_entitlement_keyword] = ACTIONS(6892),
    [anon_sym_pagecustomization] = ACTIONS(6892),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6892),
    [anon_sym_Pagecustomization] = ACTIONS(6892),
    [anon_sym_PageCustomization] = ACTIONS(6892),
    [anon_sym_pageCustomization] = ACTIONS(6892),
    [sym_using_keyword] = ACTIONS(6892),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6892),
    [sym_preproc_close] = ACTIONS(6892),
  },
  [STATE(2780)] = {
    [anon_sym_POUNDif] = ACTIONS(6896),
    [anon_sym_POUNDIF] = ACTIONS(6896),
    [anon_sym_POUNDIf] = ACTIONS(6896),
    [anon_sym_POUNDelif] = ACTIONS(6896),
    [anon_sym_POUNDELIF] = ACTIONS(6896),
    [anon_sym_POUNDElif] = ACTIONS(6896),
    [anon_sym_POUNDelse] = ACTIONS(6896),
    [anon_sym_POUNDELSE] = ACTIONS(6896),
    [anon_sym_POUNDElse] = ACTIONS(6896),
    [anon_sym_POUNDelse2] = ACTIONS(6896),
    [anon_sym_POUNDELSE2] = ACTIONS(6896),
    [anon_sym_POUNDElse2] = ACTIONS(6896),
    [anon_sym_POUNDendif] = ACTIONS(6896),
    [anon_sym_POUNDENDIF] = ACTIONS(6896),
    [anon_sym_POUNDEndif] = ACTIONS(6896),
    [anon_sym_POUNDendif2] = ACTIONS(6896),
    [anon_sym_POUNDENDIF2] = ACTIONS(6896),
    [anon_sym_POUNDEndif2] = ACTIONS(6896),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6898),
    [anon_sym_tableextension] = ACTIONS(6896),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6896),
    [anon_sym_Tableextension] = ACTIONS(6896),
    [anon_sym_TableExtension] = ACTIONS(6896),
    [anon_sym_tableExtension] = ACTIONS(6896),
    [sym_page_keyword] = ACTIONS(6898),
    [anon_sym_pageextension] = ACTIONS(6896),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6896),
    [anon_sym_Pageextension] = ACTIONS(6896),
    [anon_sym_PageExtension] = ACTIONS(6896),
    [anon_sym_pageExtension] = ACTIONS(6896),
    [anon_sym_codeunit] = ACTIONS(6896),
    [anon_sym_CODEUNIT] = ACTIONS(6896),
    [anon_sym_Codeunit] = ACTIONS(6896),
    [anon_sym_CodeUnit] = ACTIONS(6896),
    [anon_sym_COdeunit] = ACTIONS(6896),
    [anon_sym_codeUnit] = ACTIONS(6896),
    [sym_report_keyword] = ACTIONS(6898),
    [anon_sym_reportextension] = ACTIONS(6896),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6896),
    [anon_sym_Reportextension] = ACTIONS(6896),
    [anon_sym_ReportExtension] = ACTIONS(6896),
    [anon_sym_reportExtension] = ACTIONS(6896),
    [sym_query_keyword] = ACTIONS(6896),
    [anon_sym_xmlport] = ACTIONS(6896),
    [anon_sym_XMLPORT] = ACTIONS(6896),
    [anon_sym_Xmlport] = ACTIONS(6896),
    [anon_sym_XMLport] = ACTIONS(6896),
    [anon_sym_XMLPort] = ACTIONS(6896),
    [anon_sym_XmlPort] = ACTIONS(6896),
    [anon_sym_enum] = ACTIONS(6898),
    [anon_sym_ENUM] = ACTIONS(6898),
    [anon_sym_Enum] = ACTIONS(6898),
    [anon_sym_eNUM] = ACTIONS(6896),
    [anon_sym_eNum] = ACTIONS(6896),
    [anon_sym_ENum] = ACTIONS(6896),
    [anon_sym_enumextension] = ACTIONS(6896),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6896),
    [anon_sym_Enumextension] = ACTIONS(6896),
    [anon_sym_EnumExtension] = ACTIONS(6896),
    [anon_sym_enumExtension] = ACTIONS(6896),
    [sym_interface_keyword] = ACTIONS(6896),
    [anon_sym_controladdin] = ACTIONS(6896),
    [anon_sym_CONTROLADDIN] = ACTIONS(6896),
    [anon_sym_Controladdin] = ACTIONS(6896),
    [anon_sym_ControlAddIn] = ACTIONS(6896),
    [anon_sym_ControlAddin] = ACTIONS(6896),
    [anon_sym_controlAddIn] = ACTIONS(6896),
    [anon_sym_controlAddin] = ACTIONS(6896),
    [anon_sym_dotnet] = ACTIONS(6896),
    [anon_sym_DOTNET] = ACTIONS(6896),
    [anon_sym_Dotnet] = ACTIONS(6896),
    [anon_sym_DotNet] = ACTIONS(6896),
    [anon_sym_dotNet] = ACTIONS(6896),
    [sym_profile_keyword] = ACTIONS(6898),
    [anon_sym_profileextension] = ACTIONS(6896),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6896),
    [anon_sym_Profileextension] = ACTIONS(6896),
    [anon_sym_ProfileExtension] = ACTIONS(6896),
    [anon_sym_profileExtension] = ACTIONS(6896),
    [anon_sym_permissionset] = ACTIONS(6898),
    [anon_sym_PERMISSIONSET] = ACTIONS(6898),
    [anon_sym_Permissionset] = ACTIONS(6898),
    [anon_sym_PermissionSet] = ACTIONS(6898),
    [anon_sym_permissionSet] = ACTIONS(6898),
    [anon_sym_permissionsetextension] = ACTIONS(6896),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6896),
    [anon_sym_Permissionsetextension] = ACTIONS(6896),
    [anon_sym_PermissionSetExtension] = ACTIONS(6896),
    [anon_sym_permissionSetExtension] = ACTIONS(6896),
    [sym_entitlement_keyword] = ACTIONS(6896),
    [anon_sym_pagecustomization] = ACTIONS(6896),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6896),
    [anon_sym_Pagecustomization] = ACTIONS(6896),
    [anon_sym_PageCustomization] = ACTIONS(6896),
    [anon_sym_pageCustomization] = ACTIONS(6896),
    [sym_using_keyword] = ACTIONS(6896),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6896),
    [sym_preproc_close] = ACTIONS(6896),
  },
  [STATE(2781)] = {
    [anon_sym_POUNDif] = ACTIONS(6900),
    [anon_sym_POUNDIF] = ACTIONS(6900),
    [anon_sym_POUNDIf] = ACTIONS(6900),
    [anon_sym_POUNDelif] = ACTIONS(6900),
    [anon_sym_POUNDELIF] = ACTIONS(6900),
    [anon_sym_POUNDElif] = ACTIONS(6900),
    [anon_sym_POUNDelse] = ACTIONS(6900),
    [anon_sym_POUNDELSE] = ACTIONS(6900),
    [anon_sym_POUNDElse] = ACTIONS(6900),
    [anon_sym_POUNDelse2] = ACTIONS(6900),
    [anon_sym_POUNDELSE2] = ACTIONS(6900),
    [anon_sym_POUNDElse2] = ACTIONS(6900),
    [anon_sym_POUNDendif] = ACTIONS(6900),
    [anon_sym_POUNDENDIF] = ACTIONS(6900),
    [anon_sym_POUNDEndif] = ACTIONS(6900),
    [anon_sym_POUNDendif2] = ACTIONS(6900),
    [anon_sym_POUNDENDIF2] = ACTIONS(6900),
    [anon_sym_POUNDEndif2] = ACTIONS(6900),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6902),
    [anon_sym_tableextension] = ACTIONS(6900),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6900),
    [anon_sym_Tableextension] = ACTIONS(6900),
    [anon_sym_TableExtension] = ACTIONS(6900),
    [anon_sym_tableExtension] = ACTIONS(6900),
    [sym_page_keyword] = ACTIONS(6902),
    [anon_sym_pageextension] = ACTIONS(6900),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6900),
    [anon_sym_Pageextension] = ACTIONS(6900),
    [anon_sym_PageExtension] = ACTIONS(6900),
    [anon_sym_pageExtension] = ACTIONS(6900),
    [anon_sym_codeunit] = ACTIONS(6900),
    [anon_sym_CODEUNIT] = ACTIONS(6900),
    [anon_sym_Codeunit] = ACTIONS(6900),
    [anon_sym_CodeUnit] = ACTIONS(6900),
    [anon_sym_COdeunit] = ACTIONS(6900),
    [anon_sym_codeUnit] = ACTIONS(6900),
    [sym_report_keyword] = ACTIONS(6902),
    [anon_sym_reportextension] = ACTIONS(6900),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6900),
    [anon_sym_Reportextension] = ACTIONS(6900),
    [anon_sym_ReportExtension] = ACTIONS(6900),
    [anon_sym_reportExtension] = ACTIONS(6900),
    [sym_query_keyword] = ACTIONS(6900),
    [anon_sym_xmlport] = ACTIONS(6900),
    [anon_sym_XMLPORT] = ACTIONS(6900),
    [anon_sym_Xmlport] = ACTIONS(6900),
    [anon_sym_XMLport] = ACTIONS(6900),
    [anon_sym_XMLPort] = ACTIONS(6900),
    [anon_sym_XmlPort] = ACTIONS(6900),
    [anon_sym_enum] = ACTIONS(6902),
    [anon_sym_ENUM] = ACTIONS(6902),
    [anon_sym_Enum] = ACTIONS(6902),
    [anon_sym_eNUM] = ACTIONS(6900),
    [anon_sym_eNum] = ACTIONS(6900),
    [anon_sym_ENum] = ACTIONS(6900),
    [anon_sym_enumextension] = ACTIONS(6900),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6900),
    [anon_sym_Enumextension] = ACTIONS(6900),
    [anon_sym_EnumExtension] = ACTIONS(6900),
    [anon_sym_enumExtension] = ACTIONS(6900),
    [sym_interface_keyword] = ACTIONS(6900),
    [anon_sym_controladdin] = ACTIONS(6900),
    [anon_sym_CONTROLADDIN] = ACTIONS(6900),
    [anon_sym_Controladdin] = ACTIONS(6900),
    [anon_sym_ControlAddIn] = ACTIONS(6900),
    [anon_sym_ControlAddin] = ACTIONS(6900),
    [anon_sym_controlAddIn] = ACTIONS(6900),
    [anon_sym_controlAddin] = ACTIONS(6900),
    [anon_sym_dotnet] = ACTIONS(6900),
    [anon_sym_DOTNET] = ACTIONS(6900),
    [anon_sym_Dotnet] = ACTIONS(6900),
    [anon_sym_DotNet] = ACTIONS(6900),
    [anon_sym_dotNet] = ACTIONS(6900),
    [sym_profile_keyword] = ACTIONS(6902),
    [anon_sym_profileextension] = ACTIONS(6900),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6900),
    [anon_sym_Profileextension] = ACTIONS(6900),
    [anon_sym_ProfileExtension] = ACTIONS(6900),
    [anon_sym_profileExtension] = ACTIONS(6900),
    [anon_sym_permissionset] = ACTIONS(6902),
    [anon_sym_PERMISSIONSET] = ACTIONS(6902),
    [anon_sym_Permissionset] = ACTIONS(6902),
    [anon_sym_PermissionSet] = ACTIONS(6902),
    [anon_sym_permissionSet] = ACTIONS(6902),
    [anon_sym_permissionsetextension] = ACTIONS(6900),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6900),
    [anon_sym_Permissionsetextension] = ACTIONS(6900),
    [anon_sym_PermissionSetExtension] = ACTIONS(6900),
    [anon_sym_permissionSetExtension] = ACTIONS(6900),
    [sym_entitlement_keyword] = ACTIONS(6900),
    [anon_sym_pagecustomization] = ACTIONS(6900),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6900),
    [anon_sym_Pagecustomization] = ACTIONS(6900),
    [anon_sym_PageCustomization] = ACTIONS(6900),
    [anon_sym_pageCustomization] = ACTIONS(6900),
    [sym_using_keyword] = ACTIONS(6900),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6900),
    [sym_preproc_close] = ACTIONS(6900),
  },
  [STATE(2782)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2782),
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(6904),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelif] = ACTIONS(3634),
    [anon_sym_POUNDELIF] = ACTIONS(3634),
    [anon_sym_POUNDElif] = ACTIONS(3634),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [anon_sym_POUNDendif] = ACTIONS(3634),
    [anon_sym_POUNDENDIF] = ACTIONS(3634),
    [anon_sym_POUNDEndif] = ACTIONS(3634),
    [anon_sym_POUNDendif2] = ACTIONS(3634),
    [anon_sym_POUNDENDIF2] = ACTIONS(3634),
    [anon_sym_POUNDEndif2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3634),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_close] = ACTIONS(3634),
  },
  [STATE(2783)] = {
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(6002),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_COLON_COLON] = ACTIONS(6820),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [anon_sym_POUNDelif] = ACTIONS(6002),
    [anon_sym_POUNDELIF] = ACTIONS(6002),
    [anon_sym_POUNDElif] = ACTIONS(6002),
    [anon_sym_POUNDelse] = ACTIONS(6002),
    [anon_sym_POUNDELSE] = ACTIONS(6002),
    [anon_sym_POUNDElse] = ACTIONS(6002),
    [anon_sym_POUNDelse2] = ACTIONS(6002),
    [anon_sym_POUNDELSE2] = ACTIONS(6002),
    [anon_sym_POUNDElse2] = ACTIONS(6002),
    [anon_sym_POUNDendif] = ACTIONS(6002),
    [anon_sym_POUNDENDIF] = ACTIONS(6002),
    [anon_sym_POUNDEndif] = ACTIONS(6002),
    [anon_sym_POUNDendif2] = ACTIONS(6002),
    [anon_sym_POUNDENDIF2] = ACTIONS(6002),
    [anon_sym_POUNDEndif2] = ACTIONS(6002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_close] = ACTIONS(6002),
  },
  [STATE(2784)] = {
    [anon_sym_POUNDif] = ACTIONS(6907),
    [anon_sym_POUNDIF] = ACTIONS(6907),
    [anon_sym_POUNDIf] = ACTIONS(6907),
    [anon_sym_POUNDelif] = ACTIONS(6907),
    [anon_sym_POUNDELIF] = ACTIONS(6907),
    [anon_sym_POUNDElif] = ACTIONS(6907),
    [anon_sym_POUNDelse] = ACTIONS(6907),
    [anon_sym_POUNDELSE] = ACTIONS(6907),
    [anon_sym_POUNDElse] = ACTIONS(6907),
    [anon_sym_POUNDelse2] = ACTIONS(6907),
    [anon_sym_POUNDELSE2] = ACTIONS(6907),
    [anon_sym_POUNDElse2] = ACTIONS(6907),
    [anon_sym_POUNDendif] = ACTIONS(6907),
    [anon_sym_POUNDENDIF] = ACTIONS(6907),
    [anon_sym_POUNDEndif] = ACTIONS(6907),
    [anon_sym_POUNDendif2] = ACTIONS(6907),
    [anon_sym_POUNDENDIF2] = ACTIONS(6907),
    [anon_sym_POUNDEndif2] = ACTIONS(6907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6909),
    [anon_sym_tableextension] = ACTIONS(6907),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6907),
    [anon_sym_Tableextension] = ACTIONS(6907),
    [anon_sym_TableExtension] = ACTIONS(6907),
    [anon_sym_tableExtension] = ACTIONS(6907),
    [sym_page_keyword] = ACTIONS(6909),
    [anon_sym_pageextension] = ACTIONS(6907),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6907),
    [anon_sym_Pageextension] = ACTIONS(6907),
    [anon_sym_PageExtension] = ACTIONS(6907),
    [anon_sym_pageExtension] = ACTIONS(6907),
    [anon_sym_codeunit] = ACTIONS(6907),
    [anon_sym_CODEUNIT] = ACTIONS(6907),
    [anon_sym_Codeunit] = ACTIONS(6907),
    [anon_sym_CodeUnit] = ACTIONS(6907),
    [anon_sym_COdeunit] = ACTIONS(6907),
    [anon_sym_codeUnit] = ACTIONS(6907),
    [sym_report_keyword] = ACTIONS(6909),
    [anon_sym_reportextension] = ACTIONS(6907),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6907),
    [anon_sym_Reportextension] = ACTIONS(6907),
    [anon_sym_ReportExtension] = ACTIONS(6907),
    [anon_sym_reportExtension] = ACTIONS(6907),
    [sym_query_keyword] = ACTIONS(6907),
    [anon_sym_xmlport] = ACTIONS(6907),
    [anon_sym_XMLPORT] = ACTIONS(6907),
    [anon_sym_Xmlport] = ACTIONS(6907),
    [anon_sym_XMLport] = ACTIONS(6907),
    [anon_sym_XMLPort] = ACTIONS(6907),
    [anon_sym_XmlPort] = ACTIONS(6907),
    [anon_sym_enum] = ACTIONS(6909),
    [anon_sym_ENUM] = ACTIONS(6909),
    [anon_sym_Enum] = ACTIONS(6909),
    [anon_sym_eNUM] = ACTIONS(6907),
    [anon_sym_eNum] = ACTIONS(6907),
    [anon_sym_ENum] = ACTIONS(6907),
    [anon_sym_enumextension] = ACTIONS(6907),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6907),
    [anon_sym_Enumextension] = ACTIONS(6907),
    [anon_sym_EnumExtension] = ACTIONS(6907),
    [anon_sym_enumExtension] = ACTIONS(6907),
    [sym_interface_keyword] = ACTIONS(6907),
    [anon_sym_controladdin] = ACTIONS(6907),
    [anon_sym_CONTROLADDIN] = ACTIONS(6907),
    [anon_sym_Controladdin] = ACTIONS(6907),
    [anon_sym_ControlAddIn] = ACTIONS(6907),
    [anon_sym_ControlAddin] = ACTIONS(6907),
    [anon_sym_controlAddIn] = ACTIONS(6907),
    [anon_sym_controlAddin] = ACTIONS(6907),
    [anon_sym_dotnet] = ACTIONS(6907),
    [anon_sym_DOTNET] = ACTIONS(6907),
    [anon_sym_Dotnet] = ACTIONS(6907),
    [anon_sym_DotNet] = ACTIONS(6907),
    [anon_sym_dotNet] = ACTIONS(6907),
    [sym_profile_keyword] = ACTIONS(6909),
    [anon_sym_profileextension] = ACTIONS(6907),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6907),
    [anon_sym_Profileextension] = ACTIONS(6907),
    [anon_sym_ProfileExtension] = ACTIONS(6907),
    [anon_sym_profileExtension] = ACTIONS(6907),
    [anon_sym_permissionset] = ACTIONS(6909),
    [anon_sym_PERMISSIONSET] = ACTIONS(6909),
    [anon_sym_Permissionset] = ACTIONS(6909),
    [anon_sym_PermissionSet] = ACTIONS(6909),
    [anon_sym_permissionSet] = ACTIONS(6909),
    [anon_sym_permissionsetextension] = ACTIONS(6907),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6907),
    [anon_sym_Permissionsetextension] = ACTIONS(6907),
    [anon_sym_PermissionSetExtension] = ACTIONS(6907),
    [anon_sym_permissionSetExtension] = ACTIONS(6907),
    [sym_entitlement_keyword] = ACTIONS(6907),
    [anon_sym_pagecustomization] = ACTIONS(6907),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6907),
    [anon_sym_Pagecustomization] = ACTIONS(6907),
    [anon_sym_PageCustomization] = ACTIONS(6907),
    [anon_sym_pageCustomization] = ACTIONS(6907),
    [sym_using_keyword] = ACTIONS(6907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6907),
    [sym_preproc_close] = ACTIONS(6907),
  },
  [STATE(2785)] = {
    [anon_sym_POUNDif] = ACTIONS(6911),
    [anon_sym_POUNDIF] = ACTIONS(6911),
    [anon_sym_POUNDIf] = ACTIONS(6911),
    [anon_sym_POUNDelif] = ACTIONS(6911),
    [anon_sym_POUNDELIF] = ACTIONS(6911),
    [anon_sym_POUNDElif] = ACTIONS(6911),
    [anon_sym_POUNDelse] = ACTIONS(6911),
    [anon_sym_POUNDELSE] = ACTIONS(6911),
    [anon_sym_POUNDElse] = ACTIONS(6911),
    [anon_sym_POUNDelse2] = ACTIONS(6911),
    [anon_sym_POUNDELSE2] = ACTIONS(6911),
    [anon_sym_POUNDElse2] = ACTIONS(6911),
    [anon_sym_POUNDendif] = ACTIONS(6911),
    [anon_sym_POUNDENDIF] = ACTIONS(6911),
    [anon_sym_POUNDEndif] = ACTIONS(6911),
    [anon_sym_POUNDendif2] = ACTIONS(6911),
    [anon_sym_POUNDENDIF2] = ACTIONS(6911),
    [anon_sym_POUNDEndif2] = ACTIONS(6911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6913),
    [anon_sym_tableextension] = ACTIONS(6911),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6911),
    [anon_sym_Tableextension] = ACTIONS(6911),
    [anon_sym_TableExtension] = ACTIONS(6911),
    [anon_sym_tableExtension] = ACTIONS(6911),
    [sym_page_keyword] = ACTIONS(6913),
    [anon_sym_pageextension] = ACTIONS(6911),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6911),
    [anon_sym_Pageextension] = ACTIONS(6911),
    [anon_sym_PageExtension] = ACTIONS(6911),
    [anon_sym_pageExtension] = ACTIONS(6911),
    [anon_sym_codeunit] = ACTIONS(6911),
    [anon_sym_CODEUNIT] = ACTIONS(6911),
    [anon_sym_Codeunit] = ACTIONS(6911),
    [anon_sym_CodeUnit] = ACTIONS(6911),
    [anon_sym_COdeunit] = ACTIONS(6911),
    [anon_sym_codeUnit] = ACTIONS(6911),
    [sym_report_keyword] = ACTIONS(6913),
    [anon_sym_reportextension] = ACTIONS(6911),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6911),
    [anon_sym_Reportextension] = ACTIONS(6911),
    [anon_sym_ReportExtension] = ACTIONS(6911),
    [anon_sym_reportExtension] = ACTIONS(6911),
    [sym_query_keyword] = ACTIONS(6911),
    [anon_sym_xmlport] = ACTIONS(6911),
    [anon_sym_XMLPORT] = ACTIONS(6911),
    [anon_sym_Xmlport] = ACTIONS(6911),
    [anon_sym_XMLport] = ACTIONS(6911),
    [anon_sym_XMLPort] = ACTIONS(6911),
    [anon_sym_XmlPort] = ACTIONS(6911),
    [anon_sym_enum] = ACTIONS(6913),
    [anon_sym_ENUM] = ACTIONS(6913),
    [anon_sym_Enum] = ACTIONS(6913),
    [anon_sym_eNUM] = ACTIONS(6911),
    [anon_sym_eNum] = ACTIONS(6911),
    [anon_sym_ENum] = ACTIONS(6911),
    [anon_sym_enumextension] = ACTIONS(6911),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6911),
    [anon_sym_Enumextension] = ACTIONS(6911),
    [anon_sym_EnumExtension] = ACTIONS(6911),
    [anon_sym_enumExtension] = ACTIONS(6911),
    [sym_interface_keyword] = ACTIONS(6911),
    [anon_sym_controladdin] = ACTIONS(6911),
    [anon_sym_CONTROLADDIN] = ACTIONS(6911),
    [anon_sym_Controladdin] = ACTIONS(6911),
    [anon_sym_ControlAddIn] = ACTIONS(6911),
    [anon_sym_ControlAddin] = ACTIONS(6911),
    [anon_sym_controlAddIn] = ACTIONS(6911),
    [anon_sym_controlAddin] = ACTIONS(6911),
    [anon_sym_dotnet] = ACTIONS(6911),
    [anon_sym_DOTNET] = ACTIONS(6911),
    [anon_sym_Dotnet] = ACTIONS(6911),
    [anon_sym_DotNet] = ACTIONS(6911),
    [anon_sym_dotNet] = ACTIONS(6911),
    [sym_profile_keyword] = ACTIONS(6913),
    [anon_sym_profileextension] = ACTIONS(6911),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6911),
    [anon_sym_Profileextension] = ACTIONS(6911),
    [anon_sym_ProfileExtension] = ACTIONS(6911),
    [anon_sym_profileExtension] = ACTIONS(6911),
    [anon_sym_permissionset] = ACTIONS(6913),
    [anon_sym_PERMISSIONSET] = ACTIONS(6913),
    [anon_sym_Permissionset] = ACTIONS(6913),
    [anon_sym_PermissionSet] = ACTIONS(6913),
    [anon_sym_permissionSet] = ACTIONS(6913),
    [anon_sym_permissionsetextension] = ACTIONS(6911),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6911),
    [anon_sym_Permissionsetextension] = ACTIONS(6911),
    [anon_sym_PermissionSetExtension] = ACTIONS(6911),
    [anon_sym_permissionSetExtension] = ACTIONS(6911),
    [sym_entitlement_keyword] = ACTIONS(6911),
    [anon_sym_pagecustomization] = ACTIONS(6911),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6911),
    [anon_sym_Pagecustomization] = ACTIONS(6911),
    [anon_sym_PageCustomization] = ACTIONS(6911),
    [anon_sym_pageCustomization] = ACTIONS(6911),
    [sym_using_keyword] = ACTIONS(6911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6911),
    [sym_preproc_close] = ACTIONS(6911),
  },
  [STATE(2786)] = {
    [anon_sym_POUNDif] = ACTIONS(6915),
    [anon_sym_POUNDIF] = ACTIONS(6915),
    [anon_sym_POUNDIf] = ACTIONS(6915),
    [anon_sym_POUNDelif] = ACTIONS(6915),
    [anon_sym_POUNDELIF] = ACTIONS(6915),
    [anon_sym_POUNDElif] = ACTIONS(6915),
    [anon_sym_POUNDelse] = ACTIONS(6915),
    [anon_sym_POUNDELSE] = ACTIONS(6915),
    [anon_sym_POUNDElse] = ACTIONS(6915),
    [anon_sym_POUNDelse2] = ACTIONS(6915),
    [anon_sym_POUNDELSE2] = ACTIONS(6915),
    [anon_sym_POUNDElse2] = ACTIONS(6915),
    [anon_sym_POUNDendif] = ACTIONS(6915),
    [anon_sym_POUNDENDIF] = ACTIONS(6915),
    [anon_sym_POUNDEndif] = ACTIONS(6915),
    [anon_sym_POUNDendif2] = ACTIONS(6915),
    [anon_sym_POUNDENDIF2] = ACTIONS(6915),
    [anon_sym_POUNDEndif2] = ACTIONS(6915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6917),
    [anon_sym_tableextension] = ACTIONS(6915),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6915),
    [anon_sym_Tableextension] = ACTIONS(6915),
    [anon_sym_TableExtension] = ACTIONS(6915),
    [anon_sym_tableExtension] = ACTIONS(6915),
    [sym_page_keyword] = ACTIONS(6917),
    [anon_sym_pageextension] = ACTIONS(6915),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6915),
    [anon_sym_Pageextension] = ACTIONS(6915),
    [anon_sym_PageExtension] = ACTIONS(6915),
    [anon_sym_pageExtension] = ACTIONS(6915),
    [anon_sym_codeunit] = ACTIONS(6915),
    [anon_sym_CODEUNIT] = ACTIONS(6915),
    [anon_sym_Codeunit] = ACTIONS(6915),
    [anon_sym_CodeUnit] = ACTIONS(6915),
    [anon_sym_COdeunit] = ACTIONS(6915),
    [anon_sym_codeUnit] = ACTIONS(6915),
    [sym_report_keyword] = ACTIONS(6917),
    [anon_sym_reportextension] = ACTIONS(6915),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6915),
    [anon_sym_Reportextension] = ACTIONS(6915),
    [anon_sym_ReportExtension] = ACTIONS(6915),
    [anon_sym_reportExtension] = ACTIONS(6915),
    [sym_query_keyword] = ACTIONS(6915),
    [anon_sym_xmlport] = ACTIONS(6915),
    [anon_sym_XMLPORT] = ACTIONS(6915),
    [anon_sym_Xmlport] = ACTIONS(6915),
    [anon_sym_XMLport] = ACTIONS(6915),
    [anon_sym_XMLPort] = ACTIONS(6915),
    [anon_sym_XmlPort] = ACTIONS(6915),
    [anon_sym_enum] = ACTIONS(6917),
    [anon_sym_ENUM] = ACTIONS(6917),
    [anon_sym_Enum] = ACTIONS(6917),
    [anon_sym_eNUM] = ACTIONS(6915),
    [anon_sym_eNum] = ACTIONS(6915),
    [anon_sym_ENum] = ACTIONS(6915),
    [anon_sym_enumextension] = ACTIONS(6915),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6915),
    [anon_sym_Enumextension] = ACTIONS(6915),
    [anon_sym_EnumExtension] = ACTIONS(6915),
    [anon_sym_enumExtension] = ACTIONS(6915),
    [sym_interface_keyword] = ACTIONS(6915),
    [anon_sym_controladdin] = ACTIONS(6915),
    [anon_sym_CONTROLADDIN] = ACTIONS(6915),
    [anon_sym_Controladdin] = ACTIONS(6915),
    [anon_sym_ControlAddIn] = ACTIONS(6915),
    [anon_sym_ControlAddin] = ACTIONS(6915),
    [anon_sym_controlAddIn] = ACTIONS(6915),
    [anon_sym_controlAddin] = ACTIONS(6915),
    [anon_sym_dotnet] = ACTIONS(6915),
    [anon_sym_DOTNET] = ACTIONS(6915),
    [anon_sym_Dotnet] = ACTIONS(6915),
    [anon_sym_DotNet] = ACTIONS(6915),
    [anon_sym_dotNet] = ACTIONS(6915),
    [sym_profile_keyword] = ACTIONS(6917),
    [anon_sym_profileextension] = ACTIONS(6915),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6915),
    [anon_sym_Profileextension] = ACTIONS(6915),
    [anon_sym_ProfileExtension] = ACTIONS(6915),
    [anon_sym_profileExtension] = ACTIONS(6915),
    [anon_sym_permissionset] = ACTIONS(6917),
    [anon_sym_PERMISSIONSET] = ACTIONS(6917),
    [anon_sym_Permissionset] = ACTIONS(6917),
    [anon_sym_PermissionSet] = ACTIONS(6917),
    [anon_sym_permissionSet] = ACTIONS(6917),
    [anon_sym_permissionsetextension] = ACTIONS(6915),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6915),
    [anon_sym_Permissionsetextension] = ACTIONS(6915),
    [anon_sym_PermissionSetExtension] = ACTIONS(6915),
    [anon_sym_permissionSetExtension] = ACTIONS(6915),
    [sym_entitlement_keyword] = ACTIONS(6915),
    [anon_sym_pagecustomization] = ACTIONS(6915),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6915),
    [anon_sym_Pagecustomization] = ACTIONS(6915),
    [anon_sym_PageCustomization] = ACTIONS(6915),
    [anon_sym_pageCustomization] = ACTIONS(6915),
    [sym_using_keyword] = ACTIONS(6915),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6915),
    [sym_preproc_close] = ACTIONS(6915),
  },
  [STATE(2787)] = {
    [sym_else_keyword] = STATE(677),
    [sym_identifier] = ACTIONS(5477),
    [anon_sym_SEMI] = ACTIONS(5479),
    [anon_sym_DASH] = ACTIONS(5479),
    [aux_sym_boolean_token1] = ACTIONS(5477),
    [aux_sym_boolean_token2] = ACTIONS(5477),
    [sym_decimal] = ACTIONS(5477),
    [anon_sym_LPAREN] = ACTIONS(5479),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5477),
    [anon_sym_LBRACK] = ACTIONS(5479),
    [aux_sym_record_type_token1] = ACTIONS(5477),
    [aux_sym_basic_type_token21] = ACTIONS(5477),
    [aux_sym_basic_type_token22] = ACTIONS(5477),
    [aux_sym_basic_type_token48] = ACTIONS(5477),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5477),
    [anon_sym_POUNDif] = ACTIONS(5479),
    [anon_sym_POUNDIF] = ACTIONS(5479),
    [anon_sym_POUNDIf] = ACTIONS(5479),
    [anon_sym_not] = ACTIONS(5477),
    [anon_sym_NOT] = ACTIONS(5477),
    [anon_sym_Not] = ACTIONS(5477),
    [anon_sym_POUNDelse] = ACTIONS(5479),
    [anon_sym_POUNDELSE] = ACTIONS(5479),
    [anon_sym_POUNDElse] = ACTIONS(5479),
    [anon_sym_POUNDelse2] = ACTIONS(5479),
    [anon_sym_POUNDELSE2] = ACTIONS(5479),
    [anon_sym_POUNDElse2] = ACTIONS(5479),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5477),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5477),
    [anon_sym_PLUS] = ACTIONS(5479),
    [sym_datetime_literal] = ACTIONS(5479),
    [sym_date_literal] = ACTIONS(5477),
    [sym_time_literal] = ACTIONS(5477),
    [sym_biginteger_literal] = ACTIONS(5479),
    [anon_sym_if] = ACTIONS(5477),
    [anon_sym_IF] = ACTIONS(5477),
    [anon_sym_If] = ACTIONS(5477),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5477),
    [anon_sym_CASE] = ACTIONS(5477),
    [anon_sym_Case] = ACTIONS(5477),
    [anon_sym_for] = ACTIONS(5477),
    [anon_sym_FOR] = ACTIONS(5477),
    [anon_sym_For] = ACTIONS(5477),
    [anon_sym_foreach] = ACTIONS(5477),
    [anon_sym_FOREACH] = ACTIONS(5477),
    [anon_sym_Foreach] = ACTIONS(5477),
    [anon_sym_while] = ACTIONS(5477),
    [anon_sym_WHILE] = ACTIONS(5477),
    [anon_sym_While] = ACTIONS(5477),
    [anon_sym_repeat] = ACTIONS(5477),
    [anon_sym_REPEAT] = ACTIONS(5477),
    [anon_sym_Repeat] = ACTIONS(5477),
    [anon_sym_until] = ACTIONS(5477),
    [anon_sym_UNTIL] = ACTIONS(5477),
    [anon_sym_Until] = ACTIONS(5477),
    [anon_sym_exit] = ACTIONS(5477),
    [anon_sym_EXIT] = ACTIONS(5477),
    [anon_sym_Exit] = ACTIONS(5477),
    [anon_sym_continue] = ACTIONS(5477),
    [anon_sym_CONTINUE] = ACTIONS(5477),
    [anon_sym_Continue] = ACTIONS(5477),
    [anon_sym_break] = ACTIONS(5477),
    [anon_sym_BREAK] = ACTIONS(5477),
    [anon_sym_Break] = ACTIONS(5477),
    [anon_sym_with] = ACTIONS(5477),
    [anon_sym_WITH] = ACTIONS(5477),
    [anon_sym_With] = ACTIONS(5477),
    [sym_asserterror_keyword] = ACTIONS(5479),
    [sym_page_keyword] = ACTIONS(5477),
    [anon_sym_codeunit] = ACTIONS(5477),
    [anon_sym_CODEUNIT] = ACTIONS(5477),
    [anon_sym_Codeunit] = ACTIONS(5477),
    [anon_sym_CodeUnit] = ACTIONS(5477),
    [anon_sym_COdeunit] = ACTIONS(5477),
    [anon_sym_codeUnit] = ACTIONS(5477),
    [sym_report_keyword] = ACTIONS(5477),
    [sym_query_keyword] = ACTIONS(5477),
    [anon_sym_xmlport] = ACTIONS(5477),
    [anon_sym_XMLPORT] = ACTIONS(5477),
    [anon_sym_Xmlport] = ACTIONS(5477),
    [anon_sym_XMLport] = ACTIONS(5477),
    [anon_sym_XMLPort] = ACTIONS(5477),
    [anon_sym_XmlPort] = ACTIONS(5477),
    [anon_sym_enum] = ACTIONS(5477),
    [anon_sym_ENUM] = ACTIONS(5477),
    [anon_sym_Enum] = ACTIONS(5477),
    [anon_sym_eNUM] = ACTIONS(5477),
    [anon_sym_eNum] = ACTIONS(5477),
    [anon_sym_ENum] = ACTIONS(5477),
    [sym_quoted_identifier] = ACTIONS(5479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5479),
    [sym_verbatim_string] = ACTIONS(5479),
    [sym_integer] = ACTIONS(5477),
    [sym_continue_as_identifier] = ACTIONS(5479),
    [sym_preproc_open] = ACTIONS(5479),
  },
  [STATE(2788)] = {
    [sym_else_keyword] = STATE(678),
    [sym_identifier] = ACTIONS(5441),
    [anon_sym_SEMI] = ACTIONS(5443),
    [anon_sym_DASH] = ACTIONS(5443),
    [aux_sym_boolean_token1] = ACTIONS(5441),
    [aux_sym_boolean_token2] = ACTIONS(5441),
    [sym_decimal] = ACTIONS(5441),
    [anon_sym_LPAREN] = ACTIONS(5443),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5441),
    [anon_sym_LBRACK] = ACTIONS(5443),
    [aux_sym_record_type_token1] = ACTIONS(5441),
    [aux_sym_basic_type_token21] = ACTIONS(5441),
    [aux_sym_basic_type_token22] = ACTIONS(5441),
    [aux_sym_basic_type_token48] = ACTIONS(5441),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5441),
    [anon_sym_POUNDif] = ACTIONS(5443),
    [anon_sym_POUNDIF] = ACTIONS(5443),
    [anon_sym_POUNDIf] = ACTIONS(5443),
    [anon_sym_not] = ACTIONS(5441),
    [anon_sym_NOT] = ACTIONS(5441),
    [anon_sym_Not] = ACTIONS(5441),
    [anon_sym_POUNDelse] = ACTIONS(5443),
    [anon_sym_POUNDELSE] = ACTIONS(5443),
    [anon_sym_POUNDElse] = ACTIONS(5443),
    [anon_sym_POUNDelse2] = ACTIONS(5443),
    [anon_sym_POUNDELSE2] = ACTIONS(5443),
    [anon_sym_POUNDElse2] = ACTIONS(5443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5441),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5441),
    [anon_sym_PLUS] = ACTIONS(5443),
    [sym_datetime_literal] = ACTIONS(5443),
    [sym_date_literal] = ACTIONS(5441),
    [sym_time_literal] = ACTIONS(5441),
    [sym_biginteger_literal] = ACTIONS(5443),
    [anon_sym_if] = ACTIONS(5441),
    [anon_sym_IF] = ACTIONS(5441),
    [anon_sym_If] = ACTIONS(5441),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5441),
    [anon_sym_CASE] = ACTIONS(5441),
    [anon_sym_Case] = ACTIONS(5441),
    [anon_sym_for] = ACTIONS(5441),
    [anon_sym_FOR] = ACTIONS(5441),
    [anon_sym_For] = ACTIONS(5441),
    [anon_sym_foreach] = ACTIONS(5441),
    [anon_sym_FOREACH] = ACTIONS(5441),
    [anon_sym_Foreach] = ACTIONS(5441),
    [anon_sym_while] = ACTIONS(5441),
    [anon_sym_WHILE] = ACTIONS(5441),
    [anon_sym_While] = ACTIONS(5441),
    [anon_sym_repeat] = ACTIONS(5441),
    [anon_sym_REPEAT] = ACTIONS(5441),
    [anon_sym_Repeat] = ACTIONS(5441),
    [anon_sym_until] = ACTIONS(5441),
    [anon_sym_UNTIL] = ACTIONS(5441),
    [anon_sym_Until] = ACTIONS(5441),
    [anon_sym_exit] = ACTIONS(5441),
    [anon_sym_EXIT] = ACTIONS(5441),
    [anon_sym_Exit] = ACTIONS(5441),
    [anon_sym_continue] = ACTIONS(5441),
    [anon_sym_CONTINUE] = ACTIONS(5441),
    [anon_sym_Continue] = ACTIONS(5441),
    [anon_sym_break] = ACTIONS(5441),
    [anon_sym_BREAK] = ACTIONS(5441),
    [anon_sym_Break] = ACTIONS(5441),
    [anon_sym_with] = ACTIONS(5441),
    [anon_sym_WITH] = ACTIONS(5441),
    [anon_sym_With] = ACTIONS(5441),
    [sym_asserterror_keyword] = ACTIONS(5443),
    [sym_page_keyword] = ACTIONS(5441),
    [anon_sym_codeunit] = ACTIONS(5441),
    [anon_sym_CODEUNIT] = ACTIONS(5441),
    [anon_sym_Codeunit] = ACTIONS(5441),
    [anon_sym_CodeUnit] = ACTIONS(5441),
    [anon_sym_COdeunit] = ACTIONS(5441),
    [anon_sym_codeUnit] = ACTIONS(5441),
    [sym_report_keyword] = ACTIONS(5441),
    [sym_query_keyword] = ACTIONS(5441),
    [anon_sym_xmlport] = ACTIONS(5441),
    [anon_sym_XMLPORT] = ACTIONS(5441),
    [anon_sym_Xmlport] = ACTIONS(5441),
    [anon_sym_XMLport] = ACTIONS(5441),
    [anon_sym_XMLPort] = ACTIONS(5441),
    [anon_sym_XmlPort] = ACTIONS(5441),
    [anon_sym_enum] = ACTIONS(5441),
    [anon_sym_ENUM] = ACTIONS(5441),
    [anon_sym_Enum] = ACTIONS(5441),
    [anon_sym_eNUM] = ACTIONS(5441),
    [anon_sym_eNum] = ACTIONS(5441),
    [anon_sym_ENum] = ACTIONS(5441),
    [sym_quoted_identifier] = ACTIONS(5443),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5443),
    [sym_verbatim_string] = ACTIONS(5443),
    [sym_integer] = ACTIONS(5441),
    [sym_continue_as_identifier] = ACTIONS(5443),
    [sym_preproc_open] = ACTIONS(5443),
  },
  [STATE(2789)] = {
    [sym_else_keyword] = STATE(679),
    [sym_identifier] = ACTIONS(5431),
    [anon_sym_SEMI] = ACTIONS(5433),
    [anon_sym_DASH] = ACTIONS(5433),
    [aux_sym_boolean_token1] = ACTIONS(5431),
    [aux_sym_boolean_token2] = ACTIONS(5431),
    [sym_decimal] = ACTIONS(5431),
    [anon_sym_LPAREN] = ACTIONS(5433),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5431),
    [anon_sym_LBRACK] = ACTIONS(5433),
    [aux_sym_record_type_token1] = ACTIONS(5431),
    [aux_sym_basic_type_token21] = ACTIONS(5431),
    [aux_sym_basic_type_token22] = ACTIONS(5431),
    [aux_sym_basic_type_token48] = ACTIONS(5431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5431),
    [anon_sym_POUNDif] = ACTIONS(5433),
    [anon_sym_POUNDIF] = ACTIONS(5433),
    [anon_sym_POUNDIf] = ACTIONS(5433),
    [anon_sym_not] = ACTIONS(5431),
    [anon_sym_NOT] = ACTIONS(5431),
    [anon_sym_Not] = ACTIONS(5431),
    [anon_sym_POUNDelse] = ACTIONS(5433),
    [anon_sym_POUNDELSE] = ACTIONS(5433),
    [anon_sym_POUNDElse] = ACTIONS(5433),
    [anon_sym_POUNDelse2] = ACTIONS(5433),
    [anon_sym_POUNDELSE2] = ACTIONS(5433),
    [anon_sym_POUNDElse2] = ACTIONS(5433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5431),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5431),
    [anon_sym_PLUS] = ACTIONS(5433),
    [sym_datetime_literal] = ACTIONS(5433),
    [sym_date_literal] = ACTIONS(5431),
    [sym_time_literal] = ACTIONS(5431),
    [sym_biginteger_literal] = ACTIONS(5433),
    [anon_sym_if] = ACTIONS(5431),
    [anon_sym_IF] = ACTIONS(5431),
    [anon_sym_If] = ACTIONS(5431),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5431),
    [anon_sym_CASE] = ACTIONS(5431),
    [anon_sym_Case] = ACTIONS(5431),
    [anon_sym_for] = ACTIONS(5431),
    [anon_sym_FOR] = ACTIONS(5431),
    [anon_sym_For] = ACTIONS(5431),
    [anon_sym_foreach] = ACTIONS(5431),
    [anon_sym_FOREACH] = ACTIONS(5431),
    [anon_sym_Foreach] = ACTIONS(5431),
    [anon_sym_while] = ACTIONS(5431),
    [anon_sym_WHILE] = ACTIONS(5431),
    [anon_sym_While] = ACTIONS(5431),
    [anon_sym_repeat] = ACTIONS(5431),
    [anon_sym_REPEAT] = ACTIONS(5431),
    [anon_sym_Repeat] = ACTIONS(5431),
    [anon_sym_until] = ACTIONS(5431),
    [anon_sym_UNTIL] = ACTIONS(5431),
    [anon_sym_Until] = ACTIONS(5431),
    [anon_sym_exit] = ACTIONS(5431),
    [anon_sym_EXIT] = ACTIONS(5431),
    [anon_sym_Exit] = ACTIONS(5431),
    [anon_sym_continue] = ACTIONS(5431),
    [anon_sym_CONTINUE] = ACTIONS(5431),
    [anon_sym_Continue] = ACTIONS(5431),
    [anon_sym_break] = ACTIONS(5431),
    [anon_sym_BREAK] = ACTIONS(5431),
    [anon_sym_Break] = ACTIONS(5431),
    [anon_sym_with] = ACTIONS(5431),
    [anon_sym_WITH] = ACTIONS(5431),
    [anon_sym_With] = ACTIONS(5431),
    [sym_asserterror_keyword] = ACTIONS(5433),
    [sym_page_keyword] = ACTIONS(5431),
    [anon_sym_codeunit] = ACTIONS(5431),
    [anon_sym_CODEUNIT] = ACTIONS(5431),
    [anon_sym_Codeunit] = ACTIONS(5431),
    [anon_sym_CodeUnit] = ACTIONS(5431),
    [anon_sym_COdeunit] = ACTIONS(5431),
    [anon_sym_codeUnit] = ACTIONS(5431),
    [sym_report_keyword] = ACTIONS(5431),
    [sym_query_keyword] = ACTIONS(5431),
    [anon_sym_xmlport] = ACTIONS(5431),
    [anon_sym_XMLPORT] = ACTIONS(5431),
    [anon_sym_Xmlport] = ACTIONS(5431),
    [anon_sym_XMLport] = ACTIONS(5431),
    [anon_sym_XMLPort] = ACTIONS(5431),
    [anon_sym_XmlPort] = ACTIONS(5431),
    [anon_sym_enum] = ACTIONS(5431),
    [anon_sym_ENUM] = ACTIONS(5431),
    [anon_sym_Enum] = ACTIONS(5431),
    [anon_sym_eNUM] = ACTIONS(5431),
    [anon_sym_eNum] = ACTIONS(5431),
    [anon_sym_ENum] = ACTIONS(5431),
    [sym_quoted_identifier] = ACTIONS(5433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5433),
    [sym_verbatim_string] = ACTIONS(5433),
    [sym_integer] = ACTIONS(5431),
    [sym_continue_as_identifier] = ACTIONS(5433),
    [sym_preproc_open] = ACTIONS(5433),
  },
  [STATE(2790)] = {
    [sym_else_keyword] = STATE(680),
    [sym_identifier] = ACTIONS(5481),
    [anon_sym_SEMI] = ACTIONS(5483),
    [anon_sym_DASH] = ACTIONS(5483),
    [aux_sym_boolean_token1] = ACTIONS(5481),
    [aux_sym_boolean_token2] = ACTIONS(5481),
    [sym_decimal] = ACTIONS(5481),
    [anon_sym_LPAREN] = ACTIONS(5483),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5481),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [aux_sym_record_type_token1] = ACTIONS(5481),
    [aux_sym_basic_type_token21] = ACTIONS(5481),
    [aux_sym_basic_type_token22] = ACTIONS(5481),
    [aux_sym_basic_type_token48] = ACTIONS(5481),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5481),
    [anon_sym_POUNDif] = ACTIONS(5483),
    [anon_sym_POUNDIF] = ACTIONS(5483),
    [anon_sym_POUNDIf] = ACTIONS(5483),
    [anon_sym_not] = ACTIONS(5481),
    [anon_sym_NOT] = ACTIONS(5481),
    [anon_sym_Not] = ACTIONS(5481),
    [anon_sym_POUNDelse] = ACTIONS(5483),
    [anon_sym_POUNDELSE] = ACTIONS(5483),
    [anon_sym_POUNDElse] = ACTIONS(5483),
    [anon_sym_POUNDelse2] = ACTIONS(5483),
    [anon_sym_POUNDELSE2] = ACTIONS(5483),
    [anon_sym_POUNDElse2] = ACTIONS(5483),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5481),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5481),
    [anon_sym_PLUS] = ACTIONS(5483),
    [sym_datetime_literal] = ACTIONS(5483),
    [sym_date_literal] = ACTIONS(5481),
    [sym_time_literal] = ACTIONS(5481),
    [sym_biginteger_literal] = ACTIONS(5483),
    [anon_sym_if] = ACTIONS(5481),
    [anon_sym_IF] = ACTIONS(5481),
    [anon_sym_If] = ACTIONS(5481),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5481),
    [anon_sym_CASE] = ACTIONS(5481),
    [anon_sym_Case] = ACTIONS(5481),
    [anon_sym_for] = ACTIONS(5481),
    [anon_sym_FOR] = ACTIONS(5481),
    [anon_sym_For] = ACTIONS(5481),
    [anon_sym_foreach] = ACTIONS(5481),
    [anon_sym_FOREACH] = ACTIONS(5481),
    [anon_sym_Foreach] = ACTIONS(5481),
    [anon_sym_while] = ACTIONS(5481),
    [anon_sym_WHILE] = ACTIONS(5481),
    [anon_sym_While] = ACTIONS(5481),
    [anon_sym_repeat] = ACTIONS(5481),
    [anon_sym_REPEAT] = ACTIONS(5481),
    [anon_sym_Repeat] = ACTIONS(5481),
    [anon_sym_until] = ACTIONS(5481),
    [anon_sym_UNTIL] = ACTIONS(5481),
    [anon_sym_Until] = ACTIONS(5481),
    [anon_sym_exit] = ACTIONS(5481),
    [anon_sym_EXIT] = ACTIONS(5481),
    [anon_sym_Exit] = ACTIONS(5481),
    [anon_sym_continue] = ACTIONS(5481),
    [anon_sym_CONTINUE] = ACTIONS(5481),
    [anon_sym_Continue] = ACTIONS(5481),
    [anon_sym_break] = ACTIONS(5481),
    [anon_sym_BREAK] = ACTIONS(5481),
    [anon_sym_Break] = ACTIONS(5481),
    [anon_sym_with] = ACTIONS(5481),
    [anon_sym_WITH] = ACTIONS(5481),
    [anon_sym_With] = ACTIONS(5481),
    [sym_asserterror_keyword] = ACTIONS(5483),
    [sym_page_keyword] = ACTIONS(5481),
    [anon_sym_codeunit] = ACTIONS(5481),
    [anon_sym_CODEUNIT] = ACTIONS(5481),
    [anon_sym_Codeunit] = ACTIONS(5481),
    [anon_sym_CodeUnit] = ACTIONS(5481),
    [anon_sym_COdeunit] = ACTIONS(5481),
    [anon_sym_codeUnit] = ACTIONS(5481),
    [sym_report_keyword] = ACTIONS(5481),
    [sym_query_keyword] = ACTIONS(5481),
    [anon_sym_xmlport] = ACTIONS(5481),
    [anon_sym_XMLPORT] = ACTIONS(5481),
    [anon_sym_Xmlport] = ACTIONS(5481),
    [anon_sym_XMLport] = ACTIONS(5481),
    [anon_sym_XMLPort] = ACTIONS(5481),
    [anon_sym_XmlPort] = ACTIONS(5481),
    [anon_sym_enum] = ACTIONS(5481),
    [anon_sym_ENUM] = ACTIONS(5481),
    [anon_sym_Enum] = ACTIONS(5481),
    [anon_sym_eNUM] = ACTIONS(5481),
    [anon_sym_eNum] = ACTIONS(5481),
    [anon_sym_ENum] = ACTIONS(5481),
    [sym_quoted_identifier] = ACTIONS(5483),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5483),
    [sym_verbatim_string] = ACTIONS(5483),
    [sym_integer] = ACTIONS(5481),
    [sym_continue_as_identifier] = ACTIONS(5483),
    [sym_preproc_open] = ACTIONS(5483),
  },
  [STATE(2791)] = {
    [sym_else_keyword] = STATE(685),
    [sym_identifier] = ACTIONS(5489),
    [anon_sym_SEMI] = ACTIONS(5491),
    [anon_sym_DASH] = ACTIONS(5491),
    [aux_sym_boolean_token1] = ACTIONS(5489),
    [aux_sym_boolean_token2] = ACTIONS(5489),
    [sym_decimal] = ACTIONS(5489),
    [anon_sym_LPAREN] = ACTIONS(5491),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5489),
    [anon_sym_LBRACK] = ACTIONS(5491),
    [aux_sym_record_type_token1] = ACTIONS(5489),
    [aux_sym_basic_type_token21] = ACTIONS(5489),
    [aux_sym_basic_type_token22] = ACTIONS(5489),
    [aux_sym_basic_type_token48] = ACTIONS(5489),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5489),
    [anon_sym_POUNDif] = ACTIONS(5491),
    [anon_sym_POUNDIF] = ACTIONS(5491),
    [anon_sym_POUNDIf] = ACTIONS(5491),
    [anon_sym_not] = ACTIONS(5489),
    [anon_sym_NOT] = ACTIONS(5489),
    [anon_sym_Not] = ACTIONS(5489),
    [anon_sym_POUNDelse] = ACTIONS(5491),
    [anon_sym_POUNDELSE] = ACTIONS(5491),
    [anon_sym_POUNDElse] = ACTIONS(5491),
    [anon_sym_POUNDelse2] = ACTIONS(5491),
    [anon_sym_POUNDELSE2] = ACTIONS(5491),
    [anon_sym_POUNDElse2] = ACTIONS(5491),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5489),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5489),
    [anon_sym_PLUS] = ACTIONS(5491),
    [sym_datetime_literal] = ACTIONS(5491),
    [sym_date_literal] = ACTIONS(5489),
    [sym_time_literal] = ACTIONS(5489),
    [sym_biginteger_literal] = ACTIONS(5491),
    [anon_sym_if] = ACTIONS(5489),
    [anon_sym_IF] = ACTIONS(5489),
    [anon_sym_If] = ACTIONS(5489),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5489),
    [anon_sym_CASE] = ACTIONS(5489),
    [anon_sym_Case] = ACTIONS(5489),
    [anon_sym_for] = ACTIONS(5489),
    [anon_sym_FOR] = ACTIONS(5489),
    [anon_sym_For] = ACTIONS(5489),
    [anon_sym_foreach] = ACTIONS(5489),
    [anon_sym_FOREACH] = ACTIONS(5489),
    [anon_sym_Foreach] = ACTIONS(5489),
    [anon_sym_while] = ACTIONS(5489),
    [anon_sym_WHILE] = ACTIONS(5489),
    [anon_sym_While] = ACTIONS(5489),
    [anon_sym_repeat] = ACTIONS(5489),
    [anon_sym_REPEAT] = ACTIONS(5489),
    [anon_sym_Repeat] = ACTIONS(5489),
    [anon_sym_until] = ACTIONS(5489),
    [anon_sym_UNTIL] = ACTIONS(5489),
    [anon_sym_Until] = ACTIONS(5489),
    [anon_sym_exit] = ACTIONS(5489),
    [anon_sym_EXIT] = ACTIONS(5489),
    [anon_sym_Exit] = ACTIONS(5489),
    [anon_sym_continue] = ACTIONS(5489),
    [anon_sym_CONTINUE] = ACTIONS(5489),
    [anon_sym_Continue] = ACTIONS(5489),
    [anon_sym_break] = ACTIONS(5489),
    [anon_sym_BREAK] = ACTIONS(5489),
    [anon_sym_Break] = ACTIONS(5489),
    [anon_sym_with] = ACTIONS(5489),
    [anon_sym_WITH] = ACTIONS(5489),
    [anon_sym_With] = ACTIONS(5489),
    [sym_asserterror_keyword] = ACTIONS(5491),
    [sym_page_keyword] = ACTIONS(5489),
    [anon_sym_codeunit] = ACTIONS(5489),
    [anon_sym_CODEUNIT] = ACTIONS(5489),
    [anon_sym_Codeunit] = ACTIONS(5489),
    [anon_sym_CodeUnit] = ACTIONS(5489),
    [anon_sym_COdeunit] = ACTIONS(5489),
    [anon_sym_codeUnit] = ACTIONS(5489),
    [sym_report_keyword] = ACTIONS(5489),
    [sym_query_keyword] = ACTIONS(5489),
    [anon_sym_xmlport] = ACTIONS(5489),
    [anon_sym_XMLPORT] = ACTIONS(5489),
    [anon_sym_Xmlport] = ACTIONS(5489),
    [anon_sym_XMLport] = ACTIONS(5489),
    [anon_sym_XMLPort] = ACTIONS(5489),
    [anon_sym_XmlPort] = ACTIONS(5489),
    [anon_sym_enum] = ACTIONS(5489),
    [anon_sym_ENUM] = ACTIONS(5489),
    [anon_sym_Enum] = ACTIONS(5489),
    [anon_sym_eNUM] = ACTIONS(5489),
    [anon_sym_eNum] = ACTIONS(5489),
    [anon_sym_ENum] = ACTIONS(5489),
    [sym_quoted_identifier] = ACTIONS(5491),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5491),
    [sym_verbatim_string] = ACTIONS(5491),
    [sym_integer] = ACTIONS(5489),
    [sym_continue_as_identifier] = ACTIONS(5491),
    [sym_preproc_open] = ACTIONS(5491),
  },
  [STATE(2792)] = {
    [sym_else_keyword] = STATE(686),
    [sym_identifier] = ACTIONS(5437),
    [anon_sym_SEMI] = ACTIONS(5439),
    [anon_sym_DASH] = ACTIONS(5439),
    [aux_sym_boolean_token1] = ACTIONS(5437),
    [aux_sym_boolean_token2] = ACTIONS(5437),
    [sym_decimal] = ACTIONS(5437),
    [anon_sym_LPAREN] = ACTIONS(5439),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5437),
    [anon_sym_LBRACK] = ACTIONS(5439),
    [aux_sym_record_type_token1] = ACTIONS(5437),
    [aux_sym_basic_type_token21] = ACTIONS(5437),
    [aux_sym_basic_type_token22] = ACTIONS(5437),
    [aux_sym_basic_type_token48] = ACTIONS(5437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5437),
    [anon_sym_POUNDif] = ACTIONS(5439),
    [anon_sym_POUNDIF] = ACTIONS(5439),
    [anon_sym_POUNDIf] = ACTIONS(5439),
    [anon_sym_not] = ACTIONS(5437),
    [anon_sym_NOT] = ACTIONS(5437),
    [anon_sym_Not] = ACTIONS(5437),
    [anon_sym_POUNDelse] = ACTIONS(5439),
    [anon_sym_POUNDELSE] = ACTIONS(5439),
    [anon_sym_POUNDElse] = ACTIONS(5439),
    [anon_sym_POUNDelse2] = ACTIONS(5439),
    [anon_sym_POUNDELSE2] = ACTIONS(5439),
    [anon_sym_POUNDElse2] = ACTIONS(5439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5437),
    [anon_sym_PLUS] = ACTIONS(5439),
    [sym_datetime_literal] = ACTIONS(5439),
    [sym_date_literal] = ACTIONS(5437),
    [sym_time_literal] = ACTIONS(5437),
    [sym_biginteger_literal] = ACTIONS(5439),
    [anon_sym_if] = ACTIONS(5437),
    [anon_sym_IF] = ACTIONS(5437),
    [anon_sym_If] = ACTIONS(5437),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5437),
    [anon_sym_CASE] = ACTIONS(5437),
    [anon_sym_Case] = ACTIONS(5437),
    [anon_sym_for] = ACTIONS(5437),
    [anon_sym_FOR] = ACTIONS(5437),
    [anon_sym_For] = ACTIONS(5437),
    [anon_sym_foreach] = ACTIONS(5437),
    [anon_sym_FOREACH] = ACTIONS(5437),
    [anon_sym_Foreach] = ACTIONS(5437),
    [anon_sym_while] = ACTIONS(5437),
    [anon_sym_WHILE] = ACTIONS(5437),
    [anon_sym_While] = ACTIONS(5437),
    [anon_sym_repeat] = ACTIONS(5437),
    [anon_sym_REPEAT] = ACTIONS(5437),
    [anon_sym_Repeat] = ACTIONS(5437),
    [anon_sym_until] = ACTIONS(5437),
    [anon_sym_UNTIL] = ACTIONS(5437),
    [anon_sym_Until] = ACTIONS(5437),
    [anon_sym_exit] = ACTIONS(5437),
    [anon_sym_EXIT] = ACTIONS(5437),
    [anon_sym_Exit] = ACTIONS(5437),
    [anon_sym_continue] = ACTIONS(5437),
    [anon_sym_CONTINUE] = ACTIONS(5437),
    [anon_sym_Continue] = ACTIONS(5437),
    [anon_sym_break] = ACTIONS(5437),
    [anon_sym_BREAK] = ACTIONS(5437),
    [anon_sym_Break] = ACTIONS(5437),
    [anon_sym_with] = ACTIONS(5437),
    [anon_sym_WITH] = ACTIONS(5437),
    [anon_sym_With] = ACTIONS(5437),
    [sym_asserterror_keyword] = ACTIONS(5439),
    [sym_page_keyword] = ACTIONS(5437),
    [anon_sym_codeunit] = ACTIONS(5437),
    [anon_sym_CODEUNIT] = ACTIONS(5437),
    [anon_sym_Codeunit] = ACTIONS(5437),
    [anon_sym_CodeUnit] = ACTIONS(5437),
    [anon_sym_COdeunit] = ACTIONS(5437),
    [anon_sym_codeUnit] = ACTIONS(5437),
    [sym_report_keyword] = ACTIONS(5437),
    [sym_query_keyword] = ACTIONS(5437),
    [anon_sym_xmlport] = ACTIONS(5437),
    [anon_sym_XMLPORT] = ACTIONS(5437),
    [anon_sym_Xmlport] = ACTIONS(5437),
    [anon_sym_XMLport] = ACTIONS(5437),
    [anon_sym_XMLPort] = ACTIONS(5437),
    [anon_sym_XmlPort] = ACTIONS(5437),
    [anon_sym_enum] = ACTIONS(5437),
    [anon_sym_ENUM] = ACTIONS(5437),
    [anon_sym_Enum] = ACTIONS(5437),
    [anon_sym_eNUM] = ACTIONS(5437),
    [anon_sym_eNum] = ACTIONS(5437),
    [anon_sym_ENum] = ACTIONS(5437),
    [sym_quoted_identifier] = ACTIONS(5439),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5439),
    [sym_verbatim_string] = ACTIONS(5439),
    [sym_integer] = ACTIONS(5437),
    [sym_continue_as_identifier] = ACTIONS(5439),
    [sym_preproc_open] = ACTIONS(5439),
  },
  [STATE(2793)] = {
    [anon_sym_POUNDif] = ACTIONS(6919),
    [anon_sym_POUNDIF] = ACTIONS(6919),
    [anon_sym_POUNDIf] = ACTIONS(6919),
    [anon_sym_POUNDelif] = ACTIONS(6919),
    [anon_sym_POUNDELIF] = ACTIONS(6919),
    [anon_sym_POUNDElif] = ACTIONS(6919),
    [anon_sym_POUNDelse] = ACTIONS(6919),
    [anon_sym_POUNDELSE] = ACTIONS(6919),
    [anon_sym_POUNDElse] = ACTIONS(6919),
    [anon_sym_POUNDelse2] = ACTIONS(6919),
    [anon_sym_POUNDELSE2] = ACTIONS(6919),
    [anon_sym_POUNDElse2] = ACTIONS(6919),
    [anon_sym_POUNDendif] = ACTIONS(6919),
    [anon_sym_POUNDENDIF] = ACTIONS(6919),
    [anon_sym_POUNDEndif] = ACTIONS(6919),
    [anon_sym_POUNDendif2] = ACTIONS(6919),
    [anon_sym_POUNDENDIF2] = ACTIONS(6919),
    [anon_sym_POUNDEndif2] = ACTIONS(6919),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6921),
    [anon_sym_tableextension] = ACTIONS(6919),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6919),
    [anon_sym_Tableextension] = ACTIONS(6919),
    [anon_sym_TableExtension] = ACTIONS(6919),
    [anon_sym_tableExtension] = ACTIONS(6919),
    [sym_page_keyword] = ACTIONS(6921),
    [anon_sym_pageextension] = ACTIONS(6919),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6919),
    [anon_sym_Pageextension] = ACTIONS(6919),
    [anon_sym_PageExtension] = ACTIONS(6919),
    [anon_sym_pageExtension] = ACTIONS(6919),
    [anon_sym_codeunit] = ACTIONS(6919),
    [anon_sym_CODEUNIT] = ACTIONS(6919),
    [anon_sym_Codeunit] = ACTIONS(6919),
    [anon_sym_CodeUnit] = ACTIONS(6919),
    [anon_sym_COdeunit] = ACTIONS(6919),
    [anon_sym_codeUnit] = ACTIONS(6919),
    [sym_report_keyword] = ACTIONS(6921),
    [anon_sym_reportextension] = ACTIONS(6919),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6919),
    [anon_sym_Reportextension] = ACTIONS(6919),
    [anon_sym_ReportExtension] = ACTIONS(6919),
    [anon_sym_reportExtension] = ACTIONS(6919),
    [sym_query_keyword] = ACTIONS(6919),
    [anon_sym_xmlport] = ACTIONS(6919),
    [anon_sym_XMLPORT] = ACTIONS(6919),
    [anon_sym_Xmlport] = ACTIONS(6919),
    [anon_sym_XMLport] = ACTIONS(6919),
    [anon_sym_XMLPort] = ACTIONS(6919),
    [anon_sym_XmlPort] = ACTIONS(6919),
    [anon_sym_enum] = ACTIONS(6921),
    [anon_sym_ENUM] = ACTIONS(6921),
    [anon_sym_Enum] = ACTIONS(6921),
    [anon_sym_eNUM] = ACTIONS(6919),
    [anon_sym_eNum] = ACTIONS(6919),
    [anon_sym_ENum] = ACTIONS(6919),
    [anon_sym_enumextension] = ACTIONS(6919),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6919),
    [anon_sym_Enumextension] = ACTIONS(6919),
    [anon_sym_EnumExtension] = ACTIONS(6919),
    [anon_sym_enumExtension] = ACTIONS(6919),
    [sym_interface_keyword] = ACTIONS(6919),
    [anon_sym_controladdin] = ACTIONS(6919),
    [anon_sym_CONTROLADDIN] = ACTIONS(6919),
    [anon_sym_Controladdin] = ACTIONS(6919),
    [anon_sym_ControlAddIn] = ACTIONS(6919),
    [anon_sym_ControlAddin] = ACTIONS(6919),
    [anon_sym_controlAddIn] = ACTIONS(6919),
    [anon_sym_controlAddin] = ACTIONS(6919),
    [anon_sym_dotnet] = ACTIONS(6919),
    [anon_sym_DOTNET] = ACTIONS(6919),
    [anon_sym_Dotnet] = ACTIONS(6919),
    [anon_sym_DotNet] = ACTIONS(6919),
    [anon_sym_dotNet] = ACTIONS(6919),
    [sym_profile_keyword] = ACTIONS(6921),
    [anon_sym_profileextension] = ACTIONS(6919),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6919),
    [anon_sym_Profileextension] = ACTIONS(6919),
    [anon_sym_ProfileExtension] = ACTIONS(6919),
    [anon_sym_profileExtension] = ACTIONS(6919),
    [anon_sym_permissionset] = ACTIONS(6921),
    [anon_sym_PERMISSIONSET] = ACTIONS(6921),
    [anon_sym_Permissionset] = ACTIONS(6921),
    [anon_sym_PermissionSet] = ACTIONS(6921),
    [anon_sym_permissionSet] = ACTIONS(6921),
    [anon_sym_permissionsetextension] = ACTIONS(6919),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6919),
    [anon_sym_Permissionsetextension] = ACTIONS(6919),
    [anon_sym_PermissionSetExtension] = ACTIONS(6919),
    [anon_sym_permissionSetExtension] = ACTIONS(6919),
    [sym_entitlement_keyword] = ACTIONS(6919),
    [anon_sym_pagecustomization] = ACTIONS(6919),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6919),
    [anon_sym_Pagecustomization] = ACTIONS(6919),
    [anon_sym_PageCustomization] = ACTIONS(6919),
    [anon_sym_pageCustomization] = ACTIONS(6919),
    [sym_using_keyword] = ACTIONS(6919),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6919),
    [sym_preproc_close] = ACTIONS(6919),
  },
  [STATE(2794)] = {
    [anon_sym_POUNDif] = ACTIONS(6923),
    [anon_sym_POUNDIF] = ACTIONS(6923),
    [anon_sym_POUNDIf] = ACTIONS(6923),
    [anon_sym_POUNDelif] = ACTIONS(6923),
    [anon_sym_POUNDELIF] = ACTIONS(6923),
    [anon_sym_POUNDElif] = ACTIONS(6923),
    [anon_sym_POUNDelse] = ACTIONS(6923),
    [anon_sym_POUNDELSE] = ACTIONS(6923),
    [anon_sym_POUNDElse] = ACTIONS(6923),
    [anon_sym_POUNDelse2] = ACTIONS(6923),
    [anon_sym_POUNDELSE2] = ACTIONS(6923),
    [anon_sym_POUNDElse2] = ACTIONS(6923),
    [anon_sym_POUNDendif] = ACTIONS(6923),
    [anon_sym_POUNDENDIF] = ACTIONS(6923),
    [anon_sym_POUNDEndif] = ACTIONS(6923),
    [anon_sym_POUNDendif2] = ACTIONS(6923),
    [anon_sym_POUNDENDIF2] = ACTIONS(6923),
    [anon_sym_POUNDEndif2] = ACTIONS(6923),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6925),
    [anon_sym_tableextension] = ACTIONS(6923),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6923),
    [anon_sym_Tableextension] = ACTIONS(6923),
    [anon_sym_TableExtension] = ACTIONS(6923),
    [anon_sym_tableExtension] = ACTIONS(6923),
    [sym_page_keyword] = ACTIONS(6925),
    [anon_sym_pageextension] = ACTIONS(6923),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6923),
    [anon_sym_Pageextension] = ACTIONS(6923),
    [anon_sym_PageExtension] = ACTIONS(6923),
    [anon_sym_pageExtension] = ACTIONS(6923),
    [anon_sym_codeunit] = ACTIONS(6923),
    [anon_sym_CODEUNIT] = ACTIONS(6923),
    [anon_sym_Codeunit] = ACTIONS(6923),
    [anon_sym_CodeUnit] = ACTIONS(6923),
    [anon_sym_COdeunit] = ACTIONS(6923),
    [anon_sym_codeUnit] = ACTIONS(6923),
    [sym_report_keyword] = ACTIONS(6925),
    [anon_sym_reportextension] = ACTIONS(6923),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6923),
    [anon_sym_Reportextension] = ACTIONS(6923),
    [anon_sym_ReportExtension] = ACTIONS(6923),
    [anon_sym_reportExtension] = ACTIONS(6923),
    [sym_query_keyword] = ACTIONS(6923),
    [anon_sym_xmlport] = ACTIONS(6923),
    [anon_sym_XMLPORT] = ACTIONS(6923),
    [anon_sym_Xmlport] = ACTIONS(6923),
    [anon_sym_XMLport] = ACTIONS(6923),
    [anon_sym_XMLPort] = ACTIONS(6923),
    [anon_sym_XmlPort] = ACTIONS(6923),
    [anon_sym_enum] = ACTIONS(6925),
    [anon_sym_ENUM] = ACTIONS(6925),
    [anon_sym_Enum] = ACTIONS(6925),
    [anon_sym_eNUM] = ACTIONS(6923),
    [anon_sym_eNum] = ACTIONS(6923),
    [anon_sym_ENum] = ACTIONS(6923),
    [anon_sym_enumextension] = ACTIONS(6923),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6923),
    [anon_sym_Enumextension] = ACTIONS(6923),
    [anon_sym_EnumExtension] = ACTIONS(6923),
    [anon_sym_enumExtension] = ACTIONS(6923),
    [sym_interface_keyword] = ACTIONS(6923),
    [anon_sym_controladdin] = ACTIONS(6923),
    [anon_sym_CONTROLADDIN] = ACTIONS(6923),
    [anon_sym_Controladdin] = ACTIONS(6923),
    [anon_sym_ControlAddIn] = ACTIONS(6923),
    [anon_sym_ControlAddin] = ACTIONS(6923),
    [anon_sym_controlAddIn] = ACTIONS(6923),
    [anon_sym_controlAddin] = ACTIONS(6923),
    [anon_sym_dotnet] = ACTIONS(6923),
    [anon_sym_DOTNET] = ACTIONS(6923),
    [anon_sym_Dotnet] = ACTIONS(6923),
    [anon_sym_DotNet] = ACTIONS(6923),
    [anon_sym_dotNet] = ACTIONS(6923),
    [sym_profile_keyword] = ACTIONS(6925),
    [anon_sym_profileextension] = ACTIONS(6923),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6923),
    [anon_sym_Profileextension] = ACTIONS(6923),
    [anon_sym_ProfileExtension] = ACTIONS(6923),
    [anon_sym_profileExtension] = ACTIONS(6923),
    [anon_sym_permissionset] = ACTIONS(6925),
    [anon_sym_PERMISSIONSET] = ACTIONS(6925),
    [anon_sym_Permissionset] = ACTIONS(6925),
    [anon_sym_PermissionSet] = ACTIONS(6925),
    [anon_sym_permissionSet] = ACTIONS(6925),
    [anon_sym_permissionsetextension] = ACTIONS(6923),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6923),
    [anon_sym_Permissionsetextension] = ACTIONS(6923),
    [anon_sym_PermissionSetExtension] = ACTIONS(6923),
    [anon_sym_permissionSetExtension] = ACTIONS(6923),
    [sym_entitlement_keyword] = ACTIONS(6923),
    [anon_sym_pagecustomization] = ACTIONS(6923),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6923),
    [anon_sym_Pagecustomization] = ACTIONS(6923),
    [anon_sym_PageCustomization] = ACTIONS(6923),
    [anon_sym_pageCustomization] = ACTIONS(6923),
    [sym_using_keyword] = ACTIONS(6923),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6923),
    [sym_preproc_close] = ACTIONS(6923),
  },
  [STATE(2795)] = {
    [anon_sym_POUNDif] = ACTIONS(6927),
    [anon_sym_POUNDIF] = ACTIONS(6927),
    [anon_sym_POUNDIf] = ACTIONS(6927),
    [anon_sym_POUNDelif] = ACTIONS(6927),
    [anon_sym_POUNDELIF] = ACTIONS(6927),
    [anon_sym_POUNDElif] = ACTIONS(6927),
    [anon_sym_POUNDelse] = ACTIONS(6927),
    [anon_sym_POUNDELSE] = ACTIONS(6927),
    [anon_sym_POUNDElse] = ACTIONS(6927),
    [anon_sym_POUNDelse2] = ACTIONS(6927),
    [anon_sym_POUNDELSE2] = ACTIONS(6927),
    [anon_sym_POUNDElse2] = ACTIONS(6927),
    [anon_sym_POUNDendif] = ACTIONS(6927),
    [anon_sym_POUNDENDIF] = ACTIONS(6927),
    [anon_sym_POUNDEndif] = ACTIONS(6927),
    [anon_sym_POUNDendif2] = ACTIONS(6927),
    [anon_sym_POUNDENDIF2] = ACTIONS(6927),
    [anon_sym_POUNDEndif2] = ACTIONS(6927),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6929),
    [anon_sym_tableextension] = ACTIONS(6927),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6927),
    [anon_sym_Tableextension] = ACTIONS(6927),
    [anon_sym_TableExtension] = ACTIONS(6927),
    [anon_sym_tableExtension] = ACTIONS(6927),
    [sym_page_keyword] = ACTIONS(6929),
    [anon_sym_pageextension] = ACTIONS(6927),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6927),
    [anon_sym_Pageextension] = ACTIONS(6927),
    [anon_sym_PageExtension] = ACTIONS(6927),
    [anon_sym_pageExtension] = ACTIONS(6927),
    [anon_sym_codeunit] = ACTIONS(6927),
    [anon_sym_CODEUNIT] = ACTIONS(6927),
    [anon_sym_Codeunit] = ACTIONS(6927),
    [anon_sym_CodeUnit] = ACTIONS(6927),
    [anon_sym_COdeunit] = ACTIONS(6927),
    [anon_sym_codeUnit] = ACTIONS(6927),
    [sym_report_keyword] = ACTIONS(6929),
    [anon_sym_reportextension] = ACTIONS(6927),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6927),
    [anon_sym_Reportextension] = ACTIONS(6927),
    [anon_sym_ReportExtension] = ACTIONS(6927),
    [anon_sym_reportExtension] = ACTIONS(6927),
    [sym_query_keyword] = ACTIONS(6927),
    [anon_sym_xmlport] = ACTIONS(6927),
    [anon_sym_XMLPORT] = ACTIONS(6927),
    [anon_sym_Xmlport] = ACTIONS(6927),
    [anon_sym_XMLport] = ACTIONS(6927),
    [anon_sym_XMLPort] = ACTIONS(6927),
    [anon_sym_XmlPort] = ACTIONS(6927),
    [anon_sym_enum] = ACTIONS(6929),
    [anon_sym_ENUM] = ACTIONS(6929),
    [anon_sym_Enum] = ACTIONS(6929),
    [anon_sym_eNUM] = ACTIONS(6927),
    [anon_sym_eNum] = ACTIONS(6927),
    [anon_sym_ENum] = ACTIONS(6927),
    [anon_sym_enumextension] = ACTIONS(6927),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6927),
    [anon_sym_Enumextension] = ACTIONS(6927),
    [anon_sym_EnumExtension] = ACTIONS(6927),
    [anon_sym_enumExtension] = ACTIONS(6927),
    [sym_interface_keyword] = ACTIONS(6927),
    [anon_sym_controladdin] = ACTIONS(6927),
    [anon_sym_CONTROLADDIN] = ACTIONS(6927),
    [anon_sym_Controladdin] = ACTIONS(6927),
    [anon_sym_ControlAddIn] = ACTIONS(6927),
    [anon_sym_ControlAddin] = ACTIONS(6927),
    [anon_sym_controlAddIn] = ACTIONS(6927),
    [anon_sym_controlAddin] = ACTIONS(6927),
    [anon_sym_dotnet] = ACTIONS(6927),
    [anon_sym_DOTNET] = ACTIONS(6927),
    [anon_sym_Dotnet] = ACTIONS(6927),
    [anon_sym_DotNet] = ACTIONS(6927),
    [anon_sym_dotNet] = ACTIONS(6927),
    [sym_profile_keyword] = ACTIONS(6929),
    [anon_sym_profileextension] = ACTIONS(6927),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6927),
    [anon_sym_Profileextension] = ACTIONS(6927),
    [anon_sym_ProfileExtension] = ACTIONS(6927),
    [anon_sym_profileExtension] = ACTIONS(6927),
    [anon_sym_permissionset] = ACTIONS(6929),
    [anon_sym_PERMISSIONSET] = ACTIONS(6929),
    [anon_sym_Permissionset] = ACTIONS(6929),
    [anon_sym_PermissionSet] = ACTIONS(6929),
    [anon_sym_permissionSet] = ACTIONS(6929),
    [anon_sym_permissionsetextension] = ACTIONS(6927),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6927),
    [anon_sym_Permissionsetextension] = ACTIONS(6927),
    [anon_sym_PermissionSetExtension] = ACTIONS(6927),
    [anon_sym_permissionSetExtension] = ACTIONS(6927),
    [sym_entitlement_keyword] = ACTIONS(6927),
    [anon_sym_pagecustomization] = ACTIONS(6927),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6927),
    [anon_sym_Pagecustomization] = ACTIONS(6927),
    [anon_sym_PageCustomization] = ACTIONS(6927),
    [anon_sym_pageCustomization] = ACTIONS(6927),
    [sym_using_keyword] = ACTIONS(6927),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6927),
    [sym_preproc_close] = ACTIONS(6927),
  },
  [STATE(2796)] = {
    [anon_sym_POUNDif] = ACTIONS(6931),
    [anon_sym_POUNDIF] = ACTIONS(6931),
    [anon_sym_POUNDIf] = ACTIONS(6931),
    [anon_sym_POUNDelif] = ACTIONS(6931),
    [anon_sym_POUNDELIF] = ACTIONS(6931),
    [anon_sym_POUNDElif] = ACTIONS(6931),
    [anon_sym_POUNDelse] = ACTIONS(6931),
    [anon_sym_POUNDELSE] = ACTIONS(6931),
    [anon_sym_POUNDElse] = ACTIONS(6931),
    [anon_sym_POUNDelse2] = ACTIONS(6931),
    [anon_sym_POUNDELSE2] = ACTIONS(6931),
    [anon_sym_POUNDElse2] = ACTIONS(6931),
    [anon_sym_POUNDendif] = ACTIONS(6931),
    [anon_sym_POUNDENDIF] = ACTIONS(6931),
    [anon_sym_POUNDEndif] = ACTIONS(6931),
    [anon_sym_POUNDendif2] = ACTIONS(6931),
    [anon_sym_POUNDENDIF2] = ACTIONS(6931),
    [anon_sym_POUNDEndif2] = ACTIONS(6931),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6933),
    [anon_sym_tableextension] = ACTIONS(6931),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6931),
    [anon_sym_Tableextension] = ACTIONS(6931),
    [anon_sym_TableExtension] = ACTIONS(6931),
    [anon_sym_tableExtension] = ACTIONS(6931),
    [sym_page_keyword] = ACTIONS(6933),
    [anon_sym_pageextension] = ACTIONS(6931),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6931),
    [anon_sym_Pageextension] = ACTIONS(6931),
    [anon_sym_PageExtension] = ACTIONS(6931),
    [anon_sym_pageExtension] = ACTIONS(6931),
    [anon_sym_codeunit] = ACTIONS(6931),
    [anon_sym_CODEUNIT] = ACTIONS(6931),
    [anon_sym_Codeunit] = ACTIONS(6931),
    [anon_sym_CodeUnit] = ACTIONS(6931),
    [anon_sym_COdeunit] = ACTIONS(6931),
    [anon_sym_codeUnit] = ACTIONS(6931),
    [sym_report_keyword] = ACTIONS(6933),
    [anon_sym_reportextension] = ACTIONS(6931),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6931),
    [anon_sym_Reportextension] = ACTIONS(6931),
    [anon_sym_ReportExtension] = ACTIONS(6931),
    [anon_sym_reportExtension] = ACTIONS(6931),
    [sym_query_keyword] = ACTIONS(6931),
    [anon_sym_xmlport] = ACTIONS(6931),
    [anon_sym_XMLPORT] = ACTIONS(6931),
    [anon_sym_Xmlport] = ACTIONS(6931),
    [anon_sym_XMLport] = ACTIONS(6931),
    [anon_sym_XMLPort] = ACTIONS(6931),
    [anon_sym_XmlPort] = ACTIONS(6931),
    [anon_sym_enum] = ACTIONS(6933),
    [anon_sym_ENUM] = ACTIONS(6933),
    [anon_sym_Enum] = ACTIONS(6933),
    [anon_sym_eNUM] = ACTIONS(6931),
    [anon_sym_eNum] = ACTIONS(6931),
    [anon_sym_ENum] = ACTIONS(6931),
    [anon_sym_enumextension] = ACTIONS(6931),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6931),
    [anon_sym_Enumextension] = ACTIONS(6931),
    [anon_sym_EnumExtension] = ACTIONS(6931),
    [anon_sym_enumExtension] = ACTIONS(6931),
    [sym_interface_keyword] = ACTIONS(6931),
    [anon_sym_controladdin] = ACTIONS(6931),
    [anon_sym_CONTROLADDIN] = ACTIONS(6931),
    [anon_sym_Controladdin] = ACTIONS(6931),
    [anon_sym_ControlAddIn] = ACTIONS(6931),
    [anon_sym_ControlAddin] = ACTIONS(6931),
    [anon_sym_controlAddIn] = ACTIONS(6931),
    [anon_sym_controlAddin] = ACTIONS(6931),
    [anon_sym_dotnet] = ACTIONS(6931),
    [anon_sym_DOTNET] = ACTIONS(6931),
    [anon_sym_Dotnet] = ACTIONS(6931),
    [anon_sym_DotNet] = ACTIONS(6931),
    [anon_sym_dotNet] = ACTIONS(6931),
    [sym_profile_keyword] = ACTIONS(6933),
    [anon_sym_profileextension] = ACTIONS(6931),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6931),
    [anon_sym_Profileextension] = ACTIONS(6931),
    [anon_sym_ProfileExtension] = ACTIONS(6931),
    [anon_sym_profileExtension] = ACTIONS(6931),
    [anon_sym_permissionset] = ACTIONS(6933),
    [anon_sym_PERMISSIONSET] = ACTIONS(6933),
    [anon_sym_Permissionset] = ACTIONS(6933),
    [anon_sym_PermissionSet] = ACTIONS(6933),
    [anon_sym_permissionSet] = ACTIONS(6933),
    [anon_sym_permissionsetextension] = ACTIONS(6931),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6931),
    [anon_sym_Permissionsetextension] = ACTIONS(6931),
    [anon_sym_PermissionSetExtension] = ACTIONS(6931),
    [anon_sym_permissionSetExtension] = ACTIONS(6931),
    [sym_entitlement_keyword] = ACTIONS(6931),
    [anon_sym_pagecustomization] = ACTIONS(6931),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6931),
    [anon_sym_Pagecustomization] = ACTIONS(6931),
    [anon_sym_PageCustomization] = ACTIONS(6931),
    [anon_sym_pageCustomization] = ACTIONS(6931),
    [sym_using_keyword] = ACTIONS(6931),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6931),
    [sym_preproc_close] = ACTIONS(6931),
  },
  [STATE(2797)] = {
    [anon_sym_POUNDif] = ACTIONS(6935),
    [anon_sym_POUNDIF] = ACTIONS(6935),
    [anon_sym_POUNDIf] = ACTIONS(6935),
    [anon_sym_POUNDelif] = ACTIONS(6935),
    [anon_sym_POUNDELIF] = ACTIONS(6935),
    [anon_sym_POUNDElif] = ACTIONS(6935),
    [anon_sym_POUNDelse] = ACTIONS(6935),
    [anon_sym_POUNDELSE] = ACTIONS(6935),
    [anon_sym_POUNDElse] = ACTIONS(6935),
    [anon_sym_POUNDelse2] = ACTIONS(6935),
    [anon_sym_POUNDELSE2] = ACTIONS(6935),
    [anon_sym_POUNDElse2] = ACTIONS(6935),
    [anon_sym_POUNDendif] = ACTIONS(6935),
    [anon_sym_POUNDENDIF] = ACTIONS(6935),
    [anon_sym_POUNDEndif] = ACTIONS(6935),
    [anon_sym_POUNDendif2] = ACTIONS(6935),
    [anon_sym_POUNDENDIF2] = ACTIONS(6935),
    [anon_sym_POUNDEndif2] = ACTIONS(6935),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6937),
    [anon_sym_tableextension] = ACTIONS(6935),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6935),
    [anon_sym_Tableextension] = ACTIONS(6935),
    [anon_sym_TableExtension] = ACTIONS(6935),
    [anon_sym_tableExtension] = ACTIONS(6935),
    [sym_page_keyword] = ACTIONS(6937),
    [anon_sym_pageextension] = ACTIONS(6935),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6935),
    [anon_sym_Pageextension] = ACTIONS(6935),
    [anon_sym_PageExtension] = ACTIONS(6935),
    [anon_sym_pageExtension] = ACTIONS(6935),
    [anon_sym_codeunit] = ACTIONS(6935),
    [anon_sym_CODEUNIT] = ACTIONS(6935),
    [anon_sym_Codeunit] = ACTIONS(6935),
    [anon_sym_CodeUnit] = ACTIONS(6935),
    [anon_sym_COdeunit] = ACTIONS(6935),
    [anon_sym_codeUnit] = ACTIONS(6935),
    [sym_report_keyword] = ACTIONS(6937),
    [anon_sym_reportextension] = ACTIONS(6935),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6935),
    [anon_sym_Reportextension] = ACTIONS(6935),
    [anon_sym_ReportExtension] = ACTIONS(6935),
    [anon_sym_reportExtension] = ACTIONS(6935),
    [sym_query_keyword] = ACTIONS(6935),
    [anon_sym_xmlport] = ACTIONS(6935),
    [anon_sym_XMLPORT] = ACTIONS(6935),
    [anon_sym_Xmlport] = ACTIONS(6935),
    [anon_sym_XMLport] = ACTIONS(6935),
    [anon_sym_XMLPort] = ACTIONS(6935),
    [anon_sym_XmlPort] = ACTIONS(6935),
    [anon_sym_enum] = ACTIONS(6937),
    [anon_sym_ENUM] = ACTIONS(6937),
    [anon_sym_Enum] = ACTIONS(6937),
    [anon_sym_eNUM] = ACTIONS(6935),
    [anon_sym_eNum] = ACTIONS(6935),
    [anon_sym_ENum] = ACTIONS(6935),
    [anon_sym_enumextension] = ACTIONS(6935),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6935),
    [anon_sym_Enumextension] = ACTIONS(6935),
    [anon_sym_EnumExtension] = ACTIONS(6935),
    [anon_sym_enumExtension] = ACTIONS(6935),
    [sym_interface_keyword] = ACTIONS(6935),
    [anon_sym_controladdin] = ACTIONS(6935),
    [anon_sym_CONTROLADDIN] = ACTIONS(6935),
    [anon_sym_Controladdin] = ACTIONS(6935),
    [anon_sym_ControlAddIn] = ACTIONS(6935),
    [anon_sym_ControlAddin] = ACTIONS(6935),
    [anon_sym_controlAddIn] = ACTIONS(6935),
    [anon_sym_controlAddin] = ACTIONS(6935),
    [anon_sym_dotnet] = ACTIONS(6935),
    [anon_sym_DOTNET] = ACTIONS(6935),
    [anon_sym_Dotnet] = ACTIONS(6935),
    [anon_sym_DotNet] = ACTIONS(6935),
    [anon_sym_dotNet] = ACTIONS(6935),
    [sym_profile_keyword] = ACTIONS(6937),
    [anon_sym_profileextension] = ACTIONS(6935),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6935),
    [anon_sym_Profileextension] = ACTIONS(6935),
    [anon_sym_ProfileExtension] = ACTIONS(6935),
    [anon_sym_profileExtension] = ACTIONS(6935),
    [anon_sym_permissionset] = ACTIONS(6937),
    [anon_sym_PERMISSIONSET] = ACTIONS(6937),
    [anon_sym_Permissionset] = ACTIONS(6937),
    [anon_sym_PermissionSet] = ACTIONS(6937),
    [anon_sym_permissionSet] = ACTIONS(6937),
    [anon_sym_permissionsetextension] = ACTIONS(6935),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6935),
    [anon_sym_Permissionsetextension] = ACTIONS(6935),
    [anon_sym_PermissionSetExtension] = ACTIONS(6935),
    [anon_sym_permissionSetExtension] = ACTIONS(6935),
    [sym_entitlement_keyword] = ACTIONS(6935),
    [anon_sym_pagecustomization] = ACTIONS(6935),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6935),
    [anon_sym_Pagecustomization] = ACTIONS(6935),
    [anon_sym_PageCustomization] = ACTIONS(6935),
    [anon_sym_pageCustomization] = ACTIONS(6935),
    [sym_using_keyword] = ACTIONS(6935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6935),
    [sym_preproc_close] = ACTIONS(6935),
  },
  [STATE(2798)] = {
    [anon_sym_POUNDif] = ACTIONS(6939),
    [anon_sym_POUNDIF] = ACTIONS(6939),
    [anon_sym_POUNDIf] = ACTIONS(6939),
    [anon_sym_POUNDelif] = ACTIONS(6939),
    [anon_sym_POUNDELIF] = ACTIONS(6939),
    [anon_sym_POUNDElif] = ACTIONS(6939),
    [anon_sym_POUNDelse] = ACTIONS(6939),
    [anon_sym_POUNDELSE] = ACTIONS(6939),
    [anon_sym_POUNDElse] = ACTIONS(6939),
    [anon_sym_POUNDelse2] = ACTIONS(6939),
    [anon_sym_POUNDELSE2] = ACTIONS(6939),
    [anon_sym_POUNDElse2] = ACTIONS(6939),
    [anon_sym_POUNDendif] = ACTIONS(6939),
    [anon_sym_POUNDENDIF] = ACTIONS(6939),
    [anon_sym_POUNDEndif] = ACTIONS(6939),
    [anon_sym_POUNDendif2] = ACTIONS(6939),
    [anon_sym_POUNDENDIF2] = ACTIONS(6939),
    [anon_sym_POUNDEndif2] = ACTIONS(6939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6941),
    [anon_sym_tableextension] = ACTIONS(6939),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6939),
    [anon_sym_Tableextension] = ACTIONS(6939),
    [anon_sym_TableExtension] = ACTIONS(6939),
    [anon_sym_tableExtension] = ACTIONS(6939),
    [sym_page_keyword] = ACTIONS(6941),
    [anon_sym_pageextension] = ACTIONS(6939),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6939),
    [anon_sym_Pageextension] = ACTIONS(6939),
    [anon_sym_PageExtension] = ACTIONS(6939),
    [anon_sym_pageExtension] = ACTIONS(6939),
    [anon_sym_codeunit] = ACTIONS(6939),
    [anon_sym_CODEUNIT] = ACTIONS(6939),
    [anon_sym_Codeunit] = ACTIONS(6939),
    [anon_sym_CodeUnit] = ACTIONS(6939),
    [anon_sym_COdeunit] = ACTIONS(6939),
    [anon_sym_codeUnit] = ACTIONS(6939),
    [sym_report_keyword] = ACTIONS(6941),
    [anon_sym_reportextension] = ACTIONS(6939),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6939),
    [anon_sym_Reportextension] = ACTIONS(6939),
    [anon_sym_ReportExtension] = ACTIONS(6939),
    [anon_sym_reportExtension] = ACTIONS(6939),
    [sym_query_keyword] = ACTIONS(6939),
    [anon_sym_xmlport] = ACTIONS(6939),
    [anon_sym_XMLPORT] = ACTIONS(6939),
    [anon_sym_Xmlport] = ACTIONS(6939),
    [anon_sym_XMLport] = ACTIONS(6939),
    [anon_sym_XMLPort] = ACTIONS(6939),
    [anon_sym_XmlPort] = ACTIONS(6939),
    [anon_sym_enum] = ACTIONS(6941),
    [anon_sym_ENUM] = ACTIONS(6941),
    [anon_sym_Enum] = ACTIONS(6941),
    [anon_sym_eNUM] = ACTIONS(6939),
    [anon_sym_eNum] = ACTIONS(6939),
    [anon_sym_ENum] = ACTIONS(6939),
    [anon_sym_enumextension] = ACTIONS(6939),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6939),
    [anon_sym_Enumextension] = ACTIONS(6939),
    [anon_sym_EnumExtension] = ACTIONS(6939),
    [anon_sym_enumExtension] = ACTIONS(6939),
    [sym_interface_keyword] = ACTIONS(6939),
    [anon_sym_controladdin] = ACTIONS(6939),
    [anon_sym_CONTROLADDIN] = ACTIONS(6939),
    [anon_sym_Controladdin] = ACTIONS(6939),
    [anon_sym_ControlAddIn] = ACTIONS(6939),
    [anon_sym_ControlAddin] = ACTIONS(6939),
    [anon_sym_controlAddIn] = ACTIONS(6939),
    [anon_sym_controlAddin] = ACTIONS(6939),
    [anon_sym_dotnet] = ACTIONS(6939),
    [anon_sym_DOTNET] = ACTIONS(6939),
    [anon_sym_Dotnet] = ACTIONS(6939),
    [anon_sym_DotNet] = ACTIONS(6939),
    [anon_sym_dotNet] = ACTIONS(6939),
    [sym_profile_keyword] = ACTIONS(6941),
    [anon_sym_profileextension] = ACTIONS(6939),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6939),
    [anon_sym_Profileextension] = ACTIONS(6939),
    [anon_sym_ProfileExtension] = ACTIONS(6939),
    [anon_sym_profileExtension] = ACTIONS(6939),
    [anon_sym_permissionset] = ACTIONS(6941),
    [anon_sym_PERMISSIONSET] = ACTIONS(6941),
    [anon_sym_Permissionset] = ACTIONS(6941),
    [anon_sym_PermissionSet] = ACTIONS(6941),
    [anon_sym_permissionSet] = ACTIONS(6941),
    [anon_sym_permissionsetextension] = ACTIONS(6939),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6939),
    [anon_sym_Permissionsetextension] = ACTIONS(6939),
    [anon_sym_PermissionSetExtension] = ACTIONS(6939),
    [anon_sym_permissionSetExtension] = ACTIONS(6939),
    [sym_entitlement_keyword] = ACTIONS(6939),
    [anon_sym_pagecustomization] = ACTIONS(6939),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6939),
    [anon_sym_Pagecustomization] = ACTIONS(6939),
    [anon_sym_PageCustomization] = ACTIONS(6939),
    [anon_sym_pageCustomization] = ACTIONS(6939),
    [sym_using_keyword] = ACTIONS(6939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6939),
    [sym_preproc_close] = ACTIONS(6939),
  },
  [STATE(2799)] = {
    [anon_sym_POUNDif] = ACTIONS(6943),
    [anon_sym_POUNDIF] = ACTIONS(6943),
    [anon_sym_POUNDIf] = ACTIONS(6943),
    [anon_sym_POUNDelif] = ACTIONS(6943),
    [anon_sym_POUNDELIF] = ACTIONS(6943),
    [anon_sym_POUNDElif] = ACTIONS(6943),
    [anon_sym_POUNDelse] = ACTIONS(6943),
    [anon_sym_POUNDELSE] = ACTIONS(6943),
    [anon_sym_POUNDElse] = ACTIONS(6943),
    [anon_sym_POUNDelse2] = ACTIONS(6943),
    [anon_sym_POUNDELSE2] = ACTIONS(6943),
    [anon_sym_POUNDElse2] = ACTIONS(6943),
    [anon_sym_POUNDendif] = ACTIONS(6943),
    [anon_sym_POUNDENDIF] = ACTIONS(6943),
    [anon_sym_POUNDEndif] = ACTIONS(6943),
    [anon_sym_POUNDendif2] = ACTIONS(6943),
    [anon_sym_POUNDENDIF2] = ACTIONS(6943),
    [anon_sym_POUNDEndif2] = ACTIONS(6943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6945),
    [anon_sym_tableextension] = ACTIONS(6943),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6943),
    [anon_sym_Tableextension] = ACTIONS(6943),
    [anon_sym_TableExtension] = ACTIONS(6943),
    [anon_sym_tableExtension] = ACTIONS(6943),
    [sym_page_keyword] = ACTIONS(6945),
    [anon_sym_pageextension] = ACTIONS(6943),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6943),
    [anon_sym_Pageextension] = ACTIONS(6943),
    [anon_sym_PageExtension] = ACTIONS(6943),
    [anon_sym_pageExtension] = ACTIONS(6943),
    [anon_sym_codeunit] = ACTIONS(6943),
    [anon_sym_CODEUNIT] = ACTIONS(6943),
    [anon_sym_Codeunit] = ACTIONS(6943),
    [anon_sym_CodeUnit] = ACTIONS(6943),
    [anon_sym_COdeunit] = ACTIONS(6943),
    [anon_sym_codeUnit] = ACTIONS(6943),
    [sym_report_keyword] = ACTIONS(6945),
    [anon_sym_reportextension] = ACTIONS(6943),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6943),
    [anon_sym_Reportextension] = ACTIONS(6943),
    [anon_sym_ReportExtension] = ACTIONS(6943),
    [anon_sym_reportExtension] = ACTIONS(6943),
    [sym_query_keyword] = ACTIONS(6943),
    [anon_sym_xmlport] = ACTIONS(6943),
    [anon_sym_XMLPORT] = ACTIONS(6943),
    [anon_sym_Xmlport] = ACTIONS(6943),
    [anon_sym_XMLport] = ACTIONS(6943),
    [anon_sym_XMLPort] = ACTIONS(6943),
    [anon_sym_XmlPort] = ACTIONS(6943),
    [anon_sym_enum] = ACTIONS(6945),
    [anon_sym_ENUM] = ACTIONS(6945),
    [anon_sym_Enum] = ACTIONS(6945),
    [anon_sym_eNUM] = ACTIONS(6943),
    [anon_sym_eNum] = ACTIONS(6943),
    [anon_sym_ENum] = ACTIONS(6943),
    [anon_sym_enumextension] = ACTIONS(6943),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6943),
    [anon_sym_Enumextension] = ACTIONS(6943),
    [anon_sym_EnumExtension] = ACTIONS(6943),
    [anon_sym_enumExtension] = ACTIONS(6943),
    [sym_interface_keyword] = ACTIONS(6943),
    [anon_sym_controladdin] = ACTIONS(6943),
    [anon_sym_CONTROLADDIN] = ACTIONS(6943),
    [anon_sym_Controladdin] = ACTIONS(6943),
    [anon_sym_ControlAddIn] = ACTIONS(6943),
    [anon_sym_ControlAddin] = ACTIONS(6943),
    [anon_sym_controlAddIn] = ACTIONS(6943),
    [anon_sym_controlAddin] = ACTIONS(6943),
    [anon_sym_dotnet] = ACTIONS(6943),
    [anon_sym_DOTNET] = ACTIONS(6943),
    [anon_sym_Dotnet] = ACTIONS(6943),
    [anon_sym_DotNet] = ACTIONS(6943),
    [anon_sym_dotNet] = ACTIONS(6943),
    [sym_profile_keyword] = ACTIONS(6945),
    [anon_sym_profileextension] = ACTIONS(6943),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6943),
    [anon_sym_Profileextension] = ACTIONS(6943),
    [anon_sym_ProfileExtension] = ACTIONS(6943),
    [anon_sym_profileExtension] = ACTIONS(6943),
    [anon_sym_permissionset] = ACTIONS(6945),
    [anon_sym_PERMISSIONSET] = ACTIONS(6945),
    [anon_sym_Permissionset] = ACTIONS(6945),
    [anon_sym_PermissionSet] = ACTIONS(6945),
    [anon_sym_permissionSet] = ACTIONS(6945),
    [anon_sym_permissionsetextension] = ACTIONS(6943),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6943),
    [anon_sym_Permissionsetextension] = ACTIONS(6943),
    [anon_sym_PermissionSetExtension] = ACTIONS(6943),
    [anon_sym_permissionSetExtension] = ACTIONS(6943),
    [sym_entitlement_keyword] = ACTIONS(6943),
    [anon_sym_pagecustomization] = ACTIONS(6943),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6943),
    [anon_sym_Pagecustomization] = ACTIONS(6943),
    [anon_sym_PageCustomization] = ACTIONS(6943),
    [anon_sym_pageCustomization] = ACTIONS(6943),
    [sym_using_keyword] = ACTIONS(6943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6943),
    [sym_preproc_close] = ACTIONS(6943),
  },
  [STATE(2800)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2782),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_DOT] = ACTIONS(3667),
    [anon_sym_EQ] = ACTIONS(3669),
    [anon_sym_COMMA] = ACTIONS(6947),
    [anon_sym_DASH] = ACTIONS(3667),
    [aux_sym_boolean_token1] = ACTIONS(3667),
    [aux_sym_boolean_token2] = ACTIONS(3667),
    [sym_decimal] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3669),
    [anon_sym_DOT_DOT] = ACTIONS(3669),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3667),
    [anon_sym_STAR] = ACTIONS(3667),
    [anon_sym_LBRACK] = ACTIONS(3669),
    [aux_sym_record_type_token1] = ACTIONS(3667),
    [aux_sym_basic_type_token21] = ACTIONS(3667),
    [aux_sym_basic_type_token22] = ACTIONS(3667),
    [aux_sym_basic_type_token48] = ACTIONS(3667),
    [anon_sym_not] = ACTIONS(3667),
    [anon_sym_NOT] = ACTIONS(3667),
    [anon_sym_Not] = ACTIONS(3667),
    [anon_sym_POUNDelif] = ACTIONS(3669),
    [anon_sym_POUNDELIF] = ACTIONS(3669),
    [anon_sym_POUNDElif] = ACTIONS(3669),
    [anon_sym_POUNDelse] = ACTIONS(3669),
    [anon_sym_POUNDELSE] = ACTIONS(3669),
    [anon_sym_POUNDElse] = ACTIONS(3669),
    [anon_sym_POUNDelse2] = ACTIONS(3669),
    [anon_sym_POUNDELSE2] = ACTIONS(3669),
    [anon_sym_POUNDElse2] = ACTIONS(3669),
    [anon_sym_POUNDendif] = ACTIONS(3669),
    [anon_sym_POUNDENDIF] = ACTIONS(3669),
    [anon_sym_POUNDEndif] = ACTIONS(3669),
    [anon_sym_POUNDendif2] = ACTIONS(3669),
    [anon_sym_POUNDENDIF2] = ACTIONS(3669),
    [anon_sym_POUNDEndif2] = ACTIONS(3669),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3669),
    [aux_sym__expression_token1] = ACTIONS(3669),
    [aux_sym__expression_token2] = ACTIONS(3669),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3667),
    [anon_sym_SLASH] = ACTIONS(3667),
    [anon_sym_div] = ACTIONS(3667),
    [anon_sym_DIV] = ACTIONS(3667),
    [anon_sym_Div] = ACTIONS(3667),
    [anon_sym_mod] = ACTIONS(3667),
    [anon_sym_MOD] = ACTIONS(3667),
    [anon_sym_Mod] = ACTIONS(3667),
    [anon_sym_PLUS] = ACTIONS(3667),
    [anon_sym_GT_EQ] = ACTIONS(3669),
    [anon_sym_LT_EQ] = ACTIONS(3669),
    [anon_sym_GT] = ACTIONS(3667),
    [anon_sym_LT] = ACTIONS(3667),
    [anon_sym_LT_GT] = ACTIONS(3669),
    [anon_sym_and] = ACTIONS(3667),
    [anon_sym_AND] = ACTIONS(3667),
    [anon_sym_And] = ACTIONS(3667),
    [anon_sym_or] = ACTIONS(3667),
    [anon_sym_OR] = ACTIONS(3667),
    [anon_sym_Or] = ACTIONS(3667),
    [anon_sym_xor] = ACTIONS(3667),
    [anon_sym_XOR] = ACTIONS(3667),
    [anon_sym_Xor] = ACTIONS(3667),
    [anon_sym_QMARK] = ACTIONS(3669),
    [sym_datetime_literal] = ACTIONS(3669),
    [sym_date_literal] = ACTIONS(3667),
    [sym_time_literal] = ACTIONS(3667),
    [sym_biginteger_literal] = ACTIONS(3669),
    [anon_sym_in] = ACTIONS(3667),
    [anon_sym_IN] = ACTIONS(3667),
    [anon_sym_In] = ACTIONS(3667),
    [sym_page_keyword] = ACTIONS(3667),
    [anon_sym_codeunit] = ACTIONS(3667),
    [anon_sym_CODEUNIT] = ACTIONS(3667),
    [anon_sym_Codeunit] = ACTIONS(3667),
    [anon_sym_CodeUnit] = ACTIONS(3667),
    [anon_sym_COdeunit] = ACTIONS(3667),
    [anon_sym_codeUnit] = ACTIONS(3667),
    [sym_report_keyword] = ACTIONS(3667),
    [sym_query_keyword] = ACTIONS(3667),
    [anon_sym_xmlport] = ACTIONS(3667),
    [anon_sym_XMLPORT] = ACTIONS(3667),
    [anon_sym_Xmlport] = ACTIONS(3667),
    [anon_sym_XMLport] = ACTIONS(3667),
    [anon_sym_XMLPort] = ACTIONS(3667),
    [anon_sym_XmlPort] = ACTIONS(3667),
    [anon_sym_enum] = ACTIONS(3667),
    [anon_sym_ENUM] = ACTIONS(3667),
    [anon_sym_Enum] = ACTIONS(3667),
    [anon_sym_eNUM] = ACTIONS(3667),
    [anon_sym_eNum] = ACTIONS(3667),
    [anon_sym_ENum] = ACTIONS(3667),
    [sym_quoted_identifier] = ACTIONS(3669),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3669),
    [sym_verbatim_string] = ACTIONS(3669),
    [sym_integer] = ACTIONS(3667),
    [sym_continue_as_identifier] = ACTIONS(3669),
    [sym_preproc_close] = ACTIONS(3669),
  },
  [STATE(2801)] = {
    [anon_sym_POUNDif] = ACTIONS(6949),
    [anon_sym_POUNDIF] = ACTIONS(6949),
    [anon_sym_POUNDIf] = ACTIONS(6949),
    [anon_sym_POUNDelif] = ACTIONS(6949),
    [anon_sym_POUNDELIF] = ACTIONS(6949),
    [anon_sym_POUNDElif] = ACTIONS(6949),
    [anon_sym_POUNDelse] = ACTIONS(6949),
    [anon_sym_POUNDELSE] = ACTIONS(6949),
    [anon_sym_POUNDElse] = ACTIONS(6949),
    [anon_sym_POUNDelse2] = ACTIONS(6949),
    [anon_sym_POUNDELSE2] = ACTIONS(6949),
    [anon_sym_POUNDElse2] = ACTIONS(6949),
    [anon_sym_POUNDendif] = ACTIONS(6949),
    [anon_sym_POUNDENDIF] = ACTIONS(6949),
    [anon_sym_POUNDEndif] = ACTIONS(6949),
    [anon_sym_POUNDendif2] = ACTIONS(6949),
    [anon_sym_POUNDENDIF2] = ACTIONS(6949),
    [anon_sym_POUNDEndif2] = ACTIONS(6949),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6951),
    [anon_sym_tableextension] = ACTIONS(6949),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6949),
    [anon_sym_Tableextension] = ACTIONS(6949),
    [anon_sym_TableExtension] = ACTIONS(6949),
    [anon_sym_tableExtension] = ACTIONS(6949),
    [sym_page_keyword] = ACTIONS(6951),
    [anon_sym_pageextension] = ACTIONS(6949),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6949),
    [anon_sym_Pageextension] = ACTIONS(6949),
    [anon_sym_PageExtension] = ACTIONS(6949),
    [anon_sym_pageExtension] = ACTIONS(6949),
    [anon_sym_codeunit] = ACTIONS(6949),
    [anon_sym_CODEUNIT] = ACTIONS(6949),
    [anon_sym_Codeunit] = ACTIONS(6949),
    [anon_sym_CodeUnit] = ACTIONS(6949),
    [anon_sym_COdeunit] = ACTIONS(6949),
    [anon_sym_codeUnit] = ACTIONS(6949),
    [sym_report_keyword] = ACTIONS(6951),
    [anon_sym_reportextension] = ACTIONS(6949),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6949),
    [anon_sym_Reportextension] = ACTIONS(6949),
    [anon_sym_ReportExtension] = ACTIONS(6949),
    [anon_sym_reportExtension] = ACTIONS(6949),
    [sym_query_keyword] = ACTIONS(6949),
    [anon_sym_xmlport] = ACTIONS(6949),
    [anon_sym_XMLPORT] = ACTIONS(6949),
    [anon_sym_Xmlport] = ACTIONS(6949),
    [anon_sym_XMLport] = ACTIONS(6949),
    [anon_sym_XMLPort] = ACTIONS(6949),
    [anon_sym_XmlPort] = ACTIONS(6949),
    [anon_sym_enum] = ACTIONS(6951),
    [anon_sym_ENUM] = ACTIONS(6951),
    [anon_sym_Enum] = ACTIONS(6951),
    [anon_sym_eNUM] = ACTIONS(6949),
    [anon_sym_eNum] = ACTIONS(6949),
    [anon_sym_ENum] = ACTIONS(6949),
    [anon_sym_enumextension] = ACTIONS(6949),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6949),
    [anon_sym_Enumextension] = ACTIONS(6949),
    [anon_sym_EnumExtension] = ACTIONS(6949),
    [anon_sym_enumExtension] = ACTIONS(6949),
    [sym_interface_keyword] = ACTIONS(6949),
    [anon_sym_controladdin] = ACTIONS(6949),
    [anon_sym_CONTROLADDIN] = ACTIONS(6949),
    [anon_sym_Controladdin] = ACTIONS(6949),
    [anon_sym_ControlAddIn] = ACTIONS(6949),
    [anon_sym_ControlAddin] = ACTIONS(6949),
    [anon_sym_controlAddIn] = ACTIONS(6949),
    [anon_sym_controlAddin] = ACTIONS(6949),
    [anon_sym_dotnet] = ACTIONS(6949),
    [anon_sym_DOTNET] = ACTIONS(6949),
    [anon_sym_Dotnet] = ACTIONS(6949),
    [anon_sym_DotNet] = ACTIONS(6949),
    [anon_sym_dotNet] = ACTIONS(6949),
    [sym_profile_keyword] = ACTIONS(6951),
    [anon_sym_profileextension] = ACTIONS(6949),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6949),
    [anon_sym_Profileextension] = ACTIONS(6949),
    [anon_sym_ProfileExtension] = ACTIONS(6949),
    [anon_sym_profileExtension] = ACTIONS(6949),
    [anon_sym_permissionset] = ACTIONS(6951),
    [anon_sym_PERMISSIONSET] = ACTIONS(6951),
    [anon_sym_Permissionset] = ACTIONS(6951),
    [anon_sym_PermissionSet] = ACTIONS(6951),
    [anon_sym_permissionSet] = ACTIONS(6951),
    [anon_sym_permissionsetextension] = ACTIONS(6949),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6949),
    [anon_sym_Permissionsetextension] = ACTIONS(6949),
    [anon_sym_PermissionSetExtension] = ACTIONS(6949),
    [anon_sym_permissionSetExtension] = ACTIONS(6949),
    [sym_entitlement_keyword] = ACTIONS(6949),
    [anon_sym_pagecustomization] = ACTIONS(6949),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6949),
    [anon_sym_Pagecustomization] = ACTIONS(6949),
    [anon_sym_PageCustomization] = ACTIONS(6949),
    [anon_sym_pageCustomization] = ACTIONS(6949),
    [sym_using_keyword] = ACTIONS(6949),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6949),
    [sym_preproc_close] = ACTIONS(6949),
  },
  [STATE(2802)] = {
    [anon_sym_POUNDif] = ACTIONS(6953),
    [anon_sym_POUNDIF] = ACTIONS(6953),
    [anon_sym_POUNDIf] = ACTIONS(6953),
    [anon_sym_POUNDelif] = ACTIONS(6953),
    [anon_sym_POUNDELIF] = ACTIONS(6953),
    [anon_sym_POUNDElif] = ACTIONS(6953),
    [anon_sym_POUNDelse] = ACTIONS(6953),
    [anon_sym_POUNDELSE] = ACTIONS(6953),
    [anon_sym_POUNDElse] = ACTIONS(6953),
    [anon_sym_POUNDelse2] = ACTIONS(6953),
    [anon_sym_POUNDELSE2] = ACTIONS(6953),
    [anon_sym_POUNDElse2] = ACTIONS(6953),
    [anon_sym_POUNDendif] = ACTIONS(6953),
    [anon_sym_POUNDENDIF] = ACTIONS(6953),
    [anon_sym_POUNDEndif] = ACTIONS(6953),
    [anon_sym_POUNDendif2] = ACTIONS(6953),
    [anon_sym_POUNDENDIF2] = ACTIONS(6953),
    [anon_sym_POUNDEndif2] = ACTIONS(6953),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6955),
    [anon_sym_tableextension] = ACTIONS(6953),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6953),
    [anon_sym_Tableextension] = ACTIONS(6953),
    [anon_sym_TableExtension] = ACTIONS(6953),
    [anon_sym_tableExtension] = ACTIONS(6953),
    [sym_page_keyword] = ACTIONS(6955),
    [anon_sym_pageextension] = ACTIONS(6953),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6953),
    [anon_sym_Pageextension] = ACTIONS(6953),
    [anon_sym_PageExtension] = ACTIONS(6953),
    [anon_sym_pageExtension] = ACTIONS(6953),
    [anon_sym_codeunit] = ACTIONS(6953),
    [anon_sym_CODEUNIT] = ACTIONS(6953),
    [anon_sym_Codeunit] = ACTIONS(6953),
    [anon_sym_CodeUnit] = ACTIONS(6953),
    [anon_sym_COdeunit] = ACTIONS(6953),
    [anon_sym_codeUnit] = ACTIONS(6953),
    [sym_report_keyword] = ACTIONS(6955),
    [anon_sym_reportextension] = ACTIONS(6953),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6953),
    [anon_sym_Reportextension] = ACTIONS(6953),
    [anon_sym_ReportExtension] = ACTIONS(6953),
    [anon_sym_reportExtension] = ACTIONS(6953),
    [sym_query_keyword] = ACTIONS(6953),
    [anon_sym_xmlport] = ACTIONS(6953),
    [anon_sym_XMLPORT] = ACTIONS(6953),
    [anon_sym_Xmlport] = ACTIONS(6953),
    [anon_sym_XMLport] = ACTIONS(6953),
    [anon_sym_XMLPort] = ACTIONS(6953),
    [anon_sym_XmlPort] = ACTIONS(6953),
    [anon_sym_enum] = ACTIONS(6955),
    [anon_sym_ENUM] = ACTIONS(6955),
    [anon_sym_Enum] = ACTIONS(6955),
    [anon_sym_eNUM] = ACTIONS(6953),
    [anon_sym_eNum] = ACTIONS(6953),
    [anon_sym_ENum] = ACTIONS(6953),
    [anon_sym_enumextension] = ACTIONS(6953),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6953),
    [anon_sym_Enumextension] = ACTIONS(6953),
    [anon_sym_EnumExtension] = ACTIONS(6953),
    [anon_sym_enumExtension] = ACTIONS(6953),
    [sym_interface_keyword] = ACTIONS(6953),
    [anon_sym_controladdin] = ACTIONS(6953),
    [anon_sym_CONTROLADDIN] = ACTIONS(6953),
    [anon_sym_Controladdin] = ACTIONS(6953),
    [anon_sym_ControlAddIn] = ACTIONS(6953),
    [anon_sym_ControlAddin] = ACTIONS(6953),
    [anon_sym_controlAddIn] = ACTIONS(6953),
    [anon_sym_controlAddin] = ACTIONS(6953),
    [anon_sym_dotnet] = ACTIONS(6953),
    [anon_sym_DOTNET] = ACTIONS(6953),
    [anon_sym_Dotnet] = ACTIONS(6953),
    [anon_sym_DotNet] = ACTIONS(6953),
    [anon_sym_dotNet] = ACTIONS(6953),
    [sym_profile_keyword] = ACTIONS(6955),
    [anon_sym_profileextension] = ACTIONS(6953),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6953),
    [anon_sym_Profileextension] = ACTIONS(6953),
    [anon_sym_ProfileExtension] = ACTIONS(6953),
    [anon_sym_profileExtension] = ACTIONS(6953),
    [anon_sym_permissionset] = ACTIONS(6955),
    [anon_sym_PERMISSIONSET] = ACTIONS(6955),
    [anon_sym_Permissionset] = ACTIONS(6955),
    [anon_sym_PermissionSet] = ACTIONS(6955),
    [anon_sym_permissionSet] = ACTIONS(6955),
    [anon_sym_permissionsetextension] = ACTIONS(6953),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6953),
    [anon_sym_Permissionsetextension] = ACTIONS(6953),
    [anon_sym_PermissionSetExtension] = ACTIONS(6953),
    [anon_sym_permissionSetExtension] = ACTIONS(6953),
    [sym_entitlement_keyword] = ACTIONS(6953),
    [anon_sym_pagecustomization] = ACTIONS(6953),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6953),
    [anon_sym_Pagecustomization] = ACTIONS(6953),
    [anon_sym_PageCustomization] = ACTIONS(6953),
    [anon_sym_pageCustomization] = ACTIONS(6953),
    [sym_using_keyword] = ACTIONS(6953),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6953),
    [sym_preproc_close] = ACTIONS(6953),
  },
  [STATE(2803)] = {
    [anon_sym_POUNDif] = ACTIONS(6957),
    [anon_sym_POUNDIF] = ACTIONS(6957),
    [anon_sym_POUNDIf] = ACTIONS(6957),
    [anon_sym_POUNDelif] = ACTIONS(6957),
    [anon_sym_POUNDELIF] = ACTIONS(6957),
    [anon_sym_POUNDElif] = ACTIONS(6957),
    [anon_sym_POUNDelse] = ACTIONS(6957),
    [anon_sym_POUNDELSE] = ACTIONS(6957),
    [anon_sym_POUNDElse] = ACTIONS(6957),
    [anon_sym_POUNDelse2] = ACTIONS(6957),
    [anon_sym_POUNDELSE2] = ACTIONS(6957),
    [anon_sym_POUNDElse2] = ACTIONS(6957),
    [anon_sym_POUNDendif] = ACTIONS(6957),
    [anon_sym_POUNDENDIF] = ACTIONS(6957),
    [anon_sym_POUNDEndif] = ACTIONS(6957),
    [anon_sym_POUNDendif2] = ACTIONS(6957),
    [anon_sym_POUNDENDIF2] = ACTIONS(6957),
    [anon_sym_POUNDEndif2] = ACTIONS(6957),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6959),
    [anon_sym_tableextension] = ACTIONS(6957),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6957),
    [anon_sym_Tableextension] = ACTIONS(6957),
    [anon_sym_TableExtension] = ACTIONS(6957),
    [anon_sym_tableExtension] = ACTIONS(6957),
    [sym_page_keyword] = ACTIONS(6959),
    [anon_sym_pageextension] = ACTIONS(6957),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6957),
    [anon_sym_Pageextension] = ACTIONS(6957),
    [anon_sym_PageExtension] = ACTIONS(6957),
    [anon_sym_pageExtension] = ACTIONS(6957),
    [anon_sym_codeunit] = ACTIONS(6957),
    [anon_sym_CODEUNIT] = ACTIONS(6957),
    [anon_sym_Codeunit] = ACTIONS(6957),
    [anon_sym_CodeUnit] = ACTIONS(6957),
    [anon_sym_COdeunit] = ACTIONS(6957),
    [anon_sym_codeUnit] = ACTIONS(6957),
    [sym_report_keyword] = ACTIONS(6959),
    [anon_sym_reportextension] = ACTIONS(6957),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6957),
    [anon_sym_Reportextension] = ACTIONS(6957),
    [anon_sym_ReportExtension] = ACTIONS(6957),
    [anon_sym_reportExtension] = ACTIONS(6957),
    [sym_query_keyword] = ACTIONS(6957),
    [anon_sym_xmlport] = ACTIONS(6957),
    [anon_sym_XMLPORT] = ACTIONS(6957),
    [anon_sym_Xmlport] = ACTIONS(6957),
    [anon_sym_XMLport] = ACTIONS(6957),
    [anon_sym_XMLPort] = ACTIONS(6957),
    [anon_sym_XmlPort] = ACTIONS(6957),
    [anon_sym_enum] = ACTIONS(6959),
    [anon_sym_ENUM] = ACTIONS(6959),
    [anon_sym_Enum] = ACTIONS(6959),
    [anon_sym_eNUM] = ACTIONS(6957),
    [anon_sym_eNum] = ACTIONS(6957),
    [anon_sym_ENum] = ACTIONS(6957),
    [anon_sym_enumextension] = ACTIONS(6957),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6957),
    [anon_sym_Enumextension] = ACTIONS(6957),
    [anon_sym_EnumExtension] = ACTIONS(6957),
    [anon_sym_enumExtension] = ACTIONS(6957),
    [sym_interface_keyword] = ACTIONS(6957),
    [anon_sym_controladdin] = ACTIONS(6957),
    [anon_sym_CONTROLADDIN] = ACTIONS(6957),
    [anon_sym_Controladdin] = ACTIONS(6957),
    [anon_sym_ControlAddIn] = ACTIONS(6957),
    [anon_sym_ControlAddin] = ACTIONS(6957),
    [anon_sym_controlAddIn] = ACTIONS(6957),
    [anon_sym_controlAddin] = ACTIONS(6957),
    [anon_sym_dotnet] = ACTIONS(6957),
    [anon_sym_DOTNET] = ACTIONS(6957),
    [anon_sym_Dotnet] = ACTIONS(6957),
    [anon_sym_DotNet] = ACTIONS(6957),
    [anon_sym_dotNet] = ACTIONS(6957),
    [sym_profile_keyword] = ACTIONS(6959),
    [anon_sym_profileextension] = ACTIONS(6957),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6957),
    [anon_sym_Profileextension] = ACTIONS(6957),
    [anon_sym_ProfileExtension] = ACTIONS(6957),
    [anon_sym_profileExtension] = ACTIONS(6957),
    [anon_sym_permissionset] = ACTIONS(6959),
    [anon_sym_PERMISSIONSET] = ACTIONS(6959),
    [anon_sym_Permissionset] = ACTIONS(6959),
    [anon_sym_PermissionSet] = ACTIONS(6959),
    [anon_sym_permissionSet] = ACTIONS(6959),
    [anon_sym_permissionsetextension] = ACTIONS(6957),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6957),
    [anon_sym_Permissionsetextension] = ACTIONS(6957),
    [anon_sym_PermissionSetExtension] = ACTIONS(6957),
    [anon_sym_permissionSetExtension] = ACTIONS(6957),
    [sym_entitlement_keyword] = ACTIONS(6957),
    [anon_sym_pagecustomization] = ACTIONS(6957),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6957),
    [anon_sym_Pagecustomization] = ACTIONS(6957),
    [anon_sym_PageCustomization] = ACTIONS(6957),
    [anon_sym_pageCustomization] = ACTIONS(6957),
    [sym_using_keyword] = ACTIONS(6957),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6957),
    [sym_preproc_close] = ACTIONS(6957),
  },
  [STATE(2804)] = {
    [anon_sym_POUNDif] = ACTIONS(6961),
    [anon_sym_POUNDIF] = ACTIONS(6961),
    [anon_sym_POUNDIf] = ACTIONS(6961),
    [anon_sym_POUNDelif] = ACTIONS(6961),
    [anon_sym_POUNDELIF] = ACTIONS(6961),
    [anon_sym_POUNDElif] = ACTIONS(6961),
    [anon_sym_POUNDelse] = ACTIONS(6961),
    [anon_sym_POUNDELSE] = ACTIONS(6961),
    [anon_sym_POUNDElse] = ACTIONS(6961),
    [anon_sym_POUNDelse2] = ACTIONS(6961),
    [anon_sym_POUNDELSE2] = ACTIONS(6961),
    [anon_sym_POUNDElse2] = ACTIONS(6961),
    [anon_sym_POUNDendif] = ACTIONS(6961),
    [anon_sym_POUNDENDIF] = ACTIONS(6961),
    [anon_sym_POUNDEndif] = ACTIONS(6961),
    [anon_sym_POUNDendif2] = ACTIONS(6961),
    [anon_sym_POUNDENDIF2] = ACTIONS(6961),
    [anon_sym_POUNDEndif2] = ACTIONS(6961),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6963),
    [anon_sym_tableextension] = ACTIONS(6961),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6961),
    [anon_sym_Tableextension] = ACTIONS(6961),
    [anon_sym_TableExtension] = ACTIONS(6961),
    [anon_sym_tableExtension] = ACTIONS(6961),
    [sym_page_keyword] = ACTIONS(6963),
    [anon_sym_pageextension] = ACTIONS(6961),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6961),
    [anon_sym_Pageextension] = ACTIONS(6961),
    [anon_sym_PageExtension] = ACTIONS(6961),
    [anon_sym_pageExtension] = ACTIONS(6961),
    [anon_sym_codeunit] = ACTIONS(6961),
    [anon_sym_CODEUNIT] = ACTIONS(6961),
    [anon_sym_Codeunit] = ACTIONS(6961),
    [anon_sym_CodeUnit] = ACTIONS(6961),
    [anon_sym_COdeunit] = ACTIONS(6961),
    [anon_sym_codeUnit] = ACTIONS(6961),
    [sym_report_keyword] = ACTIONS(6963),
    [anon_sym_reportextension] = ACTIONS(6961),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6961),
    [anon_sym_Reportextension] = ACTIONS(6961),
    [anon_sym_ReportExtension] = ACTIONS(6961),
    [anon_sym_reportExtension] = ACTIONS(6961),
    [sym_query_keyword] = ACTIONS(6961),
    [anon_sym_xmlport] = ACTIONS(6961),
    [anon_sym_XMLPORT] = ACTIONS(6961),
    [anon_sym_Xmlport] = ACTIONS(6961),
    [anon_sym_XMLport] = ACTIONS(6961),
    [anon_sym_XMLPort] = ACTIONS(6961),
    [anon_sym_XmlPort] = ACTIONS(6961),
    [anon_sym_enum] = ACTIONS(6963),
    [anon_sym_ENUM] = ACTIONS(6963),
    [anon_sym_Enum] = ACTIONS(6963),
    [anon_sym_eNUM] = ACTIONS(6961),
    [anon_sym_eNum] = ACTIONS(6961),
    [anon_sym_ENum] = ACTIONS(6961),
    [anon_sym_enumextension] = ACTIONS(6961),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6961),
    [anon_sym_Enumextension] = ACTIONS(6961),
    [anon_sym_EnumExtension] = ACTIONS(6961),
    [anon_sym_enumExtension] = ACTIONS(6961),
    [sym_interface_keyword] = ACTIONS(6961),
    [anon_sym_controladdin] = ACTIONS(6961),
    [anon_sym_CONTROLADDIN] = ACTIONS(6961),
    [anon_sym_Controladdin] = ACTIONS(6961),
    [anon_sym_ControlAddIn] = ACTIONS(6961),
    [anon_sym_ControlAddin] = ACTIONS(6961),
    [anon_sym_controlAddIn] = ACTIONS(6961),
    [anon_sym_controlAddin] = ACTIONS(6961),
    [anon_sym_dotnet] = ACTIONS(6961),
    [anon_sym_DOTNET] = ACTIONS(6961),
    [anon_sym_Dotnet] = ACTIONS(6961),
    [anon_sym_DotNet] = ACTIONS(6961),
    [anon_sym_dotNet] = ACTIONS(6961),
    [sym_profile_keyword] = ACTIONS(6963),
    [anon_sym_profileextension] = ACTIONS(6961),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6961),
    [anon_sym_Profileextension] = ACTIONS(6961),
    [anon_sym_ProfileExtension] = ACTIONS(6961),
    [anon_sym_profileExtension] = ACTIONS(6961),
    [anon_sym_permissionset] = ACTIONS(6963),
    [anon_sym_PERMISSIONSET] = ACTIONS(6963),
    [anon_sym_Permissionset] = ACTIONS(6963),
    [anon_sym_PermissionSet] = ACTIONS(6963),
    [anon_sym_permissionSet] = ACTIONS(6963),
    [anon_sym_permissionsetextension] = ACTIONS(6961),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6961),
    [anon_sym_Permissionsetextension] = ACTIONS(6961),
    [anon_sym_PermissionSetExtension] = ACTIONS(6961),
    [anon_sym_permissionSetExtension] = ACTIONS(6961),
    [sym_entitlement_keyword] = ACTIONS(6961),
    [anon_sym_pagecustomization] = ACTIONS(6961),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6961),
    [anon_sym_Pagecustomization] = ACTIONS(6961),
    [anon_sym_PageCustomization] = ACTIONS(6961),
    [anon_sym_pageCustomization] = ACTIONS(6961),
    [sym_using_keyword] = ACTIONS(6961),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6961),
    [sym_preproc_close] = ACTIONS(6961),
  },
  [STATE(2805)] = {
    [anon_sym_POUNDif] = ACTIONS(6965),
    [anon_sym_POUNDIF] = ACTIONS(6965),
    [anon_sym_POUNDIf] = ACTIONS(6965),
    [anon_sym_POUNDelif] = ACTIONS(6965),
    [anon_sym_POUNDELIF] = ACTIONS(6965),
    [anon_sym_POUNDElif] = ACTIONS(6965),
    [anon_sym_POUNDelse] = ACTIONS(6965),
    [anon_sym_POUNDELSE] = ACTIONS(6965),
    [anon_sym_POUNDElse] = ACTIONS(6965),
    [anon_sym_POUNDelse2] = ACTIONS(6965),
    [anon_sym_POUNDELSE2] = ACTIONS(6965),
    [anon_sym_POUNDElse2] = ACTIONS(6965),
    [anon_sym_POUNDendif] = ACTIONS(6965),
    [anon_sym_POUNDENDIF] = ACTIONS(6965),
    [anon_sym_POUNDEndif] = ACTIONS(6965),
    [anon_sym_POUNDendif2] = ACTIONS(6965),
    [anon_sym_POUNDENDIF2] = ACTIONS(6965),
    [anon_sym_POUNDEndif2] = ACTIONS(6965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6967),
    [anon_sym_tableextension] = ACTIONS(6965),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6965),
    [anon_sym_Tableextension] = ACTIONS(6965),
    [anon_sym_TableExtension] = ACTIONS(6965),
    [anon_sym_tableExtension] = ACTIONS(6965),
    [sym_page_keyword] = ACTIONS(6967),
    [anon_sym_pageextension] = ACTIONS(6965),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6965),
    [anon_sym_Pageextension] = ACTIONS(6965),
    [anon_sym_PageExtension] = ACTIONS(6965),
    [anon_sym_pageExtension] = ACTIONS(6965),
    [anon_sym_codeunit] = ACTIONS(6965),
    [anon_sym_CODEUNIT] = ACTIONS(6965),
    [anon_sym_Codeunit] = ACTIONS(6965),
    [anon_sym_CodeUnit] = ACTIONS(6965),
    [anon_sym_COdeunit] = ACTIONS(6965),
    [anon_sym_codeUnit] = ACTIONS(6965),
    [sym_report_keyword] = ACTIONS(6967),
    [anon_sym_reportextension] = ACTIONS(6965),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6965),
    [anon_sym_Reportextension] = ACTIONS(6965),
    [anon_sym_ReportExtension] = ACTIONS(6965),
    [anon_sym_reportExtension] = ACTIONS(6965),
    [sym_query_keyword] = ACTIONS(6965),
    [anon_sym_xmlport] = ACTIONS(6965),
    [anon_sym_XMLPORT] = ACTIONS(6965),
    [anon_sym_Xmlport] = ACTIONS(6965),
    [anon_sym_XMLport] = ACTIONS(6965),
    [anon_sym_XMLPort] = ACTIONS(6965),
    [anon_sym_XmlPort] = ACTIONS(6965),
    [anon_sym_enum] = ACTIONS(6967),
    [anon_sym_ENUM] = ACTIONS(6967),
    [anon_sym_Enum] = ACTIONS(6967),
    [anon_sym_eNUM] = ACTIONS(6965),
    [anon_sym_eNum] = ACTIONS(6965),
    [anon_sym_ENum] = ACTIONS(6965),
    [anon_sym_enumextension] = ACTIONS(6965),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6965),
    [anon_sym_Enumextension] = ACTIONS(6965),
    [anon_sym_EnumExtension] = ACTIONS(6965),
    [anon_sym_enumExtension] = ACTIONS(6965),
    [sym_interface_keyword] = ACTIONS(6965),
    [anon_sym_controladdin] = ACTIONS(6965),
    [anon_sym_CONTROLADDIN] = ACTIONS(6965),
    [anon_sym_Controladdin] = ACTIONS(6965),
    [anon_sym_ControlAddIn] = ACTIONS(6965),
    [anon_sym_ControlAddin] = ACTIONS(6965),
    [anon_sym_controlAddIn] = ACTIONS(6965),
    [anon_sym_controlAddin] = ACTIONS(6965),
    [anon_sym_dotnet] = ACTIONS(6965),
    [anon_sym_DOTNET] = ACTIONS(6965),
    [anon_sym_Dotnet] = ACTIONS(6965),
    [anon_sym_DotNet] = ACTIONS(6965),
    [anon_sym_dotNet] = ACTIONS(6965),
    [sym_profile_keyword] = ACTIONS(6967),
    [anon_sym_profileextension] = ACTIONS(6965),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6965),
    [anon_sym_Profileextension] = ACTIONS(6965),
    [anon_sym_ProfileExtension] = ACTIONS(6965),
    [anon_sym_profileExtension] = ACTIONS(6965),
    [anon_sym_permissionset] = ACTIONS(6967),
    [anon_sym_PERMISSIONSET] = ACTIONS(6967),
    [anon_sym_Permissionset] = ACTIONS(6967),
    [anon_sym_PermissionSet] = ACTIONS(6967),
    [anon_sym_permissionSet] = ACTIONS(6967),
    [anon_sym_permissionsetextension] = ACTIONS(6965),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6965),
    [anon_sym_Permissionsetextension] = ACTIONS(6965),
    [anon_sym_PermissionSetExtension] = ACTIONS(6965),
    [anon_sym_permissionSetExtension] = ACTIONS(6965),
    [sym_entitlement_keyword] = ACTIONS(6965),
    [anon_sym_pagecustomization] = ACTIONS(6965),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6965),
    [anon_sym_Pagecustomization] = ACTIONS(6965),
    [anon_sym_PageCustomization] = ACTIONS(6965),
    [anon_sym_pageCustomization] = ACTIONS(6965),
    [sym_using_keyword] = ACTIONS(6965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6965),
    [sym_preproc_close] = ACTIONS(6965),
  },
  [STATE(2806)] = {
    [anon_sym_POUNDif] = ACTIONS(6969),
    [anon_sym_POUNDIF] = ACTIONS(6969),
    [anon_sym_POUNDIf] = ACTIONS(6969),
    [anon_sym_POUNDelif] = ACTIONS(6969),
    [anon_sym_POUNDELIF] = ACTIONS(6969),
    [anon_sym_POUNDElif] = ACTIONS(6969),
    [anon_sym_POUNDelse] = ACTIONS(6969),
    [anon_sym_POUNDELSE] = ACTIONS(6969),
    [anon_sym_POUNDElse] = ACTIONS(6969),
    [anon_sym_POUNDelse2] = ACTIONS(6969),
    [anon_sym_POUNDELSE2] = ACTIONS(6969),
    [anon_sym_POUNDElse2] = ACTIONS(6969),
    [anon_sym_POUNDendif] = ACTIONS(6969),
    [anon_sym_POUNDENDIF] = ACTIONS(6969),
    [anon_sym_POUNDEndif] = ACTIONS(6969),
    [anon_sym_POUNDendif2] = ACTIONS(6969),
    [anon_sym_POUNDENDIF2] = ACTIONS(6969),
    [anon_sym_POUNDEndif2] = ACTIONS(6969),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6971),
    [anon_sym_tableextension] = ACTIONS(6969),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6969),
    [anon_sym_Tableextension] = ACTIONS(6969),
    [anon_sym_TableExtension] = ACTIONS(6969),
    [anon_sym_tableExtension] = ACTIONS(6969),
    [sym_page_keyword] = ACTIONS(6971),
    [anon_sym_pageextension] = ACTIONS(6969),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6969),
    [anon_sym_Pageextension] = ACTIONS(6969),
    [anon_sym_PageExtension] = ACTIONS(6969),
    [anon_sym_pageExtension] = ACTIONS(6969),
    [anon_sym_codeunit] = ACTIONS(6969),
    [anon_sym_CODEUNIT] = ACTIONS(6969),
    [anon_sym_Codeunit] = ACTIONS(6969),
    [anon_sym_CodeUnit] = ACTIONS(6969),
    [anon_sym_COdeunit] = ACTIONS(6969),
    [anon_sym_codeUnit] = ACTIONS(6969),
    [sym_report_keyword] = ACTIONS(6971),
    [anon_sym_reportextension] = ACTIONS(6969),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6969),
    [anon_sym_Reportextension] = ACTIONS(6969),
    [anon_sym_ReportExtension] = ACTIONS(6969),
    [anon_sym_reportExtension] = ACTIONS(6969),
    [sym_query_keyword] = ACTIONS(6969),
    [anon_sym_xmlport] = ACTIONS(6969),
    [anon_sym_XMLPORT] = ACTIONS(6969),
    [anon_sym_Xmlport] = ACTIONS(6969),
    [anon_sym_XMLport] = ACTIONS(6969),
    [anon_sym_XMLPort] = ACTIONS(6969),
    [anon_sym_XmlPort] = ACTIONS(6969),
    [anon_sym_enum] = ACTIONS(6971),
    [anon_sym_ENUM] = ACTIONS(6971),
    [anon_sym_Enum] = ACTIONS(6971),
    [anon_sym_eNUM] = ACTIONS(6969),
    [anon_sym_eNum] = ACTIONS(6969),
    [anon_sym_ENum] = ACTIONS(6969),
    [anon_sym_enumextension] = ACTIONS(6969),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6969),
    [anon_sym_Enumextension] = ACTIONS(6969),
    [anon_sym_EnumExtension] = ACTIONS(6969),
    [anon_sym_enumExtension] = ACTIONS(6969),
    [sym_interface_keyword] = ACTIONS(6969),
    [anon_sym_controladdin] = ACTIONS(6969),
    [anon_sym_CONTROLADDIN] = ACTIONS(6969),
    [anon_sym_Controladdin] = ACTIONS(6969),
    [anon_sym_ControlAddIn] = ACTIONS(6969),
    [anon_sym_ControlAddin] = ACTIONS(6969),
    [anon_sym_controlAddIn] = ACTIONS(6969),
    [anon_sym_controlAddin] = ACTIONS(6969),
    [anon_sym_dotnet] = ACTIONS(6969),
    [anon_sym_DOTNET] = ACTIONS(6969),
    [anon_sym_Dotnet] = ACTIONS(6969),
    [anon_sym_DotNet] = ACTIONS(6969),
    [anon_sym_dotNet] = ACTIONS(6969),
    [sym_profile_keyword] = ACTIONS(6971),
    [anon_sym_profileextension] = ACTIONS(6969),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6969),
    [anon_sym_Profileextension] = ACTIONS(6969),
    [anon_sym_ProfileExtension] = ACTIONS(6969),
    [anon_sym_profileExtension] = ACTIONS(6969),
    [anon_sym_permissionset] = ACTIONS(6971),
    [anon_sym_PERMISSIONSET] = ACTIONS(6971),
    [anon_sym_Permissionset] = ACTIONS(6971),
    [anon_sym_PermissionSet] = ACTIONS(6971),
    [anon_sym_permissionSet] = ACTIONS(6971),
    [anon_sym_permissionsetextension] = ACTIONS(6969),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6969),
    [anon_sym_Permissionsetextension] = ACTIONS(6969),
    [anon_sym_PermissionSetExtension] = ACTIONS(6969),
    [anon_sym_permissionSetExtension] = ACTIONS(6969),
    [sym_entitlement_keyword] = ACTIONS(6969),
    [anon_sym_pagecustomization] = ACTIONS(6969),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6969),
    [anon_sym_Pagecustomization] = ACTIONS(6969),
    [anon_sym_PageCustomization] = ACTIONS(6969),
    [anon_sym_pageCustomization] = ACTIONS(6969),
    [sym_using_keyword] = ACTIONS(6969),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6969),
    [sym_preproc_close] = ACTIONS(6969),
  },
  [STATE(2807)] = {
    [anon_sym_POUNDif] = ACTIONS(6973),
    [anon_sym_POUNDIF] = ACTIONS(6973),
    [anon_sym_POUNDIf] = ACTIONS(6973),
    [anon_sym_POUNDelif] = ACTIONS(6973),
    [anon_sym_POUNDELIF] = ACTIONS(6973),
    [anon_sym_POUNDElif] = ACTIONS(6973),
    [anon_sym_POUNDelse] = ACTIONS(6973),
    [anon_sym_POUNDELSE] = ACTIONS(6973),
    [anon_sym_POUNDElse] = ACTIONS(6973),
    [anon_sym_POUNDelse2] = ACTIONS(6973),
    [anon_sym_POUNDELSE2] = ACTIONS(6973),
    [anon_sym_POUNDElse2] = ACTIONS(6973),
    [anon_sym_POUNDendif] = ACTIONS(6973),
    [anon_sym_POUNDENDIF] = ACTIONS(6973),
    [anon_sym_POUNDEndif] = ACTIONS(6973),
    [anon_sym_POUNDendif2] = ACTIONS(6973),
    [anon_sym_POUNDENDIF2] = ACTIONS(6973),
    [anon_sym_POUNDEndif2] = ACTIONS(6973),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6975),
    [anon_sym_tableextension] = ACTIONS(6973),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6973),
    [anon_sym_Tableextension] = ACTIONS(6973),
    [anon_sym_TableExtension] = ACTIONS(6973),
    [anon_sym_tableExtension] = ACTIONS(6973),
    [sym_page_keyword] = ACTIONS(6975),
    [anon_sym_pageextension] = ACTIONS(6973),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6973),
    [anon_sym_Pageextension] = ACTIONS(6973),
    [anon_sym_PageExtension] = ACTIONS(6973),
    [anon_sym_pageExtension] = ACTIONS(6973),
    [anon_sym_codeunit] = ACTIONS(6973),
    [anon_sym_CODEUNIT] = ACTIONS(6973),
    [anon_sym_Codeunit] = ACTIONS(6973),
    [anon_sym_CodeUnit] = ACTIONS(6973),
    [anon_sym_COdeunit] = ACTIONS(6973),
    [anon_sym_codeUnit] = ACTIONS(6973),
    [sym_report_keyword] = ACTIONS(6975),
    [anon_sym_reportextension] = ACTIONS(6973),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6973),
    [anon_sym_Reportextension] = ACTIONS(6973),
    [anon_sym_ReportExtension] = ACTIONS(6973),
    [anon_sym_reportExtension] = ACTIONS(6973),
    [sym_query_keyword] = ACTIONS(6973),
    [anon_sym_xmlport] = ACTIONS(6973),
    [anon_sym_XMLPORT] = ACTIONS(6973),
    [anon_sym_Xmlport] = ACTIONS(6973),
    [anon_sym_XMLport] = ACTIONS(6973),
    [anon_sym_XMLPort] = ACTIONS(6973),
    [anon_sym_XmlPort] = ACTIONS(6973),
    [anon_sym_enum] = ACTIONS(6975),
    [anon_sym_ENUM] = ACTIONS(6975),
    [anon_sym_Enum] = ACTIONS(6975),
    [anon_sym_eNUM] = ACTIONS(6973),
    [anon_sym_eNum] = ACTIONS(6973),
    [anon_sym_ENum] = ACTIONS(6973),
    [anon_sym_enumextension] = ACTIONS(6973),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6973),
    [anon_sym_Enumextension] = ACTIONS(6973),
    [anon_sym_EnumExtension] = ACTIONS(6973),
    [anon_sym_enumExtension] = ACTIONS(6973),
    [sym_interface_keyword] = ACTIONS(6973),
    [anon_sym_controladdin] = ACTIONS(6973),
    [anon_sym_CONTROLADDIN] = ACTIONS(6973),
    [anon_sym_Controladdin] = ACTIONS(6973),
    [anon_sym_ControlAddIn] = ACTIONS(6973),
    [anon_sym_ControlAddin] = ACTIONS(6973),
    [anon_sym_controlAddIn] = ACTIONS(6973),
    [anon_sym_controlAddin] = ACTIONS(6973),
    [anon_sym_dotnet] = ACTIONS(6973),
    [anon_sym_DOTNET] = ACTIONS(6973),
    [anon_sym_Dotnet] = ACTIONS(6973),
    [anon_sym_DotNet] = ACTIONS(6973),
    [anon_sym_dotNet] = ACTIONS(6973),
    [sym_profile_keyword] = ACTIONS(6975),
    [anon_sym_profileextension] = ACTIONS(6973),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6973),
    [anon_sym_Profileextension] = ACTIONS(6973),
    [anon_sym_ProfileExtension] = ACTIONS(6973),
    [anon_sym_profileExtension] = ACTIONS(6973),
    [anon_sym_permissionset] = ACTIONS(6975),
    [anon_sym_PERMISSIONSET] = ACTIONS(6975),
    [anon_sym_Permissionset] = ACTIONS(6975),
    [anon_sym_PermissionSet] = ACTIONS(6975),
    [anon_sym_permissionSet] = ACTIONS(6975),
    [anon_sym_permissionsetextension] = ACTIONS(6973),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6973),
    [anon_sym_Permissionsetextension] = ACTIONS(6973),
    [anon_sym_PermissionSetExtension] = ACTIONS(6973),
    [anon_sym_permissionSetExtension] = ACTIONS(6973),
    [sym_entitlement_keyword] = ACTIONS(6973),
    [anon_sym_pagecustomization] = ACTIONS(6973),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6973),
    [anon_sym_Pagecustomization] = ACTIONS(6973),
    [anon_sym_PageCustomization] = ACTIONS(6973),
    [anon_sym_pageCustomization] = ACTIONS(6973),
    [sym_using_keyword] = ACTIONS(6973),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6973),
    [sym_preproc_close] = ACTIONS(6973),
  },
  [STATE(2808)] = {
    [anon_sym_POUNDif] = ACTIONS(6977),
    [anon_sym_POUNDIF] = ACTIONS(6977),
    [anon_sym_POUNDIf] = ACTIONS(6977),
    [anon_sym_POUNDelif] = ACTIONS(6977),
    [anon_sym_POUNDELIF] = ACTIONS(6977),
    [anon_sym_POUNDElif] = ACTIONS(6977),
    [anon_sym_POUNDelse] = ACTIONS(6977),
    [anon_sym_POUNDELSE] = ACTIONS(6977),
    [anon_sym_POUNDElse] = ACTIONS(6977),
    [anon_sym_POUNDelse2] = ACTIONS(6977),
    [anon_sym_POUNDELSE2] = ACTIONS(6977),
    [anon_sym_POUNDElse2] = ACTIONS(6977),
    [anon_sym_POUNDendif] = ACTIONS(6977),
    [anon_sym_POUNDENDIF] = ACTIONS(6977),
    [anon_sym_POUNDEndif] = ACTIONS(6977),
    [anon_sym_POUNDendif2] = ACTIONS(6977),
    [anon_sym_POUNDENDIF2] = ACTIONS(6977),
    [anon_sym_POUNDEndif2] = ACTIONS(6977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6979),
    [anon_sym_tableextension] = ACTIONS(6977),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6977),
    [anon_sym_Tableextension] = ACTIONS(6977),
    [anon_sym_TableExtension] = ACTIONS(6977),
    [anon_sym_tableExtension] = ACTIONS(6977),
    [sym_page_keyword] = ACTIONS(6979),
    [anon_sym_pageextension] = ACTIONS(6977),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6977),
    [anon_sym_Pageextension] = ACTIONS(6977),
    [anon_sym_PageExtension] = ACTIONS(6977),
    [anon_sym_pageExtension] = ACTIONS(6977),
    [anon_sym_codeunit] = ACTIONS(6977),
    [anon_sym_CODEUNIT] = ACTIONS(6977),
    [anon_sym_Codeunit] = ACTIONS(6977),
    [anon_sym_CodeUnit] = ACTIONS(6977),
    [anon_sym_COdeunit] = ACTIONS(6977),
    [anon_sym_codeUnit] = ACTIONS(6977),
    [sym_report_keyword] = ACTIONS(6979),
    [anon_sym_reportextension] = ACTIONS(6977),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6977),
    [anon_sym_Reportextension] = ACTIONS(6977),
    [anon_sym_ReportExtension] = ACTIONS(6977),
    [anon_sym_reportExtension] = ACTIONS(6977),
    [sym_query_keyword] = ACTIONS(6977),
    [anon_sym_xmlport] = ACTIONS(6977),
    [anon_sym_XMLPORT] = ACTIONS(6977),
    [anon_sym_Xmlport] = ACTIONS(6977),
    [anon_sym_XMLport] = ACTIONS(6977),
    [anon_sym_XMLPort] = ACTIONS(6977),
    [anon_sym_XmlPort] = ACTIONS(6977),
    [anon_sym_enum] = ACTIONS(6979),
    [anon_sym_ENUM] = ACTIONS(6979),
    [anon_sym_Enum] = ACTIONS(6979),
    [anon_sym_eNUM] = ACTIONS(6977),
    [anon_sym_eNum] = ACTIONS(6977),
    [anon_sym_ENum] = ACTIONS(6977),
    [anon_sym_enumextension] = ACTIONS(6977),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6977),
    [anon_sym_Enumextension] = ACTIONS(6977),
    [anon_sym_EnumExtension] = ACTIONS(6977),
    [anon_sym_enumExtension] = ACTIONS(6977),
    [sym_interface_keyword] = ACTIONS(6977),
    [anon_sym_controladdin] = ACTIONS(6977),
    [anon_sym_CONTROLADDIN] = ACTIONS(6977),
    [anon_sym_Controladdin] = ACTIONS(6977),
    [anon_sym_ControlAddIn] = ACTIONS(6977),
    [anon_sym_ControlAddin] = ACTIONS(6977),
    [anon_sym_controlAddIn] = ACTIONS(6977),
    [anon_sym_controlAddin] = ACTIONS(6977),
    [anon_sym_dotnet] = ACTIONS(6977),
    [anon_sym_DOTNET] = ACTIONS(6977),
    [anon_sym_Dotnet] = ACTIONS(6977),
    [anon_sym_DotNet] = ACTIONS(6977),
    [anon_sym_dotNet] = ACTIONS(6977),
    [sym_profile_keyword] = ACTIONS(6979),
    [anon_sym_profileextension] = ACTIONS(6977),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6977),
    [anon_sym_Profileextension] = ACTIONS(6977),
    [anon_sym_ProfileExtension] = ACTIONS(6977),
    [anon_sym_profileExtension] = ACTIONS(6977),
    [anon_sym_permissionset] = ACTIONS(6979),
    [anon_sym_PERMISSIONSET] = ACTIONS(6979),
    [anon_sym_Permissionset] = ACTIONS(6979),
    [anon_sym_PermissionSet] = ACTIONS(6979),
    [anon_sym_permissionSet] = ACTIONS(6979),
    [anon_sym_permissionsetextension] = ACTIONS(6977),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6977),
    [anon_sym_Permissionsetextension] = ACTIONS(6977),
    [anon_sym_PermissionSetExtension] = ACTIONS(6977),
    [anon_sym_permissionSetExtension] = ACTIONS(6977),
    [sym_entitlement_keyword] = ACTIONS(6977),
    [anon_sym_pagecustomization] = ACTIONS(6977),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6977),
    [anon_sym_Pagecustomization] = ACTIONS(6977),
    [anon_sym_PageCustomization] = ACTIONS(6977),
    [anon_sym_pageCustomization] = ACTIONS(6977),
    [sym_using_keyword] = ACTIONS(6977),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6977),
    [sym_preproc_close] = ACTIONS(6977),
  },
  [STATE(2809)] = {
    [anon_sym_POUNDif] = ACTIONS(6981),
    [anon_sym_POUNDIF] = ACTIONS(6981),
    [anon_sym_POUNDIf] = ACTIONS(6981),
    [anon_sym_POUNDelif] = ACTIONS(6981),
    [anon_sym_POUNDELIF] = ACTIONS(6981),
    [anon_sym_POUNDElif] = ACTIONS(6981),
    [anon_sym_POUNDelse] = ACTIONS(6981),
    [anon_sym_POUNDELSE] = ACTIONS(6981),
    [anon_sym_POUNDElse] = ACTIONS(6981),
    [anon_sym_POUNDelse2] = ACTIONS(6981),
    [anon_sym_POUNDELSE2] = ACTIONS(6981),
    [anon_sym_POUNDElse2] = ACTIONS(6981),
    [anon_sym_POUNDendif] = ACTIONS(6981),
    [anon_sym_POUNDENDIF] = ACTIONS(6981),
    [anon_sym_POUNDEndif] = ACTIONS(6981),
    [anon_sym_POUNDendif2] = ACTIONS(6981),
    [anon_sym_POUNDENDIF2] = ACTIONS(6981),
    [anon_sym_POUNDEndif2] = ACTIONS(6981),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6983),
    [anon_sym_tableextension] = ACTIONS(6981),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6981),
    [anon_sym_Tableextension] = ACTIONS(6981),
    [anon_sym_TableExtension] = ACTIONS(6981),
    [anon_sym_tableExtension] = ACTIONS(6981),
    [sym_page_keyword] = ACTIONS(6983),
    [anon_sym_pageextension] = ACTIONS(6981),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6981),
    [anon_sym_Pageextension] = ACTIONS(6981),
    [anon_sym_PageExtension] = ACTIONS(6981),
    [anon_sym_pageExtension] = ACTIONS(6981),
    [anon_sym_codeunit] = ACTIONS(6981),
    [anon_sym_CODEUNIT] = ACTIONS(6981),
    [anon_sym_Codeunit] = ACTIONS(6981),
    [anon_sym_CodeUnit] = ACTIONS(6981),
    [anon_sym_COdeunit] = ACTIONS(6981),
    [anon_sym_codeUnit] = ACTIONS(6981),
    [sym_report_keyword] = ACTIONS(6983),
    [anon_sym_reportextension] = ACTIONS(6981),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6981),
    [anon_sym_Reportextension] = ACTIONS(6981),
    [anon_sym_ReportExtension] = ACTIONS(6981),
    [anon_sym_reportExtension] = ACTIONS(6981),
    [sym_query_keyword] = ACTIONS(6981),
    [anon_sym_xmlport] = ACTIONS(6981),
    [anon_sym_XMLPORT] = ACTIONS(6981),
    [anon_sym_Xmlport] = ACTIONS(6981),
    [anon_sym_XMLport] = ACTIONS(6981),
    [anon_sym_XMLPort] = ACTIONS(6981),
    [anon_sym_XmlPort] = ACTIONS(6981),
    [anon_sym_enum] = ACTIONS(6983),
    [anon_sym_ENUM] = ACTIONS(6983),
    [anon_sym_Enum] = ACTIONS(6983),
    [anon_sym_eNUM] = ACTIONS(6981),
    [anon_sym_eNum] = ACTIONS(6981),
    [anon_sym_ENum] = ACTIONS(6981),
    [anon_sym_enumextension] = ACTIONS(6981),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6981),
    [anon_sym_Enumextension] = ACTIONS(6981),
    [anon_sym_EnumExtension] = ACTIONS(6981),
    [anon_sym_enumExtension] = ACTIONS(6981),
    [sym_interface_keyword] = ACTIONS(6981),
    [anon_sym_controladdin] = ACTIONS(6981),
    [anon_sym_CONTROLADDIN] = ACTIONS(6981),
    [anon_sym_Controladdin] = ACTIONS(6981),
    [anon_sym_ControlAddIn] = ACTIONS(6981),
    [anon_sym_ControlAddin] = ACTIONS(6981),
    [anon_sym_controlAddIn] = ACTIONS(6981),
    [anon_sym_controlAddin] = ACTIONS(6981),
    [anon_sym_dotnet] = ACTIONS(6981),
    [anon_sym_DOTNET] = ACTIONS(6981),
    [anon_sym_Dotnet] = ACTIONS(6981),
    [anon_sym_DotNet] = ACTIONS(6981),
    [anon_sym_dotNet] = ACTIONS(6981),
    [sym_profile_keyword] = ACTIONS(6983),
    [anon_sym_profileextension] = ACTIONS(6981),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6981),
    [anon_sym_Profileextension] = ACTIONS(6981),
    [anon_sym_ProfileExtension] = ACTIONS(6981),
    [anon_sym_profileExtension] = ACTIONS(6981),
    [anon_sym_permissionset] = ACTIONS(6983),
    [anon_sym_PERMISSIONSET] = ACTIONS(6983),
    [anon_sym_Permissionset] = ACTIONS(6983),
    [anon_sym_PermissionSet] = ACTIONS(6983),
    [anon_sym_permissionSet] = ACTIONS(6983),
    [anon_sym_permissionsetextension] = ACTIONS(6981),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6981),
    [anon_sym_Permissionsetextension] = ACTIONS(6981),
    [anon_sym_PermissionSetExtension] = ACTIONS(6981),
    [anon_sym_permissionSetExtension] = ACTIONS(6981),
    [sym_entitlement_keyword] = ACTIONS(6981),
    [anon_sym_pagecustomization] = ACTIONS(6981),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6981),
    [anon_sym_Pagecustomization] = ACTIONS(6981),
    [anon_sym_PageCustomization] = ACTIONS(6981),
    [anon_sym_pageCustomization] = ACTIONS(6981),
    [sym_using_keyword] = ACTIONS(6981),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6981),
    [sym_preproc_close] = ACTIONS(6981),
  },
  [STATE(2810)] = {
    [anon_sym_POUNDif] = ACTIONS(6985),
    [anon_sym_POUNDIF] = ACTIONS(6985),
    [anon_sym_POUNDIf] = ACTIONS(6985),
    [anon_sym_POUNDelif] = ACTIONS(6985),
    [anon_sym_POUNDELIF] = ACTIONS(6985),
    [anon_sym_POUNDElif] = ACTIONS(6985),
    [anon_sym_POUNDelse] = ACTIONS(6985),
    [anon_sym_POUNDELSE] = ACTIONS(6985),
    [anon_sym_POUNDElse] = ACTIONS(6985),
    [anon_sym_POUNDelse2] = ACTIONS(6985),
    [anon_sym_POUNDELSE2] = ACTIONS(6985),
    [anon_sym_POUNDElse2] = ACTIONS(6985),
    [anon_sym_POUNDendif] = ACTIONS(6985),
    [anon_sym_POUNDENDIF] = ACTIONS(6985),
    [anon_sym_POUNDEndif] = ACTIONS(6985),
    [anon_sym_POUNDendif2] = ACTIONS(6985),
    [anon_sym_POUNDENDIF2] = ACTIONS(6985),
    [anon_sym_POUNDEndif2] = ACTIONS(6985),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6987),
    [anon_sym_tableextension] = ACTIONS(6985),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6985),
    [anon_sym_Tableextension] = ACTIONS(6985),
    [anon_sym_TableExtension] = ACTIONS(6985),
    [anon_sym_tableExtension] = ACTIONS(6985),
    [sym_page_keyword] = ACTIONS(6987),
    [anon_sym_pageextension] = ACTIONS(6985),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6985),
    [anon_sym_Pageextension] = ACTIONS(6985),
    [anon_sym_PageExtension] = ACTIONS(6985),
    [anon_sym_pageExtension] = ACTIONS(6985),
    [anon_sym_codeunit] = ACTIONS(6985),
    [anon_sym_CODEUNIT] = ACTIONS(6985),
    [anon_sym_Codeunit] = ACTIONS(6985),
    [anon_sym_CodeUnit] = ACTIONS(6985),
    [anon_sym_COdeunit] = ACTIONS(6985),
    [anon_sym_codeUnit] = ACTIONS(6985),
    [sym_report_keyword] = ACTIONS(6987),
    [anon_sym_reportextension] = ACTIONS(6985),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6985),
    [anon_sym_Reportextension] = ACTIONS(6985),
    [anon_sym_ReportExtension] = ACTIONS(6985),
    [anon_sym_reportExtension] = ACTIONS(6985),
    [sym_query_keyword] = ACTIONS(6985),
    [anon_sym_xmlport] = ACTIONS(6985),
    [anon_sym_XMLPORT] = ACTIONS(6985),
    [anon_sym_Xmlport] = ACTIONS(6985),
    [anon_sym_XMLport] = ACTIONS(6985),
    [anon_sym_XMLPort] = ACTIONS(6985),
    [anon_sym_XmlPort] = ACTIONS(6985),
    [anon_sym_enum] = ACTIONS(6987),
    [anon_sym_ENUM] = ACTIONS(6987),
    [anon_sym_Enum] = ACTIONS(6987),
    [anon_sym_eNUM] = ACTIONS(6985),
    [anon_sym_eNum] = ACTIONS(6985),
    [anon_sym_ENum] = ACTIONS(6985),
    [anon_sym_enumextension] = ACTIONS(6985),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6985),
    [anon_sym_Enumextension] = ACTIONS(6985),
    [anon_sym_EnumExtension] = ACTIONS(6985),
    [anon_sym_enumExtension] = ACTIONS(6985),
    [sym_interface_keyword] = ACTIONS(6985),
    [anon_sym_controladdin] = ACTIONS(6985),
    [anon_sym_CONTROLADDIN] = ACTIONS(6985),
    [anon_sym_Controladdin] = ACTIONS(6985),
    [anon_sym_ControlAddIn] = ACTIONS(6985),
    [anon_sym_ControlAddin] = ACTIONS(6985),
    [anon_sym_controlAddIn] = ACTIONS(6985),
    [anon_sym_controlAddin] = ACTIONS(6985),
    [anon_sym_dotnet] = ACTIONS(6985),
    [anon_sym_DOTNET] = ACTIONS(6985),
    [anon_sym_Dotnet] = ACTIONS(6985),
    [anon_sym_DotNet] = ACTIONS(6985),
    [anon_sym_dotNet] = ACTIONS(6985),
    [sym_profile_keyword] = ACTIONS(6987),
    [anon_sym_profileextension] = ACTIONS(6985),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6985),
    [anon_sym_Profileextension] = ACTIONS(6985),
    [anon_sym_ProfileExtension] = ACTIONS(6985),
    [anon_sym_profileExtension] = ACTIONS(6985),
    [anon_sym_permissionset] = ACTIONS(6987),
    [anon_sym_PERMISSIONSET] = ACTIONS(6987),
    [anon_sym_Permissionset] = ACTIONS(6987),
    [anon_sym_PermissionSet] = ACTIONS(6987),
    [anon_sym_permissionSet] = ACTIONS(6987),
    [anon_sym_permissionsetextension] = ACTIONS(6985),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6985),
    [anon_sym_Permissionsetextension] = ACTIONS(6985),
    [anon_sym_PermissionSetExtension] = ACTIONS(6985),
    [anon_sym_permissionSetExtension] = ACTIONS(6985),
    [sym_entitlement_keyword] = ACTIONS(6985),
    [anon_sym_pagecustomization] = ACTIONS(6985),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6985),
    [anon_sym_Pagecustomization] = ACTIONS(6985),
    [anon_sym_PageCustomization] = ACTIONS(6985),
    [anon_sym_pageCustomization] = ACTIONS(6985),
    [sym_using_keyword] = ACTIONS(6985),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6985),
    [sym_preproc_close] = ACTIONS(6985),
  },
  [STATE(2811)] = {
    [anon_sym_POUNDif] = ACTIONS(6989),
    [anon_sym_POUNDIF] = ACTIONS(6989),
    [anon_sym_POUNDIf] = ACTIONS(6989),
    [anon_sym_POUNDelif] = ACTIONS(6989),
    [anon_sym_POUNDELIF] = ACTIONS(6989),
    [anon_sym_POUNDElif] = ACTIONS(6989),
    [anon_sym_POUNDelse] = ACTIONS(6989),
    [anon_sym_POUNDELSE] = ACTIONS(6989),
    [anon_sym_POUNDElse] = ACTIONS(6989),
    [anon_sym_POUNDelse2] = ACTIONS(6989),
    [anon_sym_POUNDELSE2] = ACTIONS(6989),
    [anon_sym_POUNDElse2] = ACTIONS(6989),
    [anon_sym_POUNDendif] = ACTIONS(6989),
    [anon_sym_POUNDENDIF] = ACTIONS(6989),
    [anon_sym_POUNDEndif] = ACTIONS(6989),
    [anon_sym_POUNDendif2] = ACTIONS(6989),
    [anon_sym_POUNDENDIF2] = ACTIONS(6989),
    [anon_sym_POUNDEndif2] = ACTIONS(6989),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6991),
    [anon_sym_tableextension] = ACTIONS(6989),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6989),
    [anon_sym_Tableextension] = ACTIONS(6989),
    [anon_sym_TableExtension] = ACTIONS(6989),
    [anon_sym_tableExtension] = ACTIONS(6989),
    [sym_page_keyword] = ACTIONS(6991),
    [anon_sym_pageextension] = ACTIONS(6989),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6989),
    [anon_sym_Pageextension] = ACTIONS(6989),
    [anon_sym_PageExtension] = ACTIONS(6989),
    [anon_sym_pageExtension] = ACTIONS(6989),
    [anon_sym_codeunit] = ACTIONS(6989),
    [anon_sym_CODEUNIT] = ACTIONS(6989),
    [anon_sym_Codeunit] = ACTIONS(6989),
    [anon_sym_CodeUnit] = ACTIONS(6989),
    [anon_sym_COdeunit] = ACTIONS(6989),
    [anon_sym_codeUnit] = ACTIONS(6989),
    [sym_report_keyword] = ACTIONS(6991),
    [anon_sym_reportextension] = ACTIONS(6989),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6989),
    [anon_sym_Reportextension] = ACTIONS(6989),
    [anon_sym_ReportExtension] = ACTIONS(6989),
    [anon_sym_reportExtension] = ACTIONS(6989),
    [sym_query_keyword] = ACTIONS(6989),
    [anon_sym_xmlport] = ACTIONS(6989),
    [anon_sym_XMLPORT] = ACTIONS(6989),
    [anon_sym_Xmlport] = ACTIONS(6989),
    [anon_sym_XMLport] = ACTIONS(6989),
    [anon_sym_XMLPort] = ACTIONS(6989),
    [anon_sym_XmlPort] = ACTIONS(6989),
    [anon_sym_enum] = ACTIONS(6991),
    [anon_sym_ENUM] = ACTIONS(6991),
    [anon_sym_Enum] = ACTIONS(6991),
    [anon_sym_eNUM] = ACTIONS(6989),
    [anon_sym_eNum] = ACTIONS(6989),
    [anon_sym_ENum] = ACTIONS(6989),
    [anon_sym_enumextension] = ACTIONS(6989),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6989),
    [anon_sym_Enumextension] = ACTIONS(6989),
    [anon_sym_EnumExtension] = ACTIONS(6989),
    [anon_sym_enumExtension] = ACTIONS(6989),
    [sym_interface_keyword] = ACTIONS(6989),
    [anon_sym_controladdin] = ACTIONS(6989),
    [anon_sym_CONTROLADDIN] = ACTIONS(6989),
    [anon_sym_Controladdin] = ACTIONS(6989),
    [anon_sym_ControlAddIn] = ACTIONS(6989),
    [anon_sym_ControlAddin] = ACTIONS(6989),
    [anon_sym_controlAddIn] = ACTIONS(6989),
    [anon_sym_controlAddin] = ACTIONS(6989),
    [anon_sym_dotnet] = ACTIONS(6989),
    [anon_sym_DOTNET] = ACTIONS(6989),
    [anon_sym_Dotnet] = ACTIONS(6989),
    [anon_sym_DotNet] = ACTIONS(6989),
    [anon_sym_dotNet] = ACTIONS(6989),
    [sym_profile_keyword] = ACTIONS(6991),
    [anon_sym_profileextension] = ACTIONS(6989),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6989),
    [anon_sym_Profileextension] = ACTIONS(6989),
    [anon_sym_ProfileExtension] = ACTIONS(6989),
    [anon_sym_profileExtension] = ACTIONS(6989),
    [anon_sym_permissionset] = ACTIONS(6991),
    [anon_sym_PERMISSIONSET] = ACTIONS(6991),
    [anon_sym_Permissionset] = ACTIONS(6991),
    [anon_sym_PermissionSet] = ACTIONS(6991),
    [anon_sym_permissionSet] = ACTIONS(6991),
    [anon_sym_permissionsetextension] = ACTIONS(6989),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6989),
    [anon_sym_Permissionsetextension] = ACTIONS(6989),
    [anon_sym_PermissionSetExtension] = ACTIONS(6989),
    [anon_sym_permissionSetExtension] = ACTIONS(6989),
    [sym_entitlement_keyword] = ACTIONS(6989),
    [anon_sym_pagecustomization] = ACTIONS(6989),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6989),
    [anon_sym_Pagecustomization] = ACTIONS(6989),
    [anon_sym_PageCustomization] = ACTIONS(6989),
    [anon_sym_pageCustomization] = ACTIONS(6989),
    [sym_using_keyword] = ACTIONS(6989),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6989),
    [sym_preproc_close] = ACTIONS(6989),
  },
  [STATE(2812)] = {
    [anon_sym_POUNDif] = ACTIONS(6993),
    [anon_sym_POUNDIF] = ACTIONS(6993),
    [anon_sym_POUNDIf] = ACTIONS(6993),
    [anon_sym_POUNDelif] = ACTIONS(6993),
    [anon_sym_POUNDELIF] = ACTIONS(6993),
    [anon_sym_POUNDElif] = ACTIONS(6993),
    [anon_sym_POUNDelse] = ACTIONS(6993),
    [anon_sym_POUNDELSE] = ACTIONS(6993),
    [anon_sym_POUNDElse] = ACTIONS(6993),
    [anon_sym_POUNDelse2] = ACTIONS(6993),
    [anon_sym_POUNDELSE2] = ACTIONS(6993),
    [anon_sym_POUNDElse2] = ACTIONS(6993),
    [anon_sym_POUNDendif] = ACTIONS(6993),
    [anon_sym_POUNDENDIF] = ACTIONS(6993),
    [anon_sym_POUNDEndif] = ACTIONS(6993),
    [anon_sym_POUNDendif2] = ACTIONS(6993),
    [anon_sym_POUNDENDIF2] = ACTIONS(6993),
    [anon_sym_POUNDEndif2] = ACTIONS(6993),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6995),
    [anon_sym_tableextension] = ACTIONS(6993),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6993),
    [anon_sym_Tableextension] = ACTIONS(6993),
    [anon_sym_TableExtension] = ACTIONS(6993),
    [anon_sym_tableExtension] = ACTIONS(6993),
    [sym_page_keyword] = ACTIONS(6995),
    [anon_sym_pageextension] = ACTIONS(6993),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6993),
    [anon_sym_Pageextension] = ACTIONS(6993),
    [anon_sym_PageExtension] = ACTIONS(6993),
    [anon_sym_pageExtension] = ACTIONS(6993),
    [anon_sym_codeunit] = ACTIONS(6993),
    [anon_sym_CODEUNIT] = ACTIONS(6993),
    [anon_sym_Codeunit] = ACTIONS(6993),
    [anon_sym_CodeUnit] = ACTIONS(6993),
    [anon_sym_COdeunit] = ACTIONS(6993),
    [anon_sym_codeUnit] = ACTIONS(6993),
    [sym_report_keyword] = ACTIONS(6995),
    [anon_sym_reportextension] = ACTIONS(6993),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6993),
    [anon_sym_Reportextension] = ACTIONS(6993),
    [anon_sym_ReportExtension] = ACTIONS(6993),
    [anon_sym_reportExtension] = ACTIONS(6993),
    [sym_query_keyword] = ACTIONS(6993),
    [anon_sym_xmlport] = ACTIONS(6993),
    [anon_sym_XMLPORT] = ACTIONS(6993),
    [anon_sym_Xmlport] = ACTIONS(6993),
    [anon_sym_XMLport] = ACTIONS(6993),
    [anon_sym_XMLPort] = ACTIONS(6993),
    [anon_sym_XmlPort] = ACTIONS(6993),
    [anon_sym_enum] = ACTIONS(6995),
    [anon_sym_ENUM] = ACTIONS(6995),
    [anon_sym_Enum] = ACTIONS(6995),
    [anon_sym_eNUM] = ACTIONS(6993),
    [anon_sym_eNum] = ACTIONS(6993),
    [anon_sym_ENum] = ACTIONS(6993),
    [anon_sym_enumextension] = ACTIONS(6993),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6993),
    [anon_sym_Enumextension] = ACTIONS(6993),
    [anon_sym_EnumExtension] = ACTIONS(6993),
    [anon_sym_enumExtension] = ACTIONS(6993),
    [sym_interface_keyword] = ACTIONS(6993),
    [anon_sym_controladdin] = ACTIONS(6993),
    [anon_sym_CONTROLADDIN] = ACTIONS(6993),
    [anon_sym_Controladdin] = ACTIONS(6993),
    [anon_sym_ControlAddIn] = ACTIONS(6993),
    [anon_sym_ControlAddin] = ACTIONS(6993),
    [anon_sym_controlAddIn] = ACTIONS(6993),
    [anon_sym_controlAddin] = ACTIONS(6993),
    [anon_sym_dotnet] = ACTIONS(6993),
    [anon_sym_DOTNET] = ACTIONS(6993),
    [anon_sym_Dotnet] = ACTIONS(6993),
    [anon_sym_DotNet] = ACTIONS(6993),
    [anon_sym_dotNet] = ACTIONS(6993),
    [sym_profile_keyword] = ACTIONS(6995),
    [anon_sym_profileextension] = ACTIONS(6993),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6993),
    [anon_sym_Profileextension] = ACTIONS(6993),
    [anon_sym_ProfileExtension] = ACTIONS(6993),
    [anon_sym_profileExtension] = ACTIONS(6993),
    [anon_sym_permissionset] = ACTIONS(6995),
    [anon_sym_PERMISSIONSET] = ACTIONS(6995),
    [anon_sym_Permissionset] = ACTIONS(6995),
    [anon_sym_PermissionSet] = ACTIONS(6995),
    [anon_sym_permissionSet] = ACTIONS(6995),
    [anon_sym_permissionsetextension] = ACTIONS(6993),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6993),
    [anon_sym_Permissionsetextension] = ACTIONS(6993),
    [anon_sym_PermissionSetExtension] = ACTIONS(6993),
    [anon_sym_permissionSetExtension] = ACTIONS(6993),
    [sym_entitlement_keyword] = ACTIONS(6993),
    [anon_sym_pagecustomization] = ACTIONS(6993),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6993),
    [anon_sym_Pagecustomization] = ACTIONS(6993),
    [anon_sym_PageCustomization] = ACTIONS(6993),
    [anon_sym_pageCustomization] = ACTIONS(6993),
    [sym_using_keyword] = ACTIONS(6993),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6993),
    [sym_preproc_close] = ACTIONS(6993),
  },
  [STATE(2813)] = {
    [sym_where_clause] = STATE(5936),
    [sym_argument_list] = STATE(7165),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_RBRACE] = ACTIONS(5386),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(6997),
    [aux_sym_where_condition_token1] = ACTIONS(5392),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5386),
    [anon_sym_STAR] = ACTIONS(3681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5386),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5386),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [aux_sym_basic_type_token6] = ACTIONS(5392),
    [aux_sym_basic_type_token22] = ACTIONS(5392),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5386),
    [aux_sym_addafter_modification_token1] = ACTIONS(5386),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5386),
    [aux_sym_modify_modification_token1] = ACTIONS(5386),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5386),
    [aux_sym_movelast_modification_token1] = ACTIONS(5386),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5386),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5386),
    [aux_sym_separator_action_token1] = ACTIONS(5386),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5386),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5386),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5386),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5386),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5392),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5386),
    [anon_sym_POUNDIF] = ACTIONS(5386),
    [anon_sym_POUNDIf] = ACTIONS(5386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5386),
    [sym_trigger_keyword] = ACTIONS(5386),
    [sym_var_keyword] = ACTIONS(5386),
    [sym_local_keyword] = ACTIONS(5386),
    [sym_internal_keyword] = ACTIONS(5386),
    [sym_protected_keyword] = ACTIONS(5386),
    [sym_event_keyword] = ACTIONS(5386),
    [sym_fields_keyword] = ACTIONS(5386),
    [sym_keys_keyword] = ACTIONS(5386),
    [sym_fieldgroups_keyword] = ACTIONS(5386),
    [sym_actions_keyword] = ACTIONS(5386),
    [sym_layout_keyword] = ACTIONS(5386),
    [sym_area_keyword] = ACTIONS(5386),
    [sym_group_keyword] = ACTIONS(5386),
    [sym_repeater_keyword] = ACTIONS(5386),
    [sym_cuegroup_keyword] = ACTIONS(5386),
    [sym_fixed_keyword] = ACTIONS(5386),
    [sym_grid_keyword] = ACTIONS(5386),
    [sym_part_keyword] = ACTIONS(5386),
    [sym_systempart_keyword] = ACTIONS(5386),
    [sym_usercontrol_keyword] = ACTIONS(5386),
    [sym_dataset_keyword] = ACTIONS(5386),
    [sym_elements_keyword] = ACTIONS(5386),
    [sym_dataitem_keyword] = ACTIONS(5386),
    [sym_column_keyword] = ACTIONS(5386),
    [sym_filter_keyword] = ACTIONS(5386),
    [sym_labels_keyword] = ACTIONS(5386),
    [sym_rendering_keyword] = ACTIONS(5386),
    [sym_requestpage_keyword] = ACTIONS(5386),
    [sym_schema_keyword] = ACTIONS(5386),
    [sym_views_keyword] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5386),
    [sym_preproc_open] = ACTIONS(5386),
  },
  [STATE(2814)] = {
    [anon_sym_POUNDif] = ACTIONS(6999),
    [anon_sym_POUNDIF] = ACTIONS(6999),
    [anon_sym_POUNDIf] = ACTIONS(6999),
    [anon_sym_POUNDelif] = ACTIONS(6999),
    [anon_sym_POUNDELIF] = ACTIONS(6999),
    [anon_sym_POUNDElif] = ACTIONS(6999),
    [anon_sym_POUNDelse] = ACTIONS(6999),
    [anon_sym_POUNDELSE] = ACTIONS(6999),
    [anon_sym_POUNDElse] = ACTIONS(6999),
    [anon_sym_POUNDelse2] = ACTIONS(6999),
    [anon_sym_POUNDELSE2] = ACTIONS(6999),
    [anon_sym_POUNDElse2] = ACTIONS(6999),
    [anon_sym_POUNDendif] = ACTIONS(6999),
    [anon_sym_POUNDENDIF] = ACTIONS(6999),
    [anon_sym_POUNDEndif] = ACTIONS(6999),
    [anon_sym_POUNDendif2] = ACTIONS(6999),
    [anon_sym_POUNDENDIF2] = ACTIONS(6999),
    [anon_sym_POUNDEndif2] = ACTIONS(6999),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7001),
    [anon_sym_tableextension] = ACTIONS(6999),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6999),
    [anon_sym_Tableextension] = ACTIONS(6999),
    [anon_sym_TableExtension] = ACTIONS(6999),
    [anon_sym_tableExtension] = ACTIONS(6999),
    [sym_page_keyword] = ACTIONS(7001),
    [anon_sym_pageextension] = ACTIONS(6999),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6999),
    [anon_sym_Pageextension] = ACTIONS(6999),
    [anon_sym_PageExtension] = ACTIONS(6999),
    [anon_sym_pageExtension] = ACTIONS(6999),
    [anon_sym_codeunit] = ACTIONS(6999),
    [anon_sym_CODEUNIT] = ACTIONS(6999),
    [anon_sym_Codeunit] = ACTIONS(6999),
    [anon_sym_CodeUnit] = ACTIONS(6999),
    [anon_sym_COdeunit] = ACTIONS(6999),
    [anon_sym_codeUnit] = ACTIONS(6999),
    [sym_report_keyword] = ACTIONS(7001),
    [anon_sym_reportextension] = ACTIONS(6999),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6999),
    [anon_sym_Reportextension] = ACTIONS(6999),
    [anon_sym_ReportExtension] = ACTIONS(6999),
    [anon_sym_reportExtension] = ACTIONS(6999),
    [sym_query_keyword] = ACTIONS(6999),
    [anon_sym_xmlport] = ACTIONS(6999),
    [anon_sym_XMLPORT] = ACTIONS(6999),
    [anon_sym_Xmlport] = ACTIONS(6999),
    [anon_sym_XMLport] = ACTIONS(6999),
    [anon_sym_XMLPort] = ACTIONS(6999),
    [anon_sym_XmlPort] = ACTIONS(6999),
    [anon_sym_enum] = ACTIONS(7001),
    [anon_sym_ENUM] = ACTIONS(7001),
    [anon_sym_Enum] = ACTIONS(7001),
    [anon_sym_eNUM] = ACTIONS(6999),
    [anon_sym_eNum] = ACTIONS(6999),
    [anon_sym_ENum] = ACTIONS(6999),
    [anon_sym_enumextension] = ACTIONS(6999),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6999),
    [anon_sym_Enumextension] = ACTIONS(6999),
    [anon_sym_EnumExtension] = ACTIONS(6999),
    [anon_sym_enumExtension] = ACTIONS(6999),
    [sym_interface_keyword] = ACTIONS(6999),
    [anon_sym_controladdin] = ACTIONS(6999),
    [anon_sym_CONTROLADDIN] = ACTIONS(6999),
    [anon_sym_Controladdin] = ACTIONS(6999),
    [anon_sym_ControlAddIn] = ACTIONS(6999),
    [anon_sym_ControlAddin] = ACTIONS(6999),
    [anon_sym_controlAddIn] = ACTIONS(6999),
    [anon_sym_controlAddin] = ACTIONS(6999),
    [anon_sym_dotnet] = ACTIONS(6999),
    [anon_sym_DOTNET] = ACTIONS(6999),
    [anon_sym_Dotnet] = ACTIONS(6999),
    [anon_sym_DotNet] = ACTIONS(6999),
    [anon_sym_dotNet] = ACTIONS(6999),
    [sym_profile_keyword] = ACTIONS(7001),
    [anon_sym_profileextension] = ACTIONS(6999),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6999),
    [anon_sym_Profileextension] = ACTIONS(6999),
    [anon_sym_ProfileExtension] = ACTIONS(6999),
    [anon_sym_profileExtension] = ACTIONS(6999),
    [anon_sym_permissionset] = ACTIONS(7001),
    [anon_sym_PERMISSIONSET] = ACTIONS(7001),
    [anon_sym_Permissionset] = ACTIONS(7001),
    [anon_sym_PermissionSet] = ACTIONS(7001),
    [anon_sym_permissionSet] = ACTIONS(7001),
    [anon_sym_permissionsetextension] = ACTIONS(6999),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6999),
    [anon_sym_Permissionsetextension] = ACTIONS(6999),
    [anon_sym_PermissionSetExtension] = ACTIONS(6999),
    [anon_sym_permissionSetExtension] = ACTIONS(6999),
    [sym_entitlement_keyword] = ACTIONS(6999),
    [anon_sym_pagecustomization] = ACTIONS(6999),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6999),
    [anon_sym_Pagecustomization] = ACTIONS(6999),
    [anon_sym_PageCustomization] = ACTIONS(6999),
    [anon_sym_pageCustomization] = ACTIONS(6999),
    [sym_using_keyword] = ACTIONS(6999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6999),
    [sym_preproc_close] = ACTIONS(6999),
  },
  [STATE(2815)] = {
    [anon_sym_POUNDif] = ACTIONS(7003),
    [anon_sym_POUNDIF] = ACTIONS(7003),
    [anon_sym_POUNDIf] = ACTIONS(7003),
    [anon_sym_POUNDelif] = ACTIONS(7003),
    [anon_sym_POUNDELIF] = ACTIONS(7003),
    [anon_sym_POUNDElif] = ACTIONS(7003),
    [anon_sym_POUNDelse] = ACTIONS(7003),
    [anon_sym_POUNDELSE] = ACTIONS(7003),
    [anon_sym_POUNDElse] = ACTIONS(7003),
    [anon_sym_POUNDelse2] = ACTIONS(7003),
    [anon_sym_POUNDELSE2] = ACTIONS(7003),
    [anon_sym_POUNDElse2] = ACTIONS(7003),
    [anon_sym_POUNDendif] = ACTIONS(7003),
    [anon_sym_POUNDENDIF] = ACTIONS(7003),
    [anon_sym_POUNDEndif] = ACTIONS(7003),
    [anon_sym_POUNDendif2] = ACTIONS(7003),
    [anon_sym_POUNDENDIF2] = ACTIONS(7003),
    [anon_sym_POUNDEndif2] = ACTIONS(7003),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7005),
    [anon_sym_tableextension] = ACTIONS(7003),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7003),
    [anon_sym_Tableextension] = ACTIONS(7003),
    [anon_sym_TableExtension] = ACTIONS(7003),
    [anon_sym_tableExtension] = ACTIONS(7003),
    [sym_page_keyword] = ACTIONS(7005),
    [anon_sym_pageextension] = ACTIONS(7003),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7003),
    [anon_sym_Pageextension] = ACTIONS(7003),
    [anon_sym_PageExtension] = ACTIONS(7003),
    [anon_sym_pageExtension] = ACTIONS(7003),
    [anon_sym_codeunit] = ACTIONS(7003),
    [anon_sym_CODEUNIT] = ACTIONS(7003),
    [anon_sym_Codeunit] = ACTIONS(7003),
    [anon_sym_CodeUnit] = ACTIONS(7003),
    [anon_sym_COdeunit] = ACTIONS(7003),
    [anon_sym_codeUnit] = ACTIONS(7003),
    [sym_report_keyword] = ACTIONS(7005),
    [anon_sym_reportextension] = ACTIONS(7003),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7003),
    [anon_sym_Reportextension] = ACTIONS(7003),
    [anon_sym_ReportExtension] = ACTIONS(7003),
    [anon_sym_reportExtension] = ACTIONS(7003),
    [sym_query_keyword] = ACTIONS(7003),
    [anon_sym_xmlport] = ACTIONS(7003),
    [anon_sym_XMLPORT] = ACTIONS(7003),
    [anon_sym_Xmlport] = ACTIONS(7003),
    [anon_sym_XMLport] = ACTIONS(7003),
    [anon_sym_XMLPort] = ACTIONS(7003),
    [anon_sym_XmlPort] = ACTIONS(7003),
    [anon_sym_enum] = ACTIONS(7005),
    [anon_sym_ENUM] = ACTIONS(7005),
    [anon_sym_Enum] = ACTIONS(7005),
    [anon_sym_eNUM] = ACTIONS(7003),
    [anon_sym_eNum] = ACTIONS(7003),
    [anon_sym_ENum] = ACTIONS(7003),
    [anon_sym_enumextension] = ACTIONS(7003),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7003),
    [anon_sym_Enumextension] = ACTIONS(7003),
    [anon_sym_EnumExtension] = ACTIONS(7003),
    [anon_sym_enumExtension] = ACTIONS(7003),
    [sym_interface_keyword] = ACTIONS(7003),
    [anon_sym_controladdin] = ACTIONS(7003),
    [anon_sym_CONTROLADDIN] = ACTIONS(7003),
    [anon_sym_Controladdin] = ACTIONS(7003),
    [anon_sym_ControlAddIn] = ACTIONS(7003),
    [anon_sym_ControlAddin] = ACTIONS(7003),
    [anon_sym_controlAddIn] = ACTIONS(7003),
    [anon_sym_controlAddin] = ACTIONS(7003),
    [anon_sym_dotnet] = ACTIONS(7003),
    [anon_sym_DOTNET] = ACTIONS(7003),
    [anon_sym_Dotnet] = ACTIONS(7003),
    [anon_sym_DotNet] = ACTIONS(7003),
    [anon_sym_dotNet] = ACTIONS(7003),
    [sym_profile_keyword] = ACTIONS(7005),
    [anon_sym_profileextension] = ACTIONS(7003),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7003),
    [anon_sym_Profileextension] = ACTIONS(7003),
    [anon_sym_ProfileExtension] = ACTIONS(7003),
    [anon_sym_profileExtension] = ACTIONS(7003),
    [anon_sym_permissionset] = ACTIONS(7005),
    [anon_sym_PERMISSIONSET] = ACTIONS(7005),
    [anon_sym_Permissionset] = ACTIONS(7005),
    [anon_sym_PermissionSet] = ACTIONS(7005),
    [anon_sym_permissionSet] = ACTIONS(7005),
    [anon_sym_permissionsetextension] = ACTIONS(7003),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7003),
    [anon_sym_Permissionsetextension] = ACTIONS(7003),
    [anon_sym_PermissionSetExtension] = ACTIONS(7003),
    [anon_sym_permissionSetExtension] = ACTIONS(7003),
    [sym_entitlement_keyword] = ACTIONS(7003),
    [anon_sym_pagecustomization] = ACTIONS(7003),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7003),
    [anon_sym_Pagecustomization] = ACTIONS(7003),
    [anon_sym_PageCustomization] = ACTIONS(7003),
    [anon_sym_pageCustomization] = ACTIONS(7003),
    [sym_using_keyword] = ACTIONS(7003),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7003),
    [sym_preproc_close] = ACTIONS(7003),
  },
  [STATE(2816)] = {
    [anon_sym_POUNDif] = ACTIONS(7007),
    [anon_sym_POUNDIF] = ACTIONS(7007),
    [anon_sym_POUNDIf] = ACTIONS(7007),
    [anon_sym_POUNDelif] = ACTIONS(7007),
    [anon_sym_POUNDELIF] = ACTIONS(7007),
    [anon_sym_POUNDElif] = ACTIONS(7007),
    [anon_sym_POUNDelse] = ACTIONS(7007),
    [anon_sym_POUNDELSE] = ACTIONS(7007),
    [anon_sym_POUNDElse] = ACTIONS(7007),
    [anon_sym_POUNDelse2] = ACTIONS(7007),
    [anon_sym_POUNDELSE2] = ACTIONS(7007),
    [anon_sym_POUNDElse2] = ACTIONS(7007),
    [anon_sym_POUNDendif] = ACTIONS(7007),
    [anon_sym_POUNDENDIF] = ACTIONS(7007),
    [anon_sym_POUNDEndif] = ACTIONS(7007),
    [anon_sym_POUNDendif2] = ACTIONS(7007),
    [anon_sym_POUNDENDIF2] = ACTIONS(7007),
    [anon_sym_POUNDEndif2] = ACTIONS(7007),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7009),
    [anon_sym_tableextension] = ACTIONS(7007),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7007),
    [anon_sym_Tableextension] = ACTIONS(7007),
    [anon_sym_TableExtension] = ACTIONS(7007),
    [anon_sym_tableExtension] = ACTIONS(7007),
    [sym_page_keyword] = ACTIONS(7009),
    [anon_sym_pageextension] = ACTIONS(7007),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7007),
    [anon_sym_Pageextension] = ACTIONS(7007),
    [anon_sym_PageExtension] = ACTIONS(7007),
    [anon_sym_pageExtension] = ACTIONS(7007),
    [anon_sym_codeunit] = ACTIONS(7007),
    [anon_sym_CODEUNIT] = ACTIONS(7007),
    [anon_sym_Codeunit] = ACTIONS(7007),
    [anon_sym_CodeUnit] = ACTIONS(7007),
    [anon_sym_COdeunit] = ACTIONS(7007),
    [anon_sym_codeUnit] = ACTIONS(7007),
    [sym_report_keyword] = ACTIONS(7009),
    [anon_sym_reportextension] = ACTIONS(7007),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7007),
    [anon_sym_Reportextension] = ACTIONS(7007),
    [anon_sym_ReportExtension] = ACTIONS(7007),
    [anon_sym_reportExtension] = ACTIONS(7007),
    [sym_query_keyword] = ACTIONS(7007),
    [anon_sym_xmlport] = ACTIONS(7007),
    [anon_sym_XMLPORT] = ACTIONS(7007),
    [anon_sym_Xmlport] = ACTIONS(7007),
    [anon_sym_XMLport] = ACTIONS(7007),
    [anon_sym_XMLPort] = ACTIONS(7007),
    [anon_sym_XmlPort] = ACTIONS(7007),
    [anon_sym_enum] = ACTIONS(7009),
    [anon_sym_ENUM] = ACTIONS(7009),
    [anon_sym_Enum] = ACTIONS(7009),
    [anon_sym_eNUM] = ACTIONS(7007),
    [anon_sym_eNum] = ACTIONS(7007),
    [anon_sym_ENum] = ACTIONS(7007),
    [anon_sym_enumextension] = ACTIONS(7007),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7007),
    [anon_sym_Enumextension] = ACTIONS(7007),
    [anon_sym_EnumExtension] = ACTIONS(7007),
    [anon_sym_enumExtension] = ACTIONS(7007),
    [sym_interface_keyword] = ACTIONS(7007),
    [anon_sym_controladdin] = ACTIONS(7007),
    [anon_sym_CONTROLADDIN] = ACTIONS(7007),
    [anon_sym_Controladdin] = ACTIONS(7007),
    [anon_sym_ControlAddIn] = ACTIONS(7007),
    [anon_sym_ControlAddin] = ACTIONS(7007),
    [anon_sym_controlAddIn] = ACTIONS(7007),
    [anon_sym_controlAddin] = ACTIONS(7007),
    [anon_sym_dotnet] = ACTIONS(7007),
    [anon_sym_DOTNET] = ACTIONS(7007),
    [anon_sym_Dotnet] = ACTIONS(7007),
    [anon_sym_DotNet] = ACTIONS(7007),
    [anon_sym_dotNet] = ACTIONS(7007),
    [sym_profile_keyword] = ACTIONS(7009),
    [anon_sym_profileextension] = ACTIONS(7007),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7007),
    [anon_sym_Profileextension] = ACTIONS(7007),
    [anon_sym_ProfileExtension] = ACTIONS(7007),
    [anon_sym_profileExtension] = ACTIONS(7007),
    [anon_sym_permissionset] = ACTIONS(7009),
    [anon_sym_PERMISSIONSET] = ACTIONS(7009),
    [anon_sym_Permissionset] = ACTIONS(7009),
    [anon_sym_PermissionSet] = ACTIONS(7009),
    [anon_sym_permissionSet] = ACTIONS(7009),
    [anon_sym_permissionsetextension] = ACTIONS(7007),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7007),
    [anon_sym_Permissionsetextension] = ACTIONS(7007),
    [anon_sym_PermissionSetExtension] = ACTIONS(7007),
    [anon_sym_permissionSetExtension] = ACTIONS(7007),
    [sym_entitlement_keyword] = ACTIONS(7007),
    [anon_sym_pagecustomization] = ACTIONS(7007),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7007),
    [anon_sym_Pagecustomization] = ACTIONS(7007),
    [anon_sym_PageCustomization] = ACTIONS(7007),
    [anon_sym_pageCustomization] = ACTIONS(7007),
    [sym_using_keyword] = ACTIONS(7007),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7007),
    [sym_preproc_close] = ACTIONS(7007),
  },
  [STATE(2817)] = {
    [anon_sym_POUNDif] = ACTIONS(7011),
    [anon_sym_POUNDIF] = ACTIONS(7011),
    [anon_sym_POUNDIf] = ACTIONS(7011),
    [anon_sym_POUNDelif] = ACTIONS(7011),
    [anon_sym_POUNDELIF] = ACTIONS(7011),
    [anon_sym_POUNDElif] = ACTIONS(7011),
    [anon_sym_POUNDelse] = ACTIONS(7011),
    [anon_sym_POUNDELSE] = ACTIONS(7011),
    [anon_sym_POUNDElse] = ACTIONS(7011),
    [anon_sym_POUNDelse2] = ACTIONS(7011),
    [anon_sym_POUNDELSE2] = ACTIONS(7011),
    [anon_sym_POUNDElse2] = ACTIONS(7011),
    [anon_sym_POUNDendif] = ACTIONS(7011),
    [anon_sym_POUNDENDIF] = ACTIONS(7011),
    [anon_sym_POUNDEndif] = ACTIONS(7011),
    [anon_sym_POUNDendif2] = ACTIONS(7011),
    [anon_sym_POUNDENDIF2] = ACTIONS(7011),
    [anon_sym_POUNDEndif2] = ACTIONS(7011),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7013),
    [anon_sym_tableextension] = ACTIONS(7011),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7011),
    [anon_sym_Tableextension] = ACTIONS(7011),
    [anon_sym_TableExtension] = ACTIONS(7011),
    [anon_sym_tableExtension] = ACTIONS(7011),
    [sym_page_keyword] = ACTIONS(7013),
    [anon_sym_pageextension] = ACTIONS(7011),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7011),
    [anon_sym_Pageextension] = ACTIONS(7011),
    [anon_sym_PageExtension] = ACTIONS(7011),
    [anon_sym_pageExtension] = ACTIONS(7011),
    [anon_sym_codeunit] = ACTIONS(7011),
    [anon_sym_CODEUNIT] = ACTIONS(7011),
    [anon_sym_Codeunit] = ACTIONS(7011),
    [anon_sym_CodeUnit] = ACTIONS(7011),
    [anon_sym_COdeunit] = ACTIONS(7011),
    [anon_sym_codeUnit] = ACTIONS(7011),
    [sym_report_keyword] = ACTIONS(7013),
    [anon_sym_reportextension] = ACTIONS(7011),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7011),
    [anon_sym_Reportextension] = ACTIONS(7011),
    [anon_sym_ReportExtension] = ACTIONS(7011),
    [anon_sym_reportExtension] = ACTIONS(7011),
    [sym_query_keyword] = ACTIONS(7011),
    [anon_sym_xmlport] = ACTIONS(7011),
    [anon_sym_XMLPORT] = ACTIONS(7011),
    [anon_sym_Xmlport] = ACTIONS(7011),
    [anon_sym_XMLport] = ACTIONS(7011),
    [anon_sym_XMLPort] = ACTIONS(7011),
    [anon_sym_XmlPort] = ACTIONS(7011),
    [anon_sym_enum] = ACTIONS(7013),
    [anon_sym_ENUM] = ACTIONS(7013),
    [anon_sym_Enum] = ACTIONS(7013),
    [anon_sym_eNUM] = ACTIONS(7011),
    [anon_sym_eNum] = ACTIONS(7011),
    [anon_sym_ENum] = ACTIONS(7011),
    [anon_sym_enumextension] = ACTIONS(7011),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7011),
    [anon_sym_Enumextension] = ACTIONS(7011),
    [anon_sym_EnumExtension] = ACTIONS(7011),
    [anon_sym_enumExtension] = ACTIONS(7011),
    [sym_interface_keyword] = ACTIONS(7011),
    [anon_sym_controladdin] = ACTIONS(7011),
    [anon_sym_CONTROLADDIN] = ACTIONS(7011),
    [anon_sym_Controladdin] = ACTIONS(7011),
    [anon_sym_ControlAddIn] = ACTIONS(7011),
    [anon_sym_ControlAddin] = ACTIONS(7011),
    [anon_sym_controlAddIn] = ACTIONS(7011),
    [anon_sym_controlAddin] = ACTIONS(7011),
    [anon_sym_dotnet] = ACTIONS(7011),
    [anon_sym_DOTNET] = ACTIONS(7011),
    [anon_sym_Dotnet] = ACTIONS(7011),
    [anon_sym_DotNet] = ACTIONS(7011),
    [anon_sym_dotNet] = ACTIONS(7011),
    [sym_profile_keyword] = ACTIONS(7013),
    [anon_sym_profileextension] = ACTIONS(7011),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7011),
    [anon_sym_Profileextension] = ACTIONS(7011),
    [anon_sym_ProfileExtension] = ACTIONS(7011),
    [anon_sym_profileExtension] = ACTIONS(7011),
    [anon_sym_permissionset] = ACTIONS(7013),
    [anon_sym_PERMISSIONSET] = ACTIONS(7013),
    [anon_sym_Permissionset] = ACTIONS(7013),
    [anon_sym_PermissionSet] = ACTIONS(7013),
    [anon_sym_permissionSet] = ACTIONS(7013),
    [anon_sym_permissionsetextension] = ACTIONS(7011),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7011),
    [anon_sym_Permissionsetextension] = ACTIONS(7011),
    [anon_sym_PermissionSetExtension] = ACTIONS(7011),
    [anon_sym_permissionSetExtension] = ACTIONS(7011),
    [sym_entitlement_keyword] = ACTIONS(7011),
    [anon_sym_pagecustomization] = ACTIONS(7011),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7011),
    [anon_sym_Pagecustomization] = ACTIONS(7011),
    [anon_sym_PageCustomization] = ACTIONS(7011),
    [anon_sym_pageCustomization] = ACTIONS(7011),
    [sym_using_keyword] = ACTIONS(7011),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7011),
    [sym_preproc_close] = ACTIONS(7011),
  },
  [STATE(2818)] = {
    [anon_sym_POUNDif] = ACTIONS(7015),
    [anon_sym_POUNDIF] = ACTIONS(7015),
    [anon_sym_POUNDIf] = ACTIONS(7015),
    [anon_sym_POUNDelif] = ACTIONS(7015),
    [anon_sym_POUNDELIF] = ACTIONS(7015),
    [anon_sym_POUNDElif] = ACTIONS(7015),
    [anon_sym_POUNDelse] = ACTIONS(7015),
    [anon_sym_POUNDELSE] = ACTIONS(7015),
    [anon_sym_POUNDElse] = ACTIONS(7015),
    [anon_sym_POUNDelse2] = ACTIONS(7015),
    [anon_sym_POUNDELSE2] = ACTIONS(7015),
    [anon_sym_POUNDElse2] = ACTIONS(7015),
    [anon_sym_POUNDendif] = ACTIONS(7015),
    [anon_sym_POUNDENDIF] = ACTIONS(7015),
    [anon_sym_POUNDEndif] = ACTIONS(7015),
    [anon_sym_POUNDendif2] = ACTIONS(7015),
    [anon_sym_POUNDENDIF2] = ACTIONS(7015),
    [anon_sym_POUNDEndif2] = ACTIONS(7015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7017),
    [anon_sym_tableextension] = ACTIONS(7015),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7015),
    [anon_sym_Tableextension] = ACTIONS(7015),
    [anon_sym_TableExtension] = ACTIONS(7015),
    [anon_sym_tableExtension] = ACTIONS(7015),
    [sym_page_keyword] = ACTIONS(7017),
    [anon_sym_pageextension] = ACTIONS(7015),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7015),
    [anon_sym_Pageextension] = ACTIONS(7015),
    [anon_sym_PageExtension] = ACTIONS(7015),
    [anon_sym_pageExtension] = ACTIONS(7015),
    [anon_sym_codeunit] = ACTIONS(7015),
    [anon_sym_CODEUNIT] = ACTIONS(7015),
    [anon_sym_Codeunit] = ACTIONS(7015),
    [anon_sym_CodeUnit] = ACTIONS(7015),
    [anon_sym_COdeunit] = ACTIONS(7015),
    [anon_sym_codeUnit] = ACTIONS(7015),
    [sym_report_keyword] = ACTIONS(7017),
    [anon_sym_reportextension] = ACTIONS(7015),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7015),
    [anon_sym_Reportextension] = ACTIONS(7015),
    [anon_sym_ReportExtension] = ACTIONS(7015),
    [anon_sym_reportExtension] = ACTIONS(7015),
    [sym_query_keyword] = ACTIONS(7015),
    [anon_sym_xmlport] = ACTIONS(7015),
    [anon_sym_XMLPORT] = ACTIONS(7015),
    [anon_sym_Xmlport] = ACTIONS(7015),
    [anon_sym_XMLport] = ACTIONS(7015),
    [anon_sym_XMLPort] = ACTIONS(7015),
    [anon_sym_XmlPort] = ACTIONS(7015),
    [anon_sym_enum] = ACTIONS(7017),
    [anon_sym_ENUM] = ACTIONS(7017),
    [anon_sym_Enum] = ACTIONS(7017),
    [anon_sym_eNUM] = ACTIONS(7015),
    [anon_sym_eNum] = ACTIONS(7015),
    [anon_sym_ENum] = ACTIONS(7015),
    [anon_sym_enumextension] = ACTIONS(7015),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7015),
    [anon_sym_Enumextension] = ACTIONS(7015),
    [anon_sym_EnumExtension] = ACTIONS(7015),
    [anon_sym_enumExtension] = ACTIONS(7015),
    [sym_interface_keyword] = ACTIONS(7015),
    [anon_sym_controladdin] = ACTIONS(7015),
    [anon_sym_CONTROLADDIN] = ACTIONS(7015),
    [anon_sym_Controladdin] = ACTIONS(7015),
    [anon_sym_ControlAddIn] = ACTIONS(7015),
    [anon_sym_ControlAddin] = ACTIONS(7015),
    [anon_sym_controlAddIn] = ACTIONS(7015),
    [anon_sym_controlAddin] = ACTIONS(7015),
    [anon_sym_dotnet] = ACTIONS(7015),
    [anon_sym_DOTNET] = ACTIONS(7015),
    [anon_sym_Dotnet] = ACTIONS(7015),
    [anon_sym_DotNet] = ACTIONS(7015),
    [anon_sym_dotNet] = ACTIONS(7015),
    [sym_profile_keyword] = ACTIONS(7017),
    [anon_sym_profileextension] = ACTIONS(7015),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7015),
    [anon_sym_Profileextension] = ACTIONS(7015),
    [anon_sym_ProfileExtension] = ACTIONS(7015),
    [anon_sym_profileExtension] = ACTIONS(7015),
    [anon_sym_permissionset] = ACTIONS(7017),
    [anon_sym_PERMISSIONSET] = ACTIONS(7017),
    [anon_sym_Permissionset] = ACTIONS(7017),
    [anon_sym_PermissionSet] = ACTIONS(7017),
    [anon_sym_permissionSet] = ACTIONS(7017),
    [anon_sym_permissionsetextension] = ACTIONS(7015),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7015),
    [anon_sym_Permissionsetextension] = ACTIONS(7015),
    [anon_sym_PermissionSetExtension] = ACTIONS(7015),
    [anon_sym_permissionSetExtension] = ACTIONS(7015),
    [sym_entitlement_keyword] = ACTIONS(7015),
    [anon_sym_pagecustomization] = ACTIONS(7015),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7015),
    [anon_sym_Pagecustomization] = ACTIONS(7015),
    [anon_sym_PageCustomization] = ACTIONS(7015),
    [anon_sym_pageCustomization] = ACTIONS(7015),
    [sym_using_keyword] = ACTIONS(7015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7015),
    [sym_preproc_close] = ACTIONS(7015),
  },
  [STATE(2819)] = {
    [anon_sym_POUNDif] = ACTIONS(7019),
    [anon_sym_POUNDIF] = ACTIONS(7019),
    [anon_sym_POUNDIf] = ACTIONS(7019),
    [anon_sym_POUNDelif] = ACTIONS(7019),
    [anon_sym_POUNDELIF] = ACTIONS(7019),
    [anon_sym_POUNDElif] = ACTIONS(7019),
    [anon_sym_POUNDelse] = ACTIONS(7019),
    [anon_sym_POUNDELSE] = ACTIONS(7019),
    [anon_sym_POUNDElse] = ACTIONS(7019),
    [anon_sym_POUNDelse2] = ACTIONS(7019),
    [anon_sym_POUNDELSE2] = ACTIONS(7019),
    [anon_sym_POUNDElse2] = ACTIONS(7019),
    [anon_sym_POUNDendif] = ACTIONS(7019),
    [anon_sym_POUNDENDIF] = ACTIONS(7019),
    [anon_sym_POUNDEndif] = ACTIONS(7019),
    [anon_sym_POUNDendif2] = ACTIONS(7019),
    [anon_sym_POUNDENDIF2] = ACTIONS(7019),
    [anon_sym_POUNDEndif2] = ACTIONS(7019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7021),
    [anon_sym_tableextension] = ACTIONS(7019),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7019),
    [anon_sym_Tableextension] = ACTIONS(7019),
    [anon_sym_TableExtension] = ACTIONS(7019),
    [anon_sym_tableExtension] = ACTIONS(7019),
    [sym_page_keyword] = ACTIONS(7021),
    [anon_sym_pageextension] = ACTIONS(7019),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7019),
    [anon_sym_Pageextension] = ACTIONS(7019),
    [anon_sym_PageExtension] = ACTIONS(7019),
    [anon_sym_pageExtension] = ACTIONS(7019),
    [anon_sym_codeunit] = ACTIONS(7019),
    [anon_sym_CODEUNIT] = ACTIONS(7019),
    [anon_sym_Codeunit] = ACTIONS(7019),
    [anon_sym_CodeUnit] = ACTIONS(7019),
    [anon_sym_COdeunit] = ACTIONS(7019),
    [anon_sym_codeUnit] = ACTIONS(7019),
    [sym_report_keyword] = ACTIONS(7021),
    [anon_sym_reportextension] = ACTIONS(7019),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7019),
    [anon_sym_Reportextension] = ACTIONS(7019),
    [anon_sym_ReportExtension] = ACTIONS(7019),
    [anon_sym_reportExtension] = ACTIONS(7019),
    [sym_query_keyword] = ACTIONS(7019),
    [anon_sym_xmlport] = ACTIONS(7019),
    [anon_sym_XMLPORT] = ACTIONS(7019),
    [anon_sym_Xmlport] = ACTIONS(7019),
    [anon_sym_XMLport] = ACTIONS(7019),
    [anon_sym_XMLPort] = ACTIONS(7019),
    [anon_sym_XmlPort] = ACTIONS(7019),
    [anon_sym_enum] = ACTIONS(7021),
    [anon_sym_ENUM] = ACTIONS(7021),
    [anon_sym_Enum] = ACTIONS(7021),
    [anon_sym_eNUM] = ACTIONS(7019),
    [anon_sym_eNum] = ACTIONS(7019),
    [anon_sym_ENum] = ACTIONS(7019),
    [anon_sym_enumextension] = ACTIONS(7019),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7019),
    [anon_sym_Enumextension] = ACTIONS(7019),
    [anon_sym_EnumExtension] = ACTIONS(7019),
    [anon_sym_enumExtension] = ACTIONS(7019),
    [sym_interface_keyword] = ACTIONS(7019),
    [anon_sym_controladdin] = ACTIONS(7019),
    [anon_sym_CONTROLADDIN] = ACTIONS(7019),
    [anon_sym_Controladdin] = ACTIONS(7019),
    [anon_sym_ControlAddIn] = ACTIONS(7019),
    [anon_sym_ControlAddin] = ACTIONS(7019),
    [anon_sym_controlAddIn] = ACTIONS(7019),
    [anon_sym_controlAddin] = ACTIONS(7019),
    [anon_sym_dotnet] = ACTIONS(7019),
    [anon_sym_DOTNET] = ACTIONS(7019),
    [anon_sym_Dotnet] = ACTIONS(7019),
    [anon_sym_DotNet] = ACTIONS(7019),
    [anon_sym_dotNet] = ACTIONS(7019),
    [sym_profile_keyword] = ACTIONS(7021),
    [anon_sym_profileextension] = ACTIONS(7019),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7019),
    [anon_sym_Profileextension] = ACTIONS(7019),
    [anon_sym_ProfileExtension] = ACTIONS(7019),
    [anon_sym_profileExtension] = ACTIONS(7019),
    [anon_sym_permissionset] = ACTIONS(7021),
    [anon_sym_PERMISSIONSET] = ACTIONS(7021),
    [anon_sym_Permissionset] = ACTIONS(7021),
    [anon_sym_PermissionSet] = ACTIONS(7021),
    [anon_sym_permissionSet] = ACTIONS(7021),
    [anon_sym_permissionsetextension] = ACTIONS(7019),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7019),
    [anon_sym_Permissionsetextension] = ACTIONS(7019),
    [anon_sym_PermissionSetExtension] = ACTIONS(7019),
    [anon_sym_permissionSetExtension] = ACTIONS(7019),
    [sym_entitlement_keyword] = ACTIONS(7019),
    [anon_sym_pagecustomization] = ACTIONS(7019),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7019),
    [anon_sym_Pagecustomization] = ACTIONS(7019),
    [anon_sym_PageCustomization] = ACTIONS(7019),
    [anon_sym_pageCustomization] = ACTIONS(7019),
    [sym_using_keyword] = ACTIONS(7019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7019),
    [sym_preproc_close] = ACTIONS(7019),
  },
  [STATE(2820)] = {
    [anon_sym_POUNDif] = ACTIONS(7023),
    [anon_sym_POUNDIF] = ACTIONS(7023),
    [anon_sym_POUNDIf] = ACTIONS(7023),
    [anon_sym_POUNDelif] = ACTIONS(7023),
    [anon_sym_POUNDELIF] = ACTIONS(7023),
    [anon_sym_POUNDElif] = ACTIONS(7023),
    [anon_sym_POUNDelse] = ACTIONS(7023),
    [anon_sym_POUNDELSE] = ACTIONS(7023),
    [anon_sym_POUNDElse] = ACTIONS(7023),
    [anon_sym_POUNDelse2] = ACTIONS(7023),
    [anon_sym_POUNDELSE2] = ACTIONS(7023),
    [anon_sym_POUNDElse2] = ACTIONS(7023),
    [anon_sym_POUNDendif] = ACTIONS(7023),
    [anon_sym_POUNDENDIF] = ACTIONS(7023),
    [anon_sym_POUNDEndif] = ACTIONS(7023),
    [anon_sym_POUNDendif2] = ACTIONS(7023),
    [anon_sym_POUNDENDIF2] = ACTIONS(7023),
    [anon_sym_POUNDEndif2] = ACTIONS(7023),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7025),
    [anon_sym_tableextension] = ACTIONS(7023),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7023),
    [anon_sym_Tableextension] = ACTIONS(7023),
    [anon_sym_TableExtension] = ACTIONS(7023),
    [anon_sym_tableExtension] = ACTIONS(7023),
    [sym_page_keyword] = ACTIONS(7025),
    [anon_sym_pageextension] = ACTIONS(7023),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7023),
    [anon_sym_Pageextension] = ACTIONS(7023),
    [anon_sym_PageExtension] = ACTIONS(7023),
    [anon_sym_pageExtension] = ACTIONS(7023),
    [anon_sym_codeunit] = ACTIONS(7023),
    [anon_sym_CODEUNIT] = ACTIONS(7023),
    [anon_sym_Codeunit] = ACTIONS(7023),
    [anon_sym_CodeUnit] = ACTIONS(7023),
    [anon_sym_COdeunit] = ACTIONS(7023),
    [anon_sym_codeUnit] = ACTIONS(7023),
    [sym_report_keyword] = ACTIONS(7025),
    [anon_sym_reportextension] = ACTIONS(7023),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7023),
    [anon_sym_Reportextension] = ACTIONS(7023),
    [anon_sym_ReportExtension] = ACTIONS(7023),
    [anon_sym_reportExtension] = ACTIONS(7023),
    [sym_query_keyword] = ACTIONS(7023),
    [anon_sym_xmlport] = ACTIONS(7023),
    [anon_sym_XMLPORT] = ACTIONS(7023),
    [anon_sym_Xmlport] = ACTIONS(7023),
    [anon_sym_XMLport] = ACTIONS(7023),
    [anon_sym_XMLPort] = ACTIONS(7023),
    [anon_sym_XmlPort] = ACTIONS(7023),
    [anon_sym_enum] = ACTIONS(7025),
    [anon_sym_ENUM] = ACTIONS(7025),
    [anon_sym_Enum] = ACTIONS(7025),
    [anon_sym_eNUM] = ACTIONS(7023),
    [anon_sym_eNum] = ACTIONS(7023),
    [anon_sym_ENum] = ACTIONS(7023),
    [anon_sym_enumextension] = ACTIONS(7023),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7023),
    [anon_sym_Enumextension] = ACTIONS(7023),
    [anon_sym_EnumExtension] = ACTIONS(7023),
    [anon_sym_enumExtension] = ACTIONS(7023),
    [sym_interface_keyword] = ACTIONS(7023),
    [anon_sym_controladdin] = ACTIONS(7023),
    [anon_sym_CONTROLADDIN] = ACTIONS(7023),
    [anon_sym_Controladdin] = ACTIONS(7023),
    [anon_sym_ControlAddIn] = ACTIONS(7023),
    [anon_sym_ControlAddin] = ACTIONS(7023),
    [anon_sym_controlAddIn] = ACTIONS(7023),
    [anon_sym_controlAddin] = ACTIONS(7023),
    [anon_sym_dotnet] = ACTIONS(7023),
    [anon_sym_DOTNET] = ACTIONS(7023),
    [anon_sym_Dotnet] = ACTIONS(7023),
    [anon_sym_DotNet] = ACTIONS(7023),
    [anon_sym_dotNet] = ACTIONS(7023),
    [sym_profile_keyword] = ACTIONS(7025),
    [anon_sym_profileextension] = ACTIONS(7023),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7023),
    [anon_sym_Profileextension] = ACTIONS(7023),
    [anon_sym_ProfileExtension] = ACTIONS(7023),
    [anon_sym_profileExtension] = ACTIONS(7023),
    [anon_sym_permissionset] = ACTIONS(7025),
    [anon_sym_PERMISSIONSET] = ACTIONS(7025),
    [anon_sym_Permissionset] = ACTIONS(7025),
    [anon_sym_PermissionSet] = ACTIONS(7025),
    [anon_sym_permissionSet] = ACTIONS(7025),
    [anon_sym_permissionsetextension] = ACTIONS(7023),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7023),
    [anon_sym_Permissionsetextension] = ACTIONS(7023),
    [anon_sym_PermissionSetExtension] = ACTIONS(7023),
    [anon_sym_permissionSetExtension] = ACTIONS(7023),
    [sym_entitlement_keyword] = ACTIONS(7023),
    [anon_sym_pagecustomization] = ACTIONS(7023),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7023),
    [anon_sym_Pagecustomization] = ACTIONS(7023),
    [anon_sym_PageCustomization] = ACTIONS(7023),
    [anon_sym_pageCustomization] = ACTIONS(7023),
    [sym_using_keyword] = ACTIONS(7023),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7023),
    [sym_preproc_close] = ACTIONS(7023),
  },
  [STATE(2821)] = {
    [anon_sym_POUNDif] = ACTIONS(7027),
    [anon_sym_POUNDIF] = ACTIONS(7027),
    [anon_sym_POUNDIf] = ACTIONS(7027),
    [anon_sym_POUNDelif] = ACTIONS(7027),
    [anon_sym_POUNDELIF] = ACTIONS(7027),
    [anon_sym_POUNDElif] = ACTIONS(7027),
    [anon_sym_POUNDelse] = ACTIONS(7027),
    [anon_sym_POUNDELSE] = ACTIONS(7027),
    [anon_sym_POUNDElse] = ACTIONS(7027),
    [anon_sym_POUNDelse2] = ACTIONS(7027),
    [anon_sym_POUNDELSE2] = ACTIONS(7027),
    [anon_sym_POUNDElse2] = ACTIONS(7027),
    [anon_sym_POUNDendif] = ACTIONS(7027),
    [anon_sym_POUNDENDIF] = ACTIONS(7027),
    [anon_sym_POUNDEndif] = ACTIONS(7027),
    [anon_sym_POUNDendif2] = ACTIONS(7027),
    [anon_sym_POUNDENDIF2] = ACTIONS(7027),
    [anon_sym_POUNDEndif2] = ACTIONS(7027),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7029),
    [anon_sym_tableextension] = ACTIONS(7027),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7027),
    [anon_sym_Tableextension] = ACTIONS(7027),
    [anon_sym_TableExtension] = ACTIONS(7027),
    [anon_sym_tableExtension] = ACTIONS(7027),
    [sym_page_keyword] = ACTIONS(7029),
    [anon_sym_pageextension] = ACTIONS(7027),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7027),
    [anon_sym_Pageextension] = ACTIONS(7027),
    [anon_sym_PageExtension] = ACTIONS(7027),
    [anon_sym_pageExtension] = ACTIONS(7027),
    [anon_sym_codeunit] = ACTIONS(7027),
    [anon_sym_CODEUNIT] = ACTIONS(7027),
    [anon_sym_Codeunit] = ACTIONS(7027),
    [anon_sym_CodeUnit] = ACTIONS(7027),
    [anon_sym_COdeunit] = ACTIONS(7027),
    [anon_sym_codeUnit] = ACTIONS(7027),
    [sym_report_keyword] = ACTIONS(7029),
    [anon_sym_reportextension] = ACTIONS(7027),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7027),
    [anon_sym_Reportextension] = ACTIONS(7027),
    [anon_sym_ReportExtension] = ACTIONS(7027),
    [anon_sym_reportExtension] = ACTIONS(7027),
    [sym_query_keyword] = ACTIONS(7027),
    [anon_sym_xmlport] = ACTIONS(7027),
    [anon_sym_XMLPORT] = ACTIONS(7027),
    [anon_sym_Xmlport] = ACTIONS(7027),
    [anon_sym_XMLport] = ACTIONS(7027),
    [anon_sym_XMLPort] = ACTIONS(7027),
    [anon_sym_XmlPort] = ACTIONS(7027),
    [anon_sym_enum] = ACTIONS(7029),
    [anon_sym_ENUM] = ACTIONS(7029),
    [anon_sym_Enum] = ACTIONS(7029),
    [anon_sym_eNUM] = ACTIONS(7027),
    [anon_sym_eNum] = ACTIONS(7027),
    [anon_sym_ENum] = ACTIONS(7027),
    [anon_sym_enumextension] = ACTIONS(7027),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7027),
    [anon_sym_Enumextension] = ACTIONS(7027),
    [anon_sym_EnumExtension] = ACTIONS(7027),
    [anon_sym_enumExtension] = ACTIONS(7027),
    [sym_interface_keyword] = ACTIONS(7027),
    [anon_sym_controladdin] = ACTIONS(7027),
    [anon_sym_CONTROLADDIN] = ACTIONS(7027),
    [anon_sym_Controladdin] = ACTIONS(7027),
    [anon_sym_ControlAddIn] = ACTIONS(7027),
    [anon_sym_ControlAddin] = ACTIONS(7027),
    [anon_sym_controlAddIn] = ACTIONS(7027),
    [anon_sym_controlAddin] = ACTIONS(7027),
    [anon_sym_dotnet] = ACTIONS(7027),
    [anon_sym_DOTNET] = ACTIONS(7027),
    [anon_sym_Dotnet] = ACTIONS(7027),
    [anon_sym_DotNet] = ACTIONS(7027),
    [anon_sym_dotNet] = ACTIONS(7027),
    [sym_profile_keyword] = ACTIONS(7029),
    [anon_sym_profileextension] = ACTIONS(7027),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7027),
    [anon_sym_Profileextension] = ACTIONS(7027),
    [anon_sym_ProfileExtension] = ACTIONS(7027),
    [anon_sym_profileExtension] = ACTIONS(7027),
    [anon_sym_permissionset] = ACTIONS(7029),
    [anon_sym_PERMISSIONSET] = ACTIONS(7029),
    [anon_sym_Permissionset] = ACTIONS(7029),
    [anon_sym_PermissionSet] = ACTIONS(7029),
    [anon_sym_permissionSet] = ACTIONS(7029),
    [anon_sym_permissionsetextension] = ACTIONS(7027),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7027),
    [anon_sym_Permissionsetextension] = ACTIONS(7027),
    [anon_sym_PermissionSetExtension] = ACTIONS(7027),
    [anon_sym_permissionSetExtension] = ACTIONS(7027),
    [sym_entitlement_keyword] = ACTIONS(7027),
    [anon_sym_pagecustomization] = ACTIONS(7027),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7027),
    [anon_sym_Pagecustomization] = ACTIONS(7027),
    [anon_sym_PageCustomization] = ACTIONS(7027),
    [anon_sym_pageCustomization] = ACTIONS(7027),
    [sym_using_keyword] = ACTIONS(7027),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7027),
    [sym_preproc_close] = ACTIONS(7027),
  },
  [STATE(2822)] = {
    [anon_sym_POUNDif] = ACTIONS(7031),
    [anon_sym_POUNDIF] = ACTIONS(7031),
    [anon_sym_POUNDIf] = ACTIONS(7031),
    [anon_sym_POUNDelif] = ACTIONS(7031),
    [anon_sym_POUNDELIF] = ACTIONS(7031),
    [anon_sym_POUNDElif] = ACTIONS(7031),
    [anon_sym_POUNDelse] = ACTIONS(7031),
    [anon_sym_POUNDELSE] = ACTIONS(7031),
    [anon_sym_POUNDElse] = ACTIONS(7031),
    [anon_sym_POUNDelse2] = ACTIONS(7031),
    [anon_sym_POUNDELSE2] = ACTIONS(7031),
    [anon_sym_POUNDElse2] = ACTIONS(7031),
    [anon_sym_POUNDendif] = ACTIONS(7031),
    [anon_sym_POUNDENDIF] = ACTIONS(7031),
    [anon_sym_POUNDEndif] = ACTIONS(7031),
    [anon_sym_POUNDendif2] = ACTIONS(7031),
    [anon_sym_POUNDENDIF2] = ACTIONS(7031),
    [anon_sym_POUNDEndif2] = ACTIONS(7031),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7033),
    [anon_sym_tableextension] = ACTIONS(7031),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7031),
    [anon_sym_Tableextension] = ACTIONS(7031),
    [anon_sym_TableExtension] = ACTIONS(7031),
    [anon_sym_tableExtension] = ACTIONS(7031),
    [sym_page_keyword] = ACTIONS(7033),
    [anon_sym_pageextension] = ACTIONS(7031),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7031),
    [anon_sym_Pageextension] = ACTIONS(7031),
    [anon_sym_PageExtension] = ACTIONS(7031),
    [anon_sym_pageExtension] = ACTIONS(7031),
    [anon_sym_codeunit] = ACTIONS(7031),
    [anon_sym_CODEUNIT] = ACTIONS(7031),
    [anon_sym_Codeunit] = ACTIONS(7031),
    [anon_sym_CodeUnit] = ACTIONS(7031),
    [anon_sym_COdeunit] = ACTIONS(7031),
    [anon_sym_codeUnit] = ACTIONS(7031),
    [sym_report_keyword] = ACTIONS(7033),
    [anon_sym_reportextension] = ACTIONS(7031),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7031),
    [anon_sym_Reportextension] = ACTIONS(7031),
    [anon_sym_ReportExtension] = ACTIONS(7031),
    [anon_sym_reportExtension] = ACTIONS(7031),
    [sym_query_keyword] = ACTIONS(7031),
    [anon_sym_xmlport] = ACTIONS(7031),
    [anon_sym_XMLPORT] = ACTIONS(7031),
    [anon_sym_Xmlport] = ACTIONS(7031),
    [anon_sym_XMLport] = ACTIONS(7031),
    [anon_sym_XMLPort] = ACTIONS(7031),
    [anon_sym_XmlPort] = ACTIONS(7031),
    [anon_sym_enum] = ACTIONS(7033),
    [anon_sym_ENUM] = ACTIONS(7033),
    [anon_sym_Enum] = ACTIONS(7033),
    [anon_sym_eNUM] = ACTIONS(7031),
    [anon_sym_eNum] = ACTIONS(7031),
    [anon_sym_ENum] = ACTIONS(7031),
    [anon_sym_enumextension] = ACTIONS(7031),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7031),
    [anon_sym_Enumextension] = ACTIONS(7031),
    [anon_sym_EnumExtension] = ACTIONS(7031),
    [anon_sym_enumExtension] = ACTIONS(7031),
    [sym_interface_keyword] = ACTIONS(7031),
    [anon_sym_controladdin] = ACTIONS(7031),
    [anon_sym_CONTROLADDIN] = ACTIONS(7031),
    [anon_sym_Controladdin] = ACTIONS(7031),
    [anon_sym_ControlAddIn] = ACTIONS(7031),
    [anon_sym_ControlAddin] = ACTIONS(7031),
    [anon_sym_controlAddIn] = ACTIONS(7031),
    [anon_sym_controlAddin] = ACTIONS(7031),
    [anon_sym_dotnet] = ACTIONS(7031),
    [anon_sym_DOTNET] = ACTIONS(7031),
    [anon_sym_Dotnet] = ACTIONS(7031),
    [anon_sym_DotNet] = ACTIONS(7031),
    [anon_sym_dotNet] = ACTIONS(7031),
    [sym_profile_keyword] = ACTIONS(7033),
    [anon_sym_profileextension] = ACTIONS(7031),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7031),
    [anon_sym_Profileextension] = ACTIONS(7031),
    [anon_sym_ProfileExtension] = ACTIONS(7031),
    [anon_sym_profileExtension] = ACTIONS(7031),
    [anon_sym_permissionset] = ACTIONS(7033),
    [anon_sym_PERMISSIONSET] = ACTIONS(7033),
    [anon_sym_Permissionset] = ACTIONS(7033),
    [anon_sym_PermissionSet] = ACTIONS(7033),
    [anon_sym_permissionSet] = ACTIONS(7033),
    [anon_sym_permissionsetextension] = ACTIONS(7031),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7031),
    [anon_sym_Permissionsetextension] = ACTIONS(7031),
    [anon_sym_PermissionSetExtension] = ACTIONS(7031),
    [anon_sym_permissionSetExtension] = ACTIONS(7031),
    [sym_entitlement_keyword] = ACTIONS(7031),
    [anon_sym_pagecustomization] = ACTIONS(7031),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7031),
    [anon_sym_Pagecustomization] = ACTIONS(7031),
    [anon_sym_PageCustomization] = ACTIONS(7031),
    [anon_sym_pageCustomization] = ACTIONS(7031),
    [sym_using_keyword] = ACTIONS(7031),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7031),
    [sym_preproc_close] = ACTIONS(7031),
  },
  [STATE(2823)] = {
    [anon_sym_POUNDif] = ACTIONS(7035),
    [anon_sym_POUNDIF] = ACTIONS(7035),
    [anon_sym_POUNDIf] = ACTIONS(7035),
    [anon_sym_POUNDelif] = ACTIONS(7035),
    [anon_sym_POUNDELIF] = ACTIONS(7035),
    [anon_sym_POUNDElif] = ACTIONS(7035),
    [anon_sym_POUNDelse] = ACTIONS(7035),
    [anon_sym_POUNDELSE] = ACTIONS(7035),
    [anon_sym_POUNDElse] = ACTIONS(7035),
    [anon_sym_POUNDelse2] = ACTIONS(7035),
    [anon_sym_POUNDELSE2] = ACTIONS(7035),
    [anon_sym_POUNDElse2] = ACTIONS(7035),
    [anon_sym_POUNDendif] = ACTIONS(7035),
    [anon_sym_POUNDENDIF] = ACTIONS(7035),
    [anon_sym_POUNDEndif] = ACTIONS(7035),
    [anon_sym_POUNDendif2] = ACTIONS(7035),
    [anon_sym_POUNDENDIF2] = ACTIONS(7035),
    [anon_sym_POUNDEndif2] = ACTIONS(7035),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7037),
    [anon_sym_tableextension] = ACTIONS(7035),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7035),
    [anon_sym_Tableextension] = ACTIONS(7035),
    [anon_sym_TableExtension] = ACTIONS(7035),
    [anon_sym_tableExtension] = ACTIONS(7035),
    [sym_page_keyword] = ACTIONS(7037),
    [anon_sym_pageextension] = ACTIONS(7035),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7035),
    [anon_sym_Pageextension] = ACTIONS(7035),
    [anon_sym_PageExtension] = ACTIONS(7035),
    [anon_sym_pageExtension] = ACTIONS(7035),
    [anon_sym_codeunit] = ACTIONS(7035),
    [anon_sym_CODEUNIT] = ACTIONS(7035),
    [anon_sym_Codeunit] = ACTIONS(7035),
    [anon_sym_CodeUnit] = ACTIONS(7035),
    [anon_sym_COdeunit] = ACTIONS(7035),
    [anon_sym_codeUnit] = ACTIONS(7035),
    [sym_report_keyword] = ACTIONS(7037),
    [anon_sym_reportextension] = ACTIONS(7035),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7035),
    [anon_sym_Reportextension] = ACTIONS(7035),
    [anon_sym_ReportExtension] = ACTIONS(7035),
    [anon_sym_reportExtension] = ACTIONS(7035),
    [sym_query_keyword] = ACTIONS(7035),
    [anon_sym_xmlport] = ACTIONS(7035),
    [anon_sym_XMLPORT] = ACTIONS(7035),
    [anon_sym_Xmlport] = ACTIONS(7035),
    [anon_sym_XMLport] = ACTIONS(7035),
    [anon_sym_XMLPort] = ACTIONS(7035),
    [anon_sym_XmlPort] = ACTIONS(7035),
    [anon_sym_enum] = ACTIONS(7037),
    [anon_sym_ENUM] = ACTIONS(7037),
    [anon_sym_Enum] = ACTIONS(7037),
    [anon_sym_eNUM] = ACTIONS(7035),
    [anon_sym_eNum] = ACTIONS(7035),
    [anon_sym_ENum] = ACTIONS(7035),
    [anon_sym_enumextension] = ACTIONS(7035),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7035),
    [anon_sym_Enumextension] = ACTIONS(7035),
    [anon_sym_EnumExtension] = ACTIONS(7035),
    [anon_sym_enumExtension] = ACTIONS(7035),
    [sym_interface_keyword] = ACTIONS(7035),
    [anon_sym_controladdin] = ACTIONS(7035),
    [anon_sym_CONTROLADDIN] = ACTIONS(7035),
    [anon_sym_Controladdin] = ACTIONS(7035),
    [anon_sym_ControlAddIn] = ACTIONS(7035),
    [anon_sym_ControlAddin] = ACTIONS(7035),
    [anon_sym_controlAddIn] = ACTIONS(7035),
    [anon_sym_controlAddin] = ACTIONS(7035),
    [anon_sym_dotnet] = ACTIONS(7035),
    [anon_sym_DOTNET] = ACTIONS(7035),
    [anon_sym_Dotnet] = ACTIONS(7035),
    [anon_sym_DotNet] = ACTIONS(7035),
    [anon_sym_dotNet] = ACTIONS(7035),
    [sym_profile_keyword] = ACTIONS(7037),
    [anon_sym_profileextension] = ACTIONS(7035),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7035),
    [anon_sym_Profileextension] = ACTIONS(7035),
    [anon_sym_ProfileExtension] = ACTIONS(7035),
    [anon_sym_profileExtension] = ACTIONS(7035),
    [anon_sym_permissionset] = ACTIONS(7037),
    [anon_sym_PERMISSIONSET] = ACTIONS(7037),
    [anon_sym_Permissionset] = ACTIONS(7037),
    [anon_sym_PermissionSet] = ACTIONS(7037),
    [anon_sym_permissionSet] = ACTIONS(7037),
    [anon_sym_permissionsetextension] = ACTIONS(7035),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7035),
    [anon_sym_Permissionsetextension] = ACTIONS(7035),
    [anon_sym_PermissionSetExtension] = ACTIONS(7035),
    [anon_sym_permissionSetExtension] = ACTIONS(7035),
    [sym_entitlement_keyword] = ACTIONS(7035),
    [anon_sym_pagecustomization] = ACTIONS(7035),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7035),
    [anon_sym_Pagecustomization] = ACTIONS(7035),
    [anon_sym_PageCustomization] = ACTIONS(7035),
    [anon_sym_pageCustomization] = ACTIONS(7035),
    [sym_using_keyword] = ACTIONS(7035),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7035),
    [sym_preproc_close] = ACTIONS(7035),
  },
  [STATE(2824)] = {
    [anon_sym_POUNDif] = ACTIONS(7039),
    [anon_sym_POUNDIF] = ACTIONS(7039),
    [anon_sym_POUNDIf] = ACTIONS(7039),
    [anon_sym_POUNDelif] = ACTIONS(7039),
    [anon_sym_POUNDELIF] = ACTIONS(7039),
    [anon_sym_POUNDElif] = ACTIONS(7039),
    [anon_sym_POUNDelse] = ACTIONS(7039),
    [anon_sym_POUNDELSE] = ACTIONS(7039),
    [anon_sym_POUNDElse] = ACTIONS(7039),
    [anon_sym_POUNDelse2] = ACTIONS(7039),
    [anon_sym_POUNDELSE2] = ACTIONS(7039),
    [anon_sym_POUNDElse2] = ACTIONS(7039),
    [anon_sym_POUNDendif] = ACTIONS(7039),
    [anon_sym_POUNDENDIF] = ACTIONS(7039),
    [anon_sym_POUNDEndif] = ACTIONS(7039),
    [anon_sym_POUNDendif2] = ACTIONS(7039),
    [anon_sym_POUNDENDIF2] = ACTIONS(7039),
    [anon_sym_POUNDEndif2] = ACTIONS(7039),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7041),
    [anon_sym_tableextension] = ACTIONS(7039),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7039),
    [anon_sym_Tableextension] = ACTIONS(7039),
    [anon_sym_TableExtension] = ACTIONS(7039),
    [anon_sym_tableExtension] = ACTIONS(7039),
    [sym_page_keyword] = ACTIONS(7041),
    [anon_sym_pageextension] = ACTIONS(7039),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7039),
    [anon_sym_Pageextension] = ACTIONS(7039),
    [anon_sym_PageExtension] = ACTIONS(7039),
    [anon_sym_pageExtension] = ACTIONS(7039),
    [anon_sym_codeunit] = ACTIONS(7039),
    [anon_sym_CODEUNIT] = ACTIONS(7039),
    [anon_sym_Codeunit] = ACTIONS(7039),
    [anon_sym_CodeUnit] = ACTIONS(7039),
    [anon_sym_COdeunit] = ACTIONS(7039),
    [anon_sym_codeUnit] = ACTIONS(7039),
    [sym_report_keyword] = ACTIONS(7041),
    [anon_sym_reportextension] = ACTIONS(7039),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7039),
    [anon_sym_Reportextension] = ACTIONS(7039),
    [anon_sym_ReportExtension] = ACTIONS(7039),
    [anon_sym_reportExtension] = ACTIONS(7039),
    [sym_query_keyword] = ACTIONS(7039),
    [anon_sym_xmlport] = ACTIONS(7039),
    [anon_sym_XMLPORT] = ACTIONS(7039),
    [anon_sym_Xmlport] = ACTIONS(7039),
    [anon_sym_XMLport] = ACTIONS(7039),
    [anon_sym_XMLPort] = ACTIONS(7039),
    [anon_sym_XmlPort] = ACTIONS(7039),
    [anon_sym_enum] = ACTIONS(7041),
    [anon_sym_ENUM] = ACTIONS(7041),
    [anon_sym_Enum] = ACTIONS(7041),
    [anon_sym_eNUM] = ACTIONS(7039),
    [anon_sym_eNum] = ACTIONS(7039),
    [anon_sym_ENum] = ACTIONS(7039),
    [anon_sym_enumextension] = ACTIONS(7039),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7039),
    [anon_sym_Enumextension] = ACTIONS(7039),
    [anon_sym_EnumExtension] = ACTIONS(7039),
    [anon_sym_enumExtension] = ACTIONS(7039),
    [sym_interface_keyword] = ACTIONS(7039),
    [anon_sym_controladdin] = ACTIONS(7039),
    [anon_sym_CONTROLADDIN] = ACTIONS(7039),
    [anon_sym_Controladdin] = ACTIONS(7039),
    [anon_sym_ControlAddIn] = ACTIONS(7039),
    [anon_sym_ControlAddin] = ACTIONS(7039),
    [anon_sym_controlAddIn] = ACTIONS(7039),
    [anon_sym_controlAddin] = ACTIONS(7039),
    [anon_sym_dotnet] = ACTIONS(7039),
    [anon_sym_DOTNET] = ACTIONS(7039),
    [anon_sym_Dotnet] = ACTIONS(7039),
    [anon_sym_DotNet] = ACTIONS(7039),
    [anon_sym_dotNet] = ACTIONS(7039),
    [sym_profile_keyword] = ACTIONS(7041),
    [anon_sym_profileextension] = ACTIONS(7039),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7039),
    [anon_sym_Profileextension] = ACTIONS(7039),
    [anon_sym_ProfileExtension] = ACTIONS(7039),
    [anon_sym_profileExtension] = ACTIONS(7039),
    [anon_sym_permissionset] = ACTIONS(7041),
    [anon_sym_PERMISSIONSET] = ACTIONS(7041),
    [anon_sym_Permissionset] = ACTIONS(7041),
    [anon_sym_PermissionSet] = ACTIONS(7041),
    [anon_sym_permissionSet] = ACTIONS(7041),
    [anon_sym_permissionsetextension] = ACTIONS(7039),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7039),
    [anon_sym_Permissionsetextension] = ACTIONS(7039),
    [anon_sym_PermissionSetExtension] = ACTIONS(7039),
    [anon_sym_permissionSetExtension] = ACTIONS(7039),
    [sym_entitlement_keyword] = ACTIONS(7039),
    [anon_sym_pagecustomization] = ACTIONS(7039),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7039),
    [anon_sym_Pagecustomization] = ACTIONS(7039),
    [anon_sym_PageCustomization] = ACTIONS(7039),
    [anon_sym_pageCustomization] = ACTIONS(7039),
    [sym_using_keyword] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7039),
    [sym_preproc_close] = ACTIONS(7039),
  },
  [STATE(2825)] = {
    [anon_sym_POUNDif] = ACTIONS(7043),
    [anon_sym_POUNDIF] = ACTIONS(7043),
    [anon_sym_POUNDIf] = ACTIONS(7043),
    [anon_sym_POUNDelif] = ACTIONS(7043),
    [anon_sym_POUNDELIF] = ACTIONS(7043),
    [anon_sym_POUNDElif] = ACTIONS(7043),
    [anon_sym_POUNDelse] = ACTIONS(7043),
    [anon_sym_POUNDELSE] = ACTIONS(7043),
    [anon_sym_POUNDElse] = ACTIONS(7043),
    [anon_sym_POUNDelse2] = ACTIONS(7043),
    [anon_sym_POUNDELSE2] = ACTIONS(7043),
    [anon_sym_POUNDElse2] = ACTIONS(7043),
    [anon_sym_POUNDendif] = ACTIONS(7043),
    [anon_sym_POUNDENDIF] = ACTIONS(7043),
    [anon_sym_POUNDEndif] = ACTIONS(7043),
    [anon_sym_POUNDendif2] = ACTIONS(7043),
    [anon_sym_POUNDENDIF2] = ACTIONS(7043),
    [anon_sym_POUNDEndif2] = ACTIONS(7043),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7045),
    [anon_sym_tableextension] = ACTIONS(7043),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7043),
    [anon_sym_Tableextension] = ACTIONS(7043),
    [anon_sym_TableExtension] = ACTIONS(7043),
    [anon_sym_tableExtension] = ACTIONS(7043),
    [sym_page_keyword] = ACTIONS(7045),
    [anon_sym_pageextension] = ACTIONS(7043),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7043),
    [anon_sym_Pageextension] = ACTIONS(7043),
    [anon_sym_PageExtension] = ACTIONS(7043),
    [anon_sym_pageExtension] = ACTIONS(7043),
    [anon_sym_codeunit] = ACTIONS(7043),
    [anon_sym_CODEUNIT] = ACTIONS(7043),
    [anon_sym_Codeunit] = ACTIONS(7043),
    [anon_sym_CodeUnit] = ACTIONS(7043),
    [anon_sym_COdeunit] = ACTIONS(7043),
    [anon_sym_codeUnit] = ACTIONS(7043),
    [sym_report_keyword] = ACTIONS(7045),
    [anon_sym_reportextension] = ACTIONS(7043),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7043),
    [anon_sym_Reportextension] = ACTIONS(7043),
    [anon_sym_ReportExtension] = ACTIONS(7043),
    [anon_sym_reportExtension] = ACTIONS(7043),
    [sym_query_keyword] = ACTIONS(7043),
    [anon_sym_xmlport] = ACTIONS(7043),
    [anon_sym_XMLPORT] = ACTIONS(7043),
    [anon_sym_Xmlport] = ACTIONS(7043),
    [anon_sym_XMLport] = ACTIONS(7043),
    [anon_sym_XMLPort] = ACTIONS(7043),
    [anon_sym_XmlPort] = ACTIONS(7043),
    [anon_sym_enum] = ACTIONS(7045),
    [anon_sym_ENUM] = ACTIONS(7045),
    [anon_sym_Enum] = ACTIONS(7045),
    [anon_sym_eNUM] = ACTIONS(7043),
    [anon_sym_eNum] = ACTIONS(7043),
    [anon_sym_ENum] = ACTIONS(7043),
    [anon_sym_enumextension] = ACTIONS(7043),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7043),
    [anon_sym_Enumextension] = ACTIONS(7043),
    [anon_sym_EnumExtension] = ACTIONS(7043),
    [anon_sym_enumExtension] = ACTIONS(7043),
    [sym_interface_keyword] = ACTIONS(7043),
    [anon_sym_controladdin] = ACTIONS(7043),
    [anon_sym_CONTROLADDIN] = ACTIONS(7043),
    [anon_sym_Controladdin] = ACTIONS(7043),
    [anon_sym_ControlAddIn] = ACTIONS(7043),
    [anon_sym_ControlAddin] = ACTIONS(7043),
    [anon_sym_controlAddIn] = ACTIONS(7043),
    [anon_sym_controlAddin] = ACTIONS(7043),
    [anon_sym_dotnet] = ACTIONS(7043),
    [anon_sym_DOTNET] = ACTIONS(7043),
    [anon_sym_Dotnet] = ACTIONS(7043),
    [anon_sym_DotNet] = ACTIONS(7043),
    [anon_sym_dotNet] = ACTIONS(7043),
    [sym_profile_keyword] = ACTIONS(7045),
    [anon_sym_profileextension] = ACTIONS(7043),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7043),
    [anon_sym_Profileextension] = ACTIONS(7043),
    [anon_sym_ProfileExtension] = ACTIONS(7043),
    [anon_sym_profileExtension] = ACTIONS(7043),
    [anon_sym_permissionset] = ACTIONS(7045),
    [anon_sym_PERMISSIONSET] = ACTIONS(7045),
    [anon_sym_Permissionset] = ACTIONS(7045),
    [anon_sym_PermissionSet] = ACTIONS(7045),
    [anon_sym_permissionSet] = ACTIONS(7045),
    [anon_sym_permissionsetextension] = ACTIONS(7043),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7043),
    [anon_sym_Permissionsetextension] = ACTIONS(7043),
    [anon_sym_PermissionSetExtension] = ACTIONS(7043),
    [anon_sym_permissionSetExtension] = ACTIONS(7043),
    [sym_entitlement_keyword] = ACTIONS(7043),
    [anon_sym_pagecustomization] = ACTIONS(7043),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7043),
    [anon_sym_Pagecustomization] = ACTIONS(7043),
    [anon_sym_PageCustomization] = ACTIONS(7043),
    [anon_sym_pageCustomization] = ACTIONS(7043),
    [sym_using_keyword] = ACTIONS(7043),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7043),
    [sym_preproc_close] = ACTIONS(7043),
  },
  [STATE(2826)] = {
    [anon_sym_POUNDif] = ACTIONS(7047),
    [anon_sym_POUNDIF] = ACTIONS(7047),
    [anon_sym_POUNDIf] = ACTIONS(7047),
    [anon_sym_POUNDelif] = ACTIONS(7047),
    [anon_sym_POUNDELIF] = ACTIONS(7047),
    [anon_sym_POUNDElif] = ACTIONS(7047),
    [anon_sym_POUNDelse] = ACTIONS(7047),
    [anon_sym_POUNDELSE] = ACTIONS(7047),
    [anon_sym_POUNDElse] = ACTIONS(7047),
    [anon_sym_POUNDelse2] = ACTIONS(7047),
    [anon_sym_POUNDELSE2] = ACTIONS(7047),
    [anon_sym_POUNDElse2] = ACTIONS(7047),
    [anon_sym_POUNDendif] = ACTIONS(7047),
    [anon_sym_POUNDENDIF] = ACTIONS(7047),
    [anon_sym_POUNDEndif] = ACTIONS(7047),
    [anon_sym_POUNDendif2] = ACTIONS(7047),
    [anon_sym_POUNDENDIF2] = ACTIONS(7047),
    [anon_sym_POUNDEndif2] = ACTIONS(7047),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7049),
    [anon_sym_tableextension] = ACTIONS(7047),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7047),
    [anon_sym_Tableextension] = ACTIONS(7047),
    [anon_sym_TableExtension] = ACTIONS(7047),
    [anon_sym_tableExtension] = ACTIONS(7047),
    [sym_page_keyword] = ACTIONS(7049),
    [anon_sym_pageextension] = ACTIONS(7047),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7047),
    [anon_sym_Pageextension] = ACTIONS(7047),
    [anon_sym_PageExtension] = ACTIONS(7047),
    [anon_sym_pageExtension] = ACTIONS(7047),
    [anon_sym_codeunit] = ACTIONS(7047),
    [anon_sym_CODEUNIT] = ACTIONS(7047),
    [anon_sym_Codeunit] = ACTIONS(7047),
    [anon_sym_CodeUnit] = ACTIONS(7047),
    [anon_sym_COdeunit] = ACTIONS(7047),
    [anon_sym_codeUnit] = ACTIONS(7047),
    [sym_report_keyword] = ACTIONS(7049),
    [anon_sym_reportextension] = ACTIONS(7047),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7047),
    [anon_sym_Reportextension] = ACTIONS(7047),
    [anon_sym_ReportExtension] = ACTIONS(7047),
    [anon_sym_reportExtension] = ACTIONS(7047),
    [sym_query_keyword] = ACTIONS(7047),
    [anon_sym_xmlport] = ACTIONS(7047),
    [anon_sym_XMLPORT] = ACTIONS(7047),
    [anon_sym_Xmlport] = ACTIONS(7047),
    [anon_sym_XMLport] = ACTIONS(7047),
    [anon_sym_XMLPort] = ACTIONS(7047),
    [anon_sym_XmlPort] = ACTIONS(7047),
    [anon_sym_enum] = ACTIONS(7049),
    [anon_sym_ENUM] = ACTIONS(7049),
    [anon_sym_Enum] = ACTIONS(7049),
    [anon_sym_eNUM] = ACTIONS(7047),
    [anon_sym_eNum] = ACTIONS(7047),
    [anon_sym_ENum] = ACTIONS(7047),
    [anon_sym_enumextension] = ACTIONS(7047),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7047),
    [anon_sym_Enumextension] = ACTIONS(7047),
    [anon_sym_EnumExtension] = ACTIONS(7047),
    [anon_sym_enumExtension] = ACTIONS(7047),
    [sym_interface_keyword] = ACTIONS(7047),
    [anon_sym_controladdin] = ACTIONS(7047),
    [anon_sym_CONTROLADDIN] = ACTIONS(7047),
    [anon_sym_Controladdin] = ACTIONS(7047),
    [anon_sym_ControlAddIn] = ACTIONS(7047),
    [anon_sym_ControlAddin] = ACTIONS(7047),
    [anon_sym_controlAddIn] = ACTIONS(7047),
    [anon_sym_controlAddin] = ACTIONS(7047),
    [anon_sym_dotnet] = ACTIONS(7047),
    [anon_sym_DOTNET] = ACTIONS(7047),
    [anon_sym_Dotnet] = ACTIONS(7047),
    [anon_sym_DotNet] = ACTIONS(7047),
    [anon_sym_dotNet] = ACTIONS(7047),
    [sym_profile_keyword] = ACTIONS(7049),
    [anon_sym_profileextension] = ACTIONS(7047),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7047),
    [anon_sym_Profileextension] = ACTIONS(7047),
    [anon_sym_ProfileExtension] = ACTIONS(7047),
    [anon_sym_profileExtension] = ACTIONS(7047),
    [anon_sym_permissionset] = ACTIONS(7049),
    [anon_sym_PERMISSIONSET] = ACTIONS(7049),
    [anon_sym_Permissionset] = ACTIONS(7049),
    [anon_sym_PermissionSet] = ACTIONS(7049),
    [anon_sym_permissionSet] = ACTIONS(7049),
    [anon_sym_permissionsetextension] = ACTIONS(7047),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7047),
    [anon_sym_Permissionsetextension] = ACTIONS(7047),
    [anon_sym_PermissionSetExtension] = ACTIONS(7047),
    [anon_sym_permissionSetExtension] = ACTIONS(7047),
    [sym_entitlement_keyword] = ACTIONS(7047),
    [anon_sym_pagecustomization] = ACTIONS(7047),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7047),
    [anon_sym_Pagecustomization] = ACTIONS(7047),
    [anon_sym_PageCustomization] = ACTIONS(7047),
    [anon_sym_pageCustomization] = ACTIONS(7047),
    [sym_using_keyword] = ACTIONS(7047),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7047),
    [sym_preproc_close] = ACTIONS(7047),
  },
  [STATE(2827)] = {
    [anon_sym_POUNDif] = ACTIONS(7051),
    [anon_sym_POUNDIF] = ACTIONS(7051),
    [anon_sym_POUNDIf] = ACTIONS(7051),
    [anon_sym_POUNDelif] = ACTIONS(7051),
    [anon_sym_POUNDELIF] = ACTIONS(7051),
    [anon_sym_POUNDElif] = ACTIONS(7051),
    [anon_sym_POUNDelse] = ACTIONS(7051),
    [anon_sym_POUNDELSE] = ACTIONS(7051),
    [anon_sym_POUNDElse] = ACTIONS(7051),
    [anon_sym_POUNDelse2] = ACTIONS(7051),
    [anon_sym_POUNDELSE2] = ACTIONS(7051),
    [anon_sym_POUNDElse2] = ACTIONS(7051),
    [anon_sym_POUNDendif] = ACTIONS(7051),
    [anon_sym_POUNDENDIF] = ACTIONS(7051),
    [anon_sym_POUNDEndif] = ACTIONS(7051),
    [anon_sym_POUNDendif2] = ACTIONS(7051),
    [anon_sym_POUNDENDIF2] = ACTIONS(7051),
    [anon_sym_POUNDEndif2] = ACTIONS(7051),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7053),
    [anon_sym_tableextension] = ACTIONS(7051),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7051),
    [anon_sym_Tableextension] = ACTIONS(7051),
    [anon_sym_TableExtension] = ACTIONS(7051),
    [anon_sym_tableExtension] = ACTIONS(7051),
    [sym_page_keyword] = ACTIONS(7053),
    [anon_sym_pageextension] = ACTIONS(7051),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7051),
    [anon_sym_Pageextension] = ACTIONS(7051),
    [anon_sym_PageExtension] = ACTIONS(7051),
    [anon_sym_pageExtension] = ACTIONS(7051),
    [anon_sym_codeunit] = ACTIONS(7051),
    [anon_sym_CODEUNIT] = ACTIONS(7051),
    [anon_sym_Codeunit] = ACTIONS(7051),
    [anon_sym_CodeUnit] = ACTIONS(7051),
    [anon_sym_COdeunit] = ACTIONS(7051),
    [anon_sym_codeUnit] = ACTIONS(7051),
    [sym_report_keyword] = ACTIONS(7053),
    [anon_sym_reportextension] = ACTIONS(7051),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7051),
    [anon_sym_Reportextension] = ACTIONS(7051),
    [anon_sym_ReportExtension] = ACTIONS(7051),
    [anon_sym_reportExtension] = ACTIONS(7051),
    [sym_query_keyword] = ACTIONS(7051),
    [anon_sym_xmlport] = ACTIONS(7051),
    [anon_sym_XMLPORT] = ACTIONS(7051),
    [anon_sym_Xmlport] = ACTIONS(7051),
    [anon_sym_XMLport] = ACTIONS(7051),
    [anon_sym_XMLPort] = ACTIONS(7051),
    [anon_sym_XmlPort] = ACTIONS(7051),
    [anon_sym_enum] = ACTIONS(7053),
    [anon_sym_ENUM] = ACTIONS(7053),
    [anon_sym_Enum] = ACTIONS(7053),
    [anon_sym_eNUM] = ACTIONS(7051),
    [anon_sym_eNum] = ACTIONS(7051),
    [anon_sym_ENum] = ACTIONS(7051),
    [anon_sym_enumextension] = ACTIONS(7051),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7051),
    [anon_sym_Enumextension] = ACTIONS(7051),
    [anon_sym_EnumExtension] = ACTIONS(7051),
    [anon_sym_enumExtension] = ACTIONS(7051),
    [sym_interface_keyword] = ACTIONS(7051),
    [anon_sym_controladdin] = ACTIONS(7051),
    [anon_sym_CONTROLADDIN] = ACTIONS(7051),
    [anon_sym_Controladdin] = ACTIONS(7051),
    [anon_sym_ControlAddIn] = ACTIONS(7051),
    [anon_sym_ControlAddin] = ACTIONS(7051),
    [anon_sym_controlAddIn] = ACTIONS(7051),
    [anon_sym_controlAddin] = ACTIONS(7051),
    [anon_sym_dotnet] = ACTIONS(7051),
    [anon_sym_DOTNET] = ACTIONS(7051),
    [anon_sym_Dotnet] = ACTIONS(7051),
    [anon_sym_DotNet] = ACTIONS(7051),
    [anon_sym_dotNet] = ACTIONS(7051),
    [sym_profile_keyword] = ACTIONS(7053),
    [anon_sym_profileextension] = ACTIONS(7051),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7051),
    [anon_sym_Profileextension] = ACTIONS(7051),
    [anon_sym_ProfileExtension] = ACTIONS(7051),
    [anon_sym_profileExtension] = ACTIONS(7051),
    [anon_sym_permissionset] = ACTIONS(7053),
    [anon_sym_PERMISSIONSET] = ACTIONS(7053),
    [anon_sym_Permissionset] = ACTIONS(7053),
    [anon_sym_PermissionSet] = ACTIONS(7053),
    [anon_sym_permissionSet] = ACTIONS(7053),
    [anon_sym_permissionsetextension] = ACTIONS(7051),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7051),
    [anon_sym_Permissionsetextension] = ACTIONS(7051),
    [anon_sym_PermissionSetExtension] = ACTIONS(7051),
    [anon_sym_permissionSetExtension] = ACTIONS(7051),
    [sym_entitlement_keyword] = ACTIONS(7051),
    [anon_sym_pagecustomization] = ACTIONS(7051),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7051),
    [anon_sym_Pagecustomization] = ACTIONS(7051),
    [anon_sym_PageCustomization] = ACTIONS(7051),
    [anon_sym_pageCustomization] = ACTIONS(7051),
    [sym_using_keyword] = ACTIONS(7051),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7051),
    [sym_preproc_close] = ACTIONS(7051),
  },
  [STATE(2828)] = {
    [anon_sym_POUNDif] = ACTIONS(7055),
    [anon_sym_POUNDIF] = ACTIONS(7055),
    [anon_sym_POUNDIf] = ACTIONS(7055),
    [anon_sym_POUNDelif] = ACTIONS(7055),
    [anon_sym_POUNDELIF] = ACTIONS(7055),
    [anon_sym_POUNDElif] = ACTIONS(7055),
    [anon_sym_POUNDelse] = ACTIONS(7055),
    [anon_sym_POUNDELSE] = ACTIONS(7055),
    [anon_sym_POUNDElse] = ACTIONS(7055),
    [anon_sym_POUNDelse2] = ACTIONS(7055),
    [anon_sym_POUNDELSE2] = ACTIONS(7055),
    [anon_sym_POUNDElse2] = ACTIONS(7055),
    [anon_sym_POUNDendif] = ACTIONS(7055),
    [anon_sym_POUNDENDIF] = ACTIONS(7055),
    [anon_sym_POUNDEndif] = ACTIONS(7055),
    [anon_sym_POUNDendif2] = ACTIONS(7055),
    [anon_sym_POUNDENDIF2] = ACTIONS(7055),
    [anon_sym_POUNDEndif2] = ACTIONS(7055),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7057),
    [anon_sym_tableextension] = ACTIONS(7055),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7055),
    [anon_sym_Tableextension] = ACTIONS(7055),
    [anon_sym_TableExtension] = ACTIONS(7055),
    [anon_sym_tableExtension] = ACTIONS(7055),
    [sym_page_keyword] = ACTIONS(7057),
    [anon_sym_pageextension] = ACTIONS(7055),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7055),
    [anon_sym_Pageextension] = ACTIONS(7055),
    [anon_sym_PageExtension] = ACTIONS(7055),
    [anon_sym_pageExtension] = ACTIONS(7055),
    [anon_sym_codeunit] = ACTIONS(7055),
    [anon_sym_CODEUNIT] = ACTIONS(7055),
    [anon_sym_Codeunit] = ACTIONS(7055),
    [anon_sym_CodeUnit] = ACTIONS(7055),
    [anon_sym_COdeunit] = ACTIONS(7055),
    [anon_sym_codeUnit] = ACTIONS(7055),
    [sym_report_keyword] = ACTIONS(7057),
    [anon_sym_reportextension] = ACTIONS(7055),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7055),
    [anon_sym_Reportextension] = ACTIONS(7055),
    [anon_sym_ReportExtension] = ACTIONS(7055),
    [anon_sym_reportExtension] = ACTIONS(7055),
    [sym_query_keyword] = ACTIONS(7055),
    [anon_sym_xmlport] = ACTIONS(7055),
    [anon_sym_XMLPORT] = ACTIONS(7055),
    [anon_sym_Xmlport] = ACTIONS(7055),
    [anon_sym_XMLport] = ACTIONS(7055),
    [anon_sym_XMLPort] = ACTIONS(7055),
    [anon_sym_XmlPort] = ACTIONS(7055),
    [anon_sym_enum] = ACTIONS(7057),
    [anon_sym_ENUM] = ACTIONS(7057),
    [anon_sym_Enum] = ACTIONS(7057),
    [anon_sym_eNUM] = ACTIONS(7055),
    [anon_sym_eNum] = ACTIONS(7055),
    [anon_sym_ENum] = ACTIONS(7055),
    [anon_sym_enumextension] = ACTIONS(7055),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7055),
    [anon_sym_Enumextension] = ACTIONS(7055),
    [anon_sym_EnumExtension] = ACTIONS(7055),
    [anon_sym_enumExtension] = ACTIONS(7055),
    [sym_interface_keyword] = ACTIONS(7055),
    [anon_sym_controladdin] = ACTIONS(7055),
    [anon_sym_CONTROLADDIN] = ACTIONS(7055),
    [anon_sym_Controladdin] = ACTIONS(7055),
    [anon_sym_ControlAddIn] = ACTIONS(7055),
    [anon_sym_ControlAddin] = ACTIONS(7055),
    [anon_sym_controlAddIn] = ACTIONS(7055),
    [anon_sym_controlAddin] = ACTIONS(7055),
    [anon_sym_dotnet] = ACTIONS(7055),
    [anon_sym_DOTNET] = ACTIONS(7055),
    [anon_sym_Dotnet] = ACTIONS(7055),
    [anon_sym_DotNet] = ACTIONS(7055),
    [anon_sym_dotNet] = ACTIONS(7055),
    [sym_profile_keyword] = ACTIONS(7057),
    [anon_sym_profileextension] = ACTIONS(7055),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7055),
    [anon_sym_Profileextension] = ACTIONS(7055),
    [anon_sym_ProfileExtension] = ACTIONS(7055),
    [anon_sym_profileExtension] = ACTIONS(7055),
    [anon_sym_permissionset] = ACTIONS(7057),
    [anon_sym_PERMISSIONSET] = ACTIONS(7057),
    [anon_sym_Permissionset] = ACTIONS(7057),
    [anon_sym_PermissionSet] = ACTIONS(7057),
    [anon_sym_permissionSet] = ACTIONS(7057),
    [anon_sym_permissionsetextension] = ACTIONS(7055),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7055),
    [anon_sym_Permissionsetextension] = ACTIONS(7055),
    [anon_sym_PermissionSetExtension] = ACTIONS(7055),
    [anon_sym_permissionSetExtension] = ACTIONS(7055),
    [sym_entitlement_keyword] = ACTIONS(7055),
    [anon_sym_pagecustomization] = ACTIONS(7055),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7055),
    [anon_sym_Pagecustomization] = ACTIONS(7055),
    [anon_sym_PageCustomization] = ACTIONS(7055),
    [anon_sym_pageCustomization] = ACTIONS(7055),
    [sym_using_keyword] = ACTIONS(7055),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7055),
    [sym_preproc_close] = ACTIONS(7055),
  },
  [STATE(2829)] = {
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_DOT] = ACTIONS(3746),
    [anon_sym_EQ] = ACTIONS(3748),
    [anon_sym_COMMA] = ACTIONS(3748),
    [anon_sym_DASH] = ACTIONS(3746),
    [aux_sym_boolean_token1] = ACTIONS(3746),
    [aux_sym_boolean_token2] = ACTIONS(3746),
    [sym_decimal] = ACTIONS(3746),
    [anon_sym_LPAREN] = ACTIONS(3748),
    [anon_sym_DOT_DOT] = ACTIONS(3748),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3746),
    [anon_sym_STAR] = ACTIONS(3746),
    [anon_sym_LBRACK] = ACTIONS(3748),
    [aux_sym_record_type_token1] = ACTIONS(3746),
    [aux_sym_basic_type_token21] = ACTIONS(3746),
    [aux_sym_basic_type_token22] = ACTIONS(3746),
    [aux_sym_basic_type_token48] = ACTIONS(3746),
    [anon_sym_not] = ACTIONS(3746),
    [anon_sym_NOT] = ACTIONS(3746),
    [anon_sym_Not] = ACTIONS(3746),
    [anon_sym_POUNDelif] = ACTIONS(3748),
    [anon_sym_POUNDELIF] = ACTIONS(3748),
    [anon_sym_POUNDElif] = ACTIONS(3748),
    [anon_sym_POUNDelse] = ACTIONS(3748),
    [anon_sym_POUNDELSE] = ACTIONS(3748),
    [anon_sym_POUNDElse] = ACTIONS(3748),
    [anon_sym_POUNDelse2] = ACTIONS(3748),
    [anon_sym_POUNDELSE2] = ACTIONS(3748),
    [anon_sym_POUNDElse2] = ACTIONS(3748),
    [anon_sym_POUNDendif] = ACTIONS(3748),
    [anon_sym_POUNDENDIF] = ACTIONS(3748),
    [anon_sym_POUNDEndif] = ACTIONS(3748),
    [anon_sym_POUNDendif2] = ACTIONS(3748),
    [anon_sym_POUNDENDIF2] = ACTIONS(3748),
    [anon_sym_POUNDEndif2] = ACTIONS(3748),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3748),
    [aux_sym__expression_token1] = ACTIONS(3748),
    [aux_sym__expression_token2] = ACTIONS(3748),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3746),
    [anon_sym_SLASH] = ACTIONS(3746),
    [anon_sym_div] = ACTIONS(3746),
    [anon_sym_DIV] = ACTIONS(3746),
    [anon_sym_Div] = ACTIONS(3746),
    [anon_sym_mod] = ACTIONS(3746),
    [anon_sym_MOD] = ACTIONS(3746),
    [anon_sym_Mod] = ACTIONS(3746),
    [anon_sym_PLUS] = ACTIONS(3746),
    [anon_sym_GT_EQ] = ACTIONS(3748),
    [anon_sym_LT_EQ] = ACTIONS(3748),
    [anon_sym_GT] = ACTIONS(3746),
    [anon_sym_LT] = ACTIONS(3746),
    [anon_sym_LT_GT] = ACTIONS(3748),
    [anon_sym_and] = ACTIONS(3746),
    [anon_sym_AND] = ACTIONS(3746),
    [anon_sym_And] = ACTIONS(3746),
    [anon_sym_or] = ACTIONS(3746),
    [anon_sym_OR] = ACTIONS(3746),
    [anon_sym_Or] = ACTIONS(3746),
    [anon_sym_xor] = ACTIONS(3746),
    [anon_sym_XOR] = ACTIONS(3746),
    [anon_sym_Xor] = ACTIONS(3746),
    [anon_sym_QMARK] = ACTIONS(3748),
    [sym_datetime_literal] = ACTIONS(3748),
    [sym_date_literal] = ACTIONS(3746),
    [sym_time_literal] = ACTIONS(3746),
    [sym_biginteger_literal] = ACTIONS(3748),
    [anon_sym_in] = ACTIONS(3746),
    [anon_sym_IN] = ACTIONS(3746),
    [anon_sym_In] = ACTIONS(3746),
    [sym_page_keyword] = ACTIONS(3746),
    [anon_sym_codeunit] = ACTIONS(3746),
    [anon_sym_CODEUNIT] = ACTIONS(3746),
    [anon_sym_Codeunit] = ACTIONS(3746),
    [anon_sym_CodeUnit] = ACTIONS(3746),
    [anon_sym_COdeunit] = ACTIONS(3746),
    [anon_sym_codeUnit] = ACTIONS(3746),
    [sym_report_keyword] = ACTIONS(3746),
    [sym_query_keyword] = ACTIONS(3746),
    [anon_sym_xmlport] = ACTIONS(3746),
    [anon_sym_XMLPORT] = ACTIONS(3746),
    [anon_sym_Xmlport] = ACTIONS(3746),
    [anon_sym_XMLport] = ACTIONS(3746),
    [anon_sym_XMLPort] = ACTIONS(3746),
    [anon_sym_XmlPort] = ACTIONS(3746),
    [anon_sym_enum] = ACTIONS(3746),
    [anon_sym_ENUM] = ACTIONS(3746),
    [anon_sym_Enum] = ACTIONS(3746),
    [anon_sym_eNUM] = ACTIONS(3746),
    [anon_sym_eNum] = ACTIONS(3746),
    [anon_sym_ENum] = ACTIONS(3746),
    [sym_temporary_keyword] = ACTIONS(7059),
    [sym_quoted_identifier] = ACTIONS(3748),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3748),
    [sym_verbatim_string] = ACTIONS(3748),
    [sym_integer] = ACTIONS(3746),
    [sym_continue_as_identifier] = ACTIONS(3748),
    [sym_preproc_close] = ACTIONS(3748),
  },
  [STATE(2830)] = {
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(6820),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [anon_sym_POUNDelif] = ACTIONS(3683),
    [anon_sym_POUNDELIF] = ACTIONS(3683),
    [anon_sym_POUNDElif] = ACTIONS(3683),
    [anon_sym_POUNDelse] = ACTIONS(3683),
    [anon_sym_POUNDELSE] = ACTIONS(3683),
    [anon_sym_POUNDElse] = ACTIONS(3683),
    [anon_sym_POUNDelse2] = ACTIONS(3683),
    [anon_sym_POUNDELSE2] = ACTIONS(3683),
    [anon_sym_POUNDElse2] = ACTIONS(3683),
    [anon_sym_POUNDendif] = ACTIONS(3683),
    [anon_sym_POUNDENDIF] = ACTIONS(3683),
    [anon_sym_POUNDEndif] = ACTIONS(3683),
    [anon_sym_POUNDendif2] = ACTIONS(3683),
    [anon_sym_POUNDENDIF2] = ACTIONS(3683),
    [anon_sym_POUNDEndif2] = ACTIONS(3683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_close] = ACTIONS(3683),
  },
  [STATE(2831)] = {
    [sym_identifier] = ACTIONS(3790),
    [anon_sym_DOT] = ACTIONS(3790),
    [anon_sym_EQ] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3792),
    [anon_sym_DASH] = ACTIONS(3790),
    [aux_sym_boolean_token1] = ACTIONS(3790),
    [aux_sym_boolean_token2] = ACTIONS(3790),
    [sym_decimal] = ACTIONS(3790),
    [anon_sym_LPAREN] = ACTIONS(3792),
    [anon_sym_DOT_DOT] = ACTIONS(3792),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3790),
    [anon_sym_STAR] = ACTIONS(3790),
    [anon_sym_LBRACK] = ACTIONS(3792),
    [aux_sym_record_type_token1] = ACTIONS(3790),
    [aux_sym_basic_type_token21] = ACTIONS(3790),
    [aux_sym_basic_type_token22] = ACTIONS(3790),
    [aux_sym_basic_type_token48] = ACTIONS(3790),
    [anon_sym_COLON_COLON] = ACTIONS(3792),
    [anon_sym_not] = ACTIONS(3790),
    [anon_sym_NOT] = ACTIONS(3790),
    [anon_sym_Not] = ACTIONS(3790),
    [anon_sym_POUNDelif] = ACTIONS(3792),
    [anon_sym_POUNDELIF] = ACTIONS(3792),
    [anon_sym_POUNDElif] = ACTIONS(3792),
    [anon_sym_POUNDelse] = ACTIONS(3792),
    [anon_sym_POUNDELSE] = ACTIONS(3792),
    [anon_sym_POUNDElse] = ACTIONS(3792),
    [anon_sym_POUNDelse2] = ACTIONS(3792),
    [anon_sym_POUNDELSE2] = ACTIONS(3792),
    [anon_sym_POUNDElse2] = ACTIONS(3792),
    [anon_sym_POUNDendif] = ACTIONS(3792),
    [anon_sym_POUNDENDIF] = ACTIONS(3792),
    [anon_sym_POUNDEndif] = ACTIONS(3792),
    [anon_sym_POUNDendif2] = ACTIONS(3792),
    [anon_sym_POUNDENDIF2] = ACTIONS(3792),
    [anon_sym_POUNDEndif2] = ACTIONS(3792),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3792),
    [aux_sym__expression_token1] = ACTIONS(3792),
    [aux_sym__expression_token2] = ACTIONS(3792),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3790),
    [anon_sym_SLASH] = ACTIONS(3790),
    [anon_sym_div] = ACTIONS(3790),
    [anon_sym_DIV] = ACTIONS(3790),
    [anon_sym_Div] = ACTIONS(3790),
    [anon_sym_mod] = ACTIONS(3790),
    [anon_sym_MOD] = ACTIONS(3790),
    [anon_sym_Mod] = ACTIONS(3790),
    [anon_sym_PLUS] = ACTIONS(3790),
    [anon_sym_GT_EQ] = ACTIONS(3792),
    [anon_sym_LT_EQ] = ACTIONS(3792),
    [anon_sym_GT] = ACTIONS(3790),
    [anon_sym_LT] = ACTIONS(3790),
    [anon_sym_LT_GT] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3790),
    [anon_sym_AND] = ACTIONS(3790),
    [anon_sym_And] = ACTIONS(3790),
    [anon_sym_or] = ACTIONS(3790),
    [anon_sym_OR] = ACTIONS(3790),
    [anon_sym_Or] = ACTIONS(3790),
    [anon_sym_xor] = ACTIONS(3790),
    [anon_sym_XOR] = ACTIONS(3790),
    [anon_sym_Xor] = ACTIONS(3790),
    [anon_sym_QMARK] = ACTIONS(3792),
    [sym_datetime_literal] = ACTIONS(3792),
    [sym_date_literal] = ACTIONS(3790),
    [sym_time_literal] = ACTIONS(3790),
    [sym_biginteger_literal] = ACTIONS(3792),
    [anon_sym_in] = ACTIONS(3790),
    [anon_sym_IN] = ACTIONS(3790),
    [anon_sym_In] = ACTIONS(3790),
    [sym_page_keyword] = ACTIONS(3790),
    [anon_sym_codeunit] = ACTIONS(3790),
    [anon_sym_CODEUNIT] = ACTIONS(3790),
    [anon_sym_Codeunit] = ACTIONS(3790),
    [anon_sym_CodeUnit] = ACTIONS(3790),
    [anon_sym_COdeunit] = ACTIONS(3790),
    [anon_sym_codeUnit] = ACTIONS(3790),
    [sym_report_keyword] = ACTIONS(3790),
    [sym_query_keyword] = ACTIONS(3790),
    [anon_sym_xmlport] = ACTIONS(3790),
    [anon_sym_XMLPORT] = ACTIONS(3790),
    [anon_sym_Xmlport] = ACTIONS(3790),
    [anon_sym_XMLport] = ACTIONS(3790),
    [anon_sym_XMLPort] = ACTIONS(3790),
    [anon_sym_XmlPort] = ACTIONS(3790),
    [anon_sym_enum] = ACTIONS(3790),
    [anon_sym_ENUM] = ACTIONS(3790),
    [anon_sym_Enum] = ACTIONS(3790),
    [anon_sym_eNUM] = ACTIONS(3790),
    [anon_sym_eNum] = ACTIONS(3790),
    [anon_sym_ENum] = ACTIONS(3790),
    [sym_quoted_identifier] = ACTIONS(3792),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3792),
    [sym_verbatim_string] = ACTIONS(3792),
    [sym_integer] = ACTIONS(3790),
    [sym_continue_as_identifier] = ACTIONS(3792),
    [sym_preproc_close] = ACTIONS(3792),
  },
  [STATE(2832)] = {
    [sym_boolean] = STATE(8034),
    [sym_option_member_list] = STATE(8134),
    [sym_option_member] = STATE(7937),
    [sym_keyword_identifier] = STATE(8034),
    [sym_codeunit_keyword] = STATE(8062),
    [sym_xmlport_keyword] = STATE(8062),
    [sym_enum_keyword] = STATE(8062),
    [sym_keyword_as_identifier] = STATE(8034),
    [aux_sym_option_member_list_repeat2] = STATE(3074),
    [sym_identifier] = ACTIONS(7061),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(7063),
    [anon_sym_DASH] = ACTIONS(7065),
    [aux_sym_boolean_token1] = ACTIONS(7067),
    [aux_sym_boolean_token2] = ACTIONS(7067),
    [aux_sym_where_condition_token1] = ACTIONS(7069),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7071),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(7071),
    [aux_sym_basic_type_token21] = ACTIONS(7071),
    [aux_sym_basic_type_token22] = ACTIONS(7073),
    [aux_sym_basic_type_token48] = ACTIONS(7071),
    [aux_sym_basic_type_token53] = ACTIONS(7069),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7069),
    [aux_sym_modify_modification_token1] = ACTIONS(584),
    [aux_sym_separator_action_token1] = ACTIONS(7069),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7069),
    [aux_sym_type_declaration_token1] = ACTIONS(7069),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(584),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [anon_sym_POUNDelif] = ACTIONS(582),
    [anon_sym_POUNDELIF] = ACTIONS(582),
    [anon_sym_POUNDElif] = ACTIONS(582),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [anon_sym_POUNDendif] = ACTIONS(582),
    [anon_sym_POUNDENDIF] = ACTIONS(582),
    [anon_sym_POUNDEndif] = ACTIONS(582),
    [anon_sym_POUNDendif2] = ACTIONS(582),
    [anon_sym_POUNDENDIF2] = ACTIONS(582),
    [anon_sym_POUNDEndif2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7071),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7071),
    [sym_table_keyword] = ACTIONS(7069),
    [sym_page_keyword] = ACTIONS(7071),
    [anon_sym_codeunit] = ACTIONS(7075),
    [anon_sym_CODEUNIT] = ACTIONS(7075),
    [anon_sym_Codeunit] = ACTIONS(7075),
    [anon_sym_CodeUnit] = ACTIONS(7075),
    [anon_sym_COdeunit] = ACTIONS(7075),
    [anon_sym_codeUnit] = ACTIONS(7075),
    [sym_report_keyword] = ACTIONS(7071),
    [sym_query_keyword] = ACTIONS(7071),
    [anon_sym_xmlport] = ACTIONS(7077),
    [anon_sym_XMLPORT] = ACTIONS(7077),
    [anon_sym_Xmlport] = ACTIONS(7077),
    [anon_sym_XMLport] = ACTIONS(7077),
    [anon_sym_XMLPort] = ACTIONS(7077),
    [anon_sym_XmlPort] = ACTIONS(7077),
    [anon_sym_enum] = ACTIONS(7079),
    [anon_sym_ENUM] = ACTIONS(7079),
    [anon_sym_Enum] = ACTIONS(7079),
    [anon_sym_eNUM] = ACTIONS(7079),
    [anon_sym_eNum] = ACTIONS(7079),
    [anon_sym_ENum] = ACTIONS(7079),
    [sym_procedure_keyword] = ACTIONS(584),
    [sym_trigger_keyword] = ACTIONS(584),
    [sym_var_keyword] = ACTIONS(584),
    [sym_local_keyword] = ACTIONS(7061),
    [sym_internal_keyword] = ACTIONS(7061),
    [sym_protected_keyword] = ACTIONS(7061),
    [sym_event_keyword] = ACTIONS(584),
    [sym_fields_keyword] = ACTIONS(584),
    [sym_keys_keyword] = ACTIONS(584),
    [sym_key_keyword] = ACTIONS(7069),
    [sym_fieldgroups_keyword] = ACTIONS(584),
    [sym_actions_keyword] = ACTIONS(584),
    [sym_layout_keyword] = ACTIONS(584),
    [sym_dataset_keyword] = ACTIONS(7069),
    [sym_elements_keyword] = ACTIONS(584),
    [sym_labels_keyword] = ACTIONS(584),
    [sym_rendering_keyword] = ACTIONS(584),
    [sym_requestpage_keyword] = ACTIONS(584),
    [sym_schema_keyword] = ACTIONS(584),
    [sym_views_keyword] = ACTIONS(584),
    [sym_quoted_identifier] = ACTIONS(7081),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7081),
    [sym_integer] = ACTIONS(7081),
    [sym_property_name] = ACTIONS(582),
    [sym_preproc_open] = ACTIONS(582),
    [sym_preproc_close] = ACTIONS(582),
    [sym_begin_keyword] = ACTIONS(582),
  },
  [STATE(2833)] = {
    [sym_identifier] = ACTIONS(3760),
    [anon_sym_DOT] = ACTIONS(3760),
    [anon_sym_EQ] = ACTIONS(3762),
    [anon_sym_COMMA] = ACTIONS(3762),
    [anon_sym_DASH] = ACTIONS(3760),
    [aux_sym_boolean_token1] = ACTIONS(3760),
    [aux_sym_boolean_token2] = ACTIONS(3760),
    [sym_decimal] = ACTIONS(3760),
    [anon_sym_LPAREN] = ACTIONS(3762),
    [anon_sym_DOT_DOT] = ACTIONS(3762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3760),
    [anon_sym_STAR] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3762),
    [aux_sym_record_type_token1] = ACTIONS(3760),
    [aux_sym_basic_type_token21] = ACTIONS(3760),
    [aux_sym_basic_type_token22] = ACTIONS(3760),
    [aux_sym_basic_type_token48] = ACTIONS(3760),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_not] = ACTIONS(3760),
    [anon_sym_NOT] = ACTIONS(3760),
    [anon_sym_Not] = ACTIONS(3760),
    [anon_sym_POUNDelif] = ACTIONS(3762),
    [anon_sym_POUNDELIF] = ACTIONS(3762),
    [anon_sym_POUNDElif] = ACTIONS(3762),
    [anon_sym_POUNDelse] = ACTIONS(3762),
    [anon_sym_POUNDELSE] = ACTIONS(3762),
    [anon_sym_POUNDElse] = ACTIONS(3762),
    [anon_sym_POUNDelse2] = ACTIONS(3762),
    [anon_sym_POUNDELSE2] = ACTIONS(3762),
    [anon_sym_POUNDElse2] = ACTIONS(3762),
    [anon_sym_POUNDendif] = ACTIONS(3762),
    [anon_sym_POUNDENDIF] = ACTIONS(3762),
    [anon_sym_POUNDEndif] = ACTIONS(3762),
    [anon_sym_POUNDendif2] = ACTIONS(3762),
    [anon_sym_POUNDENDIF2] = ACTIONS(3762),
    [anon_sym_POUNDEndif2] = ACTIONS(3762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3762),
    [aux_sym__expression_token1] = ACTIONS(3762),
    [aux_sym__expression_token2] = ACTIONS(3762),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3760),
    [anon_sym_SLASH] = ACTIONS(3760),
    [anon_sym_div] = ACTIONS(3760),
    [anon_sym_DIV] = ACTIONS(3760),
    [anon_sym_Div] = ACTIONS(3760),
    [anon_sym_mod] = ACTIONS(3760),
    [anon_sym_MOD] = ACTIONS(3760),
    [anon_sym_Mod] = ACTIONS(3760),
    [anon_sym_PLUS] = ACTIONS(3760),
    [anon_sym_GT_EQ] = ACTIONS(3762),
    [anon_sym_LT_EQ] = ACTIONS(3762),
    [anon_sym_GT] = ACTIONS(3760),
    [anon_sym_LT] = ACTIONS(3760),
    [anon_sym_LT_GT] = ACTIONS(3762),
    [anon_sym_and] = ACTIONS(3760),
    [anon_sym_AND] = ACTIONS(3760),
    [anon_sym_And] = ACTIONS(3760),
    [anon_sym_or] = ACTIONS(3760),
    [anon_sym_OR] = ACTIONS(3760),
    [anon_sym_Or] = ACTIONS(3760),
    [anon_sym_xor] = ACTIONS(3760),
    [anon_sym_XOR] = ACTIONS(3760),
    [anon_sym_Xor] = ACTIONS(3760),
    [anon_sym_QMARK] = ACTIONS(3762),
    [sym_datetime_literal] = ACTIONS(3762),
    [sym_date_literal] = ACTIONS(3760),
    [sym_time_literal] = ACTIONS(3760),
    [sym_biginteger_literal] = ACTIONS(3762),
    [anon_sym_in] = ACTIONS(3760),
    [anon_sym_IN] = ACTIONS(3760),
    [anon_sym_In] = ACTIONS(3760),
    [sym_page_keyword] = ACTIONS(3760),
    [anon_sym_codeunit] = ACTIONS(3760),
    [anon_sym_CODEUNIT] = ACTIONS(3760),
    [anon_sym_Codeunit] = ACTIONS(3760),
    [anon_sym_CodeUnit] = ACTIONS(3760),
    [anon_sym_COdeunit] = ACTIONS(3760),
    [anon_sym_codeUnit] = ACTIONS(3760),
    [sym_report_keyword] = ACTIONS(3760),
    [sym_query_keyword] = ACTIONS(3760),
    [anon_sym_xmlport] = ACTIONS(3760),
    [anon_sym_XMLPORT] = ACTIONS(3760),
    [anon_sym_Xmlport] = ACTIONS(3760),
    [anon_sym_XMLport] = ACTIONS(3760),
    [anon_sym_XMLPort] = ACTIONS(3760),
    [anon_sym_XmlPort] = ACTIONS(3760),
    [anon_sym_enum] = ACTIONS(3760),
    [anon_sym_ENUM] = ACTIONS(3760),
    [anon_sym_Enum] = ACTIONS(3760),
    [anon_sym_eNUM] = ACTIONS(3760),
    [anon_sym_eNum] = ACTIONS(3760),
    [anon_sym_ENum] = ACTIONS(3760),
    [sym_quoted_identifier] = ACTIONS(3762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3762),
    [sym_verbatim_string] = ACTIONS(3762),
    [sym_integer] = ACTIONS(3760),
    [sym_continue_as_identifier] = ACTIONS(3762),
    [sym_preproc_close] = ACTIONS(3762),
  },
  [STATE(2834)] = {
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_DOT] = ACTIONS(3703),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_COMMA] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [anon_sym_POUNDelif] = ACTIONS(3705),
    [anon_sym_POUNDELIF] = ACTIONS(3705),
    [anon_sym_POUNDElif] = ACTIONS(3705),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [anon_sym_POUNDendif] = ACTIONS(3705),
    [anon_sym_POUNDENDIF] = ACTIONS(3705),
    [anon_sym_POUNDEndif] = ACTIONS(3705),
    [anon_sym_POUNDendif2] = ACTIONS(3705),
    [anon_sym_POUNDENDIF2] = ACTIONS(3705),
    [anon_sym_POUNDEndif2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3705),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_close] = ACTIONS(3705),
  },
  [STATE(2835)] = {
    [sym_identifier] = ACTIONS(3756),
    [anon_sym_DOT] = ACTIONS(3756),
    [anon_sym_EQ] = ACTIONS(3758),
    [anon_sym_COMMA] = ACTIONS(3758),
    [anon_sym_DASH] = ACTIONS(3756),
    [aux_sym_boolean_token1] = ACTIONS(3756),
    [aux_sym_boolean_token2] = ACTIONS(3756),
    [sym_decimal] = ACTIONS(3756),
    [anon_sym_LPAREN] = ACTIONS(3758),
    [anon_sym_DOT_DOT] = ACTIONS(3758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3756),
    [anon_sym_LBRACK] = ACTIONS(3758),
    [aux_sym_record_type_token1] = ACTIONS(3756),
    [aux_sym_basic_type_token21] = ACTIONS(3756),
    [aux_sym_basic_type_token22] = ACTIONS(3756),
    [aux_sym_basic_type_token48] = ACTIONS(3756),
    [anon_sym_COLON_COLON] = ACTIONS(3758),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_NOT] = ACTIONS(3756),
    [anon_sym_Not] = ACTIONS(3756),
    [anon_sym_POUNDelif] = ACTIONS(3758),
    [anon_sym_POUNDELIF] = ACTIONS(3758),
    [anon_sym_POUNDElif] = ACTIONS(3758),
    [anon_sym_POUNDelse] = ACTIONS(3758),
    [anon_sym_POUNDELSE] = ACTIONS(3758),
    [anon_sym_POUNDElse] = ACTIONS(3758),
    [anon_sym_POUNDelse2] = ACTIONS(3758),
    [anon_sym_POUNDELSE2] = ACTIONS(3758),
    [anon_sym_POUNDElse2] = ACTIONS(3758),
    [anon_sym_POUNDendif] = ACTIONS(3758),
    [anon_sym_POUNDENDIF] = ACTIONS(3758),
    [anon_sym_POUNDEndif] = ACTIONS(3758),
    [anon_sym_POUNDendif2] = ACTIONS(3758),
    [anon_sym_POUNDENDIF2] = ACTIONS(3758),
    [anon_sym_POUNDEndif2] = ACTIONS(3758),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3758),
    [aux_sym__expression_token1] = ACTIONS(3758),
    [aux_sym__expression_token2] = ACTIONS(3758),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3756),
    [anon_sym_SLASH] = ACTIONS(3756),
    [anon_sym_div] = ACTIONS(3756),
    [anon_sym_DIV] = ACTIONS(3756),
    [anon_sym_Div] = ACTIONS(3756),
    [anon_sym_mod] = ACTIONS(3756),
    [anon_sym_MOD] = ACTIONS(3756),
    [anon_sym_Mod] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_GT_EQ] = ACTIONS(3758),
    [anon_sym_LT_EQ] = ACTIONS(3758),
    [anon_sym_GT] = ACTIONS(3756),
    [anon_sym_LT] = ACTIONS(3756),
    [anon_sym_LT_GT] = ACTIONS(3758),
    [anon_sym_and] = ACTIONS(3756),
    [anon_sym_AND] = ACTIONS(3756),
    [anon_sym_And] = ACTIONS(3756),
    [anon_sym_or] = ACTIONS(3756),
    [anon_sym_OR] = ACTIONS(3756),
    [anon_sym_Or] = ACTIONS(3756),
    [anon_sym_xor] = ACTIONS(3756),
    [anon_sym_XOR] = ACTIONS(3756),
    [anon_sym_Xor] = ACTIONS(3756),
    [anon_sym_QMARK] = ACTIONS(3758),
    [sym_datetime_literal] = ACTIONS(3758),
    [sym_date_literal] = ACTIONS(3756),
    [sym_time_literal] = ACTIONS(3756),
    [sym_biginteger_literal] = ACTIONS(3758),
    [anon_sym_in] = ACTIONS(3756),
    [anon_sym_IN] = ACTIONS(3756),
    [anon_sym_In] = ACTIONS(3756),
    [sym_page_keyword] = ACTIONS(3756),
    [anon_sym_codeunit] = ACTIONS(3756),
    [anon_sym_CODEUNIT] = ACTIONS(3756),
    [anon_sym_Codeunit] = ACTIONS(3756),
    [anon_sym_CodeUnit] = ACTIONS(3756),
    [anon_sym_COdeunit] = ACTIONS(3756),
    [anon_sym_codeUnit] = ACTIONS(3756),
    [sym_report_keyword] = ACTIONS(3756),
    [sym_query_keyword] = ACTIONS(3756),
    [anon_sym_xmlport] = ACTIONS(3756),
    [anon_sym_XMLPORT] = ACTIONS(3756),
    [anon_sym_Xmlport] = ACTIONS(3756),
    [anon_sym_XMLport] = ACTIONS(3756),
    [anon_sym_XMLPort] = ACTIONS(3756),
    [anon_sym_XmlPort] = ACTIONS(3756),
    [anon_sym_enum] = ACTIONS(3756),
    [anon_sym_ENUM] = ACTIONS(3756),
    [anon_sym_Enum] = ACTIONS(3756),
    [anon_sym_eNUM] = ACTIONS(3756),
    [anon_sym_eNum] = ACTIONS(3756),
    [anon_sym_ENum] = ACTIONS(3756),
    [sym_quoted_identifier] = ACTIONS(3758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3758),
    [sym_verbatim_string] = ACTIONS(3758),
    [sym_integer] = ACTIONS(3756),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_close] = ACTIONS(3758),
  },
  [STATE(2836)] = {
    [sym_identifier] = ACTIONS(3764),
    [anon_sym_DOT] = ACTIONS(3764),
    [anon_sym_EQ] = ACTIONS(3766),
    [anon_sym_COMMA] = ACTIONS(3766),
    [anon_sym_DASH] = ACTIONS(3764),
    [aux_sym_boolean_token1] = ACTIONS(3764),
    [aux_sym_boolean_token2] = ACTIONS(3764),
    [sym_decimal] = ACTIONS(3764),
    [anon_sym_LPAREN] = ACTIONS(3766),
    [anon_sym_DOT_DOT] = ACTIONS(3766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3764),
    [anon_sym_STAR] = ACTIONS(3764),
    [anon_sym_LBRACK] = ACTIONS(3766),
    [aux_sym_record_type_token1] = ACTIONS(3764),
    [aux_sym_basic_type_token21] = ACTIONS(3764),
    [aux_sym_basic_type_token22] = ACTIONS(3764),
    [aux_sym_basic_type_token48] = ACTIONS(3764),
    [anon_sym_COLON_COLON] = ACTIONS(3766),
    [anon_sym_not] = ACTIONS(3764),
    [anon_sym_NOT] = ACTIONS(3764),
    [anon_sym_Not] = ACTIONS(3764),
    [anon_sym_POUNDelif] = ACTIONS(3766),
    [anon_sym_POUNDELIF] = ACTIONS(3766),
    [anon_sym_POUNDElif] = ACTIONS(3766),
    [anon_sym_POUNDelse] = ACTIONS(3766),
    [anon_sym_POUNDELSE] = ACTIONS(3766),
    [anon_sym_POUNDElse] = ACTIONS(3766),
    [anon_sym_POUNDelse2] = ACTIONS(3766),
    [anon_sym_POUNDELSE2] = ACTIONS(3766),
    [anon_sym_POUNDElse2] = ACTIONS(3766),
    [anon_sym_POUNDendif] = ACTIONS(3766),
    [anon_sym_POUNDENDIF] = ACTIONS(3766),
    [anon_sym_POUNDEndif] = ACTIONS(3766),
    [anon_sym_POUNDendif2] = ACTIONS(3766),
    [anon_sym_POUNDENDIF2] = ACTIONS(3766),
    [anon_sym_POUNDEndif2] = ACTIONS(3766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3766),
    [aux_sym__expression_token1] = ACTIONS(3766),
    [aux_sym__expression_token2] = ACTIONS(3766),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3764),
    [anon_sym_SLASH] = ACTIONS(3764),
    [anon_sym_div] = ACTIONS(3764),
    [anon_sym_DIV] = ACTIONS(3764),
    [anon_sym_Div] = ACTIONS(3764),
    [anon_sym_mod] = ACTIONS(3764),
    [anon_sym_MOD] = ACTIONS(3764),
    [anon_sym_Mod] = ACTIONS(3764),
    [anon_sym_PLUS] = ACTIONS(3764),
    [anon_sym_GT_EQ] = ACTIONS(3766),
    [anon_sym_LT_EQ] = ACTIONS(3766),
    [anon_sym_GT] = ACTIONS(3764),
    [anon_sym_LT] = ACTIONS(3764),
    [anon_sym_LT_GT] = ACTIONS(3766),
    [anon_sym_and] = ACTIONS(3764),
    [anon_sym_AND] = ACTIONS(3764),
    [anon_sym_And] = ACTIONS(3764),
    [anon_sym_or] = ACTIONS(3764),
    [anon_sym_OR] = ACTIONS(3764),
    [anon_sym_Or] = ACTIONS(3764),
    [anon_sym_xor] = ACTIONS(3764),
    [anon_sym_XOR] = ACTIONS(3764),
    [anon_sym_Xor] = ACTIONS(3764),
    [anon_sym_QMARK] = ACTIONS(3766),
    [sym_datetime_literal] = ACTIONS(3766),
    [sym_date_literal] = ACTIONS(3764),
    [sym_time_literal] = ACTIONS(3764),
    [sym_biginteger_literal] = ACTIONS(3766),
    [anon_sym_in] = ACTIONS(3764),
    [anon_sym_IN] = ACTIONS(3764),
    [anon_sym_In] = ACTIONS(3764),
    [sym_page_keyword] = ACTIONS(3764),
    [anon_sym_codeunit] = ACTIONS(3764),
    [anon_sym_CODEUNIT] = ACTIONS(3764),
    [anon_sym_Codeunit] = ACTIONS(3764),
    [anon_sym_CodeUnit] = ACTIONS(3764),
    [anon_sym_COdeunit] = ACTIONS(3764),
    [anon_sym_codeUnit] = ACTIONS(3764),
    [sym_report_keyword] = ACTIONS(3764),
    [sym_query_keyword] = ACTIONS(3764),
    [anon_sym_xmlport] = ACTIONS(3764),
    [anon_sym_XMLPORT] = ACTIONS(3764),
    [anon_sym_Xmlport] = ACTIONS(3764),
    [anon_sym_XMLport] = ACTIONS(3764),
    [anon_sym_XMLPort] = ACTIONS(3764),
    [anon_sym_XmlPort] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3764),
    [anon_sym_ENUM] = ACTIONS(3764),
    [anon_sym_Enum] = ACTIONS(3764),
    [anon_sym_eNUM] = ACTIONS(3764),
    [anon_sym_eNum] = ACTIONS(3764),
    [anon_sym_ENum] = ACTIONS(3764),
    [sym_quoted_identifier] = ACTIONS(3766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3766),
    [sym_verbatim_string] = ACTIONS(3766),
    [sym_integer] = ACTIONS(3764),
    [sym_continue_as_identifier] = ACTIONS(3766),
    [sym_preproc_close] = ACTIONS(3766),
  },
  [STATE(2837)] = {
    [sym_identifier] = ACTIONS(3768),
    [anon_sym_DOT] = ACTIONS(3768),
    [anon_sym_EQ] = ACTIONS(3770),
    [anon_sym_COMMA] = ACTIONS(3770),
    [anon_sym_DASH] = ACTIONS(3768),
    [aux_sym_boolean_token1] = ACTIONS(3768),
    [aux_sym_boolean_token2] = ACTIONS(3768),
    [sym_decimal] = ACTIONS(3768),
    [anon_sym_LPAREN] = ACTIONS(3770),
    [anon_sym_DOT_DOT] = ACTIONS(3770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3768),
    [anon_sym_STAR] = ACTIONS(3768),
    [anon_sym_LBRACK] = ACTIONS(3770),
    [aux_sym_record_type_token1] = ACTIONS(3768),
    [aux_sym_basic_type_token21] = ACTIONS(3768),
    [aux_sym_basic_type_token22] = ACTIONS(3768),
    [aux_sym_basic_type_token48] = ACTIONS(3768),
    [anon_sym_COLON_COLON] = ACTIONS(3770),
    [anon_sym_not] = ACTIONS(3768),
    [anon_sym_NOT] = ACTIONS(3768),
    [anon_sym_Not] = ACTIONS(3768),
    [anon_sym_POUNDelif] = ACTIONS(3770),
    [anon_sym_POUNDELIF] = ACTIONS(3770),
    [anon_sym_POUNDElif] = ACTIONS(3770),
    [anon_sym_POUNDelse] = ACTIONS(3770),
    [anon_sym_POUNDELSE] = ACTIONS(3770),
    [anon_sym_POUNDElse] = ACTIONS(3770),
    [anon_sym_POUNDelse2] = ACTIONS(3770),
    [anon_sym_POUNDELSE2] = ACTIONS(3770),
    [anon_sym_POUNDElse2] = ACTIONS(3770),
    [anon_sym_POUNDendif] = ACTIONS(3770),
    [anon_sym_POUNDENDIF] = ACTIONS(3770),
    [anon_sym_POUNDEndif] = ACTIONS(3770),
    [anon_sym_POUNDendif2] = ACTIONS(3770),
    [anon_sym_POUNDENDIF2] = ACTIONS(3770),
    [anon_sym_POUNDEndif2] = ACTIONS(3770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3770),
    [aux_sym__expression_token1] = ACTIONS(3770),
    [aux_sym__expression_token2] = ACTIONS(3770),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3768),
    [anon_sym_SLASH] = ACTIONS(3768),
    [anon_sym_div] = ACTIONS(3768),
    [anon_sym_DIV] = ACTIONS(3768),
    [anon_sym_Div] = ACTIONS(3768),
    [anon_sym_mod] = ACTIONS(3768),
    [anon_sym_MOD] = ACTIONS(3768),
    [anon_sym_Mod] = ACTIONS(3768),
    [anon_sym_PLUS] = ACTIONS(3768),
    [anon_sym_GT_EQ] = ACTIONS(3770),
    [anon_sym_LT_EQ] = ACTIONS(3770),
    [anon_sym_GT] = ACTIONS(3768),
    [anon_sym_LT] = ACTIONS(3768),
    [anon_sym_LT_GT] = ACTIONS(3770),
    [anon_sym_and] = ACTIONS(3768),
    [anon_sym_AND] = ACTIONS(3768),
    [anon_sym_And] = ACTIONS(3768),
    [anon_sym_or] = ACTIONS(3768),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3768),
    [anon_sym_xor] = ACTIONS(3768),
    [anon_sym_XOR] = ACTIONS(3768),
    [anon_sym_Xor] = ACTIONS(3768),
    [anon_sym_QMARK] = ACTIONS(3770),
    [sym_datetime_literal] = ACTIONS(3770),
    [sym_date_literal] = ACTIONS(3768),
    [sym_time_literal] = ACTIONS(3768),
    [sym_biginteger_literal] = ACTIONS(3770),
    [anon_sym_in] = ACTIONS(3768),
    [anon_sym_IN] = ACTIONS(3768),
    [anon_sym_In] = ACTIONS(3768),
    [sym_page_keyword] = ACTIONS(3768),
    [anon_sym_codeunit] = ACTIONS(3768),
    [anon_sym_CODEUNIT] = ACTIONS(3768),
    [anon_sym_Codeunit] = ACTIONS(3768),
    [anon_sym_CodeUnit] = ACTIONS(3768),
    [anon_sym_COdeunit] = ACTIONS(3768),
    [anon_sym_codeUnit] = ACTIONS(3768),
    [sym_report_keyword] = ACTIONS(3768),
    [sym_query_keyword] = ACTIONS(3768),
    [anon_sym_xmlport] = ACTIONS(3768),
    [anon_sym_XMLPORT] = ACTIONS(3768),
    [anon_sym_Xmlport] = ACTIONS(3768),
    [anon_sym_XMLport] = ACTIONS(3768),
    [anon_sym_XMLPort] = ACTIONS(3768),
    [anon_sym_XmlPort] = ACTIONS(3768),
    [anon_sym_enum] = ACTIONS(3768),
    [anon_sym_ENUM] = ACTIONS(3768),
    [anon_sym_Enum] = ACTIONS(3768),
    [anon_sym_eNUM] = ACTIONS(3768),
    [anon_sym_eNum] = ACTIONS(3768),
    [anon_sym_ENum] = ACTIONS(3768),
    [sym_quoted_identifier] = ACTIONS(3770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3770),
    [sym_verbatim_string] = ACTIONS(3770),
    [sym_integer] = ACTIONS(3768),
    [sym_continue_as_identifier] = ACTIONS(3770),
    [sym_preproc_close] = ACTIONS(3770),
  },
  [STATE(2838)] = {
    [sym_identifier] = ACTIONS(3772),
    [anon_sym_DOT] = ACTIONS(3772),
    [anon_sym_EQ] = ACTIONS(3774),
    [anon_sym_COMMA] = ACTIONS(3774),
    [anon_sym_DASH] = ACTIONS(3772),
    [aux_sym_boolean_token1] = ACTIONS(3772),
    [aux_sym_boolean_token2] = ACTIONS(3772),
    [sym_decimal] = ACTIONS(3772),
    [anon_sym_LPAREN] = ACTIONS(3774),
    [anon_sym_DOT_DOT] = ACTIONS(3774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(3772),
    [anon_sym_LBRACK] = ACTIONS(3774),
    [aux_sym_record_type_token1] = ACTIONS(3772),
    [aux_sym_basic_type_token21] = ACTIONS(3772),
    [aux_sym_basic_type_token22] = ACTIONS(3772),
    [aux_sym_basic_type_token48] = ACTIONS(3772),
    [anon_sym_COLON_COLON] = ACTIONS(3774),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_NOT] = ACTIONS(3772),
    [anon_sym_Not] = ACTIONS(3772),
    [anon_sym_POUNDelif] = ACTIONS(3774),
    [anon_sym_POUNDELIF] = ACTIONS(3774),
    [anon_sym_POUNDElif] = ACTIONS(3774),
    [anon_sym_POUNDelse] = ACTIONS(3774),
    [anon_sym_POUNDELSE] = ACTIONS(3774),
    [anon_sym_POUNDElse] = ACTIONS(3774),
    [anon_sym_POUNDelse2] = ACTIONS(3774),
    [anon_sym_POUNDELSE2] = ACTIONS(3774),
    [anon_sym_POUNDElse2] = ACTIONS(3774),
    [anon_sym_POUNDendif] = ACTIONS(3774),
    [anon_sym_POUNDENDIF] = ACTIONS(3774),
    [anon_sym_POUNDEndif] = ACTIONS(3774),
    [anon_sym_POUNDendif2] = ACTIONS(3774),
    [anon_sym_POUNDENDIF2] = ACTIONS(3774),
    [anon_sym_POUNDEndif2] = ACTIONS(3774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3774),
    [aux_sym__expression_token1] = ACTIONS(3774),
    [aux_sym__expression_token2] = ACTIONS(3774),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3772),
    [anon_sym_SLASH] = ACTIONS(3772),
    [anon_sym_div] = ACTIONS(3772),
    [anon_sym_DIV] = ACTIONS(3772),
    [anon_sym_Div] = ACTIONS(3772),
    [anon_sym_mod] = ACTIONS(3772),
    [anon_sym_MOD] = ACTIONS(3772),
    [anon_sym_Mod] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_GT_EQ] = ACTIONS(3774),
    [anon_sym_LT_EQ] = ACTIONS(3774),
    [anon_sym_GT] = ACTIONS(3772),
    [anon_sym_LT] = ACTIONS(3772),
    [anon_sym_LT_GT] = ACTIONS(3774),
    [anon_sym_and] = ACTIONS(3772),
    [anon_sym_AND] = ACTIONS(3772),
    [anon_sym_And] = ACTIONS(3772),
    [anon_sym_or] = ACTIONS(3772),
    [anon_sym_OR] = ACTIONS(3772),
    [anon_sym_Or] = ACTIONS(3772),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3772),
    [anon_sym_Xor] = ACTIONS(3772),
    [anon_sym_QMARK] = ACTIONS(3774),
    [sym_datetime_literal] = ACTIONS(3774),
    [sym_date_literal] = ACTIONS(3772),
    [sym_time_literal] = ACTIONS(3772),
    [sym_biginteger_literal] = ACTIONS(3774),
    [anon_sym_in] = ACTIONS(3772),
    [anon_sym_IN] = ACTIONS(3772),
    [anon_sym_In] = ACTIONS(3772),
    [sym_page_keyword] = ACTIONS(3772),
    [anon_sym_codeunit] = ACTIONS(3772),
    [anon_sym_CODEUNIT] = ACTIONS(3772),
    [anon_sym_Codeunit] = ACTIONS(3772),
    [anon_sym_CodeUnit] = ACTIONS(3772),
    [anon_sym_COdeunit] = ACTIONS(3772),
    [anon_sym_codeUnit] = ACTIONS(3772),
    [sym_report_keyword] = ACTIONS(3772),
    [sym_query_keyword] = ACTIONS(3772),
    [anon_sym_xmlport] = ACTIONS(3772),
    [anon_sym_XMLPORT] = ACTIONS(3772),
    [anon_sym_Xmlport] = ACTIONS(3772),
    [anon_sym_XMLport] = ACTIONS(3772),
    [anon_sym_XMLPort] = ACTIONS(3772),
    [anon_sym_XmlPort] = ACTIONS(3772),
    [anon_sym_enum] = ACTIONS(3772),
    [anon_sym_ENUM] = ACTIONS(3772),
    [anon_sym_Enum] = ACTIONS(3772),
    [anon_sym_eNUM] = ACTIONS(3772),
    [anon_sym_eNum] = ACTIONS(3772),
    [anon_sym_ENum] = ACTIONS(3772),
    [sym_quoted_identifier] = ACTIONS(3774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3774),
    [sym_verbatim_string] = ACTIONS(3774),
    [sym_integer] = ACTIONS(3772),
    [sym_continue_as_identifier] = ACTIONS(3774),
    [sym_preproc_close] = ACTIONS(3774),
  },
  [STATE(2839)] = {
    [sym_identifier] = ACTIONS(3651),
    [anon_sym_DOT] = ACTIONS(3651),
    [anon_sym_EQ] = ACTIONS(3653),
    [anon_sym_COMMA] = ACTIONS(3653),
    [anon_sym_DASH] = ACTIONS(3651),
    [aux_sym_boolean_token1] = ACTIONS(3651),
    [aux_sym_boolean_token2] = ACTIONS(3651),
    [sym_decimal] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3653),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3651),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_LBRACK] = ACTIONS(3653),
    [aux_sym_record_type_token1] = ACTIONS(3651),
    [aux_sym_basic_type_token21] = ACTIONS(3651),
    [aux_sym_basic_type_token22] = ACTIONS(3651),
    [aux_sym_basic_type_token48] = ACTIONS(3651),
    [anon_sym_COLON_COLON] = ACTIONS(3653),
    [anon_sym_not] = ACTIONS(3651),
    [anon_sym_NOT] = ACTIONS(3651),
    [anon_sym_Not] = ACTIONS(3651),
    [anon_sym_POUNDelif] = ACTIONS(3653),
    [anon_sym_POUNDELIF] = ACTIONS(3653),
    [anon_sym_POUNDElif] = ACTIONS(3653),
    [anon_sym_POUNDelse] = ACTIONS(3653),
    [anon_sym_POUNDELSE] = ACTIONS(3653),
    [anon_sym_POUNDElse] = ACTIONS(3653),
    [anon_sym_POUNDelse2] = ACTIONS(3653),
    [anon_sym_POUNDELSE2] = ACTIONS(3653),
    [anon_sym_POUNDElse2] = ACTIONS(3653),
    [anon_sym_POUNDendif] = ACTIONS(3653),
    [anon_sym_POUNDENDIF] = ACTIONS(3653),
    [anon_sym_POUNDEndif] = ACTIONS(3653),
    [anon_sym_POUNDendif2] = ACTIONS(3653),
    [anon_sym_POUNDENDIF2] = ACTIONS(3653),
    [anon_sym_POUNDEndif2] = ACTIONS(3653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3653),
    [aux_sym__expression_token1] = ACTIONS(3653),
    [aux_sym__expression_token2] = ACTIONS(3653),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3651),
    [anon_sym_SLASH] = ACTIONS(3651),
    [anon_sym_div] = ACTIONS(3651),
    [anon_sym_DIV] = ACTIONS(3651),
    [anon_sym_Div] = ACTIONS(3651),
    [anon_sym_mod] = ACTIONS(3651),
    [anon_sym_MOD] = ACTIONS(3651),
    [anon_sym_Mod] = ACTIONS(3651),
    [anon_sym_PLUS] = ACTIONS(3651),
    [anon_sym_GT_EQ] = ACTIONS(3653),
    [anon_sym_LT_EQ] = ACTIONS(3653),
    [anon_sym_GT] = ACTIONS(3651),
    [anon_sym_LT] = ACTIONS(3651),
    [anon_sym_LT_GT] = ACTIONS(3653),
    [anon_sym_and] = ACTIONS(3651),
    [anon_sym_AND] = ACTIONS(3651),
    [anon_sym_And] = ACTIONS(3651),
    [anon_sym_or] = ACTIONS(3651),
    [anon_sym_OR] = ACTIONS(3651),
    [anon_sym_Or] = ACTIONS(3651),
    [anon_sym_xor] = ACTIONS(3651),
    [anon_sym_XOR] = ACTIONS(3651),
    [anon_sym_Xor] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [sym_datetime_literal] = ACTIONS(3653),
    [sym_date_literal] = ACTIONS(3651),
    [sym_time_literal] = ACTIONS(3651),
    [sym_biginteger_literal] = ACTIONS(3653),
    [anon_sym_in] = ACTIONS(3651),
    [anon_sym_IN] = ACTIONS(3651),
    [anon_sym_In] = ACTIONS(3651),
    [sym_page_keyword] = ACTIONS(3651),
    [anon_sym_codeunit] = ACTIONS(3651),
    [anon_sym_CODEUNIT] = ACTIONS(3651),
    [anon_sym_Codeunit] = ACTIONS(3651),
    [anon_sym_CodeUnit] = ACTIONS(3651),
    [anon_sym_COdeunit] = ACTIONS(3651),
    [anon_sym_codeUnit] = ACTIONS(3651),
    [sym_report_keyword] = ACTIONS(3651),
    [sym_query_keyword] = ACTIONS(3651),
    [anon_sym_xmlport] = ACTIONS(3651),
    [anon_sym_XMLPORT] = ACTIONS(3651),
    [anon_sym_Xmlport] = ACTIONS(3651),
    [anon_sym_XMLport] = ACTIONS(3651),
    [anon_sym_XMLPort] = ACTIONS(3651),
    [anon_sym_XmlPort] = ACTIONS(3651),
    [anon_sym_enum] = ACTIONS(3651),
    [anon_sym_ENUM] = ACTIONS(3651),
    [anon_sym_Enum] = ACTIONS(3651),
    [anon_sym_eNUM] = ACTIONS(3651),
    [anon_sym_eNum] = ACTIONS(3651),
    [anon_sym_ENum] = ACTIONS(3651),
    [sym_quoted_identifier] = ACTIONS(3653),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3653),
    [sym_verbatim_string] = ACTIONS(3653),
    [sym_integer] = ACTIONS(3651),
    [sym_continue_as_identifier] = ACTIONS(3653),
    [sym_preproc_close] = ACTIONS(3653),
  },
  [STATE(2840)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_COLON] = ACTIONS(5277),
    [anon_sym_DASH] = ACTIONS(5277),
    [aux_sym_boolean_token1] = ACTIONS(5279),
    [aux_sym_boolean_token2] = ACTIONS(5279),
    [sym_decimal] = ACTIONS(5279),
    [anon_sym_LPAREN] = ACTIONS(5277),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_record_type_token1] = ACTIONS(5279),
    [aux_sym_basic_type_token21] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token48] = ACTIONS(5279),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_not] = ACTIONS(5279),
    [anon_sym_NOT] = ACTIONS(5279),
    [anon_sym_Not] = ACTIONS(5279),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5279),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5279),
    [anon_sym_PLUS] = ACTIONS(5277),
    [sym_datetime_literal] = ACTIONS(5277),
    [sym_date_literal] = ACTIONS(5279),
    [sym_time_literal] = ACTIONS(5279),
    [sym_biginteger_literal] = ACTIONS(5277),
    [anon_sym_if] = ACTIONS(5279),
    [anon_sym_IF] = ACTIONS(5279),
    [anon_sym_If] = ACTIONS(5279),
    [anon_sym_else] = ACTIONS(5279),
    [anon_sym_ELSE] = ACTIONS(5279),
    [anon_sym_Else] = ACTIONS(5279),
    [anon_sym_case] = ACTIONS(5279),
    [anon_sym_CASE] = ACTIONS(5279),
    [anon_sym_Case] = ACTIONS(5279),
    [anon_sym_for] = ACTIONS(5279),
    [anon_sym_FOR] = ACTIONS(5279),
    [anon_sym_For] = ACTIONS(5279),
    [anon_sym_foreach] = ACTIONS(5279),
    [anon_sym_FOREACH] = ACTIONS(5279),
    [anon_sym_Foreach] = ACTIONS(5279),
    [anon_sym_while] = ACTIONS(5279),
    [anon_sym_WHILE] = ACTIONS(5279),
    [anon_sym_While] = ACTIONS(5279),
    [anon_sym_repeat] = ACTIONS(5279),
    [anon_sym_REPEAT] = ACTIONS(5279),
    [anon_sym_Repeat] = ACTIONS(5279),
    [anon_sym_until] = ACTIONS(5279),
    [anon_sym_UNTIL] = ACTIONS(5279),
    [anon_sym_Until] = ACTIONS(5279),
    [anon_sym_exit] = ACTIONS(5279),
    [anon_sym_EXIT] = ACTIONS(5279),
    [anon_sym_Exit] = ACTIONS(5279),
    [anon_sym_continue] = ACTIONS(5279),
    [anon_sym_CONTINUE] = ACTIONS(5279),
    [anon_sym_Continue] = ACTIONS(5279),
    [anon_sym_break] = ACTIONS(5279),
    [anon_sym_BREAK] = ACTIONS(5279),
    [anon_sym_Break] = ACTIONS(5279),
    [anon_sym_with] = ACTIONS(5279),
    [anon_sym_WITH] = ACTIONS(5279),
    [anon_sym_With] = ACTIONS(5279),
    [sym_asserterror_keyword] = ACTIONS(5277),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [anon_sym_enum] = ACTIONS(5279),
    [anon_sym_ENUM] = ACTIONS(5279),
    [anon_sym_Enum] = ACTIONS(5279),
    [anon_sym_eNUM] = ACTIONS(5279),
    [anon_sym_eNum] = ACTIONS(5279),
    [anon_sym_ENum] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5277),
    [sym_verbatim_string] = ACTIONS(5277),
    [sym_integer] = ACTIONS(5279),
    [sym_continue_as_identifier] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
  },
  [STATE(2841)] = {
    [anon_sym_POUNDif] = ACTIONS(7083),
    [anon_sym_POUNDIF] = ACTIONS(7083),
    [anon_sym_POUNDIf] = ACTIONS(7083),
    [anon_sym_POUNDelif] = ACTIONS(7083),
    [anon_sym_POUNDELIF] = ACTIONS(7083),
    [anon_sym_POUNDElif] = ACTIONS(7083),
    [anon_sym_POUNDelse] = ACTIONS(7083),
    [anon_sym_POUNDELSE] = ACTIONS(7083),
    [anon_sym_POUNDElse] = ACTIONS(7083),
    [anon_sym_POUNDelse2] = ACTIONS(7083),
    [anon_sym_POUNDELSE2] = ACTIONS(7083),
    [anon_sym_POUNDElse2] = ACTIONS(7083),
    [anon_sym_POUNDendif] = ACTIONS(7083),
    [anon_sym_POUNDENDIF] = ACTIONS(7083),
    [anon_sym_POUNDEndif] = ACTIONS(7083),
    [anon_sym_POUNDendif2] = ACTIONS(7083),
    [anon_sym_POUNDENDIF2] = ACTIONS(7083),
    [anon_sym_POUNDEndif2] = ACTIONS(7083),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7085),
    [anon_sym_tableextension] = ACTIONS(7083),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7083),
    [anon_sym_Tableextension] = ACTIONS(7083),
    [anon_sym_TableExtension] = ACTIONS(7083),
    [anon_sym_tableExtension] = ACTIONS(7083),
    [sym_page_keyword] = ACTIONS(7085),
    [anon_sym_pageextension] = ACTIONS(7083),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7083),
    [anon_sym_Pageextension] = ACTIONS(7083),
    [anon_sym_PageExtension] = ACTIONS(7083),
    [anon_sym_pageExtension] = ACTIONS(7083),
    [anon_sym_codeunit] = ACTIONS(7083),
    [anon_sym_CODEUNIT] = ACTIONS(7083),
    [anon_sym_Codeunit] = ACTIONS(7083),
    [anon_sym_CodeUnit] = ACTIONS(7083),
    [anon_sym_COdeunit] = ACTIONS(7083),
    [anon_sym_codeUnit] = ACTIONS(7083),
    [sym_report_keyword] = ACTIONS(7085),
    [anon_sym_reportextension] = ACTIONS(7083),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7083),
    [anon_sym_Reportextension] = ACTIONS(7083),
    [anon_sym_ReportExtension] = ACTIONS(7083),
    [anon_sym_reportExtension] = ACTIONS(7083),
    [sym_query_keyword] = ACTIONS(7083),
    [anon_sym_xmlport] = ACTIONS(7083),
    [anon_sym_XMLPORT] = ACTIONS(7083),
    [anon_sym_Xmlport] = ACTIONS(7083),
    [anon_sym_XMLport] = ACTIONS(7083),
    [anon_sym_XMLPort] = ACTIONS(7083),
    [anon_sym_XmlPort] = ACTIONS(7083),
    [anon_sym_enum] = ACTIONS(7085),
    [anon_sym_ENUM] = ACTIONS(7085),
    [anon_sym_Enum] = ACTIONS(7085),
    [anon_sym_eNUM] = ACTIONS(7083),
    [anon_sym_eNum] = ACTIONS(7083),
    [anon_sym_ENum] = ACTIONS(7083),
    [anon_sym_enumextension] = ACTIONS(7083),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7083),
    [anon_sym_Enumextension] = ACTIONS(7083),
    [anon_sym_EnumExtension] = ACTIONS(7083),
    [anon_sym_enumExtension] = ACTIONS(7083),
    [sym_interface_keyword] = ACTIONS(7083),
    [anon_sym_controladdin] = ACTIONS(7083),
    [anon_sym_CONTROLADDIN] = ACTIONS(7083),
    [anon_sym_Controladdin] = ACTIONS(7083),
    [anon_sym_ControlAddIn] = ACTIONS(7083),
    [anon_sym_ControlAddin] = ACTIONS(7083),
    [anon_sym_controlAddIn] = ACTIONS(7083),
    [anon_sym_controlAddin] = ACTIONS(7083),
    [anon_sym_dotnet] = ACTIONS(7083),
    [anon_sym_DOTNET] = ACTIONS(7083),
    [anon_sym_Dotnet] = ACTIONS(7083),
    [anon_sym_DotNet] = ACTIONS(7083),
    [anon_sym_dotNet] = ACTIONS(7083),
    [sym_profile_keyword] = ACTIONS(7085),
    [anon_sym_profileextension] = ACTIONS(7083),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7083),
    [anon_sym_Profileextension] = ACTIONS(7083),
    [anon_sym_ProfileExtension] = ACTIONS(7083),
    [anon_sym_profileExtension] = ACTIONS(7083),
    [anon_sym_permissionset] = ACTIONS(7085),
    [anon_sym_PERMISSIONSET] = ACTIONS(7085),
    [anon_sym_Permissionset] = ACTIONS(7085),
    [anon_sym_PermissionSet] = ACTIONS(7085),
    [anon_sym_permissionSet] = ACTIONS(7085),
    [anon_sym_permissionsetextension] = ACTIONS(7083),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7083),
    [anon_sym_Permissionsetextension] = ACTIONS(7083),
    [anon_sym_PermissionSetExtension] = ACTIONS(7083),
    [anon_sym_permissionSetExtension] = ACTIONS(7083),
    [sym_entitlement_keyword] = ACTIONS(7083),
    [anon_sym_pagecustomization] = ACTIONS(7083),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7083),
    [anon_sym_Pagecustomization] = ACTIONS(7083),
    [anon_sym_PageCustomization] = ACTIONS(7083),
    [anon_sym_pageCustomization] = ACTIONS(7083),
    [sym_using_keyword] = ACTIONS(7083),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7083),
    [sym_preproc_close] = ACTIONS(7083),
  },
  [STATE(2842)] = {
    [anon_sym_POUNDif] = ACTIONS(7087),
    [anon_sym_POUNDIF] = ACTIONS(7087),
    [anon_sym_POUNDIf] = ACTIONS(7087),
    [anon_sym_POUNDelif] = ACTIONS(7087),
    [anon_sym_POUNDELIF] = ACTIONS(7087),
    [anon_sym_POUNDElif] = ACTIONS(7087),
    [anon_sym_POUNDelse] = ACTIONS(7087),
    [anon_sym_POUNDELSE] = ACTIONS(7087),
    [anon_sym_POUNDElse] = ACTIONS(7087),
    [anon_sym_POUNDelse2] = ACTIONS(7087),
    [anon_sym_POUNDELSE2] = ACTIONS(7087),
    [anon_sym_POUNDElse2] = ACTIONS(7087),
    [anon_sym_POUNDendif] = ACTIONS(7087),
    [anon_sym_POUNDENDIF] = ACTIONS(7087),
    [anon_sym_POUNDEndif] = ACTIONS(7087),
    [anon_sym_POUNDendif2] = ACTIONS(7087),
    [anon_sym_POUNDENDIF2] = ACTIONS(7087),
    [anon_sym_POUNDEndif2] = ACTIONS(7087),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7089),
    [anon_sym_tableextension] = ACTIONS(7087),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7087),
    [anon_sym_Tableextension] = ACTIONS(7087),
    [anon_sym_TableExtension] = ACTIONS(7087),
    [anon_sym_tableExtension] = ACTIONS(7087),
    [sym_page_keyword] = ACTIONS(7089),
    [anon_sym_pageextension] = ACTIONS(7087),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7087),
    [anon_sym_Pageextension] = ACTIONS(7087),
    [anon_sym_PageExtension] = ACTIONS(7087),
    [anon_sym_pageExtension] = ACTIONS(7087),
    [anon_sym_codeunit] = ACTIONS(7087),
    [anon_sym_CODEUNIT] = ACTIONS(7087),
    [anon_sym_Codeunit] = ACTIONS(7087),
    [anon_sym_CodeUnit] = ACTIONS(7087),
    [anon_sym_COdeunit] = ACTIONS(7087),
    [anon_sym_codeUnit] = ACTIONS(7087),
    [sym_report_keyword] = ACTIONS(7089),
    [anon_sym_reportextension] = ACTIONS(7087),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7087),
    [anon_sym_Reportextension] = ACTIONS(7087),
    [anon_sym_ReportExtension] = ACTIONS(7087),
    [anon_sym_reportExtension] = ACTIONS(7087),
    [sym_query_keyword] = ACTIONS(7087),
    [anon_sym_xmlport] = ACTIONS(7087),
    [anon_sym_XMLPORT] = ACTIONS(7087),
    [anon_sym_Xmlport] = ACTIONS(7087),
    [anon_sym_XMLport] = ACTIONS(7087),
    [anon_sym_XMLPort] = ACTIONS(7087),
    [anon_sym_XmlPort] = ACTIONS(7087),
    [anon_sym_enum] = ACTIONS(7089),
    [anon_sym_ENUM] = ACTIONS(7089),
    [anon_sym_Enum] = ACTIONS(7089),
    [anon_sym_eNUM] = ACTIONS(7087),
    [anon_sym_eNum] = ACTIONS(7087),
    [anon_sym_ENum] = ACTIONS(7087),
    [anon_sym_enumextension] = ACTIONS(7087),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7087),
    [anon_sym_Enumextension] = ACTIONS(7087),
    [anon_sym_EnumExtension] = ACTIONS(7087),
    [anon_sym_enumExtension] = ACTIONS(7087),
    [sym_interface_keyword] = ACTIONS(7087),
    [anon_sym_controladdin] = ACTIONS(7087),
    [anon_sym_CONTROLADDIN] = ACTIONS(7087),
    [anon_sym_Controladdin] = ACTIONS(7087),
    [anon_sym_ControlAddIn] = ACTIONS(7087),
    [anon_sym_ControlAddin] = ACTIONS(7087),
    [anon_sym_controlAddIn] = ACTIONS(7087),
    [anon_sym_controlAddin] = ACTIONS(7087),
    [anon_sym_dotnet] = ACTIONS(7087),
    [anon_sym_DOTNET] = ACTIONS(7087),
    [anon_sym_Dotnet] = ACTIONS(7087),
    [anon_sym_DotNet] = ACTIONS(7087),
    [anon_sym_dotNet] = ACTIONS(7087),
    [sym_profile_keyword] = ACTIONS(7089),
    [anon_sym_profileextension] = ACTIONS(7087),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7087),
    [anon_sym_Profileextension] = ACTIONS(7087),
    [anon_sym_ProfileExtension] = ACTIONS(7087),
    [anon_sym_profileExtension] = ACTIONS(7087),
    [anon_sym_permissionset] = ACTIONS(7089),
    [anon_sym_PERMISSIONSET] = ACTIONS(7089),
    [anon_sym_Permissionset] = ACTIONS(7089),
    [anon_sym_PermissionSet] = ACTIONS(7089),
    [anon_sym_permissionSet] = ACTIONS(7089),
    [anon_sym_permissionsetextension] = ACTIONS(7087),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7087),
    [anon_sym_Permissionsetextension] = ACTIONS(7087),
    [anon_sym_PermissionSetExtension] = ACTIONS(7087),
    [anon_sym_permissionSetExtension] = ACTIONS(7087),
    [sym_entitlement_keyword] = ACTIONS(7087),
    [anon_sym_pagecustomization] = ACTIONS(7087),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7087),
    [anon_sym_Pagecustomization] = ACTIONS(7087),
    [anon_sym_PageCustomization] = ACTIONS(7087),
    [anon_sym_pageCustomization] = ACTIONS(7087),
    [sym_using_keyword] = ACTIONS(7087),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7087),
    [sym_preproc_close] = ACTIONS(7087),
  },
  [STATE(2843)] = {
    [anon_sym_POUNDif] = ACTIONS(7091),
    [anon_sym_POUNDIF] = ACTIONS(7091),
    [anon_sym_POUNDIf] = ACTIONS(7091),
    [anon_sym_POUNDelif] = ACTIONS(7091),
    [anon_sym_POUNDELIF] = ACTIONS(7091),
    [anon_sym_POUNDElif] = ACTIONS(7091),
    [anon_sym_POUNDelse] = ACTIONS(7091),
    [anon_sym_POUNDELSE] = ACTIONS(7091),
    [anon_sym_POUNDElse] = ACTIONS(7091),
    [anon_sym_POUNDelse2] = ACTIONS(7091),
    [anon_sym_POUNDELSE2] = ACTIONS(7091),
    [anon_sym_POUNDElse2] = ACTIONS(7091),
    [anon_sym_POUNDendif] = ACTIONS(7091),
    [anon_sym_POUNDENDIF] = ACTIONS(7091),
    [anon_sym_POUNDEndif] = ACTIONS(7091),
    [anon_sym_POUNDendif2] = ACTIONS(7091),
    [anon_sym_POUNDENDIF2] = ACTIONS(7091),
    [anon_sym_POUNDEndif2] = ACTIONS(7091),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7093),
    [anon_sym_tableextension] = ACTIONS(7091),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7091),
    [anon_sym_Tableextension] = ACTIONS(7091),
    [anon_sym_TableExtension] = ACTIONS(7091),
    [anon_sym_tableExtension] = ACTIONS(7091),
    [sym_page_keyword] = ACTIONS(7093),
    [anon_sym_pageextension] = ACTIONS(7091),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7091),
    [anon_sym_Pageextension] = ACTIONS(7091),
    [anon_sym_PageExtension] = ACTIONS(7091),
    [anon_sym_pageExtension] = ACTIONS(7091),
    [anon_sym_codeunit] = ACTIONS(7091),
    [anon_sym_CODEUNIT] = ACTIONS(7091),
    [anon_sym_Codeunit] = ACTIONS(7091),
    [anon_sym_CodeUnit] = ACTIONS(7091),
    [anon_sym_COdeunit] = ACTIONS(7091),
    [anon_sym_codeUnit] = ACTIONS(7091),
    [sym_report_keyword] = ACTIONS(7093),
    [anon_sym_reportextension] = ACTIONS(7091),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7091),
    [anon_sym_Reportextension] = ACTIONS(7091),
    [anon_sym_ReportExtension] = ACTIONS(7091),
    [anon_sym_reportExtension] = ACTIONS(7091),
    [sym_query_keyword] = ACTIONS(7091),
    [anon_sym_xmlport] = ACTIONS(7091),
    [anon_sym_XMLPORT] = ACTIONS(7091),
    [anon_sym_Xmlport] = ACTIONS(7091),
    [anon_sym_XMLport] = ACTIONS(7091),
    [anon_sym_XMLPort] = ACTIONS(7091),
    [anon_sym_XmlPort] = ACTIONS(7091),
    [anon_sym_enum] = ACTIONS(7093),
    [anon_sym_ENUM] = ACTIONS(7093),
    [anon_sym_Enum] = ACTIONS(7093),
    [anon_sym_eNUM] = ACTIONS(7091),
    [anon_sym_eNum] = ACTIONS(7091),
    [anon_sym_ENum] = ACTIONS(7091),
    [anon_sym_enumextension] = ACTIONS(7091),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7091),
    [anon_sym_Enumextension] = ACTIONS(7091),
    [anon_sym_EnumExtension] = ACTIONS(7091),
    [anon_sym_enumExtension] = ACTIONS(7091),
    [sym_interface_keyword] = ACTIONS(7091),
    [anon_sym_controladdin] = ACTIONS(7091),
    [anon_sym_CONTROLADDIN] = ACTIONS(7091),
    [anon_sym_Controladdin] = ACTIONS(7091),
    [anon_sym_ControlAddIn] = ACTIONS(7091),
    [anon_sym_ControlAddin] = ACTIONS(7091),
    [anon_sym_controlAddIn] = ACTIONS(7091),
    [anon_sym_controlAddin] = ACTIONS(7091),
    [anon_sym_dotnet] = ACTIONS(7091),
    [anon_sym_DOTNET] = ACTIONS(7091),
    [anon_sym_Dotnet] = ACTIONS(7091),
    [anon_sym_DotNet] = ACTIONS(7091),
    [anon_sym_dotNet] = ACTIONS(7091),
    [sym_profile_keyword] = ACTIONS(7093),
    [anon_sym_profileextension] = ACTIONS(7091),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7091),
    [anon_sym_Profileextension] = ACTIONS(7091),
    [anon_sym_ProfileExtension] = ACTIONS(7091),
    [anon_sym_profileExtension] = ACTIONS(7091),
    [anon_sym_permissionset] = ACTIONS(7093),
    [anon_sym_PERMISSIONSET] = ACTIONS(7093),
    [anon_sym_Permissionset] = ACTIONS(7093),
    [anon_sym_PermissionSet] = ACTIONS(7093),
    [anon_sym_permissionSet] = ACTIONS(7093),
    [anon_sym_permissionsetextension] = ACTIONS(7091),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7091),
    [anon_sym_Permissionsetextension] = ACTIONS(7091),
    [anon_sym_PermissionSetExtension] = ACTIONS(7091),
    [anon_sym_permissionSetExtension] = ACTIONS(7091),
    [sym_entitlement_keyword] = ACTIONS(7091),
    [anon_sym_pagecustomization] = ACTIONS(7091),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7091),
    [anon_sym_Pagecustomization] = ACTIONS(7091),
    [anon_sym_PageCustomization] = ACTIONS(7091),
    [anon_sym_pageCustomization] = ACTIONS(7091),
    [sym_using_keyword] = ACTIONS(7091),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7091),
    [sym_preproc_close] = ACTIONS(7091),
  },
  [STATE(2844)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(7095),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(2845)] = {
    [sym_identifier] = ACTIONS(3776),
    [anon_sym_DOT] = ACTIONS(3776),
    [anon_sym_EQ] = ACTIONS(3778),
    [anon_sym_COMMA] = ACTIONS(3778),
    [anon_sym_DASH] = ACTIONS(3776),
    [aux_sym_boolean_token1] = ACTIONS(3776),
    [aux_sym_boolean_token2] = ACTIONS(3776),
    [sym_decimal] = ACTIONS(3776),
    [anon_sym_LPAREN] = ACTIONS(3778),
    [anon_sym_DOT_DOT] = ACTIONS(3778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3776),
    [anon_sym_STAR] = ACTIONS(3776),
    [anon_sym_LBRACK] = ACTIONS(3778),
    [aux_sym_record_type_token1] = ACTIONS(3776),
    [aux_sym_basic_type_token21] = ACTIONS(3776),
    [aux_sym_basic_type_token22] = ACTIONS(3776),
    [aux_sym_basic_type_token48] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_not] = ACTIONS(3776),
    [anon_sym_NOT] = ACTIONS(3776),
    [anon_sym_Not] = ACTIONS(3776),
    [anon_sym_POUNDelif] = ACTIONS(3778),
    [anon_sym_POUNDELIF] = ACTIONS(3778),
    [anon_sym_POUNDElif] = ACTIONS(3778),
    [anon_sym_POUNDelse] = ACTIONS(3778),
    [anon_sym_POUNDELSE] = ACTIONS(3778),
    [anon_sym_POUNDElse] = ACTIONS(3778),
    [anon_sym_POUNDelse2] = ACTIONS(3778),
    [anon_sym_POUNDELSE2] = ACTIONS(3778),
    [anon_sym_POUNDElse2] = ACTIONS(3778),
    [anon_sym_POUNDendif] = ACTIONS(3778),
    [anon_sym_POUNDENDIF] = ACTIONS(3778),
    [anon_sym_POUNDEndif] = ACTIONS(3778),
    [anon_sym_POUNDendif2] = ACTIONS(3778),
    [anon_sym_POUNDENDIF2] = ACTIONS(3778),
    [anon_sym_POUNDEndif2] = ACTIONS(3778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3778),
    [aux_sym__expression_token1] = ACTIONS(3778),
    [aux_sym__expression_token2] = ACTIONS(3778),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3776),
    [anon_sym_SLASH] = ACTIONS(3776),
    [anon_sym_div] = ACTIONS(3776),
    [anon_sym_DIV] = ACTIONS(3776),
    [anon_sym_Div] = ACTIONS(3776),
    [anon_sym_mod] = ACTIONS(3776),
    [anon_sym_MOD] = ACTIONS(3776),
    [anon_sym_Mod] = ACTIONS(3776),
    [anon_sym_PLUS] = ACTIONS(3776),
    [anon_sym_GT_EQ] = ACTIONS(3778),
    [anon_sym_LT_EQ] = ACTIONS(3778),
    [anon_sym_GT] = ACTIONS(3776),
    [anon_sym_LT] = ACTIONS(3776),
    [anon_sym_LT_GT] = ACTIONS(3778),
    [anon_sym_and] = ACTIONS(3776),
    [anon_sym_AND] = ACTIONS(3776),
    [anon_sym_And] = ACTIONS(3776),
    [anon_sym_or] = ACTIONS(3776),
    [anon_sym_OR] = ACTIONS(3776),
    [anon_sym_Or] = ACTIONS(3776),
    [anon_sym_xor] = ACTIONS(3776),
    [anon_sym_XOR] = ACTIONS(3776),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(3778),
    [sym_date_literal] = ACTIONS(3776),
    [sym_time_literal] = ACTIONS(3776),
    [sym_biginteger_literal] = ACTIONS(3778),
    [anon_sym_in] = ACTIONS(3776),
    [anon_sym_IN] = ACTIONS(3776),
    [anon_sym_In] = ACTIONS(3776),
    [sym_page_keyword] = ACTIONS(3776),
    [anon_sym_codeunit] = ACTIONS(3776),
    [anon_sym_CODEUNIT] = ACTIONS(3776),
    [anon_sym_Codeunit] = ACTIONS(3776),
    [anon_sym_CodeUnit] = ACTIONS(3776),
    [anon_sym_COdeunit] = ACTIONS(3776),
    [anon_sym_codeUnit] = ACTIONS(3776),
    [sym_report_keyword] = ACTIONS(3776),
    [sym_query_keyword] = ACTIONS(3776),
    [anon_sym_xmlport] = ACTIONS(3776),
    [anon_sym_XMLPORT] = ACTIONS(3776),
    [anon_sym_Xmlport] = ACTIONS(3776),
    [anon_sym_XMLport] = ACTIONS(3776),
    [anon_sym_XMLPort] = ACTIONS(3776),
    [anon_sym_XmlPort] = ACTIONS(3776),
    [anon_sym_enum] = ACTIONS(3776),
    [anon_sym_ENUM] = ACTIONS(3776),
    [anon_sym_Enum] = ACTIONS(3776),
    [anon_sym_eNUM] = ACTIONS(3776),
    [anon_sym_eNum] = ACTIONS(3776),
    [anon_sym_ENum] = ACTIONS(3776),
    [sym_quoted_identifier] = ACTIONS(3778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3778),
    [sym_verbatim_string] = ACTIONS(3778),
    [sym_integer] = ACTIONS(3776),
    [sym_continue_as_identifier] = ACTIONS(3778),
    [sym_preproc_close] = ACTIONS(3778),
  },
  [STATE(2846)] = {
    [anon_sym_POUNDif] = ACTIONS(7097),
    [anon_sym_POUNDIF] = ACTIONS(7097),
    [anon_sym_POUNDIf] = ACTIONS(7097),
    [anon_sym_POUNDelif] = ACTIONS(7097),
    [anon_sym_POUNDELIF] = ACTIONS(7097),
    [anon_sym_POUNDElif] = ACTIONS(7097),
    [anon_sym_POUNDelse] = ACTIONS(7097),
    [anon_sym_POUNDELSE] = ACTIONS(7097),
    [anon_sym_POUNDElse] = ACTIONS(7097),
    [anon_sym_POUNDelse2] = ACTIONS(7097),
    [anon_sym_POUNDELSE2] = ACTIONS(7097),
    [anon_sym_POUNDElse2] = ACTIONS(7097),
    [anon_sym_POUNDendif] = ACTIONS(7097),
    [anon_sym_POUNDENDIF] = ACTIONS(7097),
    [anon_sym_POUNDEndif] = ACTIONS(7097),
    [anon_sym_POUNDendif2] = ACTIONS(7097),
    [anon_sym_POUNDENDIF2] = ACTIONS(7097),
    [anon_sym_POUNDEndif2] = ACTIONS(7097),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7099),
    [anon_sym_tableextension] = ACTIONS(7097),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7097),
    [anon_sym_Tableextension] = ACTIONS(7097),
    [anon_sym_TableExtension] = ACTIONS(7097),
    [anon_sym_tableExtension] = ACTIONS(7097),
    [sym_page_keyword] = ACTIONS(7099),
    [anon_sym_pageextension] = ACTIONS(7097),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7097),
    [anon_sym_Pageextension] = ACTIONS(7097),
    [anon_sym_PageExtension] = ACTIONS(7097),
    [anon_sym_pageExtension] = ACTIONS(7097),
    [anon_sym_codeunit] = ACTIONS(7097),
    [anon_sym_CODEUNIT] = ACTIONS(7097),
    [anon_sym_Codeunit] = ACTIONS(7097),
    [anon_sym_CodeUnit] = ACTIONS(7097),
    [anon_sym_COdeunit] = ACTIONS(7097),
    [anon_sym_codeUnit] = ACTIONS(7097),
    [sym_report_keyword] = ACTIONS(7099),
    [anon_sym_reportextension] = ACTIONS(7097),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7097),
    [anon_sym_Reportextension] = ACTIONS(7097),
    [anon_sym_ReportExtension] = ACTIONS(7097),
    [anon_sym_reportExtension] = ACTIONS(7097),
    [sym_query_keyword] = ACTIONS(7097),
    [anon_sym_xmlport] = ACTIONS(7097),
    [anon_sym_XMLPORT] = ACTIONS(7097),
    [anon_sym_Xmlport] = ACTIONS(7097),
    [anon_sym_XMLport] = ACTIONS(7097),
    [anon_sym_XMLPort] = ACTIONS(7097),
    [anon_sym_XmlPort] = ACTIONS(7097),
    [anon_sym_enum] = ACTIONS(7099),
    [anon_sym_ENUM] = ACTIONS(7099),
    [anon_sym_Enum] = ACTIONS(7099),
    [anon_sym_eNUM] = ACTIONS(7097),
    [anon_sym_eNum] = ACTIONS(7097),
    [anon_sym_ENum] = ACTIONS(7097),
    [anon_sym_enumextension] = ACTIONS(7097),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7097),
    [anon_sym_Enumextension] = ACTIONS(7097),
    [anon_sym_EnumExtension] = ACTIONS(7097),
    [anon_sym_enumExtension] = ACTIONS(7097),
    [sym_interface_keyword] = ACTIONS(7097),
    [anon_sym_controladdin] = ACTIONS(7097),
    [anon_sym_CONTROLADDIN] = ACTIONS(7097),
    [anon_sym_Controladdin] = ACTIONS(7097),
    [anon_sym_ControlAddIn] = ACTIONS(7097),
    [anon_sym_ControlAddin] = ACTIONS(7097),
    [anon_sym_controlAddIn] = ACTIONS(7097),
    [anon_sym_controlAddin] = ACTIONS(7097),
    [anon_sym_dotnet] = ACTIONS(7097),
    [anon_sym_DOTNET] = ACTIONS(7097),
    [anon_sym_Dotnet] = ACTIONS(7097),
    [anon_sym_DotNet] = ACTIONS(7097),
    [anon_sym_dotNet] = ACTIONS(7097),
    [sym_profile_keyword] = ACTIONS(7099),
    [anon_sym_profileextension] = ACTIONS(7097),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7097),
    [anon_sym_Profileextension] = ACTIONS(7097),
    [anon_sym_ProfileExtension] = ACTIONS(7097),
    [anon_sym_profileExtension] = ACTIONS(7097),
    [anon_sym_permissionset] = ACTIONS(7099),
    [anon_sym_PERMISSIONSET] = ACTIONS(7099),
    [anon_sym_Permissionset] = ACTIONS(7099),
    [anon_sym_PermissionSet] = ACTIONS(7099),
    [anon_sym_permissionSet] = ACTIONS(7099),
    [anon_sym_permissionsetextension] = ACTIONS(7097),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7097),
    [anon_sym_Permissionsetextension] = ACTIONS(7097),
    [anon_sym_PermissionSetExtension] = ACTIONS(7097),
    [anon_sym_permissionSetExtension] = ACTIONS(7097),
    [sym_entitlement_keyword] = ACTIONS(7097),
    [anon_sym_pagecustomization] = ACTIONS(7097),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7097),
    [anon_sym_Pagecustomization] = ACTIONS(7097),
    [anon_sym_PageCustomization] = ACTIONS(7097),
    [anon_sym_pageCustomization] = ACTIONS(7097),
    [sym_using_keyword] = ACTIONS(7097),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7097),
    [sym_preproc_close] = ACTIONS(7097),
  },
  [STATE(2847)] = {
    [anon_sym_POUNDif] = ACTIONS(7101),
    [anon_sym_POUNDIF] = ACTIONS(7101),
    [anon_sym_POUNDIf] = ACTIONS(7101),
    [anon_sym_POUNDelif] = ACTIONS(7101),
    [anon_sym_POUNDELIF] = ACTIONS(7101),
    [anon_sym_POUNDElif] = ACTIONS(7101),
    [anon_sym_POUNDelse] = ACTIONS(7101),
    [anon_sym_POUNDELSE] = ACTIONS(7101),
    [anon_sym_POUNDElse] = ACTIONS(7101),
    [anon_sym_POUNDelse2] = ACTIONS(7101),
    [anon_sym_POUNDELSE2] = ACTIONS(7101),
    [anon_sym_POUNDElse2] = ACTIONS(7101),
    [anon_sym_POUNDendif] = ACTIONS(7101),
    [anon_sym_POUNDENDIF] = ACTIONS(7101),
    [anon_sym_POUNDEndif] = ACTIONS(7101),
    [anon_sym_POUNDendif2] = ACTIONS(7101),
    [anon_sym_POUNDENDIF2] = ACTIONS(7101),
    [anon_sym_POUNDEndif2] = ACTIONS(7101),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7103),
    [anon_sym_tableextension] = ACTIONS(7101),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7101),
    [anon_sym_Tableextension] = ACTIONS(7101),
    [anon_sym_TableExtension] = ACTIONS(7101),
    [anon_sym_tableExtension] = ACTIONS(7101),
    [sym_page_keyword] = ACTIONS(7103),
    [anon_sym_pageextension] = ACTIONS(7101),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7101),
    [anon_sym_Pageextension] = ACTIONS(7101),
    [anon_sym_PageExtension] = ACTIONS(7101),
    [anon_sym_pageExtension] = ACTIONS(7101),
    [anon_sym_codeunit] = ACTIONS(7101),
    [anon_sym_CODEUNIT] = ACTIONS(7101),
    [anon_sym_Codeunit] = ACTIONS(7101),
    [anon_sym_CodeUnit] = ACTIONS(7101),
    [anon_sym_COdeunit] = ACTIONS(7101),
    [anon_sym_codeUnit] = ACTIONS(7101),
    [sym_report_keyword] = ACTIONS(7103),
    [anon_sym_reportextension] = ACTIONS(7101),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7101),
    [anon_sym_Reportextension] = ACTIONS(7101),
    [anon_sym_ReportExtension] = ACTIONS(7101),
    [anon_sym_reportExtension] = ACTIONS(7101),
    [sym_query_keyword] = ACTIONS(7101),
    [anon_sym_xmlport] = ACTIONS(7101),
    [anon_sym_XMLPORT] = ACTIONS(7101),
    [anon_sym_Xmlport] = ACTIONS(7101),
    [anon_sym_XMLport] = ACTIONS(7101),
    [anon_sym_XMLPort] = ACTIONS(7101),
    [anon_sym_XmlPort] = ACTIONS(7101),
    [anon_sym_enum] = ACTIONS(7103),
    [anon_sym_ENUM] = ACTIONS(7103),
    [anon_sym_Enum] = ACTIONS(7103),
    [anon_sym_eNUM] = ACTIONS(7101),
    [anon_sym_eNum] = ACTIONS(7101),
    [anon_sym_ENum] = ACTIONS(7101),
    [anon_sym_enumextension] = ACTIONS(7101),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7101),
    [anon_sym_Enumextension] = ACTIONS(7101),
    [anon_sym_EnumExtension] = ACTIONS(7101),
    [anon_sym_enumExtension] = ACTIONS(7101),
    [sym_interface_keyword] = ACTIONS(7101),
    [anon_sym_controladdin] = ACTIONS(7101),
    [anon_sym_CONTROLADDIN] = ACTIONS(7101),
    [anon_sym_Controladdin] = ACTIONS(7101),
    [anon_sym_ControlAddIn] = ACTIONS(7101),
    [anon_sym_ControlAddin] = ACTIONS(7101),
    [anon_sym_controlAddIn] = ACTIONS(7101),
    [anon_sym_controlAddin] = ACTIONS(7101),
    [anon_sym_dotnet] = ACTIONS(7101),
    [anon_sym_DOTNET] = ACTIONS(7101),
    [anon_sym_Dotnet] = ACTIONS(7101),
    [anon_sym_DotNet] = ACTIONS(7101),
    [anon_sym_dotNet] = ACTIONS(7101),
    [sym_profile_keyword] = ACTIONS(7103),
    [anon_sym_profileextension] = ACTIONS(7101),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7101),
    [anon_sym_Profileextension] = ACTIONS(7101),
    [anon_sym_ProfileExtension] = ACTIONS(7101),
    [anon_sym_profileExtension] = ACTIONS(7101),
    [anon_sym_permissionset] = ACTIONS(7103),
    [anon_sym_PERMISSIONSET] = ACTIONS(7103),
    [anon_sym_Permissionset] = ACTIONS(7103),
    [anon_sym_PermissionSet] = ACTIONS(7103),
    [anon_sym_permissionSet] = ACTIONS(7103),
    [anon_sym_permissionsetextension] = ACTIONS(7101),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7101),
    [anon_sym_Permissionsetextension] = ACTIONS(7101),
    [anon_sym_PermissionSetExtension] = ACTIONS(7101),
    [anon_sym_permissionSetExtension] = ACTIONS(7101),
    [sym_entitlement_keyword] = ACTIONS(7101),
    [anon_sym_pagecustomization] = ACTIONS(7101),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7101),
    [anon_sym_Pagecustomization] = ACTIONS(7101),
    [anon_sym_PageCustomization] = ACTIONS(7101),
    [anon_sym_pageCustomization] = ACTIONS(7101),
    [sym_using_keyword] = ACTIONS(7101),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7101),
    [sym_preproc_close] = ACTIONS(7101),
  },
  [STATE(2848)] = {
    [anon_sym_POUNDif] = ACTIONS(7105),
    [anon_sym_POUNDIF] = ACTIONS(7105),
    [anon_sym_POUNDIf] = ACTIONS(7105),
    [anon_sym_POUNDelif] = ACTIONS(7105),
    [anon_sym_POUNDELIF] = ACTIONS(7105),
    [anon_sym_POUNDElif] = ACTIONS(7105),
    [anon_sym_POUNDelse] = ACTIONS(7105),
    [anon_sym_POUNDELSE] = ACTIONS(7105),
    [anon_sym_POUNDElse] = ACTIONS(7105),
    [anon_sym_POUNDelse2] = ACTIONS(7105),
    [anon_sym_POUNDELSE2] = ACTIONS(7105),
    [anon_sym_POUNDElse2] = ACTIONS(7105),
    [anon_sym_POUNDendif] = ACTIONS(7105),
    [anon_sym_POUNDENDIF] = ACTIONS(7105),
    [anon_sym_POUNDEndif] = ACTIONS(7105),
    [anon_sym_POUNDendif2] = ACTIONS(7105),
    [anon_sym_POUNDENDIF2] = ACTIONS(7105),
    [anon_sym_POUNDEndif2] = ACTIONS(7105),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7107),
    [anon_sym_tableextension] = ACTIONS(7105),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7105),
    [anon_sym_Tableextension] = ACTIONS(7105),
    [anon_sym_TableExtension] = ACTIONS(7105),
    [anon_sym_tableExtension] = ACTIONS(7105),
    [sym_page_keyword] = ACTIONS(7107),
    [anon_sym_pageextension] = ACTIONS(7105),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7105),
    [anon_sym_Pageextension] = ACTIONS(7105),
    [anon_sym_PageExtension] = ACTIONS(7105),
    [anon_sym_pageExtension] = ACTIONS(7105),
    [anon_sym_codeunit] = ACTIONS(7105),
    [anon_sym_CODEUNIT] = ACTIONS(7105),
    [anon_sym_Codeunit] = ACTIONS(7105),
    [anon_sym_CodeUnit] = ACTIONS(7105),
    [anon_sym_COdeunit] = ACTIONS(7105),
    [anon_sym_codeUnit] = ACTIONS(7105),
    [sym_report_keyword] = ACTIONS(7107),
    [anon_sym_reportextension] = ACTIONS(7105),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7105),
    [anon_sym_Reportextension] = ACTIONS(7105),
    [anon_sym_ReportExtension] = ACTIONS(7105),
    [anon_sym_reportExtension] = ACTIONS(7105),
    [sym_query_keyword] = ACTIONS(7105),
    [anon_sym_xmlport] = ACTIONS(7105),
    [anon_sym_XMLPORT] = ACTIONS(7105),
    [anon_sym_Xmlport] = ACTIONS(7105),
    [anon_sym_XMLport] = ACTIONS(7105),
    [anon_sym_XMLPort] = ACTIONS(7105),
    [anon_sym_XmlPort] = ACTIONS(7105),
    [anon_sym_enum] = ACTIONS(7107),
    [anon_sym_ENUM] = ACTIONS(7107),
    [anon_sym_Enum] = ACTIONS(7107),
    [anon_sym_eNUM] = ACTIONS(7105),
    [anon_sym_eNum] = ACTIONS(7105),
    [anon_sym_ENum] = ACTIONS(7105),
    [anon_sym_enumextension] = ACTIONS(7105),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7105),
    [anon_sym_Enumextension] = ACTIONS(7105),
    [anon_sym_EnumExtension] = ACTIONS(7105),
    [anon_sym_enumExtension] = ACTIONS(7105),
    [sym_interface_keyword] = ACTIONS(7105),
    [anon_sym_controladdin] = ACTIONS(7105),
    [anon_sym_CONTROLADDIN] = ACTIONS(7105),
    [anon_sym_Controladdin] = ACTIONS(7105),
    [anon_sym_ControlAddIn] = ACTIONS(7105),
    [anon_sym_ControlAddin] = ACTIONS(7105),
    [anon_sym_controlAddIn] = ACTIONS(7105),
    [anon_sym_controlAddin] = ACTIONS(7105),
    [anon_sym_dotnet] = ACTIONS(7105),
    [anon_sym_DOTNET] = ACTIONS(7105),
    [anon_sym_Dotnet] = ACTIONS(7105),
    [anon_sym_DotNet] = ACTIONS(7105),
    [anon_sym_dotNet] = ACTIONS(7105),
    [sym_profile_keyword] = ACTIONS(7107),
    [anon_sym_profileextension] = ACTIONS(7105),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7105),
    [anon_sym_Profileextension] = ACTIONS(7105),
    [anon_sym_ProfileExtension] = ACTIONS(7105),
    [anon_sym_profileExtension] = ACTIONS(7105),
    [anon_sym_permissionset] = ACTIONS(7107),
    [anon_sym_PERMISSIONSET] = ACTIONS(7107),
    [anon_sym_Permissionset] = ACTIONS(7107),
    [anon_sym_PermissionSet] = ACTIONS(7107),
    [anon_sym_permissionSet] = ACTIONS(7107),
    [anon_sym_permissionsetextension] = ACTIONS(7105),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7105),
    [anon_sym_Permissionsetextension] = ACTIONS(7105),
    [anon_sym_PermissionSetExtension] = ACTIONS(7105),
    [anon_sym_permissionSetExtension] = ACTIONS(7105),
    [sym_entitlement_keyword] = ACTIONS(7105),
    [anon_sym_pagecustomization] = ACTIONS(7105),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7105),
    [anon_sym_Pagecustomization] = ACTIONS(7105),
    [anon_sym_PageCustomization] = ACTIONS(7105),
    [anon_sym_pageCustomization] = ACTIONS(7105),
    [sym_using_keyword] = ACTIONS(7105),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7105),
    [sym_preproc_close] = ACTIONS(7105),
  },
  [STATE(2849)] = {
    [anon_sym_POUNDif] = ACTIONS(7109),
    [anon_sym_POUNDIF] = ACTIONS(7109),
    [anon_sym_POUNDIf] = ACTIONS(7109),
    [anon_sym_POUNDelif] = ACTIONS(7109),
    [anon_sym_POUNDELIF] = ACTIONS(7109),
    [anon_sym_POUNDElif] = ACTIONS(7109),
    [anon_sym_POUNDelse] = ACTIONS(7109),
    [anon_sym_POUNDELSE] = ACTIONS(7109),
    [anon_sym_POUNDElse] = ACTIONS(7109),
    [anon_sym_POUNDelse2] = ACTIONS(7109),
    [anon_sym_POUNDELSE2] = ACTIONS(7109),
    [anon_sym_POUNDElse2] = ACTIONS(7109),
    [anon_sym_POUNDendif] = ACTIONS(7109),
    [anon_sym_POUNDENDIF] = ACTIONS(7109),
    [anon_sym_POUNDEndif] = ACTIONS(7109),
    [anon_sym_POUNDendif2] = ACTIONS(7109),
    [anon_sym_POUNDENDIF2] = ACTIONS(7109),
    [anon_sym_POUNDEndif2] = ACTIONS(7109),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7111),
    [anon_sym_tableextension] = ACTIONS(7109),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7109),
    [anon_sym_Tableextension] = ACTIONS(7109),
    [anon_sym_TableExtension] = ACTIONS(7109),
    [anon_sym_tableExtension] = ACTIONS(7109),
    [sym_page_keyword] = ACTIONS(7111),
    [anon_sym_pageextension] = ACTIONS(7109),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7109),
    [anon_sym_Pageextension] = ACTIONS(7109),
    [anon_sym_PageExtension] = ACTIONS(7109),
    [anon_sym_pageExtension] = ACTIONS(7109),
    [anon_sym_codeunit] = ACTIONS(7109),
    [anon_sym_CODEUNIT] = ACTIONS(7109),
    [anon_sym_Codeunit] = ACTIONS(7109),
    [anon_sym_CodeUnit] = ACTIONS(7109),
    [anon_sym_COdeunit] = ACTIONS(7109),
    [anon_sym_codeUnit] = ACTIONS(7109),
    [sym_report_keyword] = ACTIONS(7111),
    [anon_sym_reportextension] = ACTIONS(7109),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7109),
    [anon_sym_Reportextension] = ACTIONS(7109),
    [anon_sym_ReportExtension] = ACTIONS(7109),
    [anon_sym_reportExtension] = ACTIONS(7109),
    [sym_query_keyword] = ACTIONS(7109),
    [anon_sym_xmlport] = ACTIONS(7109),
    [anon_sym_XMLPORT] = ACTIONS(7109),
    [anon_sym_Xmlport] = ACTIONS(7109),
    [anon_sym_XMLport] = ACTIONS(7109),
    [anon_sym_XMLPort] = ACTIONS(7109),
    [anon_sym_XmlPort] = ACTIONS(7109),
    [anon_sym_enum] = ACTIONS(7111),
    [anon_sym_ENUM] = ACTIONS(7111),
    [anon_sym_Enum] = ACTIONS(7111),
    [anon_sym_eNUM] = ACTIONS(7109),
    [anon_sym_eNum] = ACTIONS(7109),
    [anon_sym_ENum] = ACTIONS(7109),
    [anon_sym_enumextension] = ACTIONS(7109),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7109),
    [anon_sym_Enumextension] = ACTIONS(7109),
    [anon_sym_EnumExtension] = ACTIONS(7109),
    [anon_sym_enumExtension] = ACTIONS(7109),
    [sym_interface_keyword] = ACTIONS(7109),
    [anon_sym_controladdin] = ACTIONS(7109),
    [anon_sym_CONTROLADDIN] = ACTIONS(7109),
    [anon_sym_Controladdin] = ACTIONS(7109),
    [anon_sym_ControlAddIn] = ACTIONS(7109),
    [anon_sym_ControlAddin] = ACTIONS(7109),
    [anon_sym_controlAddIn] = ACTIONS(7109),
    [anon_sym_controlAddin] = ACTIONS(7109),
    [anon_sym_dotnet] = ACTIONS(7109),
    [anon_sym_DOTNET] = ACTIONS(7109),
    [anon_sym_Dotnet] = ACTIONS(7109),
    [anon_sym_DotNet] = ACTIONS(7109),
    [anon_sym_dotNet] = ACTIONS(7109),
    [sym_profile_keyword] = ACTIONS(7111),
    [anon_sym_profileextension] = ACTIONS(7109),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7109),
    [anon_sym_Profileextension] = ACTIONS(7109),
    [anon_sym_ProfileExtension] = ACTIONS(7109),
    [anon_sym_profileExtension] = ACTIONS(7109),
    [anon_sym_permissionset] = ACTIONS(7111),
    [anon_sym_PERMISSIONSET] = ACTIONS(7111),
    [anon_sym_Permissionset] = ACTIONS(7111),
    [anon_sym_PermissionSet] = ACTIONS(7111),
    [anon_sym_permissionSet] = ACTIONS(7111),
    [anon_sym_permissionsetextension] = ACTIONS(7109),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7109),
    [anon_sym_Permissionsetextension] = ACTIONS(7109),
    [anon_sym_PermissionSetExtension] = ACTIONS(7109),
    [anon_sym_permissionSetExtension] = ACTIONS(7109),
    [sym_entitlement_keyword] = ACTIONS(7109),
    [anon_sym_pagecustomization] = ACTIONS(7109),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7109),
    [anon_sym_Pagecustomization] = ACTIONS(7109),
    [anon_sym_PageCustomization] = ACTIONS(7109),
    [anon_sym_pageCustomization] = ACTIONS(7109),
    [sym_using_keyword] = ACTIONS(7109),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7109),
    [sym_preproc_close] = ACTIONS(7109),
  },
  [STATE(2850)] = {
    [anon_sym_POUNDif] = ACTIONS(7113),
    [anon_sym_POUNDIF] = ACTIONS(7113),
    [anon_sym_POUNDIf] = ACTIONS(7113),
    [anon_sym_POUNDelif] = ACTIONS(7113),
    [anon_sym_POUNDELIF] = ACTIONS(7113),
    [anon_sym_POUNDElif] = ACTIONS(7113),
    [anon_sym_POUNDelse] = ACTIONS(7113),
    [anon_sym_POUNDELSE] = ACTIONS(7113),
    [anon_sym_POUNDElse] = ACTIONS(7113),
    [anon_sym_POUNDelse2] = ACTIONS(7113),
    [anon_sym_POUNDELSE2] = ACTIONS(7113),
    [anon_sym_POUNDElse2] = ACTIONS(7113),
    [anon_sym_POUNDendif] = ACTIONS(7113),
    [anon_sym_POUNDENDIF] = ACTIONS(7113),
    [anon_sym_POUNDEndif] = ACTIONS(7113),
    [anon_sym_POUNDendif2] = ACTIONS(7113),
    [anon_sym_POUNDENDIF2] = ACTIONS(7113),
    [anon_sym_POUNDEndif2] = ACTIONS(7113),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7115),
    [anon_sym_tableextension] = ACTIONS(7113),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7113),
    [anon_sym_Tableextension] = ACTIONS(7113),
    [anon_sym_TableExtension] = ACTIONS(7113),
    [anon_sym_tableExtension] = ACTIONS(7113),
    [sym_page_keyword] = ACTIONS(7115),
    [anon_sym_pageextension] = ACTIONS(7113),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7113),
    [anon_sym_Pageextension] = ACTIONS(7113),
    [anon_sym_PageExtension] = ACTIONS(7113),
    [anon_sym_pageExtension] = ACTIONS(7113),
    [anon_sym_codeunit] = ACTIONS(7113),
    [anon_sym_CODEUNIT] = ACTIONS(7113),
    [anon_sym_Codeunit] = ACTIONS(7113),
    [anon_sym_CodeUnit] = ACTIONS(7113),
    [anon_sym_COdeunit] = ACTIONS(7113),
    [anon_sym_codeUnit] = ACTIONS(7113),
    [sym_report_keyword] = ACTIONS(7115),
    [anon_sym_reportextension] = ACTIONS(7113),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7113),
    [anon_sym_Reportextension] = ACTIONS(7113),
    [anon_sym_ReportExtension] = ACTIONS(7113),
    [anon_sym_reportExtension] = ACTIONS(7113),
    [sym_query_keyword] = ACTIONS(7113),
    [anon_sym_xmlport] = ACTIONS(7113),
    [anon_sym_XMLPORT] = ACTIONS(7113),
    [anon_sym_Xmlport] = ACTIONS(7113),
    [anon_sym_XMLport] = ACTIONS(7113),
    [anon_sym_XMLPort] = ACTIONS(7113),
    [anon_sym_XmlPort] = ACTIONS(7113),
    [anon_sym_enum] = ACTIONS(7115),
    [anon_sym_ENUM] = ACTIONS(7115),
    [anon_sym_Enum] = ACTIONS(7115),
    [anon_sym_eNUM] = ACTIONS(7113),
    [anon_sym_eNum] = ACTIONS(7113),
    [anon_sym_ENum] = ACTIONS(7113),
    [anon_sym_enumextension] = ACTIONS(7113),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7113),
    [anon_sym_Enumextension] = ACTIONS(7113),
    [anon_sym_EnumExtension] = ACTIONS(7113),
    [anon_sym_enumExtension] = ACTIONS(7113),
    [sym_interface_keyword] = ACTIONS(7113),
    [anon_sym_controladdin] = ACTIONS(7113),
    [anon_sym_CONTROLADDIN] = ACTIONS(7113),
    [anon_sym_Controladdin] = ACTIONS(7113),
    [anon_sym_ControlAddIn] = ACTIONS(7113),
    [anon_sym_ControlAddin] = ACTIONS(7113),
    [anon_sym_controlAddIn] = ACTIONS(7113),
    [anon_sym_controlAddin] = ACTIONS(7113),
    [anon_sym_dotnet] = ACTIONS(7113),
    [anon_sym_DOTNET] = ACTIONS(7113),
    [anon_sym_Dotnet] = ACTIONS(7113),
    [anon_sym_DotNet] = ACTIONS(7113),
    [anon_sym_dotNet] = ACTIONS(7113),
    [sym_profile_keyword] = ACTIONS(7115),
    [anon_sym_profileextension] = ACTIONS(7113),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7113),
    [anon_sym_Profileextension] = ACTIONS(7113),
    [anon_sym_ProfileExtension] = ACTIONS(7113),
    [anon_sym_profileExtension] = ACTIONS(7113),
    [anon_sym_permissionset] = ACTIONS(7115),
    [anon_sym_PERMISSIONSET] = ACTIONS(7115),
    [anon_sym_Permissionset] = ACTIONS(7115),
    [anon_sym_PermissionSet] = ACTIONS(7115),
    [anon_sym_permissionSet] = ACTIONS(7115),
    [anon_sym_permissionsetextension] = ACTIONS(7113),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7113),
    [anon_sym_Permissionsetextension] = ACTIONS(7113),
    [anon_sym_PermissionSetExtension] = ACTIONS(7113),
    [anon_sym_permissionSetExtension] = ACTIONS(7113),
    [sym_entitlement_keyword] = ACTIONS(7113),
    [anon_sym_pagecustomization] = ACTIONS(7113),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7113),
    [anon_sym_Pagecustomization] = ACTIONS(7113),
    [anon_sym_PageCustomization] = ACTIONS(7113),
    [anon_sym_pageCustomization] = ACTIONS(7113),
    [sym_using_keyword] = ACTIONS(7113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7113),
    [sym_preproc_close] = ACTIONS(7113),
  },
  [STATE(2851)] = {
    [anon_sym_POUNDif] = ACTIONS(7117),
    [anon_sym_POUNDIF] = ACTIONS(7117),
    [anon_sym_POUNDIf] = ACTIONS(7117),
    [anon_sym_POUNDelif] = ACTIONS(7117),
    [anon_sym_POUNDELIF] = ACTIONS(7117),
    [anon_sym_POUNDElif] = ACTIONS(7117),
    [anon_sym_POUNDelse] = ACTIONS(7117),
    [anon_sym_POUNDELSE] = ACTIONS(7117),
    [anon_sym_POUNDElse] = ACTIONS(7117),
    [anon_sym_POUNDelse2] = ACTIONS(7117),
    [anon_sym_POUNDELSE2] = ACTIONS(7117),
    [anon_sym_POUNDElse2] = ACTIONS(7117),
    [anon_sym_POUNDendif] = ACTIONS(7117),
    [anon_sym_POUNDENDIF] = ACTIONS(7117),
    [anon_sym_POUNDEndif] = ACTIONS(7117),
    [anon_sym_POUNDendif2] = ACTIONS(7117),
    [anon_sym_POUNDENDIF2] = ACTIONS(7117),
    [anon_sym_POUNDEndif2] = ACTIONS(7117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7119),
    [anon_sym_tableextension] = ACTIONS(7117),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7117),
    [anon_sym_Tableextension] = ACTIONS(7117),
    [anon_sym_TableExtension] = ACTIONS(7117),
    [anon_sym_tableExtension] = ACTIONS(7117),
    [sym_page_keyword] = ACTIONS(7119),
    [anon_sym_pageextension] = ACTIONS(7117),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7117),
    [anon_sym_Pageextension] = ACTIONS(7117),
    [anon_sym_PageExtension] = ACTIONS(7117),
    [anon_sym_pageExtension] = ACTIONS(7117),
    [anon_sym_codeunit] = ACTIONS(7117),
    [anon_sym_CODEUNIT] = ACTIONS(7117),
    [anon_sym_Codeunit] = ACTIONS(7117),
    [anon_sym_CodeUnit] = ACTIONS(7117),
    [anon_sym_COdeunit] = ACTIONS(7117),
    [anon_sym_codeUnit] = ACTIONS(7117),
    [sym_report_keyword] = ACTIONS(7119),
    [anon_sym_reportextension] = ACTIONS(7117),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7117),
    [anon_sym_Reportextension] = ACTIONS(7117),
    [anon_sym_ReportExtension] = ACTIONS(7117),
    [anon_sym_reportExtension] = ACTIONS(7117),
    [sym_query_keyword] = ACTIONS(7117),
    [anon_sym_xmlport] = ACTIONS(7117),
    [anon_sym_XMLPORT] = ACTIONS(7117),
    [anon_sym_Xmlport] = ACTIONS(7117),
    [anon_sym_XMLport] = ACTIONS(7117),
    [anon_sym_XMLPort] = ACTIONS(7117),
    [anon_sym_XmlPort] = ACTIONS(7117),
    [anon_sym_enum] = ACTIONS(7119),
    [anon_sym_ENUM] = ACTIONS(7119),
    [anon_sym_Enum] = ACTIONS(7119),
    [anon_sym_eNUM] = ACTIONS(7117),
    [anon_sym_eNum] = ACTIONS(7117),
    [anon_sym_ENum] = ACTIONS(7117),
    [anon_sym_enumextension] = ACTIONS(7117),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7117),
    [anon_sym_Enumextension] = ACTIONS(7117),
    [anon_sym_EnumExtension] = ACTIONS(7117),
    [anon_sym_enumExtension] = ACTIONS(7117),
    [sym_interface_keyword] = ACTIONS(7117),
    [anon_sym_controladdin] = ACTIONS(7117),
    [anon_sym_CONTROLADDIN] = ACTIONS(7117),
    [anon_sym_Controladdin] = ACTIONS(7117),
    [anon_sym_ControlAddIn] = ACTIONS(7117),
    [anon_sym_ControlAddin] = ACTIONS(7117),
    [anon_sym_controlAddIn] = ACTIONS(7117),
    [anon_sym_controlAddin] = ACTIONS(7117),
    [anon_sym_dotnet] = ACTIONS(7117),
    [anon_sym_DOTNET] = ACTIONS(7117),
    [anon_sym_Dotnet] = ACTIONS(7117),
    [anon_sym_DotNet] = ACTIONS(7117),
    [anon_sym_dotNet] = ACTIONS(7117),
    [sym_profile_keyword] = ACTIONS(7119),
    [anon_sym_profileextension] = ACTIONS(7117),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7117),
    [anon_sym_Profileextension] = ACTIONS(7117),
    [anon_sym_ProfileExtension] = ACTIONS(7117),
    [anon_sym_profileExtension] = ACTIONS(7117),
    [anon_sym_permissionset] = ACTIONS(7119),
    [anon_sym_PERMISSIONSET] = ACTIONS(7119),
    [anon_sym_Permissionset] = ACTIONS(7119),
    [anon_sym_PermissionSet] = ACTIONS(7119),
    [anon_sym_permissionSet] = ACTIONS(7119),
    [anon_sym_permissionsetextension] = ACTIONS(7117),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7117),
    [anon_sym_Permissionsetextension] = ACTIONS(7117),
    [anon_sym_PermissionSetExtension] = ACTIONS(7117),
    [anon_sym_permissionSetExtension] = ACTIONS(7117),
    [sym_entitlement_keyword] = ACTIONS(7117),
    [anon_sym_pagecustomization] = ACTIONS(7117),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7117),
    [anon_sym_Pagecustomization] = ACTIONS(7117),
    [anon_sym_PageCustomization] = ACTIONS(7117),
    [anon_sym_pageCustomization] = ACTIONS(7117),
    [sym_using_keyword] = ACTIONS(7117),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7117),
    [sym_preproc_close] = ACTIONS(7117),
  },
  [STATE(2852)] = {
    [anon_sym_POUNDif] = ACTIONS(7121),
    [anon_sym_POUNDIF] = ACTIONS(7121),
    [anon_sym_POUNDIf] = ACTIONS(7121),
    [anon_sym_POUNDelif] = ACTIONS(7121),
    [anon_sym_POUNDELIF] = ACTIONS(7121),
    [anon_sym_POUNDElif] = ACTIONS(7121),
    [anon_sym_POUNDelse] = ACTIONS(7121),
    [anon_sym_POUNDELSE] = ACTIONS(7121),
    [anon_sym_POUNDElse] = ACTIONS(7121),
    [anon_sym_POUNDelse2] = ACTIONS(7121),
    [anon_sym_POUNDELSE2] = ACTIONS(7121),
    [anon_sym_POUNDElse2] = ACTIONS(7121),
    [anon_sym_POUNDendif] = ACTIONS(7121),
    [anon_sym_POUNDENDIF] = ACTIONS(7121),
    [anon_sym_POUNDEndif] = ACTIONS(7121),
    [anon_sym_POUNDendif2] = ACTIONS(7121),
    [anon_sym_POUNDENDIF2] = ACTIONS(7121),
    [anon_sym_POUNDEndif2] = ACTIONS(7121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7123),
    [anon_sym_tableextension] = ACTIONS(7121),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7121),
    [anon_sym_Tableextension] = ACTIONS(7121),
    [anon_sym_TableExtension] = ACTIONS(7121),
    [anon_sym_tableExtension] = ACTIONS(7121),
    [sym_page_keyword] = ACTIONS(7123),
    [anon_sym_pageextension] = ACTIONS(7121),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7121),
    [anon_sym_Pageextension] = ACTIONS(7121),
    [anon_sym_PageExtension] = ACTIONS(7121),
    [anon_sym_pageExtension] = ACTIONS(7121),
    [anon_sym_codeunit] = ACTIONS(7121),
    [anon_sym_CODEUNIT] = ACTIONS(7121),
    [anon_sym_Codeunit] = ACTIONS(7121),
    [anon_sym_CodeUnit] = ACTIONS(7121),
    [anon_sym_COdeunit] = ACTIONS(7121),
    [anon_sym_codeUnit] = ACTIONS(7121),
    [sym_report_keyword] = ACTIONS(7123),
    [anon_sym_reportextension] = ACTIONS(7121),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7121),
    [anon_sym_Reportextension] = ACTIONS(7121),
    [anon_sym_ReportExtension] = ACTIONS(7121),
    [anon_sym_reportExtension] = ACTIONS(7121),
    [sym_query_keyword] = ACTIONS(7121),
    [anon_sym_xmlport] = ACTIONS(7121),
    [anon_sym_XMLPORT] = ACTIONS(7121),
    [anon_sym_Xmlport] = ACTIONS(7121),
    [anon_sym_XMLport] = ACTIONS(7121),
    [anon_sym_XMLPort] = ACTIONS(7121),
    [anon_sym_XmlPort] = ACTIONS(7121),
    [anon_sym_enum] = ACTIONS(7123),
    [anon_sym_ENUM] = ACTIONS(7123),
    [anon_sym_Enum] = ACTIONS(7123),
    [anon_sym_eNUM] = ACTIONS(7121),
    [anon_sym_eNum] = ACTIONS(7121),
    [anon_sym_ENum] = ACTIONS(7121),
    [anon_sym_enumextension] = ACTIONS(7121),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7121),
    [anon_sym_Enumextension] = ACTIONS(7121),
    [anon_sym_EnumExtension] = ACTIONS(7121),
    [anon_sym_enumExtension] = ACTIONS(7121),
    [sym_interface_keyword] = ACTIONS(7121),
    [anon_sym_controladdin] = ACTIONS(7121),
    [anon_sym_CONTROLADDIN] = ACTIONS(7121),
    [anon_sym_Controladdin] = ACTIONS(7121),
    [anon_sym_ControlAddIn] = ACTIONS(7121),
    [anon_sym_ControlAddin] = ACTIONS(7121),
    [anon_sym_controlAddIn] = ACTIONS(7121),
    [anon_sym_controlAddin] = ACTIONS(7121),
    [anon_sym_dotnet] = ACTIONS(7121),
    [anon_sym_DOTNET] = ACTIONS(7121),
    [anon_sym_Dotnet] = ACTIONS(7121),
    [anon_sym_DotNet] = ACTIONS(7121),
    [anon_sym_dotNet] = ACTIONS(7121),
    [sym_profile_keyword] = ACTIONS(7123),
    [anon_sym_profileextension] = ACTIONS(7121),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7121),
    [anon_sym_Profileextension] = ACTIONS(7121),
    [anon_sym_ProfileExtension] = ACTIONS(7121),
    [anon_sym_profileExtension] = ACTIONS(7121),
    [anon_sym_permissionset] = ACTIONS(7123),
    [anon_sym_PERMISSIONSET] = ACTIONS(7123),
    [anon_sym_Permissionset] = ACTIONS(7123),
    [anon_sym_PermissionSet] = ACTIONS(7123),
    [anon_sym_permissionSet] = ACTIONS(7123),
    [anon_sym_permissionsetextension] = ACTIONS(7121),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7121),
    [anon_sym_Permissionsetextension] = ACTIONS(7121),
    [anon_sym_PermissionSetExtension] = ACTIONS(7121),
    [anon_sym_permissionSetExtension] = ACTIONS(7121),
    [sym_entitlement_keyword] = ACTIONS(7121),
    [anon_sym_pagecustomization] = ACTIONS(7121),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7121),
    [anon_sym_Pagecustomization] = ACTIONS(7121),
    [anon_sym_PageCustomization] = ACTIONS(7121),
    [anon_sym_pageCustomization] = ACTIONS(7121),
    [sym_using_keyword] = ACTIONS(7121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7121),
    [sym_preproc_close] = ACTIONS(7121),
  },
  [STATE(2853)] = {
    [anon_sym_POUNDif] = ACTIONS(7125),
    [anon_sym_POUNDIF] = ACTIONS(7125),
    [anon_sym_POUNDIf] = ACTIONS(7125),
    [anon_sym_POUNDelif] = ACTIONS(7125),
    [anon_sym_POUNDELIF] = ACTIONS(7125),
    [anon_sym_POUNDElif] = ACTIONS(7125),
    [anon_sym_POUNDelse] = ACTIONS(7125),
    [anon_sym_POUNDELSE] = ACTIONS(7125),
    [anon_sym_POUNDElse] = ACTIONS(7125),
    [anon_sym_POUNDelse2] = ACTIONS(7125),
    [anon_sym_POUNDELSE2] = ACTIONS(7125),
    [anon_sym_POUNDElse2] = ACTIONS(7125),
    [anon_sym_POUNDendif] = ACTIONS(7125),
    [anon_sym_POUNDENDIF] = ACTIONS(7125),
    [anon_sym_POUNDEndif] = ACTIONS(7125),
    [anon_sym_POUNDendif2] = ACTIONS(7125),
    [anon_sym_POUNDENDIF2] = ACTIONS(7125),
    [anon_sym_POUNDEndif2] = ACTIONS(7125),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7127),
    [anon_sym_tableextension] = ACTIONS(7125),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7125),
    [anon_sym_Tableextension] = ACTIONS(7125),
    [anon_sym_TableExtension] = ACTIONS(7125),
    [anon_sym_tableExtension] = ACTIONS(7125),
    [sym_page_keyword] = ACTIONS(7127),
    [anon_sym_pageextension] = ACTIONS(7125),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7125),
    [anon_sym_Pageextension] = ACTIONS(7125),
    [anon_sym_PageExtension] = ACTIONS(7125),
    [anon_sym_pageExtension] = ACTIONS(7125),
    [anon_sym_codeunit] = ACTIONS(7125),
    [anon_sym_CODEUNIT] = ACTIONS(7125),
    [anon_sym_Codeunit] = ACTIONS(7125),
    [anon_sym_CodeUnit] = ACTIONS(7125),
    [anon_sym_COdeunit] = ACTIONS(7125),
    [anon_sym_codeUnit] = ACTIONS(7125),
    [sym_report_keyword] = ACTIONS(7127),
    [anon_sym_reportextension] = ACTIONS(7125),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7125),
    [anon_sym_Reportextension] = ACTIONS(7125),
    [anon_sym_ReportExtension] = ACTIONS(7125),
    [anon_sym_reportExtension] = ACTIONS(7125),
    [sym_query_keyword] = ACTIONS(7125),
    [anon_sym_xmlport] = ACTIONS(7125),
    [anon_sym_XMLPORT] = ACTIONS(7125),
    [anon_sym_Xmlport] = ACTIONS(7125),
    [anon_sym_XMLport] = ACTIONS(7125),
    [anon_sym_XMLPort] = ACTIONS(7125),
    [anon_sym_XmlPort] = ACTIONS(7125),
    [anon_sym_enum] = ACTIONS(7127),
    [anon_sym_ENUM] = ACTIONS(7127),
    [anon_sym_Enum] = ACTIONS(7127),
    [anon_sym_eNUM] = ACTIONS(7125),
    [anon_sym_eNum] = ACTIONS(7125),
    [anon_sym_ENum] = ACTIONS(7125),
    [anon_sym_enumextension] = ACTIONS(7125),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7125),
    [anon_sym_Enumextension] = ACTIONS(7125),
    [anon_sym_EnumExtension] = ACTIONS(7125),
    [anon_sym_enumExtension] = ACTIONS(7125),
    [sym_interface_keyword] = ACTIONS(7125),
    [anon_sym_controladdin] = ACTIONS(7125),
    [anon_sym_CONTROLADDIN] = ACTIONS(7125),
    [anon_sym_Controladdin] = ACTIONS(7125),
    [anon_sym_ControlAddIn] = ACTIONS(7125),
    [anon_sym_ControlAddin] = ACTIONS(7125),
    [anon_sym_controlAddIn] = ACTIONS(7125),
    [anon_sym_controlAddin] = ACTIONS(7125),
    [anon_sym_dotnet] = ACTIONS(7125),
    [anon_sym_DOTNET] = ACTIONS(7125),
    [anon_sym_Dotnet] = ACTIONS(7125),
    [anon_sym_DotNet] = ACTIONS(7125),
    [anon_sym_dotNet] = ACTIONS(7125),
    [sym_profile_keyword] = ACTIONS(7127),
    [anon_sym_profileextension] = ACTIONS(7125),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7125),
    [anon_sym_Profileextension] = ACTIONS(7125),
    [anon_sym_ProfileExtension] = ACTIONS(7125),
    [anon_sym_profileExtension] = ACTIONS(7125),
    [anon_sym_permissionset] = ACTIONS(7127),
    [anon_sym_PERMISSIONSET] = ACTIONS(7127),
    [anon_sym_Permissionset] = ACTIONS(7127),
    [anon_sym_PermissionSet] = ACTIONS(7127),
    [anon_sym_permissionSet] = ACTIONS(7127),
    [anon_sym_permissionsetextension] = ACTIONS(7125),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7125),
    [anon_sym_Permissionsetextension] = ACTIONS(7125),
    [anon_sym_PermissionSetExtension] = ACTIONS(7125),
    [anon_sym_permissionSetExtension] = ACTIONS(7125),
    [sym_entitlement_keyword] = ACTIONS(7125),
    [anon_sym_pagecustomization] = ACTIONS(7125),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7125),
    [anon_sym_Pagecustomization] = ACTIONS(7125),
    [anon_sym_PageCustomization] = ACTIONS(7125),
    [anon_sym_pageCustomization] = ACTIONS(7125),
    [sym_using_keyword] = ACTIONS(7125),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7125),
    [sym_preproc_close] = ACTIONS(7125),
  },
  [STATE(2854)] = {
    [anon_sym_POUNDif] = ACTIONS(7129),
    [anon_sym_POUNDIF] = ACTIONS(7129),
    [anon_sym_POUNDIf] = ACTIONS(7129),
    [anon_sym_POUNDelif] = ACTIONS(7129),
    [anon_sym_POUNDELIF] = ACTIONS(7129),
    [anon_sym_POUNDElif] = ACTIONS(7129),
    [anon_sym_POUNDelse] = ACTIONS(7129),
    [anon_sym_POUNDELSE] = ACTIONS(7129),
    [anon_sym_POUNDElse] = ACTIONS(7129),
    [anon_sym_POUNDelse2] = ACTIONS(7129),
    [anon_sym_POUNDELSE2] = ACTIONS(7129),
    [anon_sym_POUNDElse2] = ACTIONS(7129),
    [anon_sym_POUNDendif] = ACTIONS(7129),
    [anon_sym_POUNDENDIF] = ACTIONS(7129),
    [anon_sym_POUNDEndif] = ACTIONS(7129),
    [anon_sym_POUNDendif2] = ACTIONS(7129),
    [anon_sym_POUNDENDIF2] = ACTIONS(7129),
    [anon_sym_POUNDEndif2] = ACTIONS(7129),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7131),
    [anon_sym_tableextension] = ACTIONS(7129),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7129),
    [anon_sym_Tableextension] = ACTIONS(7129),
    [anon_sym_TableExtension] = ACTIONS(7129),
    [anon_sym_tableExtension] = ACTIONS(7129),
    [sym_page_keyword] = ACTIONS(7131),
    [anon_sym_pageextension] = ACTIONS(7129),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7129),
    [anon_sym_Pageextension] = ACTIONS(7129),
    [anon_sym_PageExtension] = ACTIONS(7129),
    [anon_sym_pageExtension] = ACTIONS(7129),
    [anon_sym_codeunit] = ACTIONS(7129),
    [anon_sym_CODEUNIT] = ACTIONS(7129),
    [anon_sym_Codeunit] = ACTIONS(7129),
    [anon_sym_CodeUnit] = ACTIONS(7129),
    [anon_sym_COdeunit] = ACTIONS(7129),
    [anon_sym_codeUnit] = ACTIONS(7129),
    [sym_report_keyword] = ACTIONS(7131),
    [anon_sym_reportextension] = ACTIONS(7129),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7129),
    [anon_sym_Reportextension] = ACTIONS(7129),
    [anon_sym_ReportExtension] = ACTIONS(7129),
    [anon_sym_reportExtension] = ACTIONS(7129),
    [sym_query_keyword] = ACTIONS(7129),
    [anon_sym_xmlport] = ACTIONS(7129),
    [anon_sym_XMLPORT] = ACTIONS(7129),
    [anon_sym_Xmlport] = ACTIONS(7129),
    [anon_sym_XMLport] = ACTIONS(7129),
    [anon_sym_XMLPort] = ACTIONS(7129),
    [anon_sym_XmlPort] = ACTIONS(7129),
    [anon_sym_enum] = ACTIONS(7131),
    [anon_sym_ENUM] = ACTIONS(7131),
    [anon_sym_Enum] = ACTIONS(7131),
    [anon_sym_eNUM] = ACTIONS(7129),
    [anon_sym_eNum] = ACTIONS(7129),
    [anon_sym_ENum] = ACTIONS(7129),
    [anon_sym_enumextension] = ACTIONS(7129),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7129),
    [anon_sym_Enumextension] = ACTIONS(7129),
    [anon_sym_EnumExtension] = ACTIONS(7129),
    [anon_sym_enumExtension] = ACTIONS(7129),
    [sym_interface_keyword] = ACTIONS(7129),
    [anon_sym_controladdin] = ACTIONS(7129),
    [anon_sym_CONTROLADDIN] = ACTIONS(7129),
    [anon_sym_Controladdin] = ACTIONS(7129),
    [anon_sym_ControlAddIn] = ACTIONS(7129),
    [anon_sym_ControlAddin] = ACTIONS(7129),
    [anon_sym_controlAddIn] = ACTIONS(7129),
    [anon_sym_controlAddin] = ACTIONS(7129),
    [anon_sym_dotnet] = ACTIONS(7129),
    [anon_sym_DOTNET] = ACTIONS(7129),
    [anon_sym_Dotnet] = ACTIONS(7129),
    [anon_sym_DotNet] = ACTIONS(7129),
    [anon_sym_dotNet] = ACTIONS(7129),
    [sym_profile_keyword] = ACTIONS(7131),
    [anon_sym_profileextension] = ACTIONS(7129),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7129),
    [anon_sym_Profileextension] = ACTIONS(7129),
    [anon_sym_ProfileExtension] = ACTIONS(7129),
    [anon_sym_profileExtension] = ACTIONS(7129),
    [anon_sym_permissionset] = ACTIONS(7131),
    [anon_sym_PERMISSIONSET] = ACTIONS(7131),
    [anon_sym_Permissionset] = ACTIONS(7131),
    [anon_sym_PermissionSet] = ACTIONS(7131),
    [anon_sym_permissionSet] = ACTIONS(7131),
    [anon_sym_permissionsetextension] = ACTIONS(7129),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7129),
    [anon_sym_Permissionsetextension] = ACTIONS(7129),
    [anon_sym_PermissionSetExtension] = ACTIONS(7129),
    [anon_sym_permissionSetExtension] = ACTIONS(7129),
    [sym_entitlement_keyword] = ACTIONS(7129),
    [anon_sym_pagecustomization] = ACTIONS(7129),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7129),
    [anon_sym_Pagecustomization] = ACTIONS(7129),
    [anon_sym_PageCustomization] = ACTIONS(7129),
    [anon_sym_pageCustomization] = ACTIONS(7129),
    [sym_using_keyword] = ACTIONS(7129),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7129),
    [sym_preproc_close] = ACTIONS(7129),
  },
  [STATE(2855)] = {
    [sym_identifier] = ACTIONS(3655),
    [anon_sym_DOT] = ACTIONS(3655),
    [anon_sym_EQ] = ACTIONS(3657),
    [anon_sym_COMMA] = ACTIONS(3657),
    [anon_sym_DASH] = ACTIONS(3655),
    [aux_sym_boolean_token1] = ACTIONS(3655),
    [aux_sym_boolean_token2] = ACTIONS(3655),
    [sym_decimal] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3657),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3655),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [aux_sym_record_type_token1] = ACTIONS(3655),
    [aux_sym_basic_type_token21] = ACTIONS(3655),
    [aux_sym_basic_type_token22] = ACTIONS(3655),
    [aux_sym_basic_type_token48] = ACTIONS(3655),
    [anon_sym_COLON_COLON] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3655),
    [anon_sym_NOT] = ACTIONS(3655),
    [anon_sym_Not] = ACTIONS(3655),
    [anon_sym_POUNDelif] = ACTIONS(3657),
    [anon_sym_POUNDELIF] = ACTIONS(3657),
    [anon_sym_POUNDElif] = ACTIONS(3657),
    [anon_sym_POUNDelse] = ACTIONS(3657),
    [anon_sym_POUNDELSE] = ACTIONS(3657),
    [anon_sym_POUNDElse] = ACTIONS(3657),
    [anon_sym_POUNDelse2] = ACTIONS(3657),
    [anon_sym_POUNDELSE2] = ACTIONS(3657),
    [anon_sym_POUNDElse2] = ACTIONS(3657),
    [anon_sym_POUNDendif] = ACTIONS(3657),
    [anon_sym_POUNDENDIF] = ACTIONS(3657),
    [anon_sym_POUNDEndif] = ACTIONS(3657),
    [anon_sym_POUNDendif2] = ACTIONS(3657),
    [anon_sym_POUNDENDIF2] = ACTIONS(3657),
    [anon_sym_POUNDEndif2] = ACTIONS(3657),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3657),
    [aux_sym__expression_token1] = ACTIONS(3657),
    [aux_sym__expression_token2] = ACTIONS(3657),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3655),
    [anon_sym_SLASH] = ACTIONS(3655),
    [anon_sym_div] = ACTIONS(3655),
    [anon_sym_DIV] = ACTIONS(3655),
    [anon_sym_Div] = ACTIONS(3655),
    [anon_sym_mod] = ACTIONS(3655),
    [anon_sym_MOD] = ACTIONS(3655),
    [anon_sym_Mod] = ACTIONS(3655),
    [anon_sym_PLUS] = ACTIONS(3655),
    [anon_sym_GT_EQ] = ACTIONS(3657),
    [anon_sym_LT_EQ] = ACTIONS(3657),
    [anon_sym_GT] = ACTIONS(3655),
    [anon_sym_LT] = ACTIONS(3655),
    [anon_sym_LT_GT] = ACTIONS(3657),
    [anon_sym_and] = ACTIONS(3655),
    [anon_sym_AND] = ACTIONS(3655),
    [anon_sym_And] = ACTIONS(3655),
    [anon_sym_or] = ACTIONS(3655),
    [anon_sym_OR] = ACTIONS(3655),
    [anon_sym_Or] = ACTIONS(3655),
    [anon_sym_xor] = ACTIONS(3655),
    [anon_sym_XOR] = ACTIONS(3655),
    [anon_sym_Xor] = ACTIONS(3655),
    [anon_sym_QMARK] = ACTIONS(3657),
    [sym_datetime_literal] = ACTIONS(3657),
    [sym_date_literal] = ACTIONS(3655),
    [sym_time_literal] = ACTIONS(3655),
    [sym_biginteger_literal] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3655),
    [anon_sym_IN] = ACTIONS(3655),
    [anon_sym_In] = ACTIONS(3655),
    [sym_page_keyword] = ACTIONS(3655),
    [anon_sym_codeunit] = ACTIONS(3655),
    [anon_sym_CODEUNIT] = ACTIONS(3655),
    [anon_sym_Codeunit] = ACTIONS(3655),
    [anon_sym_CodeUnit] = ACTIONS(3655),
    [anon_sym_COdeunit] = ACTIONS(3655),
    [anon_sym_codeUnit] = ACTIONS(3655),
    [sym_report_keyword] = ACTIONS(3655),
    [sym_query_keyword] = ACTIONS(3655),
    [anon_sym_xmlport] = ACTIONS(3655),
    [anon_sym_XMLPORT] = ACTIONS(3655),
    [anon_sym_Xmlport] = ACTIONS(3655),
    [anon_sym_XMLport] = ACTIONS(3655),
    [anon_sym_XMLPort] = ACTIONS(3655),
    [anon_sym_XmlPort] = ACTIONS(3655),
    [anon_sym_enum] = ACTIONS(3655),
    [anon_sym_ENUM] = ACTIONS(3655),
    [anon_sym_Enum] = ACTIONS(3655),
    [anon_sym_eNUM] = ACTIONS(3655),
    [anon_sym_eNum] = ACTIONS(3655),
    [anon_sym_ENum] = ACTIONS(3655),
    [sym_quoted_identifier] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3657),
    [sym_verbatim_string] = ACTIONS(3657),
    [sym_integer] = ACTIONS(3655),
    [sym_continue_as_identifier] = ACTIONS(3657),
    [sym_preproc_close] = ACTIONS(3657),
  },
  [STATE(2856)] = {
    [sym_identifier] = ACTIONS(3659),
    [anon_sym_DOT] = ACTIONS(3659),
    [anon_sym_EQ] = ACTIONS(3661),
    [anon_sym_COMMA] = ACTIONS(3661),
    [anon_sym_DASH] = ACTIONS(3659),
    [aux_sym_boolean_token1] = ACTIONS(3659),
    [aux_sym_boolean_token2] = ACTIONS(3659),
    [sym_decimal] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3661),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3661),
    [aux_sym_record_type_token1] = ACTIONS(3659),
    [aux_sym_basic_type_token21] = ACTIONS(3659),
    [aux_sym_basic_type_token22] = ACTIONS(3659),
    [aux_sym_basic_type_token48] = ACTIONS(3659),
    [anon_sym_COLON_COLON] = ACTIONS(3661),
    [anon_sym_not] = ACTIONS(3659),
    [anon_sym_NOT] = ACTIONS(3659),
    [anon_sym_Not] = ACTIONS(3659),
    [anon_sym_POUNDelif] = ACTIONS(3661),
    [anon_sym_POUNDELIF] = ACTIONS(3661),
    [anon_sym_POUNDElif] = ACTIONS(3661),
    [anon_sym_POUNDelse] = ACTIONS(3661),
    [anon_sym_POUNDELSE] = ACTIONS(3661),
    [anon_sym_POUNDElse] = ACTIONS(3661),
    [anon_sym_POUNDelse2] = ACTIONS(3661),
    [anon_sym_POUNDELSE2] = ACTIONS(3661),
    [anon_sym_POUNDElse2] = ACTIONS(3661),
    [anon_sym_POUNDendif] = ACTIONS(3661),
    [anon_sym_POUNDENDIF] = ACTIONS(3661),
    [anon_sym_POUNDEndif] = ACTIONS(3661),
    [anon_sym_POUNDendif2] = ACTIONS(3661),
    [anon_sym_POUNDENDIF2] = ACTIONS(3661),
    [anon_sym_POUNDEndif2] = ACTIONS(3661),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3661),
    [aux_sym__expression_token1] = ACTIONS(3661),
    [aux_sym__expression_token2] = ACTIONS(3661),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3659),
    [anon_sym_SLASH] = ACTIONS(3659),
    [anon_sym_div] = ACTIONS(3659),
    [anon_sym_DIV] = ACTIONS(3659),
    [anon_sym_Div] = ACTIONS(3659),
    [anon_sym_mod] = ACTIONS(3659),
    [anon_sym_MOD] = ACTIONS(3659),
    [anon_sym_Mod] = ACTIONS(3659),
    [anon_sym_PLUS] = ACTIONS(3659),
    [anon_sym_GT_EQ] = ACTIONS(3661),
    [anon_sym_LT_EQ] = ACTIONS(3661),
    [anon_sym_GT] = ACTIONS(3659),
    [anon_sym_LT] = ACTIONS(3659),
    [anon_sym_LT_GT] = ACTIONS(3661),
    [anon_sym_and] = ACTIONS(3659),
    [anon_sym_AND] = ACTIONS(3659),
    [anon_sym_And] = ACTIONS(3659),
    [anon_sym_or] = ACTIONS(3659),
    [anon_sym_OR] = ACTIONS(3659),
    [anon_sym_Or] = ACTIONS(3659),
    [anon_sym_xor] = ACTIONS(3659),
    [anon_sym_XOR] = ACTIONS(3659),
    [anon_sym_Xor] = ACTIONS(3659),
    [anon_sym_QMARK] = ACTIONS(3661),
    [sym_datetime_literal] = ACTIONS(3661),
    [sym_date_literal] = ACTIONS(3659),
    [sym_time_literal] = ACTIONS(3659),
    [sym_biginteger_literal] = ACTIONS(3661),
    [anon_sym_in] = ACTIONS(3659),
    [anon_sym_IN] = ACTIONS(3659),
    [anon_sym_In] = ACTIONS(3659),
    [sym_page_keyword] = ACTIONS(3659),
    [anon_sym_codeunit] = ACTIONS(3659),
    [anon_sym_CODEUNIT] = ACTIONS(3659),
    [anon_sym_Codeunit] = ACTIONS(3659),
    [anon_sym_CodeUnit] = ACTIONS(3659),
    [anon_sym_COdeunit] = ACTIONS(3659),
    [anon_sym_codeUnit] = ACTIONS(3659),
    [sym_report_keyword] = ACTIONS(3659),
    [sym_query_keyword] = ACTIONS(3659),
    [anon_sym_xmlport] = ACTIONS(3659),
    [anon_sym_XMLPORT] = ACTIONS(3659),
    [anon_sym_Xmlport] = ACTIONS(3659),
    [anon_sym_XMLport] = ACTIONS(3659),
    [anon_sym_XMLPort] = ACTIONS(3659),
    [anon_sym_XmlPort] = ACTIONS(3659),
    [anon_sym_enum] = ACTIONS(3659),
    [anon_sym_ENUM] = ACTIONS(3659),
    [anon_sym_Enum] = ACTIONS(3659),
    [anon_sym_eNUM] = ACTIONS(3659),
    [anon_sym_eNum] = ACTIONS(3659),
    [anon_sym_ENum] = ACTIONS(3659),
    [sym_quoted_identifier] = ACTIONS(3661),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3661),
    [sym_verbatim_string] = ACTIONS(3661),
    [sym_integer] = ACTIONS(3659),
    [sym_continue_as_identifier] = ACTIONS(3661),
    [sym_preproc_close] = ACTIONS(3661),
  },
  [STATE(2857)] = {
    [anon_sym_POUNDif] = ACTIONS(7133),
    [anon_sym_POUNDIF] = ACTIONS(7133),
    [anon_sym_POUNDIf] = ACTIONS(7133),
    [anon_sym_POUNDelif] = ACTIONS(7133),
    [anon_sym_POUNDELIF] = ACTIONS(7133),
    [anon_sym_POUNDElif] = ACTIONS(7133),
    [anon_sym_POUNDelse] = ACTIONS(7133),
    [anon_sym_POUNDELSE] = ACTIONS(7133),
    [anon_sym_POUNDElse] = ACTIONS(7133),
    [anon_sym_POUNDelse2] = ACTIONS(7133),
    [anon_sym_POUNDELSE2] = ACTIONS(7133),
    [anon_sym_POUNDElse2] = ACTIONS(7133),
    [anon_sym_POUNDendif] = ACTIONS(7133),
    [anon_sym_POUNDENDIF] = ACTIONS(7133),
    [anon_sym_POUNDEndif] = ACTIONS(7133),
    [anon_sym_POUNDendif2] = ACTIONS(7133),
    [anon_sym_POUNDENDIF2] = ACTIONS(7133),
    [anon_sym_POUNDEndif2] = ACTIONS(7133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7135),
    [anon_sym_tableextension] = ACTIONS(7133),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7133),
    [anon_sym_Tableextension] = ACTIONS(7133),
    [anon_sym_TableExtension] = ACTIONS(7133),
    [anon_sym_tableExtension] = ACTIONS(7133),
    [sym_page_keyword] = ACTIONS(7135),
    [anon_sym_pageextension] = ACTIONS(7133),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7133),
    [anon_sym_Pageextension] = ACTIONS(7133),
    [anon_sym_PageExtension] = ACTIONS(7133),
    [anon_sym_pageExtension] = ACTIONS(7133),
    [anon_sym_codeunit] = ACTIONS(7133),
    [anon_sym_CODEUNIT] = ACTIONS(7133),
    [anon_sym_Codeunit] = ACTIONS(7133),
    [anon_sym_CodeUnit] = ACTIONS(7133),
    [anon_sym_COdeunit] = ACTIONS(7133),
    [anon_sym_codeUnit] = ACTIONS(7133),
    [sym_report_keyword] = ACTIONS(7135),
    [anon_sym_reportextension] = ACTIONS(7133),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7133),
    [anon_sym_Reportextension] = ACTIONS(7133),
    [anon_sym_ReportExtension] = ACTIONS(7133),
    [anon_sym_reportExtension] = ACTIONS(7133),
    [sym_query_keyword] = ACTIONS(7133),
    [anon_sym_xmlport] = ACTIONS(7133),
    [anon_sym_XMLPORT] = ACTIONS(7133),
    [anon_sym_Xmlport] = ACTIONS(7133),
    [anon_sym_XMLport] = ACTIONS(7133),
    [anon_sym_XMLPort] = ACTIONS(7133),
    [anon_sym_XmlPort] = ACTIONS(7133),
    [anon_sym_enum] = ACTIONS(7135),
    [anon_sym_ENUM] = ACTIONS(7135),
    [anon_sym_Enum] = ACTIONS(7135),
    [anon_sym_eNUM] = ACTIONS(7133),
    [anon_sym_eNum] = ACTIONS(7133),
    [anon_sym_ENum] = ACTIONS(7133),
    [anon_sym_enumextension] = ACTIONS(7133),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7133),
    [anon_sym_Enumextension] = ACTIONS(7133),
    [anon_sym_EnumExtension] = ACTIONS(7133),
    [anon_sym_enumExtension] = ACTIONS(7133),
    [sym_interface_keyword] = ACTIONS(7133),
    [anon_sym_controladdin] = ACTIONS(7133),
    [anon_sym_CONTROLADDIN] = ACTIONS(7133),
    [anon_sym_Controladdin] = ACTIONS(7133),
    [anon_sym_ControlAddIn] = ACTIONS(7133),
    [anon_sym_ControlAddin] = ACTIONS(7133),
    [anon_sym_controlAddIn] = ACTIONS(7133),
    [anon_sym_controlAddin] = ACTIONS(7133),
    [anon_sym_dotnet] = ACTIONS(7133),
    [anon_sym_DOTNET] = ACTIONS(7133),
    [anon_sym_Dotnet] = ACTIONS(7133),
    [anon_sym_DotNet] = ACTIONS(7133),
    [anon_sym_dotNet] = ACTIONS(7133),
    [sym_profile_keyword] = ACTIONS(7135),
    [anon_sym_profileextension] = ACTIONS(7133),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7133),
    [anon_sym_Profileextension] = ACTIONS(7133),
    [anon_sym_ProfileExtension] = ACTIONS(7133),
    [anon_sym_profileExtension] = ACTIONS(7133),
    [anon_sym_permissionset] = ACTIONS(7135),
    [anon_sym_PERMISSIONSET] = ACTIONS(7135),
    [anon_sym_Permissionset] = ACTIONS(7135),
    [anon_sym_PermissionSet] = ACTIONS(7135),
    [anon_sym_permissionSet] = ACTIONS(7135),
    [anon_sym_permissionsetextension] = ACTIONS(7133),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7133),
    [anon_sym_Permissionsetextension] = ACTIONS(7133),
    [anon_sym_PermissionSetExtension] = ACTIONS(7133),
    [anon_sym_permissionSetExtension] = ACTIONS(7133),
    [sym_entitlement_keyword] = ACTIONS(7133),
    [anon_sym_pagecustomization] = ACTIONS(7133),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7133),
    [anon_sym_Pagecustomization] = ACTIONS(7133),
    [anon_sym_PageCustomization] = ACTIONS(7133),
    [anon_sym_pageCustomization] = ACTIONS(7133),
    [sym_using_keyword] = ACTIONS(7133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7133),
    [sym_preproc_close] = ACTIONS(7133),
  },
  [STATE(2858)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(2859)] = {
    [anon_sym_POUNDif] = ACTIONS(7137),
    [anon_sym_POUNDIF] = ACTIONS(7137),
    [anon_sym_POUNDIf] = ACTIONS(7137),
    [anon_sym_POUNDelif] = ACTIONS(7137),
    [anon_sym_POUNDELIF] = ACTIONS(7137),
    [anon_sym_POUNDElif] = ACTIONS(7137),
    [anon_sym_POUNDelse] = ACTIONS(7137),
    [anon_sym_POUNDELSE] = ACTIONS(7137),
    [anon_sym_POUNDElse] = ACTIONS(7137),
    [anon_sym_POUNDelse2] = ACTIONS(7137),
    [anon_sym_POUNDELSE2] = ACTIONS(7137),
    [anon_sym_POUNDElse2] = ACTIONS(7137),
    [anon_sym_POUNDendif] = ACTIONS(7137),
    [anon_sym_POUNDENDIF] = ACTIONS(7137),
    [anon_sym_POUNDEndif] = ACTIONS(7137),
    [anon_sym_POUNDendif2] = ACTIONS(7137),
    [anon_sym_POUNDENDIF2] = ACTIONS(7137),
    [anon_sym_POUNDEndif2] = ACTIONS(7137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7139),
    [anon_sym_tableextension] = ACTIONS(7137),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7137),
    [anon_sym_Tableextension] = ACTIONS(7137),
    [anon_sym_TableExtension] = ACTIONS(7137),
    [anon_sym_tableExtension] = ACTIONS(7137),
    [sym_page_keyword] = ACTIONS(7139),
    [anon_sym_pageextension] = ACTIONS(7137),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7137),
    [anon_sym_Pageextension] = ACTIONS(7137),
    [anon_sym_PageExtension] = ACTIONS(7137),
    [anon_sym_pageExtension] = ACTIONS(7137),
    [anon_sym_codeunit] = ACTIONS(7137),
    [anon_sym_CODEUNIT] = ACTIONS(7137),
    [anon_sym_Codeunit] = ACTIONS(7137),
    [anon_sym_CodeUnit] = ACTIONS(7137),
    [anon_sym_COdeunit] = ACTIONS(7137),
    [anon_sym_codeUnit] = ACTIONS(7137),
    [sym_report_keyword] = ACTIONS(7139),
    [anon_sym_reportextension] = ACTIONS(7137),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7137),
    [anon_sym_Reportextension] = ACTIONS(7137),
    [anon_sym_ReportExtension] = ACTIONS(7137),
    [anon_sym_reportExtension] = ACTIONS(7137),
    [sym_query_keyword] = ACTIONS(7137),
    [anon_sym_xmlport] = ACTIONS(7137),
    [anon_sym_XMLPORT] = ACTIONS(7137),
    [anon_sym_Xmlport] = ACTIONS(7137),
    [anon_sym_XMLport] = ACTIONS(7137),
    [anon_sym_XMLPort] = ACTIONS(7137),
    [anon_sym_XmlPort] = ACTIONS(7137),
    [anon_sym_enum] = ACTIONS(7139),
    [anon_sym_ENUM] = ACTIONS(7139),
    [anon_sym_Enum] = ACTIONS(7139),
    [anon_sym_eNUM] = ACTIONS(7137),
    [anon_sym_eNum] = ACTIONS(7137),
    [anon_sym_ENum] = ACTIONS(7137),
    [anon_sym_enumextension] = ACTIONS(7137),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7137),
    [anon_sym_Enumextension] = ACTIONS(7137),
    [anon_sym_EnumExtension] = ACTIONS(7137),
    [anon_sym_enumExtension] = ACTIONS(7137),
    [sym_interface_keyword] = ACTIONS(7137),
    [anon_sym_controladdin] = ACTIONS(7137),
    [anon_sym_CONTROLADDIN] = ACTIONS(7137),
    [anon_sym_Controladdin] = ACTIONS(7137),
    [anon_sym_ControlAddIn] = ACTIONS(7137),
    [anon_sym_ControlAddin] = ACTIONS(7137),
    [anon_sym_controlAddIn] = ACTIONS(7137),
    [anon_sym_controlAddin] = ACTIONS(7137),
    [anon_sym_dotnet] = ACTIONS(7137),
    [anon_sym_DOTNET] = ACTIONS(7137),
    [anon_sym_Dotnet] = ACTIONS(7137),
    [anon_sym_DotNet] = ACTIONS(7137),
    [anon_sym_dotNet] = ACTIONS(7137),
    [sym_profile_keyword] = ACTIONS(7139),
    [anon_sym_profileextension] = ACTIONS(7137),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7137),
    [anon_sym_Profileextension] = ACTIONS(7137),
    [anon_sym_ProfileExtension] = ACTIONS(7137),
    [anon_sym_profileExtension] = ACTIONS(7137),
    [anon_sym_permissionset] = ACTIONS(7139),
    [anon_sym_PERMISSIONSET] = ACTIONS(7139),
    [anon_sym_Permissionset] = ACTIONS(7139),
    [anon_sym_PermissionSet] = ACTIONS(7139),
    [anon_sym_permissionSet] = ACTIONS(7139),
    [anon_sym_permissionsetextension] = ACTIONS(7137),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7137),
    [anon_sym_Permissionsetextension] = ACTIONS(7137),
    [anon_sym_PermissionSetExtension] = ACTIONS(7137),
    [anon_sym_permissionSetExtension] = ACTIONS(7137),
    [sym_entitlement_keyword] = ACTIONS(7137),
    [anon_sym_pagecustomization] = ACTIONS(7137),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7137),
    [anon_sym_Pagecustomization] = ACTIONS(7137),
    [anon_sym_PageCustomization] = ACTIONS(7137),
    [anon_sym_pageCustomization] = ACTIONS(7137),
    [sym_using_keyword] = ACTIONS(7137),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7137),
    [sym_preproc_close] = ACTIONS(7137),
  },
  [STATE(2860)] = {
    [anon_sym_POUNDif] = ACTIONS(7141),
    [anon_sym_POUNDIF] = ACTIONS(7141),
    [anon_sym_POUNDIf] = ACTIONS(7141),
    [anon_sym_POUNDelif] = ACTIONS(7141),
    [anon_sym_POUNDELIF] = ACTIONS(7141),
    [anon_sym_POUNDElif] = ACTIONS(7141),
    [anon_sym_POUNDelse] = ACTIONS(7141),
    [anon_sym_POUNDELSE] = ACTIONS(7141),
    [anon_sym_POUNDElse] = ACTIONS(7141),
    [anon_sym_POUNDelse2] = ACTIONS(7141),
    [anon_sym_POUNDELSE2] = ACTIONS(7141),
    [anon_sym_POUNDElse2] = ACTIONS(7141),
    [anon_sym_POUNDendif] = ACTIONS(7141),
    [anon_sym_POUNDENDIF] = ACTIONS(7141),
    [anon_sym_POUNDEndif] = ACTIONS(7141),
    [anon_sym_POUNDendif2] = ACTIONS(7141),
    [anon_sym_POUNDENDIF2] = ACTIONS(7141),
    [anon_sym_POUNDEndif2] = ACTIONS(7141),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7143),
    [anon_sym_tableextension] = ACTIONS(7141),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7141),
    [anon_sym_Tableextension] = ACTIONS(7141),
    [anon_sym_TableExtension] = ACTIONS(7141),
    [anon_sym_tableExtension] = ACTIONS(7141),
    [sym_page_keyword] = ACTIONS(7143),
    [anon_sym_pageextension] = ACTIONS(7141),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7141),
    [anon_sym_Pageextension] = ACTIONS(7141),
    [anon_sym_PageExtension] = ACTIONS(7141),
    [anon_sym_pageExtension] = ACTIONS(7141),
    [anon_sym_codeunit] = ACTIONS(7141),
    [anon_sym_CODEUNIT] = ACTIONS(7141),
    [anon_sym_Codeunit] = ACTIONS(7141),
    [anon_sym_CodeUnit] = ACTIONS(7141),
    [anon_sym_COdeunit] = ACTIONS(7141),
    [anon_sym_codeUnit] = ACTIONS(7141),
    [sym_report_keyword] = ACTIONS(7143),
    [anon_sym_reportextension] = ACTIONS(7141),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7141),
    [anon_sym_Reportextension] = ACTIONS(7141),
    [anon_sym_ReportExtension] = ACTIONS(7141),
    [anon_sym_reportExtension] = ACTIONS(7141),
    [sym_query_keyword] = ACTIONS(7141),
    [anon_sym_xmlport] = ACTIONS(7141),
    [anon_sym_XMLPORT] = ACTIONS(7141),
    [anon_sym_Xmlport] = ACTIONS(7141),
    [anon_sym_XMLport] = ACTIONS(7141),
    [anon_sym_XMLPort] = ACTIONS(7141),
    [anon_sym_XmlPort] = ACTIONS(7141),
    [anon_sym_enum] = ACTIONS(7143),
    [anon_sym_ENUM] = ACTIONS(7143),
    [anon_sym_Enum] = ACTIONS(7143),
    [anon_sym_eNUM] = ACTIONS(7141),
    [anon_sym_eNum] = ACTIONS(7141),
    [anon_sym_ENum] = ACTIONS(7141),
    [anon_sym_enumextension] = ACTIONS(7141),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7141),
    [anon_sym_Enumextension] = ACTIONS(7141),
    [anon_sym_EnumExtension] = ACTIONS(7141),
    [anon_sym_enumExtension] = ACTIONS(7141),
    [sym_interface_keyword] = ACTIONS(7141),
    [anon_sym_controladdin] = ACTIONS(7141),
    [anon_sym_CONTROLADDIN] = ACTIONS(7141),
    [anon_sym_Controladdin] = ACTIONS(7141),
    [anon_sym_ControlAddIn] = ACTIONS(7141),
    [anon_sym_ControlAddin] = ACTIONS(7141),
    [anon_sym_controlAddIn] = ACTIONS(7141),
    [anon_sym_controlAddin] = ACTIONS(7141),
    [anon_sym_dotnet] = ACTIONS(7141),
    [anon_sym_DOTNET] = ACTIONS(7141),
    [anon_sym_Dotnet] = ACTIONS(7141),
    [anon_sym_DotNet] = ACTIONS(7141),
    [anon_sym_dotNet] = ACTIONS(7141),
    [sym_profile_keyword] = ACTIONS(7143),
    [anon_sym_profileextension] = ACTIONS(7141),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7141),
    [anon_sym_Profileextension] = ACTIONS(7141),
    [anon_sym_ProfileExtension] = ACTIONS(7141),
    [anon_sym_profileExtension] = ACTIONS(7141),
    [anon_sym_permissionset] = ACTIONS(7143),
    [anon_sym_PERMISSIONSET] = ACTIONS(7143),
    [anon_sym_Permissionset] = ACTIONS(7143),
    [anon_sym_PermissionSet] = ACTIONS(7143),
    [anon_sym_permissionSet] = ACTIONS(7143),
    [anon_sym_permissionsetextension] = ACTIONS(7141),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7141),
    [anon_sym_Permissionsetextension] = ACTIONS(7141),
    [anon_sym_PermissionSetExtension] = ACTIONS(7141),
    [anon_sym_permissionSetExtension] = ACTIONS(7141),
    [sym_entitlement_keyword] = ACTIONS(7141),
    [anon_sym_pagecustomization] = ACTIONS(7141),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7141),
    [anon_sym_Pagecustomization] = ACTIONS(7141),
    [anon_sym_PageCustomization] = ACTIONS(7141),
    [anon_sym_pageCustomization] = ACTIONS(7141),
    [sym_using_keyword] = ACTIONS(7141),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7141),
    [sym_preproc_close] = ACTIONS(7141),
  },
  [STATE(2861)] = {
    [anon_sym_POUNDif] = ACTIONS(7145),
    [anon_sym_POUNDIF] = ACTIONS(7145),
    [anon_sym_POUNDIf] = ACTIONS(7145),
    [anon_sym_POUNDelif] = ACTIONS(7145),
    [anon_sym_POUNDELIF] = ACTIONS(7145),
    [anon_sym_POUNDElif] = ACTIONS(7145),
    [anon_sym_POUNDelse] = ACTIONS(7145),
    [anon_sym_POUNDELSE] = ACTIONS(7145),
    [anon_sym_POUNDElse] = ACTIONS(7145),
    [anon_sym_POUNDelse2] = ACTIONS(7145),
    [anon_sym_POUNDELSE2] = ACTIONS(7145),
    [anon_sym_POUNDElse2] = ACTIONS(7145),
    [anon_sym_POUNDendif] = ACTIONS(7145),
    [anon_sym_POUNDENDIF] = ACTIONS(7145),
    [anon_sym_POUNDEndif] = ACTIONS(7145),
    [anon_sym_POUNDendif2] = ACTIONS(7145),
    [anon_sym_POUNDENDIF2] = ACTIONS(7145),
    [anon_sym_POUNDEndif2] = ACTIONS(7145),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7147),
    [anon_sym_tableextension] = ACTIONS(7145),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7145),
    [anon_sym_Tableextension] = ACTIONS(7145),
    [anon_sym_TableExtension] = ACTIONS(7145),
    [anon_sym_tableExtension] = ACTIONS(7145),
    [sym_page_keyword] = ACTIONS(7147),
    [anon_sym_pageextension] = ACTIONS(7145),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7145),
    [anon_sym_Pageextension] = ACTIONS(7145),
    [anon_sym_PageExtension] = ACTIONS(7145),
    [anon_sym_pageExtension] = ACTIONS(7145),
    [anon_sym_codeunit] = ACTIONS(7145),
    [anon_sym_CODEUNIT] = ACTIONS(7145),
    [anon_sym_Codeunit] = ACTIONS(7145),
    [anon_sym_CodeUnit] = ACTIONS(7145),
    [anon_sym_COdeunit] = ACTIONS(7145),
    [anon_sym_codeUnit] = ACTIONS(7145),
    [sym_report_keyword] = ACTIONS(7147),
    [anon_sym_reportextension] = ACTIONS(7145),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7145),
    [anon_sym_Reportextension] = ACTIONS(7145),
    [anon_sym_ReportExtension] = ACTIONS(7145),
    [anon_sym_reportExtension] = ACTIONS(7145),
    [sym_query_keyword] = ACTIONS(7145),
    [anon_sym_xmlport] = ACTIONS(7145),
    [anon_sym_XMLPORT] = ACTIONS(7145),
    [anon_sym_Xmlport] = ACTIONS(7145),
    [anon_sym_XMLport] = ACTIONS(7145),
    [anon_sym_XMLPort] = ACTIONS(7145),
    [anon_sym_XmlPort] = ACTIONS(7145),
    [anon_sym_enum] = ACTIONS(7147),
    [anon_sym_ENUM] = ACTIONS(7147),
    [anon_sym_Enum] = ACTIONS(7147),
    [anon_sym_eNUM] = ACTIONS(7145),
    [anon_sym_eNum] = ACTIONS(7145),
    [anon_sym_ENum] = ACTIONS(7145),
    [anon_sym_enumextension] = ACTIONS(7145),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7145),
    [anon_sym_Enumextension] = ACTIONS(7145),
    [anon_sym_EnumExtension] = ACTIONS(7145),
    [anon_sym_enumExtension] = ACTIONS(7145),
    [sym_interface_keyword] = ACTIONS(7145),
    [anon_sym_controladdin] = ACTIONS(7145),
    [anon_sym_CONTROLADDIN] = ACTIONS(7145),
    [anon_sym_Controladdin] = ACTIONS(7145),
    [anon_sym_ControlAddIn] = ACTIONS(7145),
    [anon_sym_ControlAddin] = ACTIONS(7145),
    [anon_sym_controlAddIn] = ACTIONS(7145),
    [anon_sym_controlAddin] = ACTIONS(7145),
    [anon_sym_dotnet] = ACTIONS(7145),
    [anon_sym_DOTNET] = ACTIONS(7145),
    [anon_sym_Dotnet] = ACTIONS(7145),
    [anon_sym_DotNet] = ACTIONS(7145),
    [anon_sym_dotNet] = ACTIONS(7145),
    [sym_profile_keyword] = ACTIONS(7147),
    [anon_sym_profileextension] = ACTIONS(7145),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7145),
    [anon_sym_Profileextension] = ACTIONS(7145),
    [anon_sym_ProfileExtension] = ACTIONS(7145),
    [anon_sym_profileExtension] = ACTIONS(7145),
    [anon_sym_permissionset] = ACTIONS(7147),
    [anon_sym_PERMISSIONSET] = ACTIONS(7147),
    [anon_sym_Permissionset] = ACTIONS(7147),
    [anon_sym_PermissionSet] = ACTIONS(7147),
    [anon_sym_permissionSet] = ACTIONS(7147),
    [anon_sym_permissionsetextension] = ACTIONS(7145),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7145),
    [anon_sym_Permissionsetextension] = ACTIONS(7145),
    [anon_sym_PermissionSetExtension] = ACTIONS(7145),
    [anon_sym_permissionSetExtension] = ACTIONS(7145),
    [sym_entitlement_keyword] = ACTIONS(7145),
    [anon_sym_pagecustomization] = ACTIONS(7145),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7145),
    [anon_sym_Pagecustomization] = ACTIONS(7145),
    [anon_sym_PageCustomization] = ACTIONS(7145),
    [anon_sym_pageCustomization] = ACTIONS(7145),
    [sym_using_keyword] = ACTIONS(7145),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7145),
    [sym_preproc_close] = ACTIONS(7145),
  },
  [STATE(2862)] = {
    [sym_identifier] = ACTIONS(3784),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_COMMA] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [aux_sym_boolean_token1] = ACTIONS(3784),
    [aux_sym_boolean_token2] = ACTIONS(3784),
    [sym_decimal] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3784),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_record_type_token1] = ACTIONS(3784),
    [aux_sym_basic_type_token21] = ACTIONS(3784),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_basic_type_token48] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_not] = ACTIONS(3784),
    [anon_sym_NOT] = ACTIONS(3784),
    [anon_sym_Not] = ACTIONS(3784),
    [anon_sym_POUNDelif] = ACTIONS(3786),
    [anon_sym_POUNDELIF] = ACTIONS(3786),
    [anon_sym_POUNDElif] = ACTIONS(3786),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [anon_sym_POUNDendif] = ACTIONS(3786),
    [anon_sym_POUNDENDIF] = ACTIONS(3786),
    [anon_sym_POUNDEndif] = ACTIONS(3786),
    [anon_sym_POUNDendif2] = ACTIONS(3786),
    [anon_sym_POUNDENDIF2] = ACTIONS(3786),
    [anon_sym_POUNDEndif2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3784),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3784),
    [anon_sym_DIV] = ACTIONS(3784),
    [anon_sym_Div] = ACTIONS(3784),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3784),
    [anon_sym_AND] = ACTIONS(3784),
    [anon_sym_And] = ACTIONS(3784),
    [anon_sym_or] = ACTIONS(3784),
    [anon_sym_OR] = ACTIONS(3784),
    [anon_sym_Or] = ACTIONS(3784),
    [anon_sym_xor] = ACTIONS(3784),
    [anon_sym_XOR] = ACTIONS(3784),
    [anon_sym_Xor] = ACTIONS(3784),
    [anon_sym_QMARK] = ACTIONS(3786),
    [sym_datetime_literal] = ACTIONS(3786),
    [sym_date_literal] = ACTIONS(3784),
    [sym_time_literal] = ACTIONS(3784),
    [sym_biginteger_literal] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_page_keyword] = ACTIONS(3784),
    [anon_sym_codeunit] = ACTIONS(3784),
    [anon_sym_CODEUNIT] = ACTIONS(3784),
    [anon_sym_Codeunit] = ACTIONS(3784),
    [anon_sym_CodeUnit] = ACTIONS(3784),
    [anon_sym_COdeunit] = ACTIONS(3784),
    [anon_sym_codeUnit] = ACTIONS(3784),
    [sym_report_keyword] = ACTIONS(3784),
    [sym_query_keyword] = ACTIONS(3784),
    [anon_sym_xmlport] = ACTIONS(3784),
    [anon_sym_XMLPORT] = ACTIONS(3784),
    [anon_sym_Xmlport] = ACTIONS(3784),
    [anon_sym_XMLport] = ACTIONS(3784),
    [anon_sym_XMLPort] = ACTIONS(3784),
    [anon_sym_XmlPort] = ACTIONS(3784),
    [anon_sym_enum] = ACTIONS(3784),
    [anon_sym_ENUM] = ACTIONS(3784),
    [anon_sym_Enum] = ACTIONS(3784),
    [anon_sym_eNUM] = ACTIONS(3784),
    [anon_sym_eNum] = ACTIONS(3784),
    [anon_sym_ENum] = ACTIONS(3784),
    [sym_quoted_identifier] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3786),
    [sym_verbatim_string] = ACTIONS(3786),
    [sym_integer] = ACTIONS(3784),
    [sym_continue_as_identifier] = ACTIONS(3786),
    [sym_preproc_close] = ACTIONS(3786),
  },
  [STATE(2863)] = {
    [anon_sym_POUNDif] = ACTIONS(7149),
    [anon_sym_POUNDIF] = ACTIONS(7149),
    [anon_sym_POUNDIf] = ACTIONS(7149),
    [anon_sym_POUNDelif] = ACTIONS(7149),
    [anon_sym_POUNDELIF] = ACTIONS(7149),
    [anon_sym_POUNDElif] = ACTIONS(7149),
    [anon_sym_POUNDelse] = ACTIONS(7149),
    [anon_sym_POUNDELSE] = ACTIONS(7149),
    [anon_sym_POUNDElse] = ACTIONS(7149),
    [anon_sym_POUNDelse2] = ACTIONS(7149),
    [anon_sym_POUNDELSE2] = ACTIONS(7149),
    [anon_sym_POUNDElse2] = ACTIONS(7149),
    [anon_sym_POUNDendif] = ACTIONS(7149),
    [anon_sym_POUNDENDIF] = ACTIONS(7149),
    [anon_sym_POUNDEndif] = ACTIONS(7149),
    [anon_sym_POUNDendif2] = ACTIONS(7149),
    [anon_sym_POUNDENDIF2] = ACTIONS(7149),
    [anon_sym_POUNDEndif2] = ACTIONS(7149),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7151),
    [anon_sym_tableextension] = ACTIONS(7149),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7149),
    [anon_sym_Tableextension] = ACTIONS(7149),
    [anon_sym_TableExtension] = ACTIONS(7149),
    [anon_sym_tableExtension] = ACTIONS(7149),
    [sym_page_keyword] = ACTIONS(7151),
    [anon_sym_pageextension] = ACTIONS(7149),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7149),
    [anon_sym_Pageextension] = ACTIONS(7149),
    [anon_sym_PageExtension] = ACTIONS(7149),
    [anon_sym_pageExtension] = ACTIONS(7149),
    [anon_sym_codeunit] = ACTIONS(7149),
    [anon_sym_CODEUNIT] = ACTIONS(7149),
    [anon_sym_Codeunit] = ACTIONS(7149),
    [anon_sym_CodeUnit] = ACTIONS(7149),
    [anon_sym_COdeunit] = ACTIONS(7149),
    [anon_sym_codeUnit] = ACTIONS(7149),
    [sym_report_keyword] = ACTIONS(7151),
    [anon_sym_reportextension] = ACTIONS(7149),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7149),
    [anon_sym_Reportextension] = ACTIONS(7149),
    [anon_sym_ReportExtension] = ACTIONS(7149),
    [anon_sym_reportExtension] = ACTIONS(7149),
    [sym_query_keyword] = ACTIONS(7149),
    [anon_sym_xmlport] = ACTIONS(7149),
    [anon_sym_XMLPORT] = ACTIONS(7149),
    [anon_sym_Xmlport] = ACTIONS(7149),
    [anon_sym_XMLport] = ACTIONS(7149),
    [anon_sym_XMLPort] = ACTIONS(7149),
    [anon_sym_XmlPort] = ACTIONS(7149),
    [anon_sym_enum] = ACTIONS(7151),
    [anon_sym_ENUM] = ACTIONS(7151),
    [anon_sym_Enum] = ACTIONS(7151),
    [anon_sym_eNUM] = ACTIONS(7149),
    [anon_sym_eNum] = ACTIONS(7149),
    [anon_sym_ENum] = ACTIONS(7149),
    [anon_sym_enumextension] = ACTIONS(7149),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7149),
    [anon_sym_Enumextension] = ACTIONS(7149),
    [anon_sym_EnumExtension] = ACTIONS(7149),
    [anon_sym_enumExtension] = ACTIONS(7149),
    [sym_interface_keyword] = ACTIONS(7149),
    [anon_sym_controladdin] = ACTIONS(7149),
    [anon_sym_CONTROLADDIN] = ACTIONS(7149),
    [anon_sym_Controladdin] = ACTIONS(7149),
    [anon_sym_ControlAddIn] = ACTIONS(7149),
    [anon_sym_ControlAddin] = ACTIONS(7149),
    [anon_sym_controlAddIn] = ACTIONS(7149),
    [anon_sym_controlAddin] = ACTIONS(7149),
    [anon_sym_dotnet] = ACTIONS(7149),
    [anon_sym_DOTNET] = ACTIONS(7149),
    [anon_sym_Dotnet] = ACTIONS(7149),
    [anon_sym_DotNet] = ACTIONS(7149),
    [anon_sym_dotNet] = ACTIONS(7149),
    [sym_profile_keyword] = ACTIONS(7151),
    [anon_sym_profileextension] = ACTIONS(7149),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7149),
    [anon_sym_Profileextension] = ACTIONS(7149),
    [anon_sym_ProfileExtension] = ACTIONS(7149),
    [anon_sym_profileExtension] = ACTIONS(7149),
    [anon_sym_permissionset] = ACTIONS(7151),
    [anon_sym_PERMISSIONSET] = ACTIONS(7151),
    [anon_sym_Permissionset] = ACTIONS(7151),
    [anon_sym_PermissionSet] = ACTIONS(7151),
    [anon_sym_permissionSet] = ACTIONS(7151),
    [anon_sym_permissionsetextension] = ACTIONS(7149),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7149),
    [anon_sym_Permissionsetextension] = ACTIONS(7149),
    [anon_sym_PermissionSetExtension] = ACTIONS(7149),
    [anon_sym_permissionSetExtension] = ACTIONS(7149),
    [sym_entitlement_keyword] = ACTIONS(7149),
    [anon_sym_pagecustomization] = ACTIONS(7149),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7149),
    [anon_sym_Pagecustomization] = ACTIONS(7149),
    [anon_sym_PageCustomization] = ACTIONS(7149),
    [anon_sym_pageCustomization] = ACTIONS(7149),
    [sym_using_keyword] = ACTIONS(7149),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7149),
    [sym_preproc_close] = ACTIONS(7149),
  },
  [STATE(2864)] = {
    [anon_sym_POUNDif] = ACTIONS(7153),
    [anon_sym_POUNDIF] = ACTIONS(7153),
    [anon_sym_POUNDIf] = ACTIONS(7153),
    [anon_sym_POUNDelif] = ACTIONS(7153),
    [anon_sym_POUNDELIF] = ACTIONS(7153),
    [anon_sym_POUNDElif] = ACTIONS(7153),
    [anon_sym_POUNDelse] = ACTIONS(7153),
    [anon_sym_POUNDELSE] = ACTIONS(7153),
    [anon_sym_POUNDElse] = ACTIONS(7153),
    [anon_sym_POUNDelse2] = ACTIONS(7153),
    [anon_sym_POUNDELSE2] = ACTIONS(7153),
    [anon_sym_POUNDElse2] = ACTIONS(7153),
    [anon_sym_POUNDendif] = ACTIONS(7153),
    [anon_sym_POUNDENDIF] = ACTIONS(7153),
    [anon_sym_POUNDEndif] = ACTIONS(7153),
    [anon_sym_POUNDendif2] = ACTIONS(7153),
    [anon_sym_POUNDENDIF2] = ACTIONS(7153),
    [anon_sym_POUNDEndif2] = ACTIONS(7153),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7155),
    [anon_sym_tableextension] = ACTIONS(7153),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7153),
    [anon_sym_Tableextension] = ACTIONS(7153),
    [anon_sym_TableExtension] = ACTIONS(7153),
    [anon_sym_tableExtension] = ACTIONS(7153),
    [sym_page_keyword] = ACTIONS(7155),
    [anon_sym_pageextension] = ACTIONS(7153),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7153),
    [anon_sym_Pageextension] = ACTIONS(7153),
    [anon_sym_PageExtension] = ACTIONS(7153),
    [anon_sym_pageExtension] = ACTIONS(7153),
    [anon_sym_codeunit] = ACTIONS(7153),
    [anon_sym_CODEUNIT] = ACTIONS(7153),
    [anon_sym_Codeunit] = ACTIONS(7153),
    [anon_sym_CodeUnit] = ACTIONS(7153),
    [anon_sym_COdeunit] = ACTIONS(7153),
    [anon_sym_codeUnit] = ACTIONS(7153),
    [sym_report_keyword] = ACTIONS(7155),
    [anon_sym_reportextension] = ACTIONS(7153),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7153),
    [anon_sym_Reportextension] = ACTIONS(7153),
    [anon_sym_ReportExtension] = ACTIONS(7153),
    [anon_sym_reportExtension] = ACTIONS(7153),
    [sym_query_keyword] = ACTIONS(7153),
    [anon_sym_xmlport] = ACTIONS(7153),
    [anon_sym_XMLPORT] = ACTIONS(7153),
    [anon_sym_Xmlport] = ACTIONS(7153),
    [anon_sym_XMLport] = ACTIONS(7153),
    [anon_sym_XMLPort] = ACTIONS(7153),
    [anon_sym_XmlPort] = ACTIONS(7153),
    [anon_sym_enum] = ACTIONS(7155),
    [anon_sym_ENUM] = ACTIONS(7155),
    [anon_sym_Enum] = ACTIONS(7155),
    [anon_sym_eNUM] = ACTIONS(7153),
    [anon_sym_eNum] = ACTIONS(7153),
    [anon_sym_ENum] = ACTIONS(7153),
    [anon_sym_enumextension] = ACTIONS(7153),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7153),
    [anon_sym_Enumextension] = ACTIONS(7153),
    [anon_sym_EnumExtension] = ACTIONS(7153),
    [anon_sym_enumExtension] = ACTIONS(7153),
    [sym_interface_keyword] = ACTIONS(7153),
    [anon_sym_controladdin] = ACTIONS(7153),
    [anon_sym_CONTROLADDIN] = ACTIONS(7153),
    [anon_sym_Controladdin] = ACTIONS(7153),
    [anon_sym_ControlAddIn] = ACTIONS(7153),
    [anon_sym_ControlAddin] = ACTIONS(7153),
    [anon_sym_controlAddIn] = ACTIONS(7153),
    [anon_sym_controlAddin] = ACTIONS(7153),
    [anon_sym_dotnet] = ACTIONS(7153),
    [anon_sym_DOTNET] = ACTIONS(7153),
    [anon_sym_Dotnet] = ACTIONS(7153),
    [anon_sym_DotNet] = ACTIONS(7153),
    [anon_sym_dotNet] = ACTIONS(7153),
    [sym_profile_keyword] = ACTIONS(7155),
    [anon_sym_profileextension] = ACTIONS(7153),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7153),
    [anon_sym_Profileextension] = ACTIONS(7153),
    [anon_sym_ProfileExtension] = ACTIONS(7153),
    [anon_sym_profileExtension] = ACTIONS(7153),
    [anon_sym_permissionset] = ACTIONS(7155),
    [anon_sym_PERMISSIONSET] = ACTIONS(7155),
    [anon_sym_Permissionset] = ACTIONS(7155),
    [anon_sym_PermissionSet] = ACTIONS(7155),
    [anon_sym_permissionSet] = ACTIONS(7155),
    [anon_sym_permissionsetextension] = ACTIONS(7153),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7153),
    [anon_sym_Permissionsetextension] = ACTIONS(7153),
    [anon_sym_PermissionSetExtension] = ACTIONS(7153),
    [anon_sym_permissionSetExtension] = ACTIONS(7153),
    [sym_entitlement_keyword] = ACTIONS(7153),
    [anon_sym_pagecustomization] = ACTIONS(7153),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7153),
    [anon_sym_Pagecustomization] = ACTIONS(7153),
    [anon_sym_PageCustomization] = ACTIONS(7153),
    [anon_sym_pageCustomization] = ACTIONS(7153),
    [sym_using_keyword] = ACTIONS(7153),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7153),
    [sym_preproc_close] = ACTIONS(7153),
  },
  [STATE(2865)] = {
    [anon_sym_POUNDif] = ACTIONS(7157),
    [anon_sym_POUNDIF] = ACTIONS(7157),
    [anon_sym_POUNDIf] = ACTIONS(7157),
    [anon_sym_POUNDelif] = ACTIONS(7157),
    [anon_sym_POUNDELIF] = ACTIONS(7157),
    [anon_sym_POUNDElif] = ACTIONS(7157),
    [anon_sym_POUNDelse] = ACTIONS(7157),
    [anon_sym_POUNDELSE] = ACTIONS(7157),
    [anon_sym_POUNDElse] = ACTIONS(7157),
    [anon_sym_POUNDelse2] = ACTIONS(7157),
    [anon_sym_POUNDELSE2] = ACTIONS(7157),
    [anon_sym_POUNDElse2] = ACTIONS(7157),
    [anon_sym_POUNDendif] = ACTIONS(7157),
    [anon_sym_POUNDENDIF] = ACTIONS(7157),
    [anon_sym_POUNDEndif] = ACTIONS(7157),
    [anon_sym_POUNDendif2] = ACTIONS(7157),
    [anon_sym_POUNDENDIF2] = ACTIONS(7157),
    [anon_sym_POUNDEndif2] = ACTIONS(7157),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7159),
    [anon_sym_tableextension] = ACTIONS(7157),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7157),
    [anon_sym_Tableextension] = ACTIONS(7157),
    [anon_sym_TableExtension] = ACTIONS(7157),
    [anon_sym_tableExtension] = ACTIONS(7157),
    [sym_page_keyword] = ACTIONS(7159),
    [anon_sym_pageextension] = ACTIONS(7157),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7157),
    [anon_sym_Pageextension] = ACTIONS(7157),
    [anon_sym_PageExtension] = ACTIONS(7157),
    [anon_sym_pageExtension] = ACTIONS(7157),
    [anon_sym_codeunit] = ACTIONS(7157),
    [anon_sym_CODEUNIT] = ACTIONS(7157),
    [anon_sym_Codeunit] = ACTIONS(7157),
    [anon_sym_CodeUnit] = ACTIONS(7157),
    [anon_sym_COdeunit] = ACTIONS(7157),
    [anon_sym_codeUnit] = ACTIONS(7157),
    [sym_report_keyword] = ACTIONS(7159),
    [anon_sym_reportextension] = ACTIONS(7157),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7157),
    [anon_sym_Reportextension] = ACTIONS(7157),
    [anon_sym_ReportExtension] = ACTIONS(7157),
    [anon_sym_reportExtension] = ACTIONS(7157),
    [sym_query_keyword] = ACTIONS(7157),
    [anon_sym_xmlport] = ACTIONS(7157),
    [anon_sym_XMLPORT] = ACTIONS(7157),
    [anon_sym_Xmlport] = ACTIONS(7157),
    [anon_sym_XMLport] = ACTIONS(7157),
    [anon_sym_XMLPort] = ACTIONS(7157),
    [anon_sym_XmlPort] = ACTIONS(7157),
    [anon_sym_enum] = ACTIONS(7159),
    [anon_sym_ENUM] = ACTIONS(7159),
    [anon_sym_Enum] = ACTIONS(7159),
    [anon_sym_eNUM] = ACTIONS(7157),
    [anon_sym_eNum] = ACTIONS(7157),
    [anon_sym_ENum] = ACTIONS(7157),
    [anon_sym_enumextension] = ACTIONS(7157),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7157),
    [anon_sym_Enumextension] = ACTIONS(7157),
    [anon_sym_EnumExtension] = ACTIONS(7157),
    [anon_sym_enumExtension] = ACTIONS(7157),
    [sym_interface_keyword] = ACTIONS(7157),
    [anon_sym_controladdin] = ACTIONS(7157),
    [anon_sym_CONTROLADDIN] = ACTIONS(7157),
    [anon_sym_Controladdin] = ACTIONS(7157),
    [anon_sym_ControlAddIn] = ACTIONS(7157),
    [anon_sym_ControlAddin] = ACTIONS(7157),
    [anon_sym_controlAddIn] = ACTIONS(7157),
    [anon_sym_controlAddin] = ACTIONS(7157),
    [anon_sym_dotnet] = ACTIONS(7157),
    [anon_sym_DOTNET] = ACTIONS(7157),
    [anon_sym_Dotnet] = ACTIONS(7157),
    [anon_sym_DotNet] = ACTIONS(7157),
    [anon_sym_dotNet] = ACTIONS(7157),
    [sym_profile_keyword] = ACTIONS(7159),
    [anon_sym_profileextension] = ACTIONS(7157),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7157),
    [anon_sym_Profileextension] = ACTIONS(7157),
    [anon_sym_ProfileExtension] = ACTIONS(7157),
    [anon_sym_profileExtension] = ACTIONS(7157),
    [anon_sym_permissionset] = ACTIONS(7159),
    [anon_sym_PERMISSIONSET] = ACTIONS(7159),
    [anon_sym_Permissionset] = ACTIONS(7159),
    [anon_sym_PermissionSet] = ACTIONS(7159),
    [anon_sym_permissionSet] = ACTIONS(7159),
    [anon_sym_permissionsetextension] = ACTIONS(7157),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7157),
    [anon_sym_Permissionsetextension] = ACTIONS(7157),
    [anon_sym_PermissionSetExtension] = ACTIONS(7157),
    [anon_sym_permissionSetExtension] = ACTIONS(7157),
    [sym_entitlement_keyword] = ACTIONS(7157),
    [anon_sym_pagecustomization] = ACTIONS(7157),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7157),
    [anon_sym_Pagecustomization] = ACTIONS(7157),
    [anon_sym_PageCustomization] = ACTIONS(7157),
    [anon_sym_pageCustomization] = ACTIONS(7157),
    [sym_using_keyword] = ACTIONS(7157),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7157),
    [sym_preproc_close] = ACTIONS(7157),
  },
  [STATE(2866)] = {
    [anon_sym_POUNDif] = ACTIONS(7161),
    [anon_sym_POUNDIF] = ACTIONS(7161),
    [anon_sym_POUNDIf] = ACTIONS(7161),
    [anon_sym_POUNDelif] = ACTIONS(7161),
    [anon_sym_POUNDELIF] = ACTIONS(7161),
    [anon_sym_POUNDElif] = ACTIONS(7161),
    [anon_sym_POUNDelse] = ACTIONS(7161),
    [anon_sym_POUNDELSE] = ACTIONS(7161),
    [anon_sym_POUNDElse] = ACTIONS(7161),
    [anon_sym_POUNDelse2] = ACTIONS(7161),
    [anon_sym_POUNDELSE2] = ACTIONS(7161),
    [anon_sym_POUNDElse2] = ACTIONS(7161),
    [anon_sym_POUNDendif] = ACTIONS(7161),
    [anon_sym_POUNDENDIF] = ACTIONS(7161),
    [anon_sym_POUNDEndif] = ACTIONS(7161),
    [anon_sym_POUNDendif2] = ACTIONS(7161),
    [anon_sym_POUNDENDIF2] = ACTIONS(7161),
    [anon_sym_POUNDEndif2] = ACTIONS(7161),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7163),
    [anon_sym_tableextension] = ACTIONS(7161),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7161),
    [anon_sym_Tableextension] = ACTIONS(7161),
    [anon_sym_TableExtension] = ACTIONS(7161),
    [anon_sym_tableExtension] = ACTIONS(7161),
    [sym_page_keyword] = ACTIONS(7163),
    [anon_sym_pageextension] = ACTIONS(7161),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7161),
    [anon_sym_Pageextension] = ACTIONS(7161),
    [anon_sym_PageExtension] = ACTIONS(7161),
    [anon_sym_pageExtension] = ACTIONS(7161),
    [anon_sym_codeunit] = ACTIONS(7161),
    [anon_sym_CODEUNIT] = ACTIONS(7161),
    [anon_sym_Codeunit] = ACTIONS(7161),
    [anon_sym_CodeUnit] = ACTIONS(7161),
    [anon_sym_COdeunit] = ACTIONS(7161),
    [anon_sym_codeUnit] = ACTIONS(7161),
    [sym_report_keyword] = ACTIONS(7163),
    [anon_sym_reportextension] = ACTIONS(7161),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7161),
    [anon_sym_Reportextension] = ACTIONS(7161),
    [anon_sym_ReportExtension] = ACTIONS(7161),
    [anon_sym_reportExtension] = ACTIONS(7161),
    [sym_query_keyword] = ACTIONS(7161),
    [anon_sym_xmlport] = ACTIONS(7161),
    [anon_sym_XMLPORT] = ACTIONS(7161),
    [anon_sym_Xmlport] = ACTIONS(7161),
    [anon_sym_XMLport] = ACTIONS(7161),
    [anon_sym_XMLPort] = ACTIONS(7161),
    [anon_sym_XmlPort] = ACTIONS(7161),
    [anon_sym_enum] = ACTIONS(7163),
    [anon_sym_ENUM] = ACTIONS(7163),
    [anon_sym_Enum] = ACTIONS(7163),
    [anon_sym_eNUM] = ACTIONS(7161),
    [anon_sym_eNum] = ACTIONS(7161),
    [anon_sym_ENum] = ACTIONS(7161),
    [anon_sym_enumextension] = ACTIONS(7161),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7161),
    [anon_sym_Enumextension] = ACTIONS(7161),
    [anon_sym_EnumExtension] = ACTIONS(7161),
    [anon_sym_enumExtension] = ACTIONS(7161),
    [sym_interface_keyword] = ACTIONS(7161),
    [anon_sym_controladdin] = ACTIONS(7161),
    [anon_sym_CONTROLADDIN] = ACTIONS(7161),
    [anon_sym_Controladdin] = ACTIONS(7161),
    [anon_sym_ControlAddIn] = ACTIONS(7161),
    [anon_sym_ControlAddin] = ACTIONS(7161),
    [anon_sym_controlAddIn] = ACTIONS(7161),
    [anon_sym_controlAddin] = ACTIONS(7161),
    [anon_sym_dotnet] = ACTIONS(7161),
    [anon_sym_DOTNET] = ACTIONS(7161),
    [anon_sym_Dotnet] = ACTIONS(7161),
    [anon_sym_DotNet] = ACTIONS(7161),
    [anon_sym_dotNet] = ACTIONS(7161),
    [sym_profile_keyword] = ACTIONS(7163),
    [anon_sym_profileextension] = ACTIONS(7161),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7161),
    [anon_sym_Profileextension] = ACTIONS(7161),
    [anon_sym_ProfileExtension] = ACTIONS(7161),
    [anon_sym_profileExtension] = ACTIONS(7161),
    [anon_sym_permissionset] = ACTIONS(7163),
    [anon_sym_PERMISSIONSET] = ACTIONS(7163),
    [anon_sym_Permissionset] = ACTIONS(7163),
    [anon_sym_PermissionSet] = ACTIONS(7163),
    [anon_sym_permissionSet] = ACTIONS(7163),
    [anon_sym_permissionsetextension] = ACTIONS(7161),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7161),
    [anon_sym_Permissionsetextension] = ACTIONS(7161),
    [anon_sym_PermissionSetExtension] = ACTIONS(7161),
    [anon_sym_permissionSetExtension] = ACTIONS(7161),
    [sym_entitlement_keyword] = ACTIONS(7161),
    [anon_sym_pagecustomization] = ACTIONS(7161),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7161),
    [anon_sym_Pagecustomization] = ACTIONS(7161),
    [anon_sym_PageCustomization] = ACTIONS(7161),
    [anon_sym_pageCustomization] = ACTIONS(7161),
    [sym_using_keyword] = ACTIONS(7161),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7161),
    [sym_preproc_close] = ACTIONS(7161),
  },
  [STATE(2867)] = {
    [anon_sym_POUNDif] = ACTIONS(7165),
    [anon_sym_POUNDIF] = ACTIONS(7165),
    [anon_sym_POUNDIf] = ACTIONS(7165),
    [anon_sym_POUNDelif] = ACTIONS(7165),
    [anon_sym_POUNDELIF] = ACTIONS(7165),
    [anon_sym_POUNDElif] = ACTIONS(7165),
    [anon_sym_POUNDelse] = ACTIONS(7165),
    [anon_sym_POUNDELSE] = ACTIONS(7165),
    [anon_sym_POUNDElse] = ACTIONS(7165),
    [anon_sym_POUNDelse2] = ACTIONS(7165),
    [anon_sym_POUNDELSE2] = ACTIONS(7165),
    [anon_sym_POUNDElse2] = ACTIONS(7165),
    [anon_sym_POUNDendif] = ACTIONS(7165),
    [anon_sym_POUNDENDIF] = ACTIONS(7165),
    [anon_sym_POUNDEndif] = ACTIONS(7165),
    [anon_sym_POUNDendif2] = ACTIONS(7165),
    [anon_sym_POUNDENDIF2] = ACTIONS(7165),
    [anon_sym_POUNDEndif2] = ACTIONS(7165),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7167),
    [anon_sym_tableextension] = ACTIONS(7165),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7165),
    [anon_sym_Tableextension] = ACTIONS(7165),
    [anon_sym_TableExtension] = ACTIONS(7165),
    [anon_sym_tableExtension] = ACTIONS(7165),
    [sym_page_keyword] = ACTIONS(7167),
    [anon_sym_pageextension] = ACTIONS(7165),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7165),
    [anon_sym_Pageextension] = ACTIONS(7165),
    [anon_sym_PageExtension] = ACTIONS(7165),
    [anon_sym_pageExtension] = ACTIONS(7165),
    [anon_sym_codeunit] = ACTIONS(7165),
    [anon_sym_CODEUNIT] = ACTIONS(7165),
    [anon_sym_Codeunit] = ACTIONS(7165),
    [anon_sym_CodeUnit] = ACTIONS(7165),
    [anon_sym_COdeunit] = ACTIONS(7165),
    [anon_sym_codeUnit] = ACTIONS(7165),
    [sym_report_keyword] = ACTIONS(7167),
    [anon_sym_reportextension] = ACTIONS(7165),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7165),
    [anon_sym_Reportextension] = ACTIONS(7165),
    [anon_sym_ReportExtension] = ACTIONS(7165),
    [anon_sym_reportExtension] = ACTIONS(7165),
    [sym_query_keyword] = ACTIONS(7165),
    [anon_sym_xmlport] = ACTIONS(7165),
    [anon_sym_XMLPORT] = ACTIONS(7165),
    [anon_sym_Xmlport] = ACTIONS(7165),
    [anon_sym_XMLport] = ACTIONS(7165),
    [anon_sym_XMLPort] = ACTIONS(7165),
    [anon_sym_XmlPort] = ACTIONS(7165),
    [anon_sym_enum] = ACTIONS(7167),
    [anon_sym_ENUM] = ACTIONS(7167),
    [anon_sym_Enum] = ACTIONS(7167),
    [anon_sym_eNUM] = ACTIONS(7165),
    [anon_sym_eNum] = ACTIONS(7165),
    [anon_sym_ENum] = ACTIONS(7165),
    [anon_sym_enumextension] = ACTIONS(7165),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7165),
    [anon_sym_Enumextension] = ACTIONS(7165),
    [anon_sym_EnumExtension] = ACTIONS(7165),
    [anon_sym_enumExtension] = ACTIONS(7165),
    [sym_interface_keyword] = ACTIONS(7165),
    [anon_sym_controladdin] = ACTIONS(7165),
    [anon_sym_CONTROLADDIN] = ACTIONS(7165),
    [anon_sym_Controladdin] = ACTIONS(7165),
    [anon_sym_ControlAddIn] = ACTIONS(7165),
    [anon_sym_ControlAddin] = ACTIONS(7165),
    [anon_sym_controlAddIn] = ACTIONS(7165),
    [anon_sym_controlAddin] = ACTIONS(7165),
    [anon_sym_dotnet] = ACTIONS(7165),
    [anon_sym_DOTNET] = ACTIONS(7165),
    [anon_sym_Dotnet] = ACTIONS(7165),
    [anon_sym_DotNet] = ACTIONS(7165),
    [anon_sym_dotNet] = ACTIONS(7165),
    [sym_profile_keyword] = ACTIONS(7167),
    [anon_sym_profileextension] = ACTIONS(7165),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7165),
    [anon_sym_Profileextension] = ACTIONS(7165),
    [anon_sym_ProfileExtension] = ACTIONS(7165),
    [anon_sym_profileExtension] = ACTIONS(7165),
    [anon_sym_permissionset] = ACTIONS(7167),
    [anon_sym_PERMISSIONSET] = ACTIONS(7167),
    [anon_sym_Permissionset] = ACTIONS(7167),
    [anon_sym_PermissionSet] = ACTIONS(7167),
    [anon_sym_permissionSet] = ACTIONS(7167),
    [anon_sym_permissionsetextension] = ACTIONS(7165),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7165),
    [anon_sym_Permissionsetextension] = ACTIONS(7165),
    [anon_sym_PermissionSetExtension] = ACTIONS(7165),
    [anon_sym_permissionSetExtension] = ACTIONS(7165),
    [sym_entitlement_keyword] = ACTIONS(7165),
    [anon_sym_pagecustomization] = ACTIONS(7165),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7165),
    [anon_sym_Pagecustomization] = ACTIONS(7165),
    [anon_sym_PageCustomization] = ACTIONS(7165),
    [anon_sym_pageCustomization] = ACTIONS(7165),
    [sym_using_keyword] = ACTIONS(7165),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7165),
    [sym_preproc_close] = ACTIONS(7165),
  },
  [STATE(2868)] = {
    [sym_else_keyword] = STATE(638),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_until] = ACTIONS(5485),
    [anon_sym_UNTIL] = ACTIONS(5485),
    [anon_sym_Until] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
  },
  [STATE(2869)] = {
    [sym_else_keyword] = STATE(639),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_until] = ACTIONS(5453),
    [anon_sym_UNTIL] = ACTIONS(5453),
    [anon_sym_Until] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
  },
  [STATE(2870)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2782),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(6947),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelif] = ACTIONS(3691),
    [anon_sym_POUNDELIF] = ACTIONS(3691),
    [anon_sym_POUNDElif] = ACTIONS(3691),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [anon_sym_POUNDendif] = ACTIONS(3691),
    [anon_sym_POUNDENDIF] = ACTIONS(3691),
    [anon_sym_POUNDEndif] = ACTIONS(3691),
    [anon_sym_POUNDendif2] = ACTIONS(3691),
    [anon_sym_POUNDENDIF2] = ACTIONS(3691),
    [anon_sym_POUNDEndif2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3691),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_close] = ACTIONS(3691),
  },
  [STATE(2871)] = {
    [anon_sym_POUNDif] = ACTIONS(7169),
    [anon_sym_POUNDIF] = ACTIONS(7169),
    [anon_sym_POUNDIf] = ACTIONS(7169),
    [anon_sym_POUNDelif] = ACTIONS(7169),
    [anon_sym_POUNDELIF] = ACTIONS(7169),
    [anon_sym_POUNDElif] = ACTIONS(7169),
    [anon_sym_POUNDelse] = ACTIONS(7169),
    [anon_sym_POUNDELSE] = ACTIONS(7169),
    [anon_sym_POUNDElse] = ACTIONS(7169),
    [anon_sym_POUNDelse2] = ACTIONS(7169),
    [anon_sym_POUNDELSE2] = ACTIONS(7169),
    [anon_sym_POUNDElse2] = ACTIONS(7169),
    [anon_sym_POUNDendif] = ACTIONS(7169),
    [anon_sym_POUNDENDIF] = ACTIONS(7169),
    [anon_sym_POUNDEndif] = ACTIONS(7169),
    [anon_sym_POUNDendif2] = ACTIONS(7169),
    [anon_sym_POUNDENDIF2] = ACTIONS(7169),
    [anon_sym_POUNDEndif2] = ACTIONS(7169),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7171),
    [anon_sym_tableextension] = ACTIONS(7169),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7169),
    [anon_sym_Tableextension] = ACTIONS(7169),
    [anon_sym_TableExtension] = ACTIONS(7169),
    [anon_sym_tableExtension] = ACTIONS(7169),
    [sym_page_keyword] = ACTIONS(7171),
    [anon_sym_pageextension] = ACTIONS(7169),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7169),
    [anon_sym_Pageextension] = ACTIONS(7169),
    [anon_sym_PageExtension] = ACTIONS(7169),
    [anon_sym_pageExtension] = ACTIONS(7169),
    [anon_sym_codeunit] = ACTIONS(7169),
    [anon_sym_CODEUNIT] = ACTIONS(7169),
    [anon_sym_Codeunit] = ACTIONS(7169),
    [anon_sym_CodeUnit] = ACTIONS(7169),
    [anon_sym_COdeunit] = ACTIONS(7169),
    [anon_sym_codeUnit] = ACTIONS(7169),
    [sym_report_keyword] = ACTIONS(7171),
    [anon_sym_reportextension] = ACTIONS(7169),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7169),
    [anon_sym_Reportextension] = ACTIONS(7169),
    [anon_sym_ReportExtension] = ACTIONS(7169),
    [anon_sym_reportExtension] = ACTIONS(7169),
    [sym_query_keyword] = ACTIONS(7169),
    [anon_sym_xmlport] = ACTIONS(7169),
    [anon_sym_XMLPORT] = ACTIONS(7169),
    [anon_sym_Xmlport] = ACTIONS(7169),
    [anon_sym_XMLport] = ACTIONS(7169),
    [anon_sym_XMLPort] = ACTIONS(7169),
    [anon_sym_XmlPort] = ACTIONS(7169),
    [anon_sym_enum] = ACTIONS(7171),
    [anon_sym_ENUM] = ACTIONS(7171),
    [anon_sym_Enum] = ACTIONS(7171),
    [anon_sym_eNUM] = ACTIONS(7169),
    [anon_sym_eNum] = ACTIONS(7169),
    [anon_sym_ENum] = ACTIONS(7169),
    [anon_sym_enumextension] = ACTIONS(7169),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7169),
    [anon_sym_Enumextension] = ACTIONS(7169),
    [anon_sym_EnumExtension] = ACTIONS(7169),
    [anon_sym_enumExtension] = ACTIONS(7169),
    [sym_interface_keyword] = ACTIONS(7169),
    [anon_sym_controladdin] = ACTIONS(7169),
    [anon_sym_CONTROLADDIN] = ACTIONS(7169),
    [anon_sym_Controladdin] = ACTIONS(7169),
    [anon_sym_ControlAddIn] = ACTIONS(7169),
    [anon_sym_ControlAddin] = ACTIONS(7169),
    [anon_sym_controlAddIn] = ACTIONS(7169),
    [anon_sym_controlAddin] = ACTIONS(7169),
    [anon_sym_dotnet] = ACTIONS(7169),
    [anon_sym_DOTNET] = ACTIONS(7169),
    [anon_sym_Dotnet] = ACTIONS(7169),
    [anon_sym_DotNet] = ACTIONS(7169),
    [anon_sym_dotNet] = ACTIONS(7169),
    [sym_profile_keyword] = ACTIONS(7171),
    [anon_sym_profileextension] = ACTIONS(7169),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7169),
    [anon_sym_Profileextension] = ACTIONS(7169),
    [anon_sym_ProfileExtension] = ACTIONS(7169),
    [anon_sym_profileExtension] = ACTIONS(7169),
    [anon_sym_permissionset] = ACTIONS(7171),
    [anon_sym_PERMISSIONSET] = ACTIONS(7171),
    [anon_sym_Permissionset] = ACTIONS(7171),
    [anon_sym_PermissionSet] = ACTIONS(7171),
    [anon_sym_permissionSet] = ACTIONS(7171),
    [anon_sym_permissionsetextension] = ACTIONS(7169),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7169),
    [anon_sym_Permissionsetextension] = ACTIONS(7169),
    [anon_sym_PermissionSetExtension] = ACTIONS(7169),
    [anon_sym_permissionSetExtension] = ACTIONS(7169),
    [sym_entitlement_keyword] = ACTIONS(7169),
    [anon_sym_pagecustomization] = ACTIONS(7169),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7169),
    [anon_sym_Pagecustomization] = ACTIONS(7169),
    [anon_sym_PageCustomization] = ACTIONS(7169),
    [anon_sym_pageCustomization] = ACTIONS(7169),
    [sym_using_keyword] = ACTIONS(7169),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7169),
    [sym_preproc_close] = ACTIONS(7169),
  },
  [STATE(2872)] = {
    [anon_sym_POUNDif] = ACTIONS(7173),
    [anon_sym_POUNDIF] = ACTIONS(7173),
    [anon_sym_POUNDIf] = ACTIONS(7173),
    [anon_sym_POUNDelif] = ACTIONS(7173),
    [anon_sym_POUNDELIF] = ACTIONS(7173),
    [anon_sym_POUNDElif] = ACTIONS(7173),
    [anon_sym_POUNDelse] = ACTIONS(7173),
    [anon_sym_POUNDELSE] = ACTIONS(7173),
    [anon_sym_POUNDElse] = ACTIONS(7173),
    [anon_sym_POUNDelse2] = ACTIONS(7173),
    [anon_sym_POUNDELSE2] = ACTIONS(7173),
    [anon_sym_POUNDElse2] = ACTIONS(7173),
    [anon_sym_POUNDendif] = ACTIONS(7173),
    [anon_sym_POUNDENDIF] = ACTIONS(7173),
    [anon_sym_POUNDEndif] = ACTIONS(7173),
    [anon_sym_POUNDendif2] = ACTIONS(7173),
    [anon_sym_POUNDENDIF2] = ACTIONS(7173),
    [anon_sym_POUNDEndif2] = ACTIONS(7173),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7175),
    [anon_sym_tableextension] = ACTIONS(7173),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7173),
    [anon_sym_Tableextension] = ACTIONS(7173),
    [anon_sym_TableExtension] = ACTIONS(7173),
    [anon_sym_tableExtension] = ACTIONS(7173),
    [sym_page_keyword] = ACTIONS(7175),
    [anon_sym_pageextension] = ACTIONS(7173),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7173),
    [anon_sym_Pageextension] = ACTIONS(7173),
    [anon_sym_PageExtension] = ACTIONS(7173),
    [anon_sym_pageExtension] = ACTIONS(7173),
    [anon_sym_codeunit] = ACTIONS(7173),
    [anon_sym_CODEUNIT] = ACTIONS(7173),
    [anon_sym_Codeunit] = ACTIONS(7173),
    [anon_sym_CodeUnit] = ACTIONS(7173),
    [anon_sym_COdeunit] = ACTIONS(7173),
    [anon_sym_codeUnit] = ACTIONS(7173),
    [sym_report_keyword] = ACTIONS(7175),
    [anon_sym_reportextension] = ACTIONS(7173),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7173),
    [anon_sym_Reportextension] = ACTIONS(7173),
    [anon_sym_ReportExtension] = ACTIONS(7173),
    [anon_sym_reportExtension] = ACTIONS(7173),
    [sym_query_keyword] = ACTIONS(7173),
    [anon_sym_xmlport] = ACTIONS(7173),
    [anon_sym_XMLPORT] = ACTIONS(7173),
    [anon_sym_Xmlport] = ACTIONS(7173),
    [anon_sym_XMLport] = ACTIONS(7173),
    [anon_sym_XMLPort] = ACTIONS(7173),
    [anon_sym_XmlPort] = ACTIONS(7173),
    [anon_sym_enum] = ACTIONS(7175),
    [anon_sym_ENUM] = ACTIONS(7175),
    [anon_sym_Enum] = ACTIONS(7175),
    [anon_sym_eNUM] = ACTIONS(7173),
    [anon_sym_eNum] = ACTIONS(7173),
    [anon_sym_ENum] = ACTIONS(7173),
    [anon_sym_enumextension] = ACTIONS(7173),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7173),
    [anon_sym_Enumextension] = ACTIONS(7173),
    [anon_sym_EnumExtension] = ACTIONS(7173),
    [anon_sym_enumExtension] = ACTIONS(7173),
    [sym_interface_keyword] = ACTIONS(7173),
    [anon_sym_controladdin] = ACTIONS(7173),
    [anon_sym_CONTROLADDIN] = ACTIONS(7173),
    [anon_sym_Controladdin] = ACTIONS(7173),
    [anon_sym_ControlAddIn] = ACTIONS(7173),
    [anon_sym_ControlAddin] = ACTIONS(7173),
    [anon_sym_controlAddIn] = ACTIONS(7173),
    [anon_sym_controlAddin] = ACTIONS(7173),
    [anon_sym_dotnet] = ACTIONS(7173),
    [anon_sym_DOTNET] = ACTIONS(7173),
    [anon_sym_Dotnet] = ACTIONS(7173),
    [anon_sym_DotNet] = ACTIONS(7173),
    [anon_sym_dotNet] = ACTIONS(7173),
    [sym_profile_keyword] = ACTIONS(7175),
    [anon_sym_profileextension] = ACTIONS(7173),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7173),
    [anon_sym_Profileextension] = ACTIONS(7173),
    [anon_sym_ProfileExtension] = ACTIONS(7173),
    [anon_sym_profileExtension] = ACTIONS(7173),
    [anon_sym_permissionset] = ACTIONS(7175),
    [anon_sym_PERMISSIONSET] = ACTIONS(7175),
    [anon_sym_Permissionset] = ACTIONS(7175),
    [anon_sym_PermissionSet] = ACTIONS(7175),
    [anon_sym_permissionSet] = ACTIONS(7175),
    [anon_sym_permissionsetextension] = ACTIONS(7173),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7173),
    [anon_sym_Permissionsetextension] = ACTIONS(7173),
    [anon_sym_PermissionSetExtension] = ACTIONS(7173),
    [anon_sym_permissionSetExtension] = ACTIONS(7173),
    [sym_entitlement_keyword] = ACTIONS(7173),
    [anon_sym_pagecustomization] = ACTIONS(7173),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7173),
    [anon_sym_Pagecustomization] = ACTIONS(7173),
    [anon_sym_PageCustomization] = ACTIONS(7173),
    [anon_sym_pageCustomization] = ACTIONS(7173),
    [sym_using_keyword] = ACTIONS(7173),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7173),
    [sym_preproc_close] = ACTIONS(7173),
  },
  [STATE(2873)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2870),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(6947),
    [anon_sym_DASH] = ACTIONS(602),
    [aux_sym_boolean_token1] = ACTIONS(602),
    [aux_sym_boolean_token2] = ACTIONS(602),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(602),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(602),
    [aux_sym_basic_type_token21] = ACTIONS(602),
    [aux_sym_basic_type_token22] = ACTIONS(602),
    [aux_sym_basic_type_token48] = ACTIONS(602),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(602),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_page_keyword] = ACTIONS(602),
    [anon_sym_codeunit] = ACTIONS(602),
    [anon_sym_CODEUNIT] = ACTIONS(602),
    [anon_sym_Codeunit] = ACTIONS(602),
    [anon_sym_CodeUnit] = ACTIONS(602),
    [anon_sym_COdeunit] = ACTIONS(602),
    [anon_sym_codeUnit] = ACTIONS(602),
    [sym_report_keyword] = ACTIONS(602),
    [sym_query_keyword] = ACTIONS(602),
    [anon_sym_xmlport] = ACTIONS(602),
    [anon_sym_XMLPORT] = ACTIONS(602),
    [anon_sym_Xmlport] = ACTIONS(602),
    [anon_sym_XMLport] = ACTIONS(602),
    [anon_sym_XMLPort] = ACTIONS(602),
    [anon_sym_XmlPort] = ACTIONS(602),
    [anon_sym_enum] = ACTIONS(602),
    [anon_sym_ENUM] = ACTIONS(602),
    [anon_sym_Enum] = ACTIONS(602),
    [anon_sym_eNUM] = ACTIONS(602),
    [anon_sym_eNum] = ACTIONS(602),
    [anon_sym_ENum] = ACTIONS(602),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(600),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(602),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
  },
  [STATE(2874)] = {
    [anon_sym_POUNDif] = ACTIONS(7177),
    [anon_sym_POUNDIF] = ACTIONS(7177),
    [anon_sym_POUNDIf] = ACTIONS(7177),
    [anon_sym_POUNDelif] = ACTIONS(7177),
    [anon_sym_POUNDELIF] = ACTIONS(7177),
    [anon_sym_POUNDElif] = ACTIONS(7177),
    [anon_sym_POUNDelse] = ACTIONS(7177),
    [anon_sym_POUNDELSE] = ACTIONS(7177),
    [anon_sym_POUNDElse] = ACTIONS(7177),
    [anon_sym_POUNDelse2] = ACTIONS(7177),
    [anon_sym_POUNDELSE2] = ACTIONS(7177),
    [anon_sym_POUNDElse2] = ACTIONS(7177),
    [anon_sym_POUNDendif] = ACTIONS(7177),
    [anon_sym_POUNDENDIF] = ACTIONS(7177),
    [anon_sym_POUNDEndif] = ACTIONS(7177),
    [anon_sym_POUNDendif2] = ACTIONS(7177),
    [anon_sym_POUNDENDIF2] = ACTIONS(7177),
    [anon_sym_POUNDEndif2] = ACTIONS(7177),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7179),
    [anon_sym_tableextension] = ACTIONS(7177),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7177),
    [anon_sym_Tableextension] = ACTIONS(7177),
    [anon_sym_TableExtension] = ACTIONS(7177),
    [anon_sym_tableExtension] = ACTIONS(7177),
    [sym_page_keyword] = ACTIONS(7179),
    [anon_sym_pageextension] = ACTIONS(7177),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7177),
    [anon_sym_Pageextension] = ACTIONS(7177),
    [anon_sym_PageExtension] = ACTIONS(7177),
    [anon_sym_pageExtension] = ACTIONS(7177),
    [anon_sym_codeunit] = ACTIONS(7177),
    [anon_sym_CODEUNIT] = ACTIONS(7177),
    [anon_sym_Codeunit] = ACTIONS(7177),
    [anon_sym_CodeUnit] = ACTIONS(7177),
    [anon_sym_COdeunit] = ACTIONS(7177),
    [anon_sym_codeUnit] = ACTIONS(7177),
    [sym_report_keyword] = ACTIONS(7179),
    [anon_sym_reportextension] = ACTIONS(7177),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7177),
    [anon_sym_Reportextension] = ACTIONS(7177),
    [anon_sym_ReportExtension] = ACTIONS(7177),
    [anon_sym_reportExtension] = ACTIONS(7177),
    [sym_query_keyword] = ACTIONS(7177),
    [anon_sym_xmlport] = ACTIONS(7177),
    [anon_sym_XMLPORT] = ACTIONS(7177),
    [anon_sym_Xmlport] = ACTIONS(7177),
    [anon_sym_XMLport] = ACTIONS(7177),
    [anon_sym_XMLPort] = ACTIONS(7177),
    [anon_sym_XmlPort] = ACTIONS(7177),
    [anon_sym_enum] = ACTIONS(7179),
    [anon_sym_ENUM] = ACTIONS(7179),
    [anon_sym_Enum] = ACTIONS(7179),
    [anon_sym_eNUM] = ACTIONS(7177),
    [anon_sym_eNum] = ACTIONS(7177),
    [anon_sym_ENum] = ACTIONS(7177),
    [anon_sym_enumextension] = ACTIONS(7177),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7177),
    [anon_sym_Enumextension] = ACTIONS(7177),
    [anon_sym_EnumExtension] = ACTIONS(7177),
    [anon_sym_enumExtension] = ACTIONS(7177),
    [sym_interface_keyword] = ACTIONS(7177),
    [anon_sym_controladdin] = ACTIONS(7177),
    [anon_sym_CONTROLADDIN] = ACTIONS(7177),
    [anon_sym_Controladdin] = ACTIONS(7177),
    [anon_sym_ControlAddIn] = ACTIONS(7177),
    [anon_sym_ControlAddin] = ACTIONS(7177),
    [anon_sym_controlAddIn] = ACTIONS(7177),
    [anon_sym_controlAddin] = ACTIONS(7177),
    [anon_sym_dotnet] = ACTIONS(7177),
    [anon_sym_DOTNET] = ACTIONS(7177),
    [anon_sym_Dotnet] = ACTIONS(7177),
    [anon_sym_DotNet] = ACTIONS(7177),
    [anon_sym_dotNet] = ACTIONS(7177),
    [sym_profile_keyword] = ACTIONS(7179),
    [anon_sym_profileextension] = ACTIONS(7177),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7177),
    [anon_sym_Profileextension] = ACTIONS(7177),
    [anon_sym_ProfileExtension] = ACTIONS(7177),
    [anon_sym_profileExtension] = ACTIONS(7177),
    [anon_sym_permissionset] = ACTIONS(7179),
    [anon_sym_PERMISSIONSET] = ACTIONS(7179),
    [anon_sym_Permissionset] = ACTIONS(7179),
    [anon_sym_PermissionSet] = ACTIONS(7179),
    [anon_sym_permissionSet] = ACTIONS(7179),
    [anon_sym_permissionsetextension] = ACTIONS(7177),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7177),
    [anon_sym_Permissionsetextension] = ACTIONS(7177),
    [anon_sym_PermissionSetExtension] = ACTIONS(7177),
    [anon_sym_permissionSetExtension] = ACTIONS(7177),
    [sym_entitlement_keyword] = ACTIONS(7177),
    [anon_sym_pagecustomization] = ACTIONS(7177),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7177),
    [anon_sym_Pagecustomization] = ACTIONS(7177),
    [anon_sym_PageCustomization] = ACTIONS(7177),
    [anon_sym_pageCustomization] = ACTIONS(7177),
    [sym_using_keyword] = ACTIONS(7177),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7177),
    [sym_preproc_close] = ACTIONS(7177),
  },
  [STATE(2875)] = {
    [aux_sym_option_member_list_repeat1] = STATE(2800),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(6947),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [anon_sym_POUNDelif] = ACTIONS(3691),
    [anon_sym_POUNDELIF] = ACTIONS(3691),
    [anon_sym_POUNDElif] = ACTIONS(3691),
    [anon_sym_POUNDelse] = ACTIONS(3691),
    [anon_sym_POUNDELSE] = ACTIONS(3691),
    [anon_sym_POUNDElse] = ACTIONS(3691),
    [anon_sym_POUNDelse2] = ACTIONS(3691),
    [anon_sym_POUNDELSE2] = ACTIONS(3691),
    [anon_sym_POUNDElse2] = ACTIONS(3691),
    [anon_sym_POUNDendif] = ACTIONS(3691),
    [anon_sym_POUNDENDIF] = ACTIONS(3691),
    [anon_sym_POUNDEndif] = ACTIONS(3691),
    [anon_sym_POUNDendif2] = ACTIONS(3691),
    [anon_sym_POUNDENDIF2] = ACTIONS(3691),
    [anon_sym_POUNDEndif2] = ACTIONS(3691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3691),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_close] = ACTIONS(3691),
  },
  [STATE(2876)] = {
    [anon_sym_POUNDif] = ACTIONS(7181),
    [anon_sym_POUNDIF] = ACTIONS(7181),
    [anon_sym_POUNDIf] = ACTIONS(7181),
    [anon_sym_POUNDelif] = ACTIONS(7181),
    [anon_sym_POUNDELIF] = ACTIONS(7181),
    [anon_sym_POUNDElif] = ACTIONS(7181),
    [anon_sym_POUNDelse] = ACTIONS(7181),
    [anon_sym_POUNDELSE] = ACTIONS(7181),
    [anon_sym_POUNDElse] = ACTIONS(7181),
    [anon_sym_POUNDelse2] = ACTIONS(7181),
    [anon_sym_POUNDELSE2] = ACTIONS(7181),
    [anon_sym_POUNDElse2] = ACTIONS(7181),
    [anon_sym_POUNDendif] = ACTIONS(7181),
    [anon_sym_POUNDENDIF] = ACTIONS(7181),
    [anon_sym_POUNDEndif] = ACTIONS(7181),
    [anon_sym_POUNDendif2] = ACTIONS(7181),
    [anon_sym_POUNDENDIF2] = ACTIONS(7181),
    [anon_sym_POUNDEndif2] = ACTIONS(7181),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7183),
    [anon_sym_tableextension] = ACTIONS(7181),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7181),
    [anon_sym_Tableextension] = ACTIONS(7181),
    [anon_sym_TableExtension] = ACTIONS(7181),
    [anon_sym_tableExtension] = ACTIONS(7181),
    [sym_page_keyword] = ACTIONS(7183),
    [anon_sym_pageextension] = ACTIONS(7181),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7181),
    [anon_sym_Pageextension] = ACTIONS(7181),
    [anon_sym_PageExtension] = ACTIONS(7181),
    [anon_sym_pageExtension] = ACTIONS(7181),
    [anon_sym_codeunit] = ACTIONS(7181),
    [anon_sym_CODEUNIT] = ACTIONS(7181),
    [anon_sym_Codeunit] = ACTIONS(7181),
    [anon_sym_CodeUnit] = ACTIONS(7181),
    [anon_sym_COdeunit] = ACTIONS(7181),
    [anon_sym_codeUnit] = ACTIONS(7181),
    [sym_report_keyword] = ACTIONS(7183),
    [anon_sym_reportextension] = ACTIONS(7181),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7181),
    [anon_sym_Reportextension] = ACTIONS(7181),
    [anon_sym_ReportExtension] = ACTIONS(7181),
    [anon_sym_reportExtension] = ACTIONS(7181),
    [sym_query_keyword] = ACTIONS(7181),
    [anon_sym_xmlport] = ACTIONS(7181),
    [anon_sym_XMLPORT] = ACTIONS(7181),
    [anon_sym_Xmlport] = ACTIONS(7181),
    [anon_sym_XMLport] = ACTIONS(7181),
    [anon_sym_XMLPort] = ACTIONS(7181),
    [anon_sym_XmlPort] = ACTIONS(7181),
    [anon_sym_enum] = ACTIONS(7183),
    [anon_sym_ENUM] = ACTIONS(7183),
    [anon_sym_Enum] = ACTIONS(7183),
    [anon_sym_eNUM] = ACTIONS(7181),
    [anon_sym_eNum] = ACTIONS(7181),
    [anon_sym_ENum] = ACTIONS(7181),
    [anon_sym_enumextension] = ACTIONS(7181),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7181),
    [anon_sym_Enumextension] = ACTIONS(7181),
    [anon_sym_EnumExtension] = ACTIONS(7181),
    [anon_sym_enumExtension] = ACTIONS(7181),
    [sym_interface_keyword] = ACTIONS(7181),
    [anon_sym_controladdin] = ACTIONS(7181),
    [anon_sym_CONTROLADDIN] = ACTIONS(7181),
    [anon_sym_Controladdin] = ACTIONS(7181),
    [anon_sym_ControlAddIn] = ACTIONS(7181),
    [anon_sym_ControlAddin] = ACTIONS(7181),
    [anon_sym_controlAddIn] = ACTIONS(7181),
    [anon_sym_controlAddin] = ACTIONS(7181),
    [anon_sym_dotnet] = ACTIONS(7181),
    [anon_sym_DOTNET] = ACTIONS(7181),
    [anon_sym_Dotnet] = ACTIONS(7181),
    [anon_sym_DotNet] = ACTIONS(7181),
    [anon_sym_dotNet] = ACTIONS(7181),
    [sym_profile_keyword] = ACTIONS(7183),
    [anon_sym_profileextension] = ACTIONS(7181),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7181),
    [anon_sym_Profileextension] = ACTIONS(7181),
    [anon_sym_ProfileExtension] = ACTIONS(7181),
    [anon_sym_profileExtension] = ACTIONS(7181),
    [anon_sym_permissionset] = ACTIONS(7183),
    [anon_sym_PERMISSIONSET] = ACTIONS(7183),
    [anon_sym_Permissionset] = ACTIONS(7183),
    [anon_sym_PermissionSet] = ACTIONS(7183),
    [anon_sym_permissionSet] = ACTIONS(7183),
    [anon_sym_permissionsetextension] = ACTIONS(7181),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7181),
    [anon_sym_Permissionsetextension] = ACTIONS(7181),
    [anon_sym_PermissionSetExtension] = ACTIONS(7181),
    [anon_sym_permissionSetExtension] = ACTIONS(7181),
    [sym_entitlement_keyword] = ACTIONS(7181),
    [anon_sym_pagecustomization] = ACTIONS(7181),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7181),
    [anon_sym_Pagecustomization] = ACTIONS(7181),
    [anon_sym_PageCustomization] = ACTIONS(7181),
    [anon_sym_pageCustomization] = ACTIONS(7181),
    [sym_using_keyword] = ACTIONS(7181),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7181),
    [sym_preproc_close] = ACTIONS(7181),
  },
  [STATE(2877)] = {
    [sym_identifier] = ACTIONS(5789),
    [anon_sym_SEMI] = ACTIONS(7185),
    [anon_sym_DASH] = ACTIONS(5793),
    [aux_sym_boolean_token1] = ACTIONS(5789),
    [aux_sym_boolean_token2] = ACTIONS(5789),
    [sym_decimal] = ACTIONS(5789),
    [anon_sym_LPAREN] = ACTIONS(5793),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5789),
    [anon_sym_LBRACK] = ACTIONS(5793),
    [aux_sym_record_type_token1] = ACTIONS(5789),
    [aux_sym_basic_type_token21] = ACTIONS(5789),
    [aux_sym_basic_type_token22] = ACTIONS(5789),
    [aux_sym_basic_type_token48] = ACTIONS(5789),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5789),
    [anon_sym_POUNDif] = ACTIONS(5793),
    [anon_sym_POUNDIF] = ACTIONS(5793),
    [anon_sym_POUNDIf] = ACTIONS(5793),
    [anon_sym_not] = ACTIONS(5789),
    [anon_sym_NOT] = ACTIONS(5789),
    [anon_sym_Not] = ACTIONS(5789),
    [anon_sym_POUNDelse] = ACTIONS(5793),
    [anon_sym_POUNDELSE] = ACTIONS(5793),
    [anon_sym_POUNDElse] = ACTIONS(5793),
    [anon_sym_POUNDelse2] = ACTIONS(5793),
    [anon_sym_POUNDELSE2] = ACTIONS(5793),
    [anon_sym_POUNDElse2] = ACTIONS(5793),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5789),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5789),
    [anon_sym_PLUS] = ACTIONS(5793),
    [sym_datetime_literal] = ACTIONS(5793),
    [sym_date_literal] = ACTIONS(5789),
    [sym_time_literal] = ACTIONS(5789),
    [sym_biginteger_literal] = ACTIONS(5793),
    [anon_sym_if] = ACTIONS(5789),
    [anon_sym_IF] = ACTIONS(5789),
    [anon_sym_If] = ACTIONS(5789),
    [anon_sym_else] = ACTIONS(5789),
    [anon_sym_ELSE] = ACTIONS(5789),
    [anon_sym_Else] = ACTIONS(5789),
    [anon_sym_case] = ACTIONS(5789),
    [anon_sym_CASE] = ACTIONS(5789),
    [anon_sym_Case] = ACTIONS(5789),
    [anon_sym_for] = ACTIONS(5789),
    [anon_sym_FOR] = ACTIONS(5789),
    [anon_sym_For] = ACTIONS(5789),
    [anon_sym_foreach] = ACTIONS(5789),
    [anon_sym_FOREACH] = ACTIONS(5789),
    [anon_sym_Foreach] = ACTIONS(5789),
    [anon_sym_while] = ACTIONS(5789),
    [anon_sym_WHILE] = ACTIONS(5789),
    [anon_sym_While] = ACTIONS(5789),
    [anon_sym_repeat] = ACTIONS(5789),
    [anon_sym_REPEAT] = ACTIONS(5789),
    [anon_sym_Repeat] = ACTIONS(5789),
    [anon_sym_until] = ACTIONS(5789),
    [anon_sym_UNTIL] = ACTIONS(5789),
    [anon_sym_Until] = ACTIONS(5789),
    [anon_sym_exit] = ACTIONS(5789),
    [anon_sym_EXIT] = ACTIONS(5789),
    [anon_sym_Exit] = ACTIONS(5789),
    [anon_sym_continue] = ACTIONS(5789),
    [anon_sym_CONTINUE] = ACTIONS(5789),
    [anon_sym_Continue] = ACTIONS(5789),
    [anon_sym_break] = ACTIONS(5789),
    [anon_sym_BREAK] = ACTIONS(5789),
    [anon_sym_Break] = ACTIONS(5789),
    [anon_sym_with] = ACTIONS(5789),
    [anon_sym_WITH] = ACTIONS(5789),
    [anon_sym_With] = ACTIONS(5789),
    [sym_asserterror_keyword] = ACTIONS(5793),
    [sym_page_keyword] = ACTIONS(5789),
    [anon_sym_codeunit] = ACTIONS(5789),
    [anon_sym_CODEUNIT] = ACTIONS(5789),
    [anon_sym_Codeunit] = ACTIONS(5789),
    [anon_sym_CodeUnit] = ACTIONS(5789),
    [anon_sym_COdeunit] = ACTIONS(5789),
    [anon_sym_codeUnit] = ACTIONS(5789),
    [sym_report_keyword] = ACTIONS(5789),
    [sym_query_keyword] = ACTIONS(5789),
    [anon_sym_xmlport] = ACTIONS(5789),
    [anon_sym_XMLPORT] = ACTIONS(5789),
    [anon_sym_Xmlport] = ACTIONS(5789),
    [anon_sym_XMLport] = ACTIONS(5789),
    [anon_sym_XMLPort] = ACTIONS(5789),
    [anon_sym_XmlPort] = ACTIONS(5789),
    [anon_sym_enum] = ACTIONS(5789),
    [anon_sym_ENUM] = ACTIONS(5789),
    [anon_sym_Enum] = ACTIONS(5789),
    [anon_sym_eNUM] = ACTIONS(5789),
    [anon_sym_eNum] = ACTIONS(5789),
    [anon_sym_ENum] = ACTIONS(5789),
    [sym_quoted_identifier] = ACTIONS(5793),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5793),
    [sym_verbatim_string] = ACTIONS(5793),
    [sym_integer] = ACTIONS(5789),
    [sym_continue_as_identifier] = ACTIONS(5793),
    [sym_preproc_open] = ACTIONS(5793),
  },
  [STATE(2878)] = {
    [sym_identifier] = ACTIONS(6010),
    [anon_sym_SEMI] = ACTIONS(6012),
    [anon_sym_DASH] = ACTIONS(6012),
    [aux_sym_boolean_token1] = ACTIONS(6010),
    [aux_sym_boolean_token2] = ACTIONS(6010),
    [sym_decimal] = ACTIONS(6010),
    [anon_sym_LPAREN] = ACTIONS(6012),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6010),
    [anon_sym_LBRACK] = ACTIONS(6012),
    [aux_sym_record_type_token1] = ACTIONS(6010),
    [aux_sym_basic_type_token21] = ACTIONS(6010),
    [aux_sym_basic_type_token22] = ACTIONS(6010),
    [aux_sym_basic_type_token48] = ACTIONS(6010),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6010),
    [anon_sym_POUNDif] = ACTIONS(6012),
    [anon_sym_POUNDIF] = ACTIONS(6012),
    [anon_sym_POUNDIf] = ACTIONS(6012),
    [anon_sym_not] = ACTIONS(6010),
    [anon_sym_NOT] = ACTIONS(6010),
    [anon_sym_Not] = ACTIONS(6010),
    [anon_sym_POUNDelse] = ACTIONS(6012),
    [anon_sym_POUNDELSE] = ACTIONS(6012),
    [anon_sym_POUNDElse] = ACTIONS(6012),
    [anon_sym_POUNDelse2] = ACTIONS(6012),
    [anon_sym_POUNDELSE2] = ACTIONS(6012),
    [anon_sym_POUNDElse2] = ACTIONS(6012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6010),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6010),
    [anon_sym_PLUS] = ACTIONS(6012),
    [sym_datetime_literal] = ACTIONS(6012),
    [sym_date_literal] = ACTIONS(6010),
    [sym_time_literal] = ACTIONS(6010),
    [sym_biginteger_literal] = ACTIONS(6012),
    [anon_sym_if] = ACTIONS(6010),
    [anon_sym_IF] = ACTIONS(6010),
    [anon_sym_If] = ACTIONS(6010),
    [anon_sym_else] = ACTIONS(6010),
    [anon_sym_ELSE] = ACTIONS(6010),
    [anon_sym_Else] = ACTIONS(6010),
    [anon_sym_case] = ACTIONS(6010),
    [anon_sym_CASE] = ACTIONS(6010),
    [anon_sym_Case] = ACTIONS(6010),
    [anon_sym_for] = ACTIONS(6010),
    [anon_sym_FOR] = ACTIONS(6010),
    [anon_sym_For] = ACTIONS(6010),
    [anon_sym_foreach] = ACTIONS(6010),
    [anon_sym_FOREACH] = ACTIONS(6010),
    [anon_sym_Foreach] = ACTIONS(6010),
    [anon_sym_while] = ACTIONS(6010),
    [anon_sym_WHILE] = ACTIONS(6010),
    [anon_sym_While] = ACTIONS(6010),
    [anon_sym_repeat] = ACTIONS(6010),
    [anon_sym_REPEAT] = ACTIONS(6010),
    [anon_sym_Repeat] = ACTIONS(6010),
    [anon_sym_until] = ACTIONS(6010),
    [anon_sym_UNTIL] = ACTIONS(6010),
    [anon_sym_Until] = ACTIONS(6010),
    [anon_sym_exit] = ACTIONS(6010),
    [anon_sym_EXIT] = ACTIONS(6010),
    [anon_sym_Exit] = ACTIONS(6010),
    [anon_sym_continue] = ACTIONS(6010),
    [anon_sym_CONTINUE] = ACTIONS(6010),
    [anon_sym_Continue] = ACTIONS(6010),
    [anon_sym_break] = ACTIONS(6010),
    [anon_sym_BREAK] = ACTIONS(6010),
    [anon_sym_Break] = ACTIONS(6010),
    [anon_sym_with] = ACTIONS(6010),
    [anon_sym_WITH] = ACTIONS(6010),
    [anon_sym_With] = ACTIONS(6010),
    [sym_asserterror_keyword] = ACTIONS(6012),
    [sym_page_keyword] = ACTIONS(6010),
    [anon_sym_codeunit] = ACTIONS(6010),
    [anon_sym_CODEUNIT] = ACTIONS(6010),
    [anon_sym_Codeunit] = ACTIONS(6010),
    [anon_sym_CodeUnit] = ACTIONS(6010),
    [anon_sym_COdeunit] = ACTIONS(6010),
    [anon_sym_codeUnit] = ACTIONS(6010),
    [sym_report_keyword] = ACTIONS(6010),
    [sym_query_keyword] = ACTIONS(6010),
    [anon_sym_xmlport] = ACTIONS(6010),
    [anon_sym_XMLPORT] = ACTIONS(6010),
    [anon_sym_Xmlport] = ACTIONS(6010),
    [anon_sym_XMLport] = ACTIONS(6010),
    [anon_sym_XMLPort] = ACTIONS(6010),
    [anon_sym_XmlPort] = ACTIONS(6010),
    [anon_sym_enum] = ACTIONS(6010),
    [anon_sym_ENUM] = ACTIONS(6010),
    [anon_sym_Enum] = ACTIONS(6010),
    [anon_sym_eNUM] = ACTIONS(6010),
    [anon_sym_eNum] = ACTIONS(6010),
    [anon_sym_ENum] = ACTIONS(6010),
    [sym_quoted_identifier] = ACTIONS(6012),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6012),
    [sym_verbatim_string] = ACTIONS(6012),
    [sym_integer] = ACTIONS(6010),
    [sym_continue_as_identifier] = ACTIONS(6012),
    [sym_preproc_open] = ACTIONS(6012),
  },
  [STATE(2879)] = {
    [sym_identifier] = ACTIONS(6014),
    [anon_sym_SEMI] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6016),
    [aux_sym_boolean_token1] = ACTIONS(6014),
    [aux_sym_boolean_token2] = ACTIONS(6014),
    [sym_decimal] = ACTIONS(6014),
    [anon_sym_LPAREN] = ACTIONS(6016),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6014),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [aux_sym_record_type_token1] = ACTIONS(6014),
    [aux_sym_basic_type_token21] = ACTIONS(6014),
    [aux_sym_basic_type_token22] = ACTIONS(6014),
    [aux_sym_basic_type_token48] = ACTIONS(6014),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6014),
    [anon_sym_POUNDif] = ACTIONS(6016),
    [anon_sym_POUNDIF] = ACTIONS(6016),
    [anon_sym_POUNDIf] = ACTIONS(6016),
    [anon_sym_not] = ACTIONS(6014),
    [anon_sym_NOT] = ACTIONS(6014),
    [anon_sym_Not] = ACTIONS(6014),
    [anon_sym_POUNDelse] = ACTIONS(6016),
    [anon_sym_POUNDELSE] = ACTIONS(6016),
    [anon_sym_POUNDElse] = ACTIONS(6016),
    [anon_sym_POUNDelse2] = ACTIONS(6016),
    [anon_sym_POUNDELSE2] = ACTIONS(6016),
    [anon_sym_POUNDElse2] = ACTIONS(6016),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6014),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6014),
    [anon_sym_PLUS] = ACTIONS(6016),
    [sym_datetime_literal] = ACTIONS(6016),
    [sym_date_literal] = ACTIONS(6014),
    [sym_time_literal] = ACTIONS(6014),
    [sym_biginteger_literal] = ACTIONS(6016),
    [anon_sym_if] = ACTIONS(6014),
    [anon_sym_IF] = ACTIONS(6014),
    [anon_sym_If] = ACTIONS(6014),
    [anon_sym_else] = ACTIONS(6014),
    [anon_sym_ELSE] = ACTIONS(6014),
    [anon_sym_Else] = ACTIONS(6014),
    [anon_sym_case] = ACTIONS(6014),
    [anon_sym_CASE] = ACTIONS(6014),
    [anon_sym_Case] = ACTIONS(6014),
    [anon_sym_for] = ACTIONS(6014),
    [anon_sym_FOR] = ACTIONS(6014),
    [anon_sym_For] = ACTIONS(6014),
    [anon_sym_foreach] = ACTIONS(6014),
    [anon_sym_FOREACH] = ACTIONS(6014),
    [anon_sym_Foreach] = ACTIONS(6014),
    [anon_sym_while] = ACTIONS(6014),
    [anon_sym_WHILE] = ACTIONS(6014),
    [anon_sym_While] = ACTIONS(6014),
    [anon_sym_repeat] = ACTIONS(6014),
    [anon_sym_REPEAT] = ACTIONS(6014),
    [anon_sym_Repeat] = ACTIONS(6014),
    [anon_sym_until] = ACTIONS(6014),
    [anon_sym_UNTIL] = ACTIONS(6014),
    [anon_sym_Until] = ACTIONS(6014),
    [anon_sym_exit] = ACTIONS(6014),
    [anon_sym_EXIT] = ACTIONS(6014),
    [anon_sym_Exit] = ACTIONS(6014),
    [anon_sym_continue] = ACTIONS(6014),
    [anon_sym_CONTINUE] = ACTIONS(6014),
    [anon_sym_Continue] = ACTIONS(6014),
    [anon_sym_break] = ACTIONS(6014),
    [anon_sym_BREAK] = ACTIONS(6014),
    [anon_sym_Break] = ACTIONS(6014),
    [anon_sym_with] = ACTIONS(6014),
    [anon_sym_WITH] = ACTIONS(6014),
    [anon_sym_With] = ACTIONS(6014),
    [sym_asserterror_keyword] = ACTIONS(6016),
    [sym_page_keyword] = ACTIONS(6014),
    [anon_sym_codeunit] = ACTIONS(6014),
    [anon_sym_CODEUNIT] = ACTIONS(6014),
    [anon_sym_Codeunit] = ACTIONS(6014),
    [anon_sym_CodeUnit] = ACTIONS(6014),
    [anon_sym_COdeunit] = ACTIONS(6014),
    [anon_sym_codeUnit] = ACTIONS(6014),
    [sym_report_keyword] = ACTIONS(6014),
    [sym_query_keyword] = ACTIONS(6014),
    [anon_sym_xmlport] = ACTIONS(6014),
    [anon_sym_XMLPORT] = ACTIONS(6014),
    [anon_sym_Xmlport] = ACTIONS(6014),
    [anon_sym_XMLport] = ACTIONS(6014),
    [anon_sym_XMLPort] = ACTIONS(6014),
    [anon_sym_XmlPort] = ACTIONS(6014),
    [anon_sym_enum] = ACTIONS(6014),
    [anon_sym_ENUM] = ACTIONS(6014),
    [anon_sym_Enum] = ACTIONS(6014),
    [anon_sym_eNUM] = ACTIONS(6014),
    [anon_sym_eNum] = ACTIONS(6014),
    [anon_sym_ENum] = ACTIONS(6014),
    [sym_quoted_identifier] = ACTIONS(6016),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6016),
    [sym_verbatim_string] = ACTIONS(6016),
    [sym_integer] = ACTIONS(6014),
    [sym_continue_as_identifier] = ACTIONS(6016),
    [sym_preproc_open] = ACTIONS(6016),
  },
  [STATE(2880)] = {
    [sym_identifier] = ACTIONS(6018),
    [anon_sym_SEMI] = ACTIONS(6020),
    [anon_sym_DASH] = ACTIONS(6020),
    [aux_sym_boolean_token1] = ACTIONS(6018),
    [aux_sym_boolean_token2] = ACTIONS(6018),
    [sym_decimal] = ACTIONS(6018),
    [anon_sym_LPAREN] = ACTIONS(6020),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6018),
    [anon_sym_LBRACK] = ACTIONS(6020),
    [aux_sym_record_type_token1] = ACTIONS(6018),
    [aux_sym_basic_type_token21] = ACTIONS(6018),
    [aux_sym_basic_type_token22] = ACTIONS(6018),
    [aux_sym_basic_type_token48] = ACTIONS(6018),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6018),
    [anon_sym_POUNDif] = ACTIONS(6020),
    [anon_sym_POUNDIF] = ACTIONS(6020),
    [anon_sym_POUNDIf] = ACTIONS(6020),
    [anon_sym_not] = ACTIONS(6018),
    [anon_sym_NOT] = ACTIONS(6018),
    [anon_sym_Not] = ACTIONS(6018),
    [anon_sym_POUNDelse] = ACTIONS(6020),
    [anon_sym_POUNDELSE] = ACTIONS(6020),
    [anon_sym_POUNDElse] = ACTIONS(6020),
    [anon_sym_POUNDelse2] = ACTIONS(6020),
    [anon_sym_POUNDELSE2] = ACTIONS(6020),
    [anon_sym_POUNDElse2] = ACTIONS(6020),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6018),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6020),
    [sym_datetime_literal] = ACTIONS(6020),
    [sym_date_literal] = ACTIONS(6018),
    [sym_time_literal] = ACTIONS(6018),
    [sym_biginteger_literal] = ACTIONS(6020),
    [anon_sym_if] = ACTIONS(6018),
    [anon_sym_IF] = ACTIONS(6018),
    [anon_sym_If] = ACTIONS(6018),
    [anon_sym_else] = ACTIONS(6018),
    [anon_sym_ELSE] = ACTIONS(6018),
    [anon_sym_Else] = ACTIONS(6018),
    [anon_sym_case] = ACTIONS(6018),
    [anon_sym_CASE] = ACTIONS(6018),
    [anon_sym_Case] = ACTIONS(6018),
    [anon_sym_for] = ACTIONS(6018),
    [anon_sym_FOR] = ACTIONS(6018),
    [anon_sym_For] = ACTIONS(6018),
    [anon_sym_foreach] = ACTIONS(6018),
    [anon_sym_FOREACH] = ACTIONS(6018),
    [anon_sym_Foreach] = ACTIONS(6018),
    [anon_sym_while] = ACTIONS(6018),
    [anon_sym_WHILE] = ACTIONS(6018),
    [anon_sym_While] = ACTIONS(6018),
    [anon_sym_repeat] = ACTIONS(6018),
    [anon_sym_REPEAT] = ACTIONS(6018),
    [anon_sym_Repeat] = ACTIONS(6018),
    [anon_sym_until] = ACTIONS(6018),
    [anon_sym_UNTIL] = ACTIONS(6018),
    [anon_sym_Until] = ACTIONS(6018),
    [anon_sym_exit] = ACTIONS(6018),
    [anon_sym_EXIT] = ACTIONS(6018),
    [anon_sym_Exit] = ACTIONS(6018),
    [anon_sym_continue] = ACTIONS(6018),
    [anon_sym_CONTINUE] = ACTIONS(6018),
    [anon_sym_Continue] = ACTIONS(6018),
    [anon_sym_break] = ACTIONS(6018),
    [anon_sym_BREAK] = ACTIONS(6018),
    [anon_sym_Break] = ACTIONS(6018),
    [anon_sym_with] = ACTIONS(6018),
    [anon_sym_WITH] = ACTIONS(6018),
    [anon_sym_With] = ACTIONS(6018),
    [sym_asserterror_keyword] = ACTIONS(6020),
    [sym_page_keyword] = ACTIONS(6018),
    [anon_sym_codeunit] = ACTIONS(6018),
    [anon_sym_CODEUNIT] = ACTIONS(6018),
    [anon_sym_Codeunit] = ACTIONS(6018),
    [anon_sym_CodeUnit] = ACTIONS(6018),
    [anon_sym_COdeunit] = ACTIONS(6018),
    [anon_sym_codeUnit] = ACTIONS(6018),
    [sym_report_keyword] = ACTIONS(6018),
    [sym_query_keyword] = ACTIONS(6018),
    [anon_sym_xmlport] = ACTIONS(6018),
    [anon_sym_XMLPORT] = ACTIONS(6018),
    [anon_sym_Xmlport] = ACTIONS(6018),
    [anon_sym_XMLport] = ACTIONS(6018),
    [anon_sym_XMLPort] = ACTIONS(6018),
    [anon_sym_XmlPort] = ACTIONS(6018),
    [anon_sym_enum] = ACTIONS(6018),
    [anon_sym_ENUM] = ACTIONS(6018),
    [anon_sym_Enum] = ACTIONS(6018),
    [anon_sym_eNUM] = ACTIONS(6018),
    [anon_sym_eNum] = ACTIONS(6018),
    [anon_sym_ENum] = ACTIONS(6018),
    [sym_quoted_identifier] = ACTIONS(6020),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6020),
    [sym_verbatim_string] = ACTIONS(6020),
    [sym_integer] = ACTIONS(6018),
    [sym_continue_as_identifier] = ACTIONS(6020),
    [sym_preproc_open] = ACTIONS(6020),
  },
  [STATE(2881)] = {
    [sym_identifier] = ACTIONS(6022),
    [anon_sym_SEMI] = ACTIONS(6024),
    [anon_sym_DASH] = ACTIONS(6024),
    [aux_sym_boolean_token1] = ACTIONS(6022),
    [aux_sym_boolean_token2] = ACTIONS(6022),
    [sym_decimal] = ACTIONS(6022),
    [anon_sym_LPAREN] = ACTIONS(6024),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6022),
    [anon_sym_LBRACK] = ACTIONS(6024),
    [aux_sym_record_type_token1] = ACTIONS(6022),
    [aux_sym_basic_type_token21] = ACTIONS(6022),
    [aux_sym_basic_type_token22] = ACTIONS(6022),
    [aux_sym_basic_type_token48] = ACTIONS(6022),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6022),
    [anon_sym_POUNDif] = ACTIONS(6024),
    [anon_sym_POUNDIF] = ACTIONS(6024),
    [anon_sym_POUNDIf] = ACTIONS(6024),
    [anon_sym_not] = ACTIONS(6022),
    [anon_sym_NOT] = ACTIONS(6022),
    [anon_sym_Not] = ACTIONS(6022),
    [anon_sym_POUNDelse] = ACTIONS(6024),
    [anon_sym_POUNDELSE] = ACTIONS(6024),
    [anon_sym_POUNDElse] = ACTIONS(6024),
    [anon_sym_POUNDelse2] = ACTIONS(6024),
    [anon_sym_POUNDELSE2] = ACTIONS(6024),
    [anon_sym_POUNDElse2] = ACTIONS(6024),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6022),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6022),
    [anon_sym_PLUS] = ACTIONS(6024),
    [sym_datetime_literal] = ACTIONS(6024),
    [sym_date_literal] = ACTIONS(6022),
    [sym_time_literal] = ACTIONS(6022),
    [sym_biginteger_literal] = ACTIONS(6024),
    [anon_sym_if] = ACTIONS(6022),
    [anon_sym_IF] = ACTIONS(6022),
    [anon_sym_If] = ACTIONS(6022),
    [anon_sym_else] = ACTIONS(6022),
    [anon_sym_ELSE] = ACTIONS(6022),
    [anon_sym_Else] = ACTIONS(6022),
    [anon_sym_case] = ACTIONS(6022),
    [anon_sym_CASE] = ACTIONS(6022),
    [anon_sym_Case] = ACTIONS(6022),
    [anon_sym_for] = ACTIONS(6022),
    [anon_sym_FOR] = ACTIONS(6022),
    [anon_sym_For] = ACTIONS(6022),
    [anon_sym_foreach] = ACTIONS(6022),
    [anon_sym_FOREACH] = ACTIONS(6022),
    [anon_sym_Foreach] = ACTIONS(6022),
    [anon_sym_while] = ACTIONS(6022),
    [anon_sym_WHILE] = ACTIONS(6022),
    [anon_sym_While] = ACTIONS(6022),
    [anon_sym_repeat] = ACTIONS(6022),
    [anon_sym_REPEAT] = ACTIONS(6022),
    [anon_sym_Repeat] = ACTIONS(6022),
    [anon_sym_until] = ACTIONS(6022),
    [anon_sym_UNTIL] = ACTIONS(6022),
    [anon_sym_Until] = ACTIONS(6022),
    [anon_sym_exit] = ACTIONS(6022),
    [anon_sym_EXIT] = ACTIONS(6022),
    [anon_sym_Exit] = ACTIONS(6022),
    [anon_sym_continue] = ACTIONS(6022),
    [anon_sym_CONTINUE] = ACTIONS(6022),
    [anon_sym_Continue] = ACTIONS(6022),
    [anon_sym_break] = ACTIONS(6022),
    [anon_sym_BREAK] = ACTIONS(6022),
    [anon_sym_Break] = ACTIONS(6022),
    [anon_sym_with] = ACTIONS(6022),
    [anon_sym_WITH] = ACTIONS(6022),
    [anon_sym_With] = ACTIONS(6022),
    [sym_asserterror_keyword] = ACTIONS(6024),
    [sym_page_keyword] = ACTIONS(6022),
    [anon_sym_codeunit] = ACTIONS(6022),
    [anon_sym_CODEUNIT] = ACTIONS(6022),
    [anon_sym_Codeunit] = ACTIONS(6022),
    [anon_sym_CodeUnit] = ACTIONS(6022),
    [anon_sym_COdeunit] = ACTIONS(6022),
    [anon_sym_codeUnit] = ACTIONS(6022),
    [sym_report_keyword] = ACTIONS(6022),
    [sym_query_keyword] = ACTIONS(6022),
    [anon_sym_xmlport] = ACTIONS(6022),
    [anon_sym_XMLPORT] = ACTIONS(6022),
    [anon_sym_Xmlport] = ACTIONS(6022),
    [anon_sym_XMLport] = ACTIONS(6022),
    [anon_sym_XMLPort] = ACTIONS(6022),
    [anon_sym_XmlPort] = ACTIONS(6022),
    [anon_sym_enum] = ACTIONS(6022),
    [anon_sym_ENUM] = ACTIONS(6022),
    [anon_sym_Enum] = ACTIONS(6022),
    [anon_sym_eNUM] = ACTIONS(6022),
    [anon_sym_eNum] = ACTIONS(6022),
    [anon_sym_ENum] = ACTIONS(6022),
    [sym_quoted_identifier] = ACTIONS(6024),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6024),
    [sym_verbatim_string] = ACTIONS(6024),
    [sym_integer] = ACTIONS(6022),
    [sym_continue_as_identifier] = ACTIONS(6024),
    [sym_preproc_open] = ACTIONS(6024),
  },
  [STATE(2882)] = {
    [sym_identifier] = ACTIONS(6026),
    [anon_sym_SEMI] = ACTIONS(6028),
    [anon_sym_DASH] = ACTIONS(6028),
    [aux_sym_boolean_token1] = ACTIONS(6026),
    [aux_sym_boolean_token2] = ACTIONS(6026),
    [sym_decimal] = ACTIONS(6026),
    [anon_sym_LPAREN] = ACTIONS(6028),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6026),
    [anon_sym_LBRACK] = ACTIONS(6028),
    [aux_sym_record_type_token1] = ACTIONS(6026),
    [aux_sym_basic_type_token21] = ACTIONS(6026),
    [aux_sym_basic_type_token22] = ACTIONS(6026),
    [aux_sym_basic_type_token48] = ACTIONS(6026),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6026),
    [anon_sym_POUNDif] = ACTIONS(6028),
    [anon_sym_POUNDIF] = ACTIONS(6028),
    [anon_sym_POUNDIf] = ACTIONS(6028),
    [anon_sym_not] = ACTIONS(6026),
    [anon_sym_NOT] = ACTIONS(6026),
    [anon_sym_Not] = ACTIONS(6026),
    [anon_sym_POUNDelse] = ACTIONS(6028),
    [anon_sym_POUNDELSE] = ACTIONS(6028),
    [anon_sym_POUNDElse] = ACTIONS(6028),
    [anon_sym_POUNDelse2] = ACTIONS(6028),
    [anon_sym_POUNDELSE2] = ACTIONS(6028),
    [anon_sym_POUNDElse2] = ACTIONS(6028),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6026),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6026),
    [anon_sym_PLUS] = ACTIONS(6028),
    [sym_datetime_literal] = ACTIONS(6028),
    [sym_date_literal] = ACTIONS(6026),
    [sym_time_literal] = ACTIONS(6026),
    [sym_biginteger_literal] = ACTIONS(6028),
    [anon_sym_if] = ACTIONS(6026),
    [anon_sym_IF] = ACTIONS(6026),
    [anon_sym_If] = ACTIONS(6026),
    [anon_sym_else] = ACTIONS(6026),
    [anon_sym_ELSE] = ACTIONS(6026),
    [anon_sym_Else] = ACTIONS(6026),
    [anon_sym_case] = ACTIONS(6026),
    [anon_sym_CASE] = ACTIONS(6026),
    [anon_sym_Case] = ACTIONS(6026),
    [anon_sym_for] = ACTIONS(6026),
    [anon_sym_FOR] = ACTIONS(6026),
    [anon_sym_For] = ACTIONS(6026),
    [anon_sym_foreach] = ACTIONS(6026),
    [anon_sym_FOREACH] = ACTIONS(6026),
    [anon_sym_Foreach] = ACTIONS(6026),
    [anon_sym_while] = ACTIONS(6026),
    [anon_sym_WHILE] = ACTIONS(6026),
    [anon_sym_While] = ACTIONS(6026),
    [anon_sym_repeat] = ACTIONS(6026),
    [anon_sym_REPEAT] = ACTIONS(6026),
    [anon_sym_Repeat] = ACTIONS(6026),
    [anon_sym_until] = ACTIONS(6026),
    [anon_sym_UNTIL] = ACTIONS(6026),
    [anon_sym_Until] = ACTIONS(6026),
    [anon_sym_exit] = ACTIONS(6026),
    [anon_sym_EXIT] = ACTIONS(6026),
    [anon_sym_Exit] = ACTIONS(6026),
    [anon_sym_continue] = ACTIONS(6026),
    [anon_sym_CONTINUE] = ACTIONS(6026),
    [anon_sym_Continue] = ACTIONS(6026),
    [anon_sym_break] = ACTIONS(6026),
    [anon_sym_BREAK] = ACTIONS(6026),
    [anon_sym_Break] = ACTIONS(6026),
    [anon_sym_with] = ACTIONS(6026),
    [anon_sym_WITH] = ACTIONS(6026),
    [anon_sym_With] = ACTIONS(6026),
    [sym_asserterror_keyword] = ACTIONS(6028),
    [sym_page_keyword] = ACTIONS(6026),
    [anon_sym_codeunit] = ACTIONS(6026),
    [anon_sym_CODEUNIT] = ACTIONS(6026),
    [anon_sym_Codeunit] = ACTIONS(6026),
    [anon_sym_CodeUnit] = ACTIONS(6026),
    [anon_sym_COdeunit] = ACTIONS(6026),
    [anon_sym_codeUnit] = ACTIONS(6026),
    [sym_report_keyword] = ACTIONS(6026),
    [sym_query_keyword] = ACTIONS(6026),
    [anon_sym_xmlport] = ACTIONS(6026),
    [anon_sym_XMLPORT] = ACTIONS(6026),
    [anon_sym_Xmlport] = ACTIONS(6026),
    [anon_sym_XMLport] = ACTIONS(6026),
    [anon_sym_XMLPort] = ACTIONS(6026),
    [anon_sym_XmlPort] = ACTIONS(6026),
    [anon_sym_enum] = ACTIONS(6026),
    [anon_sym_ENUM] = ACTIONS(6026),
    [anon_sym_Enum] = ACTIONS(6026),
    [anon_sym_eNUM] = ACTIONS(6026),
    [anon_sym_eNum] = ACTIONS(6026),
    [anon_sym_ENum] = ACTIONS(6026),
    [sym_quoted_identifier] = ACTIONS(6028),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6028),
    [sym_verbatim_string] = ACTIONS(6028),
    [sym_integer] = ACTIONS(6026),
    [sym_continue_as_identifier] = ACTIONS(6028),
    [sym_preproc_open] = ACTIONS(6028),
  },
  [STATE(2883)] = {
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6040),
    [anon_sym_DASH] = ACTIONS(6040),
    [aux_sym_boolean_token1] = ACTIONS(6038),
    [aux_sym_boolean_token2] = ACTIONS(6038),
    [sym_decimal] = ACTIONS(6038),
    [anon_sym_LPAREN] = ACTIONS(6040),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6038),
    [anon_sym_LBRACK] = ACTIONS(6040),
    [aux_sym_record_type_token1] = ACTIONS(6038),
    [aux_sym_basic_type_token21] = ACTIONS(6038),
    [aux_sym_basic_type_token22] = ACTIONS(6038),
    [aux_sym_basic_type_token48] = ACTIONS(6038),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6038),
    [anon_sym_POUNDif] = ACTIONS(6040),
    [anon_sym_POUNDIF] = ACTIONS(6040),
    [anon_sym_POUNDIf] = ACTIONS(6040),
    [anon_sym_not] = ACTIONS(6038),
    [anon_sym_NOT] = ACTIONS(6038),
    [anon_sym_Not] = ACTIONS(6038),
    [anon_sym_POUNDelse] = ACTIONS(6040),
    [anon_sym_POUNDELSE] = ACTIONS(6040),
    [anon_sym_POUNDElse] = ACTIONS(6040),
    [anon_sym_POUNDelse2] = ACTIONS(6040),
    [anon_sym_POUNDELSE2] = ACTIONS(6040),
    [anon_sym_POUNDElse2] = ACTIONS(6040),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6038),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6038),
    [anon_sym_PLUS] = ACTIONS(6040),
    [sym_datetime_literal] = ACTIONS(6040),
    [sym_date_literal] = ACTIONS(6038),
    [sym_time_literal] = ACTIONS(6038),
    [sym_biginteger_literal] = ACTIONS(6040),
    [anon_sym_if] = ACTIONS(6038),
    [anon_sym_IF] = ACTIONS(6038),
    [anon_sym_If] = ACTIONS(6038),
    [anon_sym_else] = ACTIONS(6038),
    [anon_sym_ELSE] = ACTIONS(6038),
    [anon_sym_Else] = ACTIONS(6038),
    [anon_sym_case] = ACTIONS(6038),
    [anon_sym_CASE] = ACTIONS(6038),
    [anon_sym_Case] = ACTIONS(6038),
    [anon_sym_for] = ACTIONS(6038),
    [anon_sym_FOR] = ACTIONS(6038),
    [anon_sym_For] = ACTIONS(6038),
    [anon_sym_foreach] = ACTIONS(6038),
    [anon_sym_FOREACH] = ACTIONS(6038),
    [anon_sym_Foreach] = ACTIONS(6038),
    [anon_sym_while] = ACTIONS(6038),
    [anon_sym_WHILE] = ACTIONS(6038),
    [anon_sym_While] = ACTIONS(6038),
    [anon_sym_repeat] = ACTIONS(6038),
    [anon_sym_REPEAT] = ACTIONS(6038),
    [anon_sym_Repeat] = ACTIONS(6038),
    [anon_sym_until] = ACTIONS(6038),
    [anon_sym_UNTIL] = ACTIONS(6038),
    [anon_sym_Until] = ACTIONS(6038),
    [anon_sym_exit] = ACTIONS(6038),
    [anon_sym_EXIT] = ACTIONS(6038),
    [anon_sym_Exit] = ACTIONS(6038),
    [anon_sym_continue] = ACTIONS(6038),
    [anon_sym_CONTINUE] = ACTIONS(6038),
    [anon_sym_Continue] = ACTIONS(6038),
    [anon_sym_break] = ACTIONS(6038),
    [anon_sym_BREAK] = ACTIONS(6038),
    [anon_sym_Break] = ACTIONS(6038),
    [anon_sym_with] = ACTIONS(6038),
    [anon_sym_WITH] = ACTIONS(6038),
    [anon_sym_With] = ACTIONS(6038),
    [sym_asserterror_keyword] = ACTIONS(6040),
    [sym_page_keyword] = ACTIONS(6038),
    [anon_sym_codeunit] = ACTIONS(6038),
    [anon_sym_CODEUNIT] = ACTIONS(6038),
    [anon_sym_Codeunit] = ACTIONS(6038),
    [anon_sym_CodeUnit] = ACTIONS(6038),
    [anon_sym_COdeunit] = ACTIONS(6038),
    [anon_sym_codeUnit] = ACTIONS(6038),
    [sym_report_keyword] = ACTIONS(6038),
    [sym_query_keyword] = ACTIONS(6038),
    [anon_sym_xmlport] = ACTIONS(6038),
    [anon_sym_XMLPORT] = ACTIONS(6038),
    [anon_sym_Xmlport] = ACTIONS(6038),
    [anon_sym_XMLport] = ACTIONS(6038),
    [anon_sym_XMLPort] = ACTIONS(6038),
    [anon_sym_XmlPort] = ACTIONS(6038),
    [anon_sym_enum] = ACTIONS(6038),
    [anon_sym_ENUM] = ACTIONS(6038),
    [anon_sym_Enum] = ACTIONS(6038),
    [anon_sym_eNUM] = ACTIONS(6038),
    [anon_sym_eNum] = ACTIONS(6038),
    [anon_sym_ENum] = ACTIONS(6038),
    [sym_quoted_identifier] = ACTIONS(6040),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6040),
    [sym_verbatim_string] = ACTIONS(6040),
    [sym_integer] = ACTIONS(6038),
    [sym_continue_as_identifier] = ACTIONS(6040),
    [sym_preproc_open] = ACTIONS(6040),
  },
  [STATE(2884)] = {
    [sym_identifier] = ACTIONS(6046),
    [anon_sym_SEMI] = ACTIONS(6048),
    [anon_sym_DASH] = ACTIONS(6048),
    [aux_sym_boolean_token1] = ACTIONS(6046),
    [aux_sym_boolean_token2] = ACTIONS(6046),
    [sym_decimal] = ACTIONS(6046),
    [anon_sym_LPAREN] = ACTIONS(6048),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6046),
    [anon_sym_LBRACK] = ACTIONS(6048),
    [aux_sym_record_type_token1] = ACTIONS(6046),
    [aux_sym_basic_type_token21] = ACTIONS(6046),
    [aux_sym_basic_type_token22] = ACTIONS(6046),
    [aux_sym_basic_type_token48] = ACTIONS(6046),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6046),
    [anon_sym_POUNDif] = ACTIONS(6048),
    [anon_sym_POUNDIF] = ACTIONS(6048),
    [anon_sym_POUNDIf] = ACTIONS(6048),
    [anon_sym_not] = ACTIONS(6046),
    [anon_sym_NOT] = ACTIONS(6046),
    [anon_sym_Not] = ACTIONS(6046),
    [anon_sym_POUNDelse] = ACTIONS(6048),
    [anon_sym_POUNDELSE] = ACTIONS(6048),
    [anon_sym_POUNDElse] = ACTIONS(6048),
    [anon_sym_POUNDelse2] = ACTIONS(6048),
    [anon_sym_POUNDELSE2] = ACTIONS(6048),
    [anon_sym_POUNDElse2] = ACTIONS(6048),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6046),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6046),
    [anon_sym_PLUS] = ACTIONS(6048),
    [sym_datetime_literal] = ACTIONS(6048),
    [sym_date_literal] = ACTIONS(6046),
    [sym_time_literal] = ACTIONS(6046),
    [sym_biginteger_literal] = ACTIONS(6048),
    [anon_sym_if] = ACTIONS(6046),
    [anon_sym_IF] = ACTIONS(6046),
    [anon_sym_If] = ACTIONS(6046),
    [anon_sym_else] = ACTIONS(6046),
    [anon_sym_ELSE] = ACTIONS(6046),
    [anon_sym_Else] = ACTIONS(6046),
    [anon_sym_case] = ACTIONS(6046),
    [anon_sym_CASE] = ACTIONS(6046),
    [anon_sym_Case] = ACTIONS(6046),
    [anon_sym_for] = ACTIONS(6046),
    [anon_sym_FOR] = ACTIONS(6046),
    [anon_sym_For] = ACTIONS(6046),
    [anon_sym_foreach] = ACTIONS(6046),
    [anon_sym_FOREACH] = ACTIONS(6046),
    [anon_sym_Foreach] = ACTIONS(6046),
    [anon_sym_while] = ACTIONS(6046),
    [anon_sym_WHILE] = ACTIONS(6046),
    [anon_sym_While] = ACTIONS(6046),
    [anon_sym_repeat] = ACTIONS(6046),
    [anon_sym_REPEAT] = ACTIONS(6046),
    [anon_sym_Repeat] = ACTIONS(6046),
    [anon_sym_until] = ACTIONS(6046),
    [anon_sym_UNTIL] = ACTIONS(6046),
    [anon_sym_Until] = ACTIONS(6046),
    [anon_sym_exit] = ACTIONS(6046),
    [anon_sym_EXIT] = ACTIONS(6046),
    [anon_sym_Exit] = ACTIONS(6046),
    [anon_sym_continue] = ACTIONS(6046),
    [anon_sym_CONTINUE] = ACTIONS(6046),
    [anon_sym_Continue] = ACTIONS(6046),
    [anon_sym_break] = ACTIONS(6046),
    [anon_sym_BREAK] = ACTIONS(6046),
    [anon_sym_Break] = ACTIONS(6046),
    [anon_sym_with] = ACTIONS(6046),
    [anon_sym_WITH] = ACTIONS(6046),
    [anon_sym_With] = ACTIONS(6046),
    [sym_asserterror_keyword] = ACTIONS(6048),
    [sym_page_keyword] = ACTIONS(6046),
    [anon_sym_codeunit] = ACTIONS(6046),
    [anon_sym_CODEUNIT] = ACTIONS(6046),
    [anon_sym_Codeunit] = ACTIONS(6046),
    [anon_sym_CodeUnit] = ACTIONS(6046),
    [anon_sym_COdeunit] = ACTIONS(6046),
    [anon_sym_codeUnit] = ACTIONS(6046),
    [sym_report_keyword] = ACTIONS(6046),
    [sym_query_keyword] = ACTIONS(6046),
    [anon_sym_xmlport] = ACTIONS(6046),
    [anon_sym_XMLPORT] = ACTIONS(6046),
    [anon_sym_Xmlport] = ACTIONS(6046),
    [anon_sym_XMLport] = ACTIONS(6046),
    [anon_sym_XMLPort] = ACTIONS(6046),
    [anon_sym_XmlPort] = ACTIONS(6046),
    [anon_sym_enum] = ACTIONS(6046),
    [anon_sym_ENUM] = ACTIONS(6046),
    [anon_sym_Enum] = ACTIONS(6046),
    [anon_sym_eNUM] = ACTIONS(6046),
    [anon_sym_eNum] = ACTIONS(6046),
    [anon_sym_ENum] = ACTIONS(6046),
    [sym_quoted_identifier] = ACTIONS(6048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6048),
    [sym_verbatim_string] = ACTIONS(6048),
    [sym_integer] = ACTIONS(6046),
    [sym_continue_as_identifier] = ACTIONS(6048),
    [sym_preproc_open] = ACTIONS(6048),
  },
  [STATE(2885)] = {
    [sym_identifier] = ACTIONS(6050),
    [anon_sym_SEMI] = ACTIONS(6052),
    [anon_sym_DASH] = ACTIONS(6052),
    [aux_sym_boolean_token1] = ACTIONS(6050),
    [aux_sym_boolean_token2] = ACTIONS(6050),
    [sym_decimal] = ACTIONS(6050),
    [anon_sym_LPAREN] = ACTIONS(6052),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6050),
    [anon_sym_LBRACK] = ACTIONS(6052),
    [aux_sym_record_type_token1] = ACTIONS(6050),
    [aux_sym_basic_type_token21] = ACTIONS(6050),
    [aux_sym_basic_type_token22] = ACTIONS(6050),
    [aux_sym_basic_type_token48] = ACTIONS(6050),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6050),
    [anon_sym_POUNDif] = ACTIONS(6052),
    [anon_sym_POUNDIF] = ACTIONS(6052),
    [anon_sym_POUNDIf] = ACTIONS(6052),
    [anon_sym_not] = ACTIONS(6050),
    [anon_sym_NOT] = ACTIONS(6050),
    [anon_sym_Not] = ACTIONS(6050),
    [anon_sym_POUNDelse] = ACTIONS(6052),
    [anon_sym_POUNDELSE] = ACTIONS(6052),
    [anon_sym_POUNDElse] = ACTIONS(6052),
    [anon_sym_POUNDelse2] = ACTIONS(6052),
    [anon_sym_POUNDELSE2] = ACTIONS(6052),
    [anon_sym_POUNDElse2] = ACTIONS(6052),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6050),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6050),
    [anon_sym_PLUS] = ACTIONS(6052),
    [sym_datetime_literal] = ACTIONS(6052),
    [sym_date_literal] = ACTIONS(6050),
    [sym_time_literal] = ACTIONS(6050),
    [sym_biginteger_literal] = ACTIONS(6052),
    [anon_sym_if] = ACTIONS(6050),
    [anon_sym_IF] = ACTIONS(6050),
    [anon_sym_If] = ACTIONS(6050),
    [anon_sym_else] = ACTIONS(6050),
    [anon_sym_ELSE] = ACTIONS(6050),
    [anon_sym_Else] = ACTIONS(6050),
    [anon_sym_case] = ACTIONS(6050),
    [anon_sym_CASE] = ACTIONS(6050),
    [anon_sym_Case] = ACTIONS(6050),
    [anon_sym_for] = ACTIONS(6050),
    [anon_sym_FOR] = ACTIONS(6050),
    [anon_sym_For] = ACTIONS(6050),
    [anon_sym_foreach] = ACTIONS(6050),
    [anon_sym_FOREACH] = ACTIONS(6050),
    [anon_sym_Foreach] = ACTIONS(6050),
    [anon_sym_while] = ACTIONS(6050),
    [anon_sym_WHILE] = ACTIONS(6050),
    [anon_sym_While] = ACTIONS(6050),
    [anon_sym_repeat] = ACTIONS(6050),
    [anon_sym_REPEAT] = ACTIONS(6050),
    [anon_sym_Repeat] = ACTIONS(6050),
    [anon_sym_until] = ACTIONS(6050),
    [anon_sym_UNTIL] = ACTIONS(6050),
    [anon_sym_Until] = ACTIONS(6050),
    [anon_sym_exit] = ACTIONS(6050),
    [anon_sym_EXIT] = ACTIONS(6050),
    [anon_sym_Exit] = ACTIONS(6050),
    [anon_sym_continue] = ACTIONS(6050),
    [anon_sym_CONTINUE] = ACTIONS(6050),
    [anon_sym_Continue] = ACTIONS(6050),
    [anon_sym_break] = ACTIONS(6050),
    [anon_sym_BREAK] = ACTIONS(6050),
    [anon_sym_Break] = ACTIONS(6050),
    [anon_sym_with] = ACTIONS(6050),
    [anon_sym_WITH] = ACTIONS(6050),
    [anon_sym_With] = ACTIONS(6050),
    [sym_asserterror_keyword] = ACTIONS(6052),
    [sym_page_keyword] = ACTIONS(6050),
    [anon_sym_codeunit] = ACTIONS(6050),
    [anon_sym_CODEUNIT] = ACTIONS(6050),
    [anon_sym_Codeunit] = ACTIONS(6050),
    [anon_sym_CodeUnit] = ACTIONS(6050),
    [anon_sym_COdeunit] = ACTIONS(6050),
    [anon_sym_codeUnit] = ACTIONS(6050),
    [sym_report_keyword] = ACTIONS(6050),
    [sym_query_keyword] = ACTIONS(6050),
    [anon_sym_xmlport] = ACTIONS(6050),
    [anon_sym_XMLPORT] = ACTIONS(6050),
    [anon_sym_Xmlport] = ACTIONS(6050),
    [anon_sym_XMLport] = ACTIONS(6050),
    [anon_sym_XMLPort] = ACTIONS(6050),
    [anon_sym_XmlPort] = ACTIONS(6050),
    [anon_sym_enum] = ACTIONS(6050),
    [anon_sym_ENUM] = ACTIONS(6050),
    [anon_sym_Enum] = ACTIONS(6050),
    [anon_sym_eNUM] = ACTIONS(6050),
    [anon_sym_eNum] = ACTIONS(6050),
    [anon_sym_ENum] = ACTIONS(6050),
    [sym_quoted_identifier] = ACTIONS(6052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6052),
    [sym_verbatim_string] = ACTIONS(6052),
    [sym_integer] = ACTIONS(6050),
    [sym_continue_as_identifier] = ACTIONS(6052),
    [sym_preproc_open] = ACTIONS(6052),
  },
  [STATE(2886)] = {
    [sym_identifier] = ACTIONS(6046),
    [anon_sym_SEMI] = ACTIONS(6048),
    [anon_sym_DASH] = ACTIONS(6048),
    [aux_sym_boolean_token1] = ACTIONS(6046),
    [aux_sym_boolean_token2] = ACTIONS(6046),
    [sym_decimal] = ACTIONS(6046),
    [anon_sym_LPAREN] = ACTIONS(6048),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6046),
    [anon_sym_LBRACK] = ACTIONS(6048),
    [aux_sym_record_type_token1] = ACTIONS(6046),
    [aux_sym_basic_type_token21] = ACTIONS(6046),
    [aux_sym_basic_type_token22] = ACTIONS(6046),
    [aux_sym_basic_type_token48] = ACTIONS(6046),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6046),
    [anon_sym_POUNDif] = ACTIONS(6048),
    [anon_sym_POUNDIF] = ACTIONS(6048),
    [anon_sym_POUNDIf] = ACTIONS(6048),
    [anon_sym_not] = ACTIONS(6046),
    [anon_sym_NOT] = ACTIONS(6046),
    [anon_sym_Not] = ACTIONS(6046),
    [anon_sym_POUNDelse] = ACTIONS(6048),
    [anon_sym_POUNDELSE] = ACTIONS(6048),
    [anon_sym_POUNDElse] = ACTIONS(6048),
    [anon_sym_POUNDelse2] = ACTIONS(6048),
    [anon_sym_POUNDELSE2] = ACTIONS(6048),
    [anon_sym_POUNDElse2] = ACTIONS(6048),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6046),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6046),
    [anon_sym_PLUS] = ACTIONS(6048),
    [sym_datetime_literal] = ACTIONS(6048),
    [sym_date_literal] = ACTIONS(6046),
    [sym_time_literal] = ACTIONS(6046),
    [sym_biginteger_literal] = ACTIONS(6048),
    [anon_sym_if] = ACTIONS(6046),
    [anon_sym_IF] = ACTIONS(6046),
    [anon_sym_If] = ACTIONS(6046),
    [anon_sym_else] = ACTIONS(6046),
    [anon_sym_ELSE] = ACTIONS(6046),
    [anon_sym_Else] = ACTIONS(6046),
    [anon_sym_case] = ACTIONS(6046),
    [anon_sym_CASE] = ACTIONS(6046),
    [anon_sym_Case] = ACTIONS(6046),
    [anon_sym_for] = ACTIONS(6046),
    [anon_sym_FOR] = ACTIONS(6046),
    [anon_sym_For] = ACTIONS(6046),
    [anon_sym_foreach] = ACTIONS(6046),
    [anon_sym_FOREACH] = ACTIONS(6046),
    [anon_sym_Foreach] = ACTIONS(6046),
    [anon_sym_while] = ACTIONS(6046),
    [anon_sym_WHILE] = ACTIONS(6046),
    [anon_sym_While] = ACTIONS(6046),
    [anon_sym_repeat] = ACTIONS(6046),
    [anon_sym_REPEAT] = ACTIONS(6046),
    [anon_sym_Repeat] = ACTIONS(6046),
    [anon_sym_until] = ACTIONS(6046),
    [anon_sym_UNTIL] = ACTIONS(6046),
    [anon_sym_Until] = ACTIONS(6046),
    [anon_sym_exit] = ACTIONS(6046),
    [anon_sym_EXIT] = ACTIONS(6046),
    [anon_sym_Exit] = ACTIONS(6046),
    [anon_sym_continue] = ACTIONS(6046),
    [anon_sym_CONTINUE] = ACTIONS(6046),
    [anon_sym_Continue] = ACTIONS(6046),
    [anon_sym_break] = ACTIONS(6046),
    [anon_sym_BREAK] = ACTIONS(6046),
    [anon_sym_Break] = ACTIONS(6046),
    [anon_sym_with] = ACTIONS(6046),
    [anon_sym_WITH] = ACTIONS(6046),
    [anon_sym_With] = ACTIONS(6046),
    [sym_asserterror_keyword] = ACTIONS(6048),
    [sym_page_keyword] = ACTIONS(6046),
    [anon_sym_codeunit] = ACTIONS(6046),
    [anon_sym_CODEUNIT] = ACTIONS(6046),
    [anon_sym_Codeunit] = ACTIONS(6046),
    [anon_sym_CodeUnit] = ACTIONS(6046),
    [anon_sym_COdeunit] = ACTIONS(6046),
    [anon_sym_codeUnit] = ACTIONS(6046),
    [sym_report_keyword] = ACTIONS(6046),
    [sym_query_keyword] = ACTIONS(6046),
    [anon_sym_xmlport] = ACTIONS(6046),
    [anon_sym_XMLPORT] = ACTIONS(6046),
    [anon_sym_Xmlport] = ACTIONS(6046),
    [anon_sym_XMLport] = ACTIONS(6046),
    [anon_sym_XMLPort] = ACTIONS(6046),
    [anon_sym_XmlPort] = ACTIONS(6046),
    [anon_sym_enum] = ACTIONS(6046),
    [anon_sym_ENUM] = ACTIONS(6046),
    [anon_sym_Enum] = ACTIONS(6046),
    [anon_sym_eNUM] = ACTIONS(6046),
    [anon_sym_eNum] = ACTIONS(6046),
    [anon_sym_ENum] = ACTIONS(6046),
    [sym_quoted_identifier] = ACTIONS(6048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6048),
    [sym_verbatim_string] = ACTIONS(6048),
    [sym_integer] = ACTIONS(6046),
    [sym_continue_as_identifier] = ACTIONS(6048),
    [sym_preproc_open] = ACTIONS(6048),
  },
  [STATE(2887)] = {
    [sym_identifier] = ACTIONS(6054),
    [anon_sym_SEMI] = ACTIONS(6056),
    [anon_sym_DASH] = ACTIONS(6056),
    [aux_sym_boolean_token1] = ACTIONS(6054),
    [aux_sym_boolean_token2] = ACTIONS(6054),
    [sym_decimal] = ACTIONS(6054),
    [anon_sym_LPAREN] = ACTIONS(6056),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6054),
    [anon_sym_LBRACK] = ACTIONS(6056),
    [aux_sym_record_type_token1] = ACTIONS(6054),
    [aux_sym_basic_type_token21] = ACTIONS(6054),
    [aux_sym_basic_type_token22] = ACTIONS(6054),
    [aux_sym_basic_type_token48] = ACTIONS(6054),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6054),
    [anon_sym_POUNDif] = ACTIONS(6056),
    [anon_sym_POUNDIF] = ACTIONS(6056),
    [anon_sym_POUNDIf] = ACTIONS(6056),
    [anon_sym_not] = ACTIONS(6054),
    [anon_sym_NOT] = ACTIONS(6054),
    [anon_sym_Not] = ACTIONS(6054),
    [anon_sym_POUNDelse] = ACTIONS(6056),
    [anon_sym_POUNDELSE] = ACTIONS(6056),
    [anon_sym_POUNDElse] = ACTIONS(6056),
    [anon_sym_POUNDelse2] = ACTIONS(6056),
    [anon_sym_POUNDELSE2] = ACTIONS(6056),
    [anon_sym_POUNDElse2] = ACTIONS(6056),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6054),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6054),
    [anon_sym_PLUS] = ACTIONS(6056),
    [sym_datetime_literal] = ACTIONS(6056),
    [sym_date_literal] = ACTIONS(6054),
    [sym_time_literal] = ACTIONS(6054),
    [sym_biginteger_literal] = ACTIONS(6056),
    [anon_sym_if] = ACTIONS(6054),
    [anon_sym_IF] = ACTIONS(6054),
    [anon_sym_If] = ACTIONS(6054),
    [anon_sym_else] = ACTIONS(6054),
    [anon_sym_ELSE] = ACTIONS(6054),
    [anon_sym_Else] = ACTIONS(6054),
    [anon_sym_case] = ACTIONS(6054),
    [anon_sym_CASE] = ACTIONS(6054),
    [anon_sym_Case] = ACTIONS(6054),
    [anon_sym_for] = ACTIONS(6054),
    [anon_sym_FOR] = ACTIONS(6054),
    [anon_sym_For] = ACTIONS(6054),
    [anon_sym_foreach] = ACTIONS(6054),
    [anon_sym_FOREACH] = ACTIONS(6054),
    [anon_sym_Foreach] = ACTIONS(6054),
    [anon_sym_while] = ACTIONS(6054),
    [anon_sym_WHILE] = ACTIONS(6054),
    [anon_sym_While] = ACTIONS(6054),
    [anon_sym_repeat] = ACTIONS(6054),
    [anon_sym_REPEAT] = ACTIONS(6054),
    [anon_sym_Repeat] = ACTIONS(6054),
    [anon_sym_until] = ACTIONS(6054),
    [anon_sym_UNTIL] = ACTIONS(6054),
    [anon_sym_Until] = ACTIONS(6054),
    [anon_sym_exit] = ACTIONS(6054),
    [anon_sym_EXIT] = ACTIONS(6054),
    [anon_sym_Exit] = ACTIONS(6054),
    [anon_sym_continue] = ACTIONS(6054),
    [anon_sym_CONTINUE] = ACTIONS(6054),
    [anon_sym_Continue] = ACTIONS(6054),
    [anon_sym_break] = ACTIONS(6054),
    [anon_sym_BREAK] = ACTIONS(6054),
    [anon_sym_Break] = ACTIONS(6054),
    [anon_sym_with] = ACTIONS(6054),
    [anon_sym_WITH] = ACTIONS(6054),
    [anon_sym_With] = ACTIONS(6054),
    [sym_asserterror_keyword] = ACTIONS(6056),
    [sym_page_keyword] = ACTIONS(6054),
    [anon_sym_codeunit] = ACTIONS(6054),
    [anon_sym_CODEUNIT] = ACTIONS(6054),
    [anon_sym_Codeunit] = ACTIONS(6054),
    [anon_sym_CodeUnit] = ACTIONS(6054),
    [anon_sym_COdeunit] = ACTIONS(6054),
    [anon_sym_codeUnit] = ACTIONS(6054),
    [sym_report_keyword] = ACTIONS(6054),
    [sym_query_keyword] = ACTIONS(6054),
    [anon_sym_xmlport] = ACTIONS(6054),
    [anon_sym_XMLPORT] = ACTIONS(6054),
    [anon_sym_Xmlport] = ACTIONS(6054),
    [anon_sym_XMLport] = ACTIONS(6054),
    [anon_sym_XMLPort] = ACTIONS(6054),
    [anon_sym_XmlPort] = ACTIONS(6054),
    [anon_sym_enum] = ACTIONS(6054),
    [anon_sym_ENUM] = ACTIONS(6054),
    [anon_sym_Enum] = ACTIONS(6054),
    [anon_sym_eNUM] = ACTIONS(6054),
    [anon_sym_eNum] = ACTIONS(6054),
    [anon_sym_ENum] = ACTIONS(6054),
    [sym_quoted_identifier] = ACTIONS(6056),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6056),
    [sym_verbatim_string] = ACTIONS(6056),
    [sym_integer] = ACTIONS(6054),
    [sym_continue_as_identifier] = ACTIONS(6056),
    [sym_preproc_open] = ACTIONS(6056),
  },
  [STATE(2888)] = {
    [sym_identifier] = ACTIONS(6054),
    [anon_sym_SEMI] = ACTIONS(6056),
    [anon_sym_DASH] = ACTIONS(6056),
    [aux_sym_boolean_token1] = ACTIONS(6054),
    [aux_sym_boolean_token2] = ACTIONS(6054),
    [sym_decimal] = ACTIONS(6054),
    [anon_sym_LPAREN] = ACTIONS(6056),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6054),
    [anon_sym_LBRACK] = ACTIONS(6056),
    [aux_sym_record_type_token1] = ACTIONS(6054),
    [aux_sym_basic_type_token21] = ACTIONS(6054),
    [aux_sym_basic_type_token22] = ACTIONS(6054),
    [aux_sym_basic_type_token48] = ACTIONS(6054),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6054),
    [anon_sym_POUNDif] = ACTIONS(6056),
    [anon_sym_POUNDIF] = ACTIONS(6056),
    [anon_sym_POUNDIf] = ACTIONS(6056),
    [anon_sym_not] = ACTIONS(6054),
    [anon_sym_NOT] = ACTIONS(6054),
    [anon_sym_Not] = ACTIONS(6054),
    [anon_sym_POUNDelse] = ACTIONS(6056),
    [anon_sym_POUNDELSE] = ACTIONS(6056),
    [anon_sym_POUNDElse] = ACTIONS(6056),
    [anon_sym_POUNDelse2] = ACTIONS(6056),
    [anon_sym_POUNDELSE2] = ACTIONS(6056),
    [anon_sym_POUNDElse2] = ACTIONS(6056),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6054),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6054),
    [anon_sym_PLUS] = ACTIONS(6056),
    [sym_datetime_literal] = ACTIONS(6056),
    [sym_date_literal] = ACTIONS(6054),
    [sym_time_literal] = ACTIONS(6054),
    [sym_biginteger_literal] = ACTIONS(6056),
    [anon_sym_if] = ACTIONS(6054),
    [anon_sym_IF] = ACTIONS(6054),
    [anon_sym_If] = ACTIONS(6054),
    [anon_sym_else] = ACTIONS(6054),
    [anon_sym_ELSE] = ACTIONS(6054),
    [anon_sym_Else] = ACTIONS(6054),
    [anon_sym_case] = ACTIONS(6054),
    [anon_sym_CASE] = ACTIONS(6054),
    [anon_sym_Case] = ACTIONS(6054),
    [anon_sym_for] = ACTIONS(6054),
    [anon_sym_FOR] = ACTIONS(6054),
    [anon_sym_For] = ACTIONS(6054),
    [anon_sym_foreach] = ACTIONS(6054),
    [anon_sym_FOREACH] = ACTIONS(6054),
    [anon_sym_Foreach] = ACTIONS(6054),
    [anon_sym_while] = ACTIONS(6054),
    [anon_sym_WHILE] = ACTIONS(6054),
    [anon_sym_While] = ACTIONS(6054),
    [anon_sym_repeat] = ACTIONS(6054),
    [anon_sym_REPEAT] = ACTIONS(6054),
    [anon_sym_Repeat] = ACTIONS(6054),
    [anon_sym_until] = ACTIONS(6054),
    [anon_sym_UNTIL] = ACTIONS(6054),
    [anon_sym_Until] = ACTIONS(6054),
    [anon_sym_exit] = ACTIONS(6054),
    [anon_sym_EXIT] = ACTIONS(6054),
    [anon_sym_Exit] = ACTIONS(6054),
    [anon_sym_continue] = ACTIONS(6054),
    [anon_sym_CONTINUE] = ACTIONS(6054),
    [anon_sym_Continue] = ACTIONS(6054),
    [anon_sym_break] = ACTIONS(6054),
    [anon_sym_BREAK] = ACTIONS(6054),
    [anon_sym_Break] = ACTIONS(6054),
    [anon_sym_with] = ACTIONS(6054),
    [anon_sym_WITH] = ACTIONS(6054),
    [anon_sym_With] = ACTIONS(6054),
    [sym_asserterror_keyword] = ACTIONS(6056),
    [sym_page_keyword] = ACTIONS(6054),
    [anon_sym_codeunit] = ACTIONS(6054),
    [anon_sym_CODEUNIT] = ACTIONS(6054),
    [anon_sym_Codeunit] = ACTIONS(6054),
    [anon_sym_CodeUnit] = ACTIONS(6054),
    [anon_sym_COdeunit] = ACTIONS(6054),
    [anon_sym_codeUnit] = ACTIONS(6054),
    [sym_report_keyword] = ACTIONS(6054),
    [sym_query_keyword] = ACTIONS(6054),
    [anon_sym_xmlport] = ACTIONS(6054),
    [anon_sym_XMLPORT] = ACTIONS(6054),
    [anon_sym_Xmlport] = ACTIONS(6054),
    [anon_sym_XMLport] = ACTIONS(6054),
    [anon_sym_XMLPort] = ACTIONS(6054),
    [anon_sym_XmlPort] = ACTIONS(6054),
    [anon_sym_enum] = ACTIONS(6054),
    [anon_sym_ENUM] = ACTIONS(6054),
    [anon_sym_Enum] = ACTIONS(6054),
    [anon_sym_eNUM] = ACTIONS(6054),
    [anon_sym_eNum] = ACTIONS(6054),
    [anon_sym_ENum] = ACTIONS(6054),
    [sym_quoted_identifier] = ACTIONS(6056),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6056),
    [sym_verbatim_string] = ACTIONS(6056),
    [sym_integer] = ACTIONS(6054),
    [sym_continue_as_identifier] = ACTIONS(6056),
    [sym_preproc_open] = ACTIONS(6056),
  },
  [STATE(2889)] = {
    [sym_identifier] = ACTIONS(6058),
    [anon_sym_SEMI] = ACTIONS(6060),
    [anon_sym_DASH] = ACTIONS(6060),
    [aux_sym_boolean_token1] = ACTIONS(6058),
    [aux_sym_boolean_token2] = ACTIONS(6058),
    [sym_decimal] = ACTIONS(6058),
    [anon_sym_LPAREN] = ACTIONS(6060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6058),
    [anon_sym_LBRACK] = ACTIONS(6060),
    [aux_sym_record_type_token1] = ACTIONS(6058),
    [aux_sym_basic_type_token21] = ACTIONS(6058),
    [aux_sym_basic_type_token22] = ACTIONS(6058),
    [aux_sym_basic_type_token48] = ACTIONS(6058),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6058),
    [anon_sym_POUNDif] = ACTIONS(6060),
    [anon_sym_POUNDIF] = ACTIONS(6060),
    [anon_sym_POUNDIf] = ACTIONS(6060),
    [anon_sym_not] = ACTIONS(6058),
    [anon_sym_NOT] = ACTIONS(6058),
    [anon_sym_Not] = ACTIONS(6058),
    [anon_sym_POUNDelse] = ACTIONS(6060),
    [anon_sym_POUNDELSE] = ACTIONS(6060),
    [anon_sym_POUNDElse] = ACTIONS(6060),
    [anon_sym_POUNDelse2] = ACTIONS(6060),
    [anon_sym_POUNDELSE2] = ACTIONS(6060),
    [anon_sym_POUNDElse2] = ACTIONS(6060),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6058),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6058),
    [anon_sym_PLUS] = ACTIONS(6060),
    [sym_datetime_literal] = ACTIONS(6060),
    [sym_date_literal] = ACTIONS(6058),
    [sym_time_literal] = ACTIONS(6058),
    [sym_biginteger_literal] = ACTIONS(6060),
    [anon_sym_if] = ACTIONS(6058),
    [anon_sym_IF] = ACTIONS(6058),
    [anon_sym_If] = ACTIONS(6058),
    [anon_sym_else] = ACTIONS(6058),
    [anon_sym_ELSE] = ACTIONS(6058),
    [anon_sym_Else] = ACTIONS(6058),
    [anon_sym_case] = ACTIONS(6058),
    [anon_sym_CASE] = ACTIONS(6058),
    [anon_sym_Case] = ACTIONS(6058),
    [anon_sym_for] = ACTIONS(6058),
    [anon_sym_FOR] = ACTIONS(6058),
    [anon_sym_For] = ACTIONS(6058),
    [anon_sym_foreach] = ACTIONS(6058),
    [anon_sym_FOREACH] = ACTIONS(6058),
    [anon_sym_Foreach] = ACTIONS(6058),
    [anon_sym_while] = ACTIONS(6058),
    [anon_sym_WHILE] = ACTIONS(6058),
    [anon_sym_While] = ACTIONS(6058),
    [anon_sym_repeat] = ACTIONS(6058),
    [anon_sym_REPEAT] = ACTIONS(6058),
    [anon_sym_Repeat] = ACTIONS(6058),
    [anon_sym_until] = ACTIONS(6058),
    [anon_sym_UNTIL] = ACTIONS(6058),
    [anon_sym_Until] = ACTIONS(6058),
    [anon_sym_exit] = ACTIONS(6058),
    [anon_sym_EXIT] = ACTIONS(6058),
    [anon_sym_Exit] = ACTIONS(6058),
    [anon_sym_continue] = ACTIONS(6058),
    [anon_sym_CONTINUE] = ACTIONS(6058),
    [anon_sym_Continue] = ACTIONS(6058),
    [anon_sym_break] = ACTIONS(6058),
    [anon_sym_BREAK] = ACTIONS(6058),
    [anon_sym_Break] = ACTIONS(6058),
    [anon_sym_with] = ACTIONS(6058),
    [anon_sym_WITH] = ACTIONS(6058),
    [anon_sym_With] = ACTIONS(6058),
    [sym_asserterror_keyword] = ACTIONS(6060),
    [sym_page_keyword] = ACTIONS(6058),
    [anon_sym_codeunit] = ACTIONS(6058),
    [anon_sym_CODEUNIT] = ACTIONS(6058),
    [anon_sym_Codeunit] = ACTIONS(6058),
    [anon_sym_CodeUnit] = ACTIONS(6058),
    [anon_sym_COdeunit] = ACTIONS(6058),
    [anon_sym_codeUnit] = ACTIONS(6058),
    [sym_report_keyword] = ACTIONS(6058),
    [sym_query_keyword] = ACTIONS(6058),
    [anon_sym_xmlport] = ACTIONS(6058),
    [anon_sym_XMLPORT] = ACTIONS(6058),
    [anon_sym_Xmlport] = ACTIONS(6058),
    [anon_sym_XMLport] = ACTIONS(6058),
    [anon_sym_XMLPort] = ACTIONS(6058),
    [anon_sym_XmlPort] = ACTIONS(6058),
    [anon_sym_enum] = ACTIONS(6058),
    [anon_sym_ENUM] = ACTIONS(6058),
    [anon_sym_Enum] = ACTIONS(6058),
    [anon_sym_eNUM] = ACTIONS(6058),
    [anon_sym_eNum] = ACTIONS(6058),
    [anon_sym_ENum] = ACTIONS(6058),
    [sym_quoted_identifier] = ACTIONS(6060),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6060),
    [sym_verbatim_string] = ACTIONS(6060),
    [sym_integer] = ACTIONS(6058),
    [sym_continue_as_identifier] = ACTIONS(6060),
    [sym_preproc_open] = ACTIONS(6060),
  },
  [STATE(2890)] = {
    [sym_identifier] = ACTIONS(6062),
    [anon_sym_SEMI] = ACTIONS(6064),
    [anon_sym_DASH] = ACTIONS(6064),
    [aux_sym_boolean_token1] = ACTIONS(6062),
    [aux_sym_boolean_token2] = ACTIONS(6062),
    [sym_decimal] = ACTIONS(6062),
    [anon_sym_LPAREN] = ACTIONS(6064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6062),
    [anon_sym_LBRACK] = ACTIONS(6064),
    [aux_sym_record_type_token1] = ACTIONS(6062),
    [aux_sym_basic_type_token21] = ACTIONS(6062),
    [aux_sym_basic_type_token22] = ACTIONS(6062),
    [aux_sym_basic_type_token48] = ACTIONS(6062),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6062),
    [anon_sym_POUNDif] = ACTIONS(6064),
    [anon_sym_POUNDIF] = ACTIONS(6064),
    [anon_sym_POUNDIf] = ACTIONS(6064),
    [anon_sym_not] = ACTIONS(6062),
    [anon_sym_NOT] = ACTIONS(6062),
    [anon_sym_Not] = ACTIONS(6062),
    [anon_sym_POUNDelse] = ACTIONS(6064),
    [anon_sym_POUNDELSE] = ACTIONS(6064),
    [anon_sym_POUNDElse] = ACTIONS(6064),
    [anon_sym_POUNDelse2] = ACTIONS(6064),
    [anon_sym_POUNDELSE2] = ACTIONS(6064),
    [anon_sym_POUNDElse2] = ACTIONS(6064),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6062),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6062),
    [anon_sym_PLUS] = ACTIONS(6064),
    [sym_datetime_literal] = ACTIONS(6064),
    [sym_date_literal] = ACTIONS(6062),
    [sym_time_literal] = ACTIONS(6062),
    [sym_biginteger_literal] = ACTIONS(6064),
    [anon_sym_if] = ACTIONS(6062),
    [anon_sym_IF] = ACTIONS(6062),
    [anon_sym_If] = ACTIONS(6062),
    [anon_sym_else] = ACTIONS(6062),
    [anon_sym_ELSE] = ACTIONS(6062),
    [anon_sym_Else] = ACTIONS(6062),
    [anon_sym_case] = ACTIONS(6062),
    [anon_sym_CASE] = ACTIONS(6062),
    [anon_sym_Case] = ACTIONS(6062),
    [anon_sym_for] = ACTIONS(6062),
    [anon_sym_FOR] = ACTIONS(6062),
    [anon_sym_For] = ACTIONS(6062),
    [anon_sym_foreach] = ACTIONS(6062),
    [anon_sym_FOREACH] = ACTIONS(6062),
    [anon_sym_Foreach] = ACTIONS(6062),
    [anon_sym_while] = ACTIONS(6062),
    [anon_sym_WHILE] = ACTIONS(6062),
    [anon_sym_While] = ACTIONS(6062),
    [anon_sym_repeat] = ACTIONS(6062),
    [anon_sym_REPEAT] = ACTIONS(6062),
    [anon_sym_Repeat] = ACTIONS(6062),
    [anon_sym_until] = ACTIONS(6062),
    [anon_sym_UNTIL] = ACTIONS(6062),
    [anon_sym_Until] = ACTIONS(6062),
    [anon_sym_exit] = ACTIONS(6062),
    [anon_sym_EXIT] = ACTIONS(6062),
    [anon_sym_Exit] = ACTIONS(6062),
    [anon_sym_continue] = ACTIONS(6062),
    [anon_sym_CONTINUE] = ACTIONS(6062),
    [anon_sym_Continue] = ACTIONS(6062),
    [anon_sym_break] = ACTIONS(6062),
    [anon_sym_BREAK] = ACTIONS(6062),
    [anon_sym_Break] = ACTIONS(6062),
    [anon_sym_with] = ACTIONS(6062),
    [anon_sym_WITH] = ACTIONS(6062),
    [anon_sym_With] = ACTIONS(6062),
    [sym_asserterror_keyword] = ACTIONS(6064),
    [sym_page_keyword] = ACTIONS(6062),
    [anon_sym_codeunit] = ACTIONS(6062),
    [anon_sym_CODEUNIT] = ACTIONS(6062),
    [anon_sym_Codeunit] = ACTIONS(6062),
    [anon_sym_CodeUnit] = ACTIONS(6062),
    [anon_sym_COdeunit] = ACTIONS(6062),
    [anon_sym_codeUnit] = ACTIONS(6062),
    [sym_report_keyword] = ACTIONS(6062),
    [sym_query_keyword] = ACTIONS(6062),
    [anon_sym_xmlport] = ACTIONS(6062),
    [anon_sym_XMLPORT] = ACTIONS(6062),
    [anon_sym_Xmlport] = ACTIONS(6062),
    [anon_sym_XMLport] = ACTIONS(6062),
    [anon_sym_XMLPort] = ACTIONS(6062),
    [anon_sym_XmlPort] = ACTIONS(6062),
    [anon_sym_enum] = ACTIONS(6062),
    [anon_sym_ENUM] = ACTIONS(6062),
    [anon_sym_Enum] = ACTIONS(6062),
    [anon_sym_eNUM] = ACTIONS(6062),
    [anon_sym_eNum] = ACTIONS(6062),
    [anon_sym_ENum] = ACTIONS(6062),
    [sym_quoted_identifier] = ACTIONS(6064),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6064),
    [sym_verbatim_string] = ACTIONS(6064),
    [sym_integer] = ACTIONS(6062),
    [sym_continue_as_identifier] = ACTIONS(6064),
    [sym_preproc_open] = ACTIONS(6064),
  },
  [STATE(2891)] = {
    [sym_identifier] = ACTIONS(6058),
    [anon_sym_SEMI] = ACTIONS(6060),
    [anon_sym_DASH] = ACTIONS(6060),
    [aux_sym_boolean_token1] = ACTIONS(6058),
    [aux_sym_boolean_token2] = ACTIONS(6058),
    [sym_decimal] = ACTIONS(6058),
    [anon_sym_LPAREN] = ACTIONS(6060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6058),
    [anon_sym_LBRACK] = ACTIONS(6060),
    [aux_sym_record_type_token1] = ACTIONS(6058),
    [aux_sym_basic_type_token21] = ACTIONS(6058),
    [aux_sym_basic_type_token22] = ACTIONS(6058),
    [aux_sym_basic_type_token48] = ACTIONS(6058),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6058),
    [anon_sym_POUNDif] = ACTIONS(6060),
    [anon_sym_POUNDIF] = ACTIONS(6060),
    [anon_sym_POUNDIf] = ACTIONS(6060),
    [anon_sym_not] = ACTIONS(6058),
    [anon_sym_NOT] = ACTIONS(6058),
    [anon_sym_Not] = ACTIONS(6058),
    [anon_sym_POUNDelse] = ACTIONS(6060),
    [anon_sym_POUNDELSE] = ACTIONS(6060),
    [anon_sym_POUNDElse] = ACTIONS(6060),
    [anon_sym_POUNDelse2] = ACTIONS(6060),
    [anon_sym_POUNDELSE2] = ACTIONS(6060),
    [anon_sym_POUNDElse2] = ACTIONS(6060),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6058),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6058),
    [anon_sym_PLUS] = ACTIONS(6060),
    [sym_datetime_literal] = ACTIONS(6060),
    [sym_date_literal] = ACTIONS(6058),
    [sym_time_literal] = ACTIONS(6058),
    [sym_biginteger_literal] = ACTIONS(6060),
    [anon_sym_if] = ACTIONS(6058),
    [anon_sym_IF] = ACTIONS(6058),
    [anon_sym_If] = ACTIONS(6058),
    [anon_sym_else] = ACTIONS(6058),
    [anon_sym_ELSE] = ACTIONS(6058),
    [anon_sym_Else] = ACTIONS(6058),
    [anon_sym_case] = ACTIONS(6058),
    [anon_sym_CASE] = ACTIONS(6058),
    [anon_sym_Case] = ACTIONS(6058),
    [anon_sym_for] = ACTIONS(6058),
    [anon_sym_FOR] = ACTIONS(6058),
    [anon_sym_For] = ACTIONS(6058),
    [anon_sym_foreach] = ACTIONS(6058),
    [anon_sym_FOREACH] = ACTIONS(6058),
    [anon_sym_Foreach] = ACTIONS(6058),
    [anon_sym_while] = ACTIONS(6058),
    [anon_sym_WHILE] = ACTIONS(6058),
    [anon_sym_While] = ACTIONS(6058),
    [anon_sym_repeat] = ACTIONS(6058),
    [anon_sym_REPEAT] = ACTIONS(6058),
    [anon_sym_Repeat] = ACTIONS(6058),
    [anon_sym_until] = ACTIONS(6058),
    [anon_sym_UNTIL] = ACTIONS(6058),
    [anon_sym_Until] = ACTIONS(6058),
    [anon_sym_exit] = ACTIONS(6058),
    [anon_sym_EXIT] = ACTIONS(6058),
    [anon_sym_Exit] = ACTIONS(6058),
    [anon_sym_continue] = ACTIONS(6058),
    [anon_sym_CONTINUE] = ACTIONS(6058),
    [anon_sym_Continue] = ACTIONS(6058),
    [anon_sym_break] = ACTIONS(6058),
    [anon_sym_BREAK] = ACTIONS(6058),
    [anon_sym_Break] = ACTIONS(6058),
    [anon_sym_with] = ACTIONS(6058),
    [anon_sym_WITH] = ACTIONS(6058),
    [anon_sym_With] = ACTIONS(6058),
    [sym_asserterror_keyword] = ACTIONS(6060),
    [sym_page_keyword] = ACTIONS(6058),
    [anon_sym_codeunit] = ACTIONS(6058),
    [anon_sym_CODEUNIT] = ACTIONS(6058),
    [anon_sym_Codeunit] = ACTIONS(6058),
    [anon_sym_CodeUnit] = ACTIONS(6058),
    [anon_sym_COdeunit] = ACTIONS(6058),
    [anon_sym_codeUnit] = ACTIONS(6058),
    [sym_report_keyword] = ACTIONS(6058),
    [sym_query_keyword] = ACTIONS(6058),
    [anon_sym_xmlport] = ACTIONS(6058),
    [anon_sym_XMLPORT] = ACTIONS(6058),
    [anon_sym_Xmlport] = ACTIONS(6058),
    [anon_sym_XMLport] = ACTIONS(6058),
    [anon_sym_XMLPort] = ACTIONS(6058),
    [anon_sym_XmlPort] = ACTIONS(6058),
    [anon_sym_enum] = ACTIONS(6058),
    [anon_sym_ENUM] = ACTIONS(6058),
    [anon_sym_Enum] = ACTIONS(6058),
    [anon_sym_eNUM] = ACTIONS(6058),
    [anon_sym_eNum] = ACTIONS(6058),
    [anon_sym_ENum] = ACTIONS(6058),
    [sym_quoted_identifier] = ACTIONS(6060),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6060),
    [sym_verbatim_string] = ACTIONS(6060),
    [sym_integer] = ACTIONS(6058),
    [sym_continue_as_identifier] = ACTIONS(6060),
    [sym_preproc_open] = ACTIONS(6060),
  },
  [STATE(2892)] = {
    [sym_identifier] = ACTIONS(6066),
    [anon_sym_SEMI] = ACTIONS(6068),
    [anon_sym_DASH] = ACTIONS(6068),
    [aux_sym_boolean_token1] = ACTIONS(6066),
    [aux_sym_boolean_token2] = ACTIONS(6066),
    [sym_decimal] = ACTIONS(6066),
    [anon_sym_LPAREN] = ACTIONS(6068),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6066),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [aux_sym_record_type_token1] = ACTIONS(6066),
    [aux_sym_basic_type_token21] = ACTIONS(6066),
    [aux_sym_basic_type_token22] = ACTIONS(6066),
    [aux_sym_basic_type_token48] = ACTIONS(6066),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6066),
    [anon_sym_POUNDif] = ACTIONS(6068),
    [anon_sym_POUNDIF] = ACTIONS(6068),
    [anon_sym_POUNDIf] = ACTIONS(6068),
    [anon_sym_not] = ACTIONS(6066),
    [anon_sym_NOT] = ACTIONS(6066),
    [anon_sym_Not] = ACTIONS(6066),
    [anon_sym_POUNDelse] = ACTIONS(6068),
    [anon_sym_POUNDELSE] = ACTIONS(6068),
    [anon_sym_POUNDElse] = ACTIONS(6068),
    [anon_sym_POUNDelse2] = ACTIONS(6068),
    [anon_sym_POUNDELSE2] = ACTIONS(6068),
    [anon_sym_POUNDElse2] = ACTIONS(6068),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6066),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6066),
    [anon_sym_PLUS] = ACTIONS(6068),
    [sym_datetime_literal] = ACTIONS(6068),
    [sym_date_literal] = ACTIONS(6066),
    [sym_time_literal] = ACTIONS(6066),
    [sym_biginteger_literal] = ACTIONS(6068),
    [anon_sym_if] = ACTIONS(6066),
    [anon_sym_IF] = ACTIONS(6066),
    [anon_sym_If] = ACTIONS(6066),
    [anon_sym_else] = ACTIONS(6066),
    [anon_sym_ELSE] = ACTIONS(6066),
    [anon_sym_Else] = ACTIONS(6066),
    [anon_sym_case] = ACTIONS(6066),
    [anon_sym_CASE] = ACTIONS(6066),
    [anon_sym_Case] = ACTIONS(6066),
    [anon_sym_for] = ACTIONS(6066),
    [anon_sym_FOR] = ACTIONS(6066),
    [anon_sym_For] = ACTIONS(6066),
    [anon_sym_foreach] = ACTIONS(6066),
    [anon_sym_FOREACH] = ACTIONS(6066),
    [anon_sym_Foreach] = ACTIONS(6066),
    [anon_sym_while] = ACTIONS(6066),
    [anon_sym_WHILE] = ACTIONS(6066),
    [anon_sym_While] = ACTIONS(6066),
    [anon_sym_repeat] = ACTIONS(6066),
    [anon_sym_REPEAT] = ACTIONS(6066),
    [anon_sym_Repeat] = ACTIONS(6066),
    [anon_sym_until] = ACTIONS(6066),
    [anon_sym_UNTIL] = ACTIONS(6066),
    [anon_sym_Until] = ACTIONS(6066),
    [anon_sym_exit] = ACTIONS(6066),
    [anon_sym_EXIT] = ACTIONS(6066),
    [anon_sym_Exit] = ACTIONS(6066),
    [anon_sym_continue] = ACTIONS(6066),
    [anon_sym_CONTINUE] = ACTIONS(6066),
    [anon_sym_Continue] = ACTIONS(6066),
    [anon_sym_break] = ACTIONS(6066),
    [anon_sym_BREAK] = ACTIONS(6066),
    [anon_sym_Break] = ACTIONS(6066),
    [anon_sym_with] = ACTIONS(6066),
    [anon_sym_WITH] = ACTIONS(6066),
    [anon_sym_With] = ACTIONS(6066),
    [sym_asserterror_keyword] = ACTIONS(6068),
    [sym_page_keyword] = ACTIONS(6066),
    [anon_sym_codeunit] = ACTIONS(6066),
    [anon_sym_CODEUNIT] = ACTIONS(6066),
    [anon_sym_Codeunit] = ACTIONS(6066),
    [anon_sym_CodeUnit] = ACTIONS(6066),
    [anon_sym_COdeunit] = ACTIONS(6066),
    [anon_sym_codeUnit] = ACTIONS(6066),
    [sym_report_keyword] = ACTIONS(6066),
    [sym_query_keyword] = ACTIONS(6066),
    [anon_sym_xmlport] = ACTIONS(6066),
    [anon_sym_XMLPORT] = ACTIONS(6066),
    [anon_sym_Xmlport] = ACTIONS(6066),
    [anon_sym_XMLport] = ACTIONS(6066),
    [anon_sym_XMLPort] = ACTIONS(6066),
    [anon_sym_XmlPort] = ACTIONS(6066),
    [anon_sym_enum] = ACTIONS(6066),
    [anon_sym_ENUM] = ACTIONS(6066),
    [anon_sym_Enum] = ACTIONS(6066),
    [anon_sym_eNUM] = ACTIONS(6066),
    [anon_sym_eNum] = ACTIONS(6066),
    [anon_sym_ENum] = ACTIONS(6066),
    [sym_quoted_identifier] = ACTIONS(6068),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6068),
    [sym_verbatim_string] = ACTIONS(6068),
    [sym_integer] = ACTIONS(6066),
    [sym_continue_as_identifier] = ACTIONS(6068),
    [sym_preproc_open] = ACTIONS(6068),
  },
  [STATE(2893)] = {
    [sym_identifier] = ACTIONS(6070),
    [anon_sym_SEMI] = ACTIONS(6072),
    [anon_sym_DASH] = ACTIONS(6072),
    [aux_sym_boolean_token1] = ACTIONS(6070),
    [aux_sym_boolean_token2] = ACTIONS(6070),
    [sym_decimal] = ACTIONS(6070),
    [anon_sym_LPAREN] = ACTIONS(6072),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6070),
    [anon_sym_LBRACK] = ACTIONS(6072),
    [aux_sym_record_type_token1] = ACTIONS(6070),
    [aux_sym_basic_type_token21] = ACTIONS(6070),
    [aux_sym_basic_type_token22] = ACTIONS(6070),
    [aux_sym_basic_type_token48] = ACTIONS(6070),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6070),
    [anon_sym_POUNDif] = ACTIONS(6072),
    [anon_sym_POUNDIF] = ACTIONS(6072),
    [anon_sym_POUNDIf] = ACTIONS(6072),
    [anon_sym_not] = ACTIONS(6070),
    [anon_sym_NOT] = ACTIONS(6070),
    [anon_sym_Not] = ACTIONS(6070),
    [anon_sym_POUNDelse] = ACTIONS(6072),
    [anon_sym_POUNDELSE] = ACTIONS(6072),
    [anon_sym_POUNDElse] = ACTIONS(6072),
    [anon_sym_POUNDelse2] = ACTIONS(6072),
    [anon_sym_POUNDELSE2] = ACTIONS(6072),
    [anon_sym_POUNDElse2] = ACTIONS(6072),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6070),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6070),
    [anon_sym_PLUS] = ACTIONS(6072),
    [sym_datetime_literal] = ACTIONS(6072),
    [sym_date_literal] = ACTIONS(6070),
    [sym_time_literal] = ACTIONS(6070),
    [sym_biginteger_literal] = ACTIONS(6072),
    [anon_sym_if] = ACTIONS(6070),
    [anon_sym_IF] = ACTIONS(6070),
    [anon_sym_If] = ACTIONS(6070),
    [anon_sym_else] = ACTIONS(6070),
    [anon_sym_ELSE] = ACTIONS(6070),
    [anon_sym_Else] = ACTIONS(6070),
    [anon_sym_case] = ACTIONS(6070),
    [anon_sym_CASE] = ACTIONS(6070),
    [anon_sym_Case] = ACTIONS(6070),
    [anon_sym_for] = ACTIONS(6070),
    [anon_sym_FOR] = ACTIONS(6070),
    [anon_sym_For] = ACTIONS(6070),
    [anon_sym_foreach] = ACTIONS(6070),
    [anon_sym_FOREACH] = ACTIONS(6070),
    [anon_sym_Foreach] = ACTIONS(6070),
    [anon_sym_while] = ACTIONS(6070),
    [anon_sym_WHILE] = ACTIONS(6070),
    [anon_sym_While] = ACTIONS(6070),
    [anon_sym_repeat] = ACTIONS(6070),
    [anon_sym_REPEAT] = ACTIONS(6070),
    [anon_sym_Repeat] = ACTIONS(6070),
    [anon_sym_until] = ACTIONS(6070),
    [anon_sym_UNTIL] = ACTIONS(6070),
    [anon_sym_Until] = ACTIONS(6070),
    [anon_sym_exit] = ACTIONS(6070),
    [anon_sym_EXIT] = ACTIONS(6070),
    [anon_sym_Exit] = ACTIONS(6070),
    [anon_sym_continue] = ACTIONS(6070),
    [anon_sym_CONTINUE] = ACTIONS(6070),
    [anon_sym_Continue] = ACTIONS(6070),
    [anon_sym_break] = ACTIONS(6070),
    [anon_sym_BREAK] = ACTIONS(6070),
    [anon_sym_Break] = ACTIONS(6070),
    [anon_sym_with] = ACTIONS(6070),
    [anon_sym_WITH] = ACTIONS(6070),
    [anon_sym_With] = ACTIONS(6070),
    [sym_asserterror_keyword] = ACTIONS(6072),
    [sym_page_keyword] = ACTIONS(6070),
    [anon_sym_codeunit] = ACTIONS(6070),
    [anon_sym_CODEUNIT] = ACTIONS(6070),
    [anon_sym_Codeunit] = ACTIONS(6070),
    [anon_sym_CodeUnit] = ACTIONS(6070),
    [anon_sym_COdeunit] = ACTIONS(6070),
    [anon_sym_codeUnit] = ACTIONS(6070),
    [sym_report_keyword] = ACTIONS(6070),
    [sym_query_keyword] = ACTIONS(6070),
    [anon_sym_xmlport] = ACTIONS(6070),
    [anon_sym_XMLPORT] = ACTIONS(6070),
    [anon_sym_Xmlport] = ACTIONS(6070),
    [anon_sym_XMLport] = ACTIONS(6070),
    [anon_sym_XMLPort] = ACTIONS(6070),
    [anon_sym_XmlPort] = ACTIONS(6070),
    [anon_sym_enum] = ACTIONS(6070),
    [anon_sym_ENUM] = ACTIONS(6070),
    [anon_sym_Enum] = ACTIONS(6070),
    [anon_sym_eNUM] = ACTIONS(6070),
    [anon_sym_eNum] = ACTIONS(6070),
    [anon_sym_ENum] = ACTIONS(6070),
    [sym_quoted_identifier] = ACTIONS(6072),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6072),
    [sym_verbatim_string] = ACTIONS(6072),
    [sym_integer] = ACTIONS(6070),
    [sym_continue_as_identifier] = ACTIONS(6072),
    [sym_preproc_open] = ACTIONS(6072),
  },
  [STATE(2894)] = {
    [sym_identifier] = ACTIONS(6066),
    [anon_sym_SEMI] = ACTIONS(6068),
    [anon_sym_DASH] = ACTIONS(6068),
    [aux_sym_boolean_token1] = ACTIONS(6066),
    [aux_sym_boolean_token2] = ACTIONS(6066),
    [sym_decimal] = ACTIONS(6066),
    [anon_sym_LPAREN] = ACTIONS(6068),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6066),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [aux_sym_record_type_token1] = ACTIONS(6066),
    [aux_sym_basic_type_token21] = ACTIONS(6066),
    [aux_sym_basic_type_token22] = ACTIONS(6066),
    [aux_sym_basic_type_token48] = ACTIONS(6066),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6066),
    [anon_sym_POUNDif] = ACTIONS(6068),
    [anon_sym_POUNDIF] = ACTIONS(6068),
    [anon_sym_POUNDIf] = ACTIONS(6068),
    [anon_sym_not] = ACTIONS(6066),
    [anon_sym_NOT] = ACTIONS(6066),
    [anon_sym_Not] = ACTIONS(6066),
    [anon_sym_POUNDelse] = ACTIONS(6068),
    [anon_sym_POUNDELSE] = ACTIONS(6068),
    [anon_sym_POUNDElse] = ACTIONS(6068),
    [anon_sym_POUNDelse2] = ACTIONS(6068),
    [anon_sym_POUNDELSE2] = ACTIONS(6068),
    [anon_sym_POUNDElse2] = ACTIONS(6068),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6066),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6066),
    [anon_sym_PLUS] = ACTIONS(6068),
    [sym_datetime_literal] = ACTIONS(6068),
    [sym_date_literal] = ACTIONS(6066),
    [sym_time_literal] = ACTIONS(6066),
    [sym_biginteger_literal] = ACTIONS(6068),
    [anon_sym_if] = ACTIONS(6066),
    [anon_sym_IF] = ACTIONS(6066),
    [anon_sym_If] = ACTIONS(6066),
    [anon_sym_else] = ACTIONS(6066),
    [anon_sym_ELSE] = ACTIONS(6066),
    [anon_sym_Else] = ACTIONS(6066),
    [anon_sym_case] = ACTIONS(6066),
    [anon_sym_CASE] = ACTIONS(6066),
    [anon_sym_Case] = ACTIONS(6066),
    [anon_sym_for] = ACTIONS(6066),
    [anon_sym_FOR] = ACTIONS(6066),
    [anon_sym_For] = ACTIONS(6066),
    [anon_sym_foreach] = ACTIONS(6066),
    [anon_sym_FOREACH] = ACTIONS(6066),
    [anon_sym_Foreach] = ACTIONS(6066),
    [anon_sym_while] = ACTIONS(6066),
    [anon_sym_WHILE] = ACTIONS(6066),
    [anon_sym_While] = ACTIONS(6066),
    [anon_sym_repeat] = ACTIONS(6066),
    [anon_sym_REPEAT] = ACTIONS(6066),
    [anon_sym_Repeat] = ACTIONS(6066),
    [anon_sym_until] = ACTIONS(6066),
    [anon_sym_UNTIL] = ACTIONS(6066),
    [anon_sym_Until] = ACTIONS(6066),
    [anon_sym_exit] = ACTIONS(6066),
    [anon_sym_EXIT] = ACTIONS(6066),
    [anon_sym_Exit] = ACTIONS(6066),
    [anon_sym_continue] = ACTIONS(6066),
    [anon_sym_CONTINUE] = ACTIONS(6066),
    [anon_sym_Continue] = ACTIONS(6066),
    [anon_sym_break] = ACTIONS(6066),
    [anon_sym_BREAK] = ACTIONS(6066),
    [anon_sym_Break] = ACTIONS(6066),
    [anon_sym_with] = ACTIONS(6066),
    [anon_sym_WITH] = ACTIONS(6066),
    [anon_sym_With] = ACTIONS(6066),
    [sym_asserterror_keyword] = ACTIONS(6068),
    [sym_page_keyword] = ACTIONS(6066),
    [anon_sym_codeunit] = ACTIONS(6066),
    [anon_sym_CODEUNIT] = ACTIONS(6066),
    [anon_sym_Codeunit] = ACTIONS(6066),
    [anon_sym_CodeUnit] = ACTIONS(6066),
    [anon_sym_COdeunit] = ACTIONS(6066),
    [anon_sym_codeUnit] = ACTIONS(6066),
    [sym_report_keyword] = ACTIONS(6066),
    [sym_query_keyword] = ACTIONS(6066),
    [anon_sym_xmlport] = ACTIONS(6066),
    [anon_sym_XMLPORT] = ACTIONS(6066),
    [anon_sym_Xmlport] = ACTIONS(6066),
    [anon_sym_XMLport] = ACTIONS(6066),
    [anon_sym_XMLPort] = ACTIONS(6066),
    [anon_sym_XmlPort] = ACTIONS(6066),
    [anon_sym_enum] = ACTIONS(6066),
    [anon_sym_ENUM] = ACTIONS(6066),
    [anon_sym_Enum] = ACTIONS(6066),
    [anon_sym_eNUM] = ACTIONS(6066),
    [anon_sym_eNum] = ACTIONS(6066),
    [anon_sym_ENum] = ACTIONS(6066),
    [sym_quoted_identifier] = ACTIONS(6068),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6068),
    [sym_verbatim_string] = ACTIONS(6068),
    [sym_integer] = ACTIONS(6066),
    [sym_continue_as_identifier] = ACTIONS(6068),
    [sym_preproc_open] = ACTIONS(6068),
  },
  [STATE(2895)] = {
    [sym_identifier] = ACTIONS(6074),
    [anon_sym_SEMI] = ACTIONS(6076),
    [anon_sym_DASH] = ACTIONS(6076),
    [aux_sym_boolean_token1] = ACTIONS(6074),
    [aux_sym_boolean_token2] = ACTIONS(6074),
    [sym_decimal] = ACTIONS(6074),
    [anon_sym_LPAREN] = ACTIONS(6076),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6074),
    [anon_sym_LBRACK] = ACTIONS(6076),
    [aux_sym_record_type_token1] = ACTIONS(6074),
    [aux_sym_basic_type_token21] = ACTIONS(6074),
    [aux_sym_basic_type_token22] = ACTIONS(6074),
    [aux_sym_basic_type_token48] = ACTIONS(6074),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6074),
    [anon_sym_POUNDif] = ACTIONS(6076),
    [anon_sym_POUNDIF] = ACTIONS(6076),
    [anon_sym_POUNDIf] = ACTIONS(6076),
    [anon_sym_not] = ACTIONS(6074),
    [anon_sym_NOT] = ACTIONS(6074),
    [anon_sym_Not] = ACTIONS(6074),
    [anon_sym_POUNDelse] = ACTIONS(6076),
    [anon_sym_POUNDELSE] = ACTIONS(6076),
    [anon_sym_POUNDElse] = ACTIONS(6076),
    [anon_sym_POUNDelse2] = ACTIONS(6076),
    [anon_sym_POUNDELSE2] = ACTIONS(6076),
    [anon_sym_POUNDElse2] = ACTIONS(6076),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6074),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6074),
    [anon_sym_PLUS] = ACTIONS(6076),
    [sym_datetime_literal] = ACTIONS(6076),
    [sym_date_literal] = ACTIONS(6074),
    [sym_time_literal] = ACTIONS(6074),
    [sym_biginteger_literal] = ACTIONS(6076),
    [anon_sym_if] = ACTIONS(6074),
    [anon_sym_IF] = ACTIONS(6074),
    [anon_sym_If] = ACTIONS(6074),
    [anon_sym_else] = ACTIONS(6074),
    [anon_sym_ELSE] = ACTIONS(6074),
    [anon_sym_Else] = ACTIONS(6074),
    [anon_sym_case] = ACTIONS(6074),
    [anon_sym_CASE] = ACTIONS(6074),
    [anon_sym_Case] = ACTIONS(6074),
    [anon_sym_for] = ACTIONS(6074),
    [anon_sym_FOR] = ACTIONS(6074),
    [anon_sym_For] = ACTIONS(6074),
    [anon_sym_foreach] = ACTIONS(6074),
    [anon_sym_FOREACH] = ACTIONS(6074),
    [anon_sym_Foreach] = ACTIONS(6074),
    [anon_sym_while] = ACTIONS(6074),
    [anon_sym_WHILE] = ACTIONS(6074),
    [anon_sym_While] = ACTIONS(6074),
    [anon_sym_repeat] = ACTIONS(6074),
    [anon_sym_REPEAT] = ACTIONS(6074),
    [anon_sym_Repeat] = ACTIONS(6074),
    [anon_sym_until] = ACTIONS(6074),
    [anon_sym_UNTIL] = ACTIONS(6074),
    [anon_sym_Until] = ACTIONS(6074),
    [anon_sym_exit] = ACTIONS(6074),
    [anon_sym_EXIT] = ACTIONS(6074),
    [anon_sym_Exit] = ACTIONS(6074),
    [anon_sym_continue] = ACTIONS(6074),
    [anon_sym_CONTINUE] = ACTIONS(6074),
    [anon_sym_Continue] = ACTIONS(6074),
    [anon_sym_break] = ACTIONS(6074),
    [anon_sym_BREAK] = ACTIONS(6074),
    [anon_sym_Break] = ACTIONS(6074),
    [anon_sym_with] = ACTIONS(6074),
    [anon_sym_WITH] = ACTIONS(6074),
    [anon_sym_With] = ACTIONS(6074),
    [sym_asserterror_keyword] = ACTIONS(6076),
    [sym_page_keyword] = ACTIONS(6074),
    [anon_sym_codeunit] = ACTIONS(6074),
    [anon_sym_CODEUNIT] = ACTIONS(6074),
    [anon_sym_Codeunit] = ACTIONS(6074),
    [anon_sym_CodeUnit] = ACTIONS(6074),
    [anon_sym_COdeunit] = ACTIONS(6074),
    [anon_sym_codeUnit] = ACTIONS(6074),
    [sym_report_keyword] = ACTIONS(6074),
    [sym_query_keyword] = ACTIONS(6074),
    [anon_sym_xmlport] = ACTIONS(6074),
    [anon_sym_XMLPORT] = ACTIONS(6074),
    [anon_sym_Xmlport] = ACTIONS(6074),
    [anon_sym_XMLport] = ACTIONS(6074),
    [anon_sym_XMLPort] = ACTIONS(6074),
    [anon_sym_XmlPort] = ACTIONS(6074),
    [anon_sym_enum] = ACTIONS(6074),
    [anon_sym_ENUM] = ACTIONS(6074),
    [anon_sym_Enum] = ACTIONS(6074),
    [anon_sym_eNUM] = ACTIONS(6074),
    [anon_sym_eNum] = ACTIONS(6074),
    [anon_sym_ENum] = ACTIONS(6074),
    [sym_quoted_identifier] = ACTIONS(6076),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6076),
    [sym_verbatim_string] = ACTIONS(6076),
    [sym_integer] = ACTIONS(6074),
    [sym_continue_as_identifier] = ACTIONS(6076),
    [sym_preproc_open] = ACTIONS(6076),
  },
  [STATE(2896)] = {
    [sym_identifier] = ACTIONS(6078),
    [anon_sym_SEMI] = ACTIONS(6080),
    [anon_sym_DASH] = ACTIONS(6080),
    [aux_sym_boolean_token1] = ACTIONS(6078),
    [aux_sym_boolean_token2] = ACTIONS(6078),
    [sym_decimal] = ACTIONS(6078),
    [anon_sym_LPAREN] = ACTIONS(6080),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6078),
    [anon_sym_LBRACK] = ACTIONS(6080),
    [aux_sym_record_type_token1] = ACTIONS(6078),
    [aux_sym_basic_type_token21] = ACTIONS(6078),
    [aux_sym_basic_type_token22] = ACTIONS(6078),
    [aux_sym_basic_type_token48] = ACTIONS(6078),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6078),
    [anon_sym_POUNDif] = ACTIONS(6080),
    [anon_sym_POUNDIF] = ACTIONS(6080),
    [anon_sym_POUNDIf] = ACTIONS(6080),
    [anon_sym_not] = ACTIONS(6078),
    [anon_sym_NOT] = ACTIONS(6078),
    [anon_sym_Not] = ACTIONS(6078),
    [anon_sym_POUNDelse] = ACTIONS(6080),
    [anon_sym_POUNDELSE] = ACTIONS(6080),
    [anon_sym_POUNDElse] = ACTIONS(6080),
    [anon_sym_POUNDelse2] = ACTIONS(6080),
    [anon_sym_POUNDELSE2] = ACTIONS(6080),
    [anon_sym_POUNDElse2] = ACTIONS(6080),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6078),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6078),
    [anon_sym_PLUS] = ACTIONS(6080),
    [sym_datetime_literal] = ACTIONS(6080),
    [sym_date_literal] = ACTIONS(6078),
    [sym_time_literal] = ACTIONS(6078),
    [sym_biginteger_literal] = ACTIONS(6080),
    [anon_sym_if] = ACTIONS(6078),
    [anon_sym_IF] = ACTIONS(6078),
    [anon_sym_If] = ACTIONS(6078),
    [anon_sym_else] = ACTIONS(6078),
    [anon_sym_ELSE] = ACTIONS(6078),
    [anon_sym_Else] = ACTIONS(6078),
    [anon_sym_case] = ACTIONS(6078),
    [anon_sym_CASE] = ACTIONS(6078),
    [anon_sym_Case] = ACTIONS(6078),
    [anon_sym_for] = ACTIONS(6078),
    [anon_sym_FOR] = ACTIONS(6078),
    [anon_sym_For] = ACTIONS(6078),
    [anon_sym_foreach] = ACTIONS(6078),
    [anon_sym_FOREACH] = ACTIONS(6078),
    [anon_sym_Foreach] = ACTIONS(6078),
    [anon_sym_while] = ACTIONS(6078),
    [anon_sym_WHILE] = ACTIONS(6078),
    [anon_sym_While] = ACTIONS(6078),
    [anon_sym_repeat] = ACTIONS(6078),
    [anon_sym_REPEAT] = ACTIONS(6078),
    [anon_sym_Repeat] = ACTIONS(6078),
    [anon_sym_until] = ACTIONS(6078),
    [anon_sym_UNTIL] = ACTIONS(6078),
    [anon_sym_Until] = ACTIONS(6078),
    [anon_sym_exit] = ACTIONS(6078),
    [anon_sym_EXIT] = ACTIONS(6078),
    [anon_sym_Exit] = ACTIONS(6078),
    [anon_sym_continue] = ACTIONS(6078),
    [anon_sym_CONTINUE] = ACTIONS(6078),
    [anon_sym_Continue] = ACTIONS(6078),
    [anon_sym_break] = ACTIONS(6078),
    [anon_sym_BREAK] = ACTIONS(6078),
    [anon_sym_Break] = ACTIONS(6078),
    [anon_sym_with] = ACTIONS(6078),
    [anon_sym_WITH] = ACTIONS(6078),
    [anon_sym_With] = ACTIONS(6078),
    [sym_asserterror_keyword] = ACTIONS(6080),
    [sym_page_keyword] = ACTIONS(6078),
    [anon_sym_codeunit] = ACTIONS(6078),
    [anon_sym_CODEUNIT] = ACTIONS(6078),
    [anon_sym_Codeunit] = ACTIONS(6078),
    [anon_sym_CodeUnit] = ACTIONS(6078),
    [anon_sym_COdeunit] = ACTIONS(6078),
    [anon_sym_codeUnit] = ACTIONS(6078),
    [sym_report_keyword] = ACTIONS(6078),
    [sym_query_keyword] = ACTIONS(6078),
    [anon_sym_xmlport] = ACTIONS(6078),
    [anon_sym_XMLPORT] = ACTIONS(6078),
    [anon_sym_Xmlport] = ACTIONS(6078),
    [anon_sym_XMLport] = ACTIONS(6078),
    [anon_sym_XMLPort] = ACTIONS(6078),
    [anon_sym_XmlPort] = ACTIONS(6078),
    [anon_sym_enum] = ACTIONS(6078),
    [anon_sym_ENUM] = ACTIONS(6078),
    [anon_sym_Enum] = ACTIONS(6078),
    [anon_sym_eNUM] = ACTIONS(6078),
    [anon_sym_eNum] = ACTIONS(6078),
    [anon_sym_ENum] = ACTIONS(6078),
    [sym_quoted_identifier] = ACTIONS(6080),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6080),
    [sym_verbatim_string] = ACTIONS(6080),
    [sym_integer] = ACTIONS(6078),
    [sym_continue_as_identifier] = ACTIONS(6080),
    [sym_preproc_open] = ACTIONS(6080),
  },
  [STATE(2897)] = {
    [sym_identifier] = ACTIONS(6082),
    [anon_sym_SEMI] = ACTIONS(6084),
    [anon_sym_DASH] = ACTIONS(6084),
    [aux_sym_boolean_token1] = ACTIONS(6082),
    [aux_sym_boolean_token2] = ACTIONS(6082),
    [sym_decimal] = ACTIONS(6082),
    [anon_sym_LPAREN] = ACTIONS(6084),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6082),
    [anon_sym_LBRACK] = ACTIONS(6084),
    [aux_sym_record_type_token1] = ACTIONS(6082),
    [aux_sym_basic_type_token21] = ACTIONS(6082),
    [aux_sym_basic_type_token22] = ACTIONS(6082),
    [aux_sym_basic_type_token48] = ACTIONS(6082),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6082),
    [anon_sym_POUNDif] = ACTIONS(6084),
    [anon_sym_POUNDIF] = ACTIONS(6084),
    [anon_sym_POUNDIf] = ACTIONS(6084),
    [anon_sym_not] = ACTIONS(6082),
    [anon_sym_NOT] = ACTIONS(6082),
    [anon_sym_Not] = ACTIONS(6082),
    [anon_sym_POUNDelse] = ACTIONS(6084),
    [anon_sym_POUNDELSE] = ACTIONS(6084),
    [anon_sym_POUNDElse] = ACTIONS(6084),
    [anon_sym_POUNDelse2] = ACTIONS(6084),
    [anon_sym_POUNDELSE2] = ACTIONS(6084),
    [anon_sym_POUNDElse2] = ACTIONS(6084),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6082),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6082),
    [anon_sym_PLUS] = ACTIONS(6084),
    [sym_datetime_literal] = ACTIONS(6084),
    [sym_date_literal] = ACTIONS(6082),
    [sym_time_literal] = ACTIONS(6082),
    [sym_biginteger_literal] = ACTIONS(6084),
    [anon_sym_if] = ACTIONS(6082),
    [anon_sym_IF] = ACTIONS(6082),
    [anon_sym_If] = ACTIONS(6082),
    [anon_sym_else] = ACTIONS(6082),
    [anon_sym_ELSE] = ACTIONS(6082),
    [anon_sym_Else] = ACTIONS(6082),
    [anon_sym_case] = ACTIONS(6082),
    [anon_sym_CASE] = ACTIONS(6082),
    [anon_sym_Case] = ACTIONS(6082),
    [anon_sym_for] = ACTIONS(6082),
    [anon_sym_FOR] = ACTIONS(6082),
    [anon_sym_For] = ACTIONS(6082),
    [anon_sym_foreach] = ACTIONS(6082),
    [anon_sym_FOREACH] = ACTIONS(6082),
    [anon_sym_Foreach] = ACTIONS(6082),
    [anon_sym_while] = ACTIONS(6082),
    [anon_sym_WHILE] = ACTIONS(6082),
    [anon_sym_While] = ACTIONS(6082),
    [anon_sym_repeat] = ACTIONS(6082),
    [anon_sym_REPEAT] = ACTIONS(6082),
    [anon_sym_Repeat] = ACTIONS(6082),
    [anon_sym_until] = ACTIONS(6082),
    [anon_sym_UNTIL] = ACTIONS(6082),
    [anon_sym_Until] = ACTIONS(6082),
    [anon_sym_exit] = ACTIONS(6082),
    [anon_sym_EXIT] = ACTIONS(6082),
    [anon_sym_Exit] = ACTIONS(6082),
    [anon_sym_continue] = ACTIONS(6082),
    [anon_sym_CONTINUE] = ACTIONS(6082),
    [anon_sym_Continue] = ACTIONS(6082),
    [anon_sym_break] = ACTIONS(6082),
    [anon_sym_BREAK] = ACTIONS(6082),
    [anon_sym_Break] = ACTIONS(6082),
    [anon_sym_with] = ACTIONS(6082),
    [anon_sym_WITH] = ACTIONS(6082),
    [anon_sym_With] = ACTIONS(6082),
    [sym_asserterror_keyword] = ACTIONS(6084),
    [sym_page_keyword] = ACTIONS(6082),
    [anon_sym_codeunit] = ACTIONS(6082),
    [anon_sym_CODEUNIT] = ACTIONS(6082),
    [anon_sym_Codeunit] = ACTIONS(6082),
    [anon_sym_CodeUnit] = ACTIONS(6082),
    [anon_sym_COdeunit] = ACTIONS(6082),
    [anon_sym_codeUnit] = ACTIONS(6082),
    [sym_report_keyword] = ACTIONS(6082),
    [sym_query_keyword] = ACTIONS(6082),
    [anon_sym_xmlport] = ACTIONS(6082),
    [anon_sym_XMLPORT] = ACTIONS(6082),
    [anon_sym_Xmlport] = ACTIONS(6082),
    [anon_sym_XMLport] = ACTIONS(6082),
    [anon_sym_XMLPort] = ACTIONS(6082),
    [anon_sym_XmlPort] = ACTIONS(6082),
    [anon_sym_enum] = ACTIONS(6082),
    [anon_sym_ENUM] = ACTIONS(6082),
    [anon_sym_Enum] = ACTIONS(6082),
    [anon_sym_eNUM] = ACTIONS(6082),
    [anon_sym_eNum] = ACTIONS(6082),
    [anon_sym_ENum] = ACTIONS(6082),
    [sym_quoted_identifier] = ACTIONS(6084),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6084),
    [sym_verbatim_string] = ACTIONS(6084),
    [sym_integer] = ACTIONS(6082),
    [sym_continue_as_identifier] = ACTIONS(6084),
    [sym_preproc_open] = ACTIONS(6084),
  },
  [STATE(2898)] = {
    [sym_identifier] = ACTIONS(6086),
    [anon_sym_SEMI] = ACTIONS(6088),
    [anon_sym_DASH] = ACTIONS(6088),
    [aux_sym_boolean_token1] = ACTIONS(6086),
    [aux_sym_boolean_token2] = ACTIONS(6086),
    [sym_decimal] = ACTIONS(6086),
    [anon_sym_LPAREN] = ACTIONS(6088),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6086),
    [anon_sym_LBRACK] = ACTIONS(6088),
    [aux_sym_record_type_token1] = ACTIONS(6086),
    [aux_sym_basic_type_token21] = ACTIONS(6086),
    [aux_sym_basic_type_token22] = ACTIONS(6086),
    [aux_sym_basic_type_token48] = ACTIONS(6086),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6086),
    [anon_sym_POUNDif] = ACTIONS(6088),
    [anon_sym_POUNDIF] = ACTIONS(6088),
    [anon_sym_POUNDIf] = ACTIONS(6088),
    [anon_sym_not] = ACTIONS(6086),
    [anon_sym_NOT] = ACTIONS(6086),
    [anon_sym_Not] = ACTIONS(6086),
    [anon_sym_POUNDelse] = ACTIONS(6088),
    [anon_sym_POUNDELSE] = ACTIONS(6088),
    [anon_sym_POUNDElse] = ACTIONS(6088),
    [anon_sym_POUNDelse2] = ACTIONS(6088),
    [anon_sym_POUNDELSE2] = ACTIONS(6088),
    [anon_sym_POUNDElse2] = ACTIONS(6088),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6086),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6086),
    [anon_sym_PLUS] = ACTIONS(6088),
    [sym_datetime_literal] = ACTIONS(6088),
    [sym_date_literal] = ACTIONS(6086),
    [sym_time_literal] = ACTIONS(6086),
    [sym_biginteger_literal] = ACTIONS(6088),
    [anon_sym_if] = ACTIONS(6086),
    [anon_sym_IF] = ACTIONS(6086),
    [anon_sym_If] = ACTIONS(6086),
    [anon_sym_else] = ACTIONS(6086),
    [anon_sym_ELSE] = ACTIONS(6086),
    [anon_sym_Else] = ACTIONS(6086),
    [anon_sym_case] = ACTIONS(6086),
    [anon_sym_CASE] = ACTIONS(6086),
    [anon_sym_Case] = ACTIONS(6086),
    [anon_sym_for] = ACTIONS(6086),
    [anon_sym_FOR] = ACTIONS(6086),
    [anon_sym_For] = ACTIONS(6086),
    [anon_sym_foreach] = ACTIONS(6086),
    [anon_sym_FOREACH] = ACTIONS(6086),
    [anon_sym_Foreach] = ACTIONS(6086),
    [anon_sym_while] = ACTIONS(6086),
    [anon_sym_WHILE] = ACTIONS(6086),
    [anon_sym_While] = ACTIONS(6086),
    [anon_sym_repeat] = ACTIONS(6086),
    [anon_sym_REPEAT] = ACTIONS(6086),
    [anon_sym_Repeat] = ACTIONS(6086),
    [anon_sym_until] = ACTIONS(6086),
    [anon_sym_UNTIL] = ACTIONS(6086),
    [anon_sym_Until] = ACTIONS(6086),
    [anon_sym_exit] = ACTIONS(6086),
    [anon_sym_EXIT] = ACTIONS(6086),
    [anon_sym_Exit] = ACTIONS(6086),
    [anon_sym_continue] = ACTIONS(6086),
    [anon_sym_CONTINUE] = ACTIONS(6086),
    [anon_sym_Continue] = ACTIONS(6086),
    [anon_sym_break] = ACTIONS(6086),
    [anon_sym_BREAK] = ACTIONS(6086),
    [anon_sym_Break] = ACTIONS(6086),
    [anon_sym_with] = ACTIONS(6086),
    [anon_sym_WITH] = ACTIONS(6086),
    [anon_sym_With] = ACTIONS(6086),
    [sym_asserterror_keyword] = ACTIONS(6088),
    [sym_page_keyword] = ACTIONS(6086),
    [anon_sym_codeunit] = ACTIONS(6086),
    [anon_sym_CODEUNIT] = ACTIONS(6086),
    [anon_sym_Codeunit] = ACTIONS(6086),
    [anon_sym_CodeUnit] = ACTIONS(6086),
    [anon_sym_COdeunit] = ACTIONS(6086),
    [anon_sym_codeUnit] = ACTIONS(6086),
    [sym_report_keyword] = ACTIONS(6086),
    [sym_query_keyword] = ACTIONS(6086),
    [anon_sym_xmlport] = ACTIONS(6086),
    [anon_sym_XMLPORT] = ACTIONS(6086),
    [anon_sym_Xmlport] = ACTIONS(6086),
    [anon_sym_XMLport] = ACTIONS(6086),
    [anon_sym_XMLPort] = ACTIONS(6086),
    [anon_sym_XmlPort] = ACTIONS(6086),
    [anon_sym_enum] = ACTIONS(6086),
    [anon_sym_ENUM] = ACTIONS(6086),
    [anon_sym_Enum] = ACTIONS(6086),
    [anon_sym_eNUM] = ACTIONS(6086),
    [anon_sym_eNum] = ACTIONS(6086),
    [anon_sym_ENum] = ACTIONS(6086),
    [sym_quoted_identifier] = ACTIONS(6088),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6088),
    [sym_verbatim_string] = ACTIONS(6088),
    [sym_integer] = ACTIONS(6086),
    [sym_continue_as_identifier] = ACTIONS(6088),
    [sym_preproc_open] = ACTIONS(6088),
  },
  [STATE(2899)] = {
    [sym_identifier] = ACTIONS(6090),
    [anon_sym_SEMI] = ACTIONS(6092),
    [anon_sym_DASH] = ACTIONS(6092),
    [aux_sym_boolean_token1] = ACTIONS(6090),
    [aux_sym_boolean_token2] = ACTIONS(6090),
    [sym_decimal] = ACTIONS(6090),
    [anon_sym_LPAREN] = ACTIONS(6092),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6090),
    [anon_sym_LBRACK] = ACTIONS(6092),
    [aux_sym_record_type_token1] = ACTIONS(6090),
    [aux_sym_basic_type_token21] = ACTIONS(6090),
    [aux_sym_basic_type_token22] = ACTIONS(6090),
    [aux_sym_basic_type_token48] = ACTIONS(6090),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6090),
    [anon_sym_POUNDif] = ACTIONS(6092),
    [anon_sym_POUNDIF] = ACTIONS(6092),
    [anon_sym_POUNDIf] = ACTIONS(6092),
    [anon_sym_not] = ACTIONS(6090),
    [anon_sym_NOT] = ACTIONS(6090),
    [anon_sym_Not] = ACTIONS(6090),
    [anon_sym_POUNDelse] = ACTIONS(6092),
    [anon_sym_POUNDELSE] = ACTIONS(6092),
    [anon_sym_POUNDElse] = ACTIONS(6092),
    [anon_sym_POUNDelse2] = ACTIONS(6092),
    [anon_sym_POUNDELSE2] = ACTIONS(6092),
    [anon_sym_POUNDElse2] = ACTIONS(6092),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6090),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6090),
    [anon_sym_PLUS] = ACTIONS(6092),
    [sym_datetime_literal] = ACTIONS(6092),
    [sym_date_literal] = ACTIONS(6090),
    [sym_time_literal] = ACTIONS(6090),
    [sym_biginteger_literal] = ACTIONS(6092),
    [anon_sym_if] = ACTIONS(6090),
    [anon_sym_IF] = ACTIONS(6090),
    [anon_sym_If] = ACTIONS(6090),
    [anon_sym_else] = ACTIONS(6090),
    [anon_sym_ELSE] = ACTIONS(6090),
    [anon_sym_Else] = ACTIONS(6090),
    [anon_sym_case] = ACTIONS(6090),
    [anon_sym_CASE] = ACTIONS(6090),
    [anon_sym_Case] = ACTIONS(6090),
    [anon_sym_for] = ACTIONS(6090),
    [anon_sym_FOR] = ACTIONS(6090),
    [anon_sym_For] = ACTIONS(6090),
    [anon_sym_foreach] = ACTIONS(6090),
    [anon_sym_FOREACH] = ACTIONS(6090),
    [anon_sym_Foreach] = ACTIONS(6090),
    [anon_sym_while] = ACTIONS(6090),
    [anon_sym_WHILE] = ACTIONS(6090),
    [anon_sym_While] = ACTIONS(6090),
    [anon_sym_repeat] = ACTIONS(6090),
    [anon_sym_REPEAT] = ACTIONS(6090),
    [anon_sym_Repeat] = ACTIONS(6090),
    [anon_sym_until] = ACTIONS(6090),
    [anon_sym_UNTIL] = ACTIONS(6090),
    [anon_sym_Until] = ACTIONS(6090),
    [anon_sym_exit] = ACTIONS(6090),
    [anon_sym_EXIT] = ACTIONS(6090),
    [anon_sym_Exit] = ACTIONS(6090),
    [anon_sym_continue] = ACTIONS(6090),
    [anon_sym_CONTINUE] = ACTIONS(6090),
    [anon_sym_Continue] = ACTIONS(6090),
    [anon_sym_break] = ACTIONS(6090),
    [anon_sym_BREAK] = ACTIONS(6090),
    [anon_sym_Break] = ACTIONS(6090),
    [anon_sym_with] = ACTIONS(6090),
    [anon_sym_WITH] = ACTIONS(6090),
    [anon_sym_With] = ACTIONS(6090),
    [sym_asserterror_keyword] = ACTIONS(6092),
    [sym_page_keyword] = ACTIONS(6090),
    [anon_sym_codeunit] = ACTIONS(6090),
    [anon_sym_CODEUNIT] = ACTIONS(6090),
    [anon_sym_Codeunit] = ACTIONS(6090),
    [anon_sym_CodeUnit] = ACTIONS(6090),
    [anon_sym_COdeunit] = ACTIONS(6090),
    [anon_sym_codeUnit] = ACTIONS(6090),
    [sym_report_keyword] = ACTIONS(6090),
    [sym_query_keyword] = ACTIONS(6090),
    [anon_sym_xmlport] = ACTIONS(6090),
    [anon_sym_XMLPORT] = ACTIONS(6090),
    [anon_sym_Xmlport] = ACTIONS(6090),
    [anon_sym_XMLport] = ACTIONS(6090),
    [anon_sym_XMLPort] = ACTIONS(6090),
    [anon_sym_XmlPort] = ACTIONS(6090),
    [anon_sym_enum] = ACTIONS(6090),
    [anon_sym_ENUM] = ACTIONS(6090),
    [anon_sym_Enum] = ACTIONS(6090),
    [anon_sym_eNUM] = ACTIONS(6090),
    [anon_sym_eNum] = ACTIONS(6090),
    [anon_sym_ENum] = ACTIONS(6090),
    [sym_quoted_identifier] = ACTIONS(6092),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6092),
    [sym_verbatim_string] = ACTIONS(6092),
    [sym_integer] = ACTIONS(6090),
    [sym_continue_as_identifier] = ACTIONS(6092),
    [sym_preproc_open] = ACTIONS(6092),
  },
  [STATE(2900)] = {
    [sym_identifier] = ACTIONS(6086),
    [anon_sym_SEMI] = ACTIONS(6088),
    [anon_sym_DASH] = ACTIONS(6088),
    [aux_sym_boolean_token1] = ACTIONS(6086),
    [aux_sym_boolean_token2] = ACTIONS(6086),
    [sym_decimal] = ACTIONS(6086),
    [anon_sym_LPAREN] = ACTIONS(6088),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6086),
    [anon_sym_LBRACK] = ACTIONS(6088),
    [aux_sym_record_type_token1] = ACTIONS(6086),
    [aux_sym_basic_type_token21] = ACTIONS(6086),
    [aux_sym_basic_type_token22] = ACTIONS(6086),
    [aux_sym_basic_type_token48] = ACTIONS(6086),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6086),
    [anon_sym_POUNDif] = ACTIONS(6088),
    [anon_sym_POUNDIF] = ACTIONS(6088),
    [anon_sym_POUNDIf] = ACTIONS(6088),
    [anon_sym_not] = ACTIONS(6086),
    [anon_sym_NOT] = ACTIONS(6086),
    [anon_sym_Not] = ACTIONS(6086),
    [anon_sym_POUNDelse] = ACTIONS(6088),
    [anon_sym_POUNDELSE] = ACTIONS(6088),
    [anon_sym_POUNDElse] = ACTIONS(6088),
    [anon_sym_POUNDelse2] = ACTIONS(6088),
    [anon_sym_POUNDELSE2] = ACTIONS(6088),
    [anon_sym_POUNDElse2] = ACTIONS(6088),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6086),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6086),
    [anon_sym_PLUS] = ACTIONS(6088),
    [sym_datetime_literal] = ACTIONS(6088),
    [sym_date_literal] = ACTIONS(6086),
    [sym_time_literal] = ACTIONS(6086),
    [sym_biginteger_literal] = ACTIONS(6088),
    [anon_sym_if] = ACTIONS(6086),
    [anon_sym_IF] = ACTIONS(6086),
    [anon_sym_If] = ACTIONS(6086),
    [anon_sym_else] = ACTIONS(6086),
    [anon_sym_ELSE] = ACTIONS(6086),
    [anon_sym_Else] = ACTIONS(6086),
    [anon_sym_case] = ACTIONS(6086),
    [anon_sym_CASE] = ACTIONS(6086),
    [anon_sym_Case] = ACTIONS(6086),
    [anon_sym_for] = ACTIONS(6086),
    [anon_sym_FOR] = ACTIONS(6086),
    [anon_sym_For] = ACTIONS(6086),
    [anon_sym_foreach] = ACTIONS(6086),
    [anon_sym_FOREACH] = ACTIONS(6086),
    [anon_sym_Foreach] = ACTIONS(6086),
    [anon_sym_while] = ACTIONS(6086),
    [anon_sym_WHILE] = ACTIONS(6086),
    [anon_sym_While] = ACTIONS(6086),
    [anon_sym_repeat] = ACTIONS(6086),
    [anon_sym_REPEAT] = ACTIONS(6086),
    [anon_sym_Repeat] = ACTIONS(6086),
    [anon_sym_until] = ACTIONS(6086),
    [anon_sym_UNTIL] = ACTIONS(6086),
    [anon_sym_Until] = ACTIONS(6086),
    [anon_sym_exit] = ACTIONS(6086),
    [anon_sym_EXIT] = ACTIONS(6086),
    [anon_sym_Exit] = ACTIONS(6086),
    [anon_sym_continue] = ACTIONS(6086),
    [anon_sym_CONTINUE] = ACTIONS(6086),
    [anon_sym_Continue] = ACTIONS(6086),
    [anon_sym_break] = ACTIONS(6086),
    [anon_sym_BREAK] = ACTIONS(6086),
    [anon_sym_Break] = ACTIONS(6086),
    [anon_sym_with] = ACTIONS(6086),
    [anon_sym_WITH] = ACTIONS(6086),
    [anon_sym_With] = ACTIONS(6086),
    [sym_asserterror_keyword] = ACTIONS(6088),
    [sym_page_keyword] = ACTIONS(6086),
    [anon_sym_codeunit] = ACTIONS(6086),
    [anon_sym_CODEUNIT] = ACTIONS(6086),
    [anon_sym_Codeunit] = ACTIONS(6086),
    [anon_sym_CodeUnit] = ACTIONS(6086),
    [anon_sym_COdeunit] = ACTIONS(6086),
    [anon_sym_codeUnit] = ACTIONS(6086),
    [sym_report_keyword] = ACTIONS(6086),
    [sym_query_keyword] = ACTIONS(6086),
    [anon_sym_xmlport] = ACTIONS(6086),
    [anon_sym_XMLPORT] = ACTIONS(6086),
    [anon_sym_Xmlport] = ACTIONS(6086),
    [anon_sym_XMLport] = ACTIONS(6086),
    [anon_sym_XMLPort] = ACTIONS(6086),
    [anon_sym_XmlPort] = ACTIONS(6086),
    [anon_sym_enum] = ACTIONS(6086),
    [anon_sym_ENUM] = ACTIONS(6086),
    [anon_sym_Enum] = ACTIONS(6086),
    [anon_sym_eNUM] = ACTIONS(6086),
    [anon_sym_eNum] = ACTIONS(6086),
    [anon_sym_ENum] = ACTIONS(6086),
    [sym_quoted_identifier] = ACTIONS(6088),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6088),
    [sym_verbatim_string] = ACTIONS(6088),
    [sym_integer] = ACTIONS(6086),
    [sym_continue_as_identifier] = ACTIONS(6088),
    [sym_preproc_open] = ACTIONS(6088),
  },
  [STATE(2901)] = {
    [sym_identifier] = ACTIONS(6094),
    [anon_sym_SEMI] = ACTIONS(6096),
    [anon_sym_DASH] = ACTIONS(6096),
    [aux_sym_boolean_token1] = ACTIONS(6094),
    [aux_sym_boolean_token2] = ACTIONS(6094),
    [sym_decimal] = ACTIONS(6094),
    [anon_sym_LPAREN] = ACTIONS(6096),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6094),
    [anon_sym_LBRACK] = ACTIONS(6096),
    [aux_sym_record_type_token1] = ACTIONS(6094),
    [aux_sym_basic_type_token21] = ACTIONS(6094),
    [aux_sym_basic_type_token22] = ACTIONS(6094),
    [aux_sym_basic_type_token48] = ACTIONS(6094),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6094),
    [anon_sym_POUNDif] = ACTIONS(6096),
    [anon_sym_POUNDIF] = ACTIONS(6096),
    [anon_sym_POUNDIf] = ACTIONS(6096),
    [anon_sym_not] = ACTIONS(6094),
    [anon_sym_NOT] = ACTIONS(6094),
    [anon_sym_Not] = ACTIONS(6094),
    [anon_sym_POUNDelse] = ACTIONS(6096),
    [anon_sym_POUNDELSE] = ACTIONS(6096),
    [anon_sym_POUNDElse] = ACTIONS(6096),
    [anon_sym_POUNDelse2] = ACTIONS(6096),
    [anon_sym_POUNDELSE2] = ACTIONS(6096),
    [anon_sym_POUNDElse2] = ACTIONS(6096),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6094),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6094),
    [anon_sym_PLUS] = ACTIONS(6096),
    [sym_datetime_literal] = ACTIONS(6096),
    [sym_date_literal] = ACTIONS(6094),
    [sym_time_literal] = ACTIONS(6094),
    [sym_biginteger_literal] = ACTIONS(6096),
    [anon_sym_if] = ACTIONS(6094),
    [anon_sym_IF] = ACTIONS(6094),
    [anon_sym_If] = ACTIONS(6094),
    [anon_sym_else] = ACTIONS(6094),
    [anon_sym_ELSE] = ACTIONS(6094),
    [anon_sym_Else] = ACTIONS(6094),
    [anon_sym_case] = ACTIONS(6094),
    [anon_sym_CASE] = ACTIONS(6094),
    [anon_sym_Case] = ACTIONS(6094),
    [anon_sym_for] = ACTIONS(6094),
    [anon_sym_FOR] = ACTIONS(6094),
    [anon_sym_For] = ACTIONS(6094),
    [anon_sym_foreach] = ACTIONS(6094),
    [anon_sym_FOREACH] = ACTIONS(6094),
    [anon_sym_Foreach] = ACTIONS(6094),
    [anon_sym_while] = ACTIONS(6094),
    [anon_sym_WHILE] = ACTIONS(6094),
    [anon_sym_While] = ACTIONS(6094),
    [anon_sym_repeat] = ACTIONS(6094),
    [anon_sym_REPEAT] = ACTIONS(6094),
    [anon_sym_Repeat] = ACTIONS(6094),
    [anon_sym_until] = ACTIONS(6094),
    [anon_sym_UNTIL] = ACTIONS(6094),
    [anon_sym_Until] = ACTIONS(6094),
    [anon_sym_exit] = ACTIONS(6094),
    [anon_sym_EXIT] = ACTIONS(6094),
    [anon_sym_Exit] = ACTIONS(6094),
    [anon_sym_continue] = ACTIONS(6094),
    [anon_sym_CONTINUE] = ACTIONS(6094),
    [anon_sym_Continue] = ACTIONS(6094),
    [anon_sym_break] = ACTIONS(6094),
    [anon_sym_BREAK] = ACTIONS(6094),
    [anon_sym_Break] = ACTIONS(6094),
    [anon_sym_with] = ACTIONS(6094),
    [anon_sym_WITH] = ACTIONS(6094),
    [anon_sym_With] = ACTIONS(6094),
    [sym_asserterror_keyword] = ACTIONS(6096),
    [sym_page_keyword] = ACTIONS(6094),
    [anon_sym_codeunit] = ACTIONS(6094),
    [anon_sym_CODEUNIT] = ACTIONS(6094),
    [anon_sym_Codeunit] = ACTIONS(6094),
    [anon_sym_CodeUnit] = ACTIONS(6094),
    [anon_sym_COdeunit] = ACTIONS(6094),
    [anon_sym_codeUnit] = ACTIONS(6094),
    [sym_report_keyword] = ACTIONS(6094),
    [sym_query_keyword] = ACTIONS(6094),
    [anon_sym_xmlport] = ACTIONS(6094),
    [anon_sym_XMLPORT] = ACTIONS(6094),
    [anon_sym_Xmlport] = ACTIONS(6094),
    [anon_sym_XMLport] = ACTIONS(6094),
    [anon_sym_XMLPort] = ACTIONS(6094),
    [anon_sym_XmlPort] = ACTIONS(6094),
    [anon_sym_enum] = ACTIONS(6094),
    [anon_sym_ENUM] = ACTIONS(6094),
    [anon_sym_Enum] = ACTIONS(6094),
    [anon_sym_eNUM] = ACTIONS(6094),
    [anon_sym_eNum] = ACTIONS(6094),
    [anon_sym_ENum] = ACTIONS(6094),
    [sym_quoted_identifier] = ACTIONS(6096),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6096),
    [sym_verbatim_string] = ACTIONS(6096),
    [sym_integer] = ACTIONS(6094),
    [sym_continue_as_identifier] = ACTIONS(6096),
    [sym_preproc_open] = ACTIONS(6096),
  },
  [STATE(2902)] = {
    [sym_identifier] = ACTIONS(6098),
    [anon_sym_SEMI] = ACTIONS(6100),
    [anon_sym_DASH] = ACTIONS(6100),
    [aux_sym_boolean_token1] = ACTIONS(6098),
    [aux_sym_boolean_token2] = ACTIONS(6098),
    [sym_decimal] = ACTIONS(6098),
    [anon_sym_LPAREN] = ACTIONS(6100),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6098),
    [anon_sym_LBRACK] = ACTIONS(6100),
    [aux_sym_record_type_token1] = ACTIONS(6098),
    [aux_sym_basic_type_token21] = ACTIONS(6098),
    [aux_sym_basic_type_token22] = ACTIONS(6098),
    [aux_sym_basic_type_token48] = ACTIONS(6098),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6098),
    [anon_sym_POUNDif] = ACTIONS(6100),
    [anon_sym_POUNDIF] = ACTIONS(6100),
    [anon_sym_POUNDIf] = ACTIONS(6100),
    [anon_sym_not] = ACTIONS(6098),
    [anon_sym_NOT] = ACTIONS(6098),
    [anon_sym_Not] = ACTIONS(6098),
    [anon_sym_POUNDelse] = ACTIONS(6100),
    [anon_sym_POUNDELSE] = ACTIONS(6100),
    [anon_sym_POUNDElse] = ACTIONS(6100),
    [anon_sym_POUNDelse2] = ACTIONS(6100),
    [anon_sym_POUNDELSE2] = ACTIONS(6100),
    [anon_sym_POUNDElse2] = ACTIONS(6100),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6098),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6098),
    [anon_sym_PLUS] = ACTIONS(6100),
    [sym_datetime_literal] = ACTIONS(6100),
    [sym_date_literal] = ACTIONS(6098),
    [sym_time_literal] = ACTIONS(6098),
    [sym_biginteger_literal] = ACTIONS(6100),
    [anon_sym_if] = ACTIONS(6098),
    [anon_sym_IF] = ACTIONS(6098),
    [anon_sym_If] = ACTIONS(6098),
    [anon_sym_else] = ACTIONS(6098),
    [anon_sym_ELSE] = ACTIONS(6098),
    [anon_sym_Else] = ACTIONS(6098),
    [anon_sym_case] = ACTIONS(6098),
    [anon_sym_CASE] = ACTIONS(6098),
    [anon_sym_Case] = ACTIONS(6098),
    [anon_sym_for] = ACTIONS(6098),
    [anon_sym_FOR] = ACTIONS(6098),
    [anon_sym_For] = ACTIONS(6098),
    [anon_sym_foreach] = ACTIONS(6098),
    [anon_sym_FOREACH] = ACTIONS(6098),
    [anon_sym_Foreach] = ACTIONS(6098),
    [anon_sym_while] = ACTIONS(6098),
    [anon_sym_WHILE] = ACTIONS(6098),
    [anon_sym_While] = ACTIONS(6098),
    [anon_sym_repeat] = ACTIONS(6098),
    [anon_sym_REPEAT] = ACTIONS(6098),
    [anon_sym_Repeat] = ACTIONS(6098),
    [anon_sym_until] = ACTIONS(6098),
    [anon_sym_UNTIL] = ACTIONS(6098),
    [anon_sym_Until] = ACTIONS(6098),
    [anon_sym_exit] = ACTIONS(6098),
    [anon_sym_EXIT] = ACTIONS(6098),
    [anon_sym_Exit] = ACTIONS(6098),
    [anon_sym_continue] = ACTIONS(6098),
    [anon_sym_CONTINUE] = ACTIONS(6098),
    [anon_sym_Continue] = ACTIONS(6098),
    [anon_sym_break] = ACTIONS(6098),
    [anon_sym_BREAK] = ACTIONS(6098),
    [anon_sym_Break] = ACTIONS(6098),
    [anon_sym_with] = ACTIONS(6098),
    [anon_sym_WITH] = ACTIONS(6098),
    [anon_sym_With] = ACTIONS(6098),
    [sym_asserterror_keyword] = ACTIONS(6100),
    [sym_page_keyword] = ACTIONS(6098),
    [anon_sym_codeunit] = ACTIONS(6098),
    [anon_sym_CODEUNIT] = ACTIONS(6098),
    [anon_sym_Codeunit] = ACTIONS(6098),
    [anon_sym_CodeUnit] = ACTIONS(6098),
    [anon_sym_COdeunit] = ACTIONS(6098),
    [anon_sym_codeUnit] = ACTIONS(6098),
    [sym_report_keyword] = ACTIONS(6098),
    [sym_query_keyword] = ACTIONS(6098),
    [anon_sym_xmlport] = ACTIONS(6098),
    [anon_sym_XMLPORT] = ACTIONS(6098),
    [anon_sym_Xmlport] = ACTIONS(6098),
    [anon_sym_XMLport] = ACTIONS(6098),
    [anon_sym_XMLPort] = ACTIONS(6098),
    [anon_sym_XmlPort] = ACTIONS(6098),
    [anon_sym_enum] = ACTIONS(6098),
    [anon_sym_ENUM] = ACTIONS(6098),
    [anon_sym_Enum] = ACTIONS(6098),
    [anon_sym_eNUM] = ACTIONS(6098),
    [anon_sym_eNum] = ACTIONS(6098),
    [anon_sym_ENum] = ACTIONS(6098),
    [sym_quoted_identifier] = ACTIONS(6100),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6100),
    [sym_verbatim_string] = ACTIONS(6100),
    [sym_integer] = ACTIONS(6098),
    [sym_continue_as_identifier] = ACTIONS(6100),
    [sym_preproc_open] = ACTIONS(6100),
  },
  [STATE(2903)] = {
    [sym_identifier] = ACTIONS(6094),
    [anon_sym_SEMI] = ACTIONS(6096),
    [anon_sym_DASH] = ACTIONS(6096),
    [aux_sym_boolean_token1] = ACTIONS(6094),
    [aux_sym_boolean_token2] = ACTIONS(6094),
    [sym_decimal] = ACTIONS(6094),
    [anon_sym_LPAREN] = ACTIONS(6096),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6094),
    [anon_sym_LBRACK] = ACTIONS(6096),
    [aux_sym_record_type_token1] = ACTIONS(6094),
    [aux_sym_basic_type_token21] = ACTIONS(6094),
    [aux_sym_basic_type_token22] = ACTIONS(6094),
    [aux_sym_basic_type_token48] = ACTIONS(6094),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6094),
    [anon_sym_POUNDif] = ACTIONS(6096),
    [anon_sym_POUNDIF] = ACTIONS(6096),
    [anon_sym_POUNDIf] = ACTIONS(6096),
    [anon_sym_not] = ACTIONS(6094),
    [anon_sym_NOT] = ACTIONS(6094),
    [anon_sym_Not] = ACTIONS(6094),
    [anon_sym_POUNDelse] = ACTIONS(6096),
    [anon_sym_POUNDELSE] = ACTIONS(6096),
    [anon_sym_POUNDElse] = ACTIONS(6096),
    [anon_sym_POUNDelse2] = ACTIONS(6096),
    [anon_sym_POUNDELSE2] = ACTIONS(6096),
    [anon_sym_POUNDElse2] = ACTIONS(6096),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6094),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6094),
    [anon_sym_PLUS] = ACTIONS(6096),
    [sym_datetime_literal] = ACTIONS(6096),
    [sym_date_literal] = ACTIONS(6094),
    [sym_time_literal] = ACTIONS(6094),
    [sym_biginteger_literal] = ACTIONS(6096),
    [anon_sym_if] = ACTIONS(6094),
    [anon_sym_IF] = ACTIONS(6094),
    [anon_sym_If] = ACTIONS(6094),
    [anon_sym_else] = ACTIONS(6094),
    [anon_sym_ELSE] = ACTIONS(6094),
    [anon_sym_Else] = ACTIONS(6094),
    [anon_sym_case] = ACTIONS(6094),
    [anon_sym_CASE] = ACTIONS(6094),
    [anon_sym_Case] = ACTIONS(6094),
    [anon_sym_for] = ACTIONS(6094),
    [anon_sym_FOR] = ACTIONS(6094),
    [anon_sym_For] = ACTIONS(6094),
    [anon_sym_foreach] = ACTIONS(6094),
    [anon_sym_FOREACH] = ACTIONS(6094),
    [anon_sym_Foreach] = ACTIONS(6094),
    [anon_sym_while] = ACTIONS(6094),
    [anon_sym_WHILE] = ACTIONS(6094),
    [anon_sym_While] = ACTIONS(6094),
    [anon_sym_repeat] = ACTIONS(6094),
    [anon_sym_REPEAT] = ACTIONS(6094),
    [anon_sym_Repeat] = ACTIONS(6094),
    [anon_sym_until] = ACTIONS(6094),
    [anon_sym_UNTIL] = ACTIONS(6094),
    [anon_sym_Until] = ACTIONS(6094),
    [anon_sym_exit] = ACTIONS(6094),
    [anon_sym_EXIT] = ACTIONS(6094),
    [anon_sym_Exit] = ACTIONS(6094),
    [anon_sym_continue] = ACTIONS(6094),
    [anon_sym_CONTINUE] = ACTIONS(6094),
    [anon_sym_Continue] = ACTIONS(6094),
    [anon_sym_break] = ACTIONS(6094),
    [anon_sym_BREAK] = ACTIONS(6094),
    [anon_sym_Break] = ACTIONS(6094),
    [anon_sym_with] = ACTIONS(6094),
    [anon_sym_WITH] = ACTIONS(6094),
    [anon_sym_With] = ACTIONS(6094),
    [sym_asserterror_keyword] = ACTIONS(6096),
    [sym_page_keyword] = ACTIONS(6094),
    [anon_sym_codeunit] = ACTIONS(6094),
    [anon_sym_CODEUNIT] = ACTIONS(6094),
    [anon_sym_Codeunit] = ACTIONS(6094),
    [anon_sym_CodeUnit] = ACTIONS(6094),
    [anon_sym_COdeunit] = ACTIONS(6094),
    [anon_sym_codeUnit] = ACTIONS(6094),
    [sym_report_keyword] = ACTIONS(6094),
    [sym_query_keyword] = ACTIONS(6094),
    [anon_sym_xmlport] = ACTIONS(6094),
    [anon_sym_XMLPORT] = ACTIONS(6094),
    [anon_sym_Xmlport] = ACTIONS(6094),
    [anon_sym_XMLport] = ACTIONS(6094),
    [anon_sym_XMLPort] = ACTIONS(6094),
    [anon_sym_XmlPort] = ACTIONS(6094),
    [anon_sym_enum] = ACTIONS(6094),
    [anon_sym_ENUM] = ACTIONS(6094),
    [anon_sym_Enum] = ACTIONS(6094),
    [anon_sym_eNUM] = ACTIONS(6094),
    [anon_sym_eNum] = ACTIONS(6094),
    [anon_sym_ENum] = ACTIONS(6094),
    [sym_quoted_identifier] = ACTIONS(6096),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6096),
    [sym_verbatim_string] = ACTIONS(6096),
    [sym_integer] = ACTIONS(6094),
    [sym_continue_as_identifier] = ACTIONS(6096),
    [sym_preproc_open] = ACTIONS(6096),
  },
  [STATE(2904)] = {
    [sym_identifier] = ACTIONS(6683),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(6685),
    [anon_sym_DASH] = ACTIONS(6687),
    [aux_sym_boolean_token1] = ACTIONS(6683),
    [aux_sym_boolean_token2] = ACTIONS(6683),
    [sym_decimal] = ACTIONS(6683),
    [anon_sym_LPAREN] = ACTIONS(6685),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6683),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(6690),
    [aux_sym_record_type_token1] = ACTIONS(6683),
    [aux_sym_basic_type_token21] = ACTIONS(6683),
    [aux_sym_basic_type_token22] = ACTIONS(6683),
    [aux_sym_basic_type_token48] = ACTIONS(6683),
    [anon_sym_not] = ACTIONS(6683),
    [anon_sym_NOT] = ACTIONS(6683),
    [anon_sym_Not] = ACTIONS(6683),
    [anon_sym_POUNDelif] = ACTIONS(6685),
    [anon_sym_POUNDELIF] = ACTIONS(6685),
    [anon_sym_POUNDElif] = ACTIONS(6685),
    [anon_sym_POUNDelse] = ACTIONS(6685),
    [anon_sym_POUNDELSE] = ACTIONS(6685),
    [anon_sym_POUNDElse] = ACTIONS(6685),
    [anon_sym_POUNDelse2] = ACTIONS(6685),
    [anon_sym_POUNDELSE2] = ACTIONS(6685),
    [anon_sym_POUNDElse2] = ACTIONS(6685),
    [anon_sym_POUNDendif] = ACTIONS(6685),
    [anon_sym_POUNDENDIF] = ACTIONS(6685),
    [anon_sym_POUNDEndif] = ACTIONS(6685),
    [anon_sym_POUNDendif2] = ACTIONS(6685),
    [anon_sym_POUNDENDIF2] = ACTIONS(6685),
    [anon_sym_POUNDEndif2] = ACTIONS(6685),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6683),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6683),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(6687),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(6685),
    [sym_date_literal] = ACTIONS(6683),
    [sym_time_literal] = ACTIONS(6683),
    [sym_biginteger_literal] = ACTIONS(6685),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(6683),
    [anon_sym_codeunit] = ACTIONS(6683),
    [anon_sym_CODEUNIT] = ACTIONS(6683),
    [anon_sym_Codeunit] = ACTIONS(6683),
    [anon_sym_CodeUnit] = ACTIONS(6683),
    [anon_sym_COdeunit] = ACTIONS(6683),
    [anon_sym_codeUnit] = ACTIONS(6683),
    [sym_report_keyword] = ACTIONS(6683),
    [sym_query_keyword] = ACTIONS(6683),
    [anon_sym_xmlport] = ACTIONS(6683),
    [anon_sym_XMLPORT] = ACTIONS(6683),
    [anon_sym_Xmlport] = ACTIONS(6683),
    [anon_sym_XMLport] = ACTIONS(6683),
    [anon_sym_XMLPort] = ACTIONS(6683),
    [anon_sym_XmlPort] = ACTIONS(6683),
    [anon_sym_enum] = ACTIONS(6683),
    [anon_sym_ENUM] = ACTIONS(6683),
    [anon_sym_Enum] = ACTIONS(6683),
    [anon_sym_eNUM] = ACTIONS(6683),
    [anon_sym_eNum] = ACTIONS(6683),
    [anon_sym_ENum] = ACTIONS(6683),
    [sym_quoted_identifier] = ACTIONS(6685),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6685),
    [sym_verbatim_string] = ACTIONS(6685),
    [sym_integer] = ACTIONS(6683),
    [sym_continue_as_identifier] = ACTIONS(6685),
    [sym_preproc_close] = ACTIONS(6685),
  },
  [STATE(2905)] = {
    [sym_identifier] = ACTIONS(6102),
    [anon_sym_SEMI] = ACTIONS(6104),
    [anon_sym_DASH] = ACTIONS(6104),
    [aux_sym_boolean_token1] = ACTIONS(6102),
    [aux_sym_boolean_token2] = ACTIONS(6102),
    [sym_decimal] = ACTIONS(6102),
    [anon_sym_LPAREN] = ACTIONS(6104),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6102),
    [anon_sym_LBRACK] = ACTIONS(6104),
    [aux_sym_record_type_token1] = ACTIONS(6102),
    [aux_sym_basic_type_token21] = ACTIONS(6102),
    [aux_sym_basic_type_token22] = ACTIONS(6102),
    [aux_sym_basic_type_token48] = ACTIONS(6102),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6102),
    [anon_sym_POUNDif] = ACTIONS(6104),
    [anon_sym_POUNDIF] = ACTIONS(6104),
    [anon_sym_POUNDIf] = ACTIONS(6104),
    [anon_sym_not] = ACTIONS(6102),
    [anon_sym_NOT] = ACTIONS(6102),
    [anon_sym_Not] = ACTIONS(6102),
    [anon_sym_POUNDelse] = ACTIONS(6104),
    [anon_sym_POUNDELSE] = ACTIONS(6104),
    [anon_sym_POUNDElse] = ACTIONS(6104),
    [anon_sym_POUNDelse2] = ACTIONS(6104),
    [anon_sym_POUNDELSE2] = ACTIONS(6104),
    [anon_sym_POUNDElse2] = ACTIONS(6104),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6102),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6102),
    [anon_sym_PLUS] = ACTIONS(6104),
    [sym_datetime_literal] = ACTIONS(6104),
    [sym_date_literal] = ACTIONS(6102),
    [sym_time_literal] = ACTIONS(6102),
    [sym_biginteger_literal] = ACTIONS(6104),
    [anon_sym_if] = ACTIONS(6102),
    [anon_sym_IF] = ACTIONS(6102),
    [anon_sym_If] = ACTIONS(6102),
    [anon_sym_else] = ACTIONS(6102),
    [anon_sym_ELSE] = ACTIONS(6102),
    [anon_sym_Else] = ACTIONS(6102),
    [anon_sym_case] = ACTIONS(6102),
    [anon_sym_CASE] = ACTIONS(6102),
    [anon_sym_Case] = ACTIONS(6102),
    [anon_sym_for] = ACTIONS(6102),
    [anon_sym_FOR] = ACTIONS(6102),
    [anon_sym_For] = ACTIONS(6102),
    [anon_sym_foreach] = ACTIONS(6102),
    [anon_sym_FOREACH] = ACTIONS(6102),
    [anon_sym_Foreach] = ACTIONS(6102),
    [anon_sym_while] = ACTIONS(6102),
    [anon_sym_WHILE] = ACTIONS(6102),
    [anon_sym_While] = ACTIONS(6102),
    [anon_sym_repeat] = ACTIONS(6102),
    [anon_sym_REPEAT] = ACTIONS(6102),
    [anon_sym_Repeat] = ACTIONS(6102),
    [anon_sym_until] = ACTIONS(6102),
    [anon_sym_UNTIL] = ACTIONS(6102),
    [anon_sym_Until] = ACTIONS(6102),
    [anon_sym_exit] = ACTIONS(6102),
    [anon_sym_EXIT] = ACTIONS(6102),
    [anon_sym_Exit] = ACTIONS(6102),
    [anon_sym_continue] = ACTIONS(6102),
    [anon_sym_CONTINUE] = ACTIONS(6102),
    [anon_sym_Continue] = ACTIONS(6102),
    [anon_sym_break] = ACTIONS(6102),
    [anon_sym_BREAK] = ACTIONS(6102),
    [anon_sym_Break] = ACTIONS(6102),
    [anon_sym_with] = ACTIONS(6102),
    [anon_sym_WITH] = ACTIONS(6102),
    [anon_sym_With] = ACTIONS(6102),
    [sym_asserterror_keyword] = ACTIONS(6104),
    [sym_page_keyword] = ACTIONS(6102),
    [anon_sym_codeunit] = ACTIONS(6102),
    [anon_sym_CODEUNIT] = ACTIONS(6102),
    [anon_sym_Codeunit] = ACTIONS(6102),
    [anon_sym_CodeUnit] = ACTIONS(6102),
    [anon_sym_COdeunit] = ACTIONS(6102),
    [anon_sym_codeUnit] = ACTIONS(6102),
    [sym_report_keyword] = ACTIONS(6102),
    [sym_query_keyword] = ACTIONS(6102),
    [anon_sym_xmlport] = ACTIONS(6102),
    [anon_sym_XMLPORT] = ACTIONS(6102),
    [anon_sym_Xmlport] = ACTIONS(6102),
    [anon_sym_XMLport] = ACTIONS(6102),
    [anon_sym_XMLPort] = ACTIONS(6102),
    [anon_sym_XmlPort] = ACTIONS(6102),
    [anon_sym_enum] = ACTIONS(6102),
    [anon_sym_ENUM] = ACTIONS(6102),
    [anon_sym_Enum] = ACTIONS(6102),
    [anon_sym_eNUM] = ACTIONS(6102),
    [anon_sym_eNum] = ACTIONS(6102),
    [anon_sym_ENum] = ACTIONS(6102),
    [sym_quoted_identifier] = ACTIONS(6104),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6104),
    [sym_verbatim_string] = ACTIONS(6104),
    [sym_integer] = ACTIONS(6102),
    [sym_continue_as_identifier] = ACTIONS(6104),
    [sym_preproc_open] = ACTIONS(6104),
  },
  [STATE(2906)] = {
    [sym_identifier] = ACTIONS(6106),
    [anon_sym_SEMI] = ACTIONS(6108),
    [anon_sym_DASH] = ACTIONS(6108),
    [aux_sym_boolean_token1] = ACTIONS(6106),
    [aux_sym_boolean_token2] = ACTIONS(6106),
    [sym_decimal] = ACTIONS(6106),
    [anon_sym_LPAREN] = ACTIONS(6108),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6106),
    [anon_sym_LBRACK] = ACTIONS(6108),
    [aux_sym_record_type_token1] = ACTIONS(6106),
    [aux_sym_basic_type_token21] = ACTIONS(6106),
    [aux_sym_basic_type_token22] = ACTIONS(6106),
    [aux_sym_basic_type_token48] = ACTIONS(6106),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6106),
    [anon_sym_POUNDif] = ACTIONS(6108),
    [anon_sym_POUNDIF] = ACTIONS(6108),
    [anon_sym_POUNDIf] = ACTIONS(6108),
    [anon_sym_not] = ACTIONS(6106),
    [anon_sym_NOT] = ACTIONS(6106),
    [anon_sym_Not] = ACTIONS(6106),
    [anon_sym_POUNDelse] = ACTIONS(6108),
    [anon_sym_POUNDELSE] = ACTIONS(6108),
    [anon_sym_POUNDElse] = ACTIONS(6108),
    [anon_sym_POUNDelse2] = ACTIONS(6108),
    [anon_sym_POUNDELSE2] = ACTIONS(6108),
    [anon_sym_POUNDElse2] = ACTIONS(6108),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6106),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6106),
    [anon_sym_PLUS] = ACTIONS(6108),
    [sym_datetime_literal] = ACTIONS(6108),
    [sym_date_literal] = ACTIONS(6106),
    [sym_time_literal] = ACTIONS(6106),
    [sym_biginteger_literal] = ACTIONS(6108),
    [anon_sym_if] = ACTIONS(6106),
    [anon_sym_IF] = ACTIONS(6106),
    [anon_sym_If] = ACTIONS(6106),
    [anon_sym_else] = ACTIONS(6106),
    [anon_sym_ELSE] = ACTIONS(6106),
    [anon_sym_Else] = ACTIONS(6106),
    [anon_sym_case] = ACTIONS(6106),
    [anon_sym_CASE] = ACTIONS(6106),
    [anon_sym_Case] = ACTIONS(6106),
    [anon_sym_for] = ACTIONS(6106),
    [anon_sym_FOR] = ACTIONS(6106),
    [anon_sym_For] = ACTIONS(6106),
    [anon_sym_foreach] = ACTIONS(6106),
    [anon_sym_FOREACH] = ACTIONS(6106),
    [anon_sym_Foreach] = ACTIONS(6106),
    [anon_sym_while] = ACTIONS(6106),
    [anon_sym_WHILE] = ACTIONS(6106),
    [anon_sym_While] = ACTIONS(6106),
    [anon_sym_repeat] = ACTIONS(6106),
    [anon_sym_REPEAT] = ACTIONS(6106),
    [anon_sym_Repeat] = ACTIONS(6106),
    [anon_sym_until] = ACTIONS(6106),
    [anon_sym_UNTIL] = ACTIONS(6106),
    [anon_sym_Until] = ACTIONS(6106),
    [anon_sym_exit] = ACTIONS(6106),
    [anon_sym_EXIT] = ACTIONS(6106),
    [anon_sym_Exit] = ACTIONS(6106),
    [anon_sym_continue] = ACTIONS(6106),
    [anon_sym_CONTINUE] = ACTIONS(6106),
    [anon_sym_Continue] = ACTIONS(6106),
    [anon_sym_break] = ACTIONS(6106),
    [anon_sym_BREAK] = ACTIONS(6106),
    [anon_sym_Break] = ACTIONS(6106),
    [anon_sym_with] = ACTIONS(6106),
    [anon_sym_WITH] = ACTIONS(6106),
    [anon_sym_With] = ACTIONS(6106),
    [sym_asserterror_keyword] = ACTIONS(6108),
    [sym_page_keyword] = ACTIONS(6106),
    [anon_sym_codeunit] = ACTIONS(6106),
    [anon_sym_CODEUNIT] = ACTIONS(6106),
    [anon_sym_Codeunit] = ACTIONS(6106),
    [anon_sym_CodeUnit] = ACTIONS(6106),
    [anon_sym_COdeunit] = ACTIONS(6106),
    [anon_sym_codeUnit] = ACTIONS(6106),
    [sym_report_keyword] = ACTIONS(6106),
    [sym_query_keyword] = ACTIONS(6106),
    [anon_sym_xmlport] = ACTIONS(6106),
    [anon_sym_XMLPORT] = ACTIONS(6106),
    [anon_sym_Xmlport] = ACTIONS(6106),
    [anon_sym_XMLport] = ACTIONS(6106),
    [anon_sym_XMLPort] = ACTIONS(6106),
    [anon_sym_XmlPort] = ACTIONS(6106),
    [anon_sym_enum] = ACTIONS(6106),
    [anon_sym_ENUM] = ACTIONS(6106),
    [anon_sym_Enum] = ACTIONS(6106),
    [anon_sym_eNUM] = ACTIONS(6106),
    [anon_sym_eNum] = ACTIONS(6106),
    [anon_sym_ENum] = ACTIONS(6106),
    [sym_quoted_identifier] = ACTIONS(6108),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6108),
    [sym_verbatim_string] = ACTIONS(6108),
    [sym_integer] = ACTIONS(6106),
    [sym_continue_as_identifier] = ACTIONS(6108),
    [sym_preproc_open] = ACTIONS(6108),
  },
  [STATE(2907)] = {
    [sym_identifier] = ACTIONS(6110),
    [anon_sym_SEMI] = ACTIONS(6112),
    [anon_sym_DASH] = ACTIONS(6112),
    [aux_sym_boolean_token1] = ACTIONS(6110),
    [aux_sym_boolean_token2] = ACTIONS(6110),
    [sym_decimal] = ACTIONS(6110),
    [anon_sym_LPAREN] = ACTIONS(6112),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6110),
    [anon_sym_LBRACK] = ACTIONS(6112),
    [aux_sym_record_type_token1] = ACTIONS(6110),
    [aux_sym_basic_type_token21] = ACTIONS(6110),
    [aux_sym_basic_type_token22] = ACTIONS(6110),
    [aux_sym_basic_type_token48] = ACTIONS(6110),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6110),
    [anon_sym_POUNDif] = ACTIONS(6112),
    [anon_sym_POUNDIF] = ACTIONS(6112),
    [anon_sym_POUNDIf] = ACTIONS(6112),
    [anon_sym_not] = ACTIONS(6110),
    [anon_sym_NOT] = ACTIONS(6110),
    [anon_sym_Not] = ACTIONS(6110),
    [anon_sym_POUNDelse] = ACTIONS(6112),
    [anon_sym_POUNDELSE] = ACTIONS(6112),
    [anon_sym_POUNDElse] = ACTIONS(6112),
    [anon_sym_POUNDelse2] = ACTIONS(6112),
    [anon_sym_POUNDELSE2] = ACTIONS(6112),
    [anon_sym_POUNDElse2] = ACTIONS(6112),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6110),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6110),
    [anon_sym_PLUS] = ACTIONS(6112),
    [sym_datetime_literal] = ACTIONS(6112),
    [sym_date_literal] = ACTIONS(6110),
    [sym_time_literal] = ACTIONS(6110),
    [sym_biginteger_literal] = ACTIONS(6112),
    [anon_sym_if] = ACTIONS(6110),
    [anon_sym_IF] = ACTIONS(6110),
    [anon_sym_If] = ACTIONS(6110),
    [anon_sym_else] = ACTIONS(6110),
    [anon_sym_ELSE] = ACTIONS(6110),
    [anon_sym_Else] = ACTIONS(6110),
    [anon_sym_case] = ACTIONS(6110),
    [anon_sym_CASE] = ACTIONS(6110),
    [anon_sym_Case] = ACTIONS(6110),
    [anon_sym_for] = ACTIONS(6110),
    [anon_sym_FOR] = ACTIONS(6110),
    [anon_sym_For] = ACTIONS(6110),
    [anon_sym_foreach] = ACTIONS(6110),
    [anon_sym_FOREACH] = ACTIONS(6110),
    [anon_sym_Foreach] = ACTIONS(6110),
    [anon_sym_while] = ACTIONS(6110),
    [anon_sym_WHILE] = ACTIONS(6110),
    [anon_sym_While] = ACTIONS(6110),
    [anon_sym_repeat] = ACTIONS(6110),
    [anon_sym_REPEAT] = ACTIONS(6110),
    [anon_sym_Repeat] = ACTIONS(6110),
    [anon_sym_until] = ACTIONS(6110),
    [anon_sym_UNTIL] = ACTIONS(6110),
    [anon_sym_Until] = ACTIONS(6110),
    [anon_sym_exit] = ACTIONS(6110),
    [anon_sym_EXIT] = ACTIONS(6110),
    [anon_sym_Exit] = ACTIONS(6110),
    [anon_sym_continue] = ACTIONS(6110),
    [anon_sym_CONTINUE] = ACTIONS(6110),
    [anon_sym_Continue] = ACTIONS(6110),
    [anon_sym_break] = ACTIONS(6110),
    [anon_sym_BREAK] = ACTIONS(6110),
    [anon_sym_Break] = ACTIONS(6110),
    [anon_sym_with] = ACTIONS(6110),
    [anon_sym_WITH] = ACTIONS(6110),
    [anon_sym_With] = ACTIONS(6110),
    [sym_asserterror_keyword] = ACTIONS(6112),
    [sym_page_keyword] = ACTIONS(6110),
    [anon_sym_codeunit] = ACTIONS(6110),
    [anon_sym_CODEUNIT] = ACTIONS(6110),
    [anon_sym_Codeunit] = ACTIONS(6110),
    [anon_sym_CodeUnit] = ACTIONS(6110),
    [anon_sym_COdeunit] = ACTIONS(6110),
    [anon_sym_codeUnit] = ACTIONS(6110),
    [sym_report_keyword] = ACTIONS(6110),
    [sym_query_keyword] = ACTIONS(6110),
    [anon_sym_xmlport] = ACTIONS(6110),
    [anon_sym_XMLPORT] = ACTIONS(6110),
    [anon_sym_Xmlport] = ACTIONS(6110),
    [anon_sym_XMLport] = ACTIONS(6110),
    [anon_sym_XMLPort] = ACTIONS(6110),
    [anon_sym_XmlPort] = ACTIONS(6110),
    [anon_sym_enum] = ACTIONS(6110),
    [anon_sym_ENUM] = ACTIONS(6110),
    [anon_sym_Enum] = ACTIONS(6110),
    [anon_sym_eNUM] = ACTIONS(6110),
    [anon_sym_eNum] = ACTIONS(6110),
    [anon_sym_ENum] = ACTIONS(6110),
    [sym_quoted_identifier] = ACTIONS(6112),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6112),
    [sym_verbatim_string] = ACTIONS(6112),
    [sym_integer] = ACTIONS(6110),
    [sym_continue_as_identifier] = ACTIONS(6112),
    [sym_preproc_open] = ACTIONS(6112),
  },
  [STATE(2908)] = {
    [sym_identifier] = ACTIONS(6114),
    [anon_sym_SEMI] = ACTIONS(6116),
    [anon_sym_DASH] = ACTIONS(6116),
    [aux_sym_boolean_token1] = ACTIONS(6114),
    [aux_sym_boolean_token2] = ACTIONS(6114),
    [sym_decimal] = ACTIONS(6114),
    [anon_sym_LPAREN] = ACTIONS(6116),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6114),
    [anon_sym_LBRACK] = ACTIONS(6116),
    [aux_sym_record_type_token1] = ACTIONS(6114),
    [aux_sym_basic_type_token21] = ACTIONS(6114),
    [aux_sym_basic_type_token22] = ACTIONS(6114),
    [aux_sym_basic_type_token48] = ACTIONS(6114),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6114),
    [anon_sym_POUNDif] = ACTIONS(6116),
    [anon_sym_POUNDIF] = ACTIONS(6116),
    [anon_sym_POUNDIf] = ACTIONS(6116),
    [anon_sym_not] = ACTIONS(6114),
    [anon_sym_NOT] = ACTIONS(6114),
    [anon_sym_Not] = ACTIONS(6114),
    [anon_sym_POUNDelse] = ACTIONS(6116),
    [anon_sym_POUNDELSE] = ACTIONS(6116),
    [anon_sym_POUNDElse] = ACTIONS(6116),
    [anon_sym_POUNDelse2] = ACTIONS(6116),
    [anon_sym_POUNDELSE2] = ACTIONS(6116),
    [anon_sym_POUNDElse2] = ACTIONS(6116),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6114),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6114),
    [anon_sym_PLUS] = ACTIONS(6116),
    [sym_datetime_literal] = ACTIONS(6116),
    [sym_date_literal] = ACTIONS(6114),
    [sym_time_literal] = ACTIONS(6114),
    [sym_biginteger_literal] = ACTIONS(6116),
    [anon_sym_if] = ACTIONS(6114),
    [anon_sym_IF] = ACTIONS(6114),
    [anon_sym_If] = ACTIONS(6114),
    [anon_sym_else] = ACTIONS(6114),
    [anon_sym_ELSE] = ACTIONS(6114),
    [anon_sym_Else] = ACTIONS(6114),
    [anon_sym_case] = ACTIONS(6114),
    [anon_sym_CASE] = ACTIONS(6114),
    [anon_sym_Case] = ACTIONS(6114),
    [anon_sym_for] = ACTIONS(6114),
    [anon_sym_FOR] = ACTIONS(6114),
    [anon_sym_For] = ACTIONS(6114),
    [anon_sym_foreach] = ACTIONS(6114),
    [anon_sym_FOREACH] = ACTIONS(6114),
    [anon_sym_Foreach] = ACTIONS(6114),
    [anon_sym_while] = ACTIONS(6114),
    [anon_sym_WHILE] = ACTIONS(6114),
    [anon_sym_While] = ACTIONS(6114),
    [anon_sym_repeat] = ACTIONS(6114),
    [anon_sym_REPEAT] = ACTIONS(6114),
    [anon_sym_Repeat] = ACTIONS(6114),
    [anon_sym_until] = ACTIONS(6114),
    [anon_sym_UNTIL] = ACTIONS(6114),
    [anon_sym_Until] = ACTIONS(6114),
    [anon_sym_exit] = ACTIONS(6114),
    [anon_sym_EXIT] = ACTIONS(6114),
    [anon_sym_Exit] = ACTIONS(6114),
    [anon_sym_continue] = ACTIONS(6114),
    [anon_sym_CONTINUE] = ACTIONS(6114),
    [anon_sym_Continue] = ACTIONS(6114),
    [anon_sym_break] = ACTIONS(6114),
    [anon_sym_BREAK] = ACTIONS(6114),
    [anon_sym_Break] = ACTIONS(6114),
    [anon_sym_with] = ACTIONS(6114),
    [anon_sym_WITH] = ACTIONS(6114),
    [anon_sym_With] = ACTIONS(6114),
    [sym_asserterror_keyword] = ACTIONS(6116),
    [sym_page_keyword] = ACTIONS(6114),
    [anon_sym_codeunit] = ACTIONS(6114),
    [anon_sym_CODEUNIT] = ACTIONS(6114),
    [anon_sym_Codeunit] = ACTIONS(6114),
    [anon_sym_CodeUnit] = ACTIONS(6114),
    [anon_sym_COdeunit] = ACTIONS(6114),
    [anon_sym_codeUnit] = ACTIONS(6114),
    [sym_report_keyword] = ACTIONS(6114),
    [sym_query_keyword] = ACTIONS(6114),
    [anon_sym_xmlport] = ACTIONS(6114),
    [anon_sym_XMLPORT] = ACTIONS(6114),
    [anon_sym_Xmlport] = ACTIONS(6114),
    [anon_sym_XMLport] = ACTIONS(6114),
    [anon_sym_XMLPort] = ACTIONS(6114),
    [anon_sym_XmlPort] = ACTIONS(6114),
    [anon_sym_enum] = ACTIONS(6114),
    [anon_sym_ENUM] = ACTIONS(6114),
    [anon_sym_Enum] = ACTIONS(6114),
    [anon_sym_eNUM] = ACTIONS(6114),
    [anon_sym_eNum] = ACTIONS(6114),
    [anon_sym_ENum] = ACTIONS(6114),
    [sym_quoted_identifier] = ACTIONS(6116),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6116),
    [sym_verbatim_string] = ACTIONS(6116),
    [sym_integer] = ACTIONS(6114),
    [sym_continue_as_identifier] = ACTIONS(6116),
    [sym_preproc_open] = ACTIONS(6116),
  },
  [STATE(2909)] = {
    [sym_identifier] = ACTIONS(6132),
    [anon_sym_SEMI] = ACTIONS(6134),
    [anon_sym_DASH] = ACTIONS(6134),
    [aux_sym_boolean_token1] = ACTIONS(6132),
    [aux_sym_boolean_token2] = ACTIONS(6132),
    [sym_decimal] = ACTIONS(6132),
    [anon_sym_LPAREN] = ACTIONS(6134),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6132),
    [anon_sym_LBRACK] = ACTIONS(6134),
    [aux_sym_record_type_token1] = ACTIONS(6132),
    [aux_sym_basic_type_token21] = ACTIONS(6132),
    [aux_sym_basic_type_token22] = ACTIONS(6132),
    [aux_sym_basic_type_token48] = ACTIONS(6132),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6132),
    [anon_sym_POUNDif] = ACTIONS(6134),
    [anon_sym_POUNDIF] = ACTIONS(6134),
    [anon_sym_POUNDIf] = ACTIONS(6134),
    [anon_sym_not] = ACTIONS(6132),
    [anon_sym_NOT] = ACTIONS(6132),
    [anon_sym_Not] = ACTIONS(6132),
    [anon_sym_POUNDelse] = ACTIONS(6134),
    [anon_sym_POUNDELSE] = ACTIONS(6134),
    [anon_sym_POUNDElse] = ACTIONS(6134),
    [anon_sym_POUNDelse2] = ACTIONS(6134),
    [anon_sym_POUNDELSE2] = ACTIONS(6134),
    [anon_sym_POUNDElse2] = ACTIONS(6134),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6132),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6132),
    [anon_sym_PLUS] = ACTIONS(6134),
    [sym_datetime_literal] = ACTIONS(6134),
    [sym_date_literal] = ACTIONS(6132),
    [sym_time_literal] = ACTIONS(6132),
    [sym_biginteger_literal] = ACTIONS(6134),
    [anon_sym_if] = ACTIONS(6132),
    [anon_sym_IF] = ACTIONS(6132),
    [anon_sym_If] = ACTIONS(6132),
    [anon_sym_else] = ACTIONS(6132),
    [anon_sym_ELSE] = ACTIONS(6132),
    [anon_sym_Else] = ACTIONS(6132),
    [anon_sym_case] = ACTIONS(6132),
    [anon_sym_CASE] = ACTIONS(6132),
    [anon_sym_Case] = ACTIONS(6132),
    [anon_sym_for] = ACTIONS(6132),
    [anon_sym_FOR] = ACTIONS(6132),
    [anon_sym_For] = ACTIONS(6132),
    [anon_sym_foreach] = ACTIONS(6132),
    [anon_sym_FOREACH] = ACTIONS(6132),
    [anon_sym_Foreach] = ACTIONS(6132),
    [anon_sym_while] = ACTIONS(6132),
    [anon_sym_WHILE] = ACTIONS(6132),
    [anon_sym_While] = ACTIONS(6132),
    [anon_sym_repeat] = ACTIONS(6132),
    [anon_sym_REPEAT] = ACTIONS(6132),
    [anon_sym_Repeat] = ACTIONS(6132),
    [anon_sym_until] = ACTIONS(6132),
    [anon_sym_UNTIL] = ACTIONS(6132),
    [anon_sym_Until] = ACTIONS(6132),
    [anon_sym_exit] = ACTIONS(6132),
    [anon_sym_EXIT] = ACTIONS(6132),
    [anon_sym_Exit] = ACTIONS(6132),
    [anon_sym_continue] = ACTIONS(6132),
    [anon_sym_CONTINUE] = ACTIONS(6132),
    [anon_sym_Continue] = ACTIONS(6132),
    [anon_sym_break] = ACTIONS(6132),
    [anon_sym_BREAK] = ACTIONS(6132),
    [anon_sym_Break] = ACTIONS(6132),
    [anon_sym_with] = ACTIONS(6132),
    [anon_sym_WITH] = ACTIONS(6132),
    [anon_sym_With] = ACTIONS(6132),
    [sym_asserterror_keyword] = ACTIONS(6134),
    [sym_page_keyword] = ACTIONS(6132),
    [anon_sym_codeunit] = ACTIONS(6132),
    [anon_sym_CODEUNIT] = ACTIONS(6132),
    [anon_sym_Codeunit] = ACTIONS(6132),
    [anon_sym_CodeUnit] = ACTIONS(6132),
    [anon_sym_COdeunit] = ACTIONS(6132),
    [anon_sym_codeUnit] = ACTIONS(6132),
    [sym_report_keyword] = ACTIONS(6132),
    [sym_query_keyword] = ACTIONS(6132),
    [anon_sym_xmlport] = ACTIONS(6132),
    [anon_sym_XMLPORT] = ACTIONS(6132),
    [anon_sym_Xmlport] = ACTIONS(6132),
    [anon_sym_XMLport] = ACTIONS(6132),
    [anon_sym_XMLPort] = ACTIONS(6132),
    [anon_sym_XmlPort] = ACTIONS(6132),
    [anon_sym_enum] = ACTIONS(6132),
    [anon_sym_ENUM] = ACTIONS(6132),
    [anon_sym_Enum] = ACTIONS(6132),
    [anon_sym_eNUM] = ACTIONS(6132),
    [anon_sym_eNum] = ACTIONS(6132),
    [anon_sym_ENum] = ACTIONS(6132),
    [sym_quoted_identifier] = ACTIONS(6134),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6134),
    [sym_verbatim_string] = ACTIONS(6134),
    [sym_integer] = ACTIONS(6132),
    [sym_continue_as_identifier] = ACTIONS(6134),
    [sym_preproc_open] = ACTIONS(6134),
  },
  [STATE(2910)] = {
    [sym_identifier] = ACTIONS(6114),
    [anon_sym_SEMI] = ACTIONS(6116),
    [anon_sym_DASH] = ACTIONS(6116),
    [aux_sym_boolean_token1] = ACTIONS(6114),
    [aux_sym_boolean_token2] = ACTIONS(6114),
    [sym_decimal] = ACTIONS(6114),
    [anon_sym_LPAREN] = ACTIONS(6116),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6114),
    [anon_sym_LBRACK] = ACTIONS(6116),
    [aux_sym_record_type_token1] = ACTIONS(6114),
    [aux_sym_basic_type_token21] = ACTIONS(6114),
    [aux_sym_basic_type_token22] = ACTIONS(6114),
    [aux_sym_basic_type_token48] = ACTIONS(6114),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6114),
    [anon_sym_POUNDif] = ACTIONS(6116),
    [anon_sym_POUNDIF] = ACTIONS(6116),
    [anon_sym_POUNDIf] = ACTIONS(6116),
    [anon_sym_not] = ACTIONS(6114),
    [anon_sym_NOT] = ACTIONS(6114),
    [anon_sym_Not] = ACTIONS(6114),
    [anon_sym_POUNDelse] = ACTIONS(6116),
    [anon_sym_POUNDELSE] = ACTIONS(6116),
    [anon_sym_POUNDElse] = ACTIONS(6116),
    [anon_sym_POUNDelse2] = ACTIONS(6116),
    [anon_sym_POUNDELSE2] = ACTIONS(6116),
    [anon_sym_POUNDElse2] = ACTIONS(6116),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6114),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6114),
    [anon_sym_PLUS] = ACTIONS(6116),
    [sym_datetime_literal] = ACTIONS(6116),
    [sym_date_literal] = ACTIONS(6114),
    [sym_time_literal] = ACTIONS(6114),
    [sym_biginteger_literal] = ACTIONS(6116),
    [anon_sym_if] = ACTIONS(6114),
    [anon_sym_IF] = ACTIONS(6114),
    [anon_sym_If] = ACTIONS(6114),
    [anon_sym_else] = ACTIONS(6114),
    [anon_sym_ELSE] = ACTIONS(6114),
    [anon_sym_Else] = ACTIONS(6114),
    [anon_sym_case] = ACTIONS(6114),
    [anon_sym_CASE] = ACTIONS(6114),
    [anon_sym_Case] = ACTIONS(6114),
    [anon_sym_for] = ACTIONS(6114),
    [anon_sym_FOR] = ACTIONS(6114),
    [anon_sym_For] = ACTIONS(6114),
    [anon_sym_foreach] = ACTIONS(6114),
    [anon_sym_FOREACH] = ACTIONS(6114),
    [anon_sym_Foreach] = ACTIONS(6114),
    [anon_sym_while] = ACTIONS(6114),
    [anon_sym_WHILE] = ACTIONS(6114),
    [anon_sym_While] = ACTIONS(6114),
    [anon_sym_repeat] = ACTIONS(6114),
    [anon_sym_REPEAT] = ACTIONS(6114),
    [anon_sym_Repeat] = ACTIONS(6114),
    [anon_sym_until] = ACTIONS(6114),
    [anon_sym_UNTIL] = ACTIONS(6114),
    [anon_sym_Until] = ACTIONS(6114),
    [anon_sym_exit] = ACTIONS(6114),
    [anon_sym_EXIT] = ACTIONS(6114),
    [anon_sym_Exit] = ACTIONS(6114),
    [anon_sym_continue] = ACTIONS(6114),
    [anon_sym_CONTINUE] = ACTIONS(6114),
    [anon_sym_Continue] = ACTIONS(6114),
    [anon_sym_break] = ACTIONS(6114),
    [anon_sym_BREAK] = ACTIONS(6114),
    [anon_sym_Break] = ACTIONS(6114),
    [anon_sym_with] = ACTIONS(6114),
    [anon_sym_WITH] = ACTIONS(6114),
    [anon_sym_With] = ACTIONS(6114),
    [sym_asserterror_keyword] = ACTIONS(6116),
    [sym_page_keyword] = ACTIONS(6114),
    [anon_sym_codeunit] = ACTIONS(6114),
    [anon_sym_CODEUNIT] = ACTIONS(6114),
    [anon_sym_Codeunit] = ACTIONS(6114),
    [anon_sym_CodeUnit] = ACTIONS(6114),
    [anon_sym_COdeunit] = ACTIONS(6114),
    [anon_sym_codeUnit] = ACTIONS(6114),
    [sym_report_keyword] = ACTIONS(6114),
    [sym_query_keyword] = ACTIONS(6114),
    [anon_sym_xmlport] = ACTIONS(6114),
    [anon_sym_XMLPORT] = ACTIONS(6114),
    [anon_sym_Xmlport] = ACTIONS(6114),
    [anon_sym_XMLport] = ACTIONS(6114),
    [anon_sym_XMLPort] = ACTIONS(6114),
    [anon_sym_XmlPort] = ACTIONS(6114),
    [anon_sym_enum] = ACTIONS(6114),
    [anon_sym_ENUM] = ACTIONS(6114),
    [anon_sym_Enum] = ACTIONS(6114),
    [anon_sym_eNUM] = ACTIONS(6114),
    [anon_sym_eNum] = ACTIONS(6114),
    [anon_sym_ENum] = ACTIONS(6114),
    [sym_quoted_identifier] = ACTIONS(6116),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6116),
    [sym_verbatim_string] = ACTIONS(6116),
    [sym_integer] = ACTIONS(6114),
    [sym_continue_as_identifier] = ACTIONS(6116),
    [sym_preproc_open] = ACTIONS(6116),
  },
  [STATE(2911)] = {
    [sym_identifier] = ACTIONS(6196),
    [anon_sym_SEMI] = ACTIONS(6198),
    [anon_sym_DASH] = ACTIONS(6198),
    [aux_sym_boolean_token1] = ACTIONS(6196),
    [aux_sym_boolean_token2] = ACTIONS(6196),
    [sym_decimal] = ACTIONS(6196),
    [anon_sym_LPAREN] = ACTIONS(6198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6196),
    [anon_sym_LBRACK] = ACTIONS(6198),
    [aux_sym_record_type_token1] = ACTIONS(6196),
    [aux_sym_basic_type_token21] = ACTIONS(6196),
    [aux_sym_basic_type_token22] = ACTIONS(6196),
    [aux_sym_basic_type_token48] = ACTIONS(6196),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6196),
    [anon_sym_POUNDif] = ACTIONS(6198),
    [anon_sym_POUNDIF] = ACTIONS(6198),
    [anon_sym_POUNDIf] = ACTIONS(6198),
    [anon_sym_not] = ACTIONS(6196),
    [anon_sym_NOT] = ACTIONS(6196),
    [anon_sym_Not] = ACTIONS(6196),
    [anon_sym_POUNDelse] = ACTIONS(6198),
    [anon_sym_POUNDELSE] = ACTIONS(6198),
    [anon_sym_POUNDElse] = ACTIONS(6198),
    [anon_sym_POUNDelse2] = ACTIONS(6198),
    [anon_sym_POUNDELSE2] = ACTIONS(6198),
    [anon_sym_POUNDElse2] = ACTIONS(6198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6196),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6196),
    [anon_sym_PLUS] = ACTIONS(6198),
    [sym_datetime_literal] = ACTIONS(6198),
    [sym_date_literal] = ACTIONS(6196),
    [sym_time_literal] = ACTIONS(6196),
    [sym_biginteger_literal] = ACTIONS(6198),
    [anon_sym_if] = ACTIONS(6196),
    [anon_sym_IF] = ACTIONS(6196),
    [anon_sym_If] = ACTIONS(6196),
    [anon_sym_else] = ACTIONS(6196),
    [anon_sym_ELSE] = ACTIONS(6196),
    [anon_sym_Else] = ACTIONS(6196),
    [anon_sym_case] = ACTIONS(6196),
    [anon_sym_CASE] = ACTIONS(6196),
    [anon_sym_Case] = ACTIONS(6196),
    [anon_sym_for] = ACTIONS(6196),
    [anon_sym_FOR] = ACTIONS(6196),
    [anon_sym_For] = ACTIONS(6196),
    [anon_sym_foreach] = ACTIONS(6196),
    [anon_sym_FOREACH] = ACTIONS(6196),
    [anon_sym_Foreach] = ACTIONS(6196),
    [anon_sym_while] = ACTIONS(6196),
    [anon_sym_WHILE] = ACTIONS(6196),
    [anon_sym_While] = ACTIONS(6196),
    [anon_sym_repeat] = ACTIONS(6196),
    [anon_sym_REPEAT] = ACTIONS(6196),
    [anon_sym_Repeat] = ACTIONS(6196),
    [anon_sym_until] = ACTIONS(6196),
    [anon_sym_UNTIL] = ACTIONS(6196),
    [anon_sym_Until] = ACTIONS(6196),
    [anon_sym_exit] = ACTIONS(6196),
    [anon_sym_EXIT] = ACTIONS(6196),
    [anon_sym_Exit] = ACTIONS(6196),
    [anon_sym_continue] = ACTIONS(6196),
    [anon_sym_CONTINUE] = ACTIONS(6196),
    [anon_sym_Continue] = ACTIONS(6196),
    [anon_sym_break] = ACTIONS(6196),
    [anon_sym_BREAK] = ACTIONS(6196),
    [anon_sym_Break] = ACTIONS(6196),
    [anon_sym_with] = ACTIONS(6196),
    [anon_sym_WITH] = ACTIONS(6196),
    [anon_sym_With] = ACTIONS(6196),
    [sym_asserterror_keyword] = ACTIONS(6198),
    [sym_page_keyword] = ACTIONS(6196),
    [anon_sym_codeunit] = ACTIONS(6196),
    [anon_sym_CODEUNIT] = ACTIONS(6196),
    [anon_sym_Codeunit] = ACTIONS(6196),
    [anon_sym_CodeUnit] = ACTIONS(6196),
    [anon_sym_COdeunit] = ACTIONS(6196),
    [anon_sym_codeUnit] = ACTIONS(6196),
    [sym_report_keyword] = ACTIONS(6196),
    [sym_query_keyword] = ACTIONS(6196),
    [anon_sym_xmlport] = ACTIONS(6196),
    [anon_sym_XMLPORT] = ACTIONS(6196),
    [anon_sym_Xmlport] = ACTIONS(6196),
    [anon_sym_XMLport] = ACTIONS(6196),
    [anon_sym_XMLPort] = ACTIONS(6196),
    [anon_sym_XmlPort] = ACTIONS(6196),
    [anon_sym_enum] = ACTIONS(6196),
    [anon_sym_ENUM] = ACTIONS(6196),
    [anon_sym_Enum] = ACTIONS(6196),
    [anon_sym_eNUM] = ACTIONS(6196),
    [anon_sym_eNum] = ACTIONS(6196),
    [anon_sym_ENum] = ACTIONS(6196),
    [sym_quoted_identifier] = ACTIONS(6198),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6198),
    [sym_verbatim_string] = ACTIONS(6198),
    [sym_integer] = ACTIONS(6196),
    [sym_continue_as_identifier] = ACTIONS(6198),
    [sym_preproc_open] = ACTIONS(6198),
  },
  [STATE(2912)] = {
    [sym_identifier] = ACTIONS(6200),
    [anon_sym_SEMI] = ACTIONS(6202),
    [anon_sym_DASH] = ACTIONS(6202),
    [aux_sym_boolean_token1] = ACTIONS(6200),
    [aux_sym_boolean_token2] = ACTIONS(6200),
    [sym_decimal] = ACTIONS(6200),
    [anon_sym_LPAREN] = ACTIONS(6202),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(6202),
    [aux_sym_record_type_token1] = ACTIONS(6200),
    [aux_sym_basic_type_token21] = ACTIONS(6200),
    [aux_sym_basic_type_token22] = ACTIONS(6200),
    [aux_sym_basic_type_token48] = ACTIONS(6200),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6200),
    [anon_sym_POUNDif] = ACTIONS(6202),
    [anon_sym_POUNDIF] = ACTIONS(6202),
    [anon_sym_POUNDIf] = ACTIONS(6202),
    [anon_sym_not] = ACTIONS(6200),
    [anon_sym_NOT] = ACTIONS(6200),
    [anon_sym_Not] = ACTIONS(6200),
    [anon_sym_POUNDelse] = ACTIONS(6202),
    [anon_sym_POUNDELSE] = ACTIONS(6202),
    [anon_sym_POUNDElse] = ACTIONS(6202),
    [anon_sym_POUNDelse2] = ACTIONS(6202),
    [anon_sym_POUNDELSE2] = ACTIONS(6202),
    [anon_sym_POUNDElse2] = ACTIONS(6202),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6200),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6200),
    [anon_sym_PLUS] = ACTIONS(6202),
    [sym_datetime_literal] = ACTIONS(6202),
    [sym_date_literal] = ACTIONS(6200),
    [sym_time_literal] = ACTIONS(6200),
    [sym_biginteger_literal] = ACTIONS(6202),
    [anon_sym_if] = ACTIONS(6200),
    [anon_sym_IF] = ACTIONS(6200),
    [anon_sym_If] = ACTIONS(6200),
    [anon_sym_else] = ACTIONS(6200),
    [anon_sym_ELSE] = ACTIONS(6200),
    [anon_sym_Else] = ACTIONS(6200),
    [anon_sym_case] = ACTIONS(6200),
    [anon_sym_CASE] = ACTIONS(6200),
    [anon_sym_Case] = ACTIONS(6200),
    [anon_sym_for] = ACTIONS(6200),
    [anon_sym_FOR] = ACTIONS(6200),
    [anon_sym_For] = ACTIONS(6200),
    [anon_sym_foreach] = ACTIONS(6200),
    [anon_sym_FOREACH] = ACTIONS(6200),
    [anon_sym_Foreach] = ACTIONS(6200),
    [anon_sym_while] = ACTIONS(6200),
    [anon_sym_WHILE] = ACTIONS(6200),
    [anon_sym_While] = ACTIONS(6200),
    [anon_sym_repeat] = ACTIONS(6200),
    [anon_sym_REPEAT] = ACTIONS(6200),
    [anon_sym_Repeat] = ACTIONS(6200),
    [anon_sym_until] = ACTIONS(6200),
    [anon_sym_UNTIL] = ACTIONS(6200),
    [anon_sym_Until] = ACTIONS(6200),
    [anon_sym_exit] = ACTIONS(6200),
    [anon_sym_EXIT] = ACTIONS(6200),
    [anon_sym_Exit] = ACTIONS(6200),
    [anon_sym_continue] = ACTIONS(6200),
    [anon_sym_CONTINUE] = ACTIONS(6200),
    [anon_sym_Continue] = ACTIONS(6200),
    [anon_sym_break] = ACTIONS(6200),
    [anon_sym_BREAK] = ACTIONS(6200),
    [anon_sym_Break] = ACTIONS(6200),
    [anon_sym_with] = ACTIONS(6200),
    [anon_sym_WITH] = ACTIONS(6200),
    [anon_sym_With] = ACTIONS(6200),
    [sym_asserterror_keyword] = ACTIONS(6202),
    [sym_page_keyword] = ACTIONS(6200),
    [anon_sym_codeunit] = ACTIONS(6200),
    [anon_sym_CODEUNIT] = ACTIONS(6200),
    [anon_sym_Codeunit] = ACTIONS(6200),
    [anon_sym_CodeUnit] = ACTIONS(6200),
    [anon_sym_COdeunit] = ACTIONS(6200),
    [anon_sym_codeUnit] = ACTIONS(6200),
    [sym_report_keyword] = ACTIONS(6200),
    [sym_query_keyword] = ACTIONS(6200),
    [anon_sym_xmlport] = ACTIONS(6200),
    [anon_sym_XMLPORT] = ACTIONS(6200),
    [anon_sym_Xmlport] = ACTIONS(6200),
    [anon_sym_XMLport] = ACTIONS(6200),
    [anon_sym_XMLPort] = ACTIONS(6200),
    [anon_sym_XmlPort] = ACTIONS(6200),
    [anon_sym_enum] = ACTIONS(6200),
    [anon_sym_ENUM] = ACTIONS(6200),
    [anon_sym_Enum] = ACTIONS(6200),
    [anon_sym_eNUM] = ACTIONS(6200),
    [anon_sym_eNum] = ACTIONS(6200),
    [anon_sym_ENum] = ACTIONS(6200),
    [sym_quoted_identifier] = ACTIONS(6202),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6202),
    [sym_verbatim_string] = ACTIONS(6202),
    [sym_integer] = ACTIONS(6200),
    [sym_continue_as_identifier] = ACTIONS(6202),
    [sym_preproc_open] = ACTIONS(6202),
  },
  [STATE(2913)] = {
    [sym_identifier] = ACTIONS(6196),
    [anon_sym_SEMI] = ACTIONS(6198),
    [anon_sym_DASH] = ACTIONS(6198),
    [aux_sym_boolean_token1] = ACTIONS(6196),
    [aux_sym_boolean_token2] = ACTIONS(6196),
    [sym_decimal] = ACTIONS(6196),
    [anon_sym_LPAREN] = ACTIONS(6198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6196),
    [anon_sym_LBRACK] = ACTIONS(6198),
    [aux_sym_record_type_token1] = ACTIONS(6196),
    [aux_sym_basic_type_token21] = ACTIONS(6196),
    [aux_sym_basic_type_token22] = ACTIONS(6196),
    [aux_sym_basic_type_token48] = ACTIONS(6196),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6196),
    [anon_sym_POUNDif] = ACTIONS(6198),
    [anon_sym_POUNDIF] = ACTIONS(6198),
    [anon_sym_POUNDIf] = ACTIONS(6198),
    [anon_sym_not] = ACTIONS(6196),
    [anon_sym_NOT] = ACTIONS(6196),
    [anon_sym_Not] = ACTIONS(6196),
    [anon_sym_POUNDelse] = ACTIONS(6198),
    [anon_sym_POUNDELSE] = ACTIONS(6198),
    [anon_sym_POUNDElse] = ACTIONS(6198),
    [anon_sym_POUNDelse2] = ACTIONS(6198),
    [anon_sym_POUNDELSE2] = ACTIONS(6198),
    [anon_sym_POUNDElse2] = ACTIONS(6198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6196),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6196),
    [anon_sym_PLUS] = ACTIONS(6198),
    [sym_datetime_literal] = ACTIONS(6198),
    [sym_date_literal] = ACTIONS(6196),
    [sym_time_literal] = ACTIONS(6196),
    [sym_biginteger_literal] = ACTIONS(6198),
    [anon_sym_if] = ACTIONS(6196),
    [anon_sym_IF] = ACTIONS(6196),
    [anon_sym_If] = ACTIONS(6196),
    [anon_sym_else] = ACTIONS(6196),
    [anon_sym_ELSE] = ACTIONS(6196),
    [anon_sym_Else] = ACTIONS(6196),
    [anon_sym_case] = ACTIONS(6196),
    [anon_sym_CASE] = ACTIONS(6196),
    [anon_sym_Case] = ACTIONS(6196),
    [anon_sym_for] = ACTIONS(6196),
    [anon_sym_FOR] = ACTIONS(6196),
    [anon_sym_For] = ACTIONS(6196),
    [anon_sym_foreach] = ACTIONS(6196),
    [anon_sym_FOREACH] = ACTIONS(6196),
    [anon_sym_Foreach] = ACTIONS(6196),
    [anon_sym_while] = ACTIONS(6196),
    [anon_sym_WHILE] = ACTIONS(6196),
    [anon_sym_While] = ACTIONS(6196),
    [anon_sym_repeat] = ACTIONS(6196),
    [anon_sym_REPEAT] = ACTIONS(6196),
    [anon_sym_Repeat] = ACTIONS(6196),
    [anon_sym_until] = ACTIONS(6196),
    [anon_sym_UNTIL] = ACTIONS(6196),
    [anon_sym_Until] = ACTIONS(6196),
    [anon_sym_exit] = ACTIONS(6196),
    [anon_sym_EXIT] = ACTIONS(6196),
    [anon_sym_Exit] = ACTIONS(6196),
    [anon_sym_continue] = ACTIONS(6196),
    [anon_sym_CONTINUE] = ACTIONS(6196),
    [anon_sym_Continue] = ACTIONS(6196),
    [anon_sym_break] = ACTIONS(6196),
    [anon_sym_BREAK] = ACTIONS(6196),
    [anon_sym_Break] = ACTIONS(6196),
    [anon_sym_with] = ACTIONS(6196),
    [anon_sym_WITH] = ACTIONS(6196),
    [anon_sym_With] = ACTIONS(6196),
    [sym_asserterror_keyword] = ACTIONS(6198),
    [sym_page_keyword] = ACTIONS(6196),
    [anon_sym_codeunit] = ACTIONS(6196),
    [anon_sym_CODEUNIT] = ACTIONS(6196),
    [anon_sym_Codeunit] = ACTIONS(6196),
    [anon_sym_CodeUnit] = ACTIONS(6196),
    [anon_sym_COdeunit] = ACTIONS(6196),
    [anon_sym_codeUnit] = ACTIONS(6196),
    [sym_report_keyword] = ACTIONS(6196),
    [sym_query_keyword] = ACTIONS(6196),
    [anon_sym_xmlport] = ACTIONS(6196),
    [anon_sym_XMLPORT] = ACTIONS(6196),
    [anon_sym_Xmlport] = ACTIONS(6196),
    [anon_sym_XMLport] = ACTIONS(6196),
    [anon_sym_XMLPort] = ACTIONS(6196),
    [anon_sym_XmlPort] = ACTIONS(6196),
    [anon_sym_enum] = ACTIONS(6196),
    [anon_sym_ENUM] = ACTIONS(6196),
    [anon_sym_Enum] = ACTIONS(6196),
    [anon_sym_eNUM] = ACTIONS(6196),
    [anon_sym_eNum] = ACTIONS(6196),
    [anon_sym_ENum] = ACTIONS(6196),
    [sym_quoted_identifier] = ACTIONS(6198),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6198),
    [sym_verbatim_string] = ACTIONS(6198),
    [sym_integer] = ACTIONS(6196),
    [sym_continue_as_identifier] = ACTIONS(6198),
    [sym_preproc_open] = ACTIONS(6198),
  },
  [STATE(2914)] = {
    [sym_identifier] = ACTIONS(6204),
    [anon_sym_SEMI] = ACTIONS(6206),
    [anon_sym_DASH] = ACTIONS(6206),
    [aux_sym_boolean_token1] = ACTIONS(6204),
    [aux_sym_boolean_token2] = ACTIONS(6204),
    [sym_decimal] = ACTIONS(6204),
    [anon_sym_LPAREN] = ACTIONS(6206),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6204),
    [anon_sym_LBRACK] = ACTIONS(6206),
    [aux_sym_record_type_token1] = ACTIONS(6204),
    [aux_sym_basic_type_token21] = ACTIONS(6204),
    [aux_sym_basic_type_token22] = ACTIONS(6204),
    [aux_sym_basic_type_token48] = ACTIONS(6204),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6204),
    [anon_sym_POUNDif] = ACTIONS(6206),
    [anon_sym_POUNDIF] = ACTIONS(6206),
    [anon_sym_POUNDIf] = ACTIONS(6206),
    [anon_sym_not] = ACTIONS(6204),
    [anon_sym_NOT] = ACTIONS(6204),
    [anon_sym_Not] = ACTIONS(6204),
    [anon_sym_POUNDelse] = ACTIONS(6206),
    [anon_sym_POUNDELSE] = ACTIONS(6206),
    [anon_sym_POUNDElse] = ACTIONS(6206),
    [anon_sym_POUNDelse2] = ACTIONS(6206),
    [anon_sym_POUNDELSE2] = ACTIONS(6206),
    [anon_sym_POUNDElse2] = ACTIONS(6206),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6204),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6204),
    [anon_sym_PLUS] = ACTIONS(6206),
    [sym_datetime_literal] = ACTIONS(6206),
    [sym_date_literal] = ACTIONS(6204),
    [sym_time_literal] = ACTIONS(6204),
    [sym_biginteger_literal] = ACTIONS(6206),
    [anon_sym_if] = ACTIONS(6204),
    [anon_sym_IF] = ACTIONS(6204),
    [anon_sym_If] = ACTIONS(6204),
    [anon_sym_else] = ACTIONS(6204),
    [anon_sym_ELSE] = ACTIONS(6204),
    [anon_sym_Else] = ACTIONS(6204),
    [anon_sym_case] = ACTIONS(6204),
    [anon_sym_CASE] = ACTIONS(6204),
    [anon_sym_Case] = ACTIONS(6204),
    [anon_sym_for] = ACTIONS(6204),
    [anon_sym_FOR] = ACTIONS(6204),
    [anon_sym_For] = ACTIONS(6204),
    [anon_sym_foreach] = ACTIONS(6204),
    [anon_sym_FOREACH] = ACTIONS(6204),
    [anon_sym_Foreach] = ACTIONS(6204),
    [anon_sym_while] = ACTIONS(6204),
    [anon_sym_WHILE] = ACTIONS(6204),
    [anon_sym_While] = ACTIONS(6204),
    [anon_sym_repeat] = ACTIONS(6204),
    [anon_sym_REPEAT] = ACTIONS(6204),
    [anon_sym_Repeat] = ACTIONS(6204),
    [anon_sym_until] = ACTIONS(6204),
    [anon_sym_UNTIL] = ACTIONS(6204),
    [anon_sym_Until] = ACTIONS(6204),
    [anon_sym_exit] = ACTIONS(6204),
    [anon_sym_EXIT] = ACTIONS(6204),
    [anon_sym_Exit] = ACTIONS(6204),
    [anon_sym_continue] = ACTIONS(6204),
    [anon_sym_CONTINUE] = ACTIONS(6204),
    [anon_sym_Continue] = ACTIONS(6204),
    [anon_sym_break] = ACTIONS(6204),
    [anon_sym_BREAK] = ACTIONS(6204),
    [anon_sym_Break] = ACTIONS(6204),
    [anon_sym_with] = ACTIONS(6204),
    [anon_sym_WITH] = ACTIONS(6204),
    [anon_sym_With] = ACTIONS(6204),
    [sym_asserterror_keyword] = ACTIONS(6206),
    [sym_page_keyword] = ACTIONS(6204),
    [anon_sym_codeunit] = ACTIONS(6204),
    [anon_sym_CODEUNIT] = ACTIONS(6204),
    [anon_sym_Codeunit] = ACTIONS(6204),
    [anon_sym_CodeUnit] = ACTIONS(6204),
    [anon_sym_COdeunit] = ACTIONS(6204),
    [anon_sym_codeUnit] = ACTIONS(6204),
    [sym_report_keyword] = ACTIONS(6204),
    [sym_query_keyword] = ACTIONS(6204),
    [anon_sym_xmlport] = ACTIONS(6204),
    [anon_sym_XMLPORT] = ACTIONS(6204),
    [anon_sym_Xmlport] = ACTIONS(6204),
    [anon_sym_XMLport] = ACTIONS(6204),
    [anon_sym_XMLPort] = ACTIONS(6204),
    [anon_sym_XmlPort] = ACTIONS(6204),
    [anon_sym_enum] = ACTIONS(6204),
    [anon_sym_ENUM] = ACTIONS(6204),
    [anon_sym_Enum] = ACTIONS(6204),
    [anon_sym_eNUM] = ACTIONS(6204),
    [anon_sym_eNum] = ACTIONS(6204),
    [anon_sym_ENum] = ACTIONS(6204),
    [sym_quoted_identifier] = ACTIONS(6206),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6206),
    [sym_verbatim_string] = ACTIONS(6206),
    [sym_integer] = ACTIONS(6204),
    [sym_continue_as_identifier] = ACTIONS(6206),
    [sym_preproc_open] = ACTIONS(6206),
  },
  [STATE(2915)] = {
    [sym_identifier] = ACTIONS(6208),
    [anon_sym_SEMI] = ACTIONS(6210),
    [anon_sym_DASH] = ACTIONS(6210),
    [aux_sym_boolean_token1] = ACTIONS(6208),
    [aux_sym_boolean_token2] = ACTIONS(6208),
    [sym_decimal] = ACTIONS(6208),
    [anon_sym_LPAREN] = ACTIONS(6210),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6208),
    [anon_sym_LBRACK] = ACTIONS(6210),
    [aux_sym_record_type_token1] = ACTIONS(6208),
    [aux_sym_basic_type_token21] = ACTIONS(6208),
    [aux_sym_basic_type_token22] = ACTIONS(6208),
    [aux_sym_basic_type_token48] = ACTIONS(6208),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6208),
    [anon_sym_POUNDif] = ACTIONS(6210),
    [anon_sym_POUNDIF] = ACTIONS(6210),
    [anon_sym_POUNDIf] = ACTIONS(6210),
    [anon_sym_not] = ACTIONS(6208),
    [anon_sym_NOT] = ACTIONS(6208),
    [anon_sym_Not] = ACTIONS(6208),
    [anon_sym_POUNDelse] = ACTIONS(6210),
    [anon_sym_POUNDELSE] = ACTIONS(6210),
    [anon_sym_POUNDElse] = ACTIONS(6210),
    [anon_sym_POUNDelse2] = ACTIONS(6210),
    [anon_sym_POUNDELSE2] = ACTIONS(6210),
    [anon_sym_POUNDElse2] = ACTIONS(6210),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6208),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6208),
    [anon_sym_PLUS] = ACTIONS(6210),
    [sym_datetime_literal] = ACTIONS(6210),
    [sym_date_literal] = ACTIONS(6208),
    [sym_time_literal] = ACTIONS(6208),
    [sym_biginteger_literal] = ACTIONS(6210),
    [anon_sym_if] = ACTIONS(6208),
    [anon_sym_IF] = ACTIONS(6208),
    [anon_sym_If] = ACTIONS(6208),
    [anon_sym_else] = ACTIONS(6208),
    [anon_sym_ELSE] = ACTIONS(6208),
    [anon_sym_Else] = ACTIONS(6208),
    [anon_sym_case] = ACTIONS(6208),
    [anon_sym_CASE] = ACTIONS(6208),
    [anon_sym_Case] = ACTIONS(6208),
    [anon_sym_for] = ACTIONS(6208),
    [anon_sym_FOR] = ACTIONS(6208),
    [anon_sym_For] = ACTIONS(6208),
    [anon_sym_foreach] = ACTIONS(6208),
    [anon_sym_FOREACH] = ACTIONS(6208),
    [anon_sym_Foreach] = ACTIONS(6208),
    [anon_sym_while] = ACTIONS(6208),
    [anon_sym_WHILE] = ACTIONS(6208),
    [anon_sym_While] = ACTIONS(6208),
    [anon_sym_repeat] = ACTIONS(6208),
    [anon_sym_REPEAT] = ACTIONS(6208),
    [anon_sym_Repeat] = ACTIONS(6208),
    [anon_sym_until] = ACTIONS(6208),
    [anon_sym_UNTIL] = ACTIONS(6208),
    [anon_sym_Until] = ACTIONS(6208),
    [anon_sym_exit] = ACTIONS(6208),
    [anon_sym_EXIT] = ACTIONS(6208),
    [anon_sym_Exit] = ACTIONS(6208),
    [anon_sym_continue] = ACTIONS(6208),
    [anon_sym_CONTINUE] = ACTIONS(6208),
    [anon_sym_Continue] = ACTIONS(6208),
    [anon_sym_break] = ACTIONS(6208),
    [anon_sym_BREAK] = ACTIONS(6208),
    [anon_sym_Break] = ACTIONS(6208),
    [anon_sym_with] = ACTIONS(6208),
    [anon_sym_WITH] = ACTIONS(6208),
    [anon_sym_With] = ACTIONS(6208),
    [sym_asserterror_keyword] = ACTIONS(6210),
    [sym_page_keyword] = ACTIONS(6208),
    [anon_sym_codeunit] = ACTIONS(6208),
    [anon_sym_CODEUNIT] = ACTIONS(6208),
    [anon_sym_Codeunit] = ACTIONS(6208),
    [anon_sym_CodeUnit] = ACTIONS(6208),
    [anon_sym_COdeunit] = ACTIONS(6208),
    [anon_sym_codeUnit] = ACTIONS(6208),
    [sym_report_keyword] = ACTIONS(6208),
    [sym_query_keyword] = ACTIONS(6208),
    [anon_sym_xmlport] = ACTIONS(6208),
    [anon_sym_XMLPORT] = ACTIONS(6208),
    [anon_sym_Xmlport] = ACTIONS(6208),
    [anon_sym_XMLport] = ACTIONS(6208),
    [anon_sym_XMLPort] = ACTIONS(6208),
    [anon_sym_XmlPort] = ACTIONS(6208),
    [anon_sym_enum] = ACTIONS(6208),
    [anon_sym_ENUM] = ACTIONS(6208),
    [anon_sym_Enum] = ACTIONS(6208),
    [anon_sym_eNUM] = ACTIONS(6208),
    [anon_sym_eNum] = ACTIONS(6208),
    [anon_sym_ENum] = ACTIONS(6208),
    [sym_quoted_identifier] = ACTIONS(6210),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6210),
    [sym_verbatim_string] = ACTIONS(6210),
    [sym_integer] = ACTIONS(6208),
    [sym_continue_as_identifier] = ACTIONS(6210),
    [sym_preproc_open] = ACTIONS(6210),
  },
  [STATE(2916)] = {
    [sym_identifier] = ACTIONS(6212),
    [anon_sym_SEMI] = ACTIONS(6214),
    [anon_sym_DASH] = ACTIONS(6214),
    [aux_sym_boolean_token1] = ACTIONS(6212),
    [aux_sym_boolean_token2] = ACTIONS(6212),
    [sym_decimal] = ACTIONS(6212),
    [anon_sym_LPAREN] = ACTIONS(6214),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6212),
    [anon_sym_LBRACK] = ACTIONS(6214),
    [aux_sym_record_type_token1] = ACTIONS(6212),
    [aux_sym_basic_type_token21] = ACTIONS(6212),
    [aux_sym_basic_type_token22] = ACTIONS(6212),
    [aux_sym_basic_type_token48] = ACTIONS(6212),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6212),
    [anon_sym_POUNDif] = ACTIONS(6214),
    [anon_sym_POUNDIF] = ACTIONS(6214),
    [anon_sym_POUNDIf] = ACTIONS(6214),
    [anon_sym_not] = ACTIONS(6212),
    [anon_sym_NOT] = ACTIONS(6212),
    [anon_sym_Not] = ACTIONS(6212),
    [anon_sym_POUNDelse] = ACTIONS(6214),
    [anon_sym_POUNDELSE] = ACTIONS(6214),
    [anon_sym_POUNDElse] = ACTIONS(6214),
    [anon_sym_POUNDelse2] = ACTIONS(6214),
    [anon_sym_POUNDELSE2] = ACTIONS(6214),
    [anon_sym_POUNDElse2] = ACTIONS(6214),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6212),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6212),
    [anon_sym_PLUS] = ACTIONS(6214),
    [sym_datetime_literal] = ACTIONS(6214),
    [sym_date_literal] = ACTIONS(6212),
    [sym_time_literal] = ACTIONS(6212),
    [sym_biginteger_literal] = ACTIONS(6214),
    [anon_sym_if] = ACTIONS(6212),
    [anon_sym_IF] = ACTIONS(6212),
    [anon_sym_If] = ACTIONS(6212),
    [anon_sym_else] = ACTIONS(6212),
    [anon_sym_ELSE] = ACTIONS(6212),
    [anon_sym_Else] = ACTIONS(6212),
    [anon_sym_case] = ACTIONS(6212),
    [anon_sym_CASE] = ACTIONS(6212),
    [anon_sym_Case] = ACTIONS(6212),
    [anon_sym_for] = ACTIONS(6212),
    [anon_sym_FOR] = ACTIONS(6212),
    [anon_sym_For] = ACTIONS(6212),
    [anon_sym_foreach] = ACTIONS(6212),
    [anon_sym_FOREACH] = ACTIONS(6212),
    [anon_sym_Foreach] = ACTIONS(6212),
    [anon_sym_while] = ACTIONS(6212),
    [anon_sym_WHILE] = ACTIONS(6212),
    [anon_sym_While] = ACTIONS(6212),
    [anon_sym_repeat] = ACTIONS(6212),
    [anon_sym_REPEAT] = ACTIONS(6212),
    [anon_sym_Repeat] = ACTIONS(6212),
    [anon_sym_until] = ACTIONS(6212),
    [anon_sym_UNTIL] = ACTIONS(6212),
    [anon_sym_Until] = ACTIONS(6212),
    [anon_sym_exit] = ACTIONS(6212),
    [anon_sym_EXIT] = ACTIONS(6212),
    [anon_sym_Exit] = ACTIONS(6212),
    [anon_sym_continue] = ACTIONS(6212),
    [anon_sym_CONTINUE] = ACTIONS(6212),
    [anon_sym_Continue] = ACTIONS(6212),
    [anon_sym_break] = ACTIONS(6212),
    [anon_sym_BREAK] = ACTIONS(6212),
    [anon_sym_Break] = ACTIONS(6212),
    [anon_sym_with] = ACTIONS(6212),
    [anon_sym_WITH] = ACTIONS(6212),
    [anon_sym_With] = ACTIONS(6212),
    [sym_asserterror_keyword] = ACTIONS(6214),
    [sym_page_keyword] = ACTIONS(6212),
    [anon_sym_codeunit] = ACTIONS(6212),
    [anon_sym_CODEUNIT] = ACTIONS(6212),
    [anon_sym_Codeunit] = ACTIONS(6212),
    [anon_sym_CodeUnit] = ACTIONS(6212),
    [anon_sym_COdeunit] = ACTIONS(6212),
    [anon_sym_codeUnit] = ACTIONS(6212),
    [sym_report_keyword] = ACTIONS(6212),
    [sym_query_keyword] = ACTIONS(6212),
    [anon_sym_xmlport] = ACTIONS(6212),
    [anon_sym_XMLPORT] = ACTIONS(6212),
    [anon_sym_Xmlport] = ACTIONS(6212),
    [anon_sym_XMLport] = ACTIONS(6212),
    [anon_sym_XMLPort] = ACTIONS(6212),
    [anon_sym_XmlPort] = ACTIONS(6212),
    [anon_sym_enum] = ACTIONS(6212),
    [anon_sym_ENUM] = ACTIONS(6212),
    [anon_sym_Enum] = ACTIONS(6212),
    [anon_sym_eNUM] = ACTIONS(6212),
    [anon_sym_eNum] = ACTIONS(6212),
    [anon_sym_ENum] = ACTIONS(6212),
    [sym_quoted_identifier] = ACTIONS(6214),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6214),
    [sym_verbatim_string] = ACTIONS(6214),
    [sym_integer] = ACTIONS(6212),
    [sym_continue_as_identifier] = ACTIONS(6214),
    [sym_preproc_open] = ACTIONS(6214),
  },
  [STATE(2917)] = {
    [sym_identifier] = ACTIONS(6216),
    [anon_sym_SEMI] = ACTIONS(7187),
    [anon_sym_DASH] = ACTIONS(6220),
    [aux_sym_boolean_token1] = ACTIONS(6216),
    [aux_sym_boolean_token2] = ACTIONS(6216),
    [sym_decimal] = ACTIONS(6216),
    [anon_sym_LPAREN] = ACTIONS(6220),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6220),
    [aux_sym_record_type_token1] = ACTIONS(6216),
    [aux_sym_basic_type_token21] = ACTIONS(6216),
    [aux_sym_basic_type_token22] = ACTIONS(6216),
    [aux_sym_basic_type_token48] = ACTIONS(6216),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6216),
    [anon_sym_POUNDif] = ACTIONS(6220),
    [anon_sym_POUNDIF] = ACTIONS(6220),
    [anon_sym_POUNDIf] = ACTIONS(6220),
    [anon_sym_not] = ACTIONS(6216),
    [anon_sym_NOT] = ACTIONS(6216),
    [anon_sym_Not] = ACTIONS(6216),
    [anon_sym_POUNDelse] = ACTIONS(6220),
    [anon_sym_POUNDELSE] = ACTIONS(6220),
    [anon_sym_POUNDElse] = ACTIONS(6220),
    [anon_sym_POUNDelse2] = ACTIONS(6220),
    [anon_sym_POUNDELSE2] = ACTIONS(6220),
    [anon_sym_POUNDElse2] = ACTIONS(6220),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6216),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6216),
    [anon_sym_PLUS] = ACTIONS(6220),
    [sym_datetime_literal] = ACTIONS(6220),
    [sym_date_literal] = ACTIONS(6216),
    [sym_time_literal] = ACTIONS(6216),
    [sym_biginteger_literal] = ACTIONS(6220),
    [anon_sym_if] = ACTIONS(6216),
    [anon_sym_IF] = ACTIONS(6216),
    [anon_sym_If] = ACTIONS(6216),
    [anon_sym_else] = ACTIONS(6216),
    [anon_sym_ELSE] = ACTIONS(6216),
    [anon_sym_Else] = ACTIONS(6216),
    [anon_sym_case] = ACTIONS(6216),
    [anon_sym_CASE] = ACTIONS(6216),
    [anon_sym_Case] = ACTIONS(6216),
    [anon_sym_for] = ACTIONS(6216),
    [anon_sym_FOR] = ACTIONS(6216),
    [anon_sym_For] = ACTIONS(6216),
    [anon_sym_foreach] = ACTIONS(6216),
    [anon_sym_FOREACH] = ACTIONS(6216),
    [anon_sym_Foreach] = ACTIONS(6216),
    [anon_sym_while] = ACTIONS(6216),
    [anon_sym_WHILE] = ACTIONS(6216),
    [anon_sym_While] = ACTIONS(6216),
    [anon_sym_repeat] = ACTIONS(6216),
    [anon_sym_REPEAT] = ACTIONS(6216),
    [anon_sym_Repeat] = ACTIONS(6216),
    [anon_sym_until] = ACTIONS(6216),
    [anon_sym_UNTIL] = ACTIONS(6216),
    [anon_sym_Until] = ACTIONS(6216),
    [anon_sym_exit] = ACTIONS(6216),
    [anon_sym_EXIT] = ACTIONS(6216),
    [anon_sym_Exit] = ACTIONS(6216),
    [anon_sym_continue] = ACTIONS(6216),
    [anon_sym_CONTINUE] = ACTIONS(6216),
    [anon_sym_Continue] = ACTIONS(6216),
    [anon_sym_break] = ACTIONS(6216),
    [anon_sym_BREAK] = ACTIONS(6216),
    [anon_sym_Break] = ACTIONS(6216),
    [anon_sym_with] = ACTIONS(6216),
    [anon_sym_WITH] = ACTIONS(6216),
    [anon_sym_With] = ACTIONS(6216),
    [sym_asserterror_keyword] = ACTIONS(6220),
    [sym_page_keyword] = ACTIONS(6216),
    [anon_sym_codeunit] = ACTIONS(6216),
    [anon_sym_CODEUNIT] = ACTIONS(6216),
    [anon_sym_Codeunit] = ACTIONS(6216),
    [anon_sym_CodeUnit] = ACTIONS(6216),
    [anon_sym_COdeunit] = ACTIONS(6216),
    [anon_sym_codeUnit] = ACTIONS(6216),
    [sym_report_keyword] = ACTIONS(6216),
    [sym_query_keyword] = ACTIONS(6216),
    [anon_sym_xmlport] = ACTIONS(6216),
    [anon_sym_XMLPORT] = ACTIONS(6216),
    [anon_sym_Xmlport] = ACTIONS(6216),
    [anon_sym_XMLport] = ACTIONS(6216),
    [anon_sym_XMLPort] = ACTIONS(6216),
    [anon_sym_XmlPort] = ACTIONS(6216),
    [anon_sym_enum] = ACTIONS(6216),
    [anon_sym_ENUM] = ACTIONS(6216),
    [anon_sym_Enum] = ACTIONS(6216),
    [anon_sym_eNUM] = ACTIONS(6216),
    [anon_sym_eNum] = ACTIONS(6216),
    [anon_sym_ENum] = ACTIONS(6216),
    [sym_quoted_identifier] = ACTIONS(6220),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6220),
    [sym_verbatim_string] = ACTIONS(6220),
    [sym_integer] = ACTIONS(6216),
    [sym_continue_as_identifier] = ACTIONS(6220),
    [sym_preproc_open] = ACTIONS(6220),
  },
  [STATE(2918)] = {
    [sym_identifier] = ACTIONS(6216),
    [anon_sym_SEMI] = ACTIONS(7189),
    [anon_sym_DASH] = ACTIONS(6220),
    [aux_sym_boolean_token1] = ACTIONS(6216),
    [aux_sym_boolean_token2] = ACTIONS(6216),
    [sym_decimal] = ACTIONS(6216),
    [anon_sym_LPAREN] = ACTIONS(6220),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6220),
    [aux_sym_record_type_token1] = ACTIONS(6216),
    [aux_sym_basic_type_token21] = ACTIONS(6216),
    [aux_sym_basic_type_token22] = ACTIONS(6216),
    [aux_sym_basic_type_token48] = ACTIONS(6216),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6216),
    [anon_sym_POUNDif] = ACTIONS(6220),
    [anon_sym_POUNDIF] = ACTIONS(6220),
    [anon_sym_POUNDIf] = ACTIONS(6220),
    [anon_sym_not] = ACTIONS(6216),
    [anon_sym_NOT] = ACTIONS(6216),
    [anon_sym_Not] = ACTIONS(6216),
    [anon_sym_POUNDelse] = ACTIONS(6220),
    [anon_sym_POUNDELSE] = ACTIONS(6220),
    [anon_sym_POUNDElse] = ACTIONS(6220),
    [anon_sym_POUNDelse2] = ACTIONS(6220),
    [anon_sym_POUNDELSE2] = ACTIONS(6220),
    [anon_sym_POUNDElse2] = ACTIONS(6220),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6216),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6216),
    [anon_sym_PLUS] = ACTIONS(6220),
    [sym_datetime_literal] = ACTIONS(6220),
    [sym_date_literal] = ACTIONS(6216),
    [sym_time_literal] = ACTIONS(6216),
    [sym_biginteger_literal] = ACTIONS(6220),
    [anon_sym_if] = ACTIONS(6216),
    [anon_sym_IF] = ACTIONS(6216),
    [anon_sym_If] = ACTIONS(6216),
    [anon_sym_else] = ACTIONS(6216),
    [anon_sym_ELSE] = ACTIONS(6216),
    [anon_sym_Else] = ACTIONS(6216),
    [anon_sym_case] = ACTIONS(6216),
    [anon_sym_CASE] = ACTIONS(6216),
    [anon_sym_Case] = ACTIONS(6216),
    [anon_sym_for] = ACTIONS(6216),
    [anon_sym_FOR] = ACTIONS(6216),
    [anon_sym_For] = ACTIONS(6216),
    [anon_sym_foreach] = ACTIONS(6216),
    [anon_sym_FOREACH] = ACTIONS(6216),
    [anon_sym_Foreach] = ACTIONS(6216),
    [anon_sym_while] = ACTIONS(6216),
    [anon_sym_WHILE] = ACTIONS(6216),
    [anon_sym_While] = ACTIONS(6216),
    [anon_sym_repeat] = ACTIONS(6216),
    [anon_sym_REPEAT] = ACTIONS(6216),
    [anon_sym_Repeat] = ACTIONS(6216),
    [anon_sym_until] = ACTIONS(6216),
    [anon_sym_UNTIL] = ACTIONS(6216),
    [anon_sym_Until] = ACTIONS(6216),
    [anon_sym_exit] = ACTIONS(6216),
    [anon_sym_EXIT] = ACTIONS(6216),
    [anon_sym_Exit] = ACTIONS(6216),
    [anon_sym_continue] = ACTIONS(6216),
    [anon_sym_CONTINUE] = ACTIONS(6216),
    [anon_sym_Continue] = ACTIONS(6216),
    [anon_sym_break] = ACTIONS(6216),
    [anon_sym_BREAK] = ACTIONS(6216),
    [anon_sym_Break] = ACTIONS(6216),
    [anon_sym_with] = ACTIONS(6216),
    [anon_sym_WITH] = ACTIONS(6216),
    [anon_sym_With] = ACTIONS(6216),
    [sym_asserterror_keyword] = ACTIONS(6220),
    [sym_page_keyword] = ACTIONS(6216),
    [anon_sym_codeunit] = ACTIONS(6216),
    [anon_sym_CODEUNIT] = ACTIONS(6216),
    [anon_sym_Codeunit] = ACTIONS(6216),
    [anon_sym_CodeUnit] = ACTIONS(6216),
    [anon_sym_COdeunit] = ACTIONS(6216),
    [anon_sym_codeUnit] = ACTIONS(6216),
    [sym_report_keyword] = ACTIONS(6216),
    [sym_query_keyword] = ACTIONS(6216),
    [anon_sym_xmlport] = ACTIONS(6216),
    [anon_sym_XMLPORT] = ACTIONS(6216),
    [anon_sym_Xmlport] = ACTIONS(6216),
    [anon_sym_XMLport] = ACTIONS(6216),
    [anon_sym_XMLPort] = ACTIONS(6216),
    [anon_sym_XmlPort] = ACTIONS(6216),
    [anon_sym_enum] = ACTIONS(6216),
    [anon_sym_ENUM] = ACTIONS(6216),
    [anon_sym_Enum] = ACTIONS(6216),
    [anon_sym_eNUM] = ACTIONS(6216),
    [anon_sym_eNum] = ACTIONS(6216),
    [anon_sym_ENum] = ACTIONS(6216),
    [sym_quoted_identifier] = ACTIONS(6220),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6220),
    [sym_verbatim_string] = ACTIONS(6220),
    [sym_integer] = ACTIONS(6216),
    [sym_continue_as_identifier] = ACTIONS(6220),
    [sym_preproc_open] = ACTIONS(6220),
  },
  [STATE(2919)] = {
    [sym_identifier] = ACTIONS(6224),
    [anon_sym_SEMI] = ACTIONS(6226),
    [anon_sym_DASH] = ACTIONS(6226),
    [aux_sym_boolean_token1] = ACTIONS(6224),
    [aux_sym_boolean_token2] = ACTIONS(6224),
    [sym_decimal] = ACTIONS(6224),
    [anon_sym_LPAREN] = ACTIONS(6226),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6224),
    [anon_sym_LBRACK] = ACTIONS(6226),
    [aux_sym_record_type_token1] = ACTIONS(6224),
    [aux_sym_basic_type_token21] = ACTIONS(6224),
    [aux_sym_basic_type_token22] = ACTIONS(6224),
    [aux_sym_basic_type_token48] = ACTIONS(6224),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6224),
    [anon_sym_POUNDif] = ACTIONS(6226),
    [anon_sym_POUNDIF] = ACTIONS(6226),
    [anon_sym_POUNDIf] = ACTIONS(6226),
    [anon_sym_not] = ACTIONS(6224),
    [anon_sym_NOT] = ACTIONS(6224),
    [anon_sym_Not] = ACTIONS(6224),
    [anon_sym_POUNDelse] = ACTIONS(6226),
    [anon_sym_POUNDELSE] = ACTIONS(6226),
    [anon_sym_POUNDElse] = ACTIONS(6226),
    [anon_sym_POUNDelse2] = ACTIONS(6226),
    [anon_sym_POUNDELSE2] = ACTIONS(6226),
    [anon_sym_POUNDElse2] = ACTIONS(6226),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6224),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6224),
    [anon_sym_PLUS] = ACTIONS(6226),
    [sym_datetime_literal] = ACTIONS(6226),
    [sym_date_literal] = ACTIONS(6224),
    [sym_time_literal] = ACTIONS(6224),
    [sym_biginteger_literal] = ACTIONS(6226),
    [anon_sym_if] = ACTIONS(6224),
    [anon_sym_IF] = ACTIONS(6224),
    [anon_sym_If] = ACTIONS(6224),
    [anon_sym_else] = ACTIONS(6224),
    [anon_sym_ELSE] = ACTIONS(6224),
    [anon_sym_Else] = ACTIONS(6224),
    [anon_sym_case] = ACTIONS(6224),
    [anon_sym_CASE] = ACTIONS(6224),
    [anon_sym_Case] = ACTIONS(6224),
    [anon_sym_for] = ACTIONS(6224),
    [anon_sym_FOR] = ACTIONS(6224),
    [anon_sym_For] = ACTIONS(6224),
    [anon_sym_foreach] = ACTIONS(6224),
    [anon_sym_FOREACH] = ACTIONS(6224),
    [anon_sym_Foreach] = ACTIONS(6224),
    [anon_sym_while] = ACTIONS(6224),
    [anon_sym_WHILE] = ACTIONS(6224),
    [anon_sym_While] = ACTIONS(6224),
    [anon_sym_repeat] = ACTIONS(6224),
    [anon_sym_REPEAT] = ACTIONS(6224),
    [anon_sym_Repeat] = ACTIONS(6224),
    [anon_sym_until] = ACTIONS(6224),
    [anon_sym_UNTIL] = ACTIONS(6224),
    [anon_sym_Until] = ACTIONS(6224),
    [anon_sym_exit] = ACTIONS(6224),
    [anon_sym_EXIT] = ACTIONS(6224),
    [anon_sym_Exit] = ACTIONS(6224),
    [anon_sym_continue] = ACTIONS(6224),
    [anon_sym_CONTINUE] = ACTIONS(6224),
    [anon_sym_Continue] = ACTIONS(6224),
    [anon_sym_break] = ACTIONS(6224),
    [anon_sym_BREAK] = ACTIONS(6224),
    [anon_sym_Break] = ACTIONS(6224),
    [anon_sym_with] = ACTIONS(6224),
    [anon_sym_WITH] = ACTIONS(6224),
    [anon_sym_With] = ACTIONS(6224),
    [sym_asserterror_keyword] = ACTIONS(6226),
    [sym_page_keyword] = ACTIONS(6224),
    [anon_sym_codeunit] = ACTIONS(6224),
    [anon_sym_CODEUNIT] = ACTIONS(6224),
    [anon_sym_Codeunit] = ACTIONS(6224),
    [anon_sym_CodeUnit] = ACTIONS(6224),
    [anon_sym_COdeunit] = ACTIONS(6224),
    [anon_sym_codeUnit] = ACTIONS(6224),
    [sym_report_keyword] = ACTIONS(6224),
    [sym_query_keyword] = ACTIONS(6224),
    [anon_sym_xmlport] = ACTIONS(6224),
    [anon_sym_XMLPORT] = ACTIONS(6224),
    [anon_sym_Xmlport] = ACTIONS(6224),
    [anon_sym_XMLport] = ACTIONS(6224),
    [anon_sym_XMLPort] = ACTIONS(6224),
    [anon_sym_XmlPort] = ACTIONS(6224),
    [anon_sym_enum] = ACTIONS(6224),
    [anon_sym_ENUM] = ACTIONS(6224),
    [anon_sym_Enum] = ACTIONS(6224),
    [anon_sym_eNUM] = ACTIONS(6224),
    [anon_sym_eNum] = ACTIONS(6224),
    [anon_sym_ENum] = ACTIONS(6224),
    [sym_quoted_identifier] = ACTIONS(6226),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6226),
    [sym_verbatim_string] = ACTIONS(6226),
    [sym_integer] = ACTIONS(6224),
    [sym_continue_as_identifier] = ACTIONS(6226),
    [sym_preproc_open] = ACTIONS(6226),
  },
  [STATE(2920)] = {
    [sym_identifier] = ACTIONS(6228),
    [anon_sym_SEMI] = ACTIONS(6230),
    [anon_sym_DASH] = ACTIONS(6230),
    [aux_sym_boolean_token1] = ACTIONS(6228),
    [aux_sym_boolean_token2] = ACTIONS(6228),
    [sym_decimal] = ACTIONS(6228),
    [anon_sym_LPAREN] = ACTIONS(6230),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6228),
    [anon_sym_LBRACK] = ACTIONS(6230),
    [aux_sym_record_type_token1] = ACTIONS(6228),
    [aux_sym_basic_type_token21] = ACTIONS(6228),
    [aux_sym_basic_type_token22] = ACTIONS(6228),
    [aux_sym_basic_type_token48] = ACTIONS(6228),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6228),
    [anon_sym_POUNDif] = ACTIONS(6230),
    [anon_sym_POUNDIF] = ACTIONS(6230),
    [anon_sym_POUNDIf] = ACTIONS(6230),
    [anon_sym_not] = ACTIONS(6228),
    [anon_sym_NOT] = ACTIONS(6228),
    [anon_sym_Not] = ACTIONS(6228),
    [anon_sym_POUNDelse] = ACTIONS(6230),
    [anon_sym_POUNDELSE] = ACTIONS(6230),
    [anon_sym_POUNDElse] = ACTIONS(6230),
    [anon_sym_POUNDelse2] = ACTIONS(6230),
    [anon_sym_POUNDELSE2] = ACTIONS(6230),
    [anon_sym_POUNDElse2] = ACTIONS(6230),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6228),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6228),
    [anon_sym_PLUS] = ACTIONS(6230),
    [sym_datetime_literal] = ACTIONS(6230),
    [sym_date_literal] = ACTIONS(6228),
    [sym_time_literal] = ACTIONS(6228),
    [sym_biginteger_literal] = ACTIONS(6230),
    [anon_sym_if] = ACTIONS(6228),
    [anon_sym_IF] = ACTIONS(6228),
    [anon_sym_If] = ACTIONS(6228),
    [anon_sym_else] = ACTIONS(6228),
    [anon_sym_ELSE] = ACTIONS(6228),
    [anon_sym_Else] = ACTIONS(6228),
    [anon_sym_case] = ACTIONS(6228),
    [anon_sym_CASE] = ACTIONS(6228),
    [anon_sym_Case] = ACTIONS(6228),
    [anon_sym_for] = ACTIONS(6228),
    [anon_sym_FOR] = ACTIONS(6228),
    [anon_sym_For] = ACTIONS(6228),
    [anon_sym_foreach] = ACTIONS(6228),
    [anon_sym_FOREACH] = ACTIONS(6228),
    [anon_sym_Foreach] = ACTIONS(6228),
    [anon_sym_while] = ACTIONS(6228),
    [anon_sym_WHILE] = ACTIONS(6228),
    [anon_sym_While] = ACTIONS(6228),
    [anon_sym_repeat] = ACTIONS(6228),
    [anon_sym_REPEAT] = ACTIONS(6228),
    [anon_sym_Repeat] = ACTIONS(6228),
    [anon_sym_until] = ACTIONS(6228),
    [anon_sym_UNTIL] = ACTIONS(6228),
    [anon_sym_Until] = ACTIONS(6228),
    [anon_sym_exit] = ACTIONS(6228),
    [anon_sym_EXIT] = ACTIONS(6228),
    [anon_sym_Exit] = ACTIONS(6228),
    [anon_sym_continue] = ACTIONS(6228),
    [anon_sym_CONTINUE] = ACTIONS(6228),
    [anon_sym_Continue] = ACTIONS(6228),
    [anon_sym_break] = ACTIONS(6228),
    [anon_sym_BREAK] = ACTIONS(6228),
    [anon_sym_Break] = ACTIONS(6228),
    [anon_sym_with] = ACTIONS(6228),
    [anon_sym_WITH] = ACTIONS(6228),
    [anon_sym_With] = ACTIONS(6228),
    [sym_asserterror_keyword] = ACTIONS(6230),
    [sym_page_keyword] = ACTIONS(6228),
    [anon_sym_codeunit] = ACTIONS(6228),
    [anon_sym_CODEUNIT] = ACTIONS(6228),
    [anon_sym_Codeunit] = ACTIONS(6228),
    [anon_sym_CodeUnit] = ACTIONS(6228),
    [anon_sym_COdeunit] = ACTIONS(6228),
    [anon_sym_codeUnit] = ACTIONS(6228),
    [sym_report_keyword] = ACTIONS(6228),
    [sym_query_keyword] = ACTIONS(6228),
    [anon_sym_xmlport] = ACTIONS(6228),
    [anon_sym_XMLPORT] = ACTIONS(6228),
    [anon_sym_Xmlport] = ACTIONS(6228),
    [anon_sym_XMLport] = ACTIONS(6228),
    [anon_sym_XMLPort] = ACTIONS(6228),
    [anon_sym_XmlPort] = ACTIONS(6228),
    [anon_sym_enum] = ACTIONS(6228),
    [anon_sym_ENUM] = ACTIONS(6228),
    [anon_sym_Enum] = ACTIONS(6228),
    [anon_sym_eNUM] = ACTIONS(6228),
    [anon_sym_eNum] = ACTIONS(6228),
    [anon_sym_ENum] = ACTIONS(6228),
    [sym_quoted_identifier] = ACTIONS(6230),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6230),
    [sym_verbatim_string] = ACTIONS(6230),
    [sym_integer] = ACTIONS(6228),
    [sym_continue_as_identifier] = ACTIONS(6230),
    [sym_preproc_open] = ACTIONS(6230),
  },
  [STATE(2921)] = {
    [sym_identifier] = ACTIONS(6232),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6234),
    [aux_sym_boolean_token1] = ACTIONS(6232),
    [aux_sym_boolean_token2] = ACTIONS(6232),
    [sym_decimal] = ACTIONS(6232),
    [anon_sym_LPAREN] = ACTIONS(6234),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6232),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [aux_sym_record_type_token1] = ACTIONS(6232),
    [aux_sym_basic_type_token21] = ACTIONS(6232),
    [aux_sym_basic_type_token22] = ACTIONS(6232),
    [aux_sym_basic_type_token48] = ACTIONS(6232),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6232),
    [anon_sym_POUNDif] = ACTIONS(6234),
    [anon_sym_POUNDIF] = ACTIONS(6234),
    [anon_sym_POUNDIf] = ACTIONS(6234),
    [anon_sym_not] = ACTIONS(6232),
    [anon_sym_NOT] = ACTIONS(6232),
    [anon_sym_Not] = ACTIONS(6232),
    [anon_sym_POUNDelse] = ACTIONS(6234),
    [anon_sym_POUNDELSE] = ACTIONS(6234),
    [anon_sym_POUNDElse] = ACTIONS(6234),
    [anon_sym_POUNDelse2] = ACTIONS(6234),
    [anon_sym_POUNDELSE2] = ACTIONS(6234),
    [anon_sym_POUNDElse2] = ACTIONS(6234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6232),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6232),
    [anon_sym_PLUS] = ACTIONS(6234),
    [sym_datetime_literal] = ACTIONS(6234),
    [sym_date_literal] = ACTIONS(6232),
    [sym_time_literal] = ACTIONS(6232),
    [sym_biginteger_literal] = ACTIONS(6234),
    [anon_sym_if] = ACTIONS(6232),
    [anon_sym_IF] = ACTIONS(6232),
    [anon_sym_If] = ACTIONS(6232),
    [anon_sym_else] = ACTIONS(6232),
    [anon_sym_ELSE] = ACTIONS(6232),
    [anon_sym_Else] = ACTIONS(6232),
    [anon_sym_case] = ACTIONS(6232),
    [anon_sym_CASE] = ACTIONS(6232),
    [anon_sym_Case] = ACTIONS(6232),
    [anon_sym_for] = ACTIONS(6232),
    [anon_sym_FOR] = ACTIONS(6232),
    [anon_sym_For] = ACTIONS(6232),
    [anon_sym_foreach] = ACTIONS(6232),
    [anon_sym_FOREACH] = ACTIONS(6232),
    [anon_sym_Foreach] = ACTIONS(6232),
    [anon_sym_while] = ACTIONS(6232),
    [anon_sym_WHILE] = ACTIONS(6232),
    [anon_sym_While] = ACTIONS(6232),
    [anon_sym_repeat] = ACTIONS(6232),
    [anon_sym_REPEAT] = ACTIONS(6232),
    [anon_sym_Repeat] = ACTIONS(6232),
    [anon_sym_until] = ACTIONS(6232),
    [anon_sym_UNTIL] = ACTIONS(6232),
    [anon_sym_Until] = ACTIONS(6232),
    [anon_sym_exit] = ACTIONS(6232),
    [anon_sym_EXIT] = ACTIONS(6232),
    [anon_sym_Exit] = ACTIONS(6232),
    [anon_sym_continue] = ACTIONS(6232),
    [anon_sym_CONTINUE] = ACTIONS(6232),
    [anon_sym_Continue] = ACTIONS(6232),
    [anon_sym_break] = ACTIONS(6232),
    [anon_sym_BREAK] = ACTIONS(6232),
    [anon_sym_Break] = ACTIONS(6232),
    [anon_sym_with] = ACTIONS(6232),
    [anon_sym_WITH] = ACTIONS(6232),
    [anon_sym_With] = ACTIONS(6232),
    [sym_asserterror_keyword] = ACTIONS(6234),
    [sym_page_keyword] = ACTIONS(6232),
    [anon_sym_codeunit] = ACTIONS(6232),
    [anon_sym_CODEUNIT] = ACTIONS(6232),
    [anon_sym_Codeunit] = ACTIONS(6232),
    [anon_sym_CodeUnit] = ACTIONS(6232),
    [anon_sym_COdeunit] = ACTIONS(6232),
    [anon_sym_codeUnit] = ACTIONS(6232),
    [sym_report_keyword] = ACTIONS(6232),
    [sym_query_keyword] = ACTIONS(6232),
    [anon_sym_xmlport] = ACTIONS(6232),
    [anon_sym_XMLPORT] = ACTIONS(6232),
    [anon_sym_Xmlport] = ACTIONS(6232),
    [anon_sym_XMLport] = ACTIONS(6232),
    [anon_sym_XMLPort] = ACTIONS(6232),
    [anon_sym_XmlPort] = ACTIONS(6232),
    [anon_sym_enum] = ACTIONS(6232),
    [anon_sym_ENUM] = ACTIONS(6232),
    [anon_sym_Enum] = ACTIONS(6232),
    [anon_sym_eNUM] = ACTIONS(6232),
    [anon_sym_eNum] = ACTIONS(6232),
    [anon_sym_ENum] = ACTIONS(6232),
    [sym_quoted_identifier] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6234),
    [sym_verbatim_string] = ACTIONS(6234),
    [sym_integer] = ACTIONS(6232),
    [sym_continue_as_identifier] = ACTIONS(6234),
    [sym_preproc_open] = ACTIONS(6234),
  },
  [STATE(2922)] = {
    [sym_identifier] = ACTIONS(6236),
    [anon_sym_SEMI] = ACTIONS(6238),
    [anon_sym_DASH] = ACTIONS(6238),
    [aux_sym_boolean_token1] = ACTIONS(6236),
    [aux_sym_boolean_token2] = ACTIONS(6236),
    [sym_decimal] = ACTIONS(6236),
    [anon_sym_LPAREN] = ACTIONS(6238),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6236),
    [anon_sym_LBRACK] = ACTIONS(6238),
    [aux_sym_record_type_token1] = ACTIONS(6236),
    [aux_sym_basic_type_token21] = ACTIONS(6236),
    [aux_sym_basic_type_token22] = ACTIONS(6236),
    [aux_sym_basic_type_token48] = ACTIONS(6236),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6236),
    [anon_sym_POUNDif] = ACTIONS(6238),
    [anon_sym_POUNDIF] = ACTIONS(6238),
    [anon_sym_POUNDIf] = ACTIONS(6238),
    [anon_sym_not] = ACTIONS(6236),
    [anon_sym_NOT] = ACTIONS(6236),
    [anon_sym_Not] = ACTIONS(6236),
    [anon_sym_POUNDelse] = ACTIONS(6238),
    [anon_sym_POUNDELSE] = ACTIONS(6238),
    [anon_sym_POUNDElse] = ACTIONS(6238),
    [anon_sym_POUNDelse2] = ACTIONS(6238),
    [anon_sym_POUNDELSE2] = ACTIONS(6238),
    [anon_sym_POUNDElse2] = ACTIONS(6238),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6236),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6236),
    [anon_sym_PLUS] = ACTIONS(6238),
    [sym_datetime_literal] = ACTIONS(6238),
    [sym_date_literal] = ACTIONS(6236),
    [sym_time_literal] = ACTIONS(6236),
    [sym_biginteger_literal] = ACTIONS(6238),
    [anon_sym_if] = ACTIONS(6236),
    [anon_sym_IF] = ACTIONS(6236),
    [anon_sym_If] = ACTIONS(6236),
    [anon_sym_else] = ACTIONS(6236),
    [anon_sym_ELSE] = ACTIONS(6236),
    [anon_sym_Else] = ACTIONS(6236),
    [anon_sym_case] = ACTIONS(6236),
    [anon_sym_CASE] = ACTIONS(6236),
    [anon_sym_Case] = ACTIONS(6236),
    [anon_sym_for] = ACTIONS(6236),
    [anon_sym_FOR] = ACTIONS(6236),
    [anon_sym_For] = ACTIONS(6236),
    [anon_sym_foreach] = ACTIONS(6236),
    [anon_sym_FOREACH] = ACTIONS(6236),
    [anon_sym_Foreach] = ACTIONS(6236),
    [anon_sym_while] = ACTIONS(6236),
    [anon_sym_WHILE] = ACTIONS(6236),
    [anon_sym_While] = ACTIONS(6236),
    [anon_sym_repeat] = ACTIONS(6236),
    [anon_sym_REPEAT] = ACTIONS(6236),
    [anon_sym_Repeat] = ACTIONS(6236),
    [anon_sym_until] = ACTIONS(6236),
    [anon_sym_UNTIL] = ACTIONS(6236),
    [anon_sym_Until] = ACTIONS(6236),
    [anon_sym_exit] = ACTIONS(6236),
    [anon_sym_EXIT] = ACTIONS(6236),
    [anon_sym_Exit] = ACTIONS(6236),
    [anon_sym_continue] = ACTIONS(6236),
    [anon_sym_CONTINUE] = ACTIONS(6236),
    [anon_sym_Continue] = ACTIONS(6236),
    [anon_sym_break] = ACTIONS(6236),
    [anon_sym_BREAK] = ACTIONS(6236),
    [anon_sym_Break] = ACTIONS(6236),
    [anon_sym_with] = ACTIONS(6236),
    [anon_sym_WITH] = ACTIONS(6236),
    [anon_sym_With] = ACTIONS(6236),
    [sym_asserterror_keyword] = ACTIONS(6238),
    [sym_page_keyword] = ACTIONS(6236),
    [anon_sym_codeunit] = ACTIONS(6236),
    [anon_sym_CODEUNIT] = ACTIONS(6236),
    [anon_sym_Codeunit] = ACTIONS(6236),
    [anon_sym_CodeUnit] = ACTIONS(6236),
    [anon_sym_COdeunit] = ACTIONS(6236),
    [anon_sym_codeUnit] = ACTIONS(6236),
    [sym_report_keyword] = ACTIONS(6236),
    [sym_query_keyword] = ACTIONS(6236),
    [anon_sym_xmlport] = ACTIONS(6236),
    [anon_sym_XMLPORT] = ACTIONS(6236),
    [anon_sym_Xmlport] = ACTIONS(6236),
    [anon_sym_XMLport] = ACTIONS(6236),
    [anon_sym_XMLPort] = ACTIONS(6236),
    [anon_sym_XmlPort] = ACTIONS(6236),
    [anon_sym_enum] = ACTIONS(6236),
    [anon_sym_ENUM] = ACTIONS(6236),
    [anon_sym_Enum] = ACTIONS(6236),
    [anon_sym_eNUM] = ACTIONS(6236),
    [anon_sym_eNum] = ACTIONS(6236),
    [anon_sym_ENum] = ACTIONS(6236),
    [sym_quoted_identifier] = ACTIONS(6238),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6238),
    [sym_verbatim_string] = ACTIONS(6238),
    [sym_integer] = ACTIONS(6236),
    [sym_continue_as_identifier] = ACTIONS(6238),
    [sym_preproc_open] = ACTIONS(6238),
  },
  [STATE(2923)] = {
    [sym_identifier] = ACTIONS(6232),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6234),
    [aux_sym_boolean_token1] = ACTIONS(6232),
    [aux_sym_boolean_token2] = ACTIONS(6232),
    [sym_decimal] = ACTIONS(6232),
    [anon_sym_LPAREN] = ACTIONS(6234),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6232),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [aux_sym_record_type_token1] = ACTIONS(6232),
    [aux_sym_basic_type_token21] = ACTIONS(6232),
    [aux_sym_basic_type_token22] = ACTIONS(6232),
    [aux_sym_basic_type_token48] = ACTIONS(6232),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6232),
    [anon_sym_POUNDif] = ACTIONS(6234),
    [anon_sym_POUNDIF] = ACTIONS(6234),
    [anon_sym_POUNDIf] = ACTIONS(6234),
    [anon_sym_not] = ACTIONS(6232),
    [anon_sym_NOT] = ACTIONS(6232),
    [anon_sym_Not] = ACTIONS(6232),
    [anon_sym_POUNDelse] = ACTIONS(6234),
    [anon_sym_POUNDELSE] = ACTIONS(6234),
    [anon_sym_POUNDElse] = ACTIONS(6234),
    [anon_sym_POUNDelse2] = ACTIONS(6234),
    [anon_sym_POUNDELSE2] = ACTIONS(6234),
    [anon_sym_POUNDElse2] = ACTIONS(6234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6232),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6232),
    [anon_sym_PLUS] = ACTIONS(6234),
    [sym_datetime_literal] = ACTIONS(6234),
    [sym_date_literal] = ACTIONS(6232),
    [sym_time_literal] = ACTIONS(6232),
    [sym_biginteger_literal] = ACTIONS(6234),
    [anon_sym_if] = ACTIONS(6232),
    [anon_sym_IF] = ACTIONS(6232),
    [anon_sym_If] = ACTIONS(6232),
    [anon_sym_else] = ACTIONS(6232),
    [anon_sym_ELSE] = ACTIONS(6232),
    [anon_sym_Else] = ACTIONS(6232),
    [anon_sym_case] = ACTIONS(6232),
    [anon_sym_CASE] = ACTIONS(6232),
    [anon_sym_Case] = ACTIONS(6232),
    [anon_sym_for] = ACTIONS(6232),
    [anon_sym_FOR] = ACTIONS(6232),
    [anon_sym_For] = ACTIONS(6232),
    [anon_sym_foreach] = ACTIONS(6232),
    [anon_sym_FOREACH] = ACTIONS(6232),
    [anon_sym_Foreach] = ACTIONS(6232),
    [anon_sym_while] = ACTIONS(6232),
    [anon_sym_WHILE] = ACTIONS(6232),
    [anon_sym_While] = ACTIONS(6232),
    [anon_sym_repeat] = ACTIONS(6232),
    [anon_sym_REPEAT] = ACTIONS(6232),
    [anon_sym_Repeat] = ACTIONS(6232),
    [anon_sym_until] = ACTIONS(6232),
    [anon_sym_UNTIL] = ACTIONS(6232),
    [anon_sym_Until] = ACTIONS(6232),
    [anon_sym_exit] = ACTIONS(6232),
    [anon_sym_EXIT] = ACTIONS(6232),
    [anon_sym_Exit] = ACTIONS(6232),
    [anon_sym_continue] = ACTIONS(6232),
    [anon_sym_CONTINUE] = ACTIONS(6232),
    [anon_sym_Continue] = ACTIONS(6232),
    [anon_sym_break] = ACTIONS(6232),
    [anon_sym_BREAK] = ACTIONS(6232),
    [anon_sym_Break] = ACTIONS(6232),
    [anon_sym_with] = ACTIONS(6232),
    [anon_sym_WITH] = ACTIONS(6232),
    [anon_sym_With] = ACTIONS(6232),
    [sym_asserterror_keyword] = ACTIONS(6234),
    [sym_page_keyword] = ACTIONS(6232),
    [anon_sym_codeunit] = ACTIONS(6232),
    [anon_sym_CODEUNIT] = ACTIONS(6232),
    [anon_sym_Codeunit] = ACTIONS(6232),
    [anon_sym_CodeUnit] = ACTIONS(6232),
    [anon_sym_COdeunit] = ACTIONS(6232),
    [anon_sym_codeUnit] = ACTIONS(6232),
    [sym_report_keyword] = ACTIONS(6232),
    [sym_query_keyword] = ACTIONS(6232),
    [anon_sym_xmlport] = ACTIONS(6232),
    [anon_sym_XMLPORT] = ACTIONS(6232),
    [anon_sym_Xmlport] = ACTIONS(6232),
    [anon_sym_XMLport] = ACTIONS(6232),
    [anon_sym_XMLPort] = ACTIONS(6232),
    [anon_sym_XmlPort] = ACTIONS(6232),
    [anon_sym_enum] = ACTIONS(6232),
    [anon_sym_ENUM] = ACTIONS(6232),
    [anon_sym_Enum] = ACTIONS(6232),
    [anon_sym_eNUM] = ACTIONS(6232),
    [anon_sym_eNum] = ACTIONS(6232),
    [anon_sym_ENum] = ACTIONS(6232),
    [sym_quoted_identifier] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6234),
    [sym_verbatim_string] = ACTIONS(6234),
    [sym_integer] = ACTIONS(6232),
    [sym_continue_as_identifier] = ACTIONS(6234),
    [sym_preproc_open] = ACTIONS(6234),
  },
  [STATE(2924)] = {
    [sym_identifier] = ACTIONS(6240),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6242),
    [aux_sym_boolean_token1] = ACTIONS(6240),
    [aux_sym_boolean_token2] = ACTIONS(6240),
    [sym_decimal] = ACTIONS(6240),
    [anon_sym_LPAREN] = ACTIONS(6242),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6240),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [aux_sym_record_type_token1] = ACTIONS(6240),
    [aux_sym_basic_type_token21] = ACTIONS(6240),
    [aux_sym_basic_type_token22] = ACTIONS(6240),
    [aux_sym_basic_type_token48] = ACTIONS(6240),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6240),
    [anon_sym_POUNDif] = ACTIONS(6242),
    [anon_sym_POUNDIF] = ACTIONS(6242),
    [anon_sym_POUNDIf] = ACTIONS(6242),
    [anon_sym_not] = ACTIONS(6240),
    [anon_sym_NOT] = ACTIONS(6240),
    [anon_sym_Not] = ACTIONS(6240),
    [anon_sym_POUNDelse] = ACTIONS(6242),
    [anon_sym_POUNDELSE] = ACTIONS(6242),
    [anon_sym_POUNDElse] = ACTIONS(6242),
    [anon_sym_POUNDelse2] = ACTIONS(6242),
    [anon_sym_POUNDELSE2] = ACTIONS(6242),
    [anon_sym_POUNDElse2] = ACTIONS(6242),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6240),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6242),
    [sym_datetime_literal] = ACTIONS(6242),
    [sym_date_literal] = ACTIONS(6240),
    [sym_time_literal] = ACTIONS(6240),
    [sym_biginteger_literal] = ACTIONS(6242),
    [anon_sym_if] = ACTIONS(6240),
    [anon_sym_IF] = ACTIONS(6240),
    [anon_sym_If] = ACTIONS(6240),
    [anon_sym_else] = ACTIONS(6240),
    [anon_sym_ELSE] = ACTIONS(6240),
    [anon_sym_Else] = ACTIONS(6240),
    [anon_sym_case] = ACTIONS(6240),
    [anon_sym_CASE] = ACTIONS(6240),
    [anon_sym_Case] = ACTIONS(6240),
    [anon_sym_for] = ACTIONS(6240),
    [anon_sym_FOR] = ACTIONS(6240),
    [anon_sym_For] = ACTIONS(6240),
    [anon_sym_foreach] = ACTIONS(6240),
    [anon_sym_FOREACH] = ACTIONS(6240),
    [anon_sym_Foreach] = ACTIONS(6240),
    [anon_sym_while] = ACTIONS(6240),
    [anon_sym_WHILE] = ACTIONS(6240),
    [anon_sym_While] = ACTIONS(6240),
    [anon_sym_repeat] = ACTIONS(6240),
    [anon_sym_REPEAT] = ACTIONS(6240),
    [anon_sym_Repeat] = ACTIONS(6240),
    [anon_sym_until] = ACTIONS(6240),
    [anon_sym_UNTIL] = ACTIONS(6240),
    [anon_sym_Until] = ACTIONS(6240),
    [anon_sym_exit] = ACTIONS(6240),
    [anon_sym_EXIT] = ACTIONS(6240),
    [anon_sym_Exit] = ACTIONS(6240),
    [anon_sym_continue] = ACTIONS(6240),
    [anon_sym_CONTINUE] = ACTIONS(6240),
    [anon_sym_Continue] = ACTIONS(6240),
    [anon_sym_break] = ACTIONS(6240),
    [anon_sym_BREAK] = ACTIONS(6240),
    [anon_sym_Break] = ACTIONS(6240),
    [anon_sym_with] = ACTIONS(6240),
    [anon_sym_WITH] = ACTIONS(6240),
    [anon_sym_With] = ACTIONS(6240),
    [sym_asserterror_keyword] = ACTIONS(6242),
    [sym_page_keyword] = ACTIONS(6240),
    [anon_sym_codeunit] = ACTIONS(6240),
    [anon_sym_CODEUNIT] = ACTIONS(6240),
    [anon_sym_Codeunit] = ACTIONS(6240),
    [anon_sym_CodeUnit] = ACTIONS(6240),
    [anon_sym_COdeunit] = ACTIONS(6240),
    [anon_sym_codeUnit] = ACTIONS(6240),
    [sym_report_keyword] = ACTIONS(6240),
    [sym_query_keyword] = ACTIONS(6240),
    [anon_sym_xmlport] = ACTIONS(6240),
    [anon_sym_XMLPORT] = ACTIONS(6240),
    [anon_sym_Xmlport] = ACTIONS(6240),
    [anon_sym_XMLport] = ACTIONS(6240),
    [anon_sym_XMLPort] = ACTIONS(6240),
    [anon_sym_XmlPort] = ACTIONS(6240),
    [anon_sym_enum] = ACTIONS(6240),
    [anon_sym_ENUM] = ACTIONS(6240),
    [anon_sym_Enum] = ACTIONS(6240),
    [anon_sym_eNUM] = ACTIONS(6240),
    [anon_sym_eNum] = ACTIONS(6240),
    [anon_sym_ENum] = ACTIONS(6240),
    [sym_quoted_identifier] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6242),
    [sym_verbatim_string] = ACTIONS(6242),
    [sym_integer] = ACTIONS(6240),
    [sym_continue_as_identifier] = ACTIONS(6242),
    [sym_preproc_open] = ACTIONS(6242),
  },
  [STATE(2925)] = {
    [sym_identifier] = ACTIONS(6244),
    [anon_sym_SEMI] = ACTIONS(6246),
    [anon_sym_DASH] = ACTIONS(6246),
    [aux_sym_boolean_token1] = ACTIONS(6244),
    [aux_sym_boolean_token2] = ACTIONS(6244),
    [sym_decimal] = ACTIONS(6244),
    [anon_sym_LPAREN] = ACTIONS(6246),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6244),
    [anon_sym_LBRACK] = ACTIONS(6246),
    [aux_sym_record_type_token1] = ACTIONS(6244),
    [aux_sym_basic_type_token21] = ACTIONS(6244),
    [aux_sym_basic_type_token22] = ACTIONS(6244),
    [aux_sym_basic_type_token48] = ACTIONS(6244),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6244),
    [anon_sym_POUNDif] = ACTIONS(6246),
    [anon_sym_POUNDIF] = ACTIONS(6246),
    [anon_sym_POUNDIf] = ACTIONS(6246),
    [anon_sym_not] = ACTIONS(6244),
    [anon_sym_NOT] = ACTIONS(6244),
    [anon_sym_Not] = ACTIONS(6244),
    [anon_sym_POUNDelse] = ACTIONS(6246),
    [anon_sym_POUNDELSE] = ACTIONS(6246),
    [anon_sym_POUNDElse] = ACTIONS(6246),
    [anon_sym_POUNDelse2] = ACTIONS(6246),
    [anon_sym_POUNDELSE2] = ACTIONS(6246),
    [anon_sym_POUNDElse2] = ACTIONS(6246),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6244),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6244),
    [anon_sym_PLUS] = ACTIONS(6246),
    [sym_datetime_literal] = ACTIONS(6246),
    [sym_date_literal] = ACTIONS(6244),
    [sym_time_literal] = ACTIONS(6244),
    [sym_biginteger_literal] = ACTIONS(6246),
    [anon_sym_if] = ACTIONS(6244),
    [anon_sym_IF] = ACTIONS(6244),
    [anon_sym_If] = ACTIONS(6244),
    [anon_sym_else] = ACTIONS(6244),
    [anon_sym_ELSE] = ACTIONS(6244),
    [anon_sym_Else] = ACTIONS(6244),
    [anon_sym_case] = ACTIONS(6244),
    [anon_sym_CASE] = ACTIONS(6244),
    [anon_sym_Case] = ACTIONS(6244),
    [anon_sym_for] = ACTIONS(6244),
    [anon_sym_FOR] = ACTIONS(6244),
    [anon_sym_For] = ACTIONS(6244),
    [anon_sym_foreach] = ACTIONS(6244),
    [anon_sym_FOREACH] = ACTIONS(6244),
    [anon_sym_Foreach] = ACTIONS(6244),
    [anon_sym_while] = ACTIONS(6244),
    [anon_sym_WHILE] = ACTIONS(6244),
    [anon_sym_While] = ACTIONS(6244),
    [anon_sym_repeat] = ACTIONS(6244),
    [anon_sym_REPEAT] = ACTIONS(6244),
    [anon_sym_Repeat] = ACTIONS(6244),
    [anon_sym_until] = ACTIONS(6244),
    [anon_sym_UNTIL] = ACTIONS(6244),
    [anon_sym_Until] = ACTIONS(6244),
    [anon_sym_exit] = ACTIONS(6244),
    [anon_sym_EXIT] = ACTIONS(6244),
    [anon_sym_Exit] = ACTIONS(6244),
    [anon_sym_continue] = ACTIONS(6244),
    [anon_sym_CONTINUE] = ACTIONS(6244),
    [anon_sym_Continue] = ACTIONS(6244),
    [anon_sym_break] = ACTIONS(6244),
    [anon_sym_BREAK] = ACTIONS(6244),
    [anon_sym_Break] = ACTIONS(6244),
    [anon_sym_with] = ACTIONS(6244),
    [anon_sym_WITH] = ACTIONS(6244),
    [anon_sym_With] = ACTIONS(6244),
    [sym_asserterror_keyword] = ACTIONS(6246),
    [sym_page_keyword] = ACTIONS(6244),
    [anon_sym_codeunit] = ACTIONS(6244),
    [anon_sym_CODEUNIT] = ACTIONS(6244),
    [anon_sym_Codeunit] = ACTIONS(6244),
    [anon_sym_CodeUnit] = ACTIONS(6244),
    [anon_sym_COdeunit] = ACTIONS(6244),
    [anon_sym_codeUnit] = ACTIONS(6244),
    [sym_report_keyword] = ACTIONS(6244),
    [sym_query_keyword] = ACTIONS(6244),
    [anon_sym_xmlport] = ACTIONS(6244),
    [anon_sym_XMLPORT] = ACTIONS(6244),
    [anon_sym_Xmlport] = ACTIONS(6244),
    [anon_sym_XMLport] = ACTIONS(6244),
    [anon_sym_XMLPort] = ACTIONS(6244),
    [anon_sym_XmlPort] = ACTIONS(6244),
    [anon_sym_enum] = ACTIONS(6244),
    [anon_sym_ENUM] = ACTIONS(6244),
    [anon_sym_Enum] = ACTIONS(6244),
    [anon_sym_eNUM] = ACTIONS(6244),
    [anon_sym_eNum] = ACTIONS(6244),
    [anon_sym_ENum] = ACTIONS(6244),
    [sym_quoted_identifier] = ACTIONS(6246),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6246),
    [sym_verbatim_string] = ACTIONS(6246),
    [sym_integer] = ACTIONS(6244),
    [sym_continue_as_identifier] = ACTIONS(6246),
    [sym_preproc_open] = ACTIONS(6246),
  },
  [STATE(2926)] = {
    [sym_identifier] = ACTIONS(6240),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6242),
    [aux_sym_boolean_token1] = ACTIONS(6240),
    [aux_sym_boolean_token2] = ACTIONS(6240),
    [sym_decimal] = ACTIONS(6240),
    [anon_sym_LPAREN] = ACTIONS(6242),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6240),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [aux_sym_record_type_token1] = ACTIONS(6240),
    [aux_sym_basic_type_token21] = ACTIONS(6240),
    [aux_sym_basic_type_token22] = ACTIONS(6240),
    [aux_sym_basic_type_token48] = ACTIONS(6240),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6240),
    [anon_sym_POUNDif] = ACTIONS(6242),
    [anon_sym_POUNDIF] = ACTIONS(6242),
    [anon_sym_POUNDIf] = ACTIONS(6242),
    [anon_sym_not] = ACTIONS(6240),
    [anon_sym_NOT] = ACTIONS(6240),
    [anon_sym_Not] = ACTIONS(6240),
    [anon_sym_POUNDelse] = ACTIONS(6242),
    [anon_sym_POUNDELSE] = ACTIONS(6242),
    [anon_sym_POUNDElse] = ACTIONS(6242),
    [anon_sym_POUNDelse2] = ACTIONS(6242),
    [anon_sym_POUNDELSE2] = ACTIONS(6242),
    [anon_sym_POUNDElse2] = ACTIONS(6242),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6240),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6242),
    [sym_datetime_literal] = ACTIONS(6242),
    [sym_date_literal] = ACTIONS(6240),
    [sym_time_literal] = ACTIONS(6240),
    [sym_biginteger_literal] = ACTIONS(6242),
    [anon_sym_if] = ACTIONS(6240),
    [anon_sym_IF] = ACTIONS(6240),
    [anon_sym_If] = ACTIONS(6240),
    [anon_sym_else] = ACTIONS(6240),
    [anon_sym_ELSE] = ACTIONS(6240),
    [anon_sym_Else] = ACTIONS(6240),
    [anon_sym_case] = ACTIONS(6240),
    [anon_sym_CASE] = ACTIONS(6240),
    [anon_sym_Case] = ACTIONS(6240),
    [anon_sym_for] = ACTIONS(6240),
    [anon_sym_FOR] = ACTIONS(6240),
    [anon_sym_For] = ACTIONS(6240),
    [anon_sym_foreach] = ACTIONS(6240),
    [anon_sym_FOREACH] = ACTIONS(6240),
    [anon_sym_Foreach] = ACTIONS(6240),
    [anon_sym_while] = ACTIONS(6240),
    [anon_sym_WHILE] = ACTIONS(6240),
    [anon_sym_While] = ACTIONS(6240),
    [anon_sym_repeat] = ACTIONS(6240),
    [anon_sym_REPEAT] = ACTIONS(6240),
    [anon_sym_Repeat] = ACTIONS(6240),
    [anon_sym_until] = ACTIONS(6240),
    [anon_sym_UNTIL] = ACTIONS(6240),
    [anon_sym_Until] = ACTIONS(6240),
    [anon_sym_exit] = ACTIONS(6240),
    [anon_sym_EXIT] = ACTIONS(6240),
    [anon_sym_Exit] = ACTIONS(6240),
    [anon_sym_continue] = ACTIONS(6240),
    [anon_sym_CONTINUE] = ACTIONS(6240),
    [anon_sym_Continue] = ACTIONS(6240),
    [anon_sym_break] = ACTIONS(6240),
    [anon_sym_BREAK] = ACTIONS(6240),
    [anon_sym_Break] = ACTIONS(6240),
    [anon_sym_with] = ACTIONS(6240),
    [anon_sym_WITH] = ACTIONS(6240),
    [anon_sym_With] = ACTIONS(6240),
    [sym_asserterror_keyword] = ACTIONS(6242),
    [sym_page_keyword] = ACTIONS(6240),
    [anon_sym_codeunit] = ACTIONS(6240),
    [anon_sym_CODEUNIT] = ACTIONS(6240),
    [anon_sym_Codeunit] = ACTIONS(6240),
    [anon_sym_CodeUnit] = ACTIONS(6240),
    [anon_sym_COdeunit] = ACTIONS(6240),
    [anon_sym_codeUnit] = ACTIONS(6240),
    [sym_report_keyword] = ACTIONS(6240),
    [sym_query_keyword] = ACTIONS(6240),
    [anon_sym_xmlport] = ACTIONS(6240),
    [anon_sym_XMLPORT] = ACTIONS(6240),
    [anon_sym_Xmlport] = ACTIONS(6240),
    [anon_sym_XMLport] = ACTIONS(6240),
    [anon_sym_XMLPort] = ACTIONS(6240),
    [anon_sym_XmlPort] = ACTIONS(6240),
    [anon_sym_enum] = ACTIONS(6240),
    [anon_sym_ENUM] = ACTIONS(6240),
    [anon_sym_Enum] = ACTIONS(6240),
    [anon_sym_eNUM] = ACTIONS(6240),
    [anon_sym_eNum] = ACTIONS(6240),
    [anon_sym_ENum] = ACTIONS(6240),
    [sym_quoted_identifier] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6242),
    [sym_verbatim_string] = ACTIONS(6242),
    [sym_integer] = ACTIONS(6240),
    [sym_continue_as_identifier] = ACTIONS(6242),
    [sym_preproc_open] = ACTIONS(6242),
  },
  [STATE(2927)] = {
    [sym_identifier] = ACTIONS(6248),
    [anon_sym_SEMI] = ACTIONS(6250),
    [anon_sym_DASH] = ACTIONS(6250),
    [aux_sym_boolean_token1] = ACTIONS(6248),
    [aux_sym_boolean_token2] = ACTIONS(6248),
    [sym_decimal] = ACTIONS(6248),
    [anon_sym_LPAREN] = ACTIONS(6250),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6248),
    [anon_sym_LBRACK] = ACTIONS(6250),
    [aux_sym_record_type_token1] = ACTIONS(6248),
    [aux_sym_basic_type_token21] = ACTIONS(6248),
    [aux_sym_basic_type_token22] = ACTIONS(6248),
    [aux_sym_basic_type_token48] = ACTIONS(6248),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6248),
    [anon_sym_POUNDif] = ACTIONS(6250),
    [anon_sym_POUNDIF] = ACTIONS(6250),
    [anon_sym_POUNDIf] = ACTIONS(6250),
    [anon_sym_not] = ACTIONS(6248),
    [anon_sym_NOT] = ACTIONS(6248),
    [anon_sym_Not] = ACTIONS(6248),
    [anon_sym_POUNDelse] = ACTIONS(6250),
    [anon_sym_POUNDELSE] = ACTIONS(6250),
    [anon_sym_POUNDElse] = ACTIONS(6250),
    [anon_sym_POUNDelse2] = ACTIONS(6250),
    [anon_sym_POUNDELSE2] = ACTIONS(6250),
    [anon_sym_POUNDElse2] = ACTIONS(6250),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6248),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6248),
    [anon_sym_PLUS] = ACTIONS(6250),
    [sym_datetime_literal] = ACTIONS(6250),
    [sym_date_literal] = ACTIONS(6248),
    [sym_time_literal] = ACTIONS(6248),
    [sym_biginteger_literal] = ACTIONS(6250),
    [anon_sym_if] = ACTIONS(6248),
    [anon_sym_IF] = ACTIONS(6248),
    [anon_sym_If] = ACTIONS(6248),
    [anon_sym_else] = ACTIONS(6248),
    [anon_sym_ELSE] = ACTIONS(6248),
    [anon_sym_Else] = ACTIONS(6248),
    [anon_sym_case] = ACTIONS(6248),
    [anon_sym_CASE] = ACTIONS(6248),
    [anon_sym_Case] = ACTIONS(6248),
    [anon_sym_for] = ACTIONS(6248),
    [anon_sym_FOR] = ACTIONS(6248),
    [anon_sym_For] = ACTIONS(6248),
    [anon_sym_foreach] = ACTIONS(6248),
    [anon_sym_FOREACH] = ACTIONS(6248),
    [anon_sym_Foreach] = ACTIONS(6248),
    [anon_sym_while] = ACTIONS(6248),
    [anon_sym_WHILE] = ACTIONS(6248),
    [anon_sym_While] = ACTIONS(6248),
    [anon_sym_repeat] = ACTIONS(6248),
    [anon_sym_REPEAT] = ACTIONS(6248),
    [anon_sym_Repeat] = ACTIONS(6248),
    [anon_sym_until] = ACTIONS(6248),
    [anon_sym_UNTIL] = ACTIONS(6248),
    [anon_sym_Until] = ACTIONS(6248),
    [anon_sym_exit] = ACTIONS(6248),
    [anon_sym_EXIT] = ACTIONS(6248),
    [anon_sym_Exit] = ACTIONS(6248),
    [anon_sym_continue] = ACTIONS(6248),
    [anon_sym_CONTINUE] = ACTIONS(6248),
    [anon_sym_Continue] = ACTIONS(6248),
    [anon_sym_break] = ACTIONS(6248),
    [anon_sym_BREAK] = ACTIONS(6248),
    [anon_sym_Break] = ACTIONS(6248),
    [anon_sym_with] = ACTIONS(6248),
    [anon_sym_WITH] = ACTIONS(6248),
    [anon_sym_With] = ACTIONS(6248),
    [sym_asserterror_keyword] = ACTIONS(6250),
    [sym_page_keyword] = ACTIONS(6248),
    [anon_sym_codeunit] = ACTIONS(6248),
    [anon_sym_CODEUNIT] = ACTIONS(6248),
    [anon_sym_Codeunit] = ACTIONS(6248),
    [anon_sym_CodeUnit] = ACTIONS(6248),
    [anon_sym_COdeunit] = ACTIONS(6248),
    [anon_sym_codeUnit] = ACTIONS(6248),
    [sym_report_keyword] = ACTIONS(6248),
    [sym_query_keyword] = ACTIONS(6248),
    [anon_sym_xmlport] = ACTIONS(6248),
    [anon_sym_XMLPORT] = ACTIONS(6248),
    [anon_sym_Xmlport] = ACTIONS(6248),
    [anon_sym_XMLport] = ACTIONS(6248),
    [anon_sym_XMLPort] = ACTIONS(6248),
    [anon_sym_XmlPort] = ACTIONS(6248),
    [anon_sym_enum] = ACTIONS(6248),
    [anon_sym_ENUM] = ACTIONS(6248),
    [anon_sym_Enum] = ACTIONS(6248),
    [anon_sym_eNUM] = ACTIONS(6248),
    [anon_sym_eNum] = ACTIONS(6248),
    [anon_sym_ENum] = ACTIONS(6248),
    [sym_quoted_identifier] = ACTIONS(6250),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6250),
    [sym_verbatim_string] = ACTIONS(6250),
    [sym_integer] = ACTIONS(6248),
    [sym_continue_as_identifier] = ACTIONS(6250),
    [sym_preproc_open] = ACTIONS(6250),
  },
  [STATE(2928)] = {
    [sym_identifier] = ACTIONS(6252),
    [anon_sym_SEMI] = ACTIONS(6254),
    [anon_sym_DASH] = ACTIONS(6254),
    [aux_sym_boolean_token1] = ACTIONS(6252),
    [aux_sym_boolean_token2] = ACTIONS(6252),
    [sym_decimal] = ACTIONS(6252),
    [anon_sym_LPAREN] = ACTIONS(6254),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6252),
    [anon_sym_LBRACK] = ACTIONS(6254),
    [aux_sym_record_type_token1] = ACTIONS(6252),
    [aux_sym_basic_type_token21] = ACTIONS(6252),
    [aux_sym_basic_type_token22] = ACTIONS(6252),
    [aux_sym_basic_type_token48] = ACTIONS(6252),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6252),
    [anon_sym_POUNDif] = ACTIONS(6254),
    [anon_sym_POUNDIF] = ACTIONS(6254),
    [anon_sym_POUNDIf] = ACTIONS(6254),
    [anon_sym_not] = ACTIONS(6252),
    [anon_sym_NOT] = ACTIONS(6252),
    [anon_sym_Not] = ACTIONS(6252),
    [anon_sym_POUNDelse] = ACTIONS(6254),
    [anon_sym_POUNDELSE] = ACTIONS(6254),
    [anon_sym_POUNDElse] = ACTIONS(6254),
    [anon_sym_POUNDelse2] = ACTIONS(6254),
    [anon_sym_POUNDELSE2] = ACTIONS(6254),
    [anon_sym_POUNDElse2] = ACTIONS(6254),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6252),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6252),
    [anon_sym_PLUS] = ACTIONS(6254),
    [sym_datetime_literal] = ACTIONS(6254),
    [sym_date_literal] = ACTIONS(6252),
    [sym_time_literal] = ACTIONS(6252),
    [sym_biginteger_literal] = ACTIONS(6254),
    [anon_sym_if] = ACTIONS(6252),
    [anon_sym_IF] = ACTIONS(6252),
    [anon_sym_If] = ACTIONS(6252),
    [anon_sym_else] = ACTIONS(6252),
    [anon_sym_ELSE] = ACTIONS(6252),
    [anon_sym_Else] = ACTIONS(6252),
    [anon_sym_case] = ACTIONS(6252),
    [anon_sym_CASE] = ACTIONS(6252),
    [anon_sym_Case] = ACTIONS(6252),
    [anon_sym_for] = ACTIONS(6252),
    [anon_sym_FOR] = ACTIONS(6252),
    [anon_sym_For] = ACTIONS(6252),
    [anon_sym_foreach] = ACTIONS(6252),
    [anon_sym_FOREACH] = ACTIONS(6252),
    [anon_sym_Foreach] = ACTIONS(6252),
    [anon_sym_while] = ACTIONS(6252),
    [anon_sym_WHILE] = ACTIONS(6252),
    [anon_sym_While] = ACTIONS(6252),
    [anon_sym_repeat] = ACTIONS(6252),
    [anon_sym_REPEAT] = ACTIONS(6252),
    [anon_sym_Repeat] = ACTIONS(6252),
    [anon_sym_until] = ACTIONS(6252),
    [anon_sym_UNTIL] = ACTIONS(6252),
    [anon_sym_Until] = ACTIONS(6252),
    [anon_sym_exit] = ACTIONS(6252),
    [anon_sym_EXIT] = ACTIONS(6252),
    [anon_sym_Exit] = ACTIONS(6252),
    [anon_sym_continue] = ACTIONS(6252),
    [anon_sym_CONTINUE] = ACTIONS(6252),
    [anon_sym_Continue] = ACTIONS(6252),
    [anon_sym_break] = ACTIONS(6252),
    [anon_sym_BREAK] = ACTIONS(6252),
    [anon_sym_Break] = ACTIONS(6252),
    [anon_sym_with] = ACTIONS(6252),
    [anon_sym_WITH] = ACTIONS(6252),
    [anon_sym_With] = ACTIONS(6252),
    [sym_asserterror_keyword] = ACTIONS(6254),
    [sym_page_keyword] = ACTIONS(6252),
    [anon_sym_codeunit] = ACTIONS(6252),
    [anon_sym_CODEUNIT] = ACTIONS(6252),
    [anon_sym_Codeunit] = ACTIONS(6252),
    [anon_sym_CodeUnit] = ACTIONS(6252),
    [anon_sym_COdeunit] = ACTIONS(6252),
    [anon_sym_codeUnit] = ACTIONS(6252),
    [sym_report_keyword] = ACTIONS(6252),
    [sym_query_keyword] = ACTIONS(6252),
    [anon_sym_xmlport] = ACTIONS(6252),
    [anon_sym_XMLPORT] = ACTIONS(6252),
    [anon_sym_Xmlport] = ACTIONS(6252),
    [anon_sym_XMLport] = ACTIONS(6252),
    [anon_sym_XMLPort] = ACTIONS(6252),
    [anon_sym_XmlPort] = ACTIONS(6252),
    [anon_sym_enum] = ACTIONS(6252),
    [anon_sym_ENUM] = ACTIONS(6252),
    [anon_sym_Enum] = ACTIONS(6252),
    [anon_sym_eNUM] = ACTIONS(6252),
    [anon_sym_eNum] = ACTIONS(6252),
    [anon_sym_ENum] = ACTIONS(6252),
    [sym_quoted_identifier] = ACTIONS(6254),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6254),
    [sym_verbatim_string] = ACTIONS(6254),
    [sym_integer] = ACTIONS(6252),
    [sym_continue_as_identifier] = ACTIONS(6254),
    [sym_preproc_open] = ACTIONS(6254),
  },
  [STATE(2929)] = {
    [sym_identifier] = ACTIONS(6256),
    [anon_sym_SEMI] = ACTIONS(6258),
    [anon_sym_DASH] = ACTIONS(6258),
    [aux_sym_boolean_token1] = ACTIONS(6256),
    [aux_sym_boolean_token2] = ACTIONS(6256),
    [sym_decimal] = ACTIONS(6256),
    [anon_sym_LPAREN] = ACTIONS(6258),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(6258),
    [aux_sym_record_type_token1] = ACTIONS(6256),
    [aux_sym_basic_type_token21] = ACTIONS(6256),
    [aux_sym_basic_type_token22] = ACTIONS(6256),
    [aux_sym_basic_type_token48] = ACTIONS(6256),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6256),
    [anon_sym_POUNDif] = ACTIONS(6258),
    [anon_sym_POUNDIF] = ACTIONS(6258),
    [anon_sym_POUNDIf] = ACTIONS(6258),
    [anon_sym_not] = ACTIONS(6256),
    [anon_sym_NOT] = ACTIONS(6256),
    [anon_sym_Not] = ACTIONS(6256),
    [anon_sym_POUNDelse] = ACTIONS(6258),
    [anon_sym_POUNDELSE] = ACTIONS(6258),
    [anon_sym_POUNDElse] = ACTIONS(6258),
    [anon_sym_POUNDelse2] = ACTIONS(6258),
    [anon_sym_POUNDELSE2] = ACTIONS(6258),
    [anon_sym_POUNDElse2] = ACTIONS(6258),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6256),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6256),
    [anon_sym_PLUS] = ACTIONS(6258),
    [sym_datetime_literal] = ACTIONS(6258),
    [sym_date_literal] = ACTIONS(6256),
    [sym_time_literal] = ACTIONS(6256),
    [sym_biginteger_literal] = ACTIONS(6258),
    [anon_sym_if] = ACTIONS(6256),
    [anon_sym_IF] = ACTIONS(6256),
    [anon_sym_If] = ACTIONS(6256),
    [anon_sym_else] = ACTIONS(6256),
    [anon_sym_ELSE] = ACTIONS(6256),
    [anon_sym_Else] = ACTIONS(6256),
    [anon_sym_case] = ACTIONS(6256),
    [anon_sym_CASE] = ACTIONS(6256),
    [anon_sym_Case] = ACTIONS(6256),
    [anon_sym_for] = ACTIONS(6256),
    [anon_sym_FOR] = ACTIONS(6256),
    [anon_sym_For] = ACTIONS(6256),
    [anon_sym_foreach] = ACTIONS(6256),
    [anon_sym_FOREACH] = ACTIONS(6256),
    [anon_sym_Foreach] = ACTIONS(6256),
    [anon_sym_while] = ACTIONS(6256),
    [anon_sym_WHILE] = ACTIONS(6256),
    [anon_sym_While] = ACTIONS(6256),
    [anon_sym_repeat] = ACTIONS(6256),
    [anon_sym_REPEAT] = ACTIONS(6256),
    [anon_sym_Repeat] = ACTIONS(6256),
    [anon_sym_until] = ACTIONS(6256),
    [anon_sym_UNTIL] = ACTIONS(6256),
    [anon_sym_Until] = ACTIONS(6256),
    [anon_sym_exit] = ACTIONS(6256),
    [anon_sym_EXIT] = ACTIONS(6256),
    [anon_sym_Exit] = ACTIONS(6256),
    [anon_sym_continue] = ACTIONS(6256),
    [anon_sym_CONTINUE] = ACTIONS(6256),
    [anon_sym_Continue] = ACTIONS(6256),
    [anon_sym_break] = ACTIONS(6256),
    [anon_sym_BREAK] = ACTIONS(6256),
    [anon_sym_Break] = ACTIONS(6256),
    [anon_sym_with] = ACTIONS(6256),
    [anon_sym_WITH] = ACTIONS(6256),
    [anon_sym_With] = ACTIONS(6256),
    [sym_asserterror_keyword] = ACTIONS(6258),
    [sym_page_keyword] = ACTIONS(6256),
    [anon_sym_codeunit] = ACTIONS(6256),
    [anon_sym_CODEUNIT] = ACTIONS(6256),
    [anon_sym_Codeunit] = ACTIONS(6256),
    [anon_sym_CodeUnit] = ACTIONS(6256),
    [anon_sym_COdeunit] = ACTIONS(6256),
    [anon_sym_codeUnit] = ACTIONS(6256),
    [sym_report_keyword] = ACTIONS(6256),
    [sym_query_keyword] = ACTIONS(6256),
    [anon_sym_xmlport] = ACTIONS(6256),
    [anon_sym_XMLPORT] = ACTIONS(6256),
    [anon_sym_Xmlport] = ACTIONS(6256),
    [anon_sym_XMLport] = ACTIONS(6256),
    [anon_sym_XMLPort] = ACTIONS(6256),
    [anon_sym_XmlPort] = ACTIONS(6256),
    [anon_sym_enum] = ACTIONS(6256),
    [anon_sym_ENUM] = ACTIONS(6256),
    [anon_sym_Enum] = ACTIONS(6256),
    [anon_sym_eNUM] = ACTIONS(6256),
    [anon_sym_eNum] = ACTIONS(6256),
    [anon_sym_ENum] = ACTIONS(6256),
    [sym_quoted_identifier] = ACTIONS(6258),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6258),
    [sym_verbatim_string] = ACTIONS(6258),
    [sym_integer] = ACTIONS(6256),
    [sym_continue_as_identifier] = ACTIONS(6258),
    [sym_preproc_open] = ACTIONS(6258),
  },
  [STATE(2930)] = {
    [sym_identifier] = ACTIONS(6260),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6262),
    [aux_sym_boolean_token1] = ACTIONS(6260),
    [aux_sym_boolean_token2] = ACTIONS(6260),
    [sym_decimal] = ACTIONS(6260),
    [anon_sym_LPAREN] = ACTIONS(6262),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6260),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [aux_sym_record_type_token1] = ACTIONS(6260),
    [aux_sym_basic_type_token21] = ACTIONS(6260),
    [aux_sym_basic_type_token22] = ACTIONS(6260),
    [aux_sym_basic_type_token48] = ACTIONS(6260),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6260),
    [anon_sym_POUNDif] = ACTIONS(6262),
    [anon_sym_POUNDIF] = ACTIONS(6262),
    [anon_sym_POUNDIf] = ACTIONS(6262),
    [anon_sym_not] = ACTIONS(6260),
    [anon_sym_NOT] = ACTIONS(6260),
    [anon_sym_Not] = ACTIONS(6260),
    [anon_sym_POUNDelse] = ACTIONS(6262),
    [anon_sym_POUNDELSE] = ACTIONS(6262),
    [anon_sym_POUNDElse] = ACTIONS(6262),
    [anon_sym_POUNDelse2] = ACTIONS(6262),
    [anon_sym_POUNDELSE2] = ACTIONS(6262),
    [anon_sym_POUNDElse2] = ACTIONS(6262),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6260),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6262),
    [sym_datetime_literal] = ACTIONS(6262),
    [sym_date_literal] = ACTIONS(6260),
    [sym_time_literal] = ACTIONS(6260),
    [sym_biginteger_literal] = ACTIONS(6262),
    [anon_sym_if] = ACTIONS(6260),
    [anon_sym_IF] = ACTIONS(6260),
    [anon_sym_If] = ACTIONS(6260),
    [anon_sym_else] = ACTIONS(6260),
    [anon_sym_ELSE] = ACTIONS(6260),
    [anon_sym_Else] = ACTIONS(6260),
    [anon_sym_case] = ACTIONS(6260),
    [anon_sym_CASE] = ACTIONS(6260),
    [anon_sym_Case] = ACTIONS(6260),
    [anon_sym_for] = ACTIONS(6260),
    [anon_sym_FOR] = ACTIONS(6260),
    [anon_sym_For] = ACTIONS(6260),
    [anon_sym_foreach] = ACTIONS(6260),
    [anon_sym_FOREACH] = ACTIONS(6260),
    [anon_sym_Foreach] = ACTIONS(6260),
    [anon_sym_while] = ACTIONS(6260),
    [anon_sym_WHILE] = ACTIONS(6260),
    [anon_sym_While] = ACTIONS(6260),
    [anon_sym_repeat] = ACTIONS(6260),
    [anon_sym_REPEAT] = ACTIONS(6260),
    [anon_sym_Repeat] = ACTIONS(6260),
    [anon_sym_until] = ACTIONS(6260),
    [anon_sym_UNTIL] = ACTIONS(6260),
    [anon_sym_Until] = ACTIONS(6260),
    [anon_sym_exit] = ACTIONS(6260),
    [anon_sym_EXIT] = ACTIONS(6260),
    [anon_sym_Exit] = ACTIONS(6260),
    [anon_sym_continue] = ACTIONS(6260),
    [anon_sym_CONTINUE] = ACTIONS(6260),
    [anon_sym_Continue] = ACTIONS(6260),
    [anon_sym_break] = ACTIONS(6260),
    [anon_sym_BREAK] = ACTIONS(6260),
    [anon_sym_Break] = ACTIONS(6260),
    [anon_sym_with] = ACTIONS(6260),
    [anon_sym_WITH] = ACTIONS(6260),
    [anon_sym_With] = ACTIONS(6260),
    [sym_asserterror_keyword] = ACTIONS(6262),
    [sym_page_keyword] = ACTIONS(6260),
    [anon_sym_codeunit] = ACTIONS(6260),
    [anon_sym_CODEUNIT] = ACTIONS(6260),
    [anon_sym_Codeunit] = ACTIONS(6260),
    [anon_sym_CodeUnit] = ACTIONS(6260),
    [anon_sym_COdeunit] = ACTIONS(6260),
    [anon_sym_codeUnit] = ACTIONS(6260),
    [sym_report_keyword] = ACTIONS(6260),
    [sym_query_keyword] = ACTIONS(6260),
    [anon_sym_xmlport] = ACTIONS(6260),
    [anon_sym_XMLPORT] = ACTIONS(6260),
    [anon_sym_Xmlport] = ACTIONS(6260),
    [anon_sym_XMLport] = ACTIONS(6260),
    [anon_sym_XMLPort] = ACTIONS(6260),
    [anon_sym_XmlPort] = ACTIONS(6260),
    [anon_sym_enum] = ACTIONS(6260),
    [anon_sym_ENUM] = ACTIONS(6260),
    [anon_sym_Enum] = ACTIONS(6260),
    [anon_sym_eNUM] = ACTIONS(6260),
    [anon_sym_eNum] = ACTIONS(6260),
    [anon_sym_ENum] = ACTIONS(6260),
    [sym_quoted_identifier] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6262),
    [sym_verbatim_string] = ACTIONS(6262),
    [sym_integer] = ACTIONS(6260),
    [sym_continue_as_identifier] = ACTIONS(6262),
    [sym_preproc_open] = ACTIONS(6262),
  },
  [STATE(2931)] = {
    [sym_identifier] = ACTIONS(6260),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6262),
    [aux_sym_boolean_token1] = ACTIONS(6260),
    [aux_sym_boolean_token2] = ACTIONS(6260),
    [sym_decimal] = ACTIONS(6260),
    [anon_sym_LPAREN] = ACTIONS(6262),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6260),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [aux_sym_record_type_token1] = ACTIONS(6260),
    [aux_sym_basic_type_token21] = ACTIONS(6260),
    [aux_sym_basic_type_token22] = ACTIONS(6260),
    [aux_sym_basic_type_token48] = ACTIONS(6260),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6260),
    [anon_sym_POUNDif] = ACTIONS(6262),
    [anon_sym_POUNDIF] = ACTIONS(6262),
    [anon_sym_POUNDIf] = ACTIONS(6262),
    [anon_sym_not] = ACTIONS(6260),
    [anon_sym_NOT] = ACTIONS(6260),
    [anon_sym_Not] = ACTIONS(6260),
    [anon_sym_POUNDelse] = ACTIONS(6262),
    [anon_sym_POUNDELSE] = ACTIONS(6262),
    [anon_sym_POUNDElse] = ACTIONS(6262),
    [anon_sym_POUNDelse2] = ACTIONS(6262),
    [anon_sym_POUNDELSE2] = ACTIONS(6262),
    [anon_sym_POUNDElse2] = ACTIONS(6262),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6260),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6262),
    [sym_datetime_literal] = ACTIONS(6262),
    [sym_date_literal] = ACTIONS(6260),
    [sym_time_literal] = ACTIONS(6260),
    [sym_biginteger_literal] = ACTIONS(6262),
    [anon_sym_if] = ACTIONS(6260),
    [anon_sym_IF] = ACTIONS(6260),
    [anon_sym_If] = ACTIONS(6260),
    [anon_sym_else] = ACTIONS(6260),
    [anon_sym_ELSE] = ACTIONS(6260),
    [anon_sym_Else] = ACTIONS(6260),
    [anon_sym_case] = ACTIONS(6260),
    [anon_sym_CASE] = ACTIONS(6260),
    [anon_sym_Case] = ACTIONS(6260),
    [anon_sym_for] = ACTIONS(6260),
    [anon_sym_FOR] = ACTIONS(6260),
    [anon_sym_For] = ACTIONS(6260),
    [anon_sym_foreach] = ACTIONS(6260),
    [anon_sym_FOREACH] = ACTIONS(6260),
    [anon_sym_Foreach] = ACTIONS(6260),
    [anon_sym_while] = ACTIONS(6260),
    [anon_sym_WHILE] = ACTIONS(6260),
    [anon_sym_While] = ACTIONS(6260),
    [anon_sym_repeat] = ACTIONS(6260),
    [anon_sym_REPEAT] = ACTIONS(6260),
    [anon_sym_Repeat] = ACTIONS(6260),
    [anon_sym_until] = ACTIONS(6260),
    [anon_sym_UNTIL] = ACTIONS(6260),
    [anon_sym_Until] = ACTIONS(6260),
    [anon_sym_exit] = ACTIONS(6260),
    [anon_sym_EXIT] = ACTIONS(6260),
    [anon_sym_Exit] = ACTIONS(6260),
    [anon_sym_continue] = ACTIONS(6260),
    [anon_sym_CONTINUE] = ACTIONS(6260),
    [anon_sym_Continue] = ACTIONS(6260),
    [anon_sym_break] = ACTIONS(6260),
    [anon_sym_BREAK] = ACTIONS(6260),
    [anon_sym_Break] = ACTIONS(6260),
    [anon_sym_with] = ACTIONS(6260),
    [anon_sym_WITH] = ACTIONS(6260),
    [anon_sym_With] = ACTIONS(6260),
    [sym_asserterror_keyword] = ACTIONS(6262),
    [sym_page_keyword] = ACTIONS(6260),
    [anon_sym_codeunit] = ACTIONS(6260),
    [anon_sym_CODEUNIT] = ACTIONS(6260),
    [anon_sym_Codeunit] = ACTIONS(6260),
    [anon_sym_CodeUnit] = ACTIONS(6260),
    [anon_sym_COdeunit] = ACTIONS(6260),
    [anon_sym_codeUnit] = ACTIONS(6260),
    [sym_report_keyword] = ACTIONS(6260),
    [sym_query_keyword] = ACTIONS(6260),
    [anon_sym_xmlport] = ACTIONS(6260),
    [anon_sym_XMLPORT] = ACTIONS(6260),
    [anon_sym_Xmlport] = ACTIONS(6260),
    [anon_sym_XMLport] = ACTIONS(6260),
    [anon_sym_XMLPort] = ACTIONS(6260),
    [anon_sym_XmlPort] = ACTIONS(6260),
    [anon_sym_enum] = ACTIONS(6260),
    [anon_sym_ENUM] = ACTIONS(6260),
    [anon_sym_Enum] = ACTIONS(6260),
    [anon_sym_eNUM] = ACTIONS(6260),
    [anon_sym_eNum] = ACTIONS(6260),
    [anon_sym_ENum] = ACTIONS(6260),
    [sym_quoted_identifier] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6262),
    [sym_verbatim_string] = ACTIONS(6262),
    [sym_integer] = ACTIONS(6260),
    [sym_continue_as_identifier] = ACTIONS(6262),
    [sym_preproc_open] = ACTIONS(6262),
  },
  [STATE(2932)] = {
    [sym_identifier] = ACTIONS(6264),
    [anon_sym_SEMI] = ACTIONS(7191),
    [anon_sym_DASH] = ACTIONS(6268),
    [aux_sym_boolean_token1] = ACTIONS(6264),
    [aux_sym_boolean_token2] = ACTIONS(6264),
    [sym_decimal] = ACTIONS(6264),
    [anon_sym_LPAREN] = ACTIONS(6268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6264),
    [anon_sym_LBRACK] = ACTIONS(6268),
    [aux_sym_record_type_token1] = ACTIONS(6264),
    [aux_sym_basic_type_token21] = ACTIONS(6264),
    [aux_sym_basic_type_token22] = ACTIONS(6264),
    [aux_sym_basic_type_token48] = ACTIONS(6264),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6264),
    [anon_sym_POUNDif] = ACTIONS(6268),
    [anon_sym_POUNDIF] = ACTIONS(6268),
    [anon_sym_POUNDIf] = ACTIONS(6268),
    [anon_sym_not] = ACTIONS(6264),
    [anon_sym_NOT] = ACTIONS(6264),
    [anon_sym_Not] = ACTIONS(6264),
    [anon_sym_POUNDelse] = ACTIONS(6268),
    [anon_sym_POUNDELSE] = ACTIONS(6268),
    [anon_sym_POUNDElse] = ACTIONS(6268),
    [anon_sym_POUNDelse2] = ACTIONS(6268),
    [anon_sym_POUNDELSE2] = ACTIONS(6268),
    [anon_sym_POUNDElse2] = ACTIONS(6268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6264),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6268),
    [sym_datetime_literal] = ACTIONS(6268),
    [sym_date_literal] = ACTIONS(6264),
    [sym_time_literal] = ACTIONS(6264),
    [sym_biginteger_literal] = ACTIONS(6268),
    [anon_sym_if] = ACTIONS(6264),
    [anon_sym_IF] = ACTIONS(6264),
    [anon_sym_If] = ACTIONS(6264),
    [anon_sym_else] = ACTIONS(6264),
    [anon_sym_ELSE] = ACTIONS(6264),
    [anon_sym_Else] = ACTIONS(6264),
    [anon_sym_case] = ACTIONS(6264),
    [anon_sym_CASE] = ACTIONS(6264),
    [anon_sym_Case] = ACTIONS(6264),
    [anon_sym_for] = ACTIONS(6264),
    [anon_sym_FOR] = ACTIONS(6264),
    [anon_sym_For] = ACTIONS(6264),
    [anon_sym_foreach] = ACTIONS(6264),
    [anon_sym_FOREACH] = ACTIONS(6264),
    [anon_sym_Foreach] = ACTIONS(6264),
    [anon_sym_while] = ACTIONS(6264),
    [anon_sym_WHILE] = ACTIONS(6264),
    [anon_sym_While] = ACTIONS(6264),
    [anon_sym_repeat] = ACTIONS(6264),
    [anon_sym_REPEAT] = ACTIONS(6264),
    [anon_sym_Repeat] = ACTIONS(6264),
    [anon_sym_until] = ACTIONS(6264),
    [anon_sym_UNTIL] = ACTIONS(6264),
    [anon_sym_Until] = ACTIONS(6264),
    [anon_sym_exit] = ACTIONS(6264),
    [anon_sym_EXIT] = ACTIONS(6264),
    [anon_sym_Exit] = ACTIONS(6264),
    [anon_sym_continue] = ACTIONS(6264),
    [anon_sym_CONTINUE] = ACTIONS(6264),
    [anon_sym_Continue] = ACTIONS(6264),
    [anon_sym_break] = ACTIONS(6264),
    [anon_sym_BREAK] = ACTIONS(6264),
    [anon_sym_Break] = ACTIONS(6264),
    [anon_sym_with] = ACTIONS(6264),
    [anon_sym_WITH] = ACTIONS(6264),
    [anon_sym_With] = ACTIONS(6264),
    [sym_asserterror_keyword] = ACTIONS(6268),
    [sym_page_keyword] = ACTIONS(6264),
    [anon_sym_codeunit] = ACTIONS(6264),
    [anon_sym_CODEUNIT] = ACTIONS(6264),
    [anon_sym_Codeunit] = ACTIONS(6264),
    [anon_sym_CodeUnit] = ACTIONS(6264),
    [anon_sym_COdeunit] = ACTIONS(6264),
    [anon_sym_codeUnit] = ACTIONS(6264),
    [sym_report_keyword] = ACTIONS(6264),
    [sym_query_keyword] = ACTIONS(6264),
    [anon_sym_xmlport] = ACTIONS(6264),
    [anon_sym_XMLPORT] = ACTIONS(6264),
    [anon_sym_Xmlport] = ACTIONS(6264),
    [anon_sym_XMLport] = ACTIONS(6264),
    [anon_sym_XMLPort] = ACTIONS(6264),
    [anon_sym_XmlPort] = ACTIONS(6264),
    [anon_sym_enum] = ACTIONS(6264),
    [anon_sym_ENUM] = ACTIONS(6264),
    [anon_sym_Enum] = ACTIONS(6264),
    [anon_sym_eNUM] = ACTIONS(6264),
    [anon_sym_eNum] = ACTIONS(6264),
    [anon_sym_ENum] = ACTIONS(6264),
    [sym_quoted_identifier] = ACTIONS(6268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6268),
    [sym_verbatim_string] = ACTIONS(6268),
    [sym_integer] = ACTIONS(6264),
    [sym_continue_as_identifier] = ACTIONS(6268),
    [sym_preproc_open] = ACTIONS(6268),
  },
  [STATE(2933)] = {
    [sym_identifier] = ACTIONS(6264),
    [anon_sym_SEMI] = ACTIONS(7193),
    [anon_sym_DASH] = ACTIONS(6268),
    [aux_sym_boolean_token1] = ACTIONS(6264),
    [aux_sym_boolean_token2] = ACTIONS(6264),
    [sym_decimal] = ACTIONS(6264),
    [anon_sym_LPAREN] = ACTIONS(6268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6264),
    [anon_sym_LBRACK] = ACTIONS(6268),
    [aux_sym_record_type_token1] = ACTIONS(6264),
    [aux_sym_basic_type_token21] = ACTIONS(6264),
    [aux_sym_basic_type_token22] = ACTIONS(6264),
    [aux_sym_basic_type_token48] = ACTIONS(6264),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6264),
    [anon_sym_POUNDif] = ACTIONS(6268),
    [anon_sym_POUNDIF] = ACTIONS(6268),
    [anon_sym_POUNDIf] = ACTIONS(6268),
    [anon_sym_not] = ACTIONS(6264),
    [anon_sym_NOT] = ACTIONS(6264),
    [anon_sym_Not] = ACTIONS(6264),
    [anon_sym_POUNDelse] = ACTIONS(6268),
    [anon_sym_POUNDELSE] = ACTIONS(6268),
    [anon_sym_POUNDElse] = ACTIONS(6268),
    [anon_sym_POUNDelse2] = ACTIONS(6268),
    [anon_sym_POUNDELSE2] = ACTIONS(6268),
    [anon_sym_POUNDElse2] = ACTIONS(6268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6264),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6268),
    [sym_datetime_literal] = ACTIONS(6268),
    [sym_date_literal] = ACTIONS(6264),
    [sym_time_literal] = ACTIONS(6264),
    [sym_biginteger_literal] = ACTIONS(6268),
    [anon_sym_if] = ACTIONS(6264),
    [anon_sym_IF] = ACTIONS(6264),
    [anon_sym_If] = ACTIONS(6264),
    [anon_sym_else] = ACTIONS(6264),
    [anon_sym_ELSE] = ACTIONS(6264),
    [anon_sym_Else] = ACTIONS(6264),
    [anon_sym_case] = ACTIONS(6264),
    [anon_sym_CASE] = ACTIONS(6264),
    [anon_sym_Case] = ACTIONS(6264),
    [anon_sym_for] = ACTIONS(6264),
    [anon_sym_FOR] = ACTIONS(6264),
    [anon_sym_For] = ACTIONS(6264),
    [anon_sym_foreach] = ACTIONS(6264),
    [anon_sym_FOREACH] = ACTIONS(6264),
    [anon_sym_Foreach] = ACTIONS(6264),
    [anon_sym_while] = ACTIONS(6264),
    [anon_sym_WHILE] = ACTIONS(6264),
    [anon_sym_While] = ACTIONS(6264),
    [anon_sym_repeat] = ACTIONS(6264),
    [anon_sym_REPEAT] = ACTIONS(6264),
    [anon_sym_Repeat] = ACTIONS(6264),
    [anon_sym_until] = ACTIONS(6264),
    [anon_sym_UNTIL] = ACTIONS(6264),
    [anon_sym_Until] = ACTIONS(6264),
    [anon_sym_exit] = ACTIONS(6264),
    [anon_sym_EXIT] = ACTIONS(6264),
    [anon_sym_Exit] = ACTIONS(6264),
    [anon_sym_continue] = ACTIONS(6264),
    [anon_sym_CONTINUE] = ACTIONS(6264),
    [anon_sym_Continue] = ACTIONS(6264),
    [anon_sym_break] = ACTIONS(6264),
    [anon_sym_BREAK] = ACTIONS(6264),
    [anon_sym_Break] = ACTIONS(6264),
    [anon_sym_with] = ACTIONS(6264),
    [anon_sym_WITH] = ACTIONS(6264),
    [anon_sym_With] = ACTIONS(6264),
    [sym_asserterror_keyword] = ACTIONS(6268),
    [sym_page_keyword] = ACTIONS(6264),
    [anon_sym_codeunit] = ACTIONS(6264),
    [anon_sym_CODEUNIT] = ACTIONS(6264),
    [anon_sym_Codeunit] = ACTIONS(6264),
    [anon_sym_CodeUnit] = ACTIONS(6264),
    [anon_sym_COdeunit] = ACTIONS(6264),
    [anon_sym_codeUnit] = ACTIONS(6264),
    [sym_report_keyword] = ACTIONS(6264),
    [sym_query_keyword] = ACTIONS(6264),
    [anon_sym_xmlport] = ACTIONS(6264),
    [anon_sym_XMLPORT] = ACTIONS(6264),
    [anon_sym_Xmlport] = ACTIONS(6264),
    [anon_sym_XMLport] = ACTIONS(6264),
    [anon_sym_XMLPort] = ACTIONS(6264),
    [anon_sym_XmlPort] = ACTIONS(6264),
    [anon_sym_enum] = ACTIONS(6264),
    [anon_sym_ENUM] = ACTIONS(6264),
    [anon_sym_Enum] = ACTIONS(6264),
    [anon_sym_eNUM] = ACTIONS(6264),
    [anon_sym_eNum] = ACTIONS(6264),
    [anon_sym_ENum] = ACTIONS(6264),
    [sym_quoted_identifier] = ACTIONS(6268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6268),
    [sym_verbatim_string] = ACTIONS(6268),
    [sym_integer] = ACTIONS(6264),
    [sym_continue_as_identifier] = ACTIONS(6268),
    [sym_preproc_open] = ACTIONS(6268),
  },
  [STATE(2934)] = {
    [sym_identifier] = ACTIONS(6272),
    [anon_sym_SEMI] = ACTIONS(6274),
    [anon_sym_DASH] = ACTIONS(6274),
    [aux_sym_boolean_token1] = ACTIONS(6272),
    [aux_sym_boolean_token2] = ACTIONS(6272),
    [sym_decimal] = ACTIONS(6272),
    [anon_sym_LPAREN] = ACTIONS(6274),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6272),
    [anon_sym_LBRACK] = ACTIONS(6274),
    [aux_sym_record_type_token1] = ACTIONS(6272),
    [aux_sym_basic_type_token21] = ACTIONS(6272),
    [aux_sym_basic_type_token22] = ACTIONS(6272),
    [aux_sym_basic_type_token48] = ACTIONS(6272),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6272),
    [anon_sym_POUNDif] = ACTIONS(6274),
    [anon_sym_POUNDIF] = ACTIONS(6274),
    [anon_sym_POUNDIf] = ACTIONS(6274),
    [anon_sym_not] = ACTIONS(6272),
    [anon_sym_NOT] = ACTIONS(6272),
    [anon_sym_Not] = ACTIONS(6272),
    [anon_sym_POUNDelse] = ACTIONS(6274),
    [anon_sym_POUNDELSE] = ACTIONS(6274),
    [anon_sym_POUNDElse] = ACTIONS(6274),
    [anon_sym_POUNDelse2] = ACTIONS(6274),
    [anon_sym_POUNDELSE2] = ACTIONS(6274),
    [anon_sym_POUNDElse2] = ACTIONS(6274),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6272),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6272),
    [anon_sym_PLUS] = ACTIONS(6274),
    [sym_datetime_literal] = ACTIONS(6274),
    [sym_date_literal] = ACTIONS(6272),
    [sym_time_literal] = ACTIONS(6272),
    [sym_biginteger_literal] = ACTIONS(6274),
    [anon_sym_if] = ACTIONS(6272),
    [anon_sym_IF] = ACTIONS(6272),
    [anon_sym_If] = ACTIONS(6272),
    [anon_sym_else] = ACTIONS(6272),
    [anon_sym_ELSE] = ACTIONS(6272),
    [anon_sym_Else] = ACTIONS(6272),
    [anon_sym_case] = ACTIONS(6272),
    [anon_sym_CASE] = ACTIONS(6272),
    [anon_sym_Case] = ACTIONS(6272),
    [anon_sym_for] = ACTIONS(6272),
    [anon_sym_FOR] = ACTIONS(6272),
    [anon_sym_For] = ACTIONS(6272),
    [anon_sym_foreach] = ACTIONS(6272),
    [anon_sym_FOREACH] = ACTIONS(6272),
    [anon_sym_Foreach] = ACTIONS(6272),
    [anon_sym_while] = ACTIONS(6272),
    [anon_sym_WHILE] = ACTIONS(6272),
    [anon_sym_While] = ACTIONS(6272),
    [anon_sym_repeat] = ACTIONS(6272),
    [anon_sym_REPEAT] = ACTIONS(6272),
    [anon_sym_Repeat] = ACTIONS(6272),
    [anon_sym_until] = ACTIONS(6272),
    [anon_sym_UNTIL] = ACTIONS(6272),
    [anon_sym_Until] = ACTIONS(6272),
    [anon_sym_exit] = ACTIONS(6272),
    [anon_sym_EXIT] = ACTIONS(6272),
    [anon_sym_Exit] = ACTIONS(6272),
    [anon_sym_continue] = ACTIONS(6272),
    [anon_sym_CONTINUE] = ACTIONS(6272),
    [anon_sym_Continue] = ACTIONS(6272),
    [anon_sym_break] = ACTIONS(6272),
    [anon_sym_BREAK] = ACTIONS(6272),
    [anon_sym_Break] = ACTIONS(6272),
    [anon_sym_with] = ACTIONS(6272),
    [anon_sym_WITH] = ACTIONS(6272),
    [anon_sym_With] = ACTIONS(6272),
    [sym_asserterror_keyword] = ACTIONS(6274),
    [sym_page_keyword] = ACTIONS(6272),
    [anon_sym_codeunit] = ACTIONS(6272),
    [anon_sym_CODEUNIT] = ACTIONS(6272),
    [anon_sym_Codeunit] = ACTIONS(6272),
    [anon_sym_CodeUnit] = ACTIONS(6272),
    [anon_sym_COdeunit] = ACTIONS(6272),
    [anon_sym_codeUnit] = ACTIONS(6272),
    [sym_report_keyword] = ACTIONS(6272),
    [sym_query_keyword] = ACTIONS(6272),
    [anon_sym_xmlport] = ACTIONS(6272),
    [anon_sym_XMLPORT] = ACTIONS(6272),
    [anon_sym_Xmlport] = ACTIONS(6272),
    [anon_sym_XMLport] = ACTIONS(6272),
    [anon_sym_XMLPort] = ACTIONS(6272),
    [anon_sym_XmlPort] = ACTIONS(6272),
    [anon_sym_enum] = ACTIONS(6272),
    [anon_sym_ENUM] = ACTIONS(6272),
    [anon_sym_Enum] = ACTIONS(6272),
    [anon_sym_eNUM] = ACTIONS(6272),
    [anon_sym_eNum] = ACTIONS(6272),
    [anon_sym_ENum] = ACTIONS(6272),
    [sym_quoted_identifier] = ACTIONS(6274),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6274),
    [sym_verbatim_string] = ACTIONS(6274),
    [sym_integer] = ACTIONS(6272),
    [sym_continue_as_identifier] = ACTIONS(6274),
    [sym_preproc_open] = ACTIONS(6274),
  },
  [STATE(2935)] = {
    [sym_identifier] = ACTIONS(6276),
    [anon_sym_SEMI] = ACTIONS(6278),
    [anon_sym_DASH] = ACTIONS(6278),
    [aux_sym_boolean_token1] = ACTIONS(6276),
    [aux_sym_boolean_token2] = ACTIONS(6276),
    [sym_decimal] = ACTIONS(6276),
    [anon_sym_LPAREN] = ACTIONS(6278),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6276),
    [anon_sym_LBRACK] = ACTIONS(6278),
    [aux_sym_record_type_token1] = ACTIONS(6276),
    [aux_sym_basic_type_token21] = ACTIONS(6276),
    [aux_sym_basic_type_token22] = ACTIONS(6276),
    [aux_sym_basic_type_token48] = ACTIONS(6276),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6276),
    [anon_sym_POUNDif] = ACTIONS(6278),
    [anon_sym_POUNDIF] = ACTIONS(6278),
    [anon_sym_POUNDIf] = ACTIONS(6278),
    [anon_sym_not] = ACTIONS(6276),
    [anon_sym_NOT] = ACTIONS(6276),
    [anon_sym_Not] = ACTIONS(6276),
    [anon_sym_POUNDelse] = ACTIONS(6278),
    [anon_sym_POUNDELSE] = ACTIONS(6278),
    [anon_sym_POUNDElse] = ACTIONS(6278),
    [anon_sym_POUNDelse2] = ACTIONS(6278),
    [anon_sym_POUNDELSE2] = ACTIONS(6278),
    [anon_sym_POUNDElse2] = ACTIONS(6278),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6276),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6276),
    [anon_sym_PLUS] = ACTIONS(6278),
    [sym_datetime_literal] = ACTIONS(6278),
    [sym_date_literal] = ACTIONS(6276),
    [sym_time_literal] = ACTIONS(6276),
    [sym_biginteger_literal] = ACTIONS(6278),
    [anon_sym_if] = ACTIONS(6276),
    [anon_sym_IF] = ACTIONS(6276),
    [anon_sym_If] = ACTIONS(6276),
    [anon_sym_else] = ACTIONS(6276),
    [anon_sym_ELSE] = ACTIONS(6276),
    [anon_sym_Else] = ACTIONS(6276),
    [anon_sym_case] = ACTIONS(6276),
    [anon_sym_CASE] = ACTIONS(6276),
    [anon_sym_Case] = ACTIONS(6276),
    [anon_sym_for] = ACTIONS(6276),
    [anon_sym_FOR] = ACTIONS(6276),
    [anon_sym_For] = ACTIONS(6276),
    [anon_sym_foreach] = ACTIONS(6276),
    [anon_sym_FOREACH] = ACTIONS(6276),
    [anon_sym_Foreach] = ACTIONS(6276),
    [anon_sym_while] = ACTIONS(6276),
    [anon_sym_WHILE] = ACTIONS(6276),
    [anon_sym_While] = ACTIONS(6276),
    [anon_sym_repeat] = ACTIONS(6276),
    [anon_sym_REPEAT] = ACTIONS(6276),
    [anon_sym_Repeat] = ACTIONS(6276),
    [anon_sym_until] = ACTIONS(6276),
    [anon_sym_UNTIL] = ACTIONS(6276),
    [anon_sym_Until] = ACTIONS(6276),
    [anon_sym_exit] = ACTIONS(6276),
    [anon_sym_EXIT] = ACTIONS(6276),
    [anon_sym_Exit] = ACTIONS(6276),
    [anon_sym_continue] = ACTIONS(6276),
    [anon_sym_CONTINUE] = ACTIONS(6276),
    [anon_sym_Continue] = ACTIONS(6276),
    [anon_sym_break] = ACTIONS(6276),
    [anon_sym_BREAK] = ACTIONS(6276),
    [anon_sym_Break] = ACTIONS(6276),
    [anon_sym_with] = ACTIONS(6276),
    [anon_sym_WITH] = ACTIONS(6276),
    [anon_sym_With] = ACTIONS(6276),
    [sym_asserterror_keyword] = ACTIONS(6278),
    [sym_page_keyword] = ACTIONS(6276),
    [anon_sym_codeunit] = ACTIONS(6276),
    [anon_sym_CODEUNIT] = ACTIONS(6276),
    [anon_sym_Codeunit] = ACTIONS(6276),
    [anon_sym_CodeUnit] = ACTIONS(6276),
    [anon_sym_COdeunit] = ACTIONS(6276),
    [anon_sym_codeUnit] = ACTIONS(6276),
    [sym_report_keyword] = ACTIONS(6276),
    [sym_query_keyword] = ACTIONS(6276),
    [anon_sym_xmlport] = ACTIONS(6276),
    [anon_sym_XMLPORT] = ACTIONS(6276),
    [anon_sym_Xmlport] = ACTIONS(6276),
    [anon_sym_XMLport] = ACTIONS(6276),
    [anon_sym_XMLPort] = ACTIONS(6276),
    [anon_sym_XmlPort] = ACTIONS(6276),
    [anon_sym_enum] = ACTIONS(6276),
    [anon_sym_ENUM] = ACTIONS(6276),
    [anon_sym_Enum] = ACTIONS(6276),
    [anon_sym_eNUM] = ACTIONS(6276),
    [anon_sym_eNum] = ACTIONS(6276),
    [anon_sym_ENum] = ACTIONS(6276),
    [sym_quoted_identifier] = ACTIONS(6278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6278),
    [sym_verbatim_string] = ACTIONS(6278),
    [sym_integer] = ACTIONS(6276),
    [sym_continue_as_identifier] = ACTIONS(6278),
    [sym_preproc_open] = ACTIONS(6278),
  },
  [STATE(2936)] = {
    [sym_identifier] = ACTIONS(6284),
    [anon_sym_SEMI] = ACTIONS(6286),
    [anon_sym_DASH] = ACTIONS(6286),
    [aux_sym_boolean_token1] = ACTIONS(6284),
    [aux_sym_boolean_token2] = ACTIONS(6284),
    [sym_decimal] = ACTIONS(6284),
    [anon_sym_LPAREN] = ACTIONS(6286),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6284),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [aux_sym_record_type_token1] = ACTIONS(6284),
    [aux_sym_basic_type_token21] = ACTIONS(6284),
    [aux_sym_basic_type_token22] = ACTIONS(6284),
    [aux_sym_basic_type_token48] = ACTIONS(6284),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6284),
    [anon_sym_POUNDif] = ACTIONS(6286),
    [anon_sym_POUNDIF] = ACTIONS(6286),
    [anon_sym_POUNDIf] = ACTIONS(6286),
    [anon_sym_not] = ACTIONS(6284),
    [anon_sym_NOT] = ACTIONS(6284),
    [anon_sym_Not] = ACTIONS(6284),
    [anon_sym_POUNDelse] = ACTIONS(6286),
    [anon_sym_POUNDELSE] = ACTIONS(6286),
    [anon_sym_POUNDElse] = ACTIONS(6286),
    [anon_sym_POUNDelse2] = ACTIONS(6286),
    [anon_sym_POUNDELSE2] = ACTIONS(6286),
    [anon_sym_POUNDElse2] = ACTIONS(6286),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6284),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6284),
    [anon_sym_PLUS] = ACTIONS(6286),
    [sym_datetime_literal] = ACTIONS(6286),
    [sym_date_literal] = ACTIONS(6284),
    [sym_time_literal] = ACTIONS(6284),
    [sym_biginteger_literal] = ACTIONS(6286),
    [anon_sym_if] = ACTIONS(6284),
    [anon_sym_IF] = ACTIONS(6284),
    [anon_sym_If] = ACTIONS(6284),
    [anon_sym_else] = ACTIONS(6284),
    [anon_sym_ELSE] = ACTIONS(6284),
    [anon_sym_Else] = ACTIONS(6284),
    [anon_sym_case] = ACTIONS(6284),
    [anon_sym_CASE] = ACTIONS(6284),
    [anon_sym_Case] = ACTIONS(6284),
    [anon_sym_for] = ACTIONS(6284),
    [anon_sym_FOR] = ACTIONS(6284),
    [anon_sym_For] = ACTIONS(6284),
    [anon_sym_foreach] = ACTIONS(6284),
    [anon_sym_FOREACH] = ACTIONS(6284),
    [anon_sym_Foreach] = ACTIONS(6284),
    [anon_sym_while] = ACTIONS(6284),
    [anon_sym_WHILE] = ACTIONS(6284),
    [anon_sym_While] = ACTIONS(6284),
    [anon_sym_repeat] = ACTIONS(6284),
    [anon_sym_REPEAT] = ACTIONS(6284),
    [anon_sym_Repeat] = ACTIONS(6284),
    [anon_sym_until] = ACTIONS(6284),
    [anon_sym_UNTIL] = ACTIONS(6284),
    [anon_sym_Until] = ACTIONS(6284),
    [anon_sym_exit] = ACTIONS(6284),
    [anon_sym_EXIT] = ACTIONS(6284),
    [anon_sym_Exit] = ACTIONS(6284),
    [anon_sym_continue] = ACTIONS(6284),
    [anon_sym_CONTINUE] = ACTIONS(6284),
    [anon_sym_Continue] = ACTIONS(6284),
    [anon_sym_break] = ACTIONS(6284),
    [anon_sym_BREAK] = ACTIONS(6284),
    [anon_sym_Break] = ACTIONS(6284),
    [anon_sym_with] = ACTIONS(6284),
    [anon_sym_WITH] = ACTIONS(6284),
    [anon_sym_With] = ACTIONS(6284),
    [sym_asserterror_keyword] = ACTIONS(6286),
    [sym_page_keyword] = ACTIONS(6284),
    [anon_sym_codeunit] = ACTIONS(6284),
    [anon_sym_CODEUNIT] = ACTIONS(6284),
    [anon_sym_Codeunit] = ACTIONS(6284),
    [anon_sym_CodeUnit] = ACTIONS(6284),
    [anon_sym_COdeunit] = ACTIONS(6284),
    [anon_sym_codeUnit] = ACTIONS(6284),
    [sym_report_keyword] = ACTIONS(6284),
    [sym_query_keyword] = ACTIONS(6284),
    [anon_sym_xmlport] = ACTIONS(6284),
    [anon_sym_XMLPORT] = ACTIONS(6284),
    [anon_sym_Xmlport] = ACTIONS(6284),
    [anon_sym_XMLport] = ACTIONS(6284),
    [anon_sym_XMLPort] = ACTIONS(6284),
    [anon_sym_XmlPort] = ACTIONS(6284),
    [anon_sym_enum] = ACTIONS(6284),
    [anon_sym_ENUM] = ACTIONS(6284),
    [anon_sym_Enum] = ACTIONS(6284),
    [anon_sym_eNUM] = ACTIONS(6284),
    [anon_sym_eNum] = ACTIONS(6284),
    [anon_sym_ENum] = ACTIONS(6284),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6286),
    [sym_verbatim_string] = ACTIONS(6286),
    [sym_integer] = ACTIONS(6284),
    [sym_continue_as_identifier] = ACTIONS(6286),
    [sym_preproc_open] = ACTIONS(6286),
  },
  [STATE(2937)] = {
    [sym_identifier] = ACTIONS(6288),
    [anon_sym_SEMI] = ACTIONS(6290),
    [anon_sym_DASH] = ACTIONS(6290),
    [aux_sym_boolean_token1] = ACTIONS(6288),
    [aux_sym_boolean_token2] = ACTIONS(6288),
    [sym_decimal] = ACTIONS(6288),
    [anon_sym_LPAREN] = ACTIONS(6290),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6288),
    [anon_sym_LBRACK] = ACTIONS(6290),
    [aux_sym_record_type_token1] = ACTIONS(6288),
    [aux_sym_basic_type_token21] = ACTIONS(6288),
    [aux_sym_basic_type_token22] = ACTIONS(6288),
    [aux_sym_basic_type_token48] = ACTIONS(6288),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6288),
    [anon_sym_POUNDif] = ACTIONS(6290),
    [anon_sym_POUNDIF] = ACTIONS(6290),
    [anon_sym_POUNDIf] = ACTIONS(6290),
    [anon_sym_not] = ACTIONS(6288),
    [anon_sym_NOT] = ACTIONS(6288),
    [anon_sym_Not] = ACTIONS(6288),
    [anon_sym_POUNDelse] = ACTIONS(6290),
    [anon_sym_POUNDELSE] = ACTIONS(6290),
    [anon_sym_POUNDElse] = ACTIONS(6290),
    [anon_sym_POUNDelse2] = ACTIONS(6290),
    [anon_sym_POUNDELSE2] = ACTIONS(6290),
    [anon_sym_POUNDElse2] = ACTIONS(6290),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6288),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6288),
    [anon_sym_PLUS] = ACTIONS(6290),
    [sym_datetime_literal] = ACTIONS(6290),
    [sym_date_literal] = ACTIONS(6288),
    [sym_time_literal] = ACTIONS(6288),
    [sym_biginteger_literal] = ACTIONS(6290),
    [anon_sym_if] = ACTIONS(6288),
    [anon_sym_IF] = ACTIONS(6288),
    [anon_sym_If] = ACTIONS(6288),
    [anon_sym_else] = ACTIONS(6288),
    [anon_sym_ELSE] = ACTIONS(6288),
    [anon_sym_Else] = ACTIONS(6288),
    [anon_sym_case] = ACTIONS(6288),
    [anon_sym_CASE] = ACTIONS(6288),
    [anon_sym_Case] = ACTIONS(6288),
    [anon_sym_for] = ACTIONS(6288),
    [anon_sym_FOR] = ACTIONS(6288),
    [anon_sym_For] = ACTIONS(6288),
    [anon_sym_foreach] = ACTIONS(6288),
    [anon_sym_FOREACH] = ACTIONS(6288),
    [anon_sym_Foreach] = ACTIONS(6288),
    [anon_sym_while] = ACTIONS(6288),
    [anon_sym_WHILE] = ACTIONS(6288),
    [anon_sym_While] = ACTIONS(6288),
    [anon_sym_repeat] = ACTIONS(6288),
    [anon_sym_REPEAT] = ACTIONS(6288),
    [anon_sym_Repeat] = ACTIONS(6288),
    [anon_sym_until] = ACTIONS(6288),
    [anon_sym_UNTIL] = ACTIONS(6288),
    [anon_sym_Until] = ACTIONS(6288),
    [anon_sym_exit] = ACTIONS(6288),
    [anon_sym_EXIT] = ACTIONS(6288),
    [anon_sym_Exit] = ACTIONS(6288),
    [anon_sym_continue] = ACTIONS(6288),
    [anon_sym_CONTINUE] = ACTIONS(6288),
    [anon_sym_Continue] = ACTIONS(6288),
    [anon_sym_break] = ACTIONS(6288),
    [anon_sym_BREAK] = ACTIONS(6288),
    [anon_sym_Break] = ACTIONS(6288),
    [anon_sym_with] = ACTIONS(6288),
    [anon_sym_WITH] = ACTIONS(6288),
    [anon_sym_With] = ACTIONS(6288),
    [sym_asserterror_keyword] = ACTIONS(6290),
    [sym_page_keyword] = ACTIONS(6288),
    [anon_sym_codeunit] = ACTIONS(6288),
    [anon_sym_CODEUNIT] = ACTIONS(6288),
    [anon_sym_Codeunit] = ACTIONS(6288),
    [anon_sym_CodeUnit] = ACTIONS(6288),
    [anon_sym_COdeunit] = ACTIONS(6288),
    [anon_sym_codeUnit] = ACTIONS(6288),
    [sym_report_keyword] = ACTIONS(6288),
    [sym_query_keyword] = ACTIONS(6288),
    [anon_sym_xmlport] = ACTIONS(6288),
    [anon_sym_XMLPORT] = ACTIONS(6288),
    [anon_sym_Xmlport] = ACTIONS(6288),
    [anon_sym_XMLport] = ACTIONS(6288),
    [anon_sym_XMLPort] = ACTIONS(6288),
    [anon_sym_XmlPort] = ACTIONS(6288),
    [anon_sym_enum] = ACTIONS(6288),
    [anon_sym_ENUM] = ACTIONS(6288),
    [anon_sym_Enum] = ACTIONS(6288),
    [anon_sym_eNUM] = ACTIONS(6288),
    [anon_sym_eNum] = ACTIONS(6288),
    [anon_sym_ENum] = ACTIONS(6288),
    [sym_quoted_identifier] = ACTIONS(6290),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6290),
    [sym_verbatim_string] = ACTIONS(6290),
    [sym_integer] = ACTIONS(6288),
    [sym_continue_as_identifier] = ACTIONS(6290),
    [sym_preproc_open] = ACTIONS(6290),
  },
  [STATE(2938)] = {
    [sym_identifier] = ACTIONS(6292),
    [anon_sym_SEMI] = ACTIONS(7195),
    [anon_sym_DASH] = ACTIONS(6296),
    [aux_sym_boolean_token1] = ACTIONS(6292),
    [aux_sym_boolean_token2] = ACTIONS(6292),
    [sym_decimal] = ACTIONS(6292),
    [anon_sym_LPAREN] = ACTIONS(6296),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6292),
    [anon_sym_LBRACK] = ACTIONS(6296),
    [aux_sym_record_type_token1] = ACTIONS(6292),
    [aux_sym_basic_type_token21] = ACTIONS(6292),
    [aux_sym_basic_type_token22] = ACTIONS(6292),
    [aux_sym_basic_type_token48] = ACTIONS(6292),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6292),
    [anon_sym_POUNDif] = ACTIONS(6296),
    [anon_sym_POUNDIF] = ACTIONS(6296),
    [anon_sym_POUNDIf] = ACTIONS(6296),
    [anon_sym_not] = ACTIONS(6292),
    [anon_sym_NOT] = ACTIONS(6292),
    [anon_sym_Not] = ACTIONS(6292),
    [anon_sym_POUNDelse] = ACTIONS(6296),
    [anon_sym_POUNDELSE] = ACTIONS(6296),
    [anon_sym_POUNDElse] = ACTIONS(6296),
    [anon_sym_POUNDelse2] = ACTIONS(6296),
    [anon_sym_POUNDELSE2] = ACTIONS(6296),
    [anon_sym_POUNDElse2] = ACTIONS(6296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6292),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6292),
    [anon_sym_PLUS] = ACTIONS(6296),
    [sym_datetime_literal] = ACTIONS(6296),
    [sym_date_literal] = ACTIONS(6292),
    [sym_time_literal] = ACTIONS(6292),
    [sym_biginteger_literal] = ACTIONS(6296),
    [anon_sym_if] = ACTIONS(6292),
    [anon_sym_IF] = ACTIONS(6292),
    [anon_sym_If] = ACTIONS(6292),
    [anon_sym_else] = ACTIONS(6292),
    [anon_sym_ELSE] = ACTIONS(6292),
    [anon_sym_Else] = ACTIONS(6292),
    [anon_sym_case] = ACTIONS(6292),
    [anon_sym_CASE] = ACTIONS(6292),
    [anon_sym_Case] = ACTIONS(6292),
    [anon_sym_for] = ACTIONS(6292),
    [anon_sym_FOR] = ACTIONS(6292),
    [anon_sym_For] = ACTIONS(6292),
    [anon_sym_foreach] = ACTIONS(6292),
    [anon_sym_FOREACH] = ACTIONS(6292),
    [anon_sym_Foreach] = ACTIONS(6292),
    [anon_sym_while] = ACTIONS(6292),
    [anon_sym_WHILE] = ACTIONS(6292),
    [anon_sym_While] = ACTIONS(6292),
    [anon_sym_repeat] = ACTIONS(6292),
    [anon_sym_REPEAT] = ACTIONS(6292),
    [anon_sym_Repeat] = ACTIONS(6292),
    [anon_sym_until] = ACTIONS(6292),
    [anon_sym_UNTIL] = ACTIONS(6292),
    [anon_sym_Until] = ACTIONS(6292),
    [anon_sym_exit] = ACTIONS(6292),
    [anon_sym_EXIT] = ACTIONS(6292),
    [anon_sym_Exit] = ACTIONS(6292),
    [anon_sym_continue] = ACTIONS(6292),
    [anon_sym_CONTINUE] = ACTIONS(6292),
    [anon_sym_Continue] = ACTIONS(6292),
    [anon_sym_break] = ACTIONS(6292),
    [anon_sym_BREAK] = ACTIONS(6292),
    [anon_sym_Break] = ACTIONS(6292),
    [anon_sym_with] = ACTIONS(6292),
    [anon_sym_WITH] = ACTIONS(6292),
    [anon_sym_With] = ACTIONS(6292),
    [sym_asserterror_keyword] = ACTIONS(6296),
    [sym_page_keyword] = ACTIONS(6292),
    [anon_sym_codeunit] = ACTIONS(6292),
    [anon_sym_CODEUNIT] = ACTIONS(6292),
    [anon_sym_Codeunit] = ACTIONS(6292),
    [anon_sym_CodeUnit] = ACTIONS(6292),
    [anon_sym_COdeunit] = ACTIONS(6292),
    [anon_sym_codeUnit] = ACTIONS(6292),
    [sym_report_keyword] = ACTIONS(6292),
    [sym_query_keyword] = ACTIONS(6292),
    [anon_sym_xmlport] = ACTIONS(6292),
    [anon_sym_XMLPORT] = ACTIONS(6292),
    [anon_sym_Xmlport] = ACTIONS(6292),
    [anon_sym_XMLport] = ACTIONS(6292),
    [anon_sym_XMLPort] = ACTIONS(6292),
    [anon_sym_XmlPort] = ACTIONS(6292),
    [anon_sym_enum] = ACTIONS(6292),
    [anon_sym_ENUM] = ACTIONS(6292),
    [anon_sym_Enum] = ACTIONS(6292),
    [anon_sym_eNUM] = ACTIONS(6292),
    [anon_sym_eNum] = ACTIONS(6292),
    [anon_sym_ENum] = ACTIONS(6292),
    [sym_quoted_identifier] = ACTIONS(6296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6296),
    [sym_verbatim_string] = ACTIONS(6296),
    [sym_integer] = ACTIONS(6292),
    [sym_continue_as_identifier] = ACTIONS(6296),
    [sym_preproc_open] = ACTIONS(6296),
  },
  [STATE(2939)] = {
    [sym_identifier] = ACTIONS(6292),
    [anon_sym_SEMI] = ACTIONS(7197),
    [anon_sym_DASH] = ACTIONS(6296),
    [aux_sym_boolean_token1] = ACTIONS(6292),
    [aux_sym_boolean_token2] = ACTIONS(6292),
    [sym_decimal] = ACTIONS(6292),
    [anon_sym_LPAREN] = ACTIONS(6296),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6292),
    [anon_sym_LBRACK] = ACTIONS(6296),
    [aux_sym_record_type_token1] = ACTIONS(6292),
    [aux_sym_basic_type_token21] = ACTIONS(6292),
    [aux_sym_basic_type_token22] = ACTIONS(6292),
    [aux_sym_basic_type_token48] = ACTIONS(6292),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6292),
    [anon_sym_POUNDif] = ACTIONS(6296),
    [anon_sym_POUNDIF] = ACTIONS(6296),
    [anon_sym_POUNDIf] = ACTIONS(6296),
    [anon_sym_not] = ACTIONS(6292),
    [anon_sym_NOT] = ACTIONS(6292),
    [anon_sym_Not] = ACTIONS(6292),
    [anon_sym_POUNDelse] = ACTIONS(6296),
    [anon_sym_POUNDELSE] = ACTIONS(6296),
    [anon_sym_POUNDElse] = ACTIONS(6296),
    [anon_sym_POUNDelse2] = ACTIONS(6296),
    [anon_sym_POUNDELSE2] = ACTIONS(6296),
    [anon_sym_POUNDElse2] = ACTIONS(6296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6292),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6292),
    [anon_sym_PLUS] = ACTIONS(6296),
    [sym_datetime_literal] = ACTIONS(6296),
    [sym_date_literal] = ACTIONS(6292),
    [sym_time_literal] = ACTIONS(6292),
    [sym_biginteger_literal] = ACTIONS(6296),
    [anon_sym_if] = ACTIONS(6292),
    [anon_sym_IF] = ACTIONS(6292),
    [anon_sym_If] = ACTIONS(6292),
    [anon_sym_else] = ACTIONS(6292),
    [anon_sym_ELSE] = ACTIONS(6292),
    [anon_sym_Else] = ACTIONS(6292),
    [anon_sym_case] = ACTIONS(6292),
    [anon_sym_CASE] = ACTIONS(6292),
    [anon_sym_Case] = ACTIONS(6292),
    [anon_sym_for] = ACTIONS(6292),
    [anon_sym_FOR] = ACTIONS(6292),
    [anon_sym_For] = ACTIONS(6292),
    [anon_sym_foreach] = ACTIONS(6292),
    [anon_sym_FOREACH] = ACTIONS(6292),
    [anon_sym_Foreach] = ACTIONS(6292),
    [anon_sym_while] = ACTIONS(6292),
    [anon_sym_WHILE] = ACTIONS(6292),
    [anon_sym_While] = ACTIONS(6292),
    [anon_sym_repeat] = ACTIONS(6292),
    [anon_sym_REPEAT] = ACTIONS(6292),
    [anon_sym_Repeat] = ACTIONS(6292),
    [anon_sym_until] = ACTIONS(6292),
    [anon_sym_UNTIL] = ACTIONS(6292),
    [anon_sym_Until] = ACTIONS(6292),
    [anon_sym_exit] = ACTIONS(6292),
    [anon_sym_EXIT] = ACTIONS(6292),
    [anon_sym_Exit] = ACTIONS(6292),
    [anon_sym_continue] = ACTIONS(6292),
    [anon_sym_CONTINUE] = ACTIONS(6292),
    [anon_sym_Continue] = ACTIONS(6292),
    [anon_sym_break] = ACTIONS(6292),
    [anon_sym_BREAK] = ACTIONS(6292),
    [anon_sym_Break] = ACTIONS(6292),
    [anon_sym_with] = ACTIONS(6292),
    [anon_sym_WITH] = ACTIONS(6292),
    [anon_sym_With] = ACTIONS(6292),
    [sym_asserterror_keyword] = ACTIONS(6296),
    [sym_page_keyword] = ACTIONS(6292),
    [anon_sym_codeunit] = ACTIONS(6292),
    [anon_sym_CODEUNIT] = ACTIONS(6292),
    [anon_sym_Codeunit] = ACTIONS(6292),
    [anon_sym_CodeUnit] = ACTIONS(6292),
    [anon_sym_COdeunit] = ACTIONS(6292),
    [anon_sym_codeUnit] = ACTIONS(6292),
    [sym_report_keyword] = ACTIONS(6292),
    [sym_query_keyword] = ACTIONS(6292),
    [anon_sym_xmlport] = ACTIONS(6292),
    [anon_sym_XMLPORT] = ACTIONS(6292),
    [anon_sym_Xmlport] = ACTIONS(6292),
    [anon_sym_XMLport] = ACTIONS(6292),
    [anon_sym_XMLPort] = ACTIONS(6292),
    [anon_sym_XmlPort] = ACTIONS(6292),
    [anon_sym_enum] = ACTIONS(6292),
    [anon_sym_ENUM] = ACTIONS(6292),
    [anon_sym_Enum] = ACTIONS(6292),
    [anon_sym_eNUM] = ACTIONS(6292),
    [anon_sym_eNum] = ACTIONS(6292),
    [anon_sym_ENum] = ACTIONS(6292),
    [sym_quoted_identifier] = ACTIONS(6296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6296),
    [sym_verbatim_string] = ACTIONS(6296),
    [sym_integer] = ACTIONS(6292),
    [sym_continue_as_identifier] = ACTIONS(6296),
    [sym_preproc_open] = ACTIONS(6296),
  },
  [STATE(2940)] = {
    [sym_identifier] = ACTIONS(6300),
    [anon_sym_SEMI] = ACTIONS(6302),
    [anon_sym_DASH] = ACTIONS(6302),
    [aux_sym_boolean_token1] = ACTIONS(6300),
    [aux_sym_boolean_token2] = ACTIONS(6300),
    [sym_decimal] = ACTIONS(6300),
    [anon_sym_LPAREN] = ACTIONS(6302),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6300),
    [anon_sym_LBRACK] = ACTIONS(6302),
    [aux_sym_record_type_token1] = ACTIONS(6300),
    [aux_sym_basic_type_token21] = ACTIONS(6300),
    [aux_sym_basic_type_token22] = ACTIONS(6300),
    [aux_sym_basic_type_token48] = ACTIONS(6300),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6300),
    [anon_sym_POUNDif] = ACTIONS(6302),
    [anon_sym_POUNDIF] = ACTIONS(6302),
    [anon_sym_POUNDIf] = ACTIONS(6302),
    [anon_sym_not] = ACTIONS(6300),
    [anon_sym_NOT] = ACTIONS(6300),
    [anon_sym_Not] = ACTIONS(6300),
    [anon_sym_POUNDelse] = ACTIONS(6302),
    [anon_sym_POUNDELSE] = ACTIONS(6302),
    [anon_sym_POUNDElse] = ACTIONS(6302),
    [anon_sym_POUNDelse2] = ACTIONS(6302),
    [anon_sym_POUNDELSE2] = ACTIONS(6302),
    [anon_sym_POUNDElse2] = ACTIONS(6302),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6300),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6300),
    [anon_sym_PLUS] = ACTIONS(6302),
    [sym_datetime_literal] = ACTIONS(6302),
    [sym_date_literal] = ACTIONS(6300),
    [sym_time_literal] = ACTIONS(6300),
    [sym_biginteger_literal] = ACTIONS(6302),
    [anon_sym_if] = ACTIONS(6300),
    [anon_sym_IF] = ACTIONS(6300),
    [anon_sym_If] = ACTIONS(6300),
    [anon_sym_else] = ACTIONS(6300),
    [anon_sym_ELSE] = ACTIONS(6300),
    [anon_sym_Else] = ACTIONS(6300),
    [anon_sym_case] = ACTIONS(6300),
    [anon_sym_CASE] = ACTIONS(6300),
    [anon_sym_Case] = ACTIONS(6300),
    [anon_sym_for] = ACTIONS(6300),
    [anon_sym_FOR] = ACTIONS(6300),
    [anon_sym_For] = ACTIONS(6300),
    [anon_sym_foreach] = ACTIONS(6300),
    [anon_sym_FOREACH] = ACTIONS(6300),
    [anon_sym_Foreach] = ACTIONS(6300),
    [anon_sym_while] = ACTIONS(6300),
    [anon_sym_WHILE] = ACTIONS(6300),
    [anon_sym_While] = ACTIONS(6300),
    [anon_sym_repeat] = ACTIONS(6300),
    [anon_sym_REPEAT] = ACTIONS(6300),
    [anon_sym_Repeat] = ACTIONS(6300),
    [anon_sym_until] = ACTIONS(6300),
    [anon_sym_UNTIL] = ACTIONS(6300),
    [anon_sym_Until] = ACTIONS(6300),
    [anon_sym_exit] = ACTIONS(6300),
    [anon_sym_EXIT] = ACTIONS(6300),
    [anon_sym_Exit] = ACTIONS(6300),
    [anon_sym_continue] = ACTIONS(6300),
    [anon_sym_CONTINUE] = ACTIONS(6300),
    [anon_sym_Continue] = ACTIONS(6300),
    [anon_sym_break] = ACTIONS(6300),
    [anon_sym_BREAK] = ACTIONS(6300),
    [anon_sym_Break] = ACTIONS(6300),
    [anon_sym_with] = ACTIONS(6300),
    [anon_sym_WITH] = ACTIONS(6300),
    [anon_sym_With] = ACTIONS(6300),
    [sym_asserterror_keyword] = ACTIONS(6302),
    [sym_page_keyword] = ACTIONS(6300),
    [anon_sym_codeunit] = ACTIONS(6300),
    [anon_sym_CODEUNIT] = ACTIONS(6300),
    [anon_sym_Codeunit] = ACTIONS(6300),
    [anon_sym_CodeUnit] = ACTIONS(6300),
    [anon_sym_COdeunit] = ACTIONS(6300),
    [anon_sym_codeUnit] = ACTIONS(6300),
    [sym_report_keyword] = ACTIONS(6300),
    [sym_query_keyword] = ACTIONS(6300),
    [anon_sym_xmlport] = ACTIONS(6300),
    [anon_sym_XMLPORT] = ACTIONS(6300),
    [anon_sym_Xmlport] = ACTIONS(6300),
    [anon_sym_XMLport] = ACTIONS(6300),
    [anon_sym_XMLPort] = ACTIONS(6300),
    [anon_sym_XmlPort] = ACTIONS(6300),
    [anon_sym_enum] = ACTIONS(6300),
    [anon_sym_ENUM] = ACTIONS(6300),
    [anon_sym_Enum] = ACTIONS(6300),
    [anon_sym_eNUM] = ACTIONS(6300),
    [anon_sym_eNum] = ACTIONS(6300),
    [anon_sym_ENum] = ACTIONS(6300),
    [sym_quoted_identifier] = ACTIONS(6302),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6302),
    [sym_verbatim_string] = ACTIONS(6302),
    [sym_integer] = ACTIONS(6300),
    [sym_continue_as_identifier] = ACTIONS(6302),
    [sym_preproc_open] = ACTIONS(6302),
  },
  [STATE(2941)] = {
    [sym_identifier] = ACTIONS(6304),
    [anon_sym_SEMI] = ACTIONS(6306),
    [anon_sym_DASH] = ACTIONS(6306),
    [aux_sym_boolean_token1] = ACTIONS(6304),
    [aux_sym_boolean_token2] = ACTIONS(6304),
    [sym_decimal] = ACTIONS(6304),
    [anon_sym_LPAREN] = ACTIONS(6306),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6304),
    [anon_sym_LBRACK] = ACTIONS(6306),
    [aux_sym_record_type_token1] = ACTIONS(6304),
    [aux_sym_basic_type_token21] = ACTIONS(6304),
    [aux_sym_basic_type_token22] = ACTIONS(6304),
    [aux_sym_basic_type_token48] = ACTIONS(6304),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6304),
    [anon_sym_POUNDif] = ACTIONS(6306),
    [anon_sym_POUNDIF] = ACTIONS(6306),
    [anon_sym_POUNDIf] = ACTIONS(6306),
    [anon_sym_not] = ACTIONS(6304),
    [anon_sym_NOT] = ACTIONS(6304),
    [anon_sym_Not] = ACTIONS(6304),
    [anon_sym_POUNDelse] = ACTIONS(6306),
    [anon_sym_POUNDELSE] = ACTIONS(6306),
    [anon_sym_POUNDElse] = ACTIONS(6306),
    [anon_sym_POUNDelse2] = ACTIONS(6306),
    [anon_sym_POUNDELSE2] = ACTIONS(6306),
    [anon_sym_POUNDElse2] = ACTIONS(6306),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6304),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6304),
    [anon_sym_PLUS] = ACTIONS(6306),
    [sym_datetime_literal] = ACTIONS(6306),
    [sym_date_literal] = ACTIONS(6304),
    [sym_time_literal] = ACTIONS(6304),
    [sym_biginteger_literal] = ACTIONS(6306),
    [anon_sym_if] = ACTIONS(6304),
    [anon_sym_IF] = ACTIONS(6304),
    [anon_sym_If] = ACTIONS(6304),
    [anon_sym_else] = ACTIONS(6304),
    [anon_sym_ELSE] = ACTIONS(6304),
    [anon_sym_Else] = ACTIONS(6304),
    [anon_sym_case] = ACTIONS(6304),
    [anon_sym_CASE] = ACTIONS(6304),
    [anon_sym_Case] = ACTIONS(6304),
    [anon_sym_for] = ACTIONS(6304),
    [anon_sym_FOR] = ACTIONS(6304),
    [anon_sym_For] = ACTIONS(6304),
    [anon_sym_foreach] = ACTIONS(6304),
    [anon_sym_FOREACH] = ACTIONS(6304),
    [anon_sym_Foreach] = ACTIONS(6304),
    [anon_sym_while] = ACTIONS(6304),
    [anon_sym_WHILE] = ACTIONS(6304),
    [anon_sym_While] = ACTIONS(6304),
    [anon_sym_repeat] = ACTIONS(6304),
    [anon_sym_REPEAT] = ACTIONS(6304),
    [anon_sym_Repeat] = ACTIONS(6304),
    [anon_sym_until] = ACTIONS(6304),
    [anon_sym_UNTIL] = ACTIONS(6304),
    [anon_sym_Until] = ACTIONS(6304),
    [anon_sym_exit] = ACTIONS(6304),
    [anon_sym_EXIT] = ACTIONS(6304),
    [anon_sym_Exit] = ACTIONS(6304),
    [anon_sym_continue] = ACTIONS(6304),
    [anon_sym_CONTINUE] = ACTIONS(6304),
    [anon_sym_Continue] = ACTIONS(6304),
    [anon_sym_break] = ACTIONS(6304),
    [anon_sym_BREAK] = ACTIONS(6304),
    [anon_sym_Break] = ACTIONS(6304),
    [anon_sym_with] = ACTIONS(6304),
    [anon_sym_WITH] = ACTIONS(6304),
    [anon_sym_With] = ACTIONS(6304),
    [sym_asserterror_keyword] = ACTIONS(6306),
    [sym_page_keyword] = ACTIONS(6304),
    [anon_sym_codeunit] = ACTIONS(6304),
    [anon_sym_CODEUNIT] = ACTIONS(6304),
    [anon_sym_Codeunit] = ACTIONS(6304),
    [anon_sym_CodeUnit] = ACTIONS(6304),
    [anon_sym_COdeunit] = ACTIONS(6304),
    [anon_sym_codeUnit] = ACTIONS(6304),
    [sym_report_keyword] = ACTIONS(6304),
    [sym_query_keyword] = ACTIONS(6304),
    [anon_sym_xmlport] = ACTIONS(6304),
    [anon_sym_XMLPORT] = ACTIONS(6304),
    [anon_sym_Xmlport] = ACTIONS(6304),
    [anon_sym_XMLport] = ACTIONS(6304),
    [anon_sym_XMLPort] = ACTIONS(6304),
    [anon_sym_XmlPort] = ACTIONS(6304),
    [anon_sym_enum] = ACTIONS(6304),
    [anon_sym_ENUM] = ACTIONS(6304),
    [anon_sym_Enum] = ACTIONS(6304),
    [anon_sym_eNUM] = ACTIONS(6304),
    [anon_sym_eNum] = ACTIONS(6304),
    [anon_sym_ENum] = ACTIONS(6304),
    [sym_quoted_identifier] = ACTIONS(6306),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6306),
    [sym_verbatim_string] = ACTIONS(6306),
    [sym_integer] = ACTIONS(6304),
    [sym_continue_as_identifier] = ACTIONS(6306),
    [sym_preproc_open] = ACTIONS(6306),
  },
  [STATE(2942)] = {
    [sym_identifier] = ACTIONS(6300),
    [anon_sym_SEMI] = ACTIONS(6302),
    [anon_sym_DASH] = ACTIONS(6302),
    [aux_sym_boolean_token1] = ACTIONS(6300),
    [aux_sym_boolean_token2] = ACTIONS(6300),
    [sym_decimal] = ACTIONS(6300),
    [anon_sym_LPAREN] = ACTIONS(6302),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6300),
    [anon_sym_LBRACK] = ACTIONS(6302),
    [aux_sym_record_type_token1] = ACTIONS(6300),
    [aux_sym_basic_type_token21] = ACTIONS(6300),
    [aux_sym_basic_type_token22] = ACTIONS(6300),
    [aux_sym_basic_type_token48] = ACTIONS(6300),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6300),
    [anon_sym_POUNDif] = ACTIONS(6302),
    [anon_sym_POUNDIF] = ACTIONS(6302),
    [anon_sym_POUNDIf] = ACTIONS(6302),
    [anon_sym_not] = ACTIONS(6300),
    [anon_sym_NOT] = ACTIONS(6300),
    [anon_sym_Not] = ACTIONS(6300),
    [anon_sym_POUNDelse] = ACTIONS(6302),
    [anon_sym_POUNDELSE] = ACTIONS(6302),
    [anon_sym_POUNDElse] = ACTIONS(6302),
    [anon_sym_POUNDelse2] = ACTIONS(6302),
    [anon_sym_POUNDELSE2] = ACTIONS(6302),
    [anon_sym_POUNDElse2] = ACTIONS(6302),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6300),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6300),
    [anon_sym_PLUS] = ACTIONS(6302),
    [sym_datetime_literal] = ACTIONS(6302),
    [sym_date_literal] = ACTIONS(6300),
    [sym_time_literal] = ACTIONS(6300),
    [sym_biginteger_literal] = ACTIONS(6302),
    [anon_sym_if] = ACTIONS(6300),
    [anon_sym_IF] = ACTIONS(6300),
    [anon_sym_If] = ACTIONS(6300),
    [anon_sym_else] = ACTIONS(6300),
    [anon_sym_ELSE] = ACTIONS(6300),
    [anon_sym_Else] = ACTIONS(6300),
    [anon_sym_case] = ACTIONS(6300),
    [anon_sym_CASE] = ACTIONS(6300),
    [anon_sym_Case] = ACTIONS(6300),
    [anon_sym_for] = ACTIONS(6300),
    [anon_sym_FOR] = ACTIONS(6300),
    [anon_sym_For] = ACTIONS(6300),
    [anon_sym_foreach] = ACTIONS(6300),
    [anon_sym_FOREACH] = ACTIONS(6300),
    [anon_sym_Foreach] = ACTIONS(6300),
    [anon_sym_while] = ACTIONS(6300),
    [anon_sym_WHILE] = ACTIONS(6300),
    [anon_sym_While] = ACTIONS(6300),
    [anon_sym_repeat] = ACTIONS(6300),
    [anon_sym_REPEAT] = ACTIONS(6300),
    [anon_sym_Repeat] = ACTIONS(6300),
    [anon_sym_until] = ACTIONS(6300),
    [anon_sym_UNTIL] = ACTIONS(6300),
    [anon_sym_Until] = ACTIONS(6300),
    [anon_sym_exit] = ACTIONS(6300),
    [anon_sym_EXIT] = ACTIONS(6300),
    [anon_sym_Exit] = ACTIONS(6300),
    [anon_sym_continue] = ACTIONS(6300),
    [anon_sym_CONTINUE] = ACTIONS(6300),
    [anon_sym_Continue] = ACTIONS(6300),
    [anon_sym_break] = ACTIONS(6300),
    [anon_sym_BREAK] = ACTIONS(6300),
    [anon_sym_Break] = ACTIONS(6300),
    [anon_sym_with] = ACTIONS(6300),
    [anon_sym_WITH] = ACTIONS(6300),
    [anon_sym_With] = ACTIONS(6300),
    [sym_asserterror_keyword] = ACTIONS(6302),
    [sym_page_keyword] = ACTIONS(6300),
    [anon_sym_codeunit] = ACTIONS(6300),
    [anon_sym_CODEUNIT] = ACTIONS(6300),
    [anon_sym_Codeunit] = ACTIONS(6300),
    [anon_sym_CodeUnit] = ACTIONS(6300),
    [anon_sym_COdeunit] = ACTIONS(6300),
    [anon_sym_codeUnit] = ACTIONS(6300),
    [sym_report_keyword] = ACTIONS(6300),
    [sym_query_keyword] = ACTIONS(6300),
    [anon_sym_xmlport] = ACTIONS(6300),
    [anon_sym_XMLPORT] = ACTIONS(6300),
    [anon_sym_Xmlport] = ACTIONS(6300),
    [anon_sym_XMLport] = ACTIONS(6300),
    [anon_sym_XMLPort] = ACTIONS(6300),
    [anon_sym_XmlPort] = ACTIONS(6300),
    [anon_sym_enum] = ACTIONS(6300),
    [anon_sym_ENUM] = ACTIONS(6300),
    [anon_sym_Enum] = ACTIONS(6300),
    [anon_sym_eNUM] = ACTIONS(6300),
    [anon_sym_eNum] = ACTIONS(6300),
    [anon_sym_ENum] = ACTIONS(6300),
    [sym_quoted_identifier] = ACTIONS(6302),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6302),
    [sym_verbatim_string] = ACTIONS(6302),
    [sym_integer] = ACTIONS(6300),
    [sym_continue_as_identifier] = ACTIONS(6302),
    [sym_preproc_open] = ACTIONS(6302),
  },
  [STATE(2943)] = {
    [sym_identifier] = ACTIONS(6304),
    [anon_sym_SEMI] = ACTIONS(6306),
    [anon_sym_DASH] = ACTIONS(6306),
    [aux_sym_boolean_token1] = ACTIONS(6304),
    [aux_sym_boolean_token2] = ACTIONS(6304),
    [sym_decimal] = ACTIONS(6304),
    [anon_sym_LPAREN] = ACTIONS(6306),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6304),
    [anon_sym_LBRACK] = ACTIONS(6306),
    [aux_sym_record_type_token1] = ACTIONS(6304),
    [aux_sym_basic_type_token21] = ACTIONS(6304),
    [aux_sym_basic_type_token22] = ACTIONS(6304),
    [aux_sym_basic_type_token48] = ACTIONS(6304),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6304),
    [anon_sym_POUNDif] = ACTIONS(6306),
    [anon_sym_POUNDIF] = ACTIONS(6306),
    [anon_sym_POUNDIf] = ACTIONS(6306),
    [anon_sym_not] = ACTIONS(6304),
    [anon_sym_NOT] = ACTIONS(6304),
    [anon_sym_Not] = ACTIONS(6304),
    [anon_sym_POUNDelse] = ACTIONS(6306),
    [anon_sym_POUNDELSE] = ACTIONS(6306),
    [anon_sym_POUNDElse] = ACTIONS(6306),
    [anon_sym_POUNDelse2] = ACTIONS(6306),
    [anon_sym_POUNDELSE2] = ACTIONS(6306),
    [anon_sym_POUNDElse2] = ACTIONS(6306),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6304),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6304),
    [anon_sym_PLUS] = ACTIONS(6306),
    [sym_datetime_literal] = ACTIONS(6306),
    [sym_date_literal] = ACTIONS(6304),
    [sym_time_literal] = ACTIONS(6304),
    [sym_biginteger_literal] = ACTIONS(6306),
    [anon_sym_if] = ACTIONS(6304),
    [anon_sym_IF] = ACTIONS(6304),
    [anon_sym_If] = ACTIONS(6304),
    [anon_sym_else] = ACTIONS(6304),
    [anon_sym_ELSE] = ACTIONS(6304),
    [anon_sym_Else] = ACTIONS(6304),
    [anon_sym_case] = ACTIONS(6304),
    [anon_sym_CASE] = ACTIONS(6304),
    [anon_sym_Case] = ACTIONS(6304),
    [anon_sym_for] = ACTIONS(6304),
    [anon_sym_FOR] = ACTIONS(6304),
    [anon_sym_For] = ACTIONS(6304),
    [anon_sym_foreach] = ACTIONS(6304),
    [anon_sym_FOREACH] = ACTIONS(6304),
    [anon_sym_Foreach] = ACTIONS(6304),
    [anon_sym_while] = ACTIONS(6304),
    [anon_sym_WHILE] = ACTIONS(6304),
    [anon_sym_While] = ACTIONS(6304),
    [anon_sym_repeat] = ACTIONS(6304),
    [anon_sym_REPEAT] = ACTIONS(6304),
    [anon_sym_Repeat] = ACTIONS(6304),
    [anon_sym_until] = ACTIONS(6304),
    [anon_sym_UNTIL] = ACTIONS(6304),
    [anon_sym_Until] = ACTIONS(6304),
    [anon_sym_exit] = ACTIONS(6304),
    [anon_sym_EXIT] = ACTIONS(6304),
    [anon_sym_Exit] = ACTIONS(6304),
    [anon_sym_continue] = ACTIONS(6304),
    [anon_sym_CONTINUE] = ACTIONS(6304),
    [anon_sym_Continue] = ACTIONS(6304),
    [anon_sym_break] = ACTIONS(6304),
    [anon_sym_BREAK] = ACTIONS(6304),
    [anon_sym_Break] = ACTIONS(6304),
    [anon_sym_with] = ACTIONS(6304),
    [anon_sym_WITH] = ACTIONS(6304),
    [anon_sym_With] = ACTIONS(6304),
    [sym_asserterror_keyword] = ACTIONS(6306),
    [sym_page_keyword] = ACTIONS(6304),
    [anon_sym_codeunit] = ACTIONS(6304),
    [anon_sym_CODEUNIT] = ACTIONS(6304),
    [anon_sym_Codeunit] = ACTIONS(6304),
    [anon_sym_CodeUnit] = ACTIONS(6304),
    [anon_sym_COdeunit] = ACTIONS(6304),
    [anon_sym_codeUnit] = ACTIONS(6304),
    [sym_report_keyword] = ACTIONS(6304),
    [sym_query_keyword] = ACTIONS(6304),
    [anon_sym_xmlport] = ACTIONS(6304),
    [anon_sym_XMLPORT] = ACTIONS(6304),
    [anon_sym_Xmlport] = ACTIONS(6304),
    [anon_sym_XMLport] = ACTIONS(6304),
    [anon_sym_XMLPort] = ACTIONS(6304),
    [anon_sym_XmlPort] = ACTIONS(6304),
    [anon_sym_enum] = ACTIONS(6304),
    [anon_sym_ENUM] = ACTIONS(6304),
    [anon_sym_Enum] = ACTIONS(6304),
    [anon_sym_eNUM] = ACTIONS(6304),
    [anon_sym_eNum] = ACTIONS(6304),
    [anon_sym_ENum] = ACTIONS(6304),
    [sym_quoted_identifier] = ACTIONS(6306),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6306),
    [sym_verbatim_string] = ACTIONS(6306),
    [sym_integer] = ACTIONS(6304),
    [sym_continue_as_identifier] = ACTIONS(6306),
    [sym_preproc_open] = ACTIONS(6306),
  },
  [STATE(2944)] = {
    [sym_identifier] = ACTIONS(6308),
    [anon_sym_SEMI] = ACTIONS(6310),
    [anon_sym_DASH] = ACTIONS(6310),
    [aux_sym_boolean_token1] = ACTIONS(6308),
    [aux_sym_boolean_token2] = ACTIONS(6308),
    [sym_decimal] = ACTIONS(6308),
    [anon_sym_LPAREN] = ACTIONS(6310),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6308),
    [anon_sym_LBRACK] = ACTIONS(6310),
    [aux_sym_record_type_token1] = ACTIONS(6308),
    [aux_sym_basic_type_token21] = ACTIONS(6308),
    [aux_sym_basic_type_token22] = ACTIONS(6308),
    [aux_sym_basic_type_token48] = ACTIONS(6308),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6308),
    [anon_sym_POUNDif] = ACTIONS(6310),
    [anon_sym_POUNDIF] = ACTIONS(6310),
    [anon_sym_POUNDIf] = ACTIONS(6310),
    [anon_sym_not] = ACTIONS(6308),
    [anon_sym_NOT] = ACTIONS(6308),
    [anon_sym_Not] = ACTIONS(6308),
    [anon_sym_POUNDelse] = ACTIONS(6310),
    [anon_sym_POUNDELSE] = ACTIONS(6310),
    [anon_sym_POUNDElse] = ACTIONS(6310),
    [anon_sym_POUNDelse2] = ACTIONS(6310),
    [anon_sym_POUNDELSE2] = ACTIONS(6310),
    [anon_sym_POUNDElse2] = ACTIONS(6310),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6308),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6308),
    [anon_sym_PLUS] = ACTIONS(6310),
    [sym_datetime_literal] = ACTIONS(6310),
    [sym_date_literal] = ACTIONS(6308),
    [sym_time_literal] = ACTIONS(6308),
    [sym_biginteger_literal] = ACTIONS(6310),
    [anon_sym_if] = ACTIONS(6308),
    [anon_sym_IF] = ACTIONS(6308),
    [anon_sym_If] = ACTIONS(6308),
    [anon_sym_else] = ACTIONS(6308),
    [anon_sym_ELSE] = ACTIONS(6308),
    [anon_sym_Else] = ACTIONS(6308),
    [anon_sym_case] = ACTIONS(6308),
    [anon_sym_CASE] = ACTIONS(6308),
    [anon_sym_Case] = ACTIONS(6308),
    [anon_sym_for] = ACTIONS(6308),
    [anon_sym_FOR] = ACTIONS(6308),
    [anon_sym_For] = ACTIONS(6308),
    [anon_sym_foreach] = ACTIONS(6308),
    [anon_sym_FOREACH] = ACTIONS(6308),
    [anon_sym_Foreach] = ACTIONS(6308),
    [anon_sym_while] = ACTIONS(6308),
    [anon_sym_WHILE] = ACTIONS(6308),
    [anon_sym_While] = ACTIONS(6308),
    [anon_sym_repeat] = ACTIONS(6308),
    [anon_sym_REPEAT] = ACTIONS(6308),
    [anon_sym_Repeat] = ACTIONS(6308),
    [anon_sym_until] = ACTIONS(6308),
    [anon_sym_UNTIL] = ACTIONS(6308),
    [anon_sym_Until] = ACTIONS(6308),
    [anon_sym_exit] = ACTIONS(6308),
    [anon_sym_EXIT] = ACTIONS(6308),
    [anon_sym_Exit] = ACTIONS(6308),
    [anon_sym_continue] = ACTIONS(6308),
    [anon_sym_CONTINUE] = ACTIONS(6308),
    [anon_sym_Continue] = ACTIONS(6308),
    [anon_sym_break] = ACTIONS(6308),
    [anon_sym_BREAK] = ACTIONS(6308),
    [anon_sym_Break] = ACTIONS(6308),
    [anon_sym_with] = ACTIONS(6308),
    [anon_sym_WITH] = ACTIONS(6308),
    [anon_sym_With] = ACTIONS(6308),
    [sym_asserterror_keyword] = ACTIONS(6310),
    [sym_page_keyword] = ACTIONS(6308),
    [anon_sym_codeunit] = ACTIONS(6308),
    [anon_sym_CODEUNIT] = ACTIONS(6308),
    [anon_sym_Codeunit] = ACTIONS(6308),
    [anon_sym_CodeUnit] = ACTIONS(6308),
    [anon_sym_COdeunit] = ACTIONS(6308),
    [anon_sym_codeUnit] = ACTIONS(6308),
    [sym_report_keyword] = ACTIONS(6308),
    [sym_query_keyword] = ACTIONS(6308),
    [anon_sym_xmlport] = ACTIONS(6308),
    [anon_sym_XMLPORT] = ACTIONS(6308),
    [anon_sym_Xmlport] = ACTIONS(6308),
    [anon_sym_XMLport] = ACTIONS(6308),
    [anon_sym_XMLPort] = ACTIONS(6308),
    [anon_sym_XmlPort] = ACTIONS(6308),
    [anon_sym_enum] = ACTIONS(6308),
    [anon_sym_ENUM] = ACTIONS(6308),
    [anon_sym_Enum] = ACTIONS(6308),
    [anon_sym_eNUM] = ACTIONS(6308),
    [anon_sym_eNum] = ACTIONS(6308),
    [anon_sym_ENum] = ACTIONS(6308),
    [sym_quoted_identifier] = ACTIONS(6310),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6310),
    [sym_verbatim_string] = ACTIONS(6310),
    [sym_integer] = ACTIONS(6308),
    [sym_continue_as_identifier] = ACTIONS(6310),
    [sym_preproc_open] = ACTIONS(6310),
  },
  [STATE(2945)] = {
    [sym_identifier] = ACTIONS(6312),
    [anon_sym_SEMI] = ACTIONS(6314),
    [anon_sym_DASH] = ACTIONS(6314),
    [aux_sym_boolean_token1] = ACTIONS(6312),
    [aux_sym_boolean_token2] = ACTIONS(6312),
    [sym_decimal] = ACTIONS(6312),
    [anon_sym_LPAREN] = ACTIONS(6314),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6312),
    [anon_sym_LBRACK] = ACTIONS(6314),
    [aux_sym_record_type_token1] = ACTIONS(6312),
    [aux_sym_basic_type_token21] = ACTIONS(6312),
    [aux_sym_basic_type_token22] = ACTIONS(6312),
    [aux_sym_basic_type_token48] = ACTIONS(6312),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6312),
    [anon_sym_POUNDif] = ACTIONS(6314),
    [anon_sym_POUNDIF] = ACTIONS(6314),
    [anon_sym_POUNDIf] = ACTIONS(6314),
    [anon_sym_not] = ACTIONS(6312),
    [anon_sym_NOT] = ACTIONS(6312),
    [anon_sym_Not] = ACTIONS(6312),
    [anon_sym_POUNDelse] = ACTIONS(6314),
    [anon_sym_POUNDELSE] = ACTIONS(6314),
    [anon_sym_POUNDElse] = ACTIONS(6314),
    [anon_sym_POUNDelse2] = ACTIONS(6314),
    [anon_sym_POUNDELSE2] = ACTIONS(6314),
    [anon_sym_POUNDElse2] = ACTIONS(6314),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6312),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6312),
    [anon_sym_PLUS] = ACTIONS(6314),
    [sym_datetime_literal] = ACTIONS(6314),
    [sym_date_literal] = ACTIONS(6312),
    [sym_time_literal] = ACTIONS(6312),
    [sym_biginteger_literal] = ACTIONS(6314),
    [anon_sym_if] = ACTIONS(6312),
    [anon_sym_IF] = ACTIONS(6312),
    [anon_sym_If] = ACTIONS(6312),
    [anon_sym_else] = ACTIONS(6312),
    [anon_sym_ELSE] = ACTIONS(6312),
    [anon_sym_Else] = ACTIONS(6312),
    [anon_sym_case] = ACTIONS(6312),
    [anon_sym_CASE] = ACTIONS(6312),
    [anon_sym_Case] = ACTIONS(6312),
    [anon_sym_for] = ACTIONS(6312),
    [anon_sym_FOR] = ACTIONS(6312),
    [anon_sym_For] = ACTIONS(6312),
    [anon_sym_foreach] = ACTIONS(6312),
    [anon_sym_FOREACH] = ACTIONS(6312),
    [anon_sym_Foreach] = ACTIONS(6312),
    [anon_sym_while] = ACTIONS(6312),
    [anon_sym_WHILE] = ACTIONS(6312),
    [anon_sym_While] = ACTIONS(6312),
    [anon_sym_repeat] = ACTIONS(6312),
    [anon_sym_REPEAT] = ACTIONS(6312),
    [anon_sym_Repeat] = ACTIONS(6312),
    [anon_sym_until] = ACTIONS(6312),
    [anon_sym_UNTIL] = ACTIONS(6312),
    [anon_sym_Until] = ACTIONS(6312),
    [anon_sym_exit] = ACTIONS(6312),
    [anon_sym_EXIT] = ACTIONS(6312),
    [anon_sym_Exit] = ACTIONS(6312),
    [anon_sym_continue] = ACTIONS(6312),
    [anon_sym_CONTINUE] = ACTIONS(6312),
    [anon_sym_Continue] = ACTIONS(6312),
    [anon_sym_break] = ACTIONS(6312),
    [anon_sym_BREAK] = ACTIONS(6312),
    [anon_sym_Break] = ACTIONS(6312),
    [anon_sym_with] = ACTIONS(6312),
    [anon_sym_WITH] = ACTIONS(6312),
    [anon_sym_With] = ACTIONS(6312),
    [sym_asserterror_keyword] = ACTIONS(6314),
    [sym_page_keyword] = ACTIONS(6312),
    [anon_sym_codeunit] = ACTIONS(6312),
    [anon_sym_CODEUNIT] = ACTIONS(6312),
    [anon_sym_Codeunit] = ACTIONS(6312),
    [anon_sym_CodeUnit] = ACTIONS(6312),
    [anon_sym_COdeunit] = ACTIONS(6312),
    [anon_sym_codeUnit] = ACTIONS(6312),
    [sym_report_keyword] = ACTIONS(6312),
    [sym_query_keyword] = ACTIONS(6312),
    [anon_sym_xmlport] = ACTIONS(6312),
    [anon_sym_XMLPORT] = ACTIONS(6312),
    [anon_sym_Xmlport] = ACTIONS(6312),
    [anon_sym_XMLport] = ACTIONS(6312),
    [anon_sym_XMLPort] = ACTIONS(6312),
    [anon_sym_XmlPort] = ACTIONS(6312),
    [anon_sym_enum] = ACTIONS(6312),
    [anon_sym_ENUM] = ACTIONS(6312),
    [anon_sym_Enum] = ACTIONS(6312),
    [anon_sym_eNUM] = ACTIONS(6312),
    [anon_sym_eNum] = ACTIONS(6312),
    [anon_sym_ENum] = ACTIONS(6312),
    [sym_quoted_identifier] = ACTIONS(6314),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6314),
    [sym_verbatim_string] = ACTIONS(6314),
    [sym_integer] = ACTIONS(6312),
    [sym_continue_as_identifier] = ACTIONS(6314),
    [sym_preproc_open] = ACTIONS(6314),
  },
  [STATE(2946)] = {
    [sym_identifier] = ACTIONS(6308),
    [anon_sym_SEMI] = ACTIONS(6310),
    [anon_sym_DASH] = ACTIONS(6310),
    [aux_sym_boolean_token1] = ACTIONS(6308),
    [aux_sym_boolean_token2] = ACTIONS(6308),
    [sym_decimal] = ACTIONS(6308),
    [anon_sym_LPAREN] = ACTIONS(6310),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6308),
    [anon_sym_LBRACK] = ACTIONS(6310),
    [aux_sym_record_type_token1] = ACTIONS(6308),
    [aux_sym_basic_type_token21] = ACTIONS(6308),
    [aux_sym_basic_type_token22] = ACTIONS(6308),
    [aux_sym_basic_type_token48] = ACTIONS(6308),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6308),
    [anon_sym_POUNDif] = ACTIONS(6310),
    [anon_sym_POUNDIF] = ACTIONS(6310),
    [anon_sym_POUNDIf] = ACTIONS(6310),
    [anon_sym_not] = ACTIONS(6308),
    [anon_sym_NOT] = ACTIONS(6308),
    [anon_sym_Not] = ACTIONS(6308),
    [anon_sym_POUNDelse] = ACTIONS(6310),
    [anon_sym_POUNDELSE] = ACTIONS(6310),
    [anon_sym_POUNDElse] = ACTIONS(6310),
    [anon_sym_POUNDelse2] = ACTIONS(6310),
    [anon_sym_POUNDELSE2] = ACTIONS(6310),
    [anon_sym_POUNDElse2] = ACTIONS(6310),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6308),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6308),
    [anon_sym_PLUS] = ACTIONS(6310),
    [sym_datetime_literal] = ACTIONS(6310),
    [sym_date_literal] = ACTIONS(6308),
    [sym_time_literal] = ACTIONS(6308),
    [sym_biginteger_literal] = ACTIONS(6310),
    [anon_sym_if] = ACTIONS(6308),
    [anon_sym_IF] = ACTIONS(6308),
    [anon_sym_If] = ACTIONS(6308),
    [anon_sym_else] = ACTIONS(6308),
    [anon_sym_ELSE] = ACTIONS(6308),
    [anon_sym_Else] = ACTIONS(6308),
    [anon_sym_case] = ACTIONS(6308),
    [anon_sym_CASE] = ACTIONS(6308),
    [anon_sym_Case] = ACTIONS(6308),
    [anon_sym_for] = ACTIONS(6308),
    [anon_sym_FOR] = ACTIONS(6308),
    [anon_sym_For] = ACTIONS(6308),
    [anon_sym_foreach] = ACTIONS(6308),
    [anon_sym_FOREACH] = ACTIONS(6308),
    [anon_sym_Foreach] = ACTIONS(6308),
    [anon_sym_while] = ACTIONS(6308),
    [anon_sym_WHILE] = ACTIONS(6308),
    [anon_sym_While] = ACTIONS(6308),
    [anon_sym_repeat] = ACTIONS(6308),
    [anon_sym_REPEAT] = ACTIONS(6308),
    [anon_sym_Repeat] = ACTIONS(6308),
    [anon_sym_until] = ACTIONS(6308),
    [anon_sym_UNTIL] = ACTIONS(6308),
    [anon_sym_Until] = ACTIONS(6308),
    [anon_sym_exit] = ACTIONS(6308),
    [anon_sym_EXIT] = ACTIONS(6308),
    [anon_sym_Exit] = ACTIONS(6308),
    [anon_sym_continue] = ACTIONS(6308),
    [anon_sym_CONTINUE] = ACTIONS(6308),
    [anon_sym_Continue] = ACTIONS(6308),
    [anon_sym_break] = ACTIONS(6308),
    [anon_sym_BREAK] = ACTIONS(6308),
    [anon_sym_Break] = ACTIONS(6308),
    [anon_sym_with] = ACTIONS(6308),
    [anon_sym_WITH] = ACTIONS(6308),
    [anon_sym_With] = ACTIONS(6308),
    [sym_asserterror_keyword] = ACTIONS(6310),
    [sym_page_keyword] = ACTIONS(6308),
    [anon_sym_codeunit] = ACTIONS(6308),
    [anon_sym_CODEUNIT] = ACTIONS(6308),
    [anon_sym_Codeunit] = ACTIONS(6308),
    [anon_sym_CodeUnit] = ACTIONS(6308),
    [anon_sym_COdeunit] = ACTIONS(6308),
    [anon_sym_codeUnit] = ACTIONS(6308),
    [sym_report_keyword] = ACTIONS(6308),
    [sym_query_keyword] = ACTIONS(6308),
    [anon_sym_xmlport] = ACTIONS(6308),
    [anon_sym_XMLPORT] = ACTIONS(6308),
    [anon_sym_Xmlport] = ACTIONS(6308),
    [anon_sym_XMLport] = ACTIONS(6308),
    [anon_sym_XMLPort] = ACTIONS(6308),
    [anon_sym_XmlPort] = ACTIONS(6308),
    [anon_sym_enum] = ACTIONS(6308),
    [anon_sym_ENUM] = ACTIONS(6308),
    [anon_sym_Enum] = ACTIONS(6308),
    [anon_sym_eNUM] = ACTIONS(6308),
    [anon_sym_eNum] = ACTIONS(6308),
    [anon_sym_ENum] = ACTIONS(6308),
    [sym_quoted_identifier] = ACTIONS(6310),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6310),
    [sym_verbatim_string] = ACTIONS(6310),
    [sym_integer] = ACTIONS(6308),
    [sym_continue_as_identifier] = ACTIONS(6310),
    [sym_preproc_open] = ACTIONS(6310),
  },
  [STATE(2947)] = {
    [sym_identifier] = ACTIONS(6316),
    [anon_sym_SEMI] = ACTIONS(6318),
    [anon_sym_DASH] = ACTIONS(6318),
    [aux_sym_boolean_token1] = ACTIONS(6316),
    [aux_sym_boolean_token2] = ACTIONS(6316),
    [sym_decimal] = ACTIONS(6316),
    [anon_sym_LPAREN] = ACTIONS(6318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6316),
    [anon_sym_LBRACK] = ACTIONS(6318),
    [aux_sym_record_type_token1] = ACTIONS(6316),
    [aux_sym_basic_type_token21] = ACTIONS(6316),
    [aux_sym_basic_type_token22] = ACTIONS(6316),
    [aux_sym_basic_type_token48] = ACTIONS(6316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6316),
    [anon_sym_POUNDif] = ACTIONS(6318),
    [anon_sym_POUNDIF] = ACTIONS(6318),
    [anon_sym_POUNDIf] = ACTIONS(6318),
    [anon_sym_not] = ACTIONS(6316),
    [anon_sym_NOT] = ACTIONS(6316),
    [anon_sym_Not] = ACTIONS(6316),
    [anon_sym_POUNDelse] = ACTIONS(6318),
    [anon_sym_POUNDELSE] = ACTIONS(6318),
    [anon_sym_POUNDElse] = ACTIONS(6318),
    [anon_sym_POUNDelse2] = ACTIONS(6318),
    [anon_sym_POUNDELSE2] = ACTIONS(6318),
    [anon_sym_POUNDElse2] = ACTIONS(6318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6316),
    [anon_sym_PLUS] = ACTIONS(6318),
    [sym_datetime_literal] = ACTIONS(6318),
    [sym_date_literal] = ACTIONS(6316),
    [sym_time_literal] = ACTIONS(6316),
    [sym_biginteger_literal] = ACTIONS(6318),
    [anon_sym_if] = ACTIONS(6316),
    [anon_sym_IF] = ACTIONS(6316),
    [anon_sym_If] = ACTIONS(6316),
    [anon_sym_else] = ACTIONS(6316),
    [anon_sym_ELSE] = ACTIONS(6316),
    [anon_sym_Else] = ACTIONS(6316),
    [anon_sym_case] = ACTIONS(6316),
    [anon_sym_CASE] = ACTIONS(6316),
    [anon_sym_Case] = ACTIONS(6316),
    [anon_sym_for] = ACTIONS(6316),
    [anon_sym_FOR] = ACTIONS(6316),
    [anon_sym_For] = ACTIONS(6316),
    [anon_sym_foreach] = ACTIONS(6316),
    [anon_sym_FOREACH] = ACTIONS(6316),
    [anon_sym_Foreach] = ACTIONS(6316),
    [anon_sym_while] = ACTIONS(6316),
    [anon_sym_WHILE] = ACTIONS(6316),
    [anon_sym_While] = ACTIONS(6316),
    [anon_sym_repeat] = ACTIONS(6316),
    [anon_sym_REPEAT] = ACTIONS(6316),
    [anon_sym_Repeat] = ACTIONS(6316),
    [anon_sym_until] = ACTIONS(6316),
    [anon_sym_UNTIL] = ACTIONS(6316),
    [anon_sym_Until] = ACTIONS(6316),
    [anon_sym_exit] = ACTIONS(6316),
    [anon_sym_EXIT] = ACTIONS(6316),
    [anon_sym_Exit] = ACTIONS(6316),
    [anon_sym_continue] = ACTIONS(6316),
    [anon_sym_CONTINUE] = ACTIONS(6316),
    [anon_sym_Continue] = ACTIONS(6316),
    [anon_sym_break] = ACTIONS(6316),
    [anon_sym_BREAK] = ACTIONS(6316),
    [anon_sym_Break] = ACTIONS(6316),
    [anon_sym_with] = ACTIONS(6316),
    [anon_sym_WITH] = ACTIONS(6316),
    [anon_sym_With] = ACTIONS(6316),
    [sym_asserterror_keyword] = ACTIONS(6318),
    [sym_page_keyword] = ACTIONS(6316),
    [anon_sym_codeunit] = ACTIONS(6316),
    [anon_sym_CODEUNIT] = ACTIONS(6316),
    [anon_sym_Codeunit] = ACTIONS(6316),
    [anon_sym_CodeUnit] = ACTIONS(6316),
    [anon_sym_COdeunit] = ACTIONS(6316),
    [anon_sym_codeUnit] = ACTIONS(6316),
    [sym_report_keyword] = ACTIONS(6316),
    [sym_query_keyword] = ACTIONS(6316),
    [anon_sym_xmlport] = ACTIONS(6316),
    [anon_sym_XMLPORT] = ACTIONS(6316),
    [anon_sym_Xmlport] = ACTIONS(6316),
    [anon_sym_XMLport] = ACTIONS(6316),
    [anon_sym_XMLPort] = ACTIONS(6316),
    [anon_sym_XmlPort] = ACTIONS(6316),
    [anon_sym_enum] = ACTIONS(6316),
    [anon_sym_ENUM] = ACTIONS(6316),
    [anon_sym_Enum] = ACTIONS(6316),
    [anon_sym_eNUM] = ACTIONS(6316),
    [anon_sym_eNum] = ACTIONS(6316),
    [anon_sym_ENum] = ACTIONS(6316),
    [sym_quoted_identifier] = ACTIONS(6318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6318),
    [sym_verbatim_string] = ACTIONS(6318),
    [sym_integer] = ACTIONS(6316),
    [sym_continue_as_identifier] = ACTIONS(6318),
    [sym_preproc_open] = ACTIONS(6318),
  },
  [STATE(2948)] = {
    [sym_identifier] = ACTIONS(6320),
    [anon_sym_SEMI] = ACTIONS(6322),
    [anon_sym_DASH] = ACTIONS(6322),
    [aux_sym_boolean_token1] = ACTIONS(6320),
    [aux_sym_boolean_token2] = ACTIONS(6320),
    [sym_decimal] = ACTIONS(6320),
    [anon_sym_LPAREN] = ACTIONS(6322),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6320),
    [anon_sym_LBRACK] = ACTIONS(6322),
    [aux_sym_record_type_token1] = ACTIONS(6320),
    [aux_sym_basic_type_token21] = ACTIONS(6320),
    [aux_sym_basic_type_token22] = ACTIONS(6320),
    [aux_sym_basic_type_token48] = ACTIONS(6320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6320),
    [anon_sym_POUNDif] = ACTIONS(6322),
    [anon_sym_POUNDIF] = ACTIONS(6322),
    [anon_sym_POUNDIf] = ACTIONS(6322),
    [anon_sym_not] = ACTIONS(6320),
    [anon_sym_NOT] = ACTIONS(6320),
    [anon_sym_Not] = ACTIONS(6320),
    [anon_sym_POUNDelse] = ACTIONS(6322),
    [anon_sym_POUNDELSE] = ACTIONS(6322),
    [anon_sym_POUNDElse] = ACTIONS(6322),
    [anon_sym_POUNDelse2] = ACTIONS(6322),
    [anon_sym_POUNDELSE2] = ACTIONS(6322),
    [anon_sym_POUNDElse2] = ACTIONS(6322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6320),
    [anon_sym_PLUS] = ACTIONS(6322),
    [sym_datetime_literal] = ACTIONS(6322),
    [sym_date_literal] = ACTIONS(6320),
    [sym_time_literal] = ACTIONS(6320),
    [sym_biginteger_literal] = ACTIONS(6322),
    [anon_sym_if] = ACTIONS(6320),
    [anon_sym_IF] = ACTIONS(6320),
    [anon_sym_If] = ACTIONS(6320),
    [anon_sym_else] = ACTIONS(6320),
    [anon_sym_ELSE] = ACTIONS(6320),
    [anon_sym_Else] = ACTIONS(6320),
    [anon_sym_case] = ACTIONS(6320),
    [anon_sym_CASE] = ACTIONS(6320),
    [anon_sym_Case] = ACTIONS(6320),
    [anon_sym_for] = ACTIONS(6320),
    [anon_sym_FOR] = ACTIONS(6320),
    [anon_sym_For] = ACTIONS(6320),
    [anon_sym_foreach] = ACTIONS(6320),
    [anon_sym_FOREACH] = ACTIONS(6320),
    [anon_sym_Foreach] = ACTIONS(6320),
    [anon_sym_while] = ACTIONS(6320),
    [anon_sym_WHILE] = ACTIONS(6320),
    [anon_sym_While] = ACTIONS(6320),
    [anon_sym_repeat] = ACTIONS(6320),
    [anon_sym_REPEAT] = ACTIONS(6320),
    [anon_sym_Repeat] = ACTIONS(6320),
    [anon_sym_until] = ACTIONS(6320),
    [anon_sym_UNTIL] = ACTIONS(6320),
    [anon_sym_Until] = ACTIONS(6320),
    [anon_sym_exit] = ACTIONS(6320),
    [anon_sym_EXIT] = ACTIONS(6320),
    [anon_sym_Exit] = ACTIONS(6320),
    [anon_sym_continue] = ACTIONS(6320),
    [anon_sym_CONTINUE] = ACTIONS(6320),
    [anon_sym_Continue] = ACTIONS(6320),
    [anon_sym_break] = ACTIONS(6320),
    [anon_sym_BREAK] = ACTIONS(6320),
    [anon_sym_Break] = ACTIONS(6320),
    [anon_sym_with] = ACTIONS(6320),
    [anon_sym_WITH] = ACTIONS(6320),
    [anon_sym_With] = ACTIONS(6320),
    [sym_asserterror_keyword] = ACTIONS(6322),
    [sym_page_keyword] = ACTIONS(6320),
    [anon_sym_codeunit] = ACTIONS(6320),
    [anon_sym_CODEUNIT] = ACTIONS(6320),
    [anon_sym_Codeunit] = ACTIONS(6320),
    [anon_sym_CodeUnit] = ACTIONS(6320),
    [anon_sym_COdeunit] = ACTIONS(6320),
    [anon_sym_codeUnit] = ACTIONS(6320),
    [sym_report_keyword] = ACTIONS(6320),
    [sym_query_keyword] = ACTIONS(6320),
    [anon_sym_xmlport] = ACTIONS(6320),
    [anon_sym_XMLPORT] = ACTIONS(6320),
    [anon_sym_Xmlport] = ACTIONS(6320),
    [anon_sym_XMLport] = ACTIONS(6320),
    [anon_sym_XMLPort] = ACTIONS(6320),
    [anon_sym_XmlPort] = ACTIONS(6320),
    [anon_sym_enum] = ACTIONS(6320),
    [anon_sym_ENUM] = ACTIONS(6320),
    [anon_sym_Enum] = ACTIONS(6320),
    [anon_sym_eNUM] = ACTIONS(6320),
    [anon_sym_eNum] = ACTIONS(6320),
    [anon_sym_ENum] = ACTIONS(6320),
    [sym_quoted_identifier] = ACTIONS(6322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6322),
    [sym_verbatim_string] = ACTIONS(6322),
    [sym_integer] = ACTIONS(6320),
    [sym_continue_as_identifier] = ACTIONS(6322),
    [sym_preproc_open] = ACTIONS(6322),
  },
  [STATE(2949)] = {
    [sym_identifier] = ACTIONS(6316),
    [anon_sym_SEMI] = ACTIONS(6318),
    [anon_sym_DASH] = ACTIONS(6318),
    [aux_sym_boolean_token1] = ACTIONS(6316),
    [aux_sym_boolean_token2] = ACTIONS(6316),
    [sym_decimal] = ACTIONS(6316),
    [anon_sym_LPAREN] = ACTIONS(6318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6316),
    [anon_sym_LBRACK] = ACTIONS(6318),
    [aux_sym_record_type_token1] = ACTIONS(6316),
    [aux_sym_basic_type_token21] = ACTIONS(6316),
    [aux_sym_basic_type_token22] = ACTIONS(6316),
    [aux_sym_basic_type_token48] = ACTIONS(6316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6316),
    [anon_sym_POUNDif] = ACTIONS(6318),
    [anon_sym_POUNDIF] = ACTIONS(6318),
    [anon_sym_POUNDIf] = ACTIONS(6318),
    [anon_sym_not] = ACTIONS(6316),
    [anon_sym_NOT] = ACTIONS(6316),
    [anon_sym_Not] = ACTIONS(6316),
    [anon_sym_POUNDelse] = ACTIONS(6318),
    [anon_sym_POUNDELSE] = ACTIONS(6318),
    [anon_sym_POUNDElse] = ACTIONS(6318),
    [anon_sym_POUNDelse2] = ACTIONS(6318),
    [anon_sym_POUNDELSE2] = ACTIONS(6318),
    [anon_sym_POUNDElse2] = ACTIONS(6318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6316),
    [anon_sym_PLUS] = ACTIONS(6318),
    [sym_datetime_literal] = ACTIONS(6318),
    [sym_date_literal] = ACTIONS(6316),
    [sym_time_literal] = ACTIONS(6316),
    [sym_biginteger_literal] = ACTIONS(6318),
    [anon_sym_if] = ACTIONS(6316),
    [anon_sym_IF] = ACTIONS(6316),
    [anon_sym_If] = ACTIONS(6316),
    [anon_sym_else] = ACTIONS(6316),
    [anon_sym_ELSE] = ACTIONS(6316),
    [anon_sym_Else] = ACTIONS(6316),
    [anon_sym_case] = ACTIONS(6316),
    [anon_sym_CASE] = ACTIONS(6316),
    [anon_sym_Case] = ACTIONS(6316),
    [anon_sym_for] = ACTIONS(6316),
    [anon_sym_FOR] = ACTIONS(6316),
    [anon_sym_For] = ACTIONS(6316),
    [anon_sym_foreach] = ACTIONS(6316),
    [anon_sym_FOREACH] = ACTIONS(6316),
    [anon_sym_Foreach] = ACTIONS(6316),
    [anon_sym_while] = ACTIONS(6316),
    [anon_sym_WHILE] = ACTIONS(6316),
    [anon_sym_While] = ACTIONS(6316),
    [anon_sym_repeat] = ACTIONS(6316),
    [anon_sym_REPEAT] = ACTIONS(6316),
    [anon_sym_Repeat] = ACTIONS(6316),
    [anon_sym_until] = ACTIONS(6316),
    [anon_sym_UNTIL] = ACTIONS(6316),
    [anon_sym_Until] = ACTIONS(6316),
    [anon_sym_exit] = ACTIONS(6316),
    [anon_sym_EXIT] = ACTIONS(6316),
    [anon_sym_Exit] = ACTIONS(6316),
    [anon_sym_continue] = ACTIONS(6316),
    [anon_sym_CONTINUE] = ACTIONS(6316),
    [anon_sym_Continue] = ACTIONS(6316),
    [anon_sym_break] = ACTIONS(6316),
    [anon_sym_BREAK] = ACTIONS(6316),
    [anon_sym_Break] = ACTIONS(6316),
    [anon_sym_with] = ACTIONS(6316),
    [anon_sym_WITH] = ACTIONS(6316),
    [anon_sym_With] = ACTIONS(6316),
    [sym_asserterror_keyword] = ACTIONS(6318),
    [sym_page_keyword] = ACTIONS(6316),
    [anon_sym_codeunit] = ACTIONS(6316),
    [anon_sym_CODEUNIT] = ACTIONS(6316),
    [anon_sym_Codeunit] = ACTIONS(6316),
    [anon_sym_CodeUnit] = ACTIONS(6316),
    [anon_sym_COdeunit] = ACTIONS(6316),
    [anon_sym_codeUnit] = ACTIONS(6316),
    [sym_report_keyword] = ACTIONS(6316),
    [sym_query_keyword] = ACTIONS(6316),
    [anon_sym_xmlport] = ACTIONS(6316),
    [anon_sym_XMLPORT] = ACTIONS(6316),
    [anon_sym_Xmlport] = ACTIONS(6316),
    [anon_sym_XMLport] = ACTIONS(6316),
    [anon_sym_XMLPort] = ACTIONS(6316),
    [anon_sym_XmlPort] = ACTIONS(6316),
    [anon_sym_enum] = ACTIONS(6316),
    [anon_sym_ENUM] = ACTIONS(6316),
    [anon_sym_Enum] = ACTIONS(6316),
    [anon_sym_eNUM] = ACTIONS(6316),
    [anon_sym_eNum] = ACTIONS(6316),
    [anon_sym_ENum] = ACTIONS(6316),
    [sym_quoted_identifier] = ACTIONS(6318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6318),
    [sym_verbatim_string] = ACTIONS(6318),
    [sym_integer] = ACTIONS(6316),
    [sym_continue_as_identifier] = ACTIONS(6318),
    [sym_preproc_open] = ACTIONS(6318),
  },
  [STATE(2950)] = {
    [sym_identifier] = ACTIONS(6324),
    [anon_sym_SEMI] = ACTIONS(6326),
    [anon_sym_DASH] = ACTIONS(6326),
    [aux_sym_boolean_token1] = ACTIONS(6324),
    [aux_sym_boolean_token2] = ACTIONS(6324),
    [sym_decimal] = ACTIONS(6324),
    [anon_sym_LPAREN] = ACTIONS(6326),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6324),
    [anon_sym_LBRACK] = ACTIONS(6326),
    [aux_sym_record_type_token1] = ACTIONS(6324),
    [aux_sym_basic_type_token21] = ACTIONS(6324),
    [aux_sym_basic_type_token22] = ACTIONS(6324),
    [aux_sym_basic_type_token48] = ACTIONS(6324),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6324),
    [anon_sym_POUNDif] = ACTIONS(6326),
    [anon_sym_POUNDIF] = ACTIONS(6326),
    [anon_sym_POUNDIf] = ACTIONS(6326),
    [anon_sym_not] = ACTIONS(6324),
    [anon_sym_NOT] = ACTIONS(6324),
    [anon_sym_Not] = ACTIONS(6324),
    [anon_sym_POUNDelse] = ACTIONS(6326),
    [anon_sym_POUNDELSE] = ACTIONS(6326),
    [anon_sym_POUNDElse] = ACTIONS(6326),
    [anon_sym_POUNDelse2] = ACTIONS(6326),
    [anon_sym_POUNDELSE2] = ACTIONS(6326),
    [anon_sym_POUNDElse2] = ACTIONS(6326),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6324),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6324),
    [anon_sym_PLUS] = ACTIONS(6326),
    [sym_datetime_literal] = ACTIONS(6326),
    [sym_date_literal] = ACTIONS(6324),
    [sym_time_literal] = ACTIONS(6324),
    [sym_biginteger_literal] = ACTIONS(6326),
    [anon_sym_if] = ACTIONS(6324),
    [anon_sym_IF] = ACTIONS(6324),
    [anon_sym_If] = ACTIONS(6324),
    [anon_sym_else] = ACTIONS(6324),
    [anon_sym_ELSE] = ACTIONS(6324),
    [anon_sym_Else] = ACTIONS(6324),
    [anon_sym_case] = ACTIONS(6324),
    [anon_sym_CASE] = ACTIONS(6324),
    [anon_sym_Case] = ACTIONS(6324),
    [anon_sym_for] = ACTIONS(6324),
    [anon_sym_FOR] = ACTIONS(6324),
    [anon_sym_For] = ACTIONS(6324),
    [anon_sym_foreach] = ACTIONS(6324),
    [anon_sym_FOREACH] = ACTIONS(6324),
    [anon_sym_Foreach] = ACTIONS(6324),
    [anon_sym_while] = ACTIONS(6324),
    [anon_sym_WHILE] = ACTIONS(6324),
    [anon_sym_While] = ACTIONS(6324),
    [anon_sym_repeat] = ACTIONS(6324),
    [anon_sym_REPEAT] = ACTIONS(6324),
    [anon_sym_Repeat] = ACTIONS(6324),
    [anon_sym_until] = ACTIONS(6324),
    [anon_sym_UNTIL] = ACTIONS(6324),
    [anon_sym_Until] = ACTIONS(6324),
    [anon_sym_exit] = ACTIONS(6324),
    [anon_sym_EXIT] = ACTIONS(6324),
    [anon_sym_Exit] = ACTIONS(6324),
    [anon_sym_continue] = ACTIONS(6324),
    [anon_sym_CONTINUE] = ACTIONS(6324),
    [anon_sym_Continue] = ACTIONS(6324),
    [anon_sym_break] = ACTIONS(6324),
    [anon_sym_BREAK] = ACTIONS(6324),
    [anon_sym_Break] = ACTIONS(6324),
    [anon_sym_with] = ACTIONS(6324),
    [anon_sym_WITH] = ACTIONS(6324),
    [anon_sym_With] = ACTIONS(6324),
    [sym_asserterror_keyword] = ACTIONS(6326),
    [sym_page_keyword] = ACTIONS(6324),
    [anon_sym_codeunit] = ACTIONS(6324),
    [anon_sym_CODEUNIT] = ACTIONS(6324),
    [anon_sym_Codeunit] = ACTIONS(6324),
    [anon_sym_CodeUnit] = ACTIONS(6324),
    [anon_sym_COdeunit] = ACTIONS(6324),
    [anon_sym_codeUnit] = ACTIONS(6324),
    [sym_report_keyword] = ACTIONS(6324),
    [sym_query_keyword] = ACTIONS(6324),
    [anon_sym_xmlport] = ACTIONS(6324),
    [anon_sym_XMLPORT] = ACTIONS(6324),
    [anon_sym_Xmlport] = ACTIONS(6324),
    [anon_sym_XMLport] = ACTIONS(6324),
    [anon_sym_XMLPort] = ACTIONS(6324),
    [anon_sym_XmlPort] = ACTIONS(6324),
    [anon_sym_enum] = ACTIONS(6324),
    [anon_sym_ENUM] = ACTIONS(6324),
    [anon_sym_Enum] = ACTIONS(6324),
    [anon_sym_eNUM] = ACTIONS(6324),
    [anon_sym_eNum] = ACTIONS(6324),
    [anon_sym_ENum] = ACTIONS(6324),
    [sym_quoted_identifier] = ACTIONS(6326),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6326),
    [sym_verbatim_string] = ACTIONS(6326),
    [sym_integer] = ACTIONS(6324),
    [sym_continue_as_identifier] = ACTIONS(6326),
    [sym_preproc_open] = ACTIONS(6326),
  },
  [STATE(2951)] = {
    [sym_identifier] = ACTIONS(6328),
    [anon_sym_SEMI] = ACTIONS(6330),
    [anon_sym_DASH] = ACTIONS(6330),
    [aux_sym_boolean_token1] = ACTIONS(6328),
    [aux_sym_boolean_token2] = ACTIONS(6328),
    [sym_decimal] = ACTIONS(6328),
    [anon_sym_LPAREN] = ACTIONS(6330),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6328),
    [anon_sym_LBRACK] = ACTIONS(6330),
    [aux_sym_record_type_token1] = ACTIONS(6328),
    [aux_sym_basic_type_token21] = ACTIONS(6328),
    [aux_sym_basic_type_token22] = ACTIONS(6328),
    [aux_sym_basic_type_token48] = ACTIONS(6328),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6328),
    [anon_sym_POUNDif] = ACTIONS(6330),
    [anon_sym_POUNDIF] = ACTIONS(6330),
    [anon_sym_POUNDIf] = ACTIONS(6330),
    [anon_sym_not] = ACTIONS(6328),
    [anon_sym_NOT] = ACTIONS(6328),
    [anon_sym_Not] = ACTIONS(6328),
    [anon_sym_POUNDelse] = ACTIONS(6330),
    [anon_sym_POUNDELSE] = ACTIONS(6330),
    [anon_sym_POUNDElse] = ACTIONS(6330),
    [anon_sym_POUNDelse2] = ACTIONS(6330),
    [anon_sym_POUNDELSE2] = ACTIONS(6330),
    [anon_sym_POUNDElse2] = ACTIONS(6330),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6328),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6328),
    [anon_sym_PLUS] = ACTIONS(6330),
    [sym_datetime_literal] = ACTIONS(6330),
    [sym_date_literal] = ACTIONS(6328),
    [sym_time_literal] = ACTIONS(6328),
    [sym_biginteger_literal] = ACTIONS(6330),
    [anon_sym_if] = ACTIONS(6328),
    [anon_sym_IF] = ACTIONS(6328),
    [anon_sym_If] = ACTIONS(6328),
    [anon_sym_else] = ACTIONS(6328),
    [anon_sym_ELSE] = ACTIONS(6328),
    [anon_sym_Else] = ACTIONS(6328),
    [anon_sym_case] = ACTIONS(6328),
    [anon_sym_CASE] = ACTIONS(6328),
    [anon_sym_Case] = ACTIONS(6328),
    [anon_sym_for] = ACTIONS(6328),
    [anon_sym_FOR] = ACTIONS(6328),
    [anon_sym_For] = ACTIONS(6328),
    [anon_sym_foreach] = ACTIONS(6328),
    [anon_sym_FOREACH] = ACTIONS(6328),
    [anon_sym_Foreach] = ACTIONS(6328),
    [anon_sym_while] = ACTIONS(6328),
    [anon_sym_WHILE] = ACTIONS(6328),
    [anon_sym_While] = ACTIONS(6328),
    [anon_sym_repeat] = ACTIONS(6328),
    [anon_sym_REPEAT] = ACTIONS(6328),
    [anon_sym_Repeat] = ACTIONS(6328),
    [anon_sym_until] = ACTIONS(6328),
    [anon_sym_UNTIL] = ACTIONS(6328),
    [anon_sym_Until] = ACTIONS(6328),
    [anon_sym_exit] = ACTIONS(6328),
    [anon_sym_EXIT] = ACTIONS(6328),
    [anon_sym_Exit] = ACTIONS(6328),
    [anon_sym_continue] = ACTIONS(6328),
    [anon_sym_CONTINUE] = ACTIONS(6328),
    [anon_sym_Continue] = ACTIONS(6328),
    [anon_sym_break] = ACTIONS(6328),
    [anon_sym_BREAK] = ACTIONS(6328),
    [anon_sym_Break] = ACTIONS(6328),
    [anon_sym_with] = ACTIONS(6328),
    [anon_sym_WITH] = ACTIONS(6328),
    [anon_sym_With] = ACTIONS(6328),
    [sym_asserterror_keyword] = ACTIONS(6330),
    [sym_page_keyword] = ACTIONS(6328),
    [anon_sym_codeunit] = ACTIONS(6328),
    [anon_sym_CODEUNIT] = ACTIONS(6328),
    [anon_sym_Codeunit] = ACTIONS(6328),
    [anon_sym_CodeUnit] = ACTIONS(6328),
    [anon_sym_COdeunit] = ACTIONS(6328),
    [anon_sym_codeUnit] = ACTIONS(6328),
    [sym_report_keyword] = ACTIONS(6328),
    [sym_query_keyword] = ACTIONS(6328),
    [anon_sym_xmlport] = ACTIONS(6328),
    [anon_sym_XMLPORT] = ACTIONS(6328),
    [anon_sym_Xmlport] = ACTIONS(6328),
    [anon_sym_XMLport] = ACTIONS(6328),
    [anon_sym_XMLPort] = ACTIONS(6328),
    [anon_sym_XmlPort] = ACTIONS(6328),
    [anon_sym_enum] = ACTIONS(6328),
    [anon_sym_ENUM] = ACTIONS(6328),
    [anon_sym_Enum] = ACTIONS(6328),
    [anon_sym_eNUM] = ACTIONS(6328),
    [anon_sym_eNum] = ACTIONS(6328),
    [anon_sym_ENum] = ACTIONS(6328),
    [sym_quoted_identifier] = ACTIONS(6330),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6330),
    [sym_verbatim_string] = ACTIONS(6330),
    [sym_integer] = ACTIONS(6328),
    [sym_continue_as_identifier] = ACTIONS(6330),
    [sym_preproc_open] = ACTIONS(6330),
  },
  [STATE(2952)] = {
    [sym_identifier] = ACTIONS(6332),
    [anon_sym_SEMI] = ACTIONS(6334),
    [anon_sym_DASH] = ACTIONS(6334),
    [aux_sym_boolean_token1] = ACTIONS(6332),
    [aux_sym_boolean_token2] = ACTIONS(6332),
    [sym_decimal] = ACTIONS(6332),
    [anon_sym_LPAREN] = ACTIONS(6334),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6332),
    [anon_sym_LBRACK] = ACTIONS(6334),
    [aux_sym_record_type_token1] = ACTIONS(6332),
    [aux_sym_basic_type_token21] = ACTIONS(6332),
    [aux_sym_basic_type_token22] = ACTIONS(6332),
    [aux_sym_basic_type_token48] = ACTIONS(6332),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6332),
    [anon_sym_POUNDif] = ACTIONS(6334),
    [anon_sym_POUNDIF] = ACTIONS(6334),
    [anon_sym_POUNDIf] = ACTIONS(6334),
    [anon_sym_not] = ACTIONS(6332),
    [anon_sym_NOT] = ACTIONS(6332),
    [anon_sym_Not] = ACTIONS(6332),
    [anon_sym_POUNDelse] = ACTIONS(6334),
    [anon_sym_POUNDELSE] = ACTIONS(6334),
    [anon_sym_POUNDElse] = ACTIONS(6334),
    [anon_sym_POUNDelse2] = ACTIONS(6334),
    [anon_sym_POUNDELSE2] = ACTIONS(6334),
    [anon_sym_POUNDElse2] = ACTIONS(6334),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6332),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6332),
    [anon_sym_PLUS] = ACTIONS(6334),
    [sym_datetime_literal] = ACTIONS(6334),
    [sym_date_literal] = ACTIONS(6332),
    [sym_time_literal] = ACTIONS(6332),
    [sym_biginteger_literal] = ACTIONS(6334),
    [anon_sym_if] = ACTIONS(6332),
    [anon_sym_IF] = ACTIONS(6332),
    [anon_sym_If] = ACTIONS(6332),
    [anon_sym_else] = ACTIONS(6332),
    [anon_sym_ELSE] = ACTIONS(6332),
    [anon_sym_Else] = ACTIONS(6332),
    [anon_sym_case] = ACTIONS(6332),
    [anon_sym_CASE] = ACTIONS(6332),
    [anon_sym_Case] = ACTIONS(6332),
    [anon_sym_for] = ACTIONS(6332),
    [anon_sym_FOR] = ACTIONS(6332),
    [anon_sym_For] = ACTIONS(6332),
    [anon_sym_foreach] = ACTIONS(6332),
    [anon_sym_FOREACH] = ACTIONS(6332),
    [anon_sym_Foreach] = ACTIONS(6332),
    [anon_sym_while] = ACTIONS(6332),
    [anon_sym_WHILE] = ACTIONS(6332),
    [anon_sym_While] = ACTIONS(6332),
    [anon_sym_repeat] = ACTIONS(6332),
    [anon_sym_REPEAT] = ACTIONS(6332),
    [anon_sym_Repeat] = ACTIONS(6332),
    [anon_sym_until] = ACTIONS(6332),
    [anon_sym_UNTIL] = ACTIONS(6332),
    [anon_sym_Until] = ACTIONS(6332),
    [anon_sym_exit] = ACTIONS(6332),
    [anon_sym_EXIT] = ACTIONS(6332),
    [anon_sym_Exit] = ACTIONS(6332),
    [anon_sym_continue] = ACTIONS(6332),
    [anon_sym_CONTINUE] = ACTIONS(6332),
    [anon_sym_Continue] = ACTIONS(6332),
    [anon_sym_break] = ACTIONS(6332),
    [anon_sym_BREAK] = ACTIONS(6332),
    [anon_sym_Break] = ACTIONS(6332),
    [anon_sym_with] = ACTIONS(6332),
    [anon_sym_WITH] = ACTIONS(6332),
    [anon_sym_With] = ACTIONS(6332),
    [sym_asserterror_keyword] = ACTIONS(6334),
    [sym_page_keyword] = ACTIONS(6332),
    [anon_sym_codeunit] = ACTIONS(6332),
    [anon_sym_CODEUNIT] = ACTIONS(6332),
    [anon_sym_Codeunit] = ACTIONS(6332),
    [anon_sym_CodeUnit] = ACTIONS(6332),
    [anon_sym_COdeunit] = ACTIONS(6332),
    [anon_sym_codeUnit] = ACTIONS(6332),
    [sym_report_keyword] = ACTIONS(6332),
    [sym_query_keyword] = ACTIONS(6332),
    [anon_sym_xmlport] = ACTIONS(6332),
    [anon_sym_XMLPORT] = ACTIONS(6332),
    [anon_sym_Xmlport] = ACTIONS(6332),
    [anon_sym_XMLport] = ACTIONS(6332),
    [anon_sym_XMLPort] = ACTIONS(6332),
    [anon_sym_XmlPort] = ACTIONS(6332),
    [anon_sym_enum] = ACTIONS(6332),
    [anon_sym_ENUM] = ACTIONS(6332),
    [anon_sym_Enum] = ACTIONS(6332),
    [anon_sym_eNUM] = ACTIONS(6332),
    [anon_sym_eNum] = ACTIONS(6332),
    [anon_sym_ENum] = ACTIONS(6332),
    [sym_quoted_identifier] = ACTIONS(6334),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6334),
    [sym_verbatim_string] = ACTIONS(6334),
    [sym_integer] = ACTIONS(6332),
    [sym_continue_as_identifier] = ACTIONS(6334),
    [sym_preproc_open] = ACTIONS(6334),
  },
  [STATE(2953)] = {
    [sym_identifier] = ACTIONS(6336),
    [anon_sym_SEMI] = ACTIONS(6338),
    [anon_sym_DASH] = ACTIONS(6338),
    [aux_sym_boolean_token1] = ACTIONS(6336),
    [aux_sym_boolean_token2] = ACTIONS(6336),
    [sym_decimal] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6338),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6336),
    [anon_sym_LBRACK] = ACTIONS(6338),
    [aux_sym_record_type_token1] = ACTIONS(6336),
    [aux_sym_basic_type_token21] = ACTIONS(6336),
    [aux_sym_basic_type_token22] = ACTIONS(6336),
    [aux_sym_basic_type_token48] = ACTIONS(6336),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6336),
    [anon_sym_POUNDif] = ACTIONS(6338),
    [anon_sym_POUNDIF] = ACTIONS(6338),
    [anon_sym_POUNDIf] = ACTIONS(6338),
    [anon_sym_not] = ACTIONS(6336),
    [anon_sym_NOT] = ACTIONS(6336),
    [anon_sym_Not] = ACTIONS(6336),
    [anon_sym_POUNDelse] = ACTIONS(6338),
    [anon_sym_POUNDELSE] = ACTIONS(6338),
    [anon_sym_POUNDElse] = ACTIONS(6338),
    [anon_sym_POUNDelse2] = ACTIONS(6338),
    [anon_sym_POUNDELSE2] = ACTIONS(6338),
    [anon_sym_POUNDElse2] = ACTIONS(6338),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6336),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6336),
    [anon_sym_PLUS] = ACTIONS(6338),
    [sym_datetime_literal] = ACTIONS(6338),
    [sym_date_literal] = ACTIONS(6336),
    [sym_time_literal] = ACTIONS(6336),
    [sym_biginteger_literal] = ACTIONS(6338),
    [anon_sym_if] = ACTIONS(6336),
    [anon_sym_IF] = ACTIONS(6336),
    [anon_sym_If] = ACTIONS(6336),
    [anon_sym_else] = ACTIONS(6336),
    [anon_sym_ELSE] = ACTIONS(6336),
    [anon_sym_Else] = ACTIONS(6336),
    [anon_sym_case] = ACTIONS(6336),
    [anon_sym_CASE] = ACTIONS(6336),
    [anon_sym_Case] = ACTIONS(6336),
    [anon_sym_for] = ACTIONS(6336),
    [anon_sym_FOR] = ACTIONS(6336),
    [anon_sym_For] = ACTIONS(6336),
    [anon_sym_foreach] = ACTIONS(6336),
    [anon_sym_FOREACH] = ACTIONS(6336),
    [anon_sym_Foreach] = ACTIONS(6336),
    [anon_sym_while] = ACTIONS(6336),
    [anon_sym_WHILE] = ACTIONS(6336),
    [anon_sym_While] = ACTIONS(6336),
    [anon_sym_repeat] = ACTIONS(6336),
    [anon_sym_REPEAT] = ACTIONS(6336),
    [anon_sym_Repeat] = ACTIONS(6336),
    [anon_sym_until] = ACTIONS(6336),
    [anon_sym_UNTIL] = ACTIONS(6336),
    [anon_sym_Until] = ACTIONS(6336),
    [anon_sym_exit] = ACTIONS(6336),
    [anon_sym_EXIT] = ACTIONS(6336),
    [anon_sym_Exit] = ACTIONS(6336),
    [anon_sym_continue] = ACTIONS(6336),
    [anon_sym_CONTINUE] = ACTIONS(6336),
    [anon_sym_Continue] = ACTIONS(6336),
    [anon_sym_break] = ACTIONS(6336),
    [anon_sym_BREAK] = ACTIONS(6336),
    [anon_sym_Break] = ACTIONS(6336),
    [anon_sym_with] = ACTIONS(6336),
    [anon_sym_WITH] = ACTIONS(6336),
    [anon_sym_With] = ACTIONS(6336),
    [sym_asserterror_keyword] = ACTIONS(6338),
    [sym_page_keyword] = ACTIONS(6336),
    [anon_sym_codeunit] = ACTIONS(6336),
    [anon_sym_CODEUNIT] = ACTIONS(6336),
    [anon_sym_Codeunit] = ACTIONS(6336),
    [anon_sym_CodeUnit] = ACTIONS(6336),
    [anon_sym_COdeunit] = ACTIONS(6336),
    [anon_sym_codeUnit] = ACTIONS(6336),
    [sym_report_keyword] = ACTIONS(6336),
    [sym_query_keyword] = ACTIONS(6336),
    [anon_sym_xmlport] = ACTIONS(6336),
    [anon_sym_XMLPORT] = ACTIONS(6336),
    [anon_sym_Xmlport] = ACTIONS(6336),
    [anon_sym_XMLport] = ACTIONS(6336),
    [anon_sym_XMLPort] = ACTIONS(6336),
    [anon_sym_XmlPort] = ACTIONS(6336),
    [anon_sym_enum] = ACTIONS(6336),
    [anon_sym_ENUM] = ACTIONS(6336),
    [anon_sym_Enum] = ACTIONS(6336),
    [anon_sym_eNUM] = ACTIONS(6336),
    [anon_sym_eNum] = ACTIONS(6336),
    [anon_sym_ENum] = ACTIONS(6336),
    [sym_quoted_identifier] = ACTIONS(6338),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6338),
    [sym_verbatim_string] = ACTIONS(6338),
    [sym_integer] = ACTIONS(6336),
    [sym_continue_as_identifier] = ACTIONS(6338),
    [sym_preproc_open] = ACTIONS(6338),
  },
  [STATE(2954)] = {
    [sym_identifier] = ACTIONS(6336),
    [anon_sym_SEMI] = ACTIONS(6338),
    [anon_sym_DASH] = ACTIONS(6338),
    [aux_sym_boolean_token1] = ACTIONS(6336),
    [aux_sym_boolean_token2] = ACTIONS(6336),
    [sym_decimal] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6338),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6336),
    [anon_sym_LBRACK] = ACTIONS(6338),
    [aux_sym_record_type_token1] = ACTIONS(6336),
    [aux_sym_basic_type_token21] = ACTIONS(6336),
    [aux_sym_basic_type_token22] = ACTIONS(6336),
    [aux_sym_basic_type_token48] = ACTIONS(6336),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6336),
    [anon_sym_POUNDif] = ACTIONS(6338),
    [anon_sym_POUNDIF] = ACTIONS(6338),
    [anon_sym_POUNDIf] = ACTIONS(6338),
    [anon_sym_not] = ACTIONS(6336),
    [anon_sym_NOT] = ACTIONS(6336),
    [anon_sym_Not] = ACTIONS(6336),
    [anon_sym_POUNDelse] = ACTIONS(6338),
    [anon_sym_POUNDELSE] = ACTIONS(6338),
    [anon_sym_POUNDElse] = ACTIONS(6338),
    [anon_sym_POUNDelse2] = ACTIONS(6338),
    [anon_sym_POUNDELSE2] = ACTIONS(6338),
    [anon_sym_POUNDElse2] = ACTIONS(6338),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6336),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6336),
    [anon_sym_PLUS] = ACTIONS(6338),
    [sym_datetime_literal] = ACTIONS(6338),
    [sym_date_literal] = ACTIONS(6336),
    [sym_time_literal] = ACTIONS(6336),
    [sym_biginteger_literal] = ACTIONS(6338),
    [anon_sym_if] = ACTIONS(6336),
    [anon_sym_IF] = ACTIONS(6336),
    [anon_sym_If] = ACTIONS(6336),
    [anon_sym_else] = ACTIONS(6336),
    [anon_sym_ELSE] = ACTIONS(6336),
    [anon_sym_Else] = ACTIONS(6336),
    [anon_sym_case] = ACTIONS(6336),
    [anon_sym_CASE] = ACTIONS(6336),
    [anon_sym_Case] = ACTIONS(6336),
    [anon_sym_for] = ACTIONS(6336),
    [anon_sym_FOR] = ACTIONS(6336),
    [anon_sym_For] = ACTIONS(6336),
    [anon_sym_foreach] = ACTIONS(6336),
    [anon_sym_FOREACH] = ACTIONS(6336),
    [anon_sym_Foreach] = ACTIONS(6336),
    [anon_sym_while] = ACTIONS(6336),
    [anon_sym_WHILE] = ACTIONS(6336),
    [anon_sym_While] = ACTIONS(6336),
    [anon_sym_repeat] = ACTIONS(6336),
    [anon_sym_REPEAT] = ACTIONS(6336),
    [anon_sym_Repeat] = ACTIONS(6336),
    [anon_sym_until] = ACTIONS(6336),
    [anon_sym_UNTIL] = ACTIONS(6336),
    [anon_sym_Until] = ACTIONS(6336),
    [anon_sym_exit] = ACTIONS(6336),
    [anon_sym_EXIT] = ACTIONS(6336),
    [anon_sym_Exit] = ACTIONS(6336),
    [anon_sym_continue] = ACTIONS(6336),
    [anon_sym_CONTINUE] = ACTIONS(6336),
    [anon_sym_Continue] = ACTIONS(6336),
    [anon_sym_break] = ACTIONS(6336),
    [anon_sym_BREAK] = ACTIONS(6336),
    [anon_sym_Break] = ACTIONS(6336),
    [anon_sym_with] = ACTIONS(6336),
    [anon_sym_WITH] = ACTIONS(6336),
    [anon_sym_With] = ACTIONS(6336),
    [sym_asserterror_keyword] = ACTIONS(6338),
    [sym_page_keyword] = ACTIONS(6336),
    [anon_sym_codeunit] = ACTIONS(6336),
    [anon_sym_CODEUNIT] = ACTIONS(6336),
    [anon_sym_Codeunit] = ACTIONS(6336),
    [anon_sym_CodeUnit] = ACTIONS(6336),
    [anon_sym_COdeunit] = ACTIONS(6336),
    [anon_sym_codeUnit] = ACTIONS(6336),
    [sym_report_keyword] = ACTIONS(6336),
    [sym_query_keyword] = ACTIONS(6336),
    [anon_sym_xmlport] = ACTIONS(6336),
    [anon_sym_XMLPORT] = ACTIONS(6336),
    [anon_sym_Xmlport] = ACTIONS(6336),
    [anon_sym_XMLport] = ACTIONS(6336),
    [anon_sym_XMLPort] = ACTIONS(6336),
    [anon_sym_XmlPort] = ACTIONS(6336),
    [anon_sym_enum] = ACTIONS(6336),
    [anon_sym_ENUM] = ACTIONS(6336),
    [anon_sym_Enum] = ACTIONS(6336),
    [anon_sym_eNUM] = ACTIONS(6336),
    [anon_sym_eNum] = ACTIONS(6336),
    [anon_sym_ENum] = ACTIONS(6336),
    [sym_quoted_identifier] = ACTIONS(6338),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6338),
    [sym_verbatim_string] = ACTIONS(6338),
    [sym_integer] = ACTIONS(6336),
    [sym_continue_as_identifier] = ACTIONS(6338),
    [sym_preproc_open] = ACTIONS(6338),
  },
  [STATE(2955)] = {
    [sym_identifier] = ACTIONS(6340),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_DASH] = ACTIONS(6342),
    [aux_sym_boolean_token1] = ACTIONS(6340),
    [aux_sym_boolean_token2] = ACTIONS(6340),
    [sym_decimal] = ACTIONS(6340),
    [anon_sym_LPAREN] = ACTIONS(6342),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6340),
    [anon_sym_LBRACK] = ACTIONS(6342),
    [aux_sym_record_type_token1] = ACTIONS(6340),
    [aux_sym_basic_type_token21] = ACTIONS(6340),
    [aux_sym_basic_type_token22] = ACTIONS(6340),
    [aux_sym_basic_type_token48] = ACTIONS(6340),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6340),
    [anon_sym_POUNDif] = ACTIONS(6342),
    [anon_sym_POUNDIF] = ACTIONS(6342),
    [anon_sym_POUNDIf] = ACTIONS(6342),
    [anon_sym_not] = ACTIONS(6340),
    [anon_sym_NOT] = ACTIONS(6340),
    [anon_sym_Not] = ACTIONS(6340),
    [anon_sym_POUNDelse] = ACTIONS(6342),
    [anon_sym_POUNDELSE] = ACTIONS(6342),
    [anon_sym_POUNDElse] = ACTIONS(6342),
    [anon_sym_POUNDelse2] = ACTIONS(6342),
    [anon_sym_POUNDELSE2] = ACTIONS(6342),
    [anon_sym_POUNDElse2] = ACTIONS(6342),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6340),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6340),
    [anon_sym_PLUS] = ACTIONS(6342),
    [sym_datetime_literal] = ACTIONS(6342),
    [sym_date_literal] = ACTIONS(6340),
    [sym_time_literal] = ACTIONS(6340),
    [sym_biginteger_literal] = ACTIONS(6342),
    [anon_sym_if] = ACTIONS(6340),
    [anon_sym_IF] = ACTIONS(6340),
    [anon_sym_If] = ACTIONS(6340),
    [anon_sym_else] = ACTIONS(6340),
    [anon_sym_ELSE] = ACTIONS(6340),
    [anon_sym_Else] = ACTIONS(6340),
    [anon_sym_case] = ACTIONS(6340),
    [anon_sym_CASE] = ACTIONS(6340),
    [anon_sym_Case] = ACTIONS(6340),
    [anon_sym_for] = ACTIONS(6340),
    [anon_sym_FOR] = ACTIONS(6340),
    [anon_sym_For] = ACTIONS(6340),
    [anon_sym_foreach] = ACTIONS(6340),
    [anon_sym_FOREACH] = ACTIONS(6340),
    [anon_sym_Foreach] = ACTIONS(6340),
    [anon_sym_while] = ACTIONS(6340),
    [anon_sym_WHILE] = ACTIONS(6340),
    [anon_sym_While] = ACTIONS(6340),
    [anon_sym_repeat] = ACTIONS(6340),
    [anon_sym_REPEAT] = ACTIONS(6340),
    [anon_sym_Repeat] = ACTIONS(6340),
    [anon_sym_until] = ACTIONS(6340),
    [anon_sym_UNTIL] = ACTIONS(6340),
    [anon_sym_Until] = ACTIONS(6340),
    [anon_sym_exit] = ACTIONS(6340),
    [anon_sym_EXIT] = ACTIONS(6340),
    [anon_sym_Exit] = ACTIONS(6340),
    [anon_sym_continue] = ACTIONS(6340),
    [anon_sym_CONTINUE] = ACTIONS(6340),
    [anon_sym_Continue] = ACTIONS(6340),
    [anon_sym_break] = ACTIONS(6340),
    [anon_sym_BREAK] = ACTIONS(6340),
    [anon_sym_Break] = ACTIONS(6340),
    [anon_sym_with] = ACTIONS(6340),
    [anon_sym_WITH] = ACTIONS(6340),
    [anon_sym_With] = ACTIONS(6340),
    [sym_asserterror_keyword] = ACTIONS(6342),
    [sym_page_keyword] = ACTIONS(6340),
    [anon_sym_codeunit] = ACTIONS(6340),
    [anon_sym_CODEUNIT] = ACTIONS(6340),
    [anon_sym_Codeunit] = ACTIONS(6340),
    [anon_sym_CodeUnit] = ACTIONS(6340),
    [anon_sym_COdeunit] = ACTIONS(6340),
    [anon_sym_codeUnit] = ACTIONS(6340),
    [sym_report_keyword] = ACTIONS(6340),
    [sym_query_keyword] = ACTIONS(6340),
    [anon_sym_xmlport] = ACTIONS(6340),
    [anon_sym_XMLPORT] = ACTIONS(6340),
    [anon_sym_Xmlport] = ACTIONS(6340),
    [anon_sym_XMLport] = ACTIONS(6340),
    [anon_sym_XMLPort] = ACTIONS(6340),
    [anon_sym_XmlPort] = ACTIONS(6340),
    [anon_sym_enum] = ACTIONS(6340),
    [anon_sym_ENUM] = ACTIONS(6340),
    [anon_sym_Enum] = ACTIONS(6340),
    [anon_sym_eNUM] = ACTIONS(6340),
    [anon_sym_eNum] = ACTIONS(6340),
    [anon_sym_ENum] = ACTIONS(6340),
    [sym_quoted_identifier] = ACTIONS(6342),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6342),
    [sym_verbatim_string] = ACTIONS(6342),
    [sym_integer] = ACTIONS(6340),
    [sym_continue_as_identifier] = ACTIONS(6342),
    [sym_preproc_open] = ACTIONS(6342),
  },
  [STATE(2956)] = {
    [sym_identifier] = ACTIONS(6344),
    [anon_sym_SEMI] = ACTIONS(6346),
    [anon_sym_DASH] = ACTIONS(6346),
    [aux_sym_boolean_token1] = ACTIONS(6344),
    [aux_sym_boolean_token2] = ACTIONS(6344),
    [sym_decimal] = ACTIONS(6344),
    [anon_sym_LPAREN] = ACTIONS(6346),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6344),
    [anon_sym_LBRACK] = ACTIONS(6346),
    [aux_sym_record_type_token1] = ACTIONS(6344),
    [aux_sym_basic_type_token21] = ACTIONS(6344),
    [aux_sym_basic_type_token22] = ACTIONS(6344),
    [aux_sym_basic_type_token48] = ACTIONS(6344),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6344),
    [anon_sym_POUNDif] = ACTIONS(6346),
    [anon_sym_POUNDIF] = ACTIONS(6346),
    [anon_sym_POUNDIf] = ACTIONS(6346),
    [anon_sym_not] = ACTIONS(6344),
    [anon_sym_NOT] = ACTIONS(6344),
    [anon_sym_Not] = ACTIONS(6344),
    [anon_sym_POUNDelse] = ACTIONS(6346),
    [anon_sym_POUNDELSE] = ACTIONS(6346),
    [anon_sym_POUNDElse] = ACTIONS(6346),
    [anon_sym_POUNDelse2] = ACTIONS(6346),
    [anon_sym_POUNDELSE2] = ACTIONS(6346),
    [anon_sym_POUNDElse2] = ACTIONS(6346),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6344),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6344),
    [anon_sym_PLUS] = ACTIONS(6346),
    [sym_datetime_literal] = ACTIONS(6346),
    [sym_date_literal] = ACTIONS(6344),
    [sym_time_literal] = ACTIONS(6344),
    [sym_biginteger_literal] = ACTIONS(6346),
    [anon_sym_if] = ACTIONS(6344),
    [anon_sym_IF] = ACTIONS(6344),
    [anon_sym_If] = ACTIONS(6344),
    [anon_sym_else] = ACTIONS(6344),
    [anon_sym_ELSE] = ACTIONS(6344),
    [anon_sym_Else] = ACTIONS(6344),
    [anon_sym_case] = ACTIONS(6344),
    [anon_sym_CASE] = ACTIONS(6344),
    [anon_sym_Case] = ACTIONS(6344),
    [anon_sym_for] = ACTIONS(6344),
    [anon_sym_FOR] = ACTIONS(6344),
    [anon_sym_For] = ACTIONS(6344),
    [anon_sym_foreach] = ACTIONS(6344),
    [anon_sym_FOREACH] = ACTIONS(6344),
    [anon_sym_Foreach] = ACTIONS(6344),
    [anon_sym_while] = ACTIONS(6344),
    [anon_sym_WHILE] = ACTIONS(6344),
    [anon_sym_While] = ACTIONS(6344),
    [anon_sym_repeat] = ACTIONS(6344),
    [anon_sym_REPEAT] = ACTIONS(6344),
    [anon_sym_Repeat] = ACTIONS(6344),
    [anon_sym_until] = ACTIONS(6344),
    [anon_sym_UNTIL] = ACTIONS(6344),
    [anon_sym_Until] = ACTIONS(6344),
    [anon_sym_exit] = ACTIONS(6344),
    [anon_sym_EXIT] = ACTIONS(6344),
    [anon_sym_Exit] = ACTIONS(6344),
    [anon_sym_continue] = ACTIONS(6344),
    [anon_sym_CONTINUE] = ACTIONS(6344),
    [anon_sym_Continue] = ACTIONS(6344),
    [anon_sym_break] = ACTIONS(6344),
    [anon_sym_BREAK] = ACTIONS(6344),
    [anon_sym_Break] = ACTIONS(6344),
    [anon_sym_with] = ACTIONS(6344),
    [anon_sym_WITH] = ACTIONS(6344),
    [anon_sym_With] = ACTIONS(6344),
    [sym_asserterror_keyword] = ACTIONS(6346),
    [sym_page_keyword] = ACTIONS(6344),
    [anon_sym_codeunit] = ACTIONS(6344),
    [anon_sym_CODEUNIT] = ACTIONS(6344),
    [anon_sym_Codeunit] = ACTIONS(6344),
    [anon_sym_CodeUnit] = ACTIONS(6344),
    [anon_sym_COdeunit] = ACTIONS(6344),
    [anon_sym_codeUnit] = ACTIONS(6344),
    [sym_report_keyword] = ACTIONS(6344),
    [sym_query_keyword] = ACTIONS(6344),
    [anon_sym_xmlport] = ACTIONS(6344),
    [anon_sym_XMLPORT] = ACTIONS(6344),
    [anon_sym_Xmlport] = ACTIONS(6344),
    [anon_sym_XMLport] = ACTIONS(6344),
    [anon_sym_XMLPort] = ACTIONS(6344),
    [anon_sym_XmlPort] = ACTIONS(6344),
    [anon_sym_enum] = ACTIONS(6344),
    [anon_sym_ENUM] = ACTIONS(6344),
    [anon_sym_Enum] = ACTIONS(6344),
    [anon_sym_eNUM] = ACTIONS(6344),
    [anon_sym_eNum] = ACTIONS(6344),
    [anon_sym_ENum] = ACTIONS(6344),
    [sym_quoted_identifier] = ACTIONS(6346),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6346),
    [sym_verbatim_string] = ACTIONS(6346),
    [sym_integer] = ACTIONS(6344),
    [sym_continue_as_identifier] = ACTIONS(6346),
    [sym_preproc_open] = ACTIONS(6346),
  },
  [STATE(2957)] = {
    [sym_identifier] = ACTIONS(6348),
    [anon_sym_SEMI] = ACTIONS(6350),
    [anon_sym_DASH] = ACTIONS(6350),
    [aux_sym_boolean_token1] = ACTIONS(6348),
    [aux_sym_boolean_token2] = ACTIONS(6348),
    [sym_decimal] = ACTIONS(6348),
    [anon_sym_LPAREN] = ACTIONS(6350),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6348),
    [anon_sym_LBRACK] = ACTIONS(6350),
    [aux_sym_record_type_token1] = ACTIONS(6348),
    [aux_sym_basic_type_token21] = ACTIONS(6348),
    [aux_sym_basic_type_token22] = ACTIONS(6348),
    [aux_sym_basic_type_token48] = ACTIONS(6348),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6348),
    [anon_sym_POUNDif] = ACTIONS(6350),
    [anon_sym_POUNDIF] = ACTIONS(6350),
    [anon_sym_POUNDIf] = ACTIONS(6350),
    [anon_sym_not] = ACTIONS(6348),
    [anon_sym_NOT] = ACTIONS(6348),
    [anon_sym_Not] = ACTIONS(6348),
    [anon_sym_POUNDelse] = ACTIONS(6350),
    [anon_sym_POUNDELSE] = ACTIONS(6350),
    [anon_sym_POUNDElse] = ACTIONS(6350),
    [anon_sym_POUNDelse2] = ACTIONS(6350),
    [anon_sym_POUNDELSE2] = ACTIONS(6350),
    [anon_sym_POUNDElse2] = ACTIONS(6350),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6348),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6348),
    [anon_sym_PLUS] = ACTIONS(6350),
    [sym_datetime_literal] = ACTIONS(6350),
    [sym_date_literal] = ACTIONS(6348),
    [sym_time_literal] = ACTIONS(6348),
    [sym_biginteger_literal] = ACTIONS(6350),
    [anon_sym_if] = ACTIONS(6348),
    [anon_sym_IF] = ACTIONS(6348),
    [anon_sym_If] = ACTIONS(6348),
    [anon_sym_else] = ACTIONS(6348),
    [anon_sym_ELSE] = ACTIONS(6348),
    [anon_sym_Else] = ACTIONS(6348),
    [anon_sym_case] = ACTIONS(6348),
    [anon_sym_CASE] = ACTIONS(6348),
    [anon_sym_Case] = ACTIONS(6348),
    [anon_sym_for] = ACTIONS(6348),
    [anon_sym_FOR] = ACTIONS(6348),
    [anon_sym_For] = ACTIONS(6348),
    [anon_sym_foreach] = ACTIONS(6348),
    [anon_sym_FOREACH] = ACTIONS(6348),
    [anon_sym_Foreach] = ACTIONS(6348),
    [anon_sym_while] = ACTIONS(6348),
    [anon_sym_WHILE] = ACTIONS(6348),
    [anon_sym_While] = ACTIONS(6348),
    [anon_sym_repeat] = ACTIONS(6348),
    [anon_sym_REPEAT] = ACTIONS(6348),
    [anon_sym_Repeat] = ACTIONS(6348),
    [anon_sym_until] = ACTIONS(6348),
    [anon_sym_UNTIL] = ACTIONS(6348),
    [anon_sym_Until] = ACTIONS(6348),
    [anon_sym_exit] = ACTIONS(6348),
    [anon_sym_EXIT] = ACTIONS(6348),
    [anon_sym_Exit] = ACTIONS(6348),
    [anon_sym_continue] = ACTIONS(6348),
    [anon_sym_CONTINUE] = ACTIONS(6348),
    [anon_sym_Continue] = ACTIONS(6348),
    [anon_sym_break] = ACTIONS(6348),
    [anon_sym_BREAK] = ACTIONS(6348),
    [anon_sym_Break] = ACTIONS(6348),
    [anon_sym_with] = ACTIONS(6348),
    [anon_sym_WITH] = ACTIONS(6348),
    [anon_sym_With] = ACTIONS(6348),
    [sym_asserterror_keyword] = ACTIONS(6350),
    [sym_page_keyword] = ACTIONS(6348),
    [anon_sym_codeunit] = ACTIONS(6348),
    [anon_sym_CODEUNIT] = ACTIONS(6348),
    [anon_sym_Codeunit] = ACTIONS(6348),
    [anon_sym_CodeUnit] = ACTIONS(6348),
    [anon_sym_COdeunit] = ACTIONS(6348),
    [anon_sym_codeUnit] = ACTIONS(6348),
    [sym_report_keyword] = ACTIONS(6348),
    [sym_query_keyword] = ACTIONS(6348),
    [anon_sym_xmlport] = ACTIONS(6348),
    [anon_sym_XMLPORT] = ACTIONS(6348),
    [anon_sym_Xmlport] = ACTIONS(6348),
    [anon_sym_XMLport] = ACTIONS(6348),
    [anon_sym_XMLPort] = ACTIONS(6348),
    [anon_sym_XmlPort] = ACTIONS(6348),
    [anon_sym_enum] = ACTIONS(6348),
    [anon_sym_ENUM] = ACTIONS(6348),
    [anon_sym_Enum] = ACTIONS(6348),
    [anon_sym_eNUM] = ACTIONS(6348),
    [anon_sym_eNum] = ACTIONS(6348),
    [anon_sym_ENum] = ACTIONS(6348),
    [sym_quoted_identifier] = ACTIONS(6350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6350),
    [sym_verbatim_string] = ACTIONS(6350),
    [sym_integer] = ACTIONS(6348),
    [sym_continue_as_identifier] = ACTIONS(6350),
    [sym_preproc_open] = ACTIONS(6350),
  },
  [STATE(2958)] = {
    [sym_identifier] = ACTIONS(6352),
    [anon_sym_SEMI] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6354),
    [aux_sym_boolean_token1] = ACTIONS(6352),
    [aux_sym_boolean_token2] = ACTIONS(6352),
    [sym_decimal] = ACTIONS(6352),
    [anon_sym_LPAREN] = ACTIONS(6354),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6352),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [aux_sym_record_type_token1] = ACTIONS(6352),
    [aux_sym_basic_type_token21] = ACTIONS(6352),
    [aux_sym_basic_type_token22] = ACTIONS(6352),
    [aux_sym_basic_type_token48] = ACTIONS(6352),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6352),
    [anon_sym_POUNDif] = ACTIONS(6354),
    [anon_sym_POUNDIF] = ACTIONS(6354),
    [anon_sym_POUNDIf] = ACTIONS(6354),
    [anon_sym_not] = ACTIONS(6352),
    [anon_sym_NOT] = ACTIONS(6352),
    [anon_sym_Not] = ACTIONS(6352),
    [anon_sym_POUNDelse] = ACTIONS(6354),
    [anon_sym_POUNDELSE] = ACTIONS(6354),
    [anon_sym_POUNDElse] = ACTIONS(6354),
    [anon_sym_POUNDelse2] = ACTIONS(6354),
    [anon_sym_POUNDELSE2] = ACTIONS(6354),
    [anon_sym_POUNDElse2] = ACTIONS(6354),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6352),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6354),
    [sym_datetime_literal] = ACTIONS(6354),
    [sym_date_literal] = ACTIONS(6352),
    [sym_time_literal] = ACTIONS(6352),
    [sym_biginteger_literal] = ACTIONS(6354),
    [anon_sym_if] = ACTIONS(6352),
    [anon_sym_IF] = ACTIONS(6352),
    [anon_sym_If] = ACTIONS(6352),
    [anon_sym_else] = ACTIONS(6352),
    [anon_sym_ELSE] = ACTIONS(6352),
    [anon_sym_Else] = ACTIONS(6352),
    [anon_sym_case] = ACTIONS(6352),
    [anon_sym_CASE] = ACTIONS(6352),
    [anon_sym_Case] = ACTIONS(6352),
    [anon_sym_for] = ACTIONS(6352),
    [anon_sym_FOR] = ACTIONS(6352),
    [anon_sym_For] = ACTIONS(6352),
    [anon_sym_foreach] = ACTIONS(6352),
    [anon_sym_FOREACH] = ACTIONS(6352),
    [anon_sym_Foreach] = ACTIONS(6352),
    [anon_sym_while] = ACTIONS(6352),
    [anon_sym_WHILE] = ACTIONS(6352),
    [anon_sym_While] = ACTIONS(6352),
    [anon_sym_repeat] = ACTIONS(6352),
    [anon_sym_REPEAT] = ACTIONS(6352),
    [anon_sym_Repeat] = ACTIONS(6352),
    [anon_sym_until] = ACTIONS(6352),
    [anon_sym_UNTIL] = ACTIONS(6352),
    [anon_sym_Until] = ACTIONS(6352),
    [anon_sym_exit] = ACTIONS(6352),
    [anon_sym_EXIT] = ACTIONS(6352),
    [anon_sym_Exit] = ACTIONS(6352),
    [anon_sym_continue] = ACTIONS(6352),
    [anon_sym_CONTINUE] = ACTIONS(6352),
    [anon_sym_Continue] = ACTIONS(6352),
    [anon_sym_break] = ACTIONS(6352),
    [anon_sym_BREAK] = ACTIONS(6352),
    [anon_sym_Break] = ACTIONS(6352),
    [anon_sym_with] = ACTIONS(6352),
    [anon_sym_WITH] = ACTIONS(6352),
    [anon_sym_With] = ACTIONS(6352),
    [sym_asserterror_keyword] = ACTIONS(6354),
    [sym_page_keyword] = ACTIONS(6352),
    [anon_sym_codeunit] = ACTIONS(6352),
    [anon_sym_CODEUNIT] = ACTIONS(6352),
    [anon_sym_Codeunit] = ACTIONS(6352),
    [anon_sym_CodeUnit] = ACTIONS(6352),
    [anon_sym_COdeunit] = ACTIONS(6352),
    [anon_sym_codeUnit] = ACTIONS(6352),
    [sym_report_keyword] = ACTIONS(6352),
    [sym_query_keyword] = ACTIONS(6352),
    [anon_sym_xmlport] = ACTIONS(6352),
    [anon_sym_XMLPORT] = ACTIONS(6352),
    [anon_sym_Xmlport] = ACTIONS(6352),
    [anon_sym_XMLport] = ACTIONS(6352),
    [anon_sym_XMLPort] = ACTIONS(6352),
    [anon_sym_XmlPort] = ACTIONS(6352),
    [anon_sym_enum] = ACTIONS(6352),
    [anon_sym_ENUM] = ACTIONS(6352),
    [anon_sym_Enum] = ACTIONS(6352),
    [anon_sym_eNUM] = ACTIONS(6352),
    [anon_sym_eNum] = ACTIONS(6352),
    [anon_sym_ENum] = ACTIONS(6352),
    [sym_quoted_identifier] = ACTIONS(6354),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6354),
    [sym_verbatim_string] = ACTIONS(6354),
    [sym_integer] = ACTIONS(6352),
    [sym_continue_as_identifier] = ACTIONS(6354),
    [sym_preproc_open] = ACTIONS(6354),
  },
  [STATE(2959)] = {
    [sym_identifier] = ACTIONS(6042),
    [anon_sym_SEMI] = ACTIONS(6044),
    [anon_sym_DASH] = ACTIONS(6044),
    [aux_sym_boolean_token1] = ACTIONS(6042),
    [aux_sym_boolean_token2] = ACTIONS(6042),
    [sym_decimal] = ACTIONS(6042),
    [anon_sym_LPAREN] = ACTIONS(6044),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6042),
    [anon_sym_LBRACK] = ACTIONS(6044),
    [aux_sym_record_type_token1] = ACTIONS(6042),
    [aux_sym_basic_type_token21] = ACTIONS(6042),
    [aux_sym_basic_type_token22] = ACTIONS(6042),
    [aux_sym_basic_type_token48] = ACTIONS(6042),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6042),
    [anon_sym_POUNDif] = ACTIONS(6044),
    [anon_sym_POUNDIF] = ACTIONS(6044),
    [anon_sym_POUNDIf] = ACTIONS(6044),
    [anon_sym_not] = ACTIONS(6042),
    [anon_sym_NOT] = ACTIONS(6042),
    [anon_sym_Not] = ACTIONS(6042),
    [anon_sym_POUNDelse] = ACTIONS(6044),
    [anon_sym_POUNDELSE] = ACTIONS(6044),
    [anon_sym_POUNDElse] = ACTIONS(6044),
    [anon_sym_POUNDelse2] = ACTIONS(6044),
    [anon_sym_POUNDELSE2] = ACTIONS(6044),
    [anon_sym_POUNDElse2] = ACTIONS(6044),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6042),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6042),
    [anon_sym_PLUS] = ACTIONS(6044),
    [sym_datetime_literal] = ACTIONS(6044),
    [sym_date_literal] = ACTIONS(6042),
    [sym_time_literal] = ACTIONS(6042),
    [sym_biginteger_literal] = ACTIONS(6044),
    [anon_sym_if] = ACTIONS(6042),
    [anon_sym_IF] = ACTIONS(6042),
    [anon_sym_If] = ACTIONS(6042),
    [anon_sym_else] = ACTIONS(6042),
    [anon_sym_ELSE] = ACTIONS(6042),
    [anon_sym_Else] = ACTIONS(6042),
    [anon_sym_case] = ACTIONS(6042),
    [anon_sym_CASE] = ACTIONS(6042),
    [anon_sym_Case] = ACTIONS(6042),
    [anon_sym_for] = ACTIONS(6042),
    [anon_sym_FOR] = ACTIONS(6042),
    [anon_sym_For] = ACTIONS(6042),
    [anon_sym_foreach] = ACTIONS(6042),
    [anon_sym_FOREACH] = ACTIONS(6042),
    [anon_sym_Foreach] = ACTIONS(6042),
    [anon_sym_while] = ACTIONS(6042),
    [anon_sym_WHILE] = ACTIONS(6042),
    [anon_sym_While] = ACTIONS(6042),
    [anon_sym_repeat] = ACTIONS(6042),
    [anon_sym_REPEAT] = ACTIONS(6042),
    [anon_sym_Repeat] = ACTIONS(6042),
    [anon_sym_until] = ACTIONS(6042),
    [anon_sym_UNTIL] = ACTIONS(6042),
    [anon_sym_Until] = ACTIONS(6042),
    [anon_sym_exit] = ACTIONS(6042),
    [anon_sym_EXIT] = ACTIONS(6042),
    [anon_sym_Exit] = ACTIONS(6042),
    [anon_sym_continue] = ACTIONS(6042),
    [anon_sym_CONTINUE] = ACTIONS(6042),
    [anon_sym_Continue] = ACTIONS(6042),
    [anon_sym_break] = ACTIONS(6042),
    [anon_sym_BREAK] = ACTIONS(6042),
    [anon_sym_Break] = ACTIONS(6042),
    [anon_sym_with] = ACTIONS(6042),
    [anon_sym_WITH] = ACTIONS(6042),
    [anon_sym_With] = ACTIONS(6042),
    [sym_asserterror_keyword] = ACTIONS(6044),
    [sym_page_keyword] = ACTIONS(6042),
    [anon_sym_codeunit] = ACTIONS(6042),
    [anon_sym_CODEUNIT] = ACTIONS(6042),
    [anon_sym_Codeunit] = ACTIONS(6042),
    [anon_sym_CodeUnit] = ACTIONS(6042),
    [anon_sym_COdeunit] = ACTIONS(6042),
    [anon_sym_codeUnit] = ACTIONS(6042),
    [sym_report_keyword] = ACTIONS(6042),
    [sym_query_keyword] = ACTIONS(6042),
    [anon_sym_xmlport] = ACTIONS(6042),
    [anon_sym_XMLPORT] = ACTIONS(6042),
    [anon_sym_Xmlport] = ACTIONS(6042),
    [anon_sym_XMLport] = ACTIONS(6042),
    [anon_sym_XMLPort] = ACTIONS(6042),
    [anon_sym_XmlPort] = ACTIONS(6042),
    [anon_sym_enum] = ACTIONS(6042),
    [anon_sym_ENUM] = ACTIONS(6042),
    [anon_sym_Enum] = ACTIONS(6042),
    [anon_sym_eNUM] = ACTIONS(6042),
    [anon_sym_eNum] = ACTIONS(6042),
    [anon_sym_ENum] = ACTIONS(6042),
    [sym_quoted_identifier] = ACTIONS(6044),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6044),
    [sym_verbatim_string] = ACTIONS(6044),
    [sym_integer] = ACTIONS(6042),
    [sym_continue_as_identifier] = ACTIONS(6044),
    [sym_preproc_open] = ACTIONS(6044),
  },
  [STATE(2960)] = {
    [sym_identifier] = ACTIONS(6042),
    [anon_sym_SEMI] = ACTIONS(6044),
    [anon_sym_DASH] = ACTIONS(6044),
    [aux_sym_boolean_token1] = ACTIONS(6042),
    [aux_sym_boolean_token2] = ACTIONS(6042),
    [sym_decimal] = ACTIONS(6042),
    [anon_sym_LPAREN] = ACTIONS(6044),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6042),
    [anon_sym_LBRACK] = ACTIONS(6044),
    [aux_sym_record_type_token1] = ACTIONS(6042),
    [aux_sym_basic_type_token21] = ACTIONS(6042),
    [aux_sym_basic_type_token22] = ACTIONS(6042),
    [aux_sym_basic_type_token48] = ACTIONS(6042),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6042),
    [anon_sym_POUNDif] = ACTIONS(6044),
    [anon_sym_POUNDIF] = ACTIONS(6044),
    [anon_sym_POUNDIf] = ACTIONS(6044),
    [anon_sym_not] = ACTIONS(6042),
    [anon_sym_NOT] = ACTIONS(6042),
    [anon_sym_Not] = ACTIONS(6042),
    [anon_sym_POUNDelse] = ACTIONS(6044),
    [anon_sym_POUNDELSE] = ACTIONS(6044),
    [anon_sym_POUNDElse] = ACTIONS(6044),
    [anon_sym_POUNDelse2] = ACTIONS(6044),
    [anon_sym_POUNDELSE2] = ACTIONS(6044),
    [anon_sym_POUNDElse2] = ACTIONS(6044),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6042),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6042),
    [anon_sym_PLUS] = ACTIONS(6044),
    [sym_datetime_literal] = ACTIONS(6044),
    [sym_date_literal] = ACTIONS(6042),
    [sym_time_literal] = ACTIONS(6042),
    [sym_biginteger_literal] = ACTIONS(6044),
    [anon_sym_if] = ACTIONS(6042),
    [anon_sym_IF] = ACTIONS(6042),
    [anon_sym_If] = ACTIONS(6042),
    [anon_sym_else] = ACTIONS(6042),
    [anon_sym_ELSE] = ACTIONS(6042),
    [anon_sym_Else] = ACTIONS(6042),
    [anon_sym_case] = ACTIONS(6042),
    [anon_sym_CASE] = ACTIONS(6042),
    [anon_sym_Case] = ACTIONS(6042),
    [anon_sym_for] = ACTIONS(6042),
    [anon_sym_FOR] = ACTIONS(6042),
    [anon_sym_For] = ACTIONS(6042),
    [anon_sym_foreach] = ACTIONS(6042),
    [anon_sym_FOREACH] = ACTIONS(6042),
    [anon_sym_Foreach] = ACTIONS(6042),
    [anon_sym_while] = ACTIONS(6042),
    [anon_sym_WHILE] = ACTIONS(6042),
    [anon_sym_While] = ACTIONS(6042),
    [anon_sym_repeat] = ACTIONS(6042),
    [anon_sym_REPEAT] = ACTIONS(6042),
    [anon_sym_Repeat] = ACTIONS(6042),
    [anon_sym_until] = ACTIONS(6042),
    [anon_sym_UNTIL] = ACTIONS(6042),
    [anon_sym_Until] = ACTIONS(6042),
    [anon_sym_exit] = ACTIONS(6042),
    [anon_sym_EXIT] = ACTIONS(6042),
    [anon_sym_Exit] = ACTIONS(6042),
    [anon_sym_continue] = ACTIONS(6042),
    [anon_sym_CONTINUE] = ACTIONS(6042),
    [anon_sym_Continue] = ACTIONS(6042),
    [anon_sym_break] = ACTIONS(6042),
    [anon_sym_BREAK] = ACTIONS(6042),
    [anon_sym_Break] = ACTIONS(6042),
    [anon_sym_with] = ACTIONS(6042),
    [anon_sym_WITH] = ACTIONS(6042),
    [anon_sym_With] = ACTIONS(6042),
    [sym_asserterror_keyword] = ACTIONS(6044),
    [sym_page_keyword] = ACTIONS(6042),
    [anon_sym_codeunit] = ACTIONS(6042),
    [anon_sym_CODEUNIT] = ACTIONS(6042),
    [anon_sym_Codeunit] = ACTIONS(6042),
    [anon_sym_CodeUnit] = ACTIONS(6042),
    [anon_sym_COdeunit] = ACTIONS(6042),
    [anon_sym_codeUnit] = ACTIONS(6042),
    [sym_report_keyword] = ACTIONS(6042),
    [sym_query_keyword] = ACTIONS(6042),
    [anon_sym_xmlport] = ACTIONS(6042),
    [anon_sym_XMLPORT] = ACTIONS(6042),
    [anon_sym_Xmlport] = ACTIONS(6042),
    [anon_sym_XMLport] = ACTIONS(6042),
    [anon_sym_XMLPort] = ACTIONS(6042),
    [anon_sym_XmlPort] = ACTIONS(6042),
    [anon_sym_enum] = ACTIONS(6042),
    [anon_sym_ENUM] = ACTIONS(6042),
    [anon_sym_Enum] = ACTIONS(6042),
    [anon_sym_eNUM] = ACTIONS(6042),
    [anon_sym_eNum] = ACTIONS(6042),
    [anon_sym_ENum] = ACTIONS(6042),
    [sym_quoted_identifier] = ACTIONS(6044),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6044),
    [sym_verbatim_string] = ACTIONS(6044),
    [sym_integer] = ACTIONS(6042),
    [sym_continue_as_identifier] = ACTIONS(6044),
    [sym_preproc_open] = ACTIONS(6044),
  },
  [STATE(2961)] = {
    [sym_identifier] = ACTIONS(5497),
    [anon_sym_SEMI] = ACTIONS(7199),
    [anon_sym_DASH] = ACTIONS(5501),
    [aux_sym_boolean_token1] = ACTIONS(5497),
    [aux_sym_boolean_token2] = ACTIONS(5497),
    [sym_decimal] = ACTIONS(5497),
    [anon_sym_LPAREN] = ACTIONS(5501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5497),
    [anon_sym_LBRACK] = ACTIONS(5501),
    [aux_sym_record_type_token1] = ACTIONS(5497),
    [aux_sym_basic_type_token21] = ACTIONS(5497),
    [aux_sym_basic_type_token22] = ACTIONS(5497),
    [aux_sym_basic_type_token48] = ACTIONS(5497),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5497),
    [anon_sym_POUNDif] = ACTIONS(5501),
    [anon_sym_POUNDIF] = ACTIONS(5501),
    [anon_sym_POUNDIf] = ACTIONS(5501),
    [anon_sym_not] = ACTIONS(5497),
    [anon_sym_NOT] = ACTIONS(5497),
    [anon_sym_Not] = ACTIONS(5497),
    [anon_sym_POUNDelse] = ACTIONS(5501),
    [anon_sym_POUNDELSE] = ACTIONS(5501),
    [anon_sym_POUNDElse] = ACTIONS(5501),
    [anon_sym_POUNDelse2] = ACTIONS(5501),
    [anon_sym_POUNDELSE2] = ACTIONS(5501),
    [anon_sym_POUNDElse2] = ACTIONS(5501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5497),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5497),
    [anon_sym_PLUS] = ACTIONS(5501),
    [sym_datetime_literal] = ACTIONS(5501),
    [sym_date_literal] = ACTIONS(5497),
    [sym_time_literal] = ACTIONS(5497),
    [sym_biginteger_literal] = ACTIONS(5501),
    [anon_sym_if] = ACTIONS(5497),
    [anon_sym_IF] = ACTIONS(5497),
    [anon_sym_If] = ACTIONS(5497),
    [anon_sym_else] = ACTIONS(5497),
    [anon_sym_ELSE] = ACTIONS(5497),
    [anon_sym_Else] = ACTIONS(5497),
    [anon_sym_case] = ACTIONS(5497),
    [anon_sym_CASE] = ACTIONS(5497),
    [anon_sym_Case] = ACTIONS(5497),
    [anon_sym_for] = ACTIONS(5497),
    [anon_sym_FOR] = ACTIONS(5497),
    [anon_sym_For] = ACTIONS(5497),
    [anon_sym_foreach] = ACTIONS(5497),
    [anon_sym_FOREACH] = ACTIONS(5497),
    [anon_sym_Foreach] = ACTIONS(5497),
    [anon_sym_while] = ACTIONS(5497),
    [anon_sym_WHILE] = ACTIONS(5497),
    [anon_sym_While] = ACTIONS(5497),
    [anon_sym_repeat] = ACTIONS(5497),
    [anon_sym_REPEAT] = ACTIONS(5497),
    [anon_sym_Repeat] = ACTIONS(5497),
    [anon_sym_until] = ACTIONS(5497),
    [anon_sym_UNTIL] = ACTIONS(5497),
    [anon_sym_Until] = ACTIONS(5497),
    [anon_sym_exit] = ACTIONS(5497),
    [anon_sym_EXIT] = ACTIONS(5497),
    [anon_sym_Exit] = ACTIONS(5497),
    [anon_sym_continue] = ACTIONS(5497),
    [anon_sym_CONTINUE] = ACTIONS(5497),
    [anon_sym_Continue] = ACTIONS(5497),
    [anon_sym_break] = ACTIONS(5497),
    [anon_sym_BREAK] = ACTIONS(5497),
    [anon_sym_Break] = ACTIONS(5497),
    [anon_sym_with] = ACTIONS(5497),
    [anon_sym_WITH] = ACTIONS(5497),
    [anon_sym_With] = ACTIONS(5497),
    [sym_asserterror_keyword] = ACTIONS(5501),
    [sym_page_keyword] = ACTIONS(5497),
    [anon_sym_codeunit] = ACTIONS(5497),
    [anon_sym_CODEUNIT] = ACTIONS(5497),
    [anon_sym_Codeunit] = ACTIONS(5497),
    [anon_sym_CodeUnit] = ACTIONS(5497),
    [anon_sym_COdeunit] = ACTIONS(5497),
    [anon_sym_codeUnit] = ACTIONS(5497),
    [sym_report_keyword] = ACTIONS(5497),
    [sym_query_keyword] = ACTIONS(5497),
    [anon_sym_xmlport] = ACTIONS(5497),
    [anon_sym_XMLPORT] = ACTIONS(5497),
    [anon_sym_Xmlport] = ACTIONS(5497),
    [anon_sym_XMLport] = ACTIONS(5497),
    [anon_sym_XMLPort] = ACTIONS(5497),
    [anon_sym_XmlPort] = ACTIONS(5497),
    [anon_sym_enum] = ACTIONS(5497),
    [anon_sym_ENUM] = ACTIONS(5497),
    [anon_sym_Enum] = ACTIONS(5497),
    [anon_sym_eNUM] = ACTIONS(5497),
    [anon_sym_eNum] = ACTIONS(5497),
    [anon_sym_ENum] = ACTIONS(5497),
    [sym_quoted_identifier] = ACTIONS(5501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5501),
    [sym_verbatim_string] = ACTIONS(5501),
    [sym_integer] = ACTIONS(5497),
    [sym_continue_as_identifier] = ACTIONS(5501),
    [sym_preproc_open] = ACTIONS(5501),
  },
  [STATE(2962)] = {
    [sym_identifier] = ACTIONS(5497),
    [anon_sym_SEMI] = ACTIONS(7201),
    [anon_sym_DASH] = ACTIONS(5501),
    [aux_sym_boolean_token1] = ACTIONS(5497),
    [aux_sym_boolean_token2] = ACTIONS(5497),
    [sym_decimal] = ACTIONS(5497),
    [anon_sym_LPAREN] = ACTIONS(5501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5497),
    [anon_sym_LBRACK] = ACTIONS(5501),
    [aux_sym_record_type_token1] = ACTIONS(5497),
    [aux_sym_basic_type_token21] = ACTIONS(5497),
    [aux_sym_basic_type_token22] = ACTIONS(5497),
    [aux_sym_basic_type_token48] = ACTIONS(5497),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5497),
    [anon_sym_POUNDif] = ACTIONS(5501),
    [anon_sym_POUNDIF] = ACTIONS(5501),
    [anon_sym_POUNDIf] = ACTIONS(5501),
    [anon_sym_not] = ACTIONS(5497),
    [anon_sym_NOT] = ACTIONS(5497),
    [anon_sym_Not] = ACTIONS(5497),
    [anon_sym_POUNDelse] = ACTIONS(5501),
    [anon_sym_POUNDELSE] = ACTIONS(5501),
    [anon_sym_POUNDElse] = ACTIONS(5501),
    [anon_sym_POUNDelse2] = ACTIONS(5501),
    [anon_sym_POUNDELSE2] = ACTIONS(5501),
    [anon_sym_POUNDElse2] = ACTIONS(5501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5497),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5497),
    [anon_sym_PLUS] = ACTIONS(5501),
    [sym_datetime_literal] = ACTIONS(5501),
    [sym_date_literal] = ACTIONS(5497),
    [sym_time_literal] = ACTIONS(5497),
    [sym_biginteger_literal] = ACTIONS(5501),
    [anon_sym_if] = ACTIONS(5497),
    [anon_sym_IF] = ACTIONS(5497),
    [anon_sym_If] = ACTIONS(5497),
    [anon_sym_else] = ACTIONS(5497),
    [anon_sym_ELSE] = ACTIONS(5497),
    [anon_sym_Else] = ACTIONS(5497),
    [anon_sym_case] = ACTIONS(5497),
    [anon_sym_CASE] = ACTIONS(5497),
    [anon_sym_Case] = ACTIONS(5497),
    [anon_sym_for] = ACTIONS(5497),
    [anon_sym_FOR] = ACTIONS(5497),
    [anon_sym_For] = ACTIONS(5497),
    [anon_sym_foreach] = ACTIONS(5497),
    [anon_sym_FOREACH] = ACTIONS(5497),
    [anon_sym_Foreach] = ACTIONS(5497),
    [anon_sym_while] = ACTIONS(5497),
    [anon_sym_WHILE] = ACTIONS(5497),
    [anon_sym_While] = ACTIONS(5497),
    [anon_sym_repeat] = ACTIONS(5497),
    [anon_sym_REPEAT] = ACTIONS(5497),
    [anon_sym_Repeat] = ACTIONS(5497),
    [anon_sym_until] = ACTIONS(5497),
    [anon_sym_UNTIL] = ACTIONS(5497),
    [anon_sym_Until] = ACTIONS(5497),
    [anon_sym_exit] = ACTIONS(5497),
    [anon_sym_EXIT] = ACTIONS(5497),
    [anon_sym_Exit] = ACTIONS(5497),
    [anon_sym_continue] = ACTIONS(5497),
    [anon_sym_CONTINUE] = ACTIONS(5497),
    [anon_sym_Continue] = ACTIONS(5497),
    [anon_sym_break] = ACTIONS(5497),
    [anon_sym_BREAK] = ACTIONS(5497),
    [anon_sym_Break] = ACTIONS(5497),
    [anon_sym_with] = ACTIONS(5497),
    [anon_sym_WITH] = ACTIONS(5497),
    [anon_sym_With] = ACTIONS(5497),
    [sym_asserterror_keyword] = ACTIONS(5501),
    [sym_page_keyword] = ACTIONS(5497),
    [anon_sym_codeunit] = ACTIONS(5497),
    [anon_sym_CODEUNIT] = ACTIONS(5497),
    [anon_sym_Codeunit] = ACTIONS(5497),
    [anon_sym_CodeUnit] = ACTIONS(5497),
    [anon_sym_COdeunit] = ACTIONS(5497),
    [anon_sym_codeUnit] = ACTIONS(5497),
    [sym_report_keyword] = ACTIONS(5497),
    [sym_query_keyword] = ACTIONS(5497),
    [anon_sym_xmlport] = ACTIONS(5497),
    [anon_sym_XMLPORT] = ACTIONS(5497),
    [anon_sym_Xmlport] = ACTIONS(5497),
    [anon_sym_XMLport] = ACTIONS(5497),
    [anon_sym_XMLPort] = ACTIONS(5497),
    [anon_sym_XmlPort] = ACTIONS(5497),
    [anon_sym_enum] = ACTIONS(5497),
    [anon_sym_ENUM] = ACTIONS(5497),
    [anon_sym_Enum] = ACTIONS(5497),
    [anon_sym_eNUM] = ACTIONS(5497),
    [anon_sym_eNum] = ACTIONS(5497),
    [anon_sym_ENum] = ACTIONS(5497),
    [sym_quoted_identifier] = ACTIONS(5501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5501),
    [sym_verbatim_string] = ACTIONS(5501),
    [sym_integer] = ACTIONS(5497),
    [sym_continue_as_identifier] = ACTIONS(5501),
    [sym_preproc_open] = ACTIONS(5501),
  },
  [STATE(2963)] = {
    [sym_identifier] = ACTIONS(5505),
    [anon_sym_SEMI] = ACTIONS(5507),
    [anon_sym_DASH] = ACTIONS(5507),
    [aux_sym_boolean_token1] = ACTIONS(5505),
    [aux_sym_boolean_token2] = ACTIONS(5505),
    [sym_decimal] = ACTIONS(5505),
    [anon_sym_LPAREN] = ACTIONS(5507),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5505),
    [anon_sym_LBRACK] = ACTIONS(5507),
    [aux_sym_record_type_token1] = ACTIONS(5505),
    [aux_sym_basic_type_token21] = ACTIONS(5505),
    [aux_sym_basic_type_token22] = ACTIONS(5505),
    [aux_sym_basic_type_token48] = ACTIONS(5505),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5505),
    [anon_sym_POUNDif] = ACTIONS(5507),
    [anon_sym_POUNDIF] = ACTIONS(5507),
    [anon_sym_POUNDIf] = ACTIONS(5507),
    [anon_sym_not] = ACTIONS(5505),
    [anon_sym_NOT] = ACTIONS(5505),
    [anon_sym_Not] = ACTIONS(5505),
    [anon_sym_POUNDelse] = ACTIONS(5507),
    [anon_sym_POUNDELSE] = ACTIONS(5507),
    [anon_sym_POUNDElse] = ACTIONS(5507),
    [anon_sym_POUNDelse2] = ACTIONS(5507),
    [anon_sym_POUNDELSE2] = ACTIONS(5507),
    [anon_sym_POUNDElse2] = ACTIONS(5507),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5505),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5505),
    [anon_sym_PLUS] = ACTIONS(5507),
    [sym_datetime_literal] = ACTIONS(5507),
    [sym_date_literal] = ACTIONS(5505),
    [sym_time_literal] = ACTIONS(5505),
    [sym_biginteger_literal] = ACTIONS(5507),
    [anon_sym_if] = ACTIONS(5505),
    [anon_sym_IF] = ACTIONS(5505),
    [anon_sym_If] = ACTIONS(5505),
    [anon_sym_else] = ACTIONS(5505),
    [anon_sym_ELSE] = ACTIONS(5505),
    [anon_sym_Else] = ACTIONS(5505),
    [anon_sym_case] = ACTIONS(5505),
    [anon_sym_CASE] = ACTIONS(5505),
    [anon_sym_Case] = ACTIONS(5505),
    [anon_sym_for] = ACTIONS(5505),
    [anon_sym_FOR] = ACTIONS(5505),
    [anon_sym_For] = ACTIONS(5505),
    [anon_sym_foreach] = ACTIONS(5505),
    [anon_sym_FOREACH] = ACTIONS(5505),
    [anon_sym_Foreach] = ACTIONS(5505),
    [anon_sym_while] = ACTIONS(5505),
    [anon_sym_WHILE] = ACTIONS(5505),
    [anon_sym_While] = ACTIONS(5505),
    [anon_sym_repeat] = ACTIONS(5505),
    [anon_sym_REPEAT] = ACTIONS(5505),
    [anon_sym_Repeat] = ACTIONS(5505),
    [anon_sym_until] = ACTIONS(5505),
    [anon_sym_UNTIL] = ACTIONS(5505),
    [anon_sym_Until] = ACTIONS(5505),
    [anon_sym_exit] = ACTIONS(5505),
    [anon_sym_EXIT] = ACTIONS(5505),
    [anon_sym_Exit] = ACTIONS(5505),
    [anon_sym_continue] = ACTIONS(5505),
    [anon_sym_CONTINUE] = ACTIONS(5505),
    [anon_sym_Continue] = ACTIONS(5505),
    [anon_sym_break] = ACTIONS(5505),
    [anon_sym_BREAK] = ACTIONS(5505),
    [anon_sym_Break] = ACTIONS(5505),
    [anon_sym_with] = ACTIONS(5505),
    [anon_sym_WITH] = ACTIONS(5505),
    [anon_sym_With] = ACTIONS(5505),
    [sym_asserterror_keyword] = ACTIONS(5507),
    [sym_page_keyword] = ACTIONS(5505),
    [anon_sym_codeunit] = ACTIONS(5505),
    [anon_sym_CODEUNIT] = ACTIONS(5505),
    [anon_sym_Codeunit] = ACTIONS(5505),
    [anon_sym_CodeUnit] = ACTIONS(5505),
    [anon_sym_COdeunit] = ACTIONS(5505),
    [anon_sym_codeUnit] = ACTIONS(5505),
    [sym_report_keyword] = ACTIONS(5505),
    [sym_query_keyword] = ACTIONS(5505),
    [anon_sym_xmlport] = ACTIONS(5505),
    [anon_sym_XMLPORT] = ACTIONS(5505),
    [anon_sym_Xmlport] = ACTIONS(5505),
    [anon_sym_XMLport] = ACTIONS(5505),
    [anon_sym_XMLPort] = ACTIONS(5505),
    [anon_sym_XmlPort] = ACTIONS(5505),
    [anon_sym_enum] = ACTIONS(5505),
    [anon_sym_ENUM] = ACTIONS(5505),
    [anon_sym_Enum] = ACTIONS(5505),
    [anon_sym_eNUM] = ACTIONS(5505),
    [anon_sym_eNum] = ACTIONS(5505),
    [anon_sym_ENum] = ACTIONS(5505),
    [sym_quoted_identifier] = ACTIONS(5507),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5507),
    [sym_verbatim_string] = ACTIONS(5507),
    [sym_integer] = ACTIONS(5505),
    [sym_continue_as_identifier] = ACTIONS(5507),
    [sym_preproc_open] = ACTIONS(5507),
  },
  [STATE(2964)] = {
    [sym_identifier] = ACTIONS(5509),
    [anon_sym_SEMI] = ACTIONS(5511),
    [anon_sym_DASH] = ACTIONS(5511),
    [aux_sym_boolean_token1] = ACTIONS(5509),
    [aux_sym_boolean_token2] = ACTIONS(5509),
    [sym_decimal] = ACTIONS(5509),
    [anon_sym_LPAREN] = ACTIONS(5511),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5509),
    [anon_sym_LBRACK] = ACTIONS(5511),
    [aux_sym_record_type_token1] = ACTIONS(5509),
    [aux_sym_basic_type_token21] = ACTIONS(5509),
    [aux_sym_basic_type_token22] = ACTIONS(5509),
    [aux_sym_basic_type_token48] = ACTIONS(5509),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5509),
    [anon_sym_POUNDif] = ACTIONS(5511),
    [anon_sym_POUNDIF] = ACTIONS(5511),
    [anon_sym_POUNDIf] = ACTIONS(5511),
    [anon_sym_not] = ACTIONS(5509),
    [anon_sym_NOT] = ACTIONS(5509),
    [anon_sym_Not] = ACTIONS(5509),
    [anon_sym_POUNDelse] = ACTIONS(5511),
    [anon_sym_POUNDELSE] = ACTIONS(5511),
    [anon_sym_POUNDElse] = ACTIONS(5511),
    [anon_sym_POUNDelse2] = ACTIONS(5511),
    [anon_sym_POUNDELSE2] = ACTIONS(5511),
    [anon_sym_POUNDElse2] = ACTIONS(5511),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5509),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5509),
    [anon_sym_PLUS] = ACTIONS(5511),
    [sym_datetime_literal] = ACTIONS(5511),
    [sym_date_literal] = ACTIONS(5509),
    [sym_time_literal] = ACTIONS(5509),
    [sym_biginteger_literal] = ACTIONS(5511),
    [anon_sym_if] = ACTIONS(5509),
    [anon_sym_IF] = ACTIONS(5509),
    [anon_sym_If] = ACTIONS(5509),
    [anon_sym_else] = ACTIONS(5509),
    [anon_sym_ELSE] = ACTIONS(5509),
    [anon_sym_Else] = ACTIONS(5509),
    [anon_sym_case] = ACTIONS(5509),
    [anon_sym_CASE] = ACTIONS(5509),
    [anon_sym_Case] = ACTIONS(5509),
    [anon_sym_for] = ACTIONS(5509),
    [anon_sym_FOR] = ACTIONS(5509),
    [anon_sym_For] = ACTIONS(5509),
    [anon_sym_foreach] = ACTIONS(5509),
    [anon_sym_FOREACH] = ACTIONS(5509),
    [anon_sym_Foreach] = ACTIONS(5509),
    [anon_sym_while] = ACTIONS(5509),
    [anon_sym_WHILE] = ACTIONS(5509),
    [anon_sym_While] = ACTIONS(5509),
    [anon_sym_repeat] = ACTIONS(5509),
    [anon_sym_REPEAT] = ACTIONS(5509),
    [anon_sym_Repeat] = ACTIONS(5509),
    [anon_sym_until] = ACTIONS(5509),
    [anon_sym_UNTIL] = ACTIONS(5509),
    [anon_sym_Until] = ACTIONS(5509),
    [anon_sym_exit] = ACTIONS(5509),
    [anon_sym_EXIT] = ACTIONS(5509),
    [anon_sym_Exit] = ACTIONS(5509),
    [anon_sym_continue] = ACTIONS(5509),
    [anon_sym_CONTINUE] = ACTIONS(5509),
    [anon_sym_Continue] = ACTIONS(5509),
    [anon_sym_break] = ACTIONS(5509),
    [anon_sym_BREAK] = ACTIONS(5509),
    [anon_sym_Break] = ACTIONS(5509),
    [anon_sym_with] = ACTIONS(5509),
    [anon_sym_WITH] = ACTIONS(5509),
    [anon_sym_With] = ACTIONS(5509),
    [sym_asserterror_keyword] = ACTIONS(5511),
    [sym_page_keyword] = ACTIONS(5509),
    [anon_sym_codeunit] = ACTIONS(5509),
    [anon_sym_CODEUNIT] = ACTIONS(5509),
    [anon_sym_Codeunit] = ACTIONS(5509),
    [anon_sym_CodeUnit] = ACTIONS(5509),
    [anon_sym_COdeunit] = ACTIONS(5509),
    [anon_sym_codeUnit] = ACTIONS(5509),
    [sym_report_keyword] = ACTIONS(5509),
    [sym_query_keyword] = ACTIONS(5509),
    [anon_sym_xmlport] = ACTIONS(5509),
    [anon_sym_XMLPORT] = ACTIONS(5509),
    [anon_sym_Xmlport] = ACTIONS(5509),
    [anon_sym_XMLport] = ACTIONS(5509),
    [anon_sym_XMLPort] = ACTIONS(5509),
    [anon_sym_XmlPort] = ACTIONS(5509),
    [anon_sym_enum] = ACTIONS(5509),
    [anon_sym_ENUM] = ACTIONS(5509),
    [anon_sym_Enum] = ACTIONS(5509),
    [anon_sym_eNUM] = ACTIONS(5509),
    [anon_sym_eNum] = ACTIONS(5509),
    [anon_sym_ENum] = ACTIONS(5509),
    [sym_quoted_identifier] = ACTIONS(5511),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5511),
    [sym_verbatim_string] = ACTIONS(5511),
    [sym_integer] = ACTIONS(5509),
    [sym_continue_as_identifier] = ACTIONS(5511),
    [sym_preproc_open] = ACTIONS(5511),
  },
  [STATE(2965)] = {
    [sym_identifier] = ACTIONS(5513),
    [anon_sym_SEMI] = ACTIONS(5515),
    [anon_sym_DASH] = ACTIONS(5515),
    [aux_sym_boolean_token1] = ACTIONS(5513),
    [aux_sym_boolean_token2] = ACTIONS(5513),
    [sym_decimal] = ACTIONS(5513),
    [anon_sym_LPAREN] = ACTIONS(5515),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5513),
    [anon_sym_LBRACK] = ACTIONS(5515),
    [aux_sym_record_type_token1] = ACTIONS(5513),
    [aux_sym_basic_type_token21] = ACTIONS(5513),
    [aux_sym_basic_type_token22] = ACTIONS(5513),
    [aux_sym_basic_type_token48] = ACTIONS(5513),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5513),
    [anon_sym_POUNDif] = ACTIONS(5515),
    [anon_sym_POUNDIF] = ACTIONS(5515),
    [anon_sym_POUNDIf] = ACTIONS(5515),
    [anon_sym_not] = ACTIONS(5513),
    [anon_sym_NOT] = ACTIONS(5513),
    [anon_sym_Not] = ACTIONS(5513),
    [anon_sym_POUNDelse] = ACTIONS(5515),
    [anon_sym_POUNDELSE] = ACTIONS(5515),
    [anon_sym_POUNDElse] = ACTIONS(5515),
    [anon_sym_POUNDelse2] = ACTIONS(5515),
    [anon_sym_POUNDELSE2] = ACTIONS(5515),
    [anon_sym_POUNDElse2] = ACTIONS(5515),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5513),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5513),
    [anon_sym_PLUS] = ACTIONS(5515),
    [sym_datetime_literal] = ACTIONS(5515),
    [sym_date_literal] = ACTIONS(5513),
    [sym_time_literal] = ACTIONS(5513),
    [sym_biginteger_literal] = ACTIONS(5515),
    [anon_sym_if] = ACTIONS(5513),
    [anon_sym_IF] = ACTIONS(5513),
    [anon_sym_If] = ACTIONS(5513),
    [anon_sym_else] = ACTIONS(5513),
    [anon_sym_ELSE] = ACTIONS(5513),
    [anon_sym_Else] = ACTIONS(5513),
    [anon_sym_case] = ACTIONS(5513),
    [anon_sym_CASE] = ACTIONS(5513),
    [anon_sym_Case] = ACTIONS(5513),
    [anon_sym_for] = ACTIONS(5513),
    [anon_sym_FOR] = ACTIONS(5513),
    [anon_sym_For] = ACTIONS(5513),
    [anon_sym_foreach] = ACTIONS(5513),
    [anon_sym_FOREACH] = ACTIONS(5513),
    [anon_sym_Foreach] = ACTIONS(5513),
    [anon_sym_while] = ACTIONS(5513),
    [anon_sym_WHILE] = ACTIONS(5513),
    [anon_sym_While] = ACTIONS(5513),
    [anon_sym_repeat] = ACTIONS(5513),
    [anon_sym_REPEAT] = ACTIONS(5513),
    [anon_sym_Repeat] = ACTIONS(5513),
    [anon_sym_until] = ACTIONS(5513),
    [anon_sym_UNTIL] = ACTIONS(5513),
    [anon_sym_Until] = ACTIONS(5513),
    [anon_sym_exit] = ACTIONS(5513),
    [anon_sym_EXIT] = ACTIONS(5513),
    [anon_sym_Exit] = ACTIONS(5513),
    [anon_sym_continue] = ACTIONS(5513),
    [anon_sym_CONTINUE] = ACTIONS(5513),
    [anon_sym_Continue] = ACTIONS(5513),
    [anon_sym_break] = ACTIONS(5513),
    [anon_sym_BREAK] = ACTIONS(5513),
    [anon_sym_Break] = ACTIONS(5513),
    [anon_sym_with] = ACTIONS(5513),
    [anon_sym_WITH] = ACTIONS(5513),
    [anon_sym_With] = ACTIONS(5513),
    [sym_asserterror_keyword] = ACTIONS(5515),
    [sym_page_keyword] = ACTIONS(5513),
    [anon_sym_codeunit] = ACTIONS(5513),
    [anon_sym_CODEUNIT] = ACTIONS(5513),
    [anon_sym_Codeunit] = ACTIONS(5513),
    [anon_sym_CodeUnit] = ACTIONS(5513),
    [anon_sym_COdeunit] = ACTIONS(5513),
    [anon_sym_codeUnit] = ACTIONS(5513),
    [sym_report_keyword] = ACTIONS(5513),
    [sym_query_keyword] = ACTIONS(5513),
    [anon_sym_xmlport] = ACTIONS(5513),
    [anon_sym_XMLPORT] = ACTIONS(5513),
    [anon_sym_Xmlport] = ACTIONS(5513),
    [anon_sym_XMLport] = ACTIONS(5513),
    [anon_sym_XMLPort] = ACTIONS(5513),
    [anon_sym_XmlPort] = ACTIONS(5513),
    [anon_sym_enum] = ACTIONS(5513),
    [anon_sym_ENUM] = ACTIONS(5513),
    [anon_sym_Enum] = ACTIONS(5513),
    [anon_sym_eNUM] = ACTIONS(5513),
    [anon_sym_eNum] = ACTIONS(5513),
    [anon_sym_ENum] = ACTIONS(5513),
    [sym_quoted_identifier] = ACTIONS(5515),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5515),
    [sym_verbatim_string] = ACTIONS(5515),
    [sym_integer] = ACTIONS(5513),
    [sym_continue_as_identifier] = ACTIONS(5515),
    [sym_preproc_open] = ACTIONS(5515),
  },
  [STATE(2966)] = {
    [sym_identifier] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym_DASH] = ACTIONS(5519),
    [aux_sym_boolean_token1] = ACTIONS(5517),
    [aux_sym_boolean_token2] = ACTIONS(5517),
    [sym_decimal] = ACTIONS(5517),
    [anon_sym_LPAREN] = ACTIONS(5519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5519),
    [aux_sym_record_type_token1] = ACTIONS(5517),
    [aux_sym_basic_type_token21] = ACTIONS(5517),
    [aux_sym_basic_type_token22] = ACTIONS(5517),
    [aux_sym_basic_type_token48] = ACTIONS(5517),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5517),
    [anon_sym_POUNDif] = ACTIONS(5519),
    [anon_sym_POUNDIF] = ACTIONS(5519),
    [anon_sym_POUNDIf] = ACTIONS(5519),
    [anon_sym_not] = ACTIONS(5517),
    [anon_sym_NOT] = ACTIONS(5517),
    [anon_sym_Not] = ACTIONS(5517),
    [anon_sym_POUNDelse] = ACTIONS(5519),
    [anon_sym_POUNDELSE] = ACTIONS(5519),
    [anon_sym_POUNDElse] = ACTIONS(5519),
    [anon_sym_POUNDelse2] = ACTIONS(5519),
    [anon_sym_POUNDELSE2] = ACTIONS(5519),
    [anon_sym_POUNDElse2] = ACTIONS(5519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5517),
    [anon_sym_PLUS] = ACTIONS(5519),
    [sym_datetime_literal] = ACTIONS(5519),
    [sym_date_literal] = ACTIONS(5517),
    [sym_time_literal] = ACTIONS(5517),
    [sym_biginteger_literal] = ACTIONS(5519),
    [anon_sym_if] = ACTIONS(5517),
    [anon_sym_IF] = ACTIONS(5517),
    [anon_sym_If] = ACTIONS(5517),
    [anon_sym_else] = ACTIONS(5517),
    [anon_sym_ELSE] = ACTIONS(5517),
    [anon_sym_Else] = ACTIONS(5517),
    [anon_sym_case] = ACTIONS(5517),
    [anon_sym_CASE] = ACTIONS(5517),
    [anon_sym_Case] = ACTIONS(5517),
    [anon_sym_for] = ACTIONS(5517),
    [anon_sym_FOR] = ACTIONS(5517),
    [anon_sym_For] = ACTIONS(5517),
    [anon_sym_foreach] = ACTIONS(5517),
    [anon_sym_FOREACH] = ACTIONS(5517),
    [anon_sym_Foreach] = ACTIONS(5517),
    [anon_sym_while] = ACTIONS(5517),
    [anon_sym_WHILE] = ACTIONS(5517),
    [anon_sym_While] = ACTIONS(5517),
    [anon_sym_repeat] = ACTIONS(5517),
    [anon_sym_REPEAT] = ACTIONS(5517),
    [anon_sym_Repeat] = ACTIONS(5517),
    [anon_sym_until] = ACTIONS(5517),
    [anon_sym_UNTIL] = ACTIONS(5517),
    [anon_sym_Until] = ACTIONS(5517),
    [anon_sym_exit] = ACTIONS(5517),
    [anon_sym_EXIT] = ACTIONS(5517),
    [anon_sym_Exit] = ACTIONS(5517),
    [anon_sym_continue] = ACTIONS(5517),
    [anon_sym_CONTINUE] = ACTIONS(5517),
    [anon_sym_Continue] = ACTIONS(5517),
    [anon_sym_break] = ACTIONS(5517),
    [anon_sym_BREAK] = ACTIONS(5517),
    [anon_sym_Break] = ACTIONS(5517),
    [anon_sym_with] = ACTIONS(5517),
    [anon_sym_WITH] = ACTIONS(5517),
    [anon_sym_With] = ACTIONS(5517),
    [sym_asserterror_keyword] = ACTIONS(5519),
    [sym_page_keyword] = ACTIONS(5517),
    [anon_sym_codeunit] = ACTIONS(5517),
    [anon_sym_CODEUNIT] = ACTIONS(5517),
    [anon_sym_Codeunit] = ACTIONS(5517),
    [anon_sym_CodeUnit] = ACTIONS(5517),
    [anon_sym_COdeunit] = ACTIONS(5517),
    [anon_sym_codeUnit] = ACTIONS(5517),
    [sym_report_keyword] = ACTIONS(5517),
    [sym_query_keyword] = ACTIONS(5517),
    [anon_sym_xmlport] = ACTIONS(5517),
    [anon_sym_XMLPORT] = ACTIONS(5517),
    [anon_sym_Xmlport] = ACTIONS(5517),
    [anon_sym_XMLport] = ACTIONS(5517),
    [anon_sym_XMLPort] = ACTIONS(5517),
    [anon_sym_XmlPort] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_ENUM] = ACTIONS(5517),
    [anon_sym_Enum] = ACTIONS(5517),
    [anon_sym_eNUM] = ACTIONS(5517),
    [anon_sym_eNum] = ACTIONS(5517),
    [anon_sym_ENum] = ACTIONS(5517),
    [sym_quoted_identifier] = ACTIONS(5519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5519),
    [sym_verbatim_string] = ACTIONS(5519),
    [sym_integer] = ACTIONS(5517),
    [sym_continue_as_identifier] = ACTIONS(5519),
    [sym_preproc_open] = ACTIONS(5519),
  },
  [STATE(2967)] = {
    [sym_identifier] = ACTIONS(5521),
    [anon_sym_SEMI] = ACTIONS(5523),
    [anon_sym_DASH] = ACTIONS(5523),
    [aux_sym_boolean_token1] = ACTIONS(5521),
    [aux_sym_boolean_token2] = ACTIONS(5521),
    [sym_decimal] = ACTIONS(5521),
    [anon_sym_LPAREN] = ACTIONS(5523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5521),
    [anon_sym_LBRACK] = ACTIONS(5523),
    [aux_sym_record_type_token1] = ACTIONS(5521),
    [aux_sym_basic_type_token21] = ACTIONS(5521),
    [aux_sym_basic_type_token22] = ACTIONS(5521),
    [aux_sym_basic_type_token48] = ACTIONS(5521),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5521),
    [anon_sym_POUNDif] = ACTIONS(5523),
    [anon_sym_POUNDIF] = ACTIONS(5523),
    [anon_sym_POUNDIf] = ACTIONS(5523),
    [anon_sym_not] = ACTIONS(5521),
    [anon_sym_NOT] = ACTIONS(5521),
    [anon_sym_Not] = ACTIONS(5521),
    [anon_sym_POUNDelse] = ACTIONS(5523),
    [anon_sym_POUNDELSE] = ACTIONS(5523),
    [anon_sym_POUNDElse] = ACTIONS(5523),
    [anon_sym_POUNDelse2] = ACTIONS(5523),
    [anon_sym_POUNDELSE2] = ACTIONS(5523),
    [anon_sym_POUNDElse2] = ACTIONS(5523),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5521),
    [anon_sym_PLUS] = ACTIONS(5523),
    [sym_datetime_literal] = ACTIONS(5523),
    [sym_date_literal] = ACTIONS(5521),
    [sym_time_literal] = ACTIONS(5521),
    [sym_biginteger_literal] = ACTIONS(5523),
    [anon_sym_if] = ACTIONS(5521),
    [anon_sym_IF] = ACTIONS(5521),
    [anon_sym_If] = ACTIONS(5521),
    [anon_sym_else] = ACTIONS(5521),
    [anon_sym_ELSE] = ACTIONS(5521),
    [anon_sym_Else] = ACTIONS(5521),
    [anon_sym_case] = ACTIONS(5521),
    [anon_sym_CASE] = ACTIONS(5521),
    [anon_sym_Case] = ACTIONS(5521),
    [anon_sym_for] = ACTIONS(5521),
    [anon_sym_FOR] = ACTIONS(5521),
    [anon_sym_For] = ACTIONS(5521),
    [anon_sym_foreach] = ACTIONS(5521),
    [anon_sym_FOREACH] = ACTIONS(5521),
    [anon_sym_Foreach] = ACTIONS(5521),
    [anon_sym_while] = ACTIONS(5521),
    [anon_sym_WHILE] = ACTIONS(5521),
    [anon_sym_While] = ACTIONS(5521),
    [anon_sym_repeat] = ACTIONS(5521),
    [anon_sym_REPEAT] = ACTIONS(5521),
    [anon_sym_Repeat] = ACTIONS(5521),
    [anon_sym_until] = ACTIONS(5521),
    [anon_sym_UNTIL] = ACTIONS(5521),
    [anon_sym_Until] = ACTIONS(5521),
    [anon_sym_exit] = ACTIONS(5521),
    [anon_sym_EXIT] = ACTIONS(5521),
    [anon_sym_Exit] = ACTIONS(5521),
    [anon_sym_continue] = ACTIONS(5521),
    [anon_sym_CONTINUE] = ACTIONS(5521),
    [anon_sym_Continue] = ACTIONS(5521),
    [anon_sym_break] = ACTIONS(5521),
    [anon_sym_BREAK] = ACTIONS(5521),
    [anon_sym_Break] = ACTIONS(5521),
    [anon_sym_with] = ACTIONS(5521),
    [anon_sym_WITH] = ACTIONS(5521),
    [anon_sym_With] = ACTIONS(5521),
    [sym_asserterror_keyword] = ACTIONS(5523),
    [sym_page_keyword] = ACTIONS(5521),
    [anon_sym_codeunit] = ACTIONS(5521),
    [anon_sym_CODEUNIT] = ACTIONS(5521),
    [anon_sym_Codeunit] = ACTIONS(5521),
    [anon_sym_CodeUnit] = ACTIONS(5521),
    [anon_sym_COdeunit] = ACTIONS(5521),
    [anon_sym_codeUnit] = ACTIONS(5521),
    [sym_report_keyword] = ACTIONS(5521),
    [sym_query_keyword] = ACTIONS(5521),
    [anon_sym_xmlport] = ACTIONS(5521),
    [anon_sym_XMLPORT] = ACTIONS(5521),
    [anon_sym_Xmlport] = ACTIONS(5521),
    [anon_sym_XMLport] = ACTIONS(5521),
    [anon_sym_XMLPort] = ACTIONS(5521),
    [anon_sym_XmlPort] = ACTIONS(5521),
    [anon_sym_enum] = ACTIONS(5521),
    [anon_sym_ENUM] = ACTIONS(5521),
    [anon_sym_Enum] = ACTIONS(5521),
    [anon_sym_eNUM] = ACTIONS(5521),
    [anon_sym_eNum] = ACTIONS(5521),
    [anon_sym_ENum] = ACTIONS(5521),
    [sym_quoted_identifier] = ACTIONS(5523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5523),
    [sym_verbatim_string] = ACTIONS(5523),
    [sym_integer] = ACTIONS(5521),
    [sym_continue_as_identifier] = ACTIONS(5523),
    [sym_preproc_open] = ACTIONS(5523),
  },
  [STATE(2968)] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5527),
    [aux_sym_boolean_token1] = ACTIONS(5525),
    [aux_sym_boolean_token2] = ACTIONS(5525),
    [sym_decimal] = ACTIONS(5525),
    [anon_sym_LPAREN] = ACTIONS(5527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [aux_sym_record_type_token1] = ACTIONS(5525),
    [aux_sym_basic_type_token21] = ACTIONS(5525),
    [aux_sym_basic_type_token22] = ACTIONS(5525),
    [aux_sym_basic_type_token48] = ACTIONS(5525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5525),
    [anon_sym_POUNDif] = ACTIONS(5527),
    [anon_sym_POUNDIF] = ACTIONS(5527),
    [anon_sym_POUNDIf] = ACTIONS(5527),
    [anon_sym_not] = ACTIONS(5525),
    [anon_sym_NOT] = ACTIONS(5525),
    [anon_sym_Not] = ACTIONS(5525),
    [anon_sym_POUNDelse] = ACTIONS(5527),
    [anon_sym_POUNDELSE] = ACTIONS(5527),
    [anon_sym_POUNDElse] = ACTIONS(5527),
    [anon_sym_POUNDelse2] = ACTIONS(5527),
    [anon_sym_POUNDELSE2] = ACTIONS(5527),
    [anon_sym_POUNDElse2] = ACTIONS(5527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5527),
    [sym_datetime_literal] = ACTIONS(5527),
    [sym_date_literal] = ACTIONS(5525),
    [sym_time_literal] = ACTIONS(5525),
    [sym_biginteger_literal] = ACTIONS(5527),
    [anon_sym_if] = ACTIONS(5525),
    [anon_sym_IF] = ACTIONS(5525),
    [anon_sym_If] = ACTIONS(5525),
    [anon_sym_else] = ACTIONS(5525),
    [anon_sym_ELSE] = ACTIONS(5525),
    [anon_sym_Else] = ACTIONS(5525),
    [anon_sym_case] = ACTIONS(5525),
    [anon_sym_CASE] = ACTIONS(5525),
    [anon_sym_Case] = ACTIONS(5525),
    [anon_sym_for] = ACTIONS(5525),
    [anon_sym_FOR] = ACTIONS(5525),
    [anon_sym_For] = ACTIONS(5525),
    [anon_sym_foreach] = ACTIONS(5525),
    [anon_sym_FOREACH] = ACTIONS(5525),
    [anon_sym_Foreach] = ACTIONS(5525),
    [anon_sym_while] = ACTIONS(5525),
    [anon_sym_WHILE] = ACTIONS(5525),
    [anon_sym_While] = ACTIONS(5525),
    [anon_sym_repeat] = ACTIONS(5525),
    [anon_sym_REPEAT] = ACTIONS(5525),
    [anon_sym_Repeat] = ACTIONS(5525),
    [anon_sym_until] = ACTIONS(5525),
    [anon_sym_UNTIL] = ACTIONS(5525),
    [anon_sym_Until] = ACTIONS(5525),
    [anon_sym_exit] = ACTIONS(5525),
    [anon_sym_EXIT] = ACTIONS(5525),
    [anon_sym_Exit] = ACTIONS(5525),
    [anon_sym_continue] = ACTIONS(5525),
    [anon_sym_CONTINUE] = ACTIONS(5525),
    [anon_sym_Continue] = ACTIONS(5525),
    [anon_sym_break] = ACTIONS(5525),
    [anon_sym_BREAK] = ACTIONS(5525),
    [anon_sym_Break] = ACTIONS(5525),
    [anon_sym_with] = ACTIONS(5525),
    [anon_sym_WITH] = ACTIONS(5525),
    [anon_sym_With] = ACTIONS(5525),
    [sym_asserterror_keyword] = ACTIONS(5527),
    [sym_page_keyword] = ACTIONS(5525),
    [anon_sym_codeunit] = ACTIONS(5525),
    [anon_sym_CODEUNIT] = ACTIONS(5525),
    [anon_sym_Codeunit] = ACTIONS(5525),
    [anon_sym_CodeUnit] = ACTIONS(5525),
    [anon_sym_COdeunit] = ACTIONS(5525),
    [anon_sym_codeUnit] = ACTIONS(5525),
    [sym_report_keyword] = ACTIONS(5525),
    [sym_query_keyword] = ACTIONS(5525),
    [anon_sym_xmlport] = ACTIONS(5525),
    [anon_sym_XMLPORT] = ACTIONS(5525),
    [anon_sym_Xmlport] = ACTIONS(5525),
    [anon_sym_XMLport] = ACTIONS(5525),
    [anon_sym_XMLPort] = ACTIONS(5525),
    [anon_sym_XmlPort] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_ENUM] = ACTIONS(5525),
    [anon_sym_Enum] = ACTIONS(5525),
    [anon_sym_eNUM] = ACTIONS(5525),
    [anon_sym_eNum] = ACTIONS(5525),
    [anon_sym_ENum] = ACTIONS(5525),
    [sym_quoted_identifier] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5527),
    [sym_verbatim_string] = ACTIONS(5527),
    [sym_integer] = ACTIONS(5525),
    [sym_continue_as_identifier] = ACTIONS(5527),
    [sym_preproc_open] = ACTIONS(5527),
  },
  [STATE(2969)] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5527),
    [aux_sym_boolean_token1] = ACTIONS(5525),
    [aux_sym_boolean_token2] = ACTIONS(5525),
    [sym_decimal] = ACTIONS(5525),
    [anon_sym_LPAREN] = ACTIONS(5527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [aux_sym_record_type_token1] = ACTIONS(5525),
    [aux_sym_basic_type_token21] = ACTIONS(5525),
    [aux_sym_basic_type_token22] = ACTIONS(5525),
    [aux_sym_basic_type_token48] = ACTIONS(5525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5525),
    [anon_sym_POUNDif] = ACTIONS(5527),
    [anon_sym_POUNDIF] = ACTIONS(5527),
    [anon_sym_POUNDIf] = ACTIONS(5527),
    [anon_sym_not] = ACTIONS(5525),
    [anon_sym_NOT] = ACTIONS(5525),
    [anon_sym_Not] = ACTIONS(5525),
    [anon_sym_POUNDelse] = ACTIONS(5527),
    [anon_sym_POUNDELSE] = ACTIONS(5527),
    [anon_sym_POUNDElse] = ACTIONS(5527),
    [anon_sym_POUNDelse2] = ACTIONS(5527),
    [anon_sym_POUNDELSE2] = ACTIONS(5527),
    [anon_sym_POUNDElse2] = ACTIONS(5527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5527),
    [sym_datetime_literal] = ACTIONS(5527),
    [sym_date_literal] = ACTIONS(5525),
    [sym_time_literal] = ACTIONS(5525),
    [sym_biginteger_literal] = ACTIONS(5527),
    [anon_sym_if] = ACTIONS(5525),
    [anon_sym_IF] = ACTIONS(5525),
    [anon_sym_If] = ACTIONS(5525),
    [anon_sym_else] = ACTIONS(5525),
    [anon_sym_ELSE] = ACTIONS(5525),
    [anon_sym_Else] = ACTIONS(5525),
    [anon_sym_case] = ACTIONS(5525),
    [anon_sym_CASE] = ACTIONS(5525),
    [anon_sym_Case] = ACTIONS(5525),
    [anon_sym_for] = ACTIONS(5525),
    [anon_sym_FOR] = ACTIONS(5525),
    [anon_sym_For] = ACTIONS(5525),
    [anon_sym_foreach] = ACTIONS(5525),
    [anon_sym_FOREACH] = ACTIONS(5525),
    [anon_sym_Foreach] = ACTIONS(5525),
    [anon_sym_while] = ACTIONS(5525),
    [anon_sym_WHILE] = ACTIONS(5525),
    [anon_sym_While] = ACTIONS(5525),
    [anon_sym_repeat] = ACTIONS(5525),
    [anon_sym_REPEAT] = ACTIONS(5525),
    [anon_sym_Repeat] = ACTIONS(5525),
    [anon_sym_until] = ACTIONS(5525),
    [anon_sym_UNTIL] = ACTIONS(5525),
    [anon_sym_Until] = ACTIONS(5525),
    [anon_sym_exit] = ACTIONS(5525),
    [anon_sym_EXIT] = ACTIONS(5525),
    [anon_sym_Exit] = ACTIONS(5525),
    [anon_sym_continue] = ACTIONS(5525),
    [anon_sym_CONTINUE] = ACTIONS(5525),
    [anon_sym_Continue] = ACTIONS(5525),
    [anon_sym_break] = ACTIONS(5525),
    [anon_sym_BREAK] = ACTIONS(5525),
    [anon_sym_Break] = ACTIONS(5525),
    [anon_sym_with] = ACTIONS(5525),
    [anon_sym_WITH] = ACTIONS(5525),
    [anon_sym_With] = ACTIONS(5525),
    [sym_asserterror_keyword] = ACTIONS(5527),
    [sym_page_keyword] = ACTIONS(5525),
    [anon_sym_codeunit] = ACTIONS(5525),
    [anon_sym_CODEUNIT] = ACTIONS(5525),
    [anon_sym_Codeunit] = ACTIONS(5525),
    [anon_sym_CodeUnit] = ACTIONS(5525),
    [anon_sym_COdeunit] = ACTIONS(5525),
    [anon_sym_codeUnit] = ACTIONS(5525),
    [sym_report_keyword] = ACTIONS(5525),
    [sym_query_keyword] = ACTIONS(5525),
    [anon_sym_xmlport] = ACTIONS(5525),
    [anon_sym_XMLPORT] = ACTIONS(5525),
    [anon_sym_Xmlport] = ACTIONS(5525),
    [anon_sym_XMLport] = ACTIONS(5525),
    [anon_sym_XMLPort] = ACTIONS(5525),
    [anon_sym_XmlPort] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_ENUM] = ACTIONS(5525),
    [anon_sym_Enum] = ACTIONS(5525),
    [anon_sym_eNUM] = ACTIONS(5525),
    [anon_sym_eNum] = ACTIONS(5525),
    [anon_sym_ENum] = ACTIONS(5525),
    [sym_quoted_identifier] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5527),
    [sym_verbatim_string] = ACTIONS(5527),
    [sym_integer] = ACTIONS(5525),
    [sym_continue_as_identifier] = ACTIONS(5527),
    [sym_preproc_open] = ACTIONS(5527),
  },
  [STATE(2970)] = {
    [sym_identifier] = ACTIONS(5529),
    [anon_sym_SEMI] = ACTIONS(5531),
    [anon_sym_DASH] = ACTIONS(5531),
    [aux_sym_boolean_token1] = ACTIONS(5529),
    [aux_sym_boolean_token2] = ACTIONS(5529),
    [sym_decimal] = ACTIONS(5529),
    [anon_sym_LPAREN] = ACTIONS(5531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5529),
    [anon_sym_LBRACK] = ACTIONS(5531),
    [aux_sym_record_type_token1] = ACTIONS(5529),
    [aux_sym_basic_type_token21] = ACTIONS(5529),
    [aux_sym_basic_type_token22] = ACTIONS(5529),
    [aux_sym_basic_type_token48] = ACTIONS(5529),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5529),
    [anon_sym_POUNDif] = ACTIONS(5531),
    [anon_sym_POUNDIF] = ACTIONS(5531),
    [anon_sym_POUNDIf] = ACTIONS(5531),
    [anon_sym_not] = ACTIONS(5529),
    [anon_sym_NOT] = ACTIONS(5529),
    [anon_sym_Not] = ACTIONS(5529),
    [anon_sym_POUNDelse] = ACTIONS(5531),
    [anon_sym_POUNDELSE] = ACTIONS(5531),
    [anon_sym_POUNDElse] = ACTIONS(5531),
    [anon_sym_POUNDelse2] = ACTIONS(5531),
    [anon_sym_POUNDELSE2] = ACTIONS(5531),
    [anon_sym_POUNDElse2] = ACTIONS(5531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5529),
    [anon_sym_PLUS] = ACTIONS(5531),
    [sym_datetime_literal] = ACTIONS(5531),
    [sym_date_literal] = ACTIONS(5529),
    [sym_time_literal] = ACTIONS(5529),
    [sym_biginteger_literal] = ACTIONS(5531),
    [anon_sym_if] = ACTIONS(5529),
    [anon_sym_IF] = ACTIONS(5529),
    [anon_sym_If] = ACTIONS(5529),
    [anon_sym_else] = ACTIONS(5529),
    [anon_sym_ELSE] = ACTIONS(5529),
    [anon_sym_Else] = ACTIONS(5529),
    [anon_sym_case] = ACTIONS(5529),
    [anon_sym_CASE] = ACTIONS(5529),
    [anon_sym_Case] = ACTIONS(5529),
    [anon_sym_for] = ACTIONS(5529),
    [anon_sym_FOR] = ACTIONS(5529),
    [anon_sym_For] = ACTIONS(5529),
    [anon_sym_foreach] = ACTIONS(5529),
    [anon_sym_FOREACH] = ACTIONS(5529),
    [anon_sym_Foreach] = ACTIONS(5529),
    [anon_sym_while] = ACTIONS(5529),
    [anon_sym_WHILE] = ACTIONS(5529),
    [anon_sym_While] = ACTIONS(5529),
    [anon_sym_repeat] = ACTIONS(5529),
    [anon_sym_REPEAT] = ACTIONS(5529),
    [anon_sym_Repeat] = ACTIONS(5529),
    [anon_sym_until] = ACTIONS(5529),
    [anon_sym_UNTIL] = ACTIONS(5529),
    [anon_sym_Until] = ACTIONS(5529),
    [anon_sym_exit] = ACTIONS(5529),
    [anon_sym_EXIT] = ACTIONS(5529),
    [anon_sym_Exit] = ACTIONS(5529),
    [anon_sym_continue] = ACTIONS(5529),
    [anon_sym_CONTINUE] = ACTIONS(5529),
    [anon_sym_Continue] = ACTIONS(5529),
    [anon_sym_break] = ACTIONS(5529),
    [anon_sym_BREAK] = ACTIONS(5529),
    [anon_sym_Break] = ACTIONS(5529),
    [anon_sym_with] = ACTIONS(5529),
    [anon_sym_WITH] = ACTIONS(5529),
    [anon_sym_With] = ACTIONS(5529),
    [sym_asserterror_keyword] = ACTIONS(5531),
    [sym_page_keyword] = ACTIONS(5529),
    [anon_sym_codeunit] = ACTIONS(5529),
    [anon_sym_CODEUNIT] = ACTIONS(5529),
    [anon_sym_Codeunit] = ACTIONS(5529),
    [anon_sym_CodeUnit] = ACTIONS(5529),
    [anon_sym_COdeunit] = ACTIONS(5529),
    [anon_sym_codeUnit] = ACTIONS(5529),
    [sym_report_keyword] = ACTIONS(5529),
    [sym_query_keyword] = ACTIONS(5529),
    [anon_sym_xmlport] = ACTIONS(5529),
    [anon_sym_XMLPORT] = ACTIONS(5529),
    [anon_sym_Xmlport] = ACTIONS(5529),
    [anon_sym_XMLport] = ACTIONS(5529),
    [anon_sym_XMLPort] = ACTIONS(5529),
    [anon_sym_XmlPort] = ACTIONS(5529),
    [anon_sym_enum] = ACTIONS(5529),
    [anon_sym_ENUM] = ACTIONS(5529),
    [anon_sym_Enum] = ACTIONS(5529),
    [anon_sym_eNUM] = ACTIONS(5529),
    [anon_sym_eNum] = ACTIONS(5529),
    [anon_sym_ENum] = ACTIONS(5529),
    [sym_quoted_identifier] = ACTIONS(5531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5531),
    [sym_verbatim_string] = ACTIONS(5531),
    [sym_integer] = ACTIONS(5529),
    [sym_continue_as_identifier] = ACTIONS(5531),
    [sym_preproc_open] = ACTIONS(5531),
  },
  [STATE(2971)] = {
    [sym_identifier] = ACTIONS(5533),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym_DASH] = ACTIONS(5535),
    [aux_sym_boolean_token1] = ACTIONS(5533),
    [aux_sym_boolean_token2] = ACTIONS(5533),
    [sym_decimal] = ACTIONS(5533),
    [anon_sym_LPAREN] = ACTIONS(5535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5533),
    [anon_sym_LBRACK] = ACTIONS(5535),
    [aux_sym_record_type_token1] = ACTIONS(5533),
    [aux_sym_basic_type_token21] = ACTIONS(5533),
    [aux_sym_basic_type_token22] = ACTIONS(5533),
    [aux_sym_basic_type_token48] = ACTIONS(5533),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5533),
    [anon_sym_POUNDif] = ACTIONS(5535),
    [anon_sym_POUNDIF] = ACTIONS(5535),
    [anon_sym_POUNDIf] = ACTIONS(5535),
    [anon_sym_not] = ACTIONS(5533),
    [anon_sym_NOT] = ACTIONS(5533),
    [anon_sym_Not] = ACTIONS(5533),
    [anon_sym_POUNDelse] = ACTIONS(5535),
    [anon_sym_POUNDELSE] = ACTIONS(5535),
    [anon_sym_POUNDElse] = ACTIONS(5535),
    [anon_sym_POUNDelse2] = ACTIONS(5535),
    [anon_sym_POUNDELSE2] = ACTIONS(5535),
    [anon_sym_POUNDElse2] = ACTIONS(5535),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5533),
    [anon_sym_PLUS] = ACTIONS(5535),
    [sym_datetime_literal] = ACTIONS(5535),
    [sym_date_literal] = ACTIONS(5533),
    [sym_time_literal] = ACTIONS(5533),
    [sym_biginteger_literal] = ACTIONS(5535),
    [anon_sym_if] = ACTIONS(5533),
    [anon_sym_IF] = ACTIONS(5533),
    [anon_sym_If] = ACTIONS(5533),
    [anon_sym_else] = ACTIONS(5533),
    [anon_sym_ELSE] = ACTIONS(5533),
    [anon_sym_Else] = ACTIONS(5533),
    [anon_sym_case] = ACTIONS(5533),
    [anon_sym_CASE] = ACTIONS(5533),
    [anon_sym_Case] = ACTIONS(5533),
    [anon_sym_for] = ACTIONS(5533),
    [anon_sym_FOR] = ACTIONS(5533),
    [anon_sym_For] = ACTIONS(5533),
    [anon_sym_foreach] = ACTIONS(5533),
    [anon_sym_FOREACH] = ACTIONS(5533),
    [anon_sym_Foreach] = ACTIONS(5533),
    [anon_sym_while] = ACTIONS(5533),
    [anon_sym_WHILE] = ACTIONS(5533),
    [anon_sym_While] = ACTIONS(5533),
    [anon_sym_repeat] = ACTIONS(5533),
    [anon_sym_REPEAT] = ACTIONS(5533),
    [anon_sym_Repeat] = ACTIONS(5533),
    [anon_sym_until] = ACTIONS(5533),
    [anon_sym_UNTIL] = ACTIONS(5533),
    [anon_sym_Until] = ACTIONS(5533),
    [anon_sym_exit] = ACTIONS(5533),
    [anon_sym_EXIT] = ACTIONS(5533),
    [anon_sym_Exit] = ACTIONS(5533),
    [anon_sym_continue] = ACTIONS(5533),
    [anon_sym_CONTINUE] = ACTIONS(5533),
    [anon_sym_Continue] = ACTIONS(5533),
    [anon_sym_break] = ACTIONS(5533),
    [anon_sym_BREAK] = ACTIONS(5533),
    [anon_sym_Break] = ACTIONS(5533),
    [anon_sym_with] = ACTIONS(5533),
    [anon_sym_WITH] = ACTIONS(5533),
    [anon_sym_With] = ACTIONS(5533),
    [sym_asserterror_keyword] = ACTIONS(5535),
    [sym_page_keyword] = ACTIONS(5533),
    [anon_sym_codeunit] = ACTIONS(5533),
    [anon_sym_CODEUNIT] = ACTIONS(5533),
    [anon_sym_Codeunit] = ACTIONS(5533),
    [anon_sym_CodeUnit] = ACTIONS(5533),
    [anon_sym_COdeunit] = ACTIONS(5533),
    [anon_sym_codeUnit] = ACTIONS(5533),
    [sym_report_keyword] = ACTIONS(5533),
    [sym_query_keyword] = ACTIONS(5533),
    [anon_sym_xmlport] = ACTIONS(5533),
    [anon_sym_XMLPORT] = ACTIONS(5533),
    [anon_sym_Xmlport] = ACTIONS(5533),
    [anon_sym_XMLport] = ACTIONS(5533),
    [anon_sym_XMLPort] = ACTIONS(5533),
    [anon_sym_XmlPort] = ACTIONS(5533),
    [anon_sym_enum] = ACTIONS(5533),
    [anon_sym_ENUM] = ACTIONS(5533),
    [anon_sym_Enum] = ACTIONS(5533),
    [anon_sym_eNUM] = ACTIONS(5533),
    [anon_sym_eNum] = ACTIONS(5533),
    [anon_sym_ENum] = ACTIONS(5533),
    [sym_quoted_identifier] = ACTIONS(5535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5535),
    [sym_verbatim_string] = ACTIONS(5535),
    [sym_integer] = ACTIONS(5533),
    [sym_continue_as_identifier] = ACTIONS(5535),
    [sym_preproc_open] = ACTIONS(5535),
  },
  [STATE(2972)] = {
    [sym_identifier] = ACTIONS(5537),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym_DASH] = ACTIONS(5539),
    [aux_sym_boolean_token1] = ACTIONS(5537),
    [aux_sym_boolean_token2] = ACTIONS(5537),
    [sym_decimal] = ACTIONS(5537),
    [anon_sym_LPAREN] = ACTIONS(5539),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5537),
    [anon_sym_LBRACK] = ACTIONS(5539),
    [aux_sym_record_type_token1] = ACTIONS(5537),
    [aux_sym_basic_type_token21] = ACTIONS(5537),
    [aux_sym_basic_type_token22] = ACTIONS(5537),
    [aux_sym_basic_type_token48] = ACTIONS(5537),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5537),
    [anon_sym_POUNDif] = ACTIONS(5539),
    [anon_sym_POUNDIF] = ACTIONS(5539),
    [anon_sym_POUNDIf] = ACTIONS(5539),
    [anon_sym_not] = ACTIONS(5537),
    [anon_sym_NOT] = ACTIONS(5537),
    [anon_sym_Not] = ACTIONS(5537),
    [anon_sym_POUNDelse] = ACTIONS(5539),
    [anon_sym_POUNDELSE] = ACTIONS(5539),
    [anon_sym_POUNDElse] = ACTIONS(5539),
    [anon_sym_POUNDelse2] = ACTIONS(5539),
    [anon_sym_POUNDELSE2] = ACTIONS(5539),
    [anon_sym_POUNDElse2] = ACTIONS(5539),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5537),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5537),
    [anon_sym_PLUS] = ACTIONS(5539),
    [sym_datetime_literal] = ACTIONS(5539),
    [sym_date_literal] = ACTIONS(5537),
    [sym_time_literal] = ACTIONS(5537),
    [sym_biginteger_literal] = ACTIONS(5539),
    [anon_sym_if] = ACTIONS(5537),
    [anon_sym_IF] = ACTIONS(5537),
    [anon_sym_If] = ACTIONS(5537),
    [anon_sym_else] = ACTIONS(5537),
    [anon_sym_ELSE] = ACTIONS(5537),
    [anon_sym_Else] = ACTIONS(5537),
    [anon_sym_case] = ACTIONS(5537),
    [anon_sym_CASE] = ACTIONS(5537),
    [anon_sym_Case] = ACTIONS(5537),
    [anon_sym_for] = ACTIONS(5537),
    [anon_sym_FOR] = ACTIONS(5537),
    [anon_sym_For] = ACTIONS(5537),
    [anon_sym_foreach] = ACTIONS(5537),
    [anon_sym_FOREACH] = ACTIONS(5537),
    [anon_sym_Foreach] = ACTIONS(5537),
    [anon_sym_while] = ACTIONS(5537),
    [anon_sym_WHILE] = ACTIONS(5537),
    [anon_sym_While] = ACTIONS(5537),
    [anon_sym_repeat] = ACTIONS(5537),
    [anon_sym_REPEAT] = ACTIONS(5537),
    [anon_sym_Repeat] = ACTIONS(5537),
    [anon_sym_until] = ACTIONS(5537),
    [anon_sym_UNTIL] = ACTIONS(5537),
    [anon_sym_Until] = ACTIONS(5537),
    [anon_sym_exit] = ACTIONS(5537),
    [anon_sym_EXIT] = ACTIONS(5537),
    [anon_sym_Exit] = ACTIONS(5537),
    [anon_sym_continue] = ACTIONS(5537),
    [anon_sym_CONTINUE] = ACTIONS(5537),
    [anon_sym_Continue] = ACTIONS(5537),
    [anon_sym_break] = ACTIONS(5537),
    [anon_sym_BREAK] = ACTIONS(5537),
    [anon_sym_Break] = ACTIONS(5537),
    [anon_sym_with] = ACTIONS(5537),
    [anon_sym_WITH] = ACTIONS(5537),
    [anon_sym_With] = ACTIONS(5537),
    [sym_asserterror_keyword] = ACTIONS(5539),
    [sym_page_keyword] = ACTIONS(5537),
    [anon_sym_codeunit] = ACTIONS(5537),
    [anon_sym_CODEUNIT] = ACTIONS(5537),
    [anon_sym_Codeunit] = ACTIONS(5537),
    [anon_sym_CodeUnit] = ACTIONS(5537),
    [anon_sym_COdeunit] = ACTIONS(5537),
    [anon_sym_codeUnit] = ACTIONS(5537),
    [sym_report_keyword] = ACTIONS(5537),
    [sym_query_keyword] = ACTIONS(5537),
    [anon_sym_xmlport] = ACTIONS(5537),
    [anon_sym_XMLPORT] = ACTIONS(5537),
    [anon_sym_Xmlport] = ACTIONS(5537),
    [anon_sym_XMLport] = ACTIONS(5537),
    [anon_sym_XMLPort] = ACTIONS(5537),
    [anon_sym_XmlPort] = ACTIONS(5537),
    [anon_sym_enum] = ACTIONS(5537),
    [anon_sym_ENUM] = ACTIONS(5537),
    [anon_sym_Enum] = ACTIONS(5537),
    [anon_sym_eNUM] = ACTIONS(5537),
    [anon_sym_eNum] = ACTIONS(5537),
    [anon_sym_ENum] = ACTIONS(5537),
    [sym_quoted_identifier] = ACTIONS(5539),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5539),
    [sym_verbatim_string] = ACTIONS(5539),
    [sym_integer] = ACTIONS(5537),
    [sym_continue_as_identifier] = ACTIONS(5539),
    [sym_preproc_open] = ACTIONS(5539),
  },
  [STATE(2973)] = {
    [sym_identifier] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym_DASH] = ACTIONS(5543),
    [aux_sym_boolean_token1] = ACTIONS(5541),
    [aux_sym_boolean_token2] = ACTIONS(5541),
    [sym_decimal] = ACTIONS(5541),
    [anon_sym_LPAREN] = ACTIONS(5543),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5543),
    [aux_sym_record_type_token1] = ACTIONS(5541),
    [aux_sym_basic_type_token21] = ACTIONS(5541),
    [aux_sym_basic_type_token22] = ACTIONS(5541),
    [aux_sym_basic_type_token48] = ACTIONS(5541),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5541),
    [anon_sym_POUNDif] = ACTIONS(5543),
    [anon_sym_POUNDIF] = ACTIONS(5543),
    [anon_sym_POUNDIf] = ACTIONS(5543),
    [anon_sym_not] = ACTIONS(5541),
    [anon_sym_NOT] = ACTIONS(5541),
    [anon_sym_Not] = ACTIONS(5541),
    [anon_sym_POUNDelse] = ACTIONS(5543),
    [anon_sym_POUNDELSE] = ACTIONS(5543),
    [anon_sym_POUNDElse] = ACTIONS(5543),
    [anon_sym_POUNDelse2] = ACTIONS(5543),
    [anon_sym_POUNDELSE2] = ACTIONS(5543),
    [anon_sym_POUNDElse2] = ACTIONS(5543),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5541),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5541),
    [anon_sym_PLUS] = ACTIONS(5543),
    [sym_datetime_literal] = ACTIONS(5543),
    [sym_date_literal] = ACTIONS(5541),
    [sym_time_literal] = ACTIONS(5541),
    [sym_biginteger_literal] = ACTIONS(5543),
    [anon_sym_if] = ACTIONS(5541),
    [anon_sym_IF] = ACTIONS(5541),
    [anon_sym_If] = ACTIONS(5541),
    [anon_sym_else] = ACTIONS(5541),
    [anon_sym_ELSE] = ACTIONS(5541),
    [anon_sym_Else] = ACTIONS(5541),
    [anon_sym_case] = ACTIONS(5541),
    [anon_sym_CASE] = ACTIONS(5541),
    [anon_sym_Case] = ACTIONS(5541),
    [anon_sym_for] = ACTIONS(5541),
    [anon_sym_FOR] = ACTIONS(5541),
    [anon_sym_For] = ACTIONS(5541),
    [anon_sym_foreach] = ACTIONS(5541),
    [anon_sym_FOREACH] = ACTIONS(5541),
    [anon_sym_Foreach] = ACTIONS(5541),
    [anon_sym_while] = ACTIONS(5541),
    [anon_sym_WHILE] = ACTIONS(5541),
    [anon_sym_While] = ACTIONS(5541),
    [anon_sym_repeat] = ACTIONS(5541),
    [anon_sym_REPEAT] = ACTIONS(5541),
    [anon_sym_Repeat] = ACTIONS(5541),
    [anon_sym_until] = ACTIONS(5541),
    [anon_sym_UNTIL] = ACTIONS(5541),
    [anon_sym_Until] = ACTIONS(5541),
    [anon_sym_exit] = ACTIONS(5541),
    [anon_sym_EXIT] = ACTIONS(5541),
    [anon_sym_Exit] = ACTIONS(5541),
    [anon_sym_continue] = ACTIONS(5541),
    [anon_sym_CONTINUE] = ACTIONS(5541),
    [anon_sym_Continue] = ACTIONS(5541),
    [anon_sym_break] = ACTIONS(5541),
    [anon_sym_BREAK] = ACTIONS(5541),
    [anon_sym_Break] = ACTIONS(5541),
    [anon_sym_with] = ACTIONS(5541),
    [anon_sym_WITH] = ACTIONS(5541),
    [anon_sym_With] = ACTIONS(5541),
    [sym_asserterror_keyword] = ACTIONS(5543),
    [sym_page_keyword] = ACTIONS(5541),
    [anon_sym_codeunit] = ACTIONS(5541),
    [anon_sym_CODEUNIT] = ACTIONS(5541),
    [anon_sym_Codeunit] = ACTIONS(5541),
    [anon_sym_CodeUnit] = ACTIONS(5541),
    [anon_sym_COdeunit] = ACTIONS(5541),
    [anon_sym_codeUnit] = ACTIONS(5541),
    [sym_report_keyword] = ACTIONS(5541),
    [sym_query_keyword] = ACTIONS(5541),
    [anon_sym_xmlport] = ACTIONS(5541),
    [anon_sym_XMLPORT] = ACTIONS(5541),
    [anon_sym_Xmlport] = ACTIONS(5541),
    [anon_sym_XMLport] = ACTIONS(5541),
    [anon_sym_XMLPort] = ACTIONS(5541),
    [anon_sym_XmlPort] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_ENUM] = ACTIONS(5541),
    [anon_sym_Enum] = ACTIONS(5541),
    [anon_sym_eNUM] = ACTIONS(5541),
    [anon_sym_eNum] = ACTIONS(5541),
    [anon_sym_ENum] = ACTIONS(5541),
    [sym_quoted_identifier] = ACTIONS(5543),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5543),
    [sym_verbatim_string] = ACTIONS(5543),
    [sym_integer] = ACTIONS(5541),
    [sym_continue_as_identifier] = ACTIONS(5543),
    [sym_preproc_open] = ACTIONS(5543),
  },
  [STATE(2974)] = {
    [sym_identifier] = ACTIONS(5545),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym_DASH] = ACTIONS(5547),
    [aux_sym_boolean_token1] = ACTIONS(5545),
    [aux_sym_boolean_token2] = ACTIONS(5545),
    [sym_decimal] = ACTIONS(5545),
    [anon_sym_LPAREN] = ACTIONS(5547),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5547),
    [aux_sym_record_type_token1] = ACTIONS(5545),
    [aux_sym_basic_type_token21] = ACTIONS(5545),
    [aux_sym_basic_type_token22] = ACTIONS(5545),
    [aux_sym_basic_type_token48] = ACTIONS(5545),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5545),
    [anon_sym_POUNDif] = ACTIONS(5547),
    [anon_sym_POUNDIF] = ACTIONS(5547),
    [anon_sym_POUNDIf] = ACTIONS(5547),
    [anon_sym_not] = ACTIONS(5545),
    [anon_sym_NOT] = ACTIONS(5545),
    [anon_sym_Not] = ACTIONS(5545),
    [anon_sym_POUNDelse] = ACTIONS(5547),
    [anon_sym_POUNDELSE] = ACTIONS(5547),
    [anon_sym_POUNDElse] = ACTIONS(5547),
    [anon_sym_POUNDelse2] = ACTIONS(5547),
    [anon_sym_POUNDELSE2] = ACTIONS(5547),
    [anon_sym_POUNDElse2] = ACTIONS(5547),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5545),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5545),
    [anon_sym_PLUS] = ACTIONS(5547),
    [sym_datetime_literal] = ACTIONS(5547),
    [sym_date_literal] = ACTIONS(5545),
    [sym_time_literal] = ACTIONS(5545),
    [sym_biginteger_literal] = ACTIONS(5547),
    [anon_sym_if] = ACTIONS(5545),
    [anon_sym_IF] = ACTIONS(5545),
    [anon_sym_If] = ACTIONS(5545),
    [anon_sym_else] = ACTIONS(5545),
    [anon_sym_ELSE] = ACTIONS(5545),
    [anon_sym_Else] = ACTIONS(5545),
    [anon_sym_case] = ACTIONS(5545),
    [anon_sym_CASE] = ACTIONS(5545),
    [anon_sym_Case] = ACTIONS(5545),
    [anon_sym_for] = ACTIONS(5545),
    [anon_sym_FOR] = ACTIONS(5545),
    [anon_sym_For] = ACTIONS(5545),
    [anon_sym_foreach] = ACTIONS(5545),
    [anon_sym_FOREACH] = ACTIONS(5545),
    [anon_sym_Foreach] = ACTIONS(5545),
    [anon_sym_while] = ACTIONS(5545),
    [anon_sym_WHILE] = ACTIONS(5545),
    [anon_sym_While] = ACTIONS(5545),
    [anon_sym_repeat] = ACTIONS(5545),
    [anon_sym_REPEAT] = ACTIONS(5545),
    [anon_sym_Repeat] = ACTIONS(5545),
    [anon_sym_until] = ACTIONS(5545),
    [anon_sym_UNTIL] = ACTIONS(5545),
    [anon_sym_Until] = ACTIONS(5545),
    [anon_sym_exit] = ACTIONS(5545),
    [anon_sym_EXIT] = ACTIONS(5545),
    [anon_sym_Exit] = ACTIONS(5545),
    [anon_sym_continue] = ACTIONS(5545),
    [anon_sym_CONTINUE] = ACTIONS(5545),
    [anon_sym_Continue] = ACTIONS(5545),
    [anon_sym_break] = ACTIONS(5545),
    [anon_sym_BREAK] = ACTIONS(5545),
    [anon_sym_Break] = ACTIONS(5545),
    [anon_sym_with] = ACTIONS(5545),
    [anon_sym_WITH] = ACTIONS(5545),
    [anon_sym_With] = ACTIONS(5545),
    [sym_asserterror_keyword] = ACTIONS(5547),
    [sym_page_keyword] = ACTIONS(5545),
    [anon_sym_codeunit] = ACTIONS(5545),
    [anon_sym_CODEUNIT] = ACTIONS(5545),
    [anon_sym_Codeunit] = ACTIONS(5545),
    [anon_sym_CodeUnit] = ACTIONS(5545),
    [anon_sym_COdeunit] = ACTIONS(5545),
    [anon_sym_codeUnit] = ACTIONS(5545),
    [sym_report_keyword] = ACTIONS(5545),
    [sym_query_keyword] = ACTIONS(5545),
    [anon_sym_xmlport] = ACTIONS(5545),
    [anon_sym_XMLPORT] = ACTIONS(5545),
    [anon_sym_Xmlport] = ACTIONS(5545),
    [anon_sym_XMLport] = ACTIONS(5545),
    [anon_sym_XMLPort] = ACTIONS(5545),
    [anon_sym_XmlPort] = ACTIONS(5545),
    [anon_sym_enum] = ACTIONS(5545),
    [anon_sym_ENUM] = ACTIONS(5545),
    [anon_sym_Enum] = ACTIONS(5545),
    [anon_sym_eNUM] = ACTIONS(5545),
    [anon_sym_eNum] = ACTIONS(5545),
    [anon_sym_ENum] = ACTIONS(5545),
    [sym_quoted_identifier] = ACTIONS(5547),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5547),
    [sym_verbatim_string] = ACTIONS(5547),
    [sym_integer] = ACTIONS(5545),
    [sym_continue_as_identifier] = ACTIONS(5547),
    [sym_preproc_open] = ACTIONS(5547),
  },
  [STATE(2975)] = {
    [sym_identifier] = ACTIONS(5549),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym_DASH] = ACTIONS(5551),
    [aux_sym_boolean_token1] = ACTIONS(5549),
    [aux_sym_boolean_token2] = ACTIONS(5549),
    [sym_decimal] = ACTIONS(5549),
    [anon_sym_LPAREN] = ACTIONS(5551),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5549),
    [anon_sym_LBRACK] = ACTIONS(5551),
    [aux_sym_record_type_token1] = ACTIONS(5549),
    [aux_sym_basic_type_token21] = ACTIONS(5549),
    [aux_sym_basic_type_token22] = ACTIONS(5549),
    [aux_sym_basic_type_token48] = ACTIONS(5549),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5549),
    [anon_sym_POUNDif] = ACTIONS(5551),
    [anon_sym_POUNDIF] = ACTIONS(5551),
    [anon_sym_POUNDIf] = ACTIONS(5551),
    [anon_sym_not] = ACTIONS(5549),
    [anon_sym_NOT] = ACTIONS(5549),
    [anon_sym_Not] = ACTIONS(5549),
    [anon_sym_POUNDelse] = ACTIONS(5551),
    [anon_sym_POUNDELSE] = ACTIONS(5551),
    [anon_sym_POUNDElse] = ACTIONS(5551),
    [anon_sym_POUNDelse2] = ACTIONS(5551),
    [anon_sym_POUNDELSE2] = ACTIONS(5551),
    [anon_sym_POUNDElse2] = ACTIONS(5551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5549),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5549),
    [anon_sym_PLUS] = ACTIONS(5551),
    [sym_datetime_literal] = ACTIONS(5551),
    [sym_date_literal] = ACTIONS(5549),
    [sym_time_literal] = ACTIONS(5549),
    [sym_biginteger_literal] = ACTIONS(5551),
    [anon_sym_if] = ACTIONS(5549),
    [anon_sym_IF] = ACTIONS(5549),
    [anon_sym_If] = ACTIONS(5549),
    [anon_sym_else] = ACTIONS(5549),
    [anon_sym_ELSE] = ACTIONS(5549),
    [anon_sym_Else] = ACTIONS(5549),
    [anon_sym_case] = ACTIONS(5549),
    [anon_sym_CASE] = ACTIONS(5549),
    [anon_sym_Case] = ACTIONS(5549),
    [anon_sym_for] = ACTIONS(5549),
    [anon_sym_FOR] = ACTIONS(5549),
    [anon_sym_For] = ACTIONS(5549),
    [anon_sym_foreach] = ACTIONS(5549),
    [anon_sym_FOREACH] = ACTIONS(5549),
    [anon_sym_Foreach] = ACTIONS(5549),
    [anon_sym_while] = ACTIONS(5549),
    [anon_sym_WHILE] = ACTIONS(5549),
    [anon_sym_While] = ACTIONS(5549),
    [anon_sym_repeat] = ACTIONS(5549),
    [anon_sym_REPEAT] = ACTIONS(5549),
    [anon_sym_Repeat] = ACTIONS(5549),
    [anon_sym_until] = ACTIONS(5549),
    [anon_sym_UNTIL] = ACTIONS(5549),
    [anon_sym_Until] = ACTIONS(5549),
    [anon_sym_exit] = ACTIONS(5549),
    [anon_sym_EXIT] = ACTIONS(5549),
    [anon_sym_Exit] = ACTIONS(5549),
    [anon_sym_continue] = ACTIONS(5549),
    [anon_sym_CONTINUE] = ACTIONS(5549),
    [anon_sym_Continue] = ACTIONS(5549),
    [anon_sym_break] = ACTIONS(5549),
    [anon_sym_BREAK] = ACTIONS(5549),
    [anon_sym_Break] = ACTIONS(5549),
    [anon_sym_with] = ACTIONS(5549),
    [anon_sym_WITH] = ACTIONS(5549),
    [anon_sym_With] = ACTIONS(5549),
    [sym_asserterror_keyword] = ACTIONS(5551),
    [sym_page_keyword] = ACTIONS(5549),
    [anon_sym_codeunit] = ACTIONS(5549),
    [anon_sym_CODEUNIT] = ACTIONS(5549),
    [anon_sym_Codeunit] = ACTIONS(5549),
    [anon_sym_CodeUnit] = ACTIONS(5549),
    [anon_sym_COdeunit] = ACTIONS(5549),
    [anon_sym_codeUnit] = ACTIONS(5549),
    [sym_report_keyword] = ACTIONS(5549),
    [sym_query_keyword] = ACTIONS(5549),
    [anon_sym_xmlport] = ACTIONS(5549),
    [anon_sym_XMLPORT] = ACTIONS(5549),
    [anon_sym_Xmlport] = ACTIONS(5549),
    [anon_sym_XMLport] = ACTIONS(5549),
    [anon_sym_XMLPort] = ACTIONS(5549),
    [anon_sym_XmlPort] = ACTIONS(5549),
    [anon_sym_enum] = ACTIONS(5549),
    [anon_sym_ENUM] = ACTIONS(5549),
    [anon_sym_Enum] = ACTIONS(5549),
    [anon_sym_eNUM] = ACTIONS(5549),
    [anon_sym_eNum] = ACTIONS(5549),
    [anon_sym_ENum] = ACTIONS(5549),
    [sym_quoted_identifier] = ACTIONS(5551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5551),
    [sym_verbatim_string] = ACTIONS(5551),
    [sym_integer] = ACTIONS(5549),
    [sym_continue_as_identifier] = ACTIONS(5551),
    [sym_preproc_open] = ACTIONS(5551),
  },
  [STATE(2976)] = {
    [sym_identifier] = ACTIONS(5553),
    [anon_sym_SEMI] = ACTIONS(5555),
    [anon_sym_DASH] = ACTIONS(5555),
    [aux_sym_boolean_token1] = ACTIONS(5553),
    [aux_sym_boolean_token2] = ACTIONS(5553),
    [sym_decimal] = ACTIONS(5553),
    [anon_sym_LPAREN] = ACTIONS(5555),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5553),
    [anon_sym_LBRACK] = ACTIONS(5555),
    [aux_sym_record_type_token1] = ACTIONS(5553),
    [aux_sym_basic_type_token21] = ACTIONS(5553),
    [aux_sym_basic_type_token22] = ACTIONS(5553),
    [aux_sym_basic_type_token48] = ACTIONS(5553),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5553),
    [anon_sym_POUNDif] = ACTIONS(5555),
    [anon_sym_POUNDIF] = ACTIONS(5555),
    [anon_sym_POUNDIf] = ACTIONS(5555),
    [anon_sym_not] = ACTIONS(5553),
    [anon_sym_NOT] = ACTIONS(5553),
    [anon_sym_Not] = ACTIONS(5553),
    [anon_sym_POUNDelse] = ACTIONS(5555),
    [anon_sym_POUNDELSE] = ACTIONS(5555),
    [anon_sym_POUNDElse] = ACTIONS(5555),
    [anon_sym_POUNDelse2] = ACTIONS(5555),
    [anon_sym_POUNDELSE2] = ACTIONS(5555),
    [anon_sym_POUNDElse2] = ACTIONS(5555),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5553),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5553),
    [anon_sym_PLUS] = ACTIONS(5555),
    [sym_datetime_literal] = ACTIONS(5555),
    [sym_date_literal] = ACTIONS(5553),
    [sym_time_literal] = ACTIONS(5553),
    [sym_biginteger_literal] = ACTIONS(5555),
    [anon_sym_if] = ACTIONS(5553),
    [anon_sym_IF] = ACTIONS(5553),
    [anon_sym_If] = ACTIONS(5553),
    [anon_sym_else] = ACTIONS(5553),
    [anon_sym_ELSE] = ACTIONS(5553),
    [anon_sym_Else] = ACTIONS(5553),
    [anon_sym_case] = ACTIONS(5553),
    [anon_sym_CASE] = ACTIONS(5553),
    [anon_sym_Case] = ACTIONS(5553),
    [anon_sym_for] = ACTIONS(5553),
    [anon_sym_FOR] = ACTIONS(5553),
    [anon_sym_For] = ACTIONS(5553),
    [anon_sym_foreach] = ACTIONS(5553),
    [anon_sym_FOREACH] = ACTIONS(5553),
    [anon_sym_Foreach] = ACTIONS(5553),
    [anon_sym_while] = ACTIONS(5553),
    [anon_sym_WHILE] = ACTIONS(5553),
    [anon_sym_While] = ACTIONS(5553),
    [anon_sym_repeat] = ACTIONS(5553),
    [anon_sym_REPEAT] = ACTIONS(5553),
    [anon_sym_Repeat] = ACTIONS(5553),
    [anon_sym_until] = ACTIONS(5553),
    [anon_sym_UNTIL] = ACTIONS(5553),
    [anon_sym_Until] = ACTIONS(5553),
    [anon_sym_exit] = ACTIONS(5553),
    [anon_sym_EXIT] = ACTIONS(5553),
    [anon_sym_Exit] = ACTIONS(5553),
    [anon_sym_continue] = ACTIONS(5553),
    [anon_sym_CONTINUE] = ACTIONS(5553),
    [anon_sym_Continue] = ACTIONS(5553),
    [anon_sym_break] = ACTIONS(5553),
    [anon_sym_BREAK] = ACTIONS(5553),
    [anon_sym_Break] = ACTIONS(5553),
    [anon_sym_with] = ACTIONS(5553),
    [anon_sym_WITH] = ACTIONS(5553),
    [anon_sym_With] = ACTIONS(5553),
    [sym_asserterror_keyword] = ACTIONS(5555),
    [sym_page_keyword] = ACTIONS(5553),
    [anon_sym_codeunit] = ACTIONS(5553),
    [anon_sym_CODEUNIT] = ACTIONS(5553),
    [anon_sym_Codeunit] = ACTIONS(5553),
    [anon_sym_CodeUnit] = ACTIONS(5553),
    [anon_sym_COdeunit] = ACTIONS(5553),
    [anon_sym_codeUnit] = ACTIONS(5553),
    [sym_report_keyword] = ACTIONS(5553),
    [sym_query_keyword] = ACTIONS(5553),
    [anon_sym_xmlport] = ACTIONS(5553),
    [anon_sym_XMLPORT] = ACTIONS(5553),
    [anon_sym_Xmlport] = ACTIONS(5553),
    [anon_sym_XMLport] = ACTIONS(5553),
    [anon_sym_XMLPort] = ACTIONS(5553),
    [anon_sym_XmlPort] = ACTIONS(5553),
    [anon_sym_enum] = ACTIONS(5553),
    [anon_sym_ENUM] = ACTIONS(5553),
    [anon_sym_Enum] = ACTIONS(5553),
    [anon_sym_eNUM] = ACTIONS(5553),
    [anon_sym_eNum] = ACTIONS(5553),
    [anon_sym_ENum] = ACTIONS(5553),
    [sym_quoted_identifier] = ACTIONS(5555),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5555),
    [sym_verbatim_string] = ACTIONS(5555),
    [sym_integer] = ACTIONS(5553),
    [sym_continue_as_identifier] = ACTIONS(5555),
    [sym_preproc_open] = ACTIONS(5555),
  },
  [STATE(2977)] = {
    [sym_identifier] = ACTIONS(5557),
    [anon_sym_SEMI] = ACTIONS(5559),
    [anon_sym_DASH] = ACTIONS(5559),
    [aux_sym_boolean_token1] = ACTIONS(5557),
    [aux_sym_boolean_token2] = ACTIONS(5557),
    [sym_decimal] = ACTIONS(5557),
    [anon_sym_LPAREN] = ACTIONS(5559),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5557),
    [anon_sym_LBRACK] = ACTIONS(5559),
    [aux_sym_record_type_token1] = ACTIONS(5557),
    [aux_sym_basic_type_token21] = ACTIONS(5557),
    [aux_sym_basic_type_token22] = ACTIONS(5557),
    [aux_sym_basic_type_token48] = ACTIONS(5557),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5557),
    [anon_sym_POUNDif] = ACTIONS(5559),
    [anon_sym_POUNDIF] = ACTIONS(5559),
    [anon_sym_POUNDIf] = ACTIONS(5559),
    [anon_sym_not] = ACTIONS(5557),
    [anon_sym_NOT] = ACTIONS(5557),
    [anon_sym_Not] = ACTIONS(5557),
    [anon_sym_POUNDelse] = ACTIONS(5559),
    [anon_sym_POUNDELSE] = ACTIONS(5559),
    [anon_sym_POUNDElse] = ACTIONS(5559),
    [anon_sym_POUNDelse2] = ACTIONS(5559),
    [anon_sym_POUNDELSE2] = ACTIONS(5559),
    [anon_sym_POUNDElse2] = ACTIONS(5559),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5557),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5557),
    [anon_sym_PLUS] = ACTIONS(5559),
    [sym_datetime_literal] = ACTIONS(5559),
    [sym_date_literal] = ACTIONS(5557),
    [sym_time_literal] = ACTIONS(5557),
    [sym_biginteger_literal] = ACTIONS(5559),
    [anon_sym_if] = ACTIONS(5557),
    [anon_sym_IF] = ACTIONS(5557),
    [anon_sym_If] = ACTIONS(5557),
    [anon_sym_else] = ACTIONS(5557),
    [anon_sym_ELSE] = ACTIONS(5557),
    [anon_sym_Else] = ACTIONS(5557),
    [anon_sym_case] = ACTIONS(5557),
    [anon_sym_CASE] = ACTIONS(5557),
    [anon_sym_Case] = ACTIONS(5557),
    [anon_sym_for] = ACTIONS(5557),
    [anon_sym_FOR] = ACTIONS(5557),
    [anon_sym_For] = ACTIONS(5557),
    [anon_sym_foreach] = ACTIONS(5557),
    [anon_sym_FOREACH] = ACTIONS(5557),
    [anon_sym_Foreach] = ACTIONS(5557),
    [anon_sym_while] = ACTIONS(5557),
    [anon_sym_WHILE] = ACTIONS(5557),
    [anon_sym_While] = ACTIONS(5557),
    [anon_sym_repeat] = ACTIONS(5557),
    [anon_sym_REPEAT] = ACTIONS(5557),
    [anon_sym_Repeat] = ACTIONS(5557),
    [anon_sym_until] = ACTIONS(5557),
    [anon_sym_UNTIL] = ACTIONS(5557),
    [anon_sym_Until] = ACTIONS(5557),
    [anon_sym_exit] = ACTIONS(5557),
    [anon_sym_EXIT] = ACTIONS(5557),
    [anon_sym_Exit] = ACTIONS(5557),
    [anon_sym_continue] = ACTIONS(5557),
    [anon_sym_CONTINUE] = ACTIONS(5557),
    [anon_sym_Continue] = ACTIONS(5557),
    [anon_sym_break] = ACTIONS(5557),
    [anon_sym_BREAK] = ACTIONS(5557),
    [anon_sym_Break] = ACTIONS(5557),
    [anon_sym_with] = ACTIONS(5557),
    [anon_sym_WITH] = ACTIONS(5557),
    [anon_sym_With] = ACTIONS(5557),
    [sym_asserterror_keyword] = ACTIONS(5559),
    [sym_page_keyword] = ACTIONS(5557),
    [anon_sym_codeunit] = ACTIONS(5557),
    [anon_sym_CODEUNIT] = ACTIONS(5557),
    [anon_sym_Codeunit] = ACTIONS(5557),
    [anon_sym_CodeUnit] = ACTIONS(5557),
    [anon_sym_COdeunit] = ACTIONS(5557),
    [anon_sym_codeUnit] = ACTIONS(5557),
    [sym_report_keyword] = ACTIONS(5557),
    [sym_query_keyword] = ACTIONS(5557),
    [anon_sym_xmlport] = ACTIONS(5557),
    [anon_sym_XMLPORT] = ACTIONS(5557),
    [anon_sym_Xmlport] = ACTIONS(5557),
    [anon_sym_XMLport] = ACTIONS(5557),
    [anon_sym_XMLPort] = ACTIONS(5557),
    [anon_sym_XmlPort] = ACTIONS(5557),
    [anon_sym_enum] = ACTIONS(5557),
    [anon_sym_ENUM] = ACTIONS(5557),
    [anon_sym_Enum] = ACTIONS(5557),
    [anon_sym_eNUM] = ACTIONS(5557),
    [anon_sym_eNum] = ACTIONS(5557),
    [anon_sym_ENum] = ACTIONS(5557),
    [sym_quoted_identifier] = ACTIONS(5559),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5559),
    [sym_verbatim_string] = ACTIONS(5559),
    [sym_integer] = ACTIONS(5557),
    [sym_continue_as_identifier] = ACTIONS(5559),
    [sym_preproc_open] = ACTIONS(5559),
  },
  [STATE(2978)] = {
    [sym_identifier] = ACTIONS(5561),
    [anon_sym_SEMI] = ACTIONS(5563),
    [anon_sym_DASH] = ACTIONS(5563),
    [aux_sym_boolean_token1] = ACTIONS(5561),
    [aux_sym_boolean_token2] = ACTIONS(5561),
    [sym_decimal] = ACTIONS(5561),
    [anon_sym_LPAREN] = ACTIONS(5563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5561),
    [anon_sym_LBRACK] = ACTIONS(5563),
    [aux_sym_record_type_token1] = ACTIONS(5561),
    [aux_sym_basic_type_token21] = ACTIONS(5561),
    [aux_sym_basic_type_token22] = ACTIONS(5561),
    [aux_sym_basic_type_token48] = ACTIONS(5561),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5561),
    [anon_sym_POUNDif] = ACTIONS(5563),
    [anon_sym_POUNDIF] = ACTIONS(5563),
    [anon_sym_POUNDIf] = ACTIONS(5563),
    [anon_sym_not] = ACTIONS(5561),
    [anon_sym_NOT] = ACTIONS(5561),
    [anon_sym_Not] = ACTIONS(5561),
    [anon_sym_POUNDelse] = ACTIONS(5563),
    [anon_sym_POUNDELSE] = ACTIONS(5563),
    [anon_sym_POUNDElse] = ACTIONS(5563),
    [anon_sym_POUNDelse2] = ACTIONS(5563),
    [anon_sym_POUNDELSE2] = ACTIONS(5563),
    [anon_sym_POUNDElse2] = ACTIONS(5563),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5561),
    [anon_sym_PLUS] = ACTIONS(5563),
    [sym_datetime_literal] = ACTIONS(5563),
    [sym_date_literal] = ACTIONS(5561),
    [sym_time_literal] = ACTIONS(5561),
    [sym_biginteger_literal] = ACTIONS(5563),
    [anon_sym_if] = ACTIONS(5561),
    [anon_sym_IF] = ACTIONS(5561),
    [anon_sym_If] = ACTIONS(5561),
    [anon_sym_else] = ACTIONS(5561),
    [anon_sym_ELSE] = ACTIONS(5561),
    [anon_sym_Else] = ACTIONS(5561),
    [anon_sym_case] = ACTIONS(5561),
    [anon_sym_CASE] = ACTIONS(5561),
    [anon_sym_Case] = ACTIONS(5561),
    [anon_sym_for] = ACTIONS(5561),
    [anon_sym_FOR] = ACTIONS(5561),
    [anon_sym_For] = ACTIONS(5561),
    [anon_sym_foreach] = ACTIONS(5561),
    [anon_sym_FOREACH] = ACTIONS(5561),
    [anon_sym_Foreach] = ACTIONS(5561),
    [anon_sym_while] = ACTIONS(5561),
    [anon_sym_WHILE] = ACTIONS(5561),
    [anon_sym_While] = ACTIONS(5561),
    [anon_sym_repeat] = ACTIONS(5561),
    [anon_sym_REPEAT] = ACTIONS(5561),
    [anon_sym_Repeat] = ACTIONS(5561),
    [anon_sym_until] = ACTIONS(5561),
    [anon_sym_UNTIL] = ACTIONS(5561),
    [anon_sym_Until] = ACTIONS(5561),
    [anon_sym_exit] = ACTIONS(5561),
    [anon_sym_EXIT] = ACTIONS(5561),
    [anon_sym_Exit] = ACTIONS(5561),
    [anon_sym_continue] = ACTIONS(5561),
    [anon_sym_CONTINUE] = ACTIONS(5561),
    [anon_sym_Continue] = ACTIONS(5561),
    [anon_sym_break] = ACTIONS(5561),
    [anon_sym_BREAK] = ACTIONS(5561),
    [anon_sym_Break] = ACTIONS(5561),
    [anon_sym_with] = ACTIONS(5561),
    [anon_sym_WITH] = ACTIONS(5561),
    [anon_sym_With] = ACTIONS(5561),
    [sym_asserterror_keyword] = ACTIONS(5563),
    [sym_page_keyword] = ACTIONS(5561),
    [anon_sym_codeunit] = ACTIONS(5561),
    [anon_sym_CODEUNIT] = ACTIONS(5561),
    [anon_sym_Codeunit] = ACTIONS(5561),
    [anon_sym_CodeUnit] = ACTIONS(5561),
    [anon_sym_COdeunit] = ACTIONS(5561),
    [anon_sym_codeUnit] = ACTIONS(5561),
    [sym_report_keyword] = ACTIONS(5561),
    [sym_query_keyword] = ACTIONS(5561),
    [anon_sym_xmlport] = ACTIONS(5561),
    [anon_sym_XMLPORT] = ACTIONS(5561),
    [anon_sym_Xmlport] = ACTIONS(5561),
    [anon_sym_XMLport] = ACTIONS(5561),
    [anon_sym_XMLPort] = ACTIONS(5561),
    [anon_sym_XmlPort] = ACTIONS(5561),
    [anon_sym_enum] = ACTIONS(5561),
    [anon_sym_ENUM] = ACTIONS(5561),
    [anon_sym_Enum] = ACTIONS(5561),
    [anon_sym_eNUM] = ACTIONS(5561),
    [anon_sym_eNum] = ACTIONS(5561),
    [anon_sym_ENum] = ACTIONS(5561),
    [sym_quoted_identifier] = ACTIONS(5563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5563),
    [sym_verbatim_string] = ACTIONS(5563),
    [sym_integer] = ACTIONS(5561),
    [sym_continue_as_identifier] = ACTIONS(5563),
    [sym_preproc_open] = ACTIONS(5563),
  },
  [STATE(2979)] = {
    [sym_identifier] = ACTIONS(5565),
    [anon_sym_SEMI] = ACTIONS(5567),
    [anon_sym_DASH] = ACTIONS(5567),
    [aux_sym_boolean_token1] = ACTIONS(5565),
    [aux_sym_boolean_token2] = ACTIONS(5565),
    [sym_decimal] = ACTIONS(5565),
    [anon_sym_LPAREN] = ACTIONS(5567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5565),
    [anon_sym_LBRACK] = ACTIONS(5567),
    [aux_sym_record_type_token1] = ACTIONS(5565),
    [aux_sym_basic_type_token21] = ACTIONS(5565),
    [aux_sym_basic_type_token22] = ACTIONS(5565),
    [aux_sym_basic_type_token48] = ACTIONS(5565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5565),
    [anon_sym_POUNDif] = ACTIONS(5567),
    [anon_sym_POUNDIF] = ACTIONS(5567),
    [anon_sym_POUNDIf] = ACTIONS(5567),
    [anon_sym_not] = ACTIONS(5565),
    [anon_sym_NOT] = ACTIONS(5565),
    [anon_sym_Not] = ACTIONS(5565),
    [anon_sym_POUNDelse] = ACTIONS(5567),
    [anon_sym_POUNDELSE] = ACTIONS(5567),
    [anon_sym_POUNDElse] = ACTIONS(5567),
    [anon_sym_POUNDelse2] = ACTIONS(5567),
    [anon_sym_POUNDELSE2] = ACTIONS(5567),
    [anon_sym_POUNDElse2] = ACTIONS(5567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5565),
    [anon_sym_PLUS] = ACTIONS(5567),
    [sym_datetime_literal] = ACTIONS(5567),
    [sym_date_literal] = ACTIONS(5565),
    [sym_time_literal] = ACTIONS(5565),
    [sym_biginteger_literal] = ACTIONS(5567),
    [anon_sym_if] = ACTIONS(5565),
    [anon_sym_IF] = ACTIONS(5565),
    [anon_sym_If] = ACTIONS(5565),
    [anon_sym_else] = ACTIONS(5565),
    [anon_sym_ELSE] = ACTIONS(5565),
    [anon_sym_Else] = ACTIONS(5565),
    [anon_sym_case] = ACTIONS(5565),
    [anon_sym_CASE] = ACTIONS(5565),
    [anon_sym_Case] = ACTIONS(5565),
    [anon_sym_for] = ACTIONS(5565),
    [anon_sym_FOR] = ACTIONS(5565),
    [anon_sym_For] = ACTIONS(5565),
    [anon_sym_foreach] = ACTIONS(5565),
    [anon_sym_FOREACH] = ACTIONS(5565),
    [anon_sym_Foreach] = ACTIONS(5565),
    [anon_sym_while] = ACTIONS(5565),
    [anon_sym_WHILE] = ACTIONS(5565),
    [anon_sym_While] = ACTIONS(5565),
    [anon_sym_repeat] = ACTIONS(5565),
    [anon_sym_REPEAT] = ACTIONS(5565),
    [anon_sym_Repeat] = ACTIONS(5565),
    [anon_sym_until] = ACTIONS(5565),
    [anon_sym_UNTIL] = ACTIONS(5565),
    [anon_sym_Until] = ACTIONS(5565),
    [anon_sym_exit] = ACTIONS(5565),
    [anon_sym_EXIT] = ACTIONS(5565),
    [anon_sym_Exit] = ACTIONS(5565),
    [anon_sym_continue] = ACTIONS(5565),
    [anon_sym_CONTINUE] = ACTIONS(5565),
    [anon_sym_Continue] = ACTIONS(5565),
    [anon_sym_break] = ACTIONS(5565),
    [anon_sym_BREAK] = ACTIONS(5565),
    [anon_sym_Break] = ACTIONS(5565),
    [anon_sym_with] = ACTIONS(5565),
    [anon_sym_WITH] = ACTIONS(5565),
    [anon_sym_With] = ACTIONS(5565),
    [sym_asserterror_keyword] = ACTIONS(5567),
    [sym_page_keyword] = ACTIONS(5565),
    [anon_sym_codeunit] = ACTIONS(5565),
    [anon_sym_CODEUNIT] = ACTIONS(5565),
    [anon_sym_Codeunit] = ACTIONS(5565),
    [anon_sym_CodeUnit] = ACTIONS(5565),
    [anon_sym_COdeunit] = ACTIONS(5565),
    [anon_sym_codeUnit] = ACTIONS(5565),
    [sym_report_keyword] = ACTIONS(5565),
    [sym_query_keyword] = ACTIONS(5565),
    [anon_sym_xmlport] = ACTIONS(5565),
    [anon_sym_XMLPORT] = ACTIONS(5565),
    [anon_sym_Xmlport] = ACTIONS(5565),
    [anon_sym_XMLport] = ACTIONS(5565),
    [anon_sym_XMLPort] = ACTIONS(5565),
    [anon_sym_XmlPort] = ACTIONS(5565),
    [anon_sym_enum] = ACTIONS(5565),
    [anon_sym_ENUM] = ACTIONS(5565),
    [anon_sym_Enum] = ACTIONS(5565),
    [anon_sym_eNUM] = ACTIONS(5565),
    [anon_sym_eNum] = ACTIONS(5565),
    [anon_sym_ENum] = ACTIONS(5565),
    [sym_quoted_identifier] = ACTIONS(5567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5567),
    [sym_verbatim_string] = ACTIONS(5567),
    [sym_integer] = ACTIONS(5565),
    [sym_continue_as_identifier] = ACTIONS(5567),
    [sym_preproc_open] = ACTIONS(5567),
  },
  [STATE(2980)] = {
    [sym_identifier] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym_DASH] = ACTIONS(5571),
    [aux_sym_boolean_token1] = ACTIONS(5569),
    [aux_sym_boolean_token2] = ACTIONS(5569),
    [sym_decimal] = ACTIONS(5569),
    [anon_sym_LPAREN] = ACTIONS(5571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5571),
    [aux_sym_record_type_token1] = ACTIONS(5569),
    [aux_sym_basic_type_token21] = ACTIONS(5569),
    [aux_sym_basic_type_token22] = ACTIONS(5569),
    [aux_sym_basic_type_token48] = ACTIONS(5569),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5569),
    [anon_sym_POUNDif] = ACTIONS(5571),
    [anon_sym_POUNDIF] = ACTIONS(5571),
    [anon_sym_POUNDIf] = ACTIONS(5571),
    [anon_sym_not] = ACTIONS(5569),
    [anon_sym_NOT] = ACTIONS(5569),
    [anon_sym_Not] = ACTIONS(5569),
    [anon_sym_POUNDelse] = ACTIONS(5571),
    [anon_sym_POUNDELSE] = ACTIONS(5571),
    [anon_sym_POUNDElse] = ACTIONS(5571),
    [anon_sym_POUNDelse2] = ACTIONS(5571),
    [anon_sym_POUNDELSE2] = ACTIONS(5571),
    [anon_sym_POUNDElse2] = ACTIONS(5571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5569),
    [anon_sym_PLUS] = ACTIONS(5571),
    [sym_datetime_literal] = ACTIONS(5571),
    [sym_date_literal] = ACTIONS(5569),
    [sym_time_literal] = ACTIONS(5569),
    [sym_biginteger_literal] = ACTIONS(5571),
    [anon_sym_if] = ACTIONS(5569),
    [anon_sym_IF] = ACTIONS(5569),
    [anon_sym_If] = ACTIONS(5569),
    [anon_sym_else] = ACTIONS(5569),
    [anon_sym_ELSE] = ACTIONS(5569),
    [anon_sym_Else] = ACTIONS(5569),
    [anon_sym_case] = ACTIONS(5569),
    [anon_sym_CASE] = ACTIONS(5569),
    [anon_sym_Case] = ACTIONS(5569),
    [anon_sym_for] = ACTIONS(5569),
    [anon_sym_FOR] = ACTIONS(5569),
    [anon_sym_For] = ACTIONS(5569),
    [anon_sym_foreach] = ACTIONS(5569),
    [anon_sym_FOREACH] = ACTIONS(5569),
    [anon_sym_Foreach] = ACTIONS(5569),
    [anon_sym_while] = ACTIONS(5569),
    [anon_sym_WHILE] = ACTIONS(5569),
    [anon_sym_While] = ACTIONS(5569),
    [anon_sym_repeat] = ACTIONS(5569),
    [anon_sym_REPEAT] = ACTIONS(5569),
    [anon_sym_Repeat] = ACTIONS(5569),
    [anon_sym_until] = ACTIONS(5569),
    [anon_sym_UNTIL] = ACTIONS(5569),
    [anon_sym_Until] = ACTIONS(5569),
    [anon_sym_exit] = ACTIONS(5569),
    [anon_sym_EXIT] = ACTIONS(5569),
    [anon_sym_Exit] = ACTIONS(5569),
    [anon_sym_continue] = ACTIONS(5569),
    [anon_sym_CONTINUE] = ACTIONS(5569),
    [anon_sym_Continue] = ACTIONS(5569),
    [anon_sym_break] = ACTIONS(5569),
    [anon_sym_BREAK] = ACTIONS(5569),
    [anon_sym_Break] = ACTIONS(5569),
    [anon_sym_with] = ACTIONS(5569),
    [anon_sym_WITH] = ACTIONS(5569),
    [anon_sym_With] = ACTIONS(5569),
    [sym_asserterror_keyword] = ACTIONS(5571),
    [sym_page_keyword] = ACTIONS(5569),
    [anon_sym_codeunit] = ACTIONS(5569),
    [anon_sym_CODEUNIT] = ACTIONS(5569),
    [anon_sym_Codeunit] = ACTIONS(5569),
    [anon_sym_CodeUnit] = ACTIONS(5569),
    [anon_sym_COdeunit] = ACTIONS(5569),
    [anon_sym_codeUnit] = ACTIONS(5569),
    [sym_report_keyword] = ACTIONS(5569),
    [sym_query_keyword] = ACTIONS(5569),
    [anon_sym_xmlport] = ACTIONS(5569),
    [anon_sym_XMLPORT] = ACTIONS(5569),
    [anon_sym_Xmlport] = ACTIONS(5569),
    [anon_sym_XMLport] = ACTIONS(5569),
    [anon_sym_XMLPort] = ACTIONS(5569),
    [anon_sym_XmlPort] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_ENUM] = ACTIONS(5569),
    [anon_sym_Enum] = ACTIONS(5569),
    [anon_sym_eNUM] = ACTIONS(5569),
    [anon_sym_eNum] = ACTIONS(5569),
    [anon_sym_ENum] = ACTIONS(5569),
    [sym_quoted_identifier] = ACTIONS(5571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5571),
    [sym_verbatim_string] = ACTIONS(5571),
    [sym_integer] = ACTIONS(5569),
    [sym_continue_as_identifier] = ACTIONS(5571),
    [sym_preproc_open] = ACTIONS(5571),
  },
  [STATE(2981)] = {
    [sym_identifier] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym_DASH] = ACTIONS(5575),
    [aux_sym_boolean_token1] = ACTIONS(5573),
    [aux_sym_boolean_token2] = ACTIONS(5573),
    [sym_decimal] = ACTIONS(5573),
    [anon_sym_LPAREN] = ACTIONS(5575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5575),
    [aux_sym_record_type_token1] = ACTIONS(5573),
    [aux_sym_basic_type_token21] = ACTIONS(5573),
    [aux_sym_basic_type_token22] = ACTIONS(5573),
    [aux_sym_basic_type_token48] = ACTIONS(5573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5573),
    [anon_sym_POUNDif] = ACTIONS(5575),
    [anon_sym_POUNDIF] = ACTIONS(5575),
    [anon_sym_POUNDIf] = ACTIONS(5575),
    [anon_sym_not] = ACTIONS(5573),
    [anon_sym_NOT] = ACTIONS(5573),
    [anon_sym_Not] = ACTIONS(5573),
    [anon_sym_POUNDelse] = ACTIONS(5575),
    [anon_sym_POUNDELSE] = ACTIONS(5575),
    [anon_sym_POUNDElse] = ACTIONS(5575),
    [anon_sym_POUNDelse2] = ACTIONS(5575),
    [anon_sym_POUNDELSE2] = ACTIONS(5575),
    [anon_sym_POUNDElse2] = ACTIONS(5575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5573),
    [anon_sym_PLUS] = ACTIONS(5575),
    [sym_datetime_literal] = ACTIONS(5575),
    [sym_date_literal] = ACTIONS(5573),
    [sym_time_literal] = ACTIONS(5573),
    [sym_biginteger_literal] = ACTIONS(5575),
    [anon_sym_if] = ACTIONS(5573),
    [anon_sym_IF] = ACTIONS(5573),
    [anon_sym_If] = ACTIONS(5573),
    [anon_sym_else] = ACTIONS(5573),
    [anon_sym_ELSE] = ACTIONS(5573),
    [anon_sym_Else] = ACTIONS(5573),
    [anon_sym_case] = ACTIONS(5573),
    [anon_sym_CASE] = ACTIONS(5573),
    [anon_sym_Case] = ACTIONS(5573),
    [anon_sym_for] = ACTIONS(5573),
    [anon_sym_FOR] = ACTIONS(5573),
    [anon_sym_For] = ACTIONS(5573),
    [anon_sym_foreach] = ACTIONS(5573),
    [anon_sym_FOREACH] = ACTIONS(5573),
    [anon_sym_Foreach] = ACTIONS(5573),
    [anon_sym_while] = ACTIONS(5573),
    [anon_sym_WHILE] = ACTIONS(5573),
    [anon_sym_While] = ACTIONS(5573),
    [anon_sym_repeat] = ACTIONS(5573),
    [anon_sym_REPEAT] = ACTIONS(5573),
    [anon_sym_Repeat] = ACTIONS(5573),
    [anon_sym_until] = ACTIONS(5573),
    [anon_sym_UNTIL] = ACTIONS(5573),
    [anon_sym_Until] = ACTIONS(5573),
    [anon_sym_exit] = ACTIONS(5573),
    [anon_sym_EXIT] = ACTIONS(5573),
    [anon_sym_Exit] = ACTIONS(5573),
    [anon_sym_continue] = ACTIONS(5573),
    [anon_sym_CONTINUE] = ACTIONS(5573),
    [anon_sym_Continue] = ACTIONS(5573),
    [anon_sym_break] = ACTIONS(5573),
    [anon_sym_BREAK] = ACTIONS(5573),
    [anon_sym_Break] = ACTIONS(5573),
    [anon_sym_with] = ACTIONS(5573),
    [anon_sym_WITH] = ACTIONS(5573),
    [anon_sym_With] = ACTIONS(5573),
    [sym_asserterror_keyword] = ACTIONS(5575),
    [sym_page_keyword] = ACTIONS(5573),
    [anon_sym_codeunit] = ACTIONS(5573),
    [anon_sym_CODEUNIT] = ACTIONS(5573),
    [anon_sym_Codeunit] = ACTIONS(5573),
    [anon_sym_CodeUnit] = ACTIONS(5573),
    [anon_sym_COdeunit] = ACTIONS(5573),
    [anon_sym_codeUnit] = ACTIONS(5573),
    [sym_report_keyword] = ACTIONS(5573),
    [sym_query_keyword] = ACTIONS(5573),
    [anon_sym_xmlport] = ACTIONS(5573),
    [anon_sym_XMLPORT] = ACTIONS(5573),
    [anon_sym_Xmlport] = ACTIONS(5573),
    [anon_sym_XMLport] = ACTIONS(5573),
    [anon_sym_XMLPort] = ACTIONS(5573),
    [anon_sym_XmlPort] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_ENUM] = ACTIONS(5573),
    [anon_sym_Enum] = ACTIONS(5573),
    [anon_sym_eNUM] = ACTIONS(5573),
    [anon_sym_eNum] = ACTIONS(5573),
    [anon_sym_ENum] = ACTIONS(5573),
    [sym_quoted_identifier] = ACTIONS(5575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5575),
    [sym_verbatim_string] = ACTIONS(5575),
    [sym_integer] = ACTIONS(5573),
    [sym_continue_as_identifier] = ACTIONS(5575),
    [sym_preproc_open] = ACTIONS(5575),
  },
  [STATE(2982)] = {
    [sym_identifier] = ACTIONS(5577),
    [anon_sym_SEMI] = ACTIONS(5579),
    [anon_sym_DASH] = ACTIONS(5579),
    [aux_sym_boolean_token1] = ACTIONS(5577),
    [aux_sym_boolean_token2] = ACTIONS(5577),
    [sym_decimal] = ACTIONS(5577),
    [anon_sym_LPAREN] = ACTIONS(5579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5577),
    [anon_sym_LBRACK] = ACTIONS(5579),
    [aux_sym_record_type_token1] = ACTIONS(5577),
    [aux_sym_basic_type_token21] = ACTIONS(5577),
    [aux_sym_basic_type_token22] = ACTIONS(5577),
    [aux_sym_basic_type_token48] = ACTIONS(5577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5577),
    [anon_sym_POUNDif] = ACTIONS(5579),
    [anon_sym_POUNDIF] = ACTIONS(5579),
    [anon_sym_POUNDIf] = ACTIONS(5579),
    [anon_sym_not] = ACTIONS(5577),
    [anon_sym_NOT] = ACTIONS(5577),
    [anon_sym_Not] = ACTIONS(5577),
    [anon_sym_POUNDelse] = ACTIONS(5579),
    [anon_sym_POUNDELSE] = ACTIONS(5579),
    [anon_sym_POUNDElse] = ACTIONS(5579),
    [anon_sym_POUNDelse2] = ACTIONS(5579),
    [anon_sym_POUNDELSE2] = ACTIONS(5579),
    [anon_sym_POUNDElse2] = ACTIONS(5579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5577),
    [anon_sym_PLUS] = ACTIONS(5579),
    [sym_datetime_literal] = ACTIONS(5579),
    [sym_date_literal] = ACTIONS(5577),
    [sym_time_literal] = ACTIONS(5577),
    [sym_biginteger_literal] = ACTIONS(5579),
    [anon_sym_if] = ACTIONS(5577),
    [anon_sym_IF] = ACTIONS(5577),
    [anon_sym_If] = ACTIONS(5577),
    [anon_sym_else] = ACTIONS(5577),
    [anon_sym_ELSE] = ACTIONS(5577),
    [anon_sym_Else] = ACTIONS(5577),
    [anon_sym_case] = ACTIONS(5577),
    [anon_sym_CASE] = ACTIONS(5577),
    [anon_sym_Case] = ACTIONS(5577),
    [anon_sym_for] = ACTIONS(5577),
    [anon_sym_FOR] = ACTIONS(5577),
    [anon_sym_For] = ACTIONS(5577),
    [anon_sym_foreach] = ACTIONS(5577),
    [anon_sym_FOREACH] = ACTIONS(5577),
    [anon_sym_Foreach] = ACTIONS(5577),
    [anon_sym_while] = ACTIONS(5577),
    [anon_sym_WHILE] = ACTIONS(5577),
    [anon_sym_While] = ACTIONS(5577),
    [anon_sym_repeat] = ACTIONS(5577),
    [anon_sym_REPEAT] = ACTIONS(5577),
    [anon_sym_Repeat] = ACTIONS(5577),
    [anon_sym_until] = ACTIONS(5577),
    [anon_sym_UNTIL] = ACTIONS(5577),
    [anon_sym_Until] = ACTIONS(5577),
    [anon_sym_exit] = ACTIONS(5577),
    [anon_sym_EXIT] = ACTIONS(5577),
    [anon_sym_Exit] = ACTIONS(5577),
    [anon_sym_continue] = ACTIONS(5577),
    [anon_sym_CONTINUE] = ACTIONS(5577),
    [anon_sym_Continue] = ACTIONS(5577),
    [anon_sym_break] = ACTIONS(5577),
    [anon_sym_BREAK] = ACTIONS(5577),
    [anon_sym_Break] = ACTIONS(5577),
    [anon_sym_with] = ACTIONS(5577),
    [anon_sym_WITH] = ACTIONS(5577),
    [anon_sym_With] = ACTIONS(5577),
    [sym_asserterror_keyword] = ACTIONS(5579),
    [sym_page_keyword] = ACTIONS(5577),
    [anon_sym_codeunit] = ACTIONS(5577),
    [anon_sym_CODEUNIT] = ACTIONS(5577),
    [anon_sym_Codeunit] = ACTIONS(5577),
    [anon_sym_CodeUnit] = ACTIONS(5577),
    [anon_sym_COdeunit] = ACTIONS(5577),
    [anon_sym_codeUnit] = ACTIONS(5577),
    [sym_report_keyword] = ACTIONS(5577),
    [sym_query_keyword] = ACTIONS(5577),
    [anon_sym_xmlport] = ACTIONS(5577),
    [anon_sym_XMLPORT] = ACTIONS(5577),
    [anon_sym_Xmlport] = ACTIONS(5577),
    [anon_sym_XMLport] = ACTIONS(5577),
    [anon_sym_XMLPort] = ACTIONS(5577),
    [anon_sym_XmlPort] = ACTIONS(5577),
    [anon_sym_enum] = ACTIONS(5577),
    [anon_sym_ENUM] = ACTIONS(5577),
    [anon_sym_Enum] = ACTIONS(5577),
    [anon_sym_eNUM] = ACTIONS(5577),
    [anon_sym_eNum] = ACTIONS(5577),
    [anon_sym_ENum] = ACTIONS(5577),
    [sym_quoted_identifier] = ACTIONS(5579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5579),
    [sym_verbatim_string] = ACTIONS(5579),
    [sym_integer] = ACTIONS(5577),
    [sym_continue_as_identifier] = ACTIONS(5579),
    [sym_preproc_open] = ACTIONS(5579),
  },
  [STATE(2983)] = {
    [sym_identifier] = ACTIONS(5581),
    [anon_sym_SEMI] = ACTIONS(5583),
    [anon_sym_DASH] = ACTIONS(5583),
    [aux_sym_boolean_token1] = ACTIONS(5581),
    [aux_sym_boolean_token2] = ACTIONS(5581),
    [sym_decimal] = ACTIONS(5581),
    [anon_sym_LPAREN] = ACTIONS(5583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5581),
    [anon_sym_LBRACK] = ACTIONS(5583),
    [aux_sym_record_type_token1] = ACTIONS(5581),
    [aux_sym_basic_type_token21] = ACTIONS(5581),
    [aux_sym_basic_type_token22] = ACTIONS(5581),
    [aux_sym_basic_type_token48] = ACTIONS(5581),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5581),
    [anon_sym_POUNDif] = ACTIONS(5583),
    [anon_sym_POUNDIF] = ACTIONS(5583),
    [anon_sym_POUNDIf] = ACTIONS(5583),
    [anon_sym_not] = ACTIONS(5581),
    [anon_sym_NOT] = ACTIONS(5581),
    [anon_sym_Not] = ACTIONS(5581),
    [anon_sym_POUNDelse] = ACTIONS(5583),
    [anon_sym_POUNDELSE] = ACTIONS(5583),
    [anon_sym_POUNDElse] = ACTIONS(5583),
    [anon_sym_POUNDelse2] = ACTIONS(5583),
    [anon_sym_POUNDELSE2] = ACTIONS(5583),
    [anon_sym_POUNDElse2] = ACTIONS(5583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5581),
    [anon_sym_PLUS] = ACTIONS(5583),
    [sym_datetime_literal] = ACTIONS(5583),
    [sym_date_literal] = ACTIONS(5581),
    [sym_time_literal] = ACTIONS(5581),
    [sym_biginteger_literal] = ACTIONS(5583),
    [anon_sym_if] = ACTIONS(5581),
    [anon_sym_IF] = ACTIONS(5581),
    [anon_sym_If] = ACTIONS(5581),
    [anon_sym_else] = ACTIONS(5581),
    [anon_sym_ELSE] = ACTIONS(5581),
    [anon_sym_Else] = ACTIONS(5581),
    [anon_sym_case] = ACTIONS(5581),
    [anon_sym_CASE] = ACTIONS(5581),
    [anon_sym_Case] = ACTIONS(5581),
    [anon_sym_for] = ACTIONS(5581),
    [anon_sym_FOR] = ACTIONS(5581),
    [anon_sym_For] = ACTIONS(5581),
    [anon_sym_foreach] = ACTIONS(5581),
    [anon_sym_FOREACH] = ACTIONS(5581),
    [anon_sym_Foreach] = ACTIONS(5581),
    [anon_sym_while] = ACTIONS(5581),
    [anon_sym_WHILE] = ACTIONS(5581),
    [anon_sym_While] = ACTIONS(5581),
    [anon_sym_repeat] = ACTIONS(5581),
    [anon_sym_REPEAT] = ACTIONS(5581),
    [anon_sym_Repeat] = ACTIONS(5581),
    [anon_sym_until] = ACTIONS(5581),
    [anon_sym_UNTIL] = ACTIONS(5581),
    [anon_sym_Until] = ACTIONS(5581),
    [anon_sym_exit] = ACTIONS(5581),
    [anon_sym_EXIT] = ACTIONS(5581),
    [anon_sym_Exit] = ACTIONS(5581),
    [anon_sym_continue] = ACTIONS(5581),
    [anon_sym_CONTINUE] = ACTIONS(5581),
    [anon_sym_Continue] = ACTIONS(5581),
    [anon_sym_break] = ACTIONS(5581),
    [anon_sym_BREAK] = ACTIONS(5581),
    [anon_sym_Break] = ACTIONS(5581),
    [anon_sym_with] = ACTIONS(5581),
    [anon_sym_WITH] = ACTIONS(5581),
    [anon_sym_With] = ACTIONS(5581),
    [sym_asserterror_keyword] = ACTIONS(5583),
    [sym_page_keyword] = ACTIONS(5581),
    [anon_sym_codeunit] = ACTIONS(5581),
    [anon_sym_CODEUNIT] = ACTIONS(5581),
    [anon_sym_Codeunit] = ACTIONS(5581),
    [anon_sym_CodeUnit] = ACTIONS(5581),
    [anon_sym_COdeunit] = ACTIONS(5581),
    [anon_sym_codeUnit] = ACTIONS(5581),
    [sym_report_keyword] = ACTIONS(5581),
    [sym_query_keyword] = ACTIONS(5581),
    [anon_sym_xmlport] = ACTIONS(5581),
    [anon_sym_XMLPORT] = ACTIONS(5581),
    [anon_sym_Xmlport] = ACTIONS(5581),
    [anon_sym_XMLport] = ACTIONS(5581),
    [anon_sym_XMLPort] = ACTIONS(5581),
    [anon_sym_XmlPort] = ACTIONS(5581),
    [anon_sym_enum] = ACTIONS(5581),
    [anon_sym_ENUM] = ACTIONS(5581),
    [anon_sym_Enum] = ACTIONS(5581),
    [anon_sym_eNUM] = ACTIONS(5581),
    [anon_sym_eNum] = ACTIONS(5581),
    [anon_sym_ENum] = ACTIONS(5581),
    [sym_quoted_identifier] = ACTIONS(5583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5583),
    [sym_verbatim_string] = ACTIONS(5583),
    [sym_integer] = ACTIONS(5581),
    [sym_continue_as_identifier] = ACTIONS(5583),
    [sym_preproc_open] = ACTIONS(5583),
  },
  [STATE(2984)] = {
    [sym_identifier] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym_DASH] = ACTIONS(5587),
    [aux_sym_boolean_token1] = ACTIONS(5585),
    [aux_sym_boolean_token2] = ACTIONS(5585),
    [sym_decimal] = ACTIONS(5585),
    [anon_sym_LPAREN] = ACTIONS(5587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5587),
    [aux_sym_record_type_token1] = ACTIONS(5585),
    [aux_sym_basic_type_token21] = ACTIONS(5585),
    [aux_sym_basic_type_token22] = ACTIONS(5585),
    [aux_sym_basic_type_token48] = ACTIONS(5585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5585),
    [anon_sym_POUNDif] = ACTIONS(5587),
    [anon_sym_POUNDIF] = ACTIONS(5587),
    [anon_sym_POUNDIf] = ACTIONS(5587),
    [anon_sym_not] = ACTIONS(5585),
    [anon_sym_NOT] = ACTIONS(5585),
    [anon_sym_Not] = ACTIONS(5585),
    [anon_sym_POUNDelse] = ACTIONS(5587),
    [anon_sym_POUNDELSE] = ACTIONS(5587),
    [anon_sym_POUNDElse] = ACTIONS(5587),
    [anon_sym_POUNDelse2] = ACTIONS(5587),
    [anon_sym_POUNDELSE2] = ACTIONS(5587),
    [anon_sym_POUNDElse2] = ACTIONS(5587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5585),
    [anon_sym_PLUS] = ACTIONS(5587),
    [sym_datetime_literal] = ACTIONS(5587),
    [sym_date_literal] = ACTIONS(5585),
    [sym_time_literal] = ACTIONS(5585),
    [sym_biginteger_literal] = ACTIONS(5587),
    [anon_sym_if] = ACTIONS(5585),
    [anon_sym_IF] = ACTIONS(5585),
    [anon_sym_If] = ACTIONS(5585),
    [anon_sym_else] = ACTIONS(5585),
    [anon_sym_ELSE] = ACTIONS(5585),
    [anon_sym_Else] = ACTIONS(5585),
    [anon_sym_case] = ACTIONS(5585),
    [anon_sym_CASE] = ACTIONS(5585),
    [anon_sym_Case] = ACTIONS(5585),
    [anon_sym_for] = ACTIONS(5585),
    [anon_sym_FOR] = ACTIONS(5585),
    [anon_sym_For] = ACTIONS(5585),
    [anon_sym_foreach] = ACTIONS(5585),
    [anon_sym_FOREACH] = ACTIONS(5585),
    [anon_sym_Foreach] = ACTIONS(5585),
    [anon_sym_while] = ACTIONS(5585),
    [anon_sym_WHILE] = ACTIONS(5585),
    [anon_sym_While] = ACTIONS(5585),
    [anon_sym_repeat] = ACTIONS(5585),
    [anon_sym_REPEAT] = ACTIONS(5585),
    [anon_sym_Repeat] = ACTIONS(5585),
    [anon_sym_until] = ACTIONS(5585),
    [anon_sym_UNTIL] = ACTIONS(5585),
    [anon_sym_Until] = ACTIONS(5585),
    [anon_sym_exit] = ACTIONS(5585),
    [anon_sym_EXIT] = ACTIONS(5585),
    [anon_sym_Exit] = ACTIONS(5585),
    [anon_sym_continue] = ACTIONS(5585),
    [anon_sym_CONTINUE] = ACTIONS(5585),
    [anon_sym_Continue] = ACTIONS(5585),
    [anon_sym_break] = ACTIONS(5585),
    [anon_sym_BREAK] = ACTIONS(5585),
    [anon_sym_Break] = ACTIONS(5585),
    [anon_sym_with] = ACTIONS(5585),
    [anon_sym_WITH] = ACTIONS(5585),
    [anon_sym_With] = ACTIONS(5585),
    [sym_asserterror_keyword] = ACTIONS(5587),
    [sym_page_keyword] = ACTIONS(5585),
    [anon_sym_codeunit] = ACTIONS(5585),
    [anon_sym_CODEUNIT] = ACTIONS(5585),
    [anon_sym_Codeunit] = ACTIONS(5585),
    [anon_sym_CodeUnit] = ACTIONS(5585),
    [anon_sym_COdeunit] = ACTIONS(5585),
    [anon_sym_codeUnit] = ACTIONS(5585),
    [sym_report_keyword] = ACTIONS(5585),
    [sym_query_keyword] = ACTIONS(5585),
    [anon_sym_xmlport] = ACTIONS(5585),
    [anon_sym_XMLPORT] = ACTIONS(5585),
    [anon_sym_Xmlport] = ACTIONS(5585),
    [anon_sym_XMLport] = ACTIONS(5585),
    [anon_sym_XMLPort] = ACTIONS(5585),
    [anon_sym_XmlPort] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_ENUM] = ACTIONS(5585),
    [anon_sym_Enum] = ACTIONS(5585),
    [anon_sym_eNUM] = ACTIONS(5585),
    [anon_sym_eNum] = ACTIONS(5585),
    [anon_sym_ENum] = ACTIONS(5585),
    [sym_quoted_identifier] = ACTIONS(5587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5587),
    [sym_verbatim_string] = ACTIONS(5587),
    [sym_integer] = ACTIONS(5585),
    [sym_continue_as_identifier] = ACTIONS(5587),
    [sym_preproc_open] = ACTIONS(5587),
  },
  [STATE(2985)] = {
    [sym_identifier] = ACTIONS(5589),
    [anon_sym_SEMI] = ACTIONS(5591),
    [anon_sym_DASH] = ACTIONS(5591),
    [aux_sym_boolean_token1] = ACTIONS(5589),
    [aux_sym_boolean_token2] = ACTIONS(5589),
    [sym_decimal] = ACTIONS(5589),
    [anon_sym_LPAREN] = ACTIONS(5591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5589),
    [anon_sym_LBRACK] = ACTIONS(5591),
    [aux_sym_record_type_token1] = ACTIONS(5589),
    [aux_sym_basic_type_token21] = ACTIONS(5589),
    [aux_sym_basic_type_token22] = ACTIONS(5589),
    [aux_sym_basic_type_token48] = ACTIONS(5589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5589),
    [anon_sym_POUNDif] = ACTIONS(5591),
    [anon_sym_POUNDIF] = ACTIONS(5591),
    [anon_sym_POUNDIf] = ACTIONS(5591),
    [anon_sym_not] = ACTIONS(5589),
    [anon_sym_NOT] = ACTIONS(5589),
    [anon_sym_Not] = ACTIONS(5589),
    [anon_sym_POUNDelse] = ACTIONS(5591),
    [anon_sym_POUNDELSE] = ACTIONS(5591),
    [anon_sym_POUNDElse] = ACTIONS(5591),
    [anon_sym_POUNDelse2] = ACTIONS(5591),
    [anon_sym_POUNDELSE2] = ACTIONS(5591),
    [anon_sym_POUNDElse2] = ACTIONS(5591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5589),
    [anon_sym_PLUS] = ACTIONS(5591),
    [sym_datetime_literal] = ACTIONS(5591),
    [sym_date_literal] = ACTIONS(5589),
    [sym_time_literal] = ACTIONS(5589),
    [sym_biginteger_literal] = ACTIONS(5591),
    [anon_sym_if] = ACTIONS(5589),
    [anon_sym_IF] = ACTIONS(5589),
    [anon_sym_If] = ACTIONS(5589),
    [anon_sym_else] = ACTIONS(5589),
    [anon_sym_ELSE] = ACTIONS(5589),
    [anon_sym_Else] = ACTIONS(5589),
    [anon_sym_case] = ACTIONS(5589),
    [anon_sym_CASE] = ACTIONS(5589),
    [anon_sym_Case] = ACTIONS(5589),
    [anon_sym_for] = ACTIONS(5589),
    [anon_sym_FOR] = ACTIONS(5589),
    [anon_sym_For] = ACTIONS(5589),
    [anon_sym_foreach] = ACTIONS(5589),
    [anon_sym_FOREACH] = ACTIONS(5589),
    [anon_sym_Foreach] = ACTIONS(5589),
    [anon_sym_while] = ACTIONS(5589),
    [anon_sym_WHILE] = ACTIONS(5589),
    [anon_sym_While] = ACTIONS(5589),
    [anon_sym_repeat] = ACTIONS(5589),
    [anon_sym_REPEAT] = ACTIONS(5589),
    [anon_sym_Repeat] = ACTIONS(5589),
    [anon_sym_until] = ACTIONS(5589),
    [anon_sym_UNTIL] = ACTIONS(5589),
    [anon_sym_Until] = ACTIONS(5589),
    [anon_sym_exit] = ACTIONS(5589),
    [anon_sym_EXIT] = ACTIONS(5589),
    [anon_sym_Exit] = ACTIONS(5589),
    [anon_sym_continue] = ACTIONS(5589),
    [anon_sym_CONTINUE] = ACTIONS(5589),
    [anon_sym_Continue] = ACTIONS(5589),
    [anon_sym_break] = ACTIONS(5589),
    [anon_sym_BREAK] = ACTIONS(5589),
    [anon_sym_Break] = ACTIONS(5589),
    [anon_sym_with] = ACTIONS(5589),
    [anon_sym_WITH] = ACTIONS(5589),
    [anon_sym_With] = ACTIONS(5589),
    [sym_asserterror_keyword] = ACTIONS(5591),
    [sym_page_keyword] = ACTIONS(5589),
    [anon_sym_codeunit] = ACTIONS(5589),
    [anon_sym_CODEUNIT] = ACTIONS(5589),
    [anon_sym_Codeunit] = ACTIONS(5589),
    [anon_sym_CodeUnit] = ACTIONS(5589),
    [anon_sym_COdeunit] = ACTIONS(5589),
    [anon_sym_codeUnit] = ACTIONS(5589),
    [sym_report_keyword] = ACTIONS(5589),
    [sym_query_keyword] = ACTIONS(5589),
    [anon_sym_xmlport] = ACTIONS(5589),
    [anon_sym_XMLPORT] = ACTIONS(5589),
    [anon_sym_Xmlport] = ACTIONS(5589),
    [anon_sym_XMLport] = ACTIONS(5589),
    [anon_sym_XMLPort] = ACTIONS(5589),
    [anon_sym_XmlPort] = ACTIONS(5589),
    [anon_sym_enum] = ACTIONS(5589),
    [anon_sym_ENUM] = ACTIONS(5589),
    [anon_sym_Enum] = ACTIONS(5589),
    [anon_sym_eNUM] = ACTIONS(5589),
    [anon_sym_eNum] = ACTIONS(5589),
    [anon_sym_ENum] = ACTIONS(5589),
    [sym_quoted_identifier] = ACTIONS(5591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5591),
    [sym_verbatim_string] = ACTIONS(5591),
    [sym_integer] = ACTIONS(5589),
    [sym_continue_as_identifier] = ACTIONS(5591),
    [sym_preproc_open] = ACTIONS(5591),
  },
  [STATE(2986)] = {
    [sym_identifier] = ACTIONS(5593),
    [anon_sym_SEMI] = ACTIONS(5595),
    [anon_sym_DASH] = ACTIONS(5595),
    [aux_sym_boolean_token1] = ACTIONS(5593),
    [aux_sym_boolean_token2] = ACTIONS(5593),
    [sym_decimal] = ACTIONS(5593),
    [anon_sym_LPAREN] = ACTIONS(5595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5593),
    [anon_sym_LBRACK] = ACTIONS(5595),
    [aux_sym_record_type_token1] = ACTIONS(5593),
    [aux_sym_basic_type_token21] = ACTIONS(5593),
    [aux_sym_basic_type_token22] = ACTIONS(5593),
    [aux_sym_basic_type_token48] = ACTIONS(5593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5593),
    [anon_sym_POUNDif] = ACTIONS(5595),
    [anon_sym_POUNDIF] = ACTIONS(5595),
    [anon_sym_POUNDIf] = ACTIONS(5595),
    [anon_sym_not] = ACTIONS(5593),
    [anon_sym_NOT] = ACTIONS(5593),
    [anon_sym_Not] = ACTIONS(5593),
    [anon_sym_POUNDelse] = ACTIONS(5595),
    [anon_sym_POUNDELSE] = ACTIONS(5595),
    [anon_sym_POUNDElse] = ACTIONS(5595),
    [anon_sym_POUNDelse2] = ACTIONS(5595),
    [anon_sym_POUNDELSE2] = ACTIONS(5595),
    [anon_sym_POUNDElse2] = ACTIONS(5595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5593),
    [anon_sym_PLUS] = ACTIONS(5595),
    [sym_datetime_literal] = ACTIONS(5595),
    [sym_date_literal] = ACTIONS(5593),
    [sym_time_literal] = ACTIONS(5593),
    [sym_biginteger_literal] = ACTIONS(5595),
    [anon_sym_if] = ACTIONS(5593),
    [anon_sym_IF] = ACTIONS(5593),
    [anon_sym_If] = ACTIONS(5593),
    [anon_sym_else] = ACTIONS(5593),
    [anon_sym_ELSE] = ACTIONS(5593),
    [anon_sym_Else] = ACTIONS(5593),
    [anon_sym_case] = ACTIONS(5593),
    [anon_sym_CASE] = ACTIONS(5593),
    [anon_sym_Case] = ACTIONS(5593),
    [anon_sym_for] = ACTIONS(5593),
    [anon_sym_FOR] = ACTIONS(5593),
    [anon_sym_For] = ACTIONS(5593),
    [anon_sym_foreach] = ACTIONS(5593),
    [anon_sym_FOREACH] = ACTIONS(5593),
    [anon_sym_Foreach] = ACTIONS(5593),
    [anon_sym_while] = ACTIONS(5593),
    [anon_sym_WHILE] = ACTIONS(5593),
    [anon_sym_While] = ACTIONS(5593),
    [anon_sym_repeat] = ACTIONS(5593),
    [anon_sym_REPEAT] = ACTIONS(5593),
    [anon_sym_Repeat] = ACTIONS(5593),
    [anon_sym_until] = ACTIONS(5593),
    [anon_sym_UNTIL] = ACTIONS(5593),
    [anon_sym_Until] = ACTIONS(5593),
    [anon_sym_exit] = ACTIONS(5593),
    [anon_sym_EXIT] = ACTIONS(5593),
    [anon_sym_Exit] = ACTIONS(5593),
    [anon_sym_continue] = ACTIONS(5593),
    [anon_sym_CONTINUE] = ACTIONS(5593),
    [anon_sym_Continue] = ACTIONS(5593),
    [anon_sym_break] = ACTIONS(5593),
    [anon_sym_BREAK] = ACTIONS(5593),
    [anon_sym_Break] = ACTIONS(5593),
    [anon_sym_with] = ACTIONS(5593),
    [anon_sym_WITH] = ACTIONS(5593),
    [anon_sym_With] = ACTIONS(5593),
    [sym_asserterror_keyword] = ACTIONS(5595),
    [sym_page_keyword] = ACTIONS(5593),
    [anon_sym_codeunit] = ACTIONS(5593),
    [anon_sym_CODEUNIT] = ACTIONS(5593),
    [anon_sym_Codeunit] = ACTIONS(5593),
    [anon_sym_CodeUnit] = ACTIONS(5593),
    [anon_sym_COdeunit] = ACTIONS(5593),
    [anon_sym_codeUnit] = ACTIONS(5593),
    [sym_report_keyword] = ACTIONS(5593),
    [sym_query_keyword] = ACTIONS(5593),
    [anon_sym_xmlport] = ACTIONS(5593),
    [anon_sym_XMLPORT] = ACTIONS(5593),
    [anon_sym_Xmlport] = ACTIONS(5593),
    [anon_sym_XMLport] = ACTIONS(5593),
    [anon_sym_XMLPort] = ACTIONS(5593),
    [anon_sym_XmlPort] = ACTIONS(5593),
    [anon_sym_enum] = ACTIONS(5593),
    [anon_sym_ENUM] = ACTIONS(5593),
    [anon_sym_Enum] = ACTIONS(5593),
    [anon_sym_eNUM] = ACTIONS(5593),
    [anon_sym_eNum] = ACTIONS(5593),
    [anon_sym_ENum] = ACTIONS(5593),
    [sym_quoted_identifier] = ACTIONS(5595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5595),
    [sym_verbatim_string] = ACTIONS(5595),
    [sym_integer] = ACTIONS(5593),
    [sym_continue_as_identifier] = ACTIONS(5595),
    [sym_preproc_open] = ACTIONS(5595),
  },
  [STATE(2987)] = {
    [sym_identifier] = ACTIONS(5597),
    [anon_sym_SEMI] = ACTIONS(5599),
    [anon_sym_DASH] = ACTIONS(5599),
    [aux_sym_boolean_token1] = ACTIONS(5597),
    [aux_sym_boolean_token2] = ACTIONS(5597),
    [sym_decimal] = ACTIONS(5597),
    [anon_sym_LPAREN] = ACTIONS(5599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5597),
    [anon_sym_LBRACK] = ACTIONS(5599),
    [aux_sym_record_type_token1] = ACTIONS(5597),
    [aux_sym_basic_type_token21] = ACTIONS(5597),
    [aux_sym_basic_type_token22] = ACTIONS(5597),
    [aux_sym_basic_type_token48] = ACTIONS(5597),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5597),
    [anon_sym_POUNDif] = ACTIONS(5599),
    [anon_sym_POUNDIF] = ACTIONS(5599),
    [anon_sym_POUNDIf] = ACTIONS(5599),
    [anon_sym_not] = ACTIONS(5597),
    [anon_sym_NOT] = ACTIONS(5597),
    [anon_sym_Not] = ACTIONS(5597),
    [anon_sym_POUNDelse] = ACTIONS(5599),
    [anon_sym_POUNDELSE] = ACTIONS(5599),
    [anon_sym_POUNDElse] = ACTIONS(5599),
    [anon_sym_POUNDelse2] = ACTIONS(5599),
    [anon_sym_POUNDELSE2] = ACTIONS(5599),
    [anon_sym_POUNDElse2] = ACTIONS(5599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5597),
    [anon_sym_PLUS] = ACTIONS(5599),
    [sym_datetime_literal] = ACTIONS(5599),
    [sym_date_literal] = ACTIONS(5597),
    [sym_time_literal] = ACTIONS(5597),
    [sym_biginteger_literal] = ACTIONS(5599),
    [anon_sym_if] = ACTIONS(5597),
    [anon_sym_IF] = ACTIONS(5597),
    [anon_sym_If] = ACTIONS(5597),
    [anon_sym_else] = ACTIONS(5597),
    [anon_sym_ELSE] = ACTIONS(5597),
    [anon_sym_Else] = ACTIONS(5597),
    [anon_sym_case] = ACTIONS(5597),
    [anon_sym_CASE] = ACTIONS(5597),
    [anon_sym_Case] = ACTIONS(5597),
    [anon_sym_for] = ACTIONS(5597),
    [anon_sym_FOR] = ACTIONS(5597),
    [anon_sym_For] = ACTIONS(5597),
    [anon_sym_foreach] = ACTIONS(5597),
    [anon_sym_FOREACH] = ACTIONS(5597),
    [anon_sym_Foreach] = ACTIONS(5597),
    [anon_sym_while] = ACTIONS(5597),
    [anon_sym_WHILE] = ACTIONS(5597),
    [anon_sym_While] = ACTIONS(5597),
    [anon_sym_repeat] = ACTIONS(5597),
    [anon_sym_REPEAT] = ACTIONS(5597),
    [anon_sym_Repeat] = ACTIONS(5597),
    [anon_sym_until] = ACTIONS(5597),
    [anon_sym_UNTIL] = ACTIONS(5597),
    [anon_sym_Until] = ACTIONS(5597),
    [anon_sym_exit] = ACTIONS(5597),
    [anon_sym_EXIT] = ACTIONS(5597),
    [anon_sym_Exit] = ACTIONS(5597),
    [anon_sym_continue] = ACTIONS(5597),
    [anon_sym_CONTINUE] = ACTIONS(5597),
    [anon_sym_Continue] = ACTIONS(5597),
    [anon_sym_break] = ACTIONS(5597),
    [anon_sym_BREAK] = ACTIONS(5597),
    [anon_sym_Break] = ACTIONS(5597),
    [anon_sym_with] = ACTIONS(5597),
    [anon_sym_WITH] = ACTIONS(5597),
    [anon_sym_With] = ACTIONS(5597),
    [sym_asserterror_keyword] = ACTIONS(5599),
    [sym_page_keyword] = ACTIONS(5597),
    [anon_sym_codeunit] = ACTIONS(5597),
    [anon_sym_CODEUNIT] = ACTIONS(5597),
    [anon_sym_Codeunit] = ACTIONS(5597),
    [anon_sym_CodeUnit] = ACTIONS(5597),
    [anon_sym_COdeunit] = ACTIONS(5597),
    [anon_sym_codeUnit] = ACTIONS(5597),
    [sym_report_keyword] = ACTIONS(5597),
    [sym_query_keyword] = ACTIONS(5597),
    [anon_sym_xmlport] = ACTIONS(5597),
    [anon_sym_XMLPORT] = ACTIONS(5597),
    [anon_sym_Xmlport] = ACTIONS(5597),
    [anon_sym_XMLport] = ACTIONS(5597),
    [anon_sym_XMLPort] = ACTIONS(5597),
    [anon_sym_XmlPort] = ACTIONS(5597),
    [anon_sym_enum] = ACTIONS(5597),
    [anon_sym_ENUM] = ACTIONS(5597),
    [anon_sym_Enum] = ACTIONS(5597),
    [anon_sym_eNUM] = ACTIONS(5597),
    [anon_sym_eNum] = ACTIONS(5597),
    [anon_sym_ENum] = ACTIONS(5597),
    [sym_quoted_identifier] = ACTIONS(5599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5599),
    [sym_verbatim_string] = ACTIONS(5599),
    [sym_integer] = ACTIONS(5597),
    [sym_continue_as_identifier] = ACTIONS(5599),
    [sym_preproc_open] = ACTIONS(5599),
  },
  [STATE(2988)] = {
    [sym_identifier] = ACTIONS(5601),
    [anon_sym_SEMI] = ACTIONS(5603),
    [anon_sym_DASH] = ACTIONS(5603),
    [aux_sym_boolean_token1] = ACTIONS(5601),
    [aux_sym_boolean_token2] = ACTIONS(5601),
    [sym_decimal] = ACTIONS(5601),
    [anon_sym_LPAREN] = ACTIONS(5603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5601),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [aux_sym_record_type_token1] = ACTIONS(5601),
    [aux_sym_basic_type_token21] = ACTIONS(5601),
    [aux_sym_basic_type_token22] = ACTIONS(5601),
    [aux_sym_basic_type_token48] = ACTIONS(5601),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5601),
    [anon_sym_POUNDif] = ACTIONS(5603),
    [anon_sym_POUNDIF] = ACTIONS(5603),
    [anon_sym_POUNDIf] = ACTIONS(5603),
    [anon_sym_not] = ACTIONS(5601),
    [anon_sym_NOT] = ACTIONS(5601),
    [anon_sym_Not] = ACTIONS(5601),
    [anon_sym_POUNDelse] = ACTIONS(5603),
    [anon_sym_POUNDELSE] = ACTIONS(5603),
    [anon_sym_POUNDElse] = ACTIONS(5603),
    [anon_sym_POUNDelse2] = ACTIONS(5603),
    [anon_sym_POUNDELSE2] = ACTIONS(5603),
    [anon_sym_POUNDElse2] = ACTIONS(5603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5601),
    [anon_sym_PLUS] = ACTIONS(5603),
    [sym_datetime_literal] = ACTIONS(5603),
    [sym_date_literal] = ACTIONS(5601),
    [sym_time_literal] = ACTIONS(5601),
    [sym_biginteger_literal] = ACTIONS(5603),
    [anon_sym_if] = ACTIONS(5601),
    [anon_sym_IF] = ACTIONS(5601),
    [anon_sym_If] = ACTIONS(5601),
    [anon_sym_else] = ACTIONS(5601),
    [anon_sym_ELSE] = ACTIONS(5601),
    [anon_sym_Else] = ACTIONS(5601),
    [anon_sym_case] = ACTIONS(5601),
    [anon_sym_CASE] = ACTIONS(5601),
    [anon_sym_Case] = ACTIONS(5601),
    [anon_sym_for] = ACTIONS(5601),
    [anon_sym_FOR] = ACTIONS(5601),
    [anon_sym_For] = ACTIONS(5601),
    [anon_sym_foreach] = ACTIONS(5601),
    [anon_sym_FOREACH] = ACTIONS(5601),
    [anon_sym_Foreach] = ACTIONS(5601),
    [anon_sym_while] = ACTIONS(5601),
    [anon_sym_WHILE] = ACTIONS(5601),
    [anon_sym_While] = ACTIONS(5601),
    [anon_sym_repeat] = ACTIONS(5601),
    [anon_sym_REPEAT] = ACTIONS(5601),
    [anon_sym_Repeat] = ACTIONS(5601),
    [anon_sym_until] = ACTIONS(5601),
    [anon_sym_UNTIL] = ACTIONS(5601),
    [anon_sym_Until] = ACTIONS(5601),
    [anon_sym_exit] = ACTIONS(5601),
    [anon_sym_EXIT] = ACTIONS(5601),
    [anon_sym_Exit] = ACTIONS(5601),
    [anon_sym_continue] = ACTIONS(5601),
    [anon_sym_CONTINUE] = ACTIONS(5601),
    [anon_sym_Continue] = ACTIONS(5601),
    [anon_sym_break] = ACTIONS(5601),
    [anon_sym_BREAK] = ACTIONS(5601),
    [anon_sym_Break] = ACTIONS(5601),
    [anon_sym_with] = ACTIONS(5601),
    [anon_sym_WITH] = ACTIONS(5601),
    [anon_sym_With] = ACTIONS(5601),
    [sym_asserterror_keyword] = ACTIONS(5603),
    [sym_page_keyword] = ACTIONS(5601),
    [anon_sym_codeunit] = ACTIONS(5601),
    [anon_sym_CODEUNIT] = ACTIONS(5601),
    [anon_sym_Codeunit] = ACTIONS(5601),
    [anon_sym_CodeUnit] = ACTIONS(5601),
    [anon_sym_COdeunit] = ACTIONS(5601),
    [anon_sym_codeUnit] = ACTIONS(5601),
    [sym_report_keyword] = ACTIONS(5601),
    [sym_query_keyword] = ACTIONS(5601),
    [anon_sym_xmlport] = ACTIONS(5601),
    [anon_sym_XMLPORT] = ACTIONS(5601),
    [anon_sym_Xmlport] = ACTIONS(5601),
    [anon_sym_XMLport] = ACTIONS(5601),
    [anon_sym_XMLPort] = ACTIONS(5601),
    [anon_sym_XmlPort] = ACTIONS(5601),
    [anon_sym_enum] = ACTIONS(5601),
    [anon_sym_ENUM] = ACTIONS(5601),
    [anon_sym_Enum] = ACTIONS(5601),
    [anon_sym_eNUM] = ACTIONS(5601),
    [anon_sym_eNum] = ACTIONS(5601),
    [anon_sym_ENum] = ACTIONS(5601),
    [sym_quoted_identifier] = ACTIONS(5603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5603),
    [sym_verbatim_string] = ACTIONS(5603),
    [sym_integer] = ACTIONS(5601),
    [sym_continue_as_identifier] = ACTIONS(5603),
    [sym_preproc_open] = ACTIONS(5603),
  },
  [STATE(2989)] = {
    [sym_identifier] = ACTIONS(5605),
    [anon_sym_SEMI] = ACTIONS(5607),
    [anon_sym_DASH] = ACTIONS(5607),
    [aux_sym_boolean_token1] = ACTIONS(5605),
    [aux_sym_boolean_token2] = ACTIONS(5605),
    [sym_decimal] = ACTIONS(5605),
    [anon_sym_LPAREN] = ACTIONS(5607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5605),
    [anon_sym_LBRACK] = ACTIONS(5607),
    [aux_sym_record_type_token1] = ACTIONS(5605),
    [aux_sym_basic_type_token21] = ACTIONS(5605),
    [aux_sym_basic_type_token22] = ACTIONS(5605),
    [aux_sym_basic_type_token48] = ACTIONS(5605),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5605),
    [anon_sym_POUNDif] = ACTIONS(5607),
    [anon_sym_POUNDIF] = ACTIONS(5607),
    [anon_sym_POUNDIf] = ACTIONS(5607),
    [anon_sym_not] = ACTIONS(5605),
    [anon_sym_NOT] = ACTIONS(5605),
    [anon_sym_Not] = ACTIONS(5605),
    [anon_sym_POUNDelse] = ACTIONS(5607),
    [anon_sym_POUNDELSE] = ACTIONS(5607),
    [anon_sym_POUNDElse] = ACTIONS(5607),
    [anon_sym_POUNDelse2] = ACTIONS(5607),
    [anon_sym_POUNDELSE2] = ACTIONS(5607),
    [anon_sym_POUNDElse2] = ACTIONS(5607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5605),
    [anon_sym_PLUS] = ACTIONS(5607),
    [sym_datetime_literal] = ACTIONS(5607),
    [sym_date_literal] = ACTIONS(5605),
    [sym_time_literal] = ACTIONS(5605),
    [sym_biginteger_literal] = ACTIONS(5607),
    [anon_sym_if] = ACTIONS(5605),
    [anon_sym_IF] = ACTIONS(5605),
    [anon_sym_If] = ACTIONS(5605),
    [anon_sym_else] = ACTIONS(5605),
    [anon_sym_ELSE] = ACTIONS(5605),
    [anon_sym_Else] = ACTIONS(5605),
    [anon_sym_case] = ACTIONS(5605),
    [anon_sym_CASE] = ACTIONS(5605),
    [anon_sym_Case] = ACTIONS(5605),
    [anon_sym_for] = ACTIONS(5605),
    [anon_sym_FOR] = ACTIONS(5605),
    [anon_sym_For] = ACTIONS(5605),
    [anon_sym_foreach] = ACTIONS(5605),
    [anon_sym_FOREACH] = ACTIONS(5605),
    [anon_sym_Foreach] = ACTIONS(5605),
    [anon_sym_while] = ACTIONS(5605),
    [anon_sym_WHILE] = ACTIONS(5605),
    [anon_sym_While] = ACTIONS(5605),
    [anon_sym_repeat] = ACTIONS(5605),
    [anon_sym_REPEAT] = ACTIONS(5605),
    [anon_sym_Repeat] = ACTIONS(5605),
    [anon_sym_until] = ACTIONS(5605),
    [anon_sym_UNTIL] = ACTIONS(5605),
    [anon_sym_Until] = ACTIONS(5605),
    [anon_sym_exit] = ACTIONS(5605),
    [anon_sym_EXIT] = ACTIONS(5605),
    [anon_sym_Exit] = ACTIONS(5605),
    [anon_sym_continue] = ACTIONS(5605),
    [anon_sym_CONTINUE] = ACTIONS(5605),
    [anon_sym_Continue] = ACTIONS(5605),
    [anon_sym_break] = ACTIONS(5605),
    [anon_sym_BREAK] = ACTIONS(5605),
    [anon_sym_Break] = ACTIONS(5605),
    [anon_sym_with] = ACTIONS(5605),
    [anon_sym_WITH] = ACTIONS(5605),
    [anon_sym_With] = ACTIONS(5605),
    [sym_asserterror_keyword] = ACTIONS(5607),
    [sym_page_keyword] = ACTIONS(5605),
    [anon_sym_codeunit] = ACTIONS(5605),
    [anon_sym_CODEUNIT] = ACTIONS(5605),
    [anon_sym_Codeunit] = ACTIONS(5605),
    [anon_sym_CodeUnit] = ACTIONS(5605),
    [anon_sym_COdeunit] = ACTIONS(5605),
    [anon_sym_codeUnit] = ACTIONS(5605),
    [sym_report_keyword] = ACTIONS(5605),
    [sym_query_keyword] = ACTIONS(5605),
    [anon_sym_xmlport] = ACTIONS(5605),
    [anon_sym_XMLPORT] = ACTIONS(5605),
    [anon_sym_Xmlport] = ACTIONS(5605),
    [anon_sym_XMLport] = ACTIONS(5605),
    [anon_sym_XMLPort] = ACTIONS(5605),
    [anon_sym_XmlPort] = ACTIONS(5605),
    [anon_sym_enum] = ACTIONS(5605),
    [anon_sym_ENUM] = ACTIONS(5605),
    [anon_sym_Enum] = ACTIONS(5605),
    [anon_sym_eNUM] = ACTIONS(5605),
    [anon_sym_eNum] = ACTIONS(5605),
    [anon_sym_ENum] = ACTIONS(5605),
    [sym_quoted_identifier] = ACTIONS(5607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5607),
    [sym_verbatim_string] = ACTIONS(5607),
    [sym_integer] = ACTIONS(5605),
    [sym_continue_as_identifier] = ACTIONS(5607),
    [sym_preproc_open] = ACTIONS(5607),
  },
  [STATE(2990)] = {
    [sym_identifier] = ACTIONS(5613),
    [anon_sym_SEMI] = ACTIONS(5615),
    [anon_sym_DASH] = ACTIONS(5615),
    [aux_sym_boolean_token1] = ACTIONS(5613),
    [aux_sym_boolean_token2] = ACTIONS(5613),
    [sym_decimal] = ACTIONS(5613),
    [anon_sym_LPAREN] = ACTIONS(5615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5613),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [aux_sym_record_type_token1] = ACTIONS(5613),
    [aux_sym_basic_type_token21] = ACTIONS(5613),
    [aux_sym_basic_type_token22] = ACTIONS(5613),
    [aux_sym_basic_type_token48] = ACTIONS(5613),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5613),
    [anon_sym_POUNDif] = ACTIONS(5615),
    [anon_sym_POUNDIF] = ACTIONS(5615),
    [anon_sym_POUNDIf] = ACTIONS(5615),
    [anon_sym_not] = ACTIONS(5613),
    [anon_sym_NOT] = ACTIONS(5613),
    [anon_sym_Not] = ACTIONS(5613),
    [anon_sym_POUNDelse] = ACTIONS(5615),
    [anon_sym_POUNDELSE] = ACTIONS(5615),
    [anon_sym_POUNDElse] = ACTIONS(5615),
    [anon_sym_POUNDelse2] = ACTIONS(5615),
    [anon_sym_POUNDELSE2] = ACTIONS(5615),
    [anon_sym_POUNDElse2] = ACTIONS(5615),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5613),
    [anon_sym_PLUS] = ACTIONS(5615),
    [sym_datetime_literal] = ACTIONS(5615),
    [sym_date_literal] = ACTIONS(5613),
    [sym_time_literal] = ACTIONS(5613),
    [sym_biginteger_literal] = ACTIONS(5615),
    [anon_sym_if] = ACTIONS(5613),
    [anon_sym_IF] = ACTIONS(5613),
    [anon_sym_If] = ACTIONS(5613),
    [anon_sym_else] = ACTIONS(5613),
    [anon_sym_ELSE] = ACTIONS(5613),
    [anon_sym_Else] = ACTIONS(5613),
    [anon_sym_case] = ACTIONS(5613),
    [anon_sym_CASE] = ACTIONS(5613),
    [anon_sym_Case] = ACTIONS(5613),
    [anon_sym_for] = ACTIONS(5613),
    [anon_sym_FOR] = ACTIONS(5613),
    [anon_sym_For] = ACTIONS(5613),
    [anon_sym_foreach] = ACTIONS(5613),
    [anon_sym_FOREACH] = ACTIONS(5613),
    [anon_sym_Foreach] = ACTIONS(5613),
    [anon_sym_while] = ACTIONS(5613),
    [anon_sym_WHILE] = ACTIONS(5613),
    [anon_sym_While] = ACTIONS(5613),
    [anon_sym_repeat] = ACTIONS(5613),
    [anon_sym_REPEAT] = ACTIONS(5613),
    [anon_sym_Repeat] = ACTIONS(5613),
    [anon_sym_until] = ACTIONS(5613),
    [anon_sym_UNTIL] = ACTIONS(5613),
    [anon_sym_Until] = ACTIONS(5613),
    [anon_sym_exit] = ACTIONS(5613),
    [anon_sym_EXIT] = ACTIONS(5613),
    [anon_sym_Exit] = ACTIONS(5613),
    [anon_sym_continue] = ACTIONS(5613),
    [anon_sym_CONTINUE] = ACTIONS(5613),
    [anon_sym_Continue] = ACTIONS(5613),
    [anon_sym_break] = ACTIONS(5613),
    [anon_sym_BREAK] = ACTIONS(5613),
    [anon_sym_Break] = ACTIONS(5613),
    [anon_sym_with] = ACTIONS(5613),
    [anon_sym_WITH] = ACTIONS(5613),
    [anon_sym_With] = ACTIONS(5613),
    [sym_asserterror_keyword] = ACTIONS(5615),
    [sym_page_keyword] = ACTIONS(5613),
    [anon_sym_codeunit] = ACTIONS(5613),
    [anon_sym_CODEUNIT] = ACTIONS(5613),
    [anon_sym_Codeunit] = ACTIONS(5613),
    [anon_sym_CodeUnit] = ACTIONS(5613),
    [anon_sym_COdeunit] = ACTIONS(5613),
    [anon_sym_codeUnit] = ACTIONS(5613),
    [sym_report_keyword] = ACTIONS(5613),
    [sym_query_keyword] = ACTIONS(5613),
    [anon_sym_xmlport] = ACTIONS(5613),
    [anon_sym_XMLPORT] = ACTIONS(5613),
    [anon_sym_Xmlport] = ACTIONS(5613),
    [anon_sym_XMLport] = ACTIONS(5613),
    [anon_sym_XMLPort] = ACTIONS(5613),
    [anon_sym_XmlPort] = ACTIONS(5613),
    [anon_sym_enum] = ACTIONS(5613),
    [anon_sym_ENUM] = ACTIONS(5613),
    [anon_sym_Enum] = ACTIONS(5613),
    [anon_sym_eNUM] = ACTIONS(5613),
    [anon_sym_eNum] = ACTIONS(5613),
    [anon_sym_ENum] = ACTIONS(5613),
    [sym_quoted_identifier] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5615),
    [sym_verbatim_string] = ACTIONS(5615),
    [sym_integer] = ACTIONS(5613),
    [sym_continue_as_identifier] = ACTIONS(5615),
    [sym_preproc_open] = ACTIONS(5615),
  },
  [STATE(2991)] = {
    [sym_identifier] = ACTIONS(5617),
    [anon_sym_SEMI] = ACTIONS(5619),
    [anon_sym_DASH] = ACTIONS(5619),
    [aux_sym_boolean_token1] = ACTIONS(5617),
    [aux_sym_boolean_token2] = ACTIONS(5617),
    [sym_decimal] = ACTIONS(5617),
    [anon_sym_LPAREN] = ACTIONS(5619),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5617),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [aux_sym_record_type_token1] = ACTIONS(5617),
    [aux_sym_basic_type_token21] = ACTIONS(5617),
    [aux_sym_basic_type_token22] = ACTIONS(5617),
    [aux_sym_basic_type_token48] = ACTIONS(5617),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5617),
    [anon_sym_POUNDif] = ACTIONS(5619),
    [anon_sym_POUNDIF] = ACTIONS(5619),
    [anon_sym_POUNDIf] = ACTIONS(5619),
    [anon_sym_not] = ACTIONS(5617),
    [anon_sym_NOT] = ACTIONS(5617),
    [anon_sym_Not] = ACTIONS(5617),
    [anon_sym_POUNDelse] = ACTIONS(5619),
    [anon_sym_POUNDELSE] = ACTIONS(5619),
    [anon_sym_POUNDElse] = ACTIONS(5619),
    [anon_sym_POUNDelse2] = ACTIONS(5619),
    [anon_sym_POUNDELSE2] = ACTIONS(5619),
    [anon_sym_POUNDElse2] = ACTIONS(5619),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5617),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5617),
    [anon_sym_PLUS] = ACTIONS(5619),
    [sym_datetime_literal] = ACTIONS(5619),
    [sym_date_literal] = ACTIONS(5617),
    [sym_time_literal] = ACTIONS(5617),
    [sym_biginteger_literal] = ACTIONS(5619),
    [anon_sym_if] = ACTIONS(5617),
    [anon_sym_IF] = ACTIONS(5617),
    [anon_sym_If] = ACTIONS(5617),
    [anon_sym_else] = ACTIONS(5617),
    [anon_sym_ELSE] = ACTIONS(5617),
    [anon_sym_Else] = ACTIONS(5617),
    [anon_sym_case] = ACTIONS(5617),
    [anon_sym_CASE] = ACTIONS(5617),
    [anon_sym_Case] = ACTIONS(5617),
    [anon_sym_for] = ACTIONS(5617),
    [anon_sym_FOR] = ACTIONS(5617),
    [anon_sym_For] = ACTIONS(5617),
    [anon_sym_foreach] = ACTIONS(5617),
    [anon_sym_FOREACH] = ACTIONS(5617),
    [anon_sym_Foreach] = ACTIONS(5617),
    [anon_sym_while] = ACTIONS(5617),
    [anon_sym_WHILE] = ACTIONS(5617),
    [anon_sym_While] = ACTIONS(5617),
    [anon_sym_repeat] = ACTIONS(5617),
    [anon_sym_REPEAT] = ACTIONS(5617),
    [anon_sym_Repeat] = ACTIONS(5617),
    [anon_sym_until] = ACTIONS(5617),
    [anon_sym_UNTIL] = ACTIONS(5617),
    [anon_sym_Until] = ACTIONS(5617),
    [anon_sym_exit] = ACTIONS(5617),
    [anon_sym_EXIT] = ACTIONS(5617),
    [anon_sym_Exit] = ACTIONS(5617),
    [anon_sym_continue] = ACTIONS(5617),
    [anon_sym_CONTINUE] = ACTIONS(5617),
    [anon_sym_Continue] = ACTIONS(5617),
    [anon_sym_break] = ACTIONS(5617),
    [anon_sym_BREAK] = ACTIONS(5617),
    [anon_sym_Break] = ACTIONS(5617),
    [anon_sym_with] = ACTIONS(5617),
    [anon_sym_WITH] = ACTIONS(5617),
    [anon_sym_With] = ACTIONS(5617),
    [sym_asserterror_keyword] = ACTIONS(5619),
    [sym_page_keyword] = ACTIONS(5617),
    [anon_sym_codeunit] = ACTIONS(5617),
    [anon_sym_CODEUNIT] = ACTIONS(5617),
    [anon_sym_Codeunit] = ACTIONS(5617),
    [anon_sym_CodeUnit] = ACTIONS(5617),
    [anon_sym_COdeunit] = ACTIONS(5617),
    [anon_sym_codeUnit] = ACTIONS(5617),
    [sym_report_keyword] = ACTIONS(5617),
    [sym_query_keyword] = ACTIONS(5617),
    [anon_sym_xmlport] = ACTIONS(5617),
    [anon_sym_XMLPORT] = ACTIONS(5617),
    [anon_sym_Xmlport] = ACTIONS(5617),
    [anon_sym_XMLport] = ACTIONS(5617),
    [anon_sym_XMLPort] = ACTIONS(5617),
    [anon_sym_XmlPort] = ACTIONS(5617),
    [anon_sym_enum] = ACTIONS(5617),
    [anon_sym_ENUM] = ACTIONS(5617),
    [anon_sym_Enum] = ACTIONS(5617),
    [anon_sym_eNUM] = ACTIONS(5617),
    [anon_sym_eNum] = ACTIONS(5617),
    [anon_sym_ENum] = ACTIONS(5617),
    [sym_quoted_identifier] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5619),
    [sym_verbatim_string] = ACTIONS(5619),
    [sym_integer] = ACTIONS(5617),
    [sym_continue_as_identifier] = ACTIONS(5619),
    [sym_preproc_open] = ACTIONS(5619),
  },
  [STATE(2992)] = {
    [sym_identifier] = ACTIONS(5621),
    [anon_sym_SEMI] = ACTIONS(5623),
    [anon_sym_DASH] = ACTIONS(5623),
    [aux_sym_boolean_token1] = ACTIONS(5621),
    [aux_sym_boolean_token2] = ACTIONS(5621),
    [sym_decimal] = ACTIONS(5621),
    [anon_sym_LPAREN] = ACTIONS(5623),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5621),
    [anon_sym_LBRACK] = ACTIONS(5623),
    [aux_sym_record_type_token1] = ACTIONS(5621),
    [aux_sym_basic_type_token21] = ACTIONS(5621),
    [aux_sym_basic_type_token22] = ACTIONS(5621),
    [aux_sym_basic_type_token48] = ACTIONS(5621),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5621),
    [anon_sym_POUNDif] = ACTIONS(5623),
    [anon_sym_POUNDIF] = ACTIONS(5623),
    [anon_sym_POUNDIf] = ACTIONS(5623),
    [anon_sym_not] = ACTIONS(5621),
    [anon_sym_NOT] = ACTIONS(5621),
    [anon_sym_Not] = ACTIONS(5621),
    [anon_sym_POUNDelse] = ACTIONS(5623),
    [anon_sym_POUNDELSE] = ACTIONS(5623),
    [anon_sym_POUNDElse] = ACTIONS(5623),
    [anon_sym_POUNDelse2] = ACTIONS(5623),
    [anon_sym_POUNDELSE2] = ACTIONS(5623),
    [anon_sym_POUNDElse2] = ACTIONS(5623),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5621),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5621),
    [anon_sym_PLUS] = ACTIONS(5623),
    [sym_datetime_literal] = ACTIONS(5623),
    [sym_date_literal] = ACTIONS(5621),
    [sym_time_literal] = ACTIONS(5621),
    [sym_biginteger_literal] = ACTIONS(5623),
    [anon_sym_if] = ACTIONS(5621),
    [anon_sym_IF] = ACTIONS(5621),
    [anon_sym_If] = ACTIONS(5621),
    [anon_sym_else] = ACTIONS(5621),
    [anon_sym_ELSE] = ACTIONS(5621),
    [anon_sym_Else] = ACTIONS(5621),
    [anon_sym_case] = ACTIONS(5621),
    [anon_sym_CASE] = ACTIONS(5621),
    [anon_sym_Case] = ACTIONS(5621),
    [anon_sym_for] = ACTIONS(5621),
    [anon_sym_FOR] = ACTIONS(5621),
    [anon_sym_For] = ACTIONS(5621),
    [anon_sym_foreach] = ACTIONS(5621),
    [anon_sym_FOREACH] = ACTIONS(5621),
    [anon_sym_Foreach] = ACTIONS(5621),
    [anon_sym_while] = ACTIONS(5621),
    [anon_sym_WHILE] = ACTIONS(5621),
    [anon_sym_While] = ACTIONS(5621),
    [anon_sym_repeat] = ACTIONS(5621),
    [anon_sym_REPEAT] = ACTIONS(5621),
    [anon_sym_Repeat] = ACTIONS(5621),
    [anon_sym_until] = ACTIONS(5621),
    [anon_sym_UNTIL] = ACTIONS(5621),
    [anon_sym_Until] = ACTIONS(5621),
    [anon_sym_exit] = ACTIONS(5621),
    [anon_sym_EXIT] = ACTIONS(5621),
    [anon_sym_Exit] = ACTIONS(5621),
    [anon_sym_continue] = ACTIONS(5621),
    [anon_sym_CONTINUE] = ACTIONS(5621),
    [anon_sym_Continue] = ACTIONS(5621),
    [anon_sym_break] = ACTIONS(5621),
    [anon_sym_BREAK] = ACTIONS(5621),
    [anon_sym_Break] = ACTIONS(5621),
    [anon_sym_with] = ACTIONS(5621),
    [anon_sym_WITH] = ACTIONS(5621),
    [anon_sym_With] = ACTIONS(5621),
    [sym_asserterror_keyword] = ACTIONS(5623),
    [sym_page_keyword] = ACTIONS(5621),
    [anon_sym_codeunit] = ACTIONS(5621),
    [anon_sym_CODEUNIT] = ACTIONS(5621),
    [anon_sym_Codeunit] = ACTIONS(5621),
    [anon_sym_CodeUnit] = ACTIONS(5621),
    [anon_sym_COdeunit] = ACTIONS(5621),
    [anon_sym_codeUnit] = ACTIONS(5621),
    [sym_report_keyword] = ACTIONS(5621),
    [sym_query_keyword] = ACTIONS(5621),
    [anon_sym_xmlport] = ACTIONS(5621),
    [anon_sym_XMLPORT] = ACTIONS(5621),
    [anon_sym_Xmlport] = ACTIONS(5621),
    [anon_sym_XMLport] = ACTIONS(5621),
    [anon_sym_XMLPort] = ACTIONS(5621),
    [anon_sym_XmlPort] = ACTIONS(5621),
    [anon_sym_enum] = ACTIONS(5621),
    [anon_sym_ENUM] = ACTIONS(5621),
    [anon_sym_Enum] = ACTIONS(5621),
    [anon_sym_eNUM] = ACTIONS(5621),
    [anon_sym_eNum] = ACTIONS(5621),
    [anon_sym_ENum] = ACTIONS(5621),
    [sym_quoted_identifier] = ACTIONS(5623),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5623),
    [sym_verbatim_string] = ACTIONS(5623),
    [sym_integer] = ACTIONS(5621),
    [sym_continue_as_identifier] = ACTIONS(5623),
    [sym_preproc_open] = ACTIONS(5623),
  },
  [STATE(2993)] = {
    [sym_identifier] = ACTIONS(5625),
    [anon_sym_SEMI] = ACTIONS(5627),
    [anon_sym_DASH] = ACTIONS(5627),
    [aux_sym_boolean_token1] = ACTIONS(5625),
    [aux_sym_boolean_token2] = ACTIONS(5625),
    [sym_decimal] = ACTIONS(5625),
    [anon_sym_LPAREN] = ACTIONS(5627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5625),
    [anon_sym_LBRACK] = ACTIONS(5627),
    [aux_sym_record_type_token1] = ACTIONS(5625),
    [aux_sym_basic_type_token21] = ACTIONS(5625),
    [aux_sym_basic_type_token22] = ACTIONS(5625),
    [aux_sym_basic_type_token48] = ACTIONS(5625),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5625),
    [anon_sym_POUNDif] = ACTIONS(5627),
    [anon_sym_POUNDIF] = ACTIONS(5627),
    [anon_sym_POUNDIf] = ACTIONS(5627),
    [anon_sym_not] = ACTIONS(5625),
    [anon_sym_NOT] = ACTIONS(5625),
    [anon_sym_Not] = ACTIONS(5625),
    [anon_sym_POUNDelse] = ACTIONS(5627),
    [anon_sym_POUNDELSE] = ACTIONS(5627),
    [anon_sym_POUNDElse] = ACTIONS(5627),
    [anon_sym_POUNDelse2] = ACTIONS(5627),
    [anon_sym_POUNDELSE2] = ACTIONS(5627),
    [anon_sym_POUNDElse2] = ACTIONS(5627),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5625),
    [anon_sym_PLUS] = ACTIONS(5627),
    [sym_datetime_literal] = ACTIONS(5627),
    [sym_date_literal] = ACTIONS(5625),
    [sym_time_literal] = ACTIONS(5625),
    [sym_biginteger_literal] = ACTIONS(5627),
    [anon_sym_if] = ACTIONS(5625),
    [anon_sym_IF] = ACTIONS(5625),
    [anon_sym_If] = ACTIONS(5625),
    [anon_sym_else] = ACTIONS(5625),
    [anon_sym_ELSE] = ACTIONS(5625),
    [anon_sym_Else] = ACTIONS(5625),
    [anon_sym_case] = ACTIONS(5625),
    [anon_sym_CASE] = ACTIONS(5625),
    [anon_sym_Case] = ACTIONS(5625),
    [anon_sym_for] = ACTIONS(5625),
    [anon_sym_FOR] = ACTIONS(5625),
    [anon_sym_For] = ACTIONS(5625),
    [anon_sym_foreach] = ACTIONS(5625),
    [anon_sym_FOREACH] = ACTIONS(5625),
    [anon_sym_Foreach] = ACTIONS(5625),
    [anon_sym_while] = ACTIONS(5625),
    [anon_sym_WHILE] = ACTIONS(5625),
    [anon_sym_While] = ACTIONS(5625),
    [anon_sym_repeat] = ACTIONS(5625),
    [anon_sym_REPEAT] = ACTIONS(5625),
    [anon_sym_Repeat] = ACTIONS(5625),
    [anon_sym_until] = ACTIONS(5625),
    [anon_sym_UNTIL] = ACTIONS(5625),
    [anon_sym_Until] = ACTIONS(5625),
    [anon_sym_exit] = ACTIONS(5625),
    [anon_sym_EXIT] = ACTIONS(5625),
    [anon_sym_Exit] = ACTIONS(5625),
    [anon_sym_continue] = ACTIONS(5625),
    [anon_sym_CONTINUE] = ACTIONS(5625),
    [anon_sym_Continue] = ACTIONS(5625),
    [anon_sym_break] = ACTIONS(5625),
    [anon_sym_BREAK] = ACTIONS(5625),
    [anon_sym_Break] = ACTIONS(5625),
    [anon_sym_with] = ACTIONS(5625),
    [anon_sym_WITH] = ACTIONS(5625),
    [anon_sym_With] = ACTIONS(5625),
    [sym_asserterror_keyword] = ACTIONS(5627),
    [sym_page_keyword] = ACTIONS(5625),
    [anon_sym_codeunit] = ACTIONS(5625),
    [anon_sym_CODEUNIT] = ACTIONS(5625),
    [anon_sym_Codeunit] = ACTIONS(5625),
    [anon_sym_CodeUnit] = ACTIONS(5625),
    [anon_sym_COdeunit] = ACTIONS(5625),
    [anon_sym_codeUnit] = ACTIONS(5625),
    [sym_report_keyword] = ACTIONS(5625),
    [sym_query_keyword] = ACTIONS(5625),
    [anon_sym_xmlport] = ACTIONS(5625),
    [anon_sym_XMLPORT] = ACTIONS(5625),
    [anon_sym_Xmlport] = ACTIONS(5625),
    [anon_sym_XMLport] = ACTIONS(5625),
    [anon_sym_XMLPort] = ACTIONS(5625),
    [anon_sym_XmlPort] = ACTIONS(5625),
    [anon_sym_enum] = ACTIONS(5625),
    [anon_sym_ENUM] = ACTIONS(5625),
    [anon_sym_Enum] = ACTIONS(5625),
    [anon_sym_eNUM] = ACTIONS(5625),
    [anon_sym_eNum] = ACTIONS(5625),
    [anon_sym_ENum] = ACTIONS(5625),
    [sym_quoted_identifier] = ACTIONS(5627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5627),
    [sym_verbatim_string] = ACTIONS(5627),
    [sym_integer] = ACTIONS(5625),
    [sym_continue_as_identifier] = ACTIONS(5627),
    [sym_preproc_open] = ACTIONS(5627),
  },
  [STATE(2994)] = {
    [sym_identifier] = ACTIONS(5629),
    [anon_sym_SEMI] = ACTIONS(5631),
    [anon_sym_DASH] = ACTIONS(5631),
    [aux_sym_boolean_token1] = ACTIONS(5629),
    [aux_sym_boolean_token2] = ACTIONS(5629),
    [sym_decimal] = ACTIONS(5629),
    [anon_sym_LPAREN] = ACTIONS(5631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5629),
    [anon_sym_LBRACK] = ACTIONS(5631),
    [aux_sym_record_type_token1] = ACTIONS(5629),
    [aux_sym_basic_type_token21] = ACTIONS(5629),
    [aux_sym_basic_type_token22] = ACTIONS(5629),
    [aux_sym_basic_type_token48] = ACTIONS(5629),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5629),
    [anon_sym_POUNDif] = ACTIONS(5631),
    [anon_sym_POUNDIF] = ACTIONS(5631),
    [anon_sym_POUNDIf] = ACTIONS(5631),
    [anon_sym_not] = ACTIONS(5629),
    [anon_sym_NOT] = ACTIONS(5629),
    [anon_sym_Not] = ACTIONS(5629),
    [anon_sym_POUNDelse] = ACTIONS(5631),
    [anon_sym_POUNDELSE] = ACTIONS(5631),
    [anon_sym_POUNDElse] = ACTIONS(5631),
    [anon_sym_POUNDelse2] = ACTIONS(5631),
    [anon_sym_POUNDELSE2] = ACTIONS(5631),
    [anon_sym_POUNDElse2] = ACTIONS(5631),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5629),
    [anon_sym_PLUS] = ACTIONS(5631),
    [sym_datetime_literal] = ACTIONS(5631),
    [sym_date_literal] = ACTIONS(5629),
    [sym_time_literal] = ACTIONS(5629),
    [sym_biginteger_literal] = ACTIONS(5631),
    [anon_sym_if] = ACTIONS(5629),
    [anon_sym_IF] = ACTIONS(5629),
    [anon_sym_If] = ACTIONS(5629),
    [anon_sym_else] = ACTIONS(5629),
    [anon_sym_ELSE] = ACTIONS(5629),
    [anon_sym_Else] = ACTIONS(5629),
    [anon_sym_case] = ACTIONS(5629),
    [anon_sym_CASE] = ACTIONS(5629),
    [anon_sym_Case] = ACTIONS(5629),
    [anon_sym_for] = ACTIONS(5629),
    [anon_sym_FOR] = ACTIONS(5629),
    [anon_sym_For] = ACTIONS(5629),
    [anon_sym_foreach] = ACTIONS(5629),
    [anon_sym_FOREACH] = ACTIONS(5629),
    [anon_sym_Foreach] = ACTIONS(5629),
    [anon_sym_while] = ACTIONS(5629),
    [anon_sym_WHILE] = ACTIONS(5629),
    [anon_sym_While] = ACTIONS(5629),
    [anon_sym_repeat] = ACTIONS(5629),
    [anon_sym_REPEAT] = ACTIONS(5629),
    [anon_sym_Repeat] = ACTIONS(5629),
    [anon_sym_until] = ACTIONS(5629),
    [anon_sym_UNTIL] = ACTIONS(5629),
    [anon_sym_Until] = ACTIONS(5629),
    [anon_sym_exit] = ACTIONS(5629),
    [anon_sym_EXIT] = ACTIONS(5629),
    [anon_sym_Exit] = ACTIONS(5629),
    [anon_sym_continue] = ACTIONS(5629),
    [anon_sym_CONTINUE] = ACTIONS(5629),
    [anon_sym_Continue] = ACTIONS(5629),
    [anon_sym_break] = ACTIONS(5629),
    [anon_sym_BREAK] = ACTIONS(5629),
    [anon_sym_Break] = ACTIONS(5629),
    [anon_sym_with] = ACTIONS(5629),
    [anon_sym_WITH] = ACTIONS(5629),
    [anon_sym_With] = ACTIONS(5629),
    [sym_asserterror_keyword] = ACTIONS(5631),
    [sym_page_keyword] = ACTIONS(5629),
    [anon_sym_codeunit] = ACTIONS(5629),
    [anon_sym_CODEUNIT] = ACTIONS(5629),
    [anon_sym_Codeunit] = ACTIONS(5629),
    [anon_sym_CodeUnit] = ACTIONS(5629),
    [anon_sym_COdeunit] = ACTIONS(5629),
    [anon_sym_codeUnit] = ACTIONS(5629),
    [sym_report_keyword] = ACTIONS(5629),
    [sym_query_keyword] = ACTIONS(5629),
    [anon_sym_xmlport] = ACTIONS(5629),
    [anon_sym_XMLPORT] = ACTIONS(5629),
    [anon_sym_Xmlport] = ACTIONS(5629),
    [anon_sym_XMLport] = ACTIONS(5629),
    [anon_sym_XMLPort] = ACTIONS(5629),
    [anon_sym_XmlPort] = ACTIONS(5629),
    [anon_sym_enum] = ACTIONS(5629),
    [anon_sym_ENUM] = ACTIONS(5629),
    [anon_sym_Enum] = ACTIONS(5629),
    [anon_sym_eNUM] = ACTIONS(5629),
    [anon_sym_eNum] = ACTIONS(5629),
    [anon_sym_ENum] = ACTIONS(5629),
    [sym_quoted_identifier] = ACTIONS(5631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5631),
    [sym_verbatim_string] = ACTIONS(5631),
    [sym_integer] = ACTIONS(5629),
    [sym_continue_as_identifier] = ACTIONS(5631),
    [sym_preproc_open] = ACTIONS(5631),
  },
  [STATE(2995)] = {
    [sym_identifier] = ACTIONS(5633),
    [anon_sym_SEMI] = ACTIONS(5635),
    [anon_sym_DASH] = ACTIONS(5635),
    [aux_sym_boolean_token1] = ACTIONS(5633),
    [aux_sym_boolean_token2] = ACTIONS(5633),
    [sym_decimal] = ACTIONS(5633),
    [anon_sym_LPAREN] = ACTIONS(5635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5633),
    [anon_sym_LBRACK] = ACTIONS(5635),
    [aux_sym_record_type_token1] = ACTIONS(5633),
    [aux_sym_basic_type_token21] = ACTIONS(5633),
    [aux_sym_basic_type_token22] = ACTIONS(5633),
    [aux_sym_basic_type_token48] = ACTIONS(5633),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5633),
    [anon_sym_POUNDif] = ACTIONS(5635),
    [anon_sym_POUNDIF] = ACTIONS(5635),
    [anon_sym_POUNDIf] = ACTIONS(5635),
    [anon_sym_not] = ACTIONS(5633),
    [anon_sym_NOT] = ACTIONS(5633),
    [anon_sym_Not] = ACTIONS(5633),
    [anon_sym_POUNDelse] = ACTIONS(5635),
    [anon_sym_POUNDELSE] = ACTIONS(5635),
    [anon_sym_POUNDElse] = ACTIONS(5635),
    [anon_sym_POUNDelse2] = ACTIONS(5635),
    [anon_sym_POUNDELSE2] = ACTIONS(5635),
    [anon_sym_POUNDElse2] = ACTIONS(5635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5633),
    [anon_sym_PLUS] = ACTIONS(5635),
    [sym_datetime_literal] = ACTIONS(5635),
    [sym_date_literal] = ACTIONS(5633),
    [sym_time_literal] = ACTIONS(5633),
    [sym_biginteger_literal] = ACTIONS(5635),
    [anon_sym_if] = ACTIONS(5633),
    [anon_sym_IF] = ACTIONS(5633),
    [anon_sym_If] = ACTIONS(5633),
    [anon_sym_else] = ACTIONS(5633),
    [anon_sym_ELSE] = ACTIONS(5633),
    [anon_sym_Else] = ACTIONS(5633),
    [anon_sym_case] = ACTIONS(5633),
    [anon_sym_CASE] = ACTIONS(5633),
    [anon_sym_Case] = ACTIONS(5633),
    [anon_sym_for] = ACTIONS(5633),
    [anon_sym_FOR] = ACTIONS(5633),
    [anon_sym_For] = ACTIONS(5633),
    [anon_sym_foreach] = ACTIONS(5633),
    [anon_sym_FOREACH] = ACTIONS(5633),
    [anon_sym_Foreach] = ACTIONS(5633),
    [anon_sym_while] = ACTIONS(5633),
    [anon_sym_WHILE] = ACTIONS(5633),
    [anon_sym_While] = ACTIONS(5633),
    [anon_sym_repeat] = ACTIONS(5633),
    [anon_sym_REPEAT] = ACTIONS(5633),
    [anon_sym_Repeat] = ACTIONS(5633),
    [anon_sym_until] = ACTIONS(5633),
    [anon_sym_UNTIL] = ACTIONS(5633),
    [anon_sym_Until] = ACTIONS(5633),
    [anon_sym_exit] = ACTIONS(5633),
    [anon_sym_EXIT] = ACTIONS(5633),
    [anon_sym_Exit] = ACTIONS(5633),
    [anon_sym_continue] = ACTIONS(5633),
    [anon_sym_CONTINUE] = ACTIONS(5633),
    [anon_sym_Continue] = ACTIONS(5633),
    [anon_sym_break] = ACTIONS(5633),
    [anon_sym_BREAK] = ACTIONS(5633),
    [anon_sym_Break] = ACTIONS(5633),
    [anon_sym_with] = ACTIONS(5633),
    [anon_sym_WITH] = ACTIONS(5633),
    [anon_sym_With] = ACTIONS(5633),
    [sym_asserterror_keyword] = ACTIONS(5635),
    [sym_page_keyword] = ACTIONS(5633),
    [anon_sym_codeunit] = ACTIONS(5633),
    [anon_sym_CODEUNIT] = ACTIONS(5633),
    [anon_sym_Codeunit] = ACTIONS(5633),
    [anon_sym_CodeUnit] = ACTIONS(5633),
    [anon_sym_COdeunit] = ACTIONS(5633),
    [anon_sym_codeUnit] = ACTIONS(5633),
    [sym_report_keyword] = ACTIONS(5633),
    [sym_query_keyword] = ACTIONS(5633),
    [anon_sym_xmlport] = ACTIONS(5633),
    [anon_sym_XMLPORT] = ACTIONS(5633),
    [anon_sym_Xmlport] = ACTIONS(5633),
    [anon_sym_XMLport] = ACTIONS(5633),
    [anon_sym_XMLPort] = ACTIONS(5633),
    [anon_sym_XmlPort] = ACTIONS(5633),
    [anon_sym_enum] = ACTIONS(5633),
    [anon_sym_ENUM] = ACTIONS(5633),
    [anon_sym_Enum] = ACTIONS(5633),
    [anon_sym_eNUM] = ACTIONS(5633),
    [anon_sym_eNum] = ACTIONS(5633),
    [anon_sym_ENum] = ACTIONS(5633),
    [sym_quoted_identifier] = ACTIONS(5635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5635),
    [sym_verbatim_string] = ACTIONS(5635),
    [sym_integer] = ACTIONS(5633),
    [sym_continue_as_identifier] = ACTIONS(5635),
    [sym_preproc_open] = ACTIONS(5635),
  },
  [STATE(2996)] = {
    [sym_identifier] = ACTIONS(5637),
    [anon_sym_SEMI] = ACTIONS(5639),
    [anon_sym_DASH] = ACTIONS(5639),
    [aux_sym_boolean_token1] = ACTIONS(5637),
    [aux_sym_boolean_token2] = ACTIONS(5637),
    [sym_decimal] = ACTIONS(5637),
    [anon_sym_LPAREN] = ACTIONS(5639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5637),
    [anon_sym_LBRACK] = ACTIONS(5639),
    [aux_sym_record_type_token1] = ACTIONS(5637),
    [aux_sym_basic_type_token21] = ACTIONS(5637),
    [aux_sym_basic_type_token22] = ACTIONS(5637),
    [aux_sym_basic_type_token48] = ACTIONS(5637),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5637),
    [anon_sym_POUNDif] = ACTIONS(5639),
    [anon_sym_POUNDIF] = ACTIONS(5639),
    [anon_sym_POUNDIf] = ACTIONS(5639),
    [anon_sym_not] = ACTIONS(5637),
    [anon_sym_NOT] = ACTIONS(5637),
    [anon_sym_Not] = ACTIONS(5637),
    [anon_sym_POUNDelse] = ACTIONS(5639),
    [anon_sym_POUNDELSE] = ACTIONS(5639),
    [anon_sym_POUNDElse] = ACTIONS(5639),
    [anon_sym_POUNDelse2] = ACTIONS(5639),
    [anon_sym_POUNDELSE2] = ACTIONS(5639),
    [anon_sym_POUNDElse2] = ACTIONS(5639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5637),
    [anon_sym_PLUS] = ACTIONS(5639),
    [sym_datetime_literal] = ACTIONS(5639),
    [sym_date_literal] = ACTIONS(5637),
    [sym_time_literal] = ACTIONS(5637),
    [sym_biginteger_literal] = ACTIONS(5639),
    [anon_sym_if] = ACTIONS(5637),
    [anon_sym_IF] = ACTIONS(5637),
    [anon_sym_If] = ACTIONS(5637),
    [anon_sym_else] = ACTIONS(5637),
    [anon_sym_ELSE] = ACTIONS(5637),
    [anon_sym_Else] = ACTIONS(5637),
    [anon_sym_case] = ACTIONS(5637),
    [anon_sym_CASE] = ACTIONS(5637),
    [anon_sym_Case] = ACTIONS(5637),
    [anon_sym_for] = ACTIONS(5637),
    [anon_sym_FOR] = ACTIONS(5637),
    [anon_sym_For] = ACTIONS(5637),
    [anon_sym_foreach] = ACTIONS(5637),
    [anon_sym_FOREACH] = ACTIONS(5637),
    [anon_sym_Foreach] = ACTIONS(5637),
    [anon_sym_while] = ACTIONS(5637),
    [anon_sym_WHILE] = ACTIONS(5637),
    [anon_sym_While] = ACTIONS(5637),
    [anon_sym_repeat] = ACTIONS(5637),
    [anon_sym_REPEAT] = ACTIONS(5637),
    [anon_sym_Repeat] = ACTIONS(5637),
    [anon_sym_until] = ACTIONS(5637),
    [anon_sym_UNTIL] = ACTIONS(5637),
    [anon_sym_Until] = ACTIONS(5637),
    [anon_sym_exit] = ACTIONS(5637),
    [anon_sym_EXIT] = ACTIONS(5637),
    [anon_sym_Exit] = ACTIONS(5637),
    [anon_sym_continue] = ACTIONS(5637),
    [anon_sym_CONTINUE] = ACTIONS(5637),
    [anon_sym_Continue] = ACTIONS(5637),
    [anon_sym_break] = ACTIONS(5637),
    [anon_sym_BREAK] = ACTIONS(5637),
    [anon_sym_Break] = ACTIONS(5637),
    [anon_sym_with] = ACTIONS(5637),
    [anon_sym_WITH] = ACTIONS(5637),
    [anon_sym_With] = ACTIONS(5637),
    [sym_asserterror_keyword] = ACTIONS(5639),
    [sym_page_keyword] = ACTIONS(5637),
    [anon_sym_codeunit] = ACTIONS(5637),
    [anon_sym_CODEUNIT] = ACTIONS(5637),
    [anon_sym_Codeunit] = ACTIONS(5637),
    [anon_sym_CodeUnit] = ACTIONS(5637),
    [anon_sym_COdeunit] = ACTIONS(5637),
    [anon_sym_codeUnit] = ACTIONS(5637),
    [sym_report_keyword] = ACTIONS(5637),
    [sym_query_keyword] = ACTIONS(5637),
    [anon_sym_xmlport] = ACTIONS(5637),
    [anon_sym_XMLPORT] = ACTIONS(5637),
    [anon_sym_Xmlport] = ACTIONS(5637),
    [anon_sym_XMLport] = ACTIONS(5637),
    [anon_sym_XMLPort] = ACTIONS(5637),
    [anon_sym_XmlPort] = ACTIONS(5637),
    [anon_sym_enum] = ACTIONS(5637),
    [anon_sym_ENUM] = ACTIONS(5637),
    [anon_sym_Enum] = ACTIONS(5637),
    [anon_sym_eNUM] = ACTIONS(5637),
    [anon_sym_eNum] = ACTIONS(5637),
    [anon_sym_ENum] = ACTIONS(5637),
    [sym_quoted_identifier] = ACTIONS(5639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5639),
    [sym_verbatim_string] = ACTIONS(5639),
    [sym_integer] = ACTIONS(5637),
    [sym_continue_as_identifier] = ACTIONS(5639),
    [sym_preproc_open] = ACTIONS(5639),
  },
  [STATE(2997)] = {
    [sym_identifier] = ACTIONS(5641),
    [anon_sym_SEMI] = ACTIONS(5643),
    [anon_sym_DASH] = ACTIONS(5643),
    [aux_sym_boolean_token1] = ACTIONS(5641),
    [aux_sym_boolean_token2] = ACTIONS(5641),
    [sym_decimal] = ACTIONS(5641),
    [anon_sym_LPAREN] = ACTIONS(5643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5641),
    [anon_sym_LBRACK] = ACTIONS(5643),
    [aux_sym_record_type_token1] = ACTIONS(5641),
    [aux_sym_basic_type_token21] = ACTIONS(5641),
    [aux_sym_basic_type_token22] = ACTIONS(5641),
    [aux_sym_basic_type_token48] = ACTIONS(5641),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5641),
    [anon_sym_POUNDif] = ACTIONS(5643),
    [anon_sym_POUNDIF] = ACTIONS(5643),
    [anon_sym_POUNDIf] = ACTIONS(5643),
    [anon_sym_not] = ACTIONS(5641),
    [anon_sym_NOT] = ACTIONS(5641),
    [anon_sym_Not] = ACTIONS(5641),
    [anon_sym_POUNDelse] = ACTIONS(5643),
    [anon_sym_POUNDELSE] = ACTIONS(5643),
    [anon_sym_POUNDElse] = ACTIONS(5643),
    [anon_sym_POUNDelse2] = ACTIONS(5643),
    [anon_sym_POUNDELSE2] = ACTIONS(5643),
    [anon_sym_POUNDElse2] = ACTIONS(5643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5641),
    [anon_sym_PLUS] = ACTIONS(5643),
    [sym_datetime_literal] = ACTIONS(5643),
    [sym_date_literal] = ACTIONS(5641),
    [sym_time_literal] = ACTIONS(5641),
    [sym_biginteger_literal] = ACTIONS(5643),
    [anon_sym_if] = ACTIONS(5641),
    [anon_sym_IF] = ACTIONS(5641),
    [anon_sym_If] = ACTIONS(5641),
    [anon_sym_else] = ACTIONS(5641),
    [anon_sym_ELSE] = ACTIONS(5641),
    [anon_sym_Else] = ACTIONS(5641),
    [anon_sym_case] = ACTIONS(5641),
    [anon_sym_CASE] = ACTIONS(5641),
    [anon_sym_Case] = ACTIONS(5641),
    [anon_sym_for] = ACTIONS(5641),
    [anon_sym_FOR] = ACTIONS(5641),
    [anon_sym_For] = ACTIONS(5641),
    [anon_sym_foreach] = ACTIONS(5641),
    [anon_sym_FOREACH] = ACTIONS(5641),
    [anon_sym_Foreach] = ACTIONS(5641),
    [anon_sym_while] = ACTIONS(5641),
    [anon_sym_WHILE] = ACTIONS(5641),
    [anon_sym_While] = ACTIONS(5641),
    [anon_sym_repeat] = ACTIONS(5641),
    [anon_sym_REPEAT] = ACTIONS(5641),
    [anon_sym_Repeat] = ACTIONS(5641),
    [anon_sym_until] = ACTIONS(5641),
    [anon_sym_UNTIL] = ACTIONS(5641),
    [anon_sym_Until] = ACTIONS(5641),
    [anon_sym_exit] = ACTIONS(5641),
    [anon_sym_EXIT] = ACTIONS(5641),
    [anon_sym_Exit] = ACTIONS(5641),
    [anon_sym_continue] = ACTIONS(5641),
    [anon_sym_CONTINUE] = ACTIONS(5641),
    [anon_sym_Continue] = ACTIONS(5641),
    [anon_sym_break] = ACTIONS(5641),
    [anon_sym_BREAK] = ACTIONS(5641),
    [anon_sym_Break] = ACTIONS(5641),
    [anon_sym_with] = ACTIONS(5641),
    [anon_sym_WITH] = ACTIONS(5641),
    [anon_sym_With] = ACTIONS(5641),
    [sym_asserterror_keyword] = ACTIONS(5643),
    [sym_page_keyword] = ACTIONS(5641),
    [anon_sym_codeunit] = ACTIONS(5641),
    [anon_sym_CODEUNIT] = ACTIONS(5641),
    [anon_sym_Codeunit] = ACTIONS(5641),
    [anon_sym_CodeUnit] = ACTIONS(5641),
    [anon_sym_COdeunit] = ACTIONS(5641),
    [anon_sym_codeUnit] = ACTIONS(5641),
    [sym_report_keyword] = ACTIONS(5641),
    [sym_query_keyword] = ACTIONS(5641),
    [anon_sym_xmlport] = ACTIONS(5641),
    [anon_sym_XMLPORT] = ACTIONS(5641),
    [anon_sym_Xmlport] = ACTIONS(5641),
    [anon_sym_XMLport] = ACTIONS(5641),
    [anon_sym_XMLPort] = ACTIONS(5641),
    [anon_sym_XmlPort] = ACTIONS(5641),
    [anon_sym_enum] = ACTIONS(5641),
    [anon_sym_ENUM] = ACTIONS(5641),
    [anon_sym_Enum] = ACTIONS(5641),
    [anon_sym_eNUM] = ACTIONS(5641),
    [anon_sym_eNum] = ACTIONS(5641),
    [anon_sym_ENum] = ACTIONS(5641),
    [sym_quoted_identifier] = ACTIONS(5643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5643),
    [sym_verbatim_string] = ACTIONS(5643),
    [sym_integer] = ACTIONS(5641),
    [sym_continue_as_identifier] = ACTIONS(5643),
    [sym_preproc_open] = ACTIONS(5643),
  },
  [STATE(2998)] = {
    [sym_identifier] = ACTIONS(5645),
    [anon_sym_SEMI] = ACTIONS(5647),
    [anon_sym_DASH] = ACTIONS(5647),
    [aux_sym_boolean_token1] = ACTIONS(5645),
    [aux_sym_boolean_token2] = ACTIONS(5645),
    [sym_decimal] = ACTIONS(5645),
    [anon_sym_LPAREN] = ACTIONS(5647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5645),
    [anon_sym_LBRACK] = ACTIONS(5647),
    [aux_sym_record_type_token1] = ACTIONS(5645),
    [aux_sym_basic_type_token21] = ACTIONS(5645),
    [aux_sym_basic_type_token22] = ACTIONS(5645),
    [aux_sym_basic_type_token48] = ACTIONS(5645),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5645),
    [anon_sym_POUNDif] = ACTIONS(5647),
    [anon_sym_POUNDIF] = ACTIONS(5647),
    [anon_sym_POUNDIf] = ACTIONS(5647),
    [anon_sym_not] = ACTIONS(5645),
    [anon_sym_NOT] = ACTIONS(5645),
    [anon_sym_Not] = ACTIONS(5645),
    [anon_sym_POUNDelse] = ACTIONS(5647),
    [anon_sym_POUNDELSE] = ACTIONS(5647),
    [anon_sym_POUNDElse] = ACTIONS(5647),
    [anon_sym_POUNDelse2] = ACTIONS(5647),
    [anon_sym_POUNDELSE2] = ACTIONS(5647),
    [anon_sym_POUNDElse2] = ACTIONS(5647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5645),
    [anon_sym_PLUS] = ACTIONS(5647),
    [sym_datetime_literal] = ACTIONS(5647),
    [sym_date_literal] = ACTIONS(5645),
    [sym_time_literal] = ACTIONS(5645),
    [sym_biginteger_literal] = ACTIONS(5647),
    [anon_sym_if] = ACTIONS(5645),
    [anon_sym_IF] = ACTIONS(5645),
    [anon_sym_If] = ACTIONS(5645),
    [anon_sym_else] = ACTIONS(5645),
    [anon_sym_ELSE] = ACTIONS(5645),
    [anon_sym_Else] = ACTIONS(5645),
    [anon_sym_case] = ACTIONS(5645),
    [anon_sym_CASE] = ACTIONS(5645),
    [anon_sym_Case] = ACTIONS(5645),
    [anon_sym_for] = ACTIONS(5645),
    [anon_sym_FOR] = ACTIONS(5645),
    [anon_sym_For] = ACTIONS(5645),
    [anon_sym_foreach] = ACTIONS(5645),
    [anon_sym_FOREACH] = ACTIONS(5645),
    [anon_sym_Foreach] = ACTIONS(5645),
    [anon_sym_while] = ACTIONS(5645),
    [anon_sym_WHILE] = ACTIONS(5645),
    [anon_sym_While] = ACTIONS(5645),
    [anon_sym_repeat] = ACTIONS(5645),
    [anon_sym_REPEAT] = ACTIONS(5645),
    [anon_sym_Repeat] = ACTIONS(5645),
    [anon_sym_until] = ACTIONS(5645),
    [anon_sym_UNTIL] = ACTIONS(5645),
    [anon_sym_Until] = ACTIONS(5645),
    [anon_sym_exit] = ACTIONS(5645),
    [anon_sym_EXIT] = ACTIONS(5645),
    [anon_sym_Exit] = ACTIONS(5645),
    [anon_sym_continue] = ACTIONS(5645),
    [anon_sym_CONTINUE] = ACTIONS(5645),
    [anon_sym_Continue] = ACTIONS(5645),
    [anon_sym_break] = ACTIONS(5645),
    [anon_sym_BREAK] = ACTIONS(5645),
    [anon_sym_Break] = ACTIONS(5645),
    [anon_sym_with] = ACTIONS(5645),
    [anon_sym_WITH] = ACTIONS(5645),
    [anon_sym_With] = ACTIONS(5645),
    [sym_asserterror_keyword] = ACTIONS(5647),
    [sym_page_keyword] = ACTIONS(5645),
    [anon_sym_codeunit] = ACTIONS(5645),
    [anon_sym_CODEUNIT] = ACTIONS(5645),
    [anon_sym_Codeunit] = ACTIONS(5645),
    [anon_sym_CodeUnit] = ACTIONS(5645),
    [anon_sym_COdeunit] = ACTIONS(5645),
    [anon_sym_codeUnit] = ACTIONS(5645),
    [sym_report_keyword] = ACTIONS(5645),
    [sym_query_keyword] = ACTIONS(5645),
    [anon_sym_xmlport] = ACTIONS(5645),
    [anon_sym_XMLPORT] = ACTIONS(5645),
    [anon_sym_Xmlport] = ACTIONS(5645),
    [anon_sym_XMLport] = ACTIONS(5645),
    [anon_sym_XMLPort] = ACTIONS(5645),
    [anon_sym_XmlPort] = ACTIONS(5645),
    [anon_sym_enum] = ACTIONS(5645),
    [anon_sym_ENUM] = ACTIONS(5645),
    [anon_sym_Enum] = ACTIONS(5645),
    [anon_sym_eNUM] = ACTIONS(5645),
    [anon_sym_eNum] = ACTIONS(5645),
    [anon_sym_ENum] = ACTIONS(5645),
    [sym_quoted_identifier] = ACTIONS(5647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5647),
    [sym_verbatim_string] = ACTIONS(5647),
    [sym_integer] = ACTIONS(5645),
    [sym_continue_as_identifier] = ACTIONS(5647),
    [sym_preproc_open] = ACTIONS(5647),
  },
  [STATE(2999)] = {
    [sym_identifier] = ACTIONS(5649),
    [anon_sym_SEMI] = ACTIONS(5651),
    [anon_sym_DASH] = ACTIONS(5651),
    [aux_sym_boolean_token1] = ACTIONS(5649),
    [aux_sym_boolean_token2] = ACTIONS(5649),
    [sym_decimal] = ACTIONS(5649),
    [anon_sym_LPAREN] = ACTIONS(5651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5649),
    [anon_sym_LBRACK] = ACTIONS(5651),
    [aux_sym_record_type_token1] = ACTIONS(5649),
    [aux_sym_basic_type_token21] = ACTIONS(5649),
    [aux_sym_basic_type_token22] = ACTIONS(5649),
    [aux_sym_basic_type_token48] = ACTIONS(5649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5649),
    [anon_sym_POUNDif] = ACTIONS(5651),
    [anon_sym_POUNDIF] = ACTIONS(5651),
    [anon_sym_POUNDIf] = ACTIONS(5651),
    [anon_sym_not] = ACTIONS(5649),
    [anon_sym_NOT] = ACTIONS(5649),
    [anon_sym_Not] = ACTIONS(5649),
    [anon_sym_POUNDelse] = ACTIONS(5651),
    [anon_sym_POUNDELSE] = ACTIONS(5651),
    [anon_sym_POUNDElse] = ACTIONS(5651),
    [anon_sym_POUNDelse2] = ACTIONS(5651),
    [anon_sym_POUNDELSE2] = ACTIONS(5651),
    [anon_sym_POUNDElse2] = ACTIONS(5651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5649),
    [anon_sym_PLUS] = ACTIONS(5651),
    [sym_datetime_literal] = ACTIONS(5651),
    [sym_date_literal] = ACTIONS(5649),
    [sym_time_literal] = ACTIONS(5649),
    [sym_biginteger_literal] = ACTIONS(5651),
    [anon_sym_if] = ACTIONS(5649),
    [anon_sym_IF] = ACTIONS(5649),
    [anon_sym_If] = ACTIONS(5649),
    [anon_sym_else] = ACTIONS(5649),
    [anon_sym_ELSE] = ACTIONS(5649),
    [anon_sym_Else] = ACTIONS(5649),
    [anon_sym_case] = ACTIONS(5649),
    [anon_sym_CASE] = ACTIONS(5649),
    [anon_sym_Case] = ACTIONS(5649),
    [anon_sym_for] = ACTIONS(5649),
    [anon_sym_FOR] = ACTIONS(5649),
    [anon_sym_For] = ACTIONS(5649),
    [anon_sym_foreach] = ACTIONS(5649),
    [anon_sym_FOREACH] = ACTIONS(5649),
    [anon_sym_Foreach] = ACTIONS(5649),
    [anon_sym_while] = ACTIONS(5649),
    [anon_sym_WHILE] = ACTIONS(5649),
    [anon_sym_While] = ACTIONS(5649),
    [anon_sym_repeat] = ACTIONS(5649),
    [anon_sym_REPEAT] = ACTIONS(5649),
    [anon_sym_Repeat] = ACTIONS(5649),
    [anon_sym_until] = ACTIONS(5649),
    [anon_sym_UNTIL] = ACTIONS(5649),
    [anon_sym_Until] = ACTIONS(5649),
    [anon_sym_exit] = ACTIONS(5649),
    [anon_sym_EXIT] = ACTIONS(5649),
    [anon_sym_Exit] = ACTIONS(5649),
    [anon_sym_continue] = ACTIONS(5649),
    [anon_sym_CONTINUE] = ACTIONS(5649),
    [anon_sym_Continue] = ACTIONS(5649),
    [anon_sym_break] = ACTIONS(5649),
    [anon_sym_BREAK] = ACTIONS(5649),
    [anon_sym_Break] = ACTIONS(5649),
    [anon_sym_with] = ACTIONS(5649),
    [anon_sym_WITH] = ACTIONS(5649),
    [anon_sym_With] = ACTIONS(5649),
    [sym_asserterror_keyword] = ACTIONS(5651),
    [sym_page_keyword] = ACTIONS(5649),
    [anon_sym_codeunit] = ACTIONS(5649),
    [anon_sym_CODEUNIT] = ACTIONS(5649),
    [anon_sym_Codeunit] = ACTIONS(5649),
    [anon_sym_CodeUnit] = ACTIONS(5649),
    [anon_sym_COdeunit] = ACTIONS(5649),
    [anon_sym_codeUnit] = ACTIONS(5649),
    [sym_report_keyword] = ACTIONS(5649),
    [sym_query_keyword] = ACTIONS(5649),
    [anon_sym_xmlport] = ACTIONS(5649),
    [anon_sym_XMLPORT] = ACTIONS(5649),
    [anon_sym_Xmlport] = ACTIONS(5649),
    [anon_sym_XMLport] = ACTIONS(5649),
    [anon_sym_XMLPort] = ACTIONS(5649),
    [anon_sym_XmlPort] = ACTIONS(5649),
    [anon_sym_enum] = ACTIONS(5649),
    [anon_sym_ENUM] = ACTIONS(5649),
    [anon_sym_Enum] = ACTIONS(5649),
    [anon_sym_eNUM] = ACTIONS(5649),
    [anon_sym_eNum] = ACTIONS(5649),
    [anon_sym_ENum] = ACTIONS(5649),
    [sym_quoted_identifier] = ACTIONS(5651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5651),
    [sym_verbatim_string] = ACTIONS(5651),
    [sym_integer] = ACTIONS(5649),
    [sym_continue_as_identifier] = ACTIONS(5651),
    [sym_preproc_open] = ACTIONS(5651),
  },
  [STATE(3000)] = {
    [sym_identifier] = ACTIONS(5653),
    [anon_sym_SEMI] = ACTIONS(5655),
    [anon_sym_DASH] = ACTIONS(5655),
    [aux_sym_boolean_token1] = ACTIONS(5653),
    [aux_sym_boolean_token2] = ACTIONS(5653),
    [sym_decimal] = ACTIONS(5653),
    [anon_sym_LPAREN] = ACTIONS(5655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5653),
    [anon_sym_LBRACK] = ACTIONS(5655),
    [aux_sym_record_type_token1] = ACTIONS(5653),
    [aux_sym_basic_type_token21] = ACTIONS(5653),
    [aux_sym_basic_type_token22] = ACTIONS(5653),
    [aux_sym_basic_type_token48] = ACTIONS(5653),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5653),
    [anon_sym_POUNDif] = ACTIONS(5655),
    [anon_sym_POUNDIF] = ACTIONS(5655),
    [anon_sym_POUNDIf] = ACTIONS(5655),
    [anon_sym_not] = ACTIONS(5653),
    [anon_sym_NOT] = ACTIONS(5653),
    [anon_sym_Not] = ACTIONS(5653),
    [anon_sym_POUNDelse] = ACTIONS(5655),
    [anon_sym_POUNDELSE] = ACTIONS(5655),
    [anon_sym_POUNDElse] = ACTIONS(5655),
    [anon_sym_POUNDelse2] = ACTIONS(5655),
    [anon_sym_POUNDELSE2] = ACTIONS(5655),
    [anon_sym_POUNDElse2] = ACTIONS(5655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5653),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5653),
    [anon_sym_PLUS] = ACTIONS(5655),
    [sym_datetime_literal] = ACTIONS(5655),
    [sym_date_literal] = ACTIONS(5653),
    [sym_time_literal] = ACTIONS(5653),
    [sym_biginteger_literal] = ACTIONS(5655),
    [anon_sym_if] = ACTIONS(5653),
    [anon_sym_IF] = ACTIONS(5653),
    [anon_sym_If] = ACTIONS(5653),
    [anon_sym_else] = ACTIONS(5653),
    [anon_sym_ELSE] = ACTIONS(5653),
    [anon_sym_Else] = ACTIONS(5653),
    [anon_sym_case] = ACTIONS(5653),
    [anon_sym_CASE] = ACTIONS(5653),
    [anon_sym_Case] = ACTIONS(5653),
    [anon_sym_for] = ACTIONS(5653),
    [anon_sym_FOR] = ACTIONS(5653),
    [anon_sym_For] = ACTIONS(5653),
    [anon_sym_foreach] = ACTIONS(5653),
    [anon_sym_FOREACH] = ACTIONS(5653),
    [anon_sym_Foreach] = ACTIONS(5653),
    [anon_sym_while] = ACTIONS(5653),
    [anon_sym_WHILE] = ACTIONS(5653),
    [anon_sym_While] = ACTIONS(5653),
    [anon_sym_repeat] = ACTIONS(5653),
    [anon_sym_REPEAT] = ACTIONS(5653),
    [anon_sym_Repeat] = ACTIONS(5653),
    [anon_sym_until] = ACTIONS(5653),
    [anon_sym_UNTIL] = ACTIONS(5653),
    [anon_sym_Until] = ACTIONS(5653),
    [anon_sym_exit] = ACTIONS(5653),
    [anon_sym_EXIT] = ACTIONS(5653),
    [anon_sym_Exit] = ACTIONS(5653),
    [anon_sym_continue] = ACTIONS(5653),
    [anon_sym_CONTINUE] = ACTIONS(5653),
    [anon_sym_Continue] = ACTIONS(5653),
    [anon_sym_break] = ACTIONS(5653),
    [anon_sym_BREAK] = ACTIONS(5653),
    [anon_sym_Break] = ACTIONS(5653),
    [anon_sym_with] = ACTIONS(5653),
    [anon_sym_WITH] = ACTIONS(5653),
    [anon_sym_With] = ACTIONS(5653),
    [sym_asserterror_keyword] = ACTIONS(5655),
    [sym_page_keyword] = ACTIONS(5653),
    [anon_sym_codeunit] = ACTIONS(5653),
    [anon_sym_CODEUNIT] = ACTIONS(5653),
    [anon_sym_Codeunit] = ACTIONS(5653),
    [anon_sym_CodeUnit] = ACTIONS(5653),
    [anon_sym_COdeunit] = ACTIONS(5653),
    [anon_sym_codeUnit] = ACTIONS(5653),
    [sym_report_keyword] = ACTIONS(5653),
    [sym_query_keyword] = ACTIONS(5653),
    [anon_sym_xmlport] = ACTIONS(5653),
    [anon_sym_XMLPORT] = ACTIONS(5653),
    [anon_sym_Xmlport] = ACTIONS(5653),
    [anon_sym_XMLport] = ACTIONS(5653),
    [anon_sym_XMLPort] = ACTIONS(5653),
    [anon_sym_XmlPort] = ACTIONS(5653),
    [anon_sym_enum] = ACTIONS(5653),
    [anon_sym_ENUM] = ACTIONS(5653),
    [anon_sym_Enum] = ACTIONS(5653),
    [anon_sym_eNUM] = ACTIONS(5653),
    [anon_sym_eNum] = ACTIONS(5653),
    [anon_sym_ENum] = ACTIONS(5653),
    [sym_quoted_identifier] = ACTIONS(5655),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5655),
    [sym_verbatim_string] = ACTIONS(5655),
    [sym_integer] = ACTIONS(5653),
    [sym_continue_as_identifier] = ACTIONS(5655),
    [sym_preproc_open] = ACTIONS(5655),
  },
  [STATE(3001)] = {
    [sym_identifier] = ACTIONS(5657),
    [anon_sym_SEMI] = ACTIONS(5659),
    [anon_sym_DASH] = ACTIONS(5659),
    [aux_sym_boolean_token1] = ACTIONS(5657),
    [aux_sym_boolean_token2] = ACTIONS(5657),
    [sym_decimal] = ACTIONS(5657),
    [anon_sym_LPAREN] = ACTIONS(5659),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5657),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [aux_sym_record_type_token1] = ACTIONS(5657),
    [aux_sym_basic_type_token21] = ACTIONS(5657),
    [aux_sym_basic_type_token22] = ACTIONS(5657),
    [aux_sym_basic_type_token48] = ACTIONS(5657),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5657),
    [anon_sym_POUNDif] = ACTIONS(5659),
    [anon_sym_POUNDIF] = ACTIONS(5659),
    [anon_sym_POUNDIf] = ACTIONS(5659),
    [anon_sym_not] = ACTIONS(5657),
    [anon_sym_NOT] = ACTIONS(5657),
    [anon_sym_Not] = ACTIONS(5657),
    [anon_sym_POUNDelse] = ACTIONS(5659),
    [anon_sym_POUNDELSE] = ACTIONS(5659),
    [anon_sym_POUNDElse] = ACTIONS(5659),
    [anon_sym_POUNDelse2] = ACTIONS(5659),
    [anon_sym_POUNDELSE2] = ACTIONS(5659),
    [anon_sym_POUNDElse2] = ACTIONS(5659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5657),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5657),
    [anon_sym_PLUS] = ACTIONS(5659),
    [sym_datetime_literal] = ACTIONS(5659),
    [sym_date_literal] = ACTIONS(5657),
    [sym_time_literal] = ACTIONS(5657),
    [sym_biginteger_literal] = ACTIONS(5659),
    [anon_sym_if] = ACTIONS(5657),
    [anon_sym_IF] = ACTIONS(5657),
    [anon_sym_If] = ACTIONS(5657),
    [anon_sym_else] = ACTIONS(5657),
    [anon_sym_ELSE] = ACTIONS(5657),
    [anon_sym_Else] = ACTIONS(5657),
    [anon_sym_case] = ACTIONS(5657),
    [anon_sym_CASE] = ACTIONS(5657),
    [anon_sym_Case] = ACTIONS(5657),
    [anon_sym_for] = ACTIONS(5657),
    [anon_sym_FOR] = ACTIONS(5657),
    [anon_sym_For] = ACTIONS(5657),
    [anon_sym_foreach] = ACTIONS(5657),
    [anon_sym_FOREACH] = ACTIONS(5657),
    [anon_sym_Foreach] = ACTIONS(5657),
    [anon_sym_while] = ACTIONS(5657),
    [anon_sym_WHILE] = ACTIONS(5657),
    [anon_sym_While] = ACTIONS(5657),
    [anon_sym_repeat] = ACTIONS(5657),
    [anon_sym_REPEAT] = ACTIONS(5657),
    [anon_sym_Repeat] = ACTIONS(5657),
    [anon_sym_until] = ACTIONS(5657),
    [anon_sym_UNTIL] = ACTIONS(5657),
    [anon_sym_Until] = ACTIONS(5657),
    [anon_sym_exit] = ACTIONS(5657),
    [anon_sym_EXIT] = ACTIONS(5657),
    [anon_sym_Exit] = ACTIONS(5657),
    [anon_sym_continue] = ACTIONS(5657),
    [anon_sym_CONTINUE] = ACTIONS(5657),
    [anon_sym_Continue] = ACTIONS(5657),
    [anon_sym_break] = ACTIONS(5657),
    [anon_sym_BREAK] = ACTIONS(5657),
    [anon_sym_Break] = ACTIONS(5657),
    [anon_sym_with] = ACTIONS(5657),
    [anon_sym_WITH] = ACTIONS(5657),
    [anon_sym_With] = ACTIONS(5657),
    [sym_asserterror_keyword] = ACTIONS(5659),
    [sym_page_keyword] = ACTIONS(5657),
    [anon_sym_codeunit] = ACTIONS(5657),
    [anon_sym_CODEUNIT] = ACTIONS(5657),
    [anon_sym_Codeunit] = ACTIONS(5657),
    [anon_sym_CodeUnit] = ACTIONS(5657),
    [anon_sym_COdeunit] = ACTIONS(5657),
    [anon_sym_codeUnit] = ACTIONS(5657),
    [sym_report_keyword] = ACTIONS(5657),
    [sym_query_keyword] = ACTIONS(5657),
    [anon_sym_xmlport] = ACTIONS(5657),
    [anon_sym_XMLPORT] = ACTIONS(5657),
    [anon_sym_Xmlport] = ACTIONS(5657),
    [anon_sym_XMLport] = ACTIONS(5657),
    [anon_sym_XMLPort] = ACTIONS(5657),
    [anon_sym_XmlPort] = ACTIONS(5657),
    [anon_sym_enum] = ACTIONS(5657),
    [anon_sym_ENUM] = ACTIONS(5657),
    [anon_sym_Enum] = ACTIONS(5657),
    [anon_sym_eNUM] = ACTIONS(5657),
    [anon_sym_eNum] = ACTIONS(5657),
    [anon_sym_ENum] = ACTIONS(5657),
    [sym_quoted_identifier] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5659),
    [sym_verbatim_string] = ACTIONS(5659),
    [sym_integer] = ACTIONS(5657),
    [sym_continue_as_identifier] = ACTIONS(5659),
    [sym_preproc_open] = ACTIONS(5659),
  },
  [STATE(3002)] = {
    [sym_identifier] = ACTIONS(5661),
    [anon_sym_SEMI] = ACTIONS(5663),
    [anon_sym_DASH] = ACTIONS(5663),
    [aux_sym_boolean_token1] = ACTIONS(5661),
    [aux_sym_boolean_token2] = ACTIONS(5661),
    [sym_decimal] = ACTIONS(5661),
    [anon_sym_LPAREN] = ACTIONS(5663),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5663),
    [aux_sym_record_type_token1] = ACTIONS(5661),
    [aux_sym_basic_type_token21] = ACTIONS(5661),
    [aux_sym_basic_type_token22] = ACTIONS(5661),
    [aux_sym_basic_type_token48] = ACTIONS(5661),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5661),
    [anon_sym_POUNDif] = ACTIONS(5663),
    [anon_sym_POUNDIF] = ACTIONS(5663),
    [anon_sym_POUNDIf] = ACTIONS(5663),
    [anon_sym_not] = ACTIONS(5661),
    [anon_sym_NOT] = ACTIONS(5661),
    [anon_sym_Not] = ACTIONS(5661),
    [anon_sym_POUNDelse] = ACTIONS(5663),
    [anon_sym_POUNDELSE] = ACTIONS(5663),
    [anon_sym_POUNDElse] = ACTIONS(5663),
    [anon_sym_POUNDelse2] = ACTIONS(5663),
    [anon_sym_POUNDELSE2] = ACTIONS(5663),
    [anon_sym_POUNDElse2] = ACTIONS(5663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5661),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5661),
    [anon_sym_PLUS] = ACTIONS(5663),
    [sym_datetime_literal] = ACTIONS(5663),
    [sym_date_literal] = ACTIONS(5661),
    [sym_time_literal] = ACTIONS(5661),
    [sym_biginteger_literal] = ACTIONS(5663),
    [anon_sym_if] = ACTIONS(5661),
    [anon_sym_IF] = ACTIONS(5661),
    [anon_sym_If] = ACTIONS(5661),
    [anon_sym_else] = ACTIONS(5661),
    [anon_sym_ELSE] = ACTIONS(5661),
    [anon_sym_Else] = ACTIONS(5661),
    [anon_sym_case] = ACTIONS(5661),
    [anon_sym_CASE] = ACTIONS(5661),
    [anon_sym_Case] = ACTIONS(5661),
    [anon_sym_for] = ACTIONS(5661),
    [anon_sym_FOR] = ACTIONS(5661),
    [anon_sym_For] = ACTIONS(5661),
    [anon_sym_foreach] = ACTIONS(5661),
    [anon_sym_FOREACH] = ACTIONS(5661),
    [anon_sym_Foreach] = ACTIONS(5661),
    [anon_sym_while] = ACTIONS(5661),
    [anon_sym_WHILE] = ACTIONS(5661),
    [anon_sym_While] = ACTIONS(5661),
    [anon_sym_repeat] = ACTIONS(5661),
    [anon_sym_REPEAT] = ACTIONS(5661),
    [anon_sym_Repeat] = ACTIONS(5661),
    [anon_sym_until] = ACTIONS(5661),
    [anon_sym_UNTIL] = ACTIONS(5661),
    [anon_sym_Until] = ACTIONS(5661),
    [anon_sym_exit] = ACTIONS(5661),
    [anon_sym_EXIT] = ACTIONS(5661),
    [anon_sym_Exit] = ACTIONS(5661),
    [anon_sym_continue] = ACTIONS(5661),
    [anon_sym_CONTINUE] = ACTIONS(5661),
    [anon_sym_Continue] = ACTIONS(5661),
    [anon_sym_break] = ACTIONS(5661),
    [anon_sym_BREAK] = ACTIONS(5661),
    [anon_sym_Break] = ACTIONS(5661),
    [anon_sym_with] = ACTIONS(5661),
    [anon_sym_WITH] = ACTIONS(5661),
    [anon_sym_With] = ACTIONS(5661),
    [sym_asserterror_keyword] = ACTIONS(5663),
    [sym_page_keyword] = ACTIONS(5661),
    [anon_sym_codeunit] = ACTIONS(5661),
    [anon_sym_CODEUNIT] = ACTIONS(5661),
    [anon_sym_Codeunit] = ACTIONS(5661),
    [anon_sym_CodeUnit] = ACTIONS(5661),
    [anon_sym_COdeunit] = ACTIONS(5661),
    [anon_sym_codeUnit] = ACTIONS(5661),
    [sym_report_keyword] = ACTIONS(5661),
    [sym_query_keyword] = ACTIONS(5661),
    [anon_sym_xmlport] = ACTIONS(5661),
    [anon_sym_XMLPORT] = ACTIONS(5661),
    [anon_sym_Xmlport] = ACTIONS(5661),
    [anon_sym_XMLport] = ACTIONS(5661),
    [anon_sym_XMLPort] = ACTIONS(5661),
    [anon_sym_XmlPort] = ACTIONS(5661),
    [anon_sym_enum] = ACTIONS(5661),
    [anon_sym_ENUM] = ACTIONS(5661),
    [anon_sym_Enum] = ACTIONS(5661),
    [anon_sym_eNUM] = ACTIONS(5661),
    [anon_sym_eNum] = ACTIONS(5661),
    [anon_sym_ENum] = ACTIONS(5661),
    [sym_quoted_identifier] = ACTIONS(5663),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5663),
    [sym_verbatim_string] = ACTIONS(5663),
    [sym_integer] = ACTIONS(5661),
    [sym_continue_as_identifier] = ACTIONS(5663),
    [sym_preproc_open] = ACTIONS(5663),
  },
  [STATE(3003)] = {
    [sym_identifier] = ACTIONS(5665),
    [anon_sym_SEMI] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5667),
    [aux_sym_boolean_token1] = ACTIONS(5665),
    [aux_sym_boolean_token2] = ACTIONS(5665),
    [sym_decimal] = ACTIONS(5665),
    [anon_sym_LPAREN] = ACTIONS(5667),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5665),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [aux_sym_record_type_token1] = ACTIONS(5665),
    [aux_sym_basic_type_token21] = ACTIONS(5665),
    [aux_sym_basic_type_token22] = ACTIONS(5665),
    [aux_sym_basic_type_token48] = ACTIONS(5665),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5665),
    [anon_sym_POUNDif] = ACTIONS(5667),
    [anon_sym_POUNDIF] = ACTIONS(5667),
    [anon_sym_POUNDIf] = ACTIONS(5667),
    [anon_sym_not] = ACTIONS(5665),
    [anon_sym_NOT] = ACTIONS(5665),
    [anon_sym_Not] = ACTIONS(5665),
    [anon_sym_POUNDelse] = ACTIONS(5667),
    [anon_sym_POUNDELSE] = ACTIONS(5667),
    [anon_sym_POUNDElse] = ACTIONS(5667),
    [anon_sym_POUNDelse2] = ACTIONS(5667),
    [anon_sym_POUNDELSE2] = ACTIONS(5667),
    [anon_sym_POUNDElse2] = ACTIONS(5667),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5665),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5665),
    [anon_sym_PLUS] = ACTIONS(5667),
    [sym_datetime_literal] = ACTIONS(5667),
    [sym_date_literal] = ACTIONS(5665),
    [sym_time_literal] = ACTIONS(5665),
    [sym_biginteger_literal] = ACTIONS(5667),
    [anon_sym_if] = ACTIONS(5665),
    [anon_sym_IF] = ACTIONS(5665),
    [anon_sym_If] = ACTIONS(5665),
    [anon_sym_else] = ACTIONS(5665),
    [anon_sym_ELSE] = ACTIONS(5665),
    [anon_sym_Else] = ACTIONS(5665),
    [anon_sym_case] = ACTIONS(5665),
    [anon_sym_CASE] = ACTIONS(5665),
    [anon_sym_Case] = ACTIONS(5665),
    [anon_sym_for] = ACTIONS(5665),
    [anon_sym_FOR] = ACTIONS(5665),
    [anon_sym_For] = ACTIONS(5665),
    [anon_sym_foreach] = ACTIONS(5665),
    [anon_sym_FOREACH] = ACTIONS(5665),
    [anon_sym_Foreach] = ACTIONS(5665),
    [anon_sym_while] = ACTIONS(5665),
    [anon_sym_WHILE] = ACTIONS(5665),
    [anon_sym_While] = ACTIONS(5665),
    [anon_sym_repeat] = ACTIONS(5665),
    [anon_sym_REPEAT] = ACTIONS(5665),
    [anon_sym_Repeat] = ACTIONS(5665),
    [anon_sym_until] = ACTIONS(5665),
    [anon_sym_UNTIL] = ACTIONS(5665),
    [anon_sym_Until] = ACTIONS(5665),
    [anon_sym_exit] = ACTIONS(5665),
    [anon_sym_EXIT] = ACTIONS(5665),
    [anon_sym_Exit] = ACTIONS(5665),
    [anon_sym_continue] = ACTIONS(5665),
    [anon_sym_CONTINUE] = ACTIONS(5665),
    [anon_sym_Continue] = ACTIONS(5665),
    [anon_sym_break] = ACTIONS(5665),
    [anon_sym_BREAK] = ACTIONS(5665),
    [anon_sym_Break] = ACTIONS(5665),
    [anon_sym_with] = ACTIONS(5665),
    [anon_sym_WITH] = ACTIONS(5665),
    [anon_sym_With] = ACTIONS(5665),
    [sym_asserterror_keyword] = ACTIONS(5667),
    [sym_page_keyword] = ACTIONS(5665),
    [anon_sym_codeunit] = ACTIONS(5665),
    [anon_sym_CODEUNIT] = ACTIONS(5665),
    [anon_sym_Codeunit] = ACTIONS(5665),
    [anon_sym_CodeUnit] = ACTIONS(5665),
    [anon_sym_COdeunit] = ACTIONS(5665),
    [anon_sym_codeUnit] = ACTIONS(5665),
    [sym_report_keyword] = ACTIONS(5665),
    [sym_query_keyword] = ACTIONS(5665),
    [anon_sym_xmlport] = ACTIONS(5665),
    [anon_sym_XMLPORT] = ACTIONS(5665),
    [anon_sym_Xmlport] = ACTIONS(5665),
    [anon_sym_XMLport] = ACTIONS(5665),
    [anon_sym_XMLPort] = ACTIONS(5665),
    [anon_sym_XmlPort] = ACTIONS(5665),
    [anon_sym_enum] = ACTIONS(5665),
    [anon_sym_ENUM] = ACTIONS(5665),
    [anon_sym_Enum] = ACTIONS(5665),
    [anon_sym_eNUM] = ACTIONS(5665),
    [anon_sym_eNum] = ACTIONS(5665),
    [anon_sym_ENum] = ACTIONS(5665),
    [sym_quoted_identifier] = ACTIONS(5667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5667),
    [sym_verbatim_string] = ACTIONS(5667),
    [sym_integer] = ACTIONS(5665),
    [sym_continue_as_identifier] = ACTIONS(5667),
    [sym_preproc_open] = ACTIONS(5667),
  },
  [STATE(3004)] = {
    [sym_identifier] = ACTIONS(5669),
    [anon_sym_SEMI] = ACTIONS(5671),
    [anon_sym_DASH] = ACTIONS(5671),
    [aux_sym_boolean_token1] = ACTIONS(5669),
    [aux_sym_boolean_token2] = ACTIONS(5669),
    [sym_decimal] = ACTIONS(5669),
    [anon_sym_LPAREN] = ACTIONS(5671),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5669),
    [anon_sym_LBRACK] = ACTIONS(5671),
    [aux_sym_record_type_token1] = ACTIONS(5669),
    [aux_sym_basic_type_token21] = ACTIONS(5669),
    [aux_sym_basic_type_token22] = ACTIONS(5669),
    [aux_sym_basic_type_token48] = ACTIONS(5669),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5669),
    [anon_sym_POUNDif] = ACTIONS(5671),
    [anon_sym_POUNDIF] = ACTIONS(5671),
    [anon_sym_POUNDIf] = ACTIONS(5671),
    [anon_sym_not] = ACTIONS(5669),
    [anon_sym_NOT] = ACTIONS(5669),
    [anon_sym_Not] = ACTIONS(5669),
    [anon_sym_POUNDelse] = ACTIONS(5671),
    [anon_sym_POUNDELSE] = ACTIONS(5671),
    [anon_sym_POUNDElse] = ACTIONS(5671),
    [anon_sym_POUNDelse2] = ACTIONS(5671),
    [anon_sym_POUNDELSE2] = ACTIONS(5671),
    [anon_sym_POUNDElse2] = ACTIONS(5671),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5669),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5669),
    [anon_sym_PLUS] = ACTIONS(5671),
    [sym_datetime_literal] = ACTIONS(5671),
    [sym_date_literal] = ACTIONS(5669),
    [sym_time_literal] = ACTIONS(5669),
    [sym_biginteger_literal] = ACTIONS(5671),
    [anon_sym_if] = ACTIONS(5669),
    [anon_sym_IF] = ACTIONS(5669),
    [anon_sym_If] = ACTIONS(5669),
    [anon_sym_else] = ACTIONS(5669),
    [anon_sym_ELSE] = ACTIONS(5669),
    [anon_sym_Else] = ACTIONS(5669),
    [anon_sym_case] = ACTIONS(5669),
    [anon_sym_CASE] = ACTIONS(5669),
    [anon_sym_Case] = ACTIONS(5669),
    [anon_sym_for] = ACTIONS(5669),
    [anon_sym_FOR] = ACTIONS(5669),
    [anon_sym_For] = ACTIONS(5669),
    [anon_sym_foreach] = ACTIONS(5669),
    [anon_sym_FOREACH] = ACTIONS(5669),
    [anon_sym_Foreach] = ACTIONS(5669),
    [anon_sym_while] = ACTIONS(5669),
    [anon_sym_WHILE] = ACTIONS(5669),
    [anon_sym_While] = ACTIONS(5669),
    [anon_sym_repeat] = ACTIONS(5669),
    [anon_sym_REPEAT] = ACTIONS(5669),
    [anon_sym_Repeat] = ACTIONS(5669),
    [anon_sym_until] = ACTIONS(5669),
    [anon_sym_UNTIL] = ACTIONS(5669),
    [anon_sym_Until] = ACTIONS(5669),
    [anon_sym_exit] = ACTIONS(5669),
    [anon_sym_EXIT] = ACTIONS(5669),
    [anon_sym_Exit] = ACTIONS(5669),
    [anon_sym_continue] = ACTIONS(5669),
    [anon_sym_CONTINUE] = ACTIONS(5669),
    [anon_sym_Continue] = ACTIONS(5669),
    [anon_sym_break] = ACTIONS(5669),
    [anon_sym_BREAK] = ACTIONS(5669),
    [anon_sym_Break] = ACTIONS(5669),
    [anon_sym_with] = ACTIONS(5669),
    [anon_sym_WITH] = ACTIONS(5669),
    [anon_sym_With] = ACTIONS(5669),
    [sym_asserterror_keyword] = ACTIONS(5671),
    [sym_page_keyword] = ACTIONS(5669),
    [anon_sym_codeunit] = ACTIONS(5669),
    [anon_sym_CODEUNIT] = ACTIONS(5669),
    [anon_sym_Codeunit] = ACTIONS(5669),
    [anon_sym_CodeUnit] = ACTIONS(5669),
    [anon_sym_COdeunit] = ACTIONS(5669),
    [anon_sym_codeUnit] = ACTIONS(5669),
    [sym_report_keyword] = ACTIONS(5669),
    [sym_query_keyword] = ACTIONS(5669),
    [anon_sym_xmlport] = ACTIONS(5669),
    [anon_sym_XMLPORT] = ACTIONS(5669),
    [anon_sym_Xmlport] = ACTIONS(5669),
    [anon_sym_XMLport] = ACTIONS(5669),
    [anon_sym_XMLPort] = ACTIONS(5669),
    [anon_sym_XmlPort] = ACTIONS(5669),
    [anon_sym_enum] = ACTIONS(5669),
    [anon_sym_ENUM] = ACTIONS(5669),
    [anon_sym_Enum] = ACTIONS(5669),
    [anon_sym_eNUM] = ACTIONS(5669),
    [anon_sym_eNum] = ACTIONS(5669),
    [anon_sym_ENum] = ACTIONS(5669),
    [sym_quoted_identifier] = ACTIONS(5671),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5671),
    [sym_verbatim_string] = ACTIONS(5671),
    [sym_integer] = ACTIONS(5669),
    [sym_continue_as_identifier] = ACTIONS(5671),
    [sym_preproc_open] = ACTIONS(5671),
  },
  [STATE(3005)] = {
    [sym_identifier] = ACTIONS(5673),
    [anon_sym_SEMI] = ACTIONS(5675),
    [anon_sym_DASH] = ACTIONS(5675),
    [aux_sym_boolean_token1] = ACTIONS(5673),
    [aux_sym_boolean_token2] = ACTIONS(5673),
    [sym_decimal] = ACTIONS(5673),
    [anon_sym_LPAREN] = ACTIONS(5675),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5673),
    [anon_sym_LBRACK] = ACTIONS(5675),
    [aux_sym_record_type_token1] = ACTIONS(5673),
    [aux_sym_basic_type_token21] = ACTIONS(5673),
    [aux_sym_basic_type_token22] = ACTIONS(5673),
    [aux_sym_basic_type_token48] = ACTIONS(5673),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5673),
    [anon_sym_POUNDif] = ACTIONS(5675),
    [anon_sym_POUNDIF] = ACTIONS(5675),
    [anon_sym_POUNDIf] = ACTIONS(5675),
    [anon_sym_not] = ACTIONS(5673),
    [anon_sym_NOT] = ACTIONS(5673),
    [anon_sym_Not] = ACTIONS(5673),
    [anon_sym_POUNDelse] = ACTIONS(5675),
    [anon_sym_POUNDELSE] = ACTIONS(5675),
    [anon_sym_POUNDElse] = ACTIONS(5675),
    [anon_sym_POUNDelse2] = ACTIONS(5675),
    [anon_sym_POUNDELSE2] = ACTIONS(5675),
    [anon_sym_POUNDElse2] = ACTIONS(5675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5673),
    [anon_sym_PLUS] = ACTIONS(5675),
    [sym_datetime_literal] = ACTIONS(5675),
    [sym_date_literal] = ACTIONS(5673),
    [sym_time_literal] = ACTIONS(5673),
    [sym_biginteger_literal] = ACTIONS(5675),
    [anon_sym_if] = ACTIONS(5673),
    [anon_sym_IF] = ACTIONS(5673),
    [anon_sym_If] = ACTIONS(5673),
    [anon_sym_else] = ACTIONS(5673),
    [anon_sym_ELSE] = ACTIONS(5673),
    [anon_sym_Else] = ACTIONS(5673),
    [anon_sym_case] = ACTIONS(5673),
    [anon_sym_CASE] = ACTIONS(5673),
    [anon_sym_Case] = ACTIONS(5673),
    [anon_sym_for] = ACTIONS(5673),
    [anon_sym_FOR] = ACTIONS(5673),
    [anon_sym_For] = ACTIONS(5673),
    [anon_sym_foreach] = ACTIONS(5673),
    [anon_sym_FOREACH] = ACTIONS(5673),
    [anon_sym_Foreach] = ACTIONS(5673),
    [anon_sym_while] = ACTIONS(5673),
    [anon_sym_WHILE] = ACTIONS(5673),
    [anon_sym_While] = ACTIONS(5673),
    [anon_sym_repeat] = ACTIONS(5673),
    [anon_sym_REPEAT] = ACTIONS(5673),
    [anon_sym_Repeat] = ACTIONS(5673),
    [anon_sym_until] = ACTIONS(5673),
    [anon_sym_UNTIL] = ACTIONS(5673),
    [anon_sym_Until] = ACTIONS(5673),
    [anon_sym_exit] = ACTIONS(5673),
    [anon_sym_EXIT] = ACTIONS(5673),
    [anon_sym_Exit] = ACTIONS(5673),
    [anon_sym_continue] = ACTIONS(5673),
    [anon_sym_CONTINUE] = ACTIONS(5673),
    [anon_sym_Continue] = ACTIONS(5673),
    [anon_sym_break] = ACTIONS(5673),
    [anon_sym_BREAK] = ACTIONS(5673),
    [anon_sym_Break] = ACTIONS(5673),
    [anon_sym_with] = ACTIONS(5673),
    [anon_sym_WITH] = ACTIONS(5673),
    [anon_sym_With] = ACTIONS(5673),
    [sym_asserterror_keyword] = ACTIONS(5675),
    [sym_page_keyword] = ACTIONS(5673),
    [anon_sym_codeunit] = ACTIONS(5673),
    [anon_sym_CODEUNIT] = ACTIONS(5673),
    [anon_sym_Codeunit] = ACTIONS(5673),
    [anon_sym_CodeUnit] = ACTIONS(5673),
    [anon_sym_COdeunit] = ACTIONS(5673),
    [anon_sym_codeUnit] = ACTIONS(5673),
    [sym_report_keyword] = ACTIONS(5673),
    [sym_query_keyword] = ACTIONS(5673),
    [anon_sym_xmlport] = ACTIONS(5673),
    [anon_sym_XMLPORT] = ACTIONS(5673),
    [anon_sym_Xmlport] = ACTIONS(5673),
    [anon_sym_XMLport] = ACTIONS(5673),
    [anon_sym_XMLPort] = ACTIONS(5673),
    [anon_sym_XmlPort] = ACTIONS(5673),
    [anon_sym_enum] = ACTIONS(5673),
    [anon_sym_ENUM] = ACTIONS(5673),
    [anon_sym_Enum] = ACTIONS(5673),
    [anon_sym_eNUM] = ACTIONS(5673),
    [anon_sym_eNum] = ACTIONS(5673),
    [anon_sym_ENum] = ACTIONS(5673),
    [sym_quoted_identifier] = ACTIONS(5675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5675),
    [sym_verbatim_string] = ACTIONS(5675),
    [sym_integer] = ACTIONS(5673),
    [sym_continue_as_identifier] = ACTIONS(5675),
    [sym_preproc_open] = ACTIONS(5675),
  },
  [STATE(3006)] = {
    [sym_identifier] = ACTIONS(5677),
    [anon_sym_SEMI] = ACTIONS(5679),
    [anon_sym_DASH] = ACTIONS(5679),
    [aux_sym_boolean_token1] = ACTIONS(5677),
    [aux_sym_boolean_token2] = ACTIONS(5677),
    [sym_decimal] = ACTIONS(5677),
    [anon_sym_LPAREN] = ACTIONS(5679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5677),
    [anon_sym_LBRACK] = ACTIONS(5679),
    [aux_sym_record_type_token1] = ACTIONS(5677),
    [aux_sym_basic_type_token21] = ACTIONS(5677),
    [aux_sym_basic_type_token22] = ACTIONS(5677),
    [aux_sym_basic_type_token48] = ACTIONS(5677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5677),
    [anon_sym_POUNDif] = ACTIONS(5679),
    [anon_sym_POUNDIF] = ACTIONS(5679),
    [anon_sym_POUNDIf] = ACTIONS(5679),
    [anon_sym_not] = ACTIONS(5677),
    [anon_sym_NOT] = ACTIONS(5677),
    [anon_sym_Not] = ACTIONS(5677),
    [anon_sym_POUNDelse] = ACTIONS(5679),
    [anon_sym_POUNDELSE] = ACTIONS(5679),
    [anon_sym_POUNDElse] = ACTIONS(5679),
    [anon_sym_POUNDelse2] = ACTIONS(5679),
    [anon_sym_POUNDELSE2] = ACTIONS(5679),
    [anon_sym_POUNDElse2] = ACTIONS(5679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5677),
    [anon_sym_PLUS] = ACTIONS(5679),
    [sym_datetime_literal] = ACTIONS(5679),
    [sym_date_literal] = ACTIONS(5677),
    [sym_time_literal] = ACTIONS(5677),
    [sym_biginteger_literal] = ACTIONS(5679),
    [anon_sym_if] = ACTIONS(5677),
    [anon_sym_IF] = ACTIONS(5677),
    [anon_sym_If] = ACTIONS(5677),
    [anon_sym_else] = ACTIONS(5677),
    [anon_sym_ELSE] = ACTIONS(5677),
    [anon_sym_Else] = ACTIONS(5677),
    [anon_sym_case] = ACTIONS(5677),
    [anon_sym_CASE] = ACTIONS(5677),
    [anon_sym_Case] = ACTIONS(5677),
    [anon_sym_for] = ACTIONS(5677),
    [anon_sym_FOR] = ACTIONS(5677),
    [anon_sym_For] = ACTIONS(5677),
    [anon_sym_foreach] = ACTIONS(5677),
    [anon_sym_FOREACH] = ACTIONS(5677),
    [anon_sym_Foreach] = ACTIONS(5677),
    [anon_sym_while] = ACTIONS(5677),
    [anon_sym_WHILE] = ACTIONS(5677),
    [anon_sym_While] = ACTIONS(5677),
    [anon_sym_repeat] = ACTIONS(5677),
    [anon_sym_REPEAT] = ACTIONS(5677),
    [anon_sym_Repeat] = ACTIONS(5677),
    [anon_sym_until] = ACTIONS(5677),
    [anon_sym_UNTIL] = ACTIONS(5677),
    [anon_sym_Until] = ACTIONS(5677),
    [anon_sym_exit] = ACTIONS(5677),
    [anon_sym_EXIT] = ACTIONS(5677),
    [anon_sym_Exit] = ACTIONS(5677),
    [anon_sym_continue] = ACTIONS(5677),
    [anon_sym_CONTINUE] = ACTIONS(5677),
    [anon_sym_Continue] = ACTIONS(5677),
    [anon_sym_break] = ACTIONS(5677),
    [anon_sym_BREAK] = ACTIONS(5677),
    [anon_sym_Break] = ACTIONS(5677),
    [anon_sym_with] = ACTIONS(5677),
    [anon_sym_WITH] = ACTIONS(5677),
    [anon_sym_With] = ACTIONS(5677),
    [sym_asserterror_keyword] = ACTIONS(5679),
    [sym_page_keyword] = ACTIONS(5677),
    [anon_sym_codeunit] = ACTIONS(5677),
    [anon_sym_CODEUNIT] = ACTIONS(5677),
    [anon_sym_Codeunit] = ACTIONS(5677),
    [anon_sym_CodeUnit] = ACTIONS(5677),
    [anon_sym_COdeunit] = ACTIONS(5677),
    [anon_sym_codeUnit] = ACTIONS(5677),
    [sym_report_keyword] = ACTIONS(5677),
    [sym_query_keyword] = ACTIONS(5677),
    [anon_sym_xmlport] = ACTIONS(5677),
    [anon_sym_XMLPORT] = ACTIONS(5677),
    [anon_sym_Xmlport] = ACTIONS(5677),
    [anon_sym_XMLport] = ACTIONS(5677),
    [anon_sym_XMLPort] = ACTIONS(5677),
    [anon_sym_XmlPort] = ACTIONS(5677),
    [anon_sym_enum] = ACTIONS(5677),
    [anon_sym_ENUM] = ACTIONS(5677),
    [anon_sym_Enum] = ACTIONS(5677),
    [anon_sym_eNUM] = ACTIONS(5677),
    [anon_sym_eNum] = ACTIONS(5677),
    [anon_sym_ENum] = ACTIONS(5677),
    [sym_quoted_identifier] = ACTIONS(5679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5679),
    [sym_verbatim_string] = ACTIONS(5679),
    [sym_integer] = ACTIONS(5677),
    [sym_continue_as_identifier] = ACTIONS(5679),
    [sym_preproc_open] = ACTIONS(5679),
  },
  [STATE(3007)] = {
    [sym_identifier] = ACTIONS(5681),
    [anon_sym_SEMI] = ACTIONS(5683),
    [anon_sym_DASH] = ACTIONS(5683),
    [aux_sym_boolean_token1] = ACTIONS(5681),
    [aux_sym_boolean_token2] = ACTIONS(5681),
    [sym_decimal] = ACTIONS(5681),
    [anon_sym_LPAREN] = ACTIONS(5683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5681),
    [anon_sym_LBRACK] = ACTIONS(5683),
    [aux_sym_record_type_token1] = ACTIONS(5681),
    [aux_sym_basic_type_token21] = ACTIONS(5681),
    [aux_sym_basic_type_token22] = ACTIONS(5681),
    [aux_sym_basic_type_token48] = ACTIONS(5681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5681),
    [anon_sym_POUNDif] = ACTIONS(5683),
    [anon_sym_POUNDIF] = ACTIONS(5683),
    [anon_sym_POUNDIf] = ACTIONS(5683),
    [anon_sym_not] = ACTIONS(5681),
    [anon_sym_NOT] = ACTIONS(5681),
    [anon_sym_Not] = ACTIONS(5681),
    [anon_sym_POUNDelse] = ACTIONS(5683),
    [anon_sym_POUNDELSE] = ACTIONS(5683),
    [anon_sym_POUNDElse] = ACTIONS(5683),
    [anon_sym_POUNDelse2] = ACTIONS(5683),
    [anon_sym_POUNDELSE2] = ACTIONS(5683),
    [anon_sym_POUNDElse2] = ACTIONS(5683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5681),
    [anon_sym_PLUS] = ACTIONS(5683),
    [sym_datetime_literal] = ACTIONS(5683),
    [sym_date_literal] = ACTIONS(5681),
    [sym_time_literal] = ACTIONS(5681),
    [sym_biginteger_literal] = ACTIONS(5683),
    [anon_sym_if] = ACTIONS(5681),
    [anon_sym_IF] = ACTIONS(5681),
    [anon_sym_If] = ACTIONS(5681),
    [anon_sym_else] = ACTIONS(5681),
    [anon_sym_ELSE] = ACTIONS(5681),
    [anon_sym_Else] = ACTIONS(5681),
    [anon_sym_case] = ACTIONS(5681),
    [anon_sym_CASE] = ACTIONS(5681),
    [anon_sym_Case] = ACTIONS(5681),
    [anon_sym_for] = ACTIONS(5681),
    [anon_sym_FOR] = ACTIONS(5681),
    [anon_sym_For] = ACTIONS(5681),
    [anon_sym_foreach] = ACTIONS(5681),
    [anon_sym_FOREACH] = ACTIONS(5681),
    [anon_sym_Foreach] = ACTIONS(5681),
    [anon_sym_while] = ACTIONS(5681),
    [anon_sym_WHILE] = ACTIONS(5681),
    [anon_sym_While] = ACTIONS(5681),
    [anon_sym_repeat] = ACTIONS(5681),
    [anon_sym_REPEAT] = ACTIONS(5681),
    [anon_sym_Repeat] = ACTIONS(5681),
    [anon_sym_until] = ACTIONS(5681),
    [anon_sym_UNTIL] = ACTIONS(5681),
    [anon_sym_Until] = ACTIONS(5681),
    [anon_sym_exit] = ACTIONS(5681),
    [anon_sym_EXIT] = ACTIONS(5681),
    [anon_sym_Exit] = ACTIONS(5681),
    [anon_sym_continue] = ACTIONS(5681),
    [anon_sym_CONTINUE] = ACTIONS(5681),
    [anon_sym_Continue] = ACTIONS(5681),
    [anon_sym_break] = ACTIONS(5681),
    [anon_sym_BREAK] = ACTIONS(5681),
    [anon_sym_Break] = ACTIONS(5681),
    [anon_sym_with] = ACTIONS(5681),
    [anon_sym_WITH] = ACTIONS(5681),
    [anon_sym_With] = ACTIONS(5681),
    [sym_asserterror_keyword] = ACTIONS(5683),
    [sym_page_keyword] = ACTIONS(5681),
    [anon_sym_codeunit] = ACTIONS(5681),
    [anon_sym_CODEUNIT] = ACTIONS(5681),
    [anon_sym_Codeunit] = ACTIONS(5681),
    [anon_sym_CodeUnit] = ACTIONS(5681),
    [anon_sym_COdeunit] = ACTIONS(5681),
    [anon_sym_codeUnit] = ACTIONS(5681),
    [sym_report_keyword] = ACTIONS(5681),
    [sym_query_keyword] = ACTIONS(5681),
    [anon_sym_xmlport] = ACTIONS(5681),
    [anon_sym_XMLPORT] = ACTIONS(5681),
    [anon_sym_Xmlport] = ACTIONS(5681),
    [anon_sym_XMLport] = ACTIONS(5681),
    [anon_sym_XMLPort] = ACTIONS(5681),
    [anon_sym_XmlPort] = ACTIONS(5681),
    [anon_sym_enum] = ACTIONS(5681),
    [anon_sym_ENUM] = ACTIONS(5681),
    [anon_sym_Enum] = ACTIONS(5681),
    [anon_sym_eNUM] = ACTIONS(5681),
    [anon_sym_eNum] = ACTIONS(5681),
    [anon_sym_ENum] = ACTIONS(5681),
    [sym_quoted_identifier] = ACTIONS(5683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5683),
    [sym_verbatim_string] = ACTIONS(5683),
    [sym_integer] = ACTIONS(5681),
    [sym_continue_as_identifier] = ACTIONS(5683),
    [sym_preproc_open] = ACTIONS(5683),
  },
  [STATE(3008)] = {
    [sym_identifier] = ACTIONS(5685),
    [anon_sym_SEMI] = ACTIONS(5687),
    [anon_sym_DASH] = ACTIONS(5687),
    [aux_sym_boolean_token1] = ACTIONS(5685),
    [aux_sym_boolean_token2] = ACTIONS(5685),
    [sym_decimal] = ACTIONS(5685),
    [anon_sym_LPAREN] = ACTIONS(5687),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5685),
    [anon_sym_LBRACK] = ACTIONS(5687),
    [aux_sym_record_type_token1] = ACTIONS(5685),
    [aux_sym_basic_type_token21] = ACTIONS(5685),
    [aux_sym_basic_type_token22] = ACTIONS(5685),
    [aux_sym_basic_type_token48] = ACTIONS(5685),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5685),
    [anon_sym_POUNDif] = ACTIONS(5687),
    [anon_sym_POUNDIF] = ACTIONS(5687),
    [anon_sym_POUNDIf] = ACTIONS(5687),
    [anon_sym_not] = ACTIONS(5685),
    [anon_sym_NOT] = ACTIONS(5685),
    [anon_sym_Not] = ACTIONS(5685),
    [anon_sym_POUNDelse] = ACTIONS(5687),
    [anon_sym_POUNDELSE] = ACTIONS(5687),
    [anon_sym_POUNDElse] = ACTIONS(5687),
    [anon_sym_POUNDelse2] = ACTIONS(5687),
    [anon_sym_POUNDELSE2] = ACTIONS(5687),
    [anon_sym_POUNDElse2] = ACTIONS(5687),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5685),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5685),
    [anon_sym_PLUS] = ACTIONS(5687),
    [sym_datetime_literal] = ACTIONS(5687),
    [sym_date_literal] = ACTIONS(5685),
    [sym_time_literal] = ACTIONS(5685),
    [sym_biginteger_literal] = ACTIONS(5687),
    [anon_sym_if] = ACTIONS(5685),
    [anon_sym_IF] = ACTIONS(5685),
    [anon_sym_If] = ACTIONS(5685),
    [anon_sym_else] = ACTIONS(5685),
    [anon_sym_ELSE] = ACTIONS(5685),
    [anon_sym_Else] = ACTIONS(5685),
    [anon_sym_case] = ACTIONS(5685),
    [anon_sym_CASE] = ACTIONS(5685),
    [anon_sym_Case] = ACTIONS(5685),
    [anon_sym_for] = ACTIONS(5685),
    [anon_sym_FOR] = ACTIONS(5685),
    [anon_sym_For] = ACTIONS(5685),
    [anon_sym_foreach] = ACTIONS(5685),
    [anon_sym_FOREACH] = ACTIONS(5685),
    [anon_sym_Foreach] = ACTIONS(5685),
    [anon_sym_while] = ACTIONS(5685),
    [anon_sym_WHILE] = ACTIONS(5685),
    [anon_sym_While] = ACTIONS(5685),
    [anon_sym_repeat] = ACTIONS(5685),
    [anon_sym_REPEAT] = ACTIONS(5685),
    [anon_sym_Repeat] = ACTIONS(5685),
    [anon_sym_until] = ACTIONS(5685),
    [anon_sym_UNTIL] = ACTIONS(5685),
    [anon_sym_Until] = ACTIONS(5685),
    [anon_sym_exit] = ACTIONS(5685),
    [anon_sym_EXIT] = ACTIONS(5685),
    [anon_sym_Exit] = ACTIONS(5685),
    [anon_sym_continue] = ACTIONS(5685),
    [anon_sym_CONTINUE] = ACTIONS(5685),
    [anon_sym_Continue] = ACTIONS(5685),
    [anon_sym_break] = ACTIONS(5685),
    [anon_sym_BREAK] = ACTIONS(5685),
    [anon_sym_Break] = ACTIONS(5685),
    [anon_sym_with] = ACTIONS(5685),
    [anon_sym_WITH] = ACTIONS(5685),
    [anon_sym_With] = ACTIONS(5685),
    [sym_asserterror_keyword] = ACTIONS(5687),
    [sym_page_keyword] = ACTIONS(5685),
    [anon_sym_codeunit] = ACTIONS(5685),
    [anon_sym_CODEUNIT] = ACTIONS(5685),
    [anon_sym_Codeunit] = ACTIONS(5685),
    [anon_sym_CodeUnit] = ACTIONS(5685),
    [anon_sym_COdeunit] = ACTIONS(5685),
    [anon_sym_codeUnit] = ACTIONS(5685),
    [sym_report_keyword] = ACTIONS(5685),
    [sym_query_keyword] = ACTIONS(5685),
    [anon_sym_xmlport] = ACTIONS(5685),
    [anon_sym_XMLPORT] = ACTIONS(5685),
    [anon_sym_Xmlport] = ACTIONS(5685),
    [anon_sym_XMLport] = ACTIONS(5685),
    [anon_sym_XMLPort] = ACTIONS(5685),
    [anon_sym_XmlPort] = ACTIONS(5685),
    [anon_sym_enum] = ACTIONS(5685),
    [anon_sym_ENUM] = ACTIONS(5685),
    [anon_sym_Enum] = ACTIONS(5685),
    [anon_sym_eNUM] = ACTIONS(5685),
    [anon_sym_eNum] = ACTIONS(5685),
    [anon_sym_ENum] = ACTIONS(5685),
    [sym_quoted_identifier] = ACTIONS(5687),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5687),
    [sym_verbatim_string] = ACTIONS(5687),
    [sym_integer] = ACTIONS(5685),
    [sym_continue_as_identifier] = ACTIONS(5687),
    [sym_preproc_open] = ACTIONS(5687),
  },
  [STATE(3009)] = {
    [sym_identifier] = ACTIONS(5689),
    [anon_sym_SEMI] = ACTIONS(5691),
    [anon_sym_DASH] = ACTIONS(5691),
    [aux_sym_boolean_token1] = ACTIONS(5689),
    [aux_sym_boolean_token2] = ACTIONS(5689),
    [sym_decimal] = ACTIONS(5689),
    [anon_sym_LPAREN] = ACTIONS(5691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5689),
    [anon_sym_LBRACK] = ACTIONS(5691),
    [aux_sym_record_type_token1] = ACTIONS(5689),
    [aux_sym_basic_type_token21] = ACTIONS(5689),
    [aux_sym_basic_type_token22] = ACTIONS(5689),
    [aux_sym_basic_type_token48] = ACTIONS(5689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5689),
    [anon_sym_POUNDif] = ACTIONS(5691),
    [anon_sym_POUNDIF] = ACTIONS(5691),
    [anon_sym_POUNDIf] = ACTIONS(5691),
    [anon_sym_not] = ACTIONS(5689),
    [anon_sym_NOT] = ACTIONS(5689),
    [anon_sym_Not] = ACTIONS(5689),
    [anon_sym_POUNDelse] = ACTIONS(5691),
    [anon_sym_POUNDELSE] = ACTIONS(5691),
    [anon_sym_POUNDElse] = ACTIONS(5691),
    [anon_sym_POUNDelse2] = ACTIONS(5691),
    [anon_sym_POUNDELSE2] = ACTIONS(5691),
    [anon_sym_POUNDElse2] = ACTIONS(5691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5689),
    [anon_sym_PLUS] = ACTIONS(5691),
    [sym_datetime_literal] = ACTIONS(5691),
    [sym_date_literal] = ACTIONS(5689),
    [sym_time_literal] = ACTIONS(5689),
    [sym_biginteger_literal] = ACTIONS(5691),
    [anon_sym_if] = ACTIONS(5689),
    [anon_sym_IF] = ACTIONS(5689),
    [anon_sym_If] = ACTIONS(5689),
    [anon_sym_else] = ACTIONS(5689),
    [anon_sym_ELSE] = ACTIONS(5689),
    [anon_sym_Else] = ACTIONS(5689),
    [anon_sym_case] = ACTIONS(5689),
    [anon_sym_CASE] = ACTIONS(5689),
    [anon_sym_Case] = ACTIONS(5689),
    [anon_sym_for] = ACTIONS(5689),
    [anon_sym_FOR] = ACTIONS(5689),
    [anon_sym_For] = ACTIONS(5689),
    [anon_sym_foreach] = ACTIONS(5689),
    [anon_sym_FOREACH] = ACTIONS(5689),
    [anon_sym_Foreach] = ACTIONS(5689),
    [anon_sym_while] = ACTIONS(5689),
    [anon_sym_WHILE] = ACTIONS(5689),
    [anon_sym_While] = ACTIONS(5689),
    [anon_sym_repeat] = ACTIONS(5689),
    [anon_sym_REPEAT] = ACTIONS(5689),
    [anon_sym_Repeat] = ACTIONS(5689),
    [anon_sym_until] = ACTIONS(5689),
    [anon_sym_UNTIL] = ACTIONS(5689),
    [anon_sym_Until] = ACTIONS(5689),
    [anon_sym_exit] = ACTIONS(5689),
    [anon_sym_EXIT] = ACTIONS(5689),
    [anon_sym_Exit] = ACTIONS(5689),
    [anon_sym_continue] = ACTIONS(5689),
    [anon_sym_CONTINUE] = ACTIONS(5689),
    [anon_sym_Continue] = ACTIONS(5689),
    [anon_sym_break] = ACTIONS(5689),
    [anon_sym_BREAK] = ACTIONS(5689),
    [anon_sym_Break] = ACTIONS(5689),
    [anon_sym_with] = ACTIONS(5689),
    [anon_sym_WITH] = ACTIONS(5689),
    [anon_sym_With] = ACTIONS(5689),
    [sym_asserterror_keyword] = ACTIONS(5691),
    [sym_page_keyword] = ACTIONS(5689),
    [anon_sym_codeunit] = ACTIONS(5689),
    [anon_sym_CODEUNIT] = ACTIONS(5689),
    [anon_sym_Codeunit] = ACTIONS(5689),
    [anon_sym_CodeUnit] = ACTIONS(5689),
    [anon_sym_COdeunit] = ACTIONS(5689),
    [anon_sym_codeUnit] = ACTIONS(5689),
    [sym_report_keyword] = ACTIONS(5689),
    [sym_query_keyword] = ACTIONS(5689),
    [anon_sym_xmlport] = ACTIONS(5689),
    [anon_sym_XMLPORT] = ACTIONS(5689),
    [anon_sym_Xmlport] = ACTIONS(5689),
    [anon_sym_XMLport] = ACTIONS(5689),
    [anon_sym_XMLPort] = ACTIONS(5689),
    [anon_sym_XmlPort] = ACTIONS(5689),
    [anon_sym_enum] = ACTIONS(5689),
    [anon_sym_ENUM] = ACTIONS(5689),
    [anon_sym_Enum] = ACTIONS(5689),
    [anon_sym_eNUM] = ACTIONS(5689),
    [anon_sym_eNum] = ACTIONS(5689),
    [anon_sym_ENum] = ACTIONS(5689),
    [sym_quoted_identifier] = ACTIONS(5691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5691),
    [sym_verbatim_string] = ACTIONS(5691),
    [sym_integer] = ACTIONS(5689),
    [sym_continue_as_identifier] = ACTIONS(5691),
    [sym_preproc_open] = ACTIONS(5691),
  },
  [STATE(3010)] = {
    [sym_identifier] = ACTIONS(5697),
    [anon_sym_SEMI] = ACTIONS(5699),
    [anon_sym_DASH] = ACTIONS(5699),
    [aux_sym_boolean_token1] = ACTIONS(5697),
    [aux_sym_boolean_token2] = ACTIONS(5697),
    [sym_decimal] = ACTIONS(5697),
    [anon_sym_LPAREN] = ACTIONS(5699),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5697),
    [anon_sym_LBRACK] = ACTIONS(5699),
    [aux_sym_record_type_token1] = ACTIONS(5697),
    [aux_sym_basic_type_token21] = ACTIONS(5697),
    [aux_sym_basic_type_token22] = ACTIONS(5697),
    [aux_sym_basic_type_token48] = ACTIONS(5697),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5697),
    [anon_sym_POUNDif] = ACTIONS(5699),
    [anon_sym_POUNDIF] = ACTIONS(5699),
    [anon_sym_POUNDIf] = ACTIONS(5699),
    [anon_sym_not] = ACTIONS(5697),
    [anon_sym_NOT] = ACTIONS(5697),
    [anon_sym_Not] = ACTIONS(5697),
    [anon_sym_POUNDelse] = ACTIONS(5699),
    [anon_sym_POUNDELSE] = ACTIONS(5699),
    [anon_sym_POUNDElse] = ACTIONS(5699),
    [anon_sym_POUNDelse2] = ACTIONS(5699),
    [anon_sym_POUNDELSE2] = ACTIONS(5699),
    [anon_sym_POUNDElse2] = ACTIONS(5699),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5697),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5697),
    [anon_sym_PLUS] = ACTIONS(5699),
    [sym_datetime_literal] = ACTIONS(5699),
    [sym_date_literal] = ACTIONS(5697),
    [sym_time_literal] = ACTIONS(5697),
    [sym_biginteger_literal] = ACTIONS(5699),
    [anon_sym_if] = ACTIONS(5697),
    [anon_sym_IF] = ACTIONS(5697),
    [anon_sym_If] = ACTIONS(5697),
    [anon_sym_else] = ACTIONS(5697),
    [anon_sym_ELSE] = ACTIONS(5697),
    [anon_sym_Else] = ACTIONS(5697),
    [anon_sym_case] = ACTIONS(5697),
    [anon_sym_CASE] = ACTIONS(5697),
    [anon_sym_Case] = ACTIONS(5697),
    [anon_sym_for] = ACTIONS(5697),
    [anon_sym_FOR] = ACTIONS(5697),
    [anon_sym_For] = ACTIONS(5697),
    [anon_sym_foreach] = ACTIONS(5697),
    [anon_sym_FOREACH] = ACTIONS(5697),
    [anon_sym_Foreach] = ACTIONS(5697),
    [anon_sym_while] = ACTIONS(5697),
    [anon_sym_WHILE] = ACTIONS(5697),
    [anon_sym_While] = ACTIONS(5697),
    [anon_sym_repeat] = ACTIONS(5697),
    [anon_sym_REPEAT] = ACTIONS(5697),
    [anon_sym_Repeat] = ACTIONS(5697),
    [anon_sym_until] = ACTIONS(5697),
    [anon_sym_UNTIL] = ACTIONS(5697),
    [anon_sym_Until] = ACTIONS(5697),
    [anon_sym_exit] = ACTIONS(5697),
    [anon_sym_EXIT] = ACTIONS(5697),
    [anon_sym_Exit] = ACTIONS(5697),
    [anon_sym_continue] = ACTIONS(5697),
    [anon_sym_CONTINUE] = ACTIONS(5697),
    [anon_sym_Continue] = ACTIONS(5697),
    [anon_sym_break] = ACTIONS(5697),
    [anon_sym_BREAK] = ACTIONS(5697),
    [anon_sym_Break] = ACTIONS(5697),
    [anon_sym_with] = ACTIONS(5697),
    [anon_sym_WITH] = ACTIONS(5697),
    [anon_sym_With] = ACTIONS(5697),
    [sym_asserterror_keyword] = ACTIONS(5699),
    [sym_page_keyword] = ACTIONS(5697),
    [anon_sym_codeunit] = ACTIONS(5697),
    [anon_sym_CODEUNIT] = ACTIONS(5697),
    [anon_sym_Codeunit] = ACTIONS(5697),
    [anon_sym_CodeUnit] = ACTIONS(5697),
    [anon_sym_COdeunit] = ACTIONS(5697),
    [anon_sym_codeUnit] = ACTIONS(5697),
    [sym_report_keyword] = ACTIONS(5697),
    [sym_query_keyword] = ACTIONS(5697),
    [anon_sym_xmlport] = ACTIONS(5697),
    [anon_sym_XMLPORT] = ACTIONS(5697),
    [anon_sym_Xmlport] = ACTIONS(5697),
    [anon_sym_XMLport] = ACTIONS(5697),
    [anon_sym_XMLPort] = ACTIONS(5697),
    [anon_sym_XmlPort] = ACTIONS(5697),
    [anon_sym_enum] = ACTIONS(5697),
    [anon_sym_ENUM] = ACTIONS(5697),
    [anon_sym_Enum] = ACTIONS(5697),
    [anon_sym_eNUM] = ACTIONS(5697),
    [anon_sym_eNum] = ACTIONS(5697),
    [anon_sym_ENum] = ACTIONS(5697),
    [sym_quoted_identifier] = ACTIONS(5699),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5699),
    [sym_verbatim_string] = ACTIONS(5699),
    [sym_integer] = ACTIONS(5697),
    [sym_continue_as_identifier] = ACTIONS(5699),
    [sym_preproc_open] = ACTIONS(5699),
  },
  [STATE(3011)] = {
    [sym_identifier] = ACTIONS(5701),
    [anon_sym_SEMI] = ACTIONS(5703),
    [anon_sym_DASH] = ACTIONS(5703),
    [aux_sym_boolean_token1] = ACTIONS(5701),
    [aux_sym_boolean_token2] = ACTIONS(5701),
    [sym_decimal] = ACTIONS(5701),
    [anon_sym_LPAREN] = ACTIONS(5703),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5701),
    [anon_sym_LBRACK] = ACTIONS(5703),
    [aux_sym_record_type_token1] = ACTIONS(5701),
    [aux_sym_basic_type_token21] = ACTIONS(5701),
    [aux_sym_basic_type_token22] = ACTIONS(5701),
    [aux_sym_basic_type_token48] = ACTIONS(5701),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5701),
    [anon_sym_POUNDif] = ACTIONS(5703),
    [anon_sym_POUNDIF] = ACTIONS(5703),
    [anon_sym_POUNDIf] = ACTIONS(5703),
    [anon_sym_not] = ACTIONS(5701),
    [anon_sym_NOT] = ACTIONS(5701),
    [anon_sym_Not] = ACTIONS(5701),
    [anon_sym_POUNDelse] = ACTIONS(5703),
    [anon_sym_POUNDELSE] = ACTIONS(5703),
    [anon_sym_POUNDElse] = ACTIONS(5703),
    [anon_sym_POUNDelse2] = ACTIONS(5703),
    [anon_sym_POUNDELSE2] = ACTIONS(5703),
    [anon_sym_POUNDElse2] = ACTIONS(5703),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5701),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5701),
    [anon_sym_PLUS] = ACTIONS(5703),
    [sym_datetime_literal] = ACTIONS(5703),
    [sym_date_literal] = ACTIONS(5701),
    [sym_time_literal] = ACTIONS(5701),
    [sym_biginteger_literal] = ACTIONS(5703),
    [anon_sym_if] = ACTIONS(5701),
    [anon_sym_IF] = ACTIONS(5701),
    [anon_sym_If] = ACTIONS(5701),
    [anon_sym_else] = ACTIONS(5701),
    [anon_sym_ELSE] = ACTIONS(5701),
    [anon_sym_Else] = ACTIONS(5701),
    [anon_sym_case] = ACTIONS(5701),
    [anon_sym_CASE] = ACTIONS(5701),
    [anon_sym_Case] = ACTIONS(5701),
    [anon_sym_for] = ACTIONS(5701),
    [anon_sym_FOR] = ACTIONS(5701),
    [anon_sym_For] = ACTIONS(5701),
    [anon_sym_foreach] = ACTIONS(5701),
    [anon_sym_FOREACH] = ACTIONS(5701),
    [anon_sym_Foreach] = ACTIONS(5701),
    [anon_sym_while] = ACTIONS(5701),
    [anon_sym_WHILE] = ACTIONS(5701),
    [anon_sym_While] = ACTIONS(5701),
    [anon_sym_repeat] = ACTIONS(5701),
    [anon_sym_REPEAT] = ACTIONS(5701),
    [anon_sym_Repeat] = ACTIONS(5701),
    [anon_sym_until] = ACTIONS(5701),
    [anon_sym_UNTIL] = ACTIONS(5701),
    [anon_sym_Until] = ACTIONS(5701),
    [anon_sym_exit] = ACTIONS(5701),
    [anon_sym_EXIT] = ACTIONS(5701),
    [anon_sym_Exit] = ACTIONS(5701),
    [anon_sym_continue] = ACTIONS(5701),
    [anon_sym_CONTINUE] = ACTIONS(5701),
    [anon_sym_Continue] = ACTIONS(5701),
    [anon_sym_break] = ACTIONS(5701),
    [anon_sym_BREAK] = ACTIONS(5701),
    [anon_sym_Break] = ACTIONS(5701),
    [anon_sym_with] = ACTIONS(5701),
    [anon_sym_WITH] = ACTIONS(5701),
    [anon_sym_With] = ACTIONS(5701),
    [sym_asserterror_keyword] = ACTIONS(5703),
    [sym_page_keyword] = ACTIONS(5701),
    [anon_sym_codeunit] = ACTIONS(5701),
    [anon_sym_CODEUNIT] = ACTIONS(5701),
    [anon_sym_Codeunit] = ACTIONS(5701),
    [anon_sym_CodeUnit] = ACTIONS(5701),
    [anon_sym_COdeunit] = ACTIONS(5701),
    [anon_sym_codeUnit] = ACTIONS(5701),
    [sym_report_keyword] = ACTIONS(5701),
    [sym_query_keyword] = ACTIONS(5701),
    [anon_sym_xmlport] = ACTIONS(5701),
    [anon_sym_XMLPORT] = ACTIONS(5701),
    [anon_sym_Xmlport] = ACTIONS(5701),
    [anon_sym_XMLport] = ACTIONS(5701),
    [anon_sym_XMLPort] = ACTIONS(5701),
    [anon_sym_XmlPort] = ACTIONS(5701),
    [anon_sym_enum] = ACTIONS(5701),
    [anon_sym_ENUM] = ACTIONS(5701),
    [anon_sym_Enum] = ACTIONS(5701),
    [anon_sym_eNUM] = ACTIONS(5701),
    [anon_sym_eNum] = ACTIONS(5701),
    [anon_sym_ENum] = ACTIONS(5701),
    [sym_quoted_identifier] = ACTIONS(5703),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5703),
    [sym_verbatim_string] = ACTIONS(5703),
    [sym_integer] = ACTIONS(5701),
    [sym_continue_as_identifier] = ACTIONS(5703),
    [sym_preproc_open] = ACTIONS(5703),
  },
  [STATE(3012)] = {
    [sym_identifier] = ACTIONS(5705),
    [anon_sym_SEMI] = ACTIONS(5707),
    [anon_sym_DASH] = ACTIONS(5707),
    [aux_sym_boolean_token1] = ACTIONS(5705),
    [aux_sym_boolean_token2] = ACTIONS(5705),
    [sym_decimal] = ACTIONS(5705),
    [anon_sym_LPAREN] = ACTIONS(5707),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5705),
    [anon_sym_LBRACK] = ACTIONS(5707),
    [aux_sym_record_type_token1] = ACTIONS(5705),
    [aux_sym_basic_type_token21] = ACTIONS(5705),
    [aux_sym_basic_type_token22] = ACTIONS(5705),
    [aux_sym_basic_type_token48] = ACTIONS(5705),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5705),
    [anon_sym_POUNDif] = ACTIONS(5707),
    [anon_sym_POUNDIF] = ACTIONS(5707),
    [anon_sym_POUNDIf] = ACTIONS(5707),
    [anon_sym_not] = ACTIONS(5705),
    [anon_sym_NOT] = ACTIONS(5705),
    [anon_sym_Not] = ACTIONS(5705),
    [anon_sym_POUNDelse] = ACTIONS(5707),
    [anon_sym_POUNDELSE] = ACTIONS(5707),
    [anon_sym_POUNDElse] = ACTIONS(5707),
    [anon_sym_POUNDelse2] = ACTIONS(5707),
    [anon_sym_POUNDELSE2] = ACTIONS(5707),
    [anon_sym_POUNDElse2] = ACTIONS(5707),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5705),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5705),
    [anon_sym_PLUS] = ACTIONS(5707),
    [sym_datetime_literal] = ACTIONS(5707),
    [sym_date_literal] = ACTIONS(5705),
    [sym_time_literal] = ACTIONS(5705),
    [sym_biginteger_literal] = ACTIONS(5707),
    [anon_sym_if] = ACTIONS(5705),
    [anon_sym_IF] = ACTIONS(5705),
    [anon_sym_If] = ACTIONS(5705),
    [anon_sym_else] = ACTIONS(5705),
    [anon_sym_ELSE] = ACTIONS(5705),
    [anon_sym_Else] = ACTIONS(5705),
    [anon_sym_case] = ACTIONS(5705),
    [anon_sym_CASE] = ACTIONS(5705),
    [anon_sym_Case] = ACTIONS(5705),
    [anon_sym_for] = ACTIONS(5705),
    [anon_sym_FOR] = ACTIONS(5705),
    [anon_sym_For] = ACTIONS(5705),
    [anon_sym_foreach] = ACTIONS(5705),
    [anon_sym_FOREACH] = ACTIONS(5705),
    [anon_sym_Foreach] = ACTIONS(5705),
    [anon_sym_while] = ACTIONS(5705),
    [anon_sym_WHILE] = ACTIONS(5705),
    [anon_sym_While] = ACTIONS(5705),
    [anon_sym_repeat] = ACTIONS(5705),
    [anon_sym_REPEAT] = ACTIONS(5705),
    [anon_sym_Repeat] = ACTIONS(5705),
    [anon_sym_until] = ACTIONS(5705),
    [anon_sym_UNTIL] = ACTIONS(5705),
    [anon_sym_Until] = ACTIONS(5705),
    [anon_sym_exit] = ACTIONS(5705),
    [anon_sym_EXIT] = ACTIONS(5705),
    [anon_sym_Exit] = ACTIONS(5705),
    [anon_sym_continue] = ACTIONS(5705),
    [anon_sym_CONTINUE] = ACTIONS(5705),
    [anon_sym_Continue] = ACTIONS(5705),
    [anon_sym_break] = ACTIONS(5705),
    [anon_sym_BREAK] = ACTIONS(5705),
    [anon_sym_Break] = ACTIONS(5705),
    [anon_sym_with] = ACTIONS(5705),
    [anon_sym_WITH] = ACTIONS(5705),
    [anon_sym_With] = ACTIONS(5705),
    [sym_asserterror_keyword] = ACTIONS(5707),
    [sym_page_keyword] = ACTIONS(5705),
    [anon_sym_codeunit] = ACTIONS(5705),
    [anon_sym_CODEUNIT] = ACTIONS(5705),
    [anon_sym_Codeunit] = ACTIONS(5705),
    [anon_sym_CodeUnit] = ACTIONS(5705),
    [anon_sym_COdeunit] = ACTIONS(5705),
    [anon_sym_codeUnit] = ACTIONS(5705),
    [sym_report_keyword] = ACTIONS(5705),
    [sym_query_keyword] = ACTIONS(5705),
    [anon_sym_xmlport] = ACTIONS(5705),
    [anon_sym_XMLPORT] = ACTIONS(5705),
    [anon_sym_Xmlport] = ACTIONS(5705),
    [anon_sym_XMLport] = ACTIONS(5705),
    [anon_sym_XMLPort] = ACTIONS(5705),
    [anon_sym_XmlPort] = ACTIONS(5705),
    [anon_sym_enum] = ACTIONS(5705),
    [anon_sym_ENUM] = ACTIONS(5705),
    [anon_sym_Enum] = ACTIONS(5705),
    [anon_sym_eNUM] = ACTIONS(5705),
    [anon_sym_eNum] = ACTIONS(5705),
    [anon_sym_ENum] = ACTIONS(5705),
    [sym_quoted_identifier] = ACTIONS(5707),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5707),
    [sym_verbatim_string] = ACTIONS(5707),
    [sym_integer] = ACTIONS(5705),
    [sym_continue_as_identifier] = ACTIONS(5707),
    [sym_preproc_open] = ACTIONS(5707),
  },
  [STATE(3013)] = {
    [sym_identifier] = ACTIONS(5709),
    [anon_sym_SEMI] = ACTIONS(5711),
    [anon_sym_DASH] = ACTIONS(5711),
    [aux_sym_boolean_token1] = ACTIONS(5709),
    [aux_sym_boolean_token2] = ACTIONS(5709),
    [sym_decimal] = ACTIONS(5709),
    [anon_sym_LPAREN] = ACTIONS(5711),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5709),
    [anon_sym_LBRACK] = ACTIONS(5711),
    [aux_sym_record_type_token1] = ACTIONS(5709),
    [aux_sym_basic_type_token21] = ACTIONS(5709),
    [aux_sym_basic_type_token22] = ACTIONS(5709),
    [aux_sym_basic_type_token48] = ACTIONS(5709),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5709),
    [anon_sym_POUNDif] = ACTIONS(5711),
    [anon_sym_POUNDIF] = ACTIONS(5711),
    [anon_sym_POUNDIf] = ACTIONS(5711),
    [anon_sym_not] = ACTIONS(5709),
    [anon_sym_NOT] = ACTIONS(5709),
    [anon_sym_Not] = ACTIONS(5709),
    [anon_sym_POUNDelse] = ACTIONS(5711),
    [anon_sym_POUNDELSE] = ACTIONS(5711),
    [anon_sym_POUNDElse] = ACTIONS(5711),
    [anon_sym_POUNDelse2] = ACTIONS(5711),
    [anon_sym_POUNDELSE2] = ACTIONS(5711),
    [anon_sym_POUNDElse2] = ACTIONS(5711),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5709),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5709),
    [anon_sym_PLUS] = ACTIONS(5711),
    [sym_datetime_literal] = ACTIONS(5711),
    [sym_date_literal] = ACTIONS(5709),
    [sym_time_literal] = ACTIONS(5709),
    [sym_biginteger_literal] = ACTIONS(5711),
    [anon_sym_if] = ACTIONS(5709),
    [anon_sym_IF] = ACTIONS(5709),
    [anon_sym_If] = ACTIONS(5709),
    [anon_sym_else] = ACTIONS(5709),
    [anon_sym_ELSE] = ACTIONS(5709),
    [anon_sym_Else] = ACTIONS(5709),
    [anon_sym_case] = ACTIONS(5709),
    [anon_sym_CASE] = ACTIONS(5709),
    [anon_sym_Case] = ACTIONS(5709),
    [anon_sym_for] = ACTIONS(5709),
    [anon_sym_FOR] = ACTIONS(5709),
    [anon_sym_For] = ACTIONS(5709),
    [anon_sym_foreach] = ACTIONS(5709),
    [anon_sym_FOREACH] = ACTIONS(5709),
    [anon_sym_Foreach] = ACTIONS(5709),
    [anon_sym_while] = ACTIONS(5709),
    [anon_sym_WHILE] = ACTIONS(5709),
    [anon_sym_While] = ACTIONS(5709),
    [anon_sym_repeat] = ACTIONS(5709),
    [anon_sym_REPEAT] = ACTIONS(5709),
    [anon_sym_Repeat] = ACTIONS(5709),
    [anon_sym_until] = ACTIONS(5709),
    [anon_sym_UNTIL] = ACTIONS(5709),
    [anon_sym_Until] = ACTIONS(5709),
    [anon_sym_exit] = ACTIONS(5709),
    [anon_sym_EXIT] = ACTIONS(5709),
    [anon_sym_Exit] = ACTIONS(5709),
    [anon_sym_continue] = ACTIONS(5709),
    [anon_sym_CONTINUE] = ACTIONS(5709),
    [anon_sym_Continue] = ACTIONS(5709),
    [anon_sym_break] = ACTIONS(5709),
    [anon_sym_BREAK] = ACTIONS(5709),
    [anon_sym_Break] = ACTIONS(5709),
    [anon_sym_with] = ACTIONS(5709),
    [anon_sym_WITH] = ACTIONS(5709),
    [anon_sym_With] = ACTIONS(5709),
    [sym_asserterror_keyword] = ACTIONS(5711),
    [sym_page_keyword] = ACTIONS(5709),
    [anon_sym_codeunit] = ACTIONS(5709),
    [anon_sym_CODEUNIT] = ACTIONS(5709),
    [anon_sym_Codeunit] = ACTIONS(5709),
    [anon_sym_CodeUnit] = ACTIONS(5709),
    [anon_sym_COdeunit] = ACTIONS(5709),
    [anon_sym_codeUnit] = ACTIONS(5709),
    [sym_report_keyword] = ACTIONS(5709),
    [sym_query_keyword] = ACTIONS(5709),
    [anon_sym_xmlport] = ACTIONS(5709),
    [anon_sym_XMLPORT] = ACTIONS(5709),
    [anon_sym_Xmlport] = ACTIONS(5709),
    [anon_sym_XMLport] = ACTIONS(5709),
    [anon_sym_XMLPort] = ACTIONS(5709),
    [anon_sym_XmlPort] = ACTIONS(5709),
    [anon_sym_enum] = ACTIONS(5709),
    [anon_sym_ENUM] = ACTIONS(5709),
    [anon_sym_Enum] = ACTIONS(5709),
    [anon_sym_eNUM] = ACTIONS(5709),
    [anon_sym_eNum] = ACTIONS(5709),
    [anon_sym_ENum] = ACTIONS(5709),
    [sym_quoted_identifier] = ACTIONS(5711),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5711),
    [sym_verbatim_string] = ACTIONS(5711),
    [sym_integer] = ACTIONS(5709),
    [sym_continue_as_identifier] = ACTIONS(5711),
    [sym_preproc_open] = ACTIONS(5711),
  },
  [STATE(3014)] = {
    [sym_identifier] = ACTIONS(5713),
    [anon_sym_SEMI] = ACTIONS(5715),
    [anon_sym_DASH] = ACTIONS(5715),
    [aux_sym_boolean_token1] = ACTIONS(5713),
    [aux_sym_boolean_token2] = ACTIONS(5713),
    [sym_decimal] = ACTIONS(5713),
    [anon_sym_LPAREN] = ACTIONS(5715),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5713),
    [anon_sym_LBRACK] = ACTIONS(5715),
    [aux_sym_record_type_token1] = ACTIONS(5713),
    [aux_sym_basic_type_token21] = ACTIONS(5713),
    [aux_sym_basic_type_token22] = ACTIONS(5713),
    [aux_sym_basic_type_token48] = ACTIONS(5713),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5713),
    [anon_sym_POUNDif] = ACTIONS(5715),
    [anon_sym_POUNDIF] = ACTIONS(5715),
    [anon_sym_POUNDIf] = ACTIONS(5715),
    [anon_sym_not] = ACTIONS(5713),
    [anon_sym_NOT] = ACTIONS(5713),
    [anon_sym_Not] = ACTIONS(5713),
    [anon_sym_POUNDelse] = ACTIONS(5715),
    [anon_sym_POUNDELSE] = ACTIONS(5715),
    [anon_sym_POUNDElse] = ACTIONS(5715),
    [anon_sym_POUNDelse2] = ACTIONS(5715),
    [anon_sym_POUNDELSE2] = ACTIONS(5715),
    [anon_sym_POUNDElse2] = ACTIONS(5715),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5713),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5713),
    [anon_sym_PLUS] = ACTIONS(5715),
    [sym_datetime_literal] = ACTIONS(5715),
    [sym_date_literal] = ACTIONS(5713),
    [sym_time_literal] = ACTIONS(5713),
    [sym_biginteger_literal] = ACTIONS(5715),
    [anon_sym_if] = ACTIONS(5713),
    [anon_sym_IF] = ACTIONS(5713),
    [anon_sym_If] = ACTIONS(5713),
    [anon_sym_else] = ACTIONS(5713),
    [anon_sym_ELSE] = ACTIONS(5713),
    [anon_sym_Else] = ACTIONS(5713),
    [anon_sym_case] = ACTIONS(5713),
    [anon_sym_CASE] = ACTIONS(5713),
    [anon_sym_Case] = ACTIONS(5713),
    [anon_sym_for] = ACTIONS(5713),
    [anon_sym_FOR] = ACTIONS(5713),
    [anon_sym_For] = ACTIONS(5713),
    [anon_sym_foreach] = ACTIONS(5713),
    [anon_sym_FOREACH] = ACTIONS(5713),
    [anon_sym_Foreach] = ACTIONS(5713),
    [anon_sym_while] = ACTIONS(5713),
    [anon_sym_WHILE] = ACTIONS(5713),
    [anon_sym_While] = ACTIONS(5713),
    [anon_sym_repeat] = ACTIONS(5713),
    [anon_sym_REPEAT] = ACTIONS(5713),
    [anon_sym_Repeat] = ACTIONS(5713),
    [anon_sym_until] = ACTIONS(5713),
    [anon_sym_UNTIL] = ACTIONS(5713),
    [anon_sym_Until] = ACTIONS(5713),
    [anon_sym_exit] = ACTIONS(5713),
    [anon_sym_EXIT] = ACTIONS(5713),
    [anon_sym_Exit] = ACTIONS(5713),
    [anon_sym_continue] = ACTIONS(5713),
    [anon_sym_CONTINUE] = ACTIONS(5713),
    [anon_sym_Continue] = ACTIONS(5713),
    [anon_sym_break] = ACTIONS(5713),
    [anon_sym_BREAK] = ACTIONS(5713),
    [anon_sym_Break] = ACTIONS(5713),
    [anon_sym_with] = ACTIONS(5713),
    [anon_sym_WITH] = ACTIONS(5713),
    [anon_sym_With] = ACTIONS(5713),
    [sym_asserterror_keyword] = ACTIONS(5715),
    [sym_page_keyword] = ACTIONS(5713),
    [anon_sym_codeunit] = ACTIONS(5713),
    [anon_sym_CODEUNIT] = ACTIONS(5713),
    [anon_sym_Codeunit] = ACTIONS(5713),
    [anon_sym_CodeUnit] = ACTIONS(5713),
    [anon_sym_COdeunit] = ACTIONS(5713),
    [anon_sym_codeUnit] = ACTIONS(5713),
    [sym_report_keyword] = ACTIONS(5713),
    [sym_query_keyword] = ACTIONS(5713),
    [anon_sym_xmlport] = ACTIONS(5713),
    [anon_sym_XMLPORT] = ACTIONS(5713),
    [anon_sym_Xmlport] = ACTIONS(5713),
    [anon_sym_XMLport] = ACTIONS(5713),
    [anon_sym_XMLPort] = ACTIONS(5713),
    [anon_sym_XmlPort] = ACTIONS(5713),
    [anon_sym_enum] = ACTIONS(5713),
    [anon_sym_ENUM] = ACTIONS(5713),
    [anon_sym_Enum] = ACTIONS(5713),
    [anon_sym_eNUM] = ACTIONS(5713),
    [anon_sym_eNum] = ACTIONS(5713),
    [anon_sym_ENum] = ACTIONS(5713),
    [sym_quoted_identifier] = ACTIONS(5715),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5715),
    [sym_verbatim_string] = ACTIONS(5715),
    [sym_integer] = ACTIONS(5713),
    [sym_continue_as_identifier] = ACTIONS(5715),
    [sym_preproc_open] = ACTIONS(5715),
  },
  [STATE(3015)] = {
    [sym_identifier] = ACTIONS(5717),
    [anon_sym_SEMI] = ACTIONS(5719),
    [anon_sym_DASH] = ACTIONS(5719),
    [aux_sym_boolean_token1] = ACTIONS(5717),
    [aux_sym_boolean_token2] = ACTIONS(5717),
    [sym_decimal] = ACTIONS(5717),
    [anon_sym_LPAREN] = ACTIONS(5719),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5717),
    [anon_sym_LBRACK] = ACTIONS(5719),
    [aux_sym_record_type_token1] = ACTIONS(5717),
    [aux_sym_basic_type_token21] = ACTIONS(5717),
    [aux_sym_basic_type_token22] = ACTIONS(5717),
    [aux_sym_basic_type_token48] = ACTIONS(5717),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5717),
    [anon_sym_POUNDif] = ACTIONS(5719),
    [anon_sym_POUNDIF] = ACTIONS(5719),
    [anon_sym_POUNDIf] = ACTIONS(5719),
    [anon_sym_not] = ACTIONS(5717),
    [anon_sym_NOT] = ACTIONS(5717),
    [anon_sym_Not] = ACTIONS(5717),
    [anon_sym_POUNDelse] = ACTIONS(5719),
    [anon_sym_POUNDELSE] = ACTIONS(5719),
    [anon_sym_POUNDElse] = ACTIONS(5719),
    [anon_sym_POUNDelse2] = ACTIONS(5719),
    [anon_sym_POUNDELSE2] = ACTIONS(5719),
    [anon_sym_POUNDElse2] = ACTIONS(5719),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5717),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5717),
    [anon_sym_PLUS] = ACTIONS(5719),
    [sym_datetime_literal] = ACTIONS(5719),
    [sym_date_literal] = ACTIONS(5717),
    [sym_time_literal] = ACTIONS(5717),
    [sym_biginteger_literal] = ACTIONS(5719),
    [anon_sym_if] = ACTIONS(5717),
    [anon_sym_IF] = ACTIONS(5717),
    [anon_sym_If] = ACTIONS(5717),
    [anon_sym_else] = ACTIONS(5717),
    [anon_sym_ELSE] = ACTIONS(5717),
    [anon_sym_Else] = ACTIONS(5717),
    [anon_sym_case] = ACTIONS(5717),
    [anon_sym_CASE] = ACTIONS(5717),
    [anon_sym_Case] = ACTIONS(5717),
    [anon_sym_for] = ACTIONS(5717),
    [anon_sym_FOR] = ACTIONS(5717),
    [anon_sym_For] = ACTIONS(5717),
    [anon_sym_foreach] = ACTIONS(5717),
    [anon_sym_FOREACH] = ACTIONS(5717),
    [anon_sym_Foreach] = ACTIONS(5717),
    [anon_sym_while] = ACTIONS(5717),
    [anon_sym_WHILE] = ACTIONS(5717),
    [anon_sym_While] = ACTIONS(5717),
    [anon_sym_repeat] = ACTIONS(5717),
    [anon_sym_REPEAT] = ACTIONS(5717),
    [anon_sym_Repeat] = ACTIONS(5717),
    [anon_sym_until] = ACTIONS(5717),
    [anon_sym_UNTIL] = ACTIONS(5717),
    [anon_sym_Until] = ACTIONS(5717),
    [anon_sym_exit] = ACTIONS(5717),
    [anon_sym_EXIT] = ACTIONS(5717),
    [anon_sym_Exit] = ACTIONS(5717),
    [anon_sym_continue] = ACTIONS(5717),
    [anon_sym_CONTINUE] = ACTIONS(5717),
    [anon_sym_Continue] = ACTIONS(5717),
    [anon_sym_break] = ACTIONS(5717),
    [anon_sym_BREAK] = ACTIONS(5717),
    [anon_sym_Break] = ACTIONS(5717),
    [anon_sym_with] = ACTIONS(5717),
    [anon_sym_WITH] = ACTIONS(5717),
    [anon_sym_With] = ACTIONS(5717),
    [sym_asserterror_keyword] = ACTIONS(5719),
    [sym_page_keyword] = ACTIONS(5717),
    [anon_sym_codeunit] = ACTIONS(5717),
    [anon_sym_CODEUNIT] = ACTIONS(5717),
    [anon_sym_Codeunit] = ACTIONS(5717),
    [anon_sym_CodeUnit] = ACTIONS(5717),
    [anon_sym_COdeunit] = ACTIONS(5717),
    [anon_sym_codeUnit] = ACTIONS(5717),
    [sym_report_keyword] = ACTIONS(5717),
    [sym_query_keyword] = ACTIONS(5717),
    [anon_sym_xmlport] = ACTIONS(5717),
    [anon_sym_XMLPORT] = ACTIONS(5717),
    [anon_sym_Xmlport] = ACTIONS(5717),
    [anon_sym_XMLport] = ACTIONS(5717),
    [anon_sym_XMLPort] = ACTIONS(5717),
    [anon_sym_XmlPort] = ACTIONS(5717),
    [anon_sym_enum] = ACTIONS(5717),
    [anon_sym_ENUM] = ACTIONS(5717),
    [anon_sym_Enum] = ACTIONS(5717),
    [anon_sym_eNUM] = ACTIONS(5717),
    [anon_sym_eNum] = ACTIONS(5717),
    [anon_sym_ENum] = ACTIONS(5717),
    [sym_quoted_identifier] = ACTIONS(5719),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5719),
    [sym_verbatim_string] = ACTIONS(5719),
    [sym_integer] = ACTIONS(5717),
    [sym_continue_as_identifier] = ACTIONS(5719),
    [sym_preproc_open] = ACTIONS(5719),
  },
  [STATE(3016)] = {
    [sym_identifier] = ACTIONS(5721),
    [anon_sym_SEMI] = ACTIONS(5723),
    [anon_sym_DASH] = ACTIONS(5723),
    [aux_sym_boolean_token1] = ACTIONS(5721),
    [aux_sym_boolean_token2] = ACTIONS(5721),
    [sym_decimal] = ACTIONS(5721),
    [anon_sym_LPAREN] = ACTIONS(5723),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5721),
    [anon_sym_LBRACK] = ACTIONS(5723),
    [aux_sym_record_type_token1] = ACTIONS(5721),
    [aux_sym_basic_type_token21] = ACTIONS(5721),
    [aux_sym_basic_type_token22] = ACTIONS(5721),
    [aux_sym_basic_type_token48] = ACTIONS(5721),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5721),
    [anon_sym_POUNDif] = ACTIONS(5723),
    [anon_sym_POUNDIF] = ACTIONS(5723),
    [anon_sym_POUNDIf] = ACTIONS(5723),
    [anon_sym_not] = ACTIONS(5721),
    [anon_sym_NOT] = ACTIONS(5721),
    [anon_sym_Not] = ACTIONS(5721),
    [anon_sym_POUNDelse] = ACTIONS(5723),
    [anon_sym_POUNDELSE] = ACTIONS(5723),
    [anon_sym_POUNDElse] = ACTIONS(5723),
    [anon_sym_POUNDelse2] = ACTIONS(5723),
    [anon_sym_POUNDELSE2] = ACTIONS(5723),
    [anon_sym_POUNDElse2] = ACTIONS(5723),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5721),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5721),
    [anon_sym_PLUS] = ACTIONS(5723),
    [sym_datetime_literal] = ACTIONS(5723),
    [sym_date_literal] = ACTIONS(5721),
    [sym_time_literal] = ACTIONS(5721),
    [sym_biginteger_literal] = ACTIONS(5723),
    [anon_sym_if] = ACTIONS(5721),
    [anon_sym_IF] = ACTIONS(5721),
    [anon_sym_If] = ACTIONS(5721),
    [anon_sym_else] = ACTIONS(5721),
    [anon_sym_ELSE] = ACTIONS(5721),
    [anon_sym_Else] = ACTIONS(5721),
    [anon_sym_case] = ACTIONS(5721),
    [anon_sym_CASE] = ACTIONS(5721),
    [anon_sym_Case] = ACTIONS(5721),
    [anon_sym_for] = ACTIONS(5721),
    [anon_sym_FOR] = ACTIONS(5721),
    [anon_sym_For] = ACTIONS(5721),
    [anon_sym_foreach] = ACTIONS(5721),
    [anon_sym_FOREACH] = ACTIONS(5721),
    [anon_sym_Foreach] = ACTIONS(5721),
    [anon_sym_while] = ACTIONS(5721),
    [anon_sym_WHILE] = ACTIONS(5721),
    [anon_sym_While] = ACTIONS(5721),
    [anon_sym_repeat] = ACTIONS(5721),
    [anon_sym_REPEAT] = ACTIONS(5721),
    [anon_sym_Repeat] = ACTIONS(5721),
    [anon_sym_until] = ACTIONS(5721),
    [anon_sym_UNTIL] = ACTIONS(5721),
    [anon_sym_Until] = ACTIONS(5721),
    [anon_sym_exit] = ACTIONS(5721),
    [anon_sym_EXIT] = ACTIONS(5721),
    [anon_sym_Exit] = ACTIONS(5721),
    [anon_sym_continue] = ACTIONS(5721),
    [anon_sym_CONTINUE] = ACTIONS(5721),
    [anon_sym_Continue] = ACTIONS(5721),
    [anon_sym_break] = ACTIONS(5721),
    [anon_sym_BREAK] = ACTIONS(5721),
    [anon_sym_Break] = ACTIONS(5721),
    [anon_sym_with] = ACTIONS(5721),
    [anon_sym_WITH] = ACTIONS(5721),
    [anon_sym_With] = ACTIONS(5721),
    [sym_asserterror_keyword] = ACTIONS(5723),
    [sym_page_keyword] = ACTIONS(5721),
    [anon_sym_codeunit] = ACTIONS(5721),
    [anon_sym_CODEUNIT] = ACTIONS(5721),
    [anon_sym_Codeunit] = ACTIONS(5721),
    [anon_sym_CodeUnit] = ACTIONS(5721),
    [anon_sym_COdeunit] = ACTIONS(5721),
    [anon_sym_codeUnit] = ACTIONS(5721),
    [sym_report_keyword] = ACTIONS(5721),
    [sym_query_keyword] = ACTIONS(5721),
    [anon_sym_xmlport] = ACTIONS(5721),
    [anon_sym_XMLPORT] = ACTIONS(5721),
    [anon_sym_Xmlport] = ACTIONS(5721),
    [anon_sym_XMLport] = ACTIONS(5721),
    [anon_sym_XMLPort] = ACTIONS(5721),
    [anon_sym_XmlPort] = ACTIONS(5721),
    [anon_sym_enum] = ACTIONS(5721),
    [anon_sym_ENUM] = ACTIONS(5721),
    [anon_sym_Enum] = ACTIONS(5721),
    [anon_sym_eNUM] = ACTIONS(5721),
    [anon_sym_eNum] = ACTIONS(5721),
    [anon_sym_ENum] = ACTIONS(5721),
    [sym_quoted_identifier] = ACTIONS(5723),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5723),
    [sym_verbatim_string] = ACTIONS(5723),
    [sym_integer] = ACTIONS(5721),
    [sym_continue_as_identifier] = ACTIONS(5723),
    [sym_preproc_open] = ACTIONS(5723),
  },
  [STATE(3017)] = {
    [sym_identifier] = ACTIONS(5725),
    [anon_sym_SEMI] = ACTIONS(5727),
    [anon_sym_DASH] = ACTIONS(5727),
    [aux_sym_boolean_token1] = ACTIONS(5725),
    [aux_sym_boolean_token2] = ACTIONS(5725),
    [sym_decimal] = ACTIONS(5725),
    [anon_sym_LPAREN] = ACTIONS(5727),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5725),
    [anon_sym_LBRACK] = ACTIONS(5727),
    [aux_sym_record_type_token1] = ACTIONS(5725),
    [aux_sym_basic_type_token21] = ACTIONS(5725),
    [aux_sym_basic_type_token22] = ACTIONS(5725),
    [aux_sym_basic_type_token48] = ACTIONS(5725),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5725),
    [anon_sym_POUNDif] = ACTIONS(5727),
    [anon_sym_POUNDIF] = ACTIONS(5727),
    [anon_sym_POUNDIf] = ACTIONS(5727),
    [anon_sym_not] = ACTIONS(5725),
    [anon_sym_NOT] = ACTIONS(5725),
    [anon_sym_Not] = ACTIONS(5725),
    [anon_sym_POUNDelse] = ACTIONS(5727),
    [anon_sym_POUNDELSE] = ACTIONS(5727),
    [anon_sym_POUNDElse] = ACTIONS(5727),
    [anon_sym_POUNDelse2] = ACTIONS(5727),
    [anon_sym_POUNDELSE2] = ACTIONS(5727),
    [anon_sym_POUNDElse2] = ACTIONS(5727),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5725),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5725),
    [anon_sym_PLUS] = ACTIONS(5727),
    [sym_datetime_literal] = ACTIONS(5727),
    [sym_date_literal] = ACTIONS(5725),
    [sym_time_literal] = ACTIONS(5725),
    [sym_biginteger_literal] = ACTIONS(5727),
    [anon_sym_if] = ACTIONS(5725),
    [anon_sym_IF] = ACTIONS(5725),
    [anon_sym_If] = ACTIONS(5725),
    [anon_sym_else] = ACTIONS(5725),
    [anon_sym_ELSE] = ACTIONS(5725),
    [anon_sym_Else] = ACTIONS(5725),
    [anon_sym_case] = ACTIONS(5725),
    [anon_sym_CASE] = ACTIONS(5725),
    [anon_sym_Case] = ACTIONS(5725),
    [anon_sym_for] = ACTIONS(5725),
    [anon_sym_FOR] = ACTIONS(5725),
    [anon_sym_For] = ACTIONS(5725),
    [anon_sym_foreach] = ACTIONS(5725),
    [anon_sym_FOREACH] = ACTIONS(5725),
    [anon_sym_Foreach] = ACTIONS(5725),
    [anon_sym_while] = ACTIONS(5725),
    [anon_sym_WHILE] = ACTIONS(5725),
    [anon_sym_While] = ACTIONS(5725),
    [anon_sym_repeat] = ACTIONS(5725),
    [anon_sym_REPEAT] = ACTIONS(5725),
    [anon_sym_Repeat] = ACTIONS(5725),
    [anon_sym_until] = ACTIONS(5725),
    [anon_sym_UNTIL] = ACTIONS(5725),
    [anon_sym_Until] = ACTIONS(5725),
    [anon_sym_exit] = ACTIONS(5725),
    [anon_sym_EXIT] = ACTIONS(5725),
    [anon_sym_Exit] = ACTIONS(5725),
    [anon_sym_continue] = ACTIONS(5725),
    [anon_sym_CONTINUE] = ACTIONS(5725),
    [anon_sym_Continue] = ACTIONS(5725),
    [anon_sym_break] = ACTIONS(5725),
    [anon_sym_BREAK] = ACTIONS(5725),
    [anon_sym_Break] = ACTIONS(5725),
    [anon_sym_with] = ACTIONS(5725),
    [anon_sym_WITH] = ACTIONS(5725),
    [anon_sym_With] = ACTIONS(5725),
    [sym_asserterror_keyword] = ACTIONS(5727),
    [sym_page_keyword] = ACTIONS(5725),
    [anon_sym_codeunit] = ACTIONS(5725),
    [anon_sym_CODEUNIT] = ACTIONS(5725),
    [anon_sym_Codeunit] = ACTIONS(5725),
    [anon_sym_CodeUnit] = ACTIONS(5725),
    [anon_sym_COdeunit] = ACTIONS(5725),
    [anon_sym_codeUnit] = ACTIONS(5725),
    [sym_report_keyword] = ACTIONS(5725),
    [sym_query_keyword] = ACTIONS(5725),
    [anon_sym_xmlport] = ACTIONS(5725),
    [anon_sym_XMLPORT] = ACTIONS(5725),
    [anon_sym_Xmlport] = ACTIONS(5725),
    [anon_sym_XMLport] = ACTIONS(5725),
    [anon_sym_XMLPort] = ACTIONS(5725),
    [anon_sym_XmlPort] = ACTIONS(5725),
    [anon_sym_enum] = ACTIONS(5725),
    [anon_sym_ENUM] = ACTIONS(5725),
    [anon_sym_Enum] = ACTIONS(5725),
    [anon_sym_eNUM] = ACTIONS(5725),
    [anon_sym_eNum] = ACTIONS(5725),
    [anon_sym_ENum] = ACTIONS(5725),
    [sym_quoted_identifier] = ACTIONS(5727),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5727),
    [sym_verbatim_string] = ACTIONS(5727),
    [sym_integer] = ACTIONS(5725),
    [sym_continue_as_identifier] = ACTIONS(5727),
    [sym_preproc_open] = ACTIONS(5727),
  },
  [STATE(3018)] = {
    [sym_identifier] = ACTIONS(5729),
    [anon_sym_SEMI] = ACTIONS(5731),
    [anon_sym_DASH] = ACTIONS(5731),
    [aux_sym_boolean_token1] = ACTIONS(5729),
    [aux_sym_boolean_token2] = ACTIONS(5729),
    [sym_decimal] = ACTIONS(5729),
    [anon_sym_LPAREN] = ACTIONS(5731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5729),
    [anon_sym_LBRACK] = ACTIONS(5731),
    [aux_sym_record_type_token1] = ACTIONS(5729),
    [aux_sym_basic_type_token21] = ACTIONS(5729),
    [aux_sym_basic_type_token22] = ACTIONS(5729),
    [aux_sym_basic_type_token48] = ACTIONS(5729),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5729),
    [anon_sym_POUNDif] = ACTIONS(5731),
    [anon_sym_POUNDIF] = ACTIONS(5731),
    [anon_sym_POUNDIf] = ACTIONS(5731),
    [anon_sym_not] = ACTIONS(5729),
    [anon_sym_NOT] = ACTIONS(5729),
    [anon_sym_Not] = ACTIONS(5729),
    [anon_sym_POUNDelse] = ACTIONS(5731),
    [anon_sym_POUNDELSE] = ACTIONS(5731),
    [anon_sym_POUNDElse] = ACTIONS(5731),
    [anon_sym_POUNDelse2] = ACTIONS(5731),
    [anon_sym_POUNDELSE2] = ACTIONS(5731),
    [anon_sym_POUNDElse2] = ACTIONS(5731),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5729),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5729),
    [anon_sym_PLUS] = ACTIONS(5731),
    [sym_datetime_literal] = ACTIONS(5731),
    [sym_date_literal] = ACTIONS(5729),
    [sym_time_literal] = ACTIONS(5729),
    [sym_biginteger_literal] = ACTIONS(5731),
    [anon_sym_if] = ACTIONS(5729),
    [anon_sym_IF] = ACTIONS(5729),
    [anon_sym_If] = ACTIONS(5729),
    [anon_sym_else] = ACTIONS(5729),
    [anon_sym_ELSE] = ACTIONS(5729),
    [anon_sym_Else] = ACTIONS(5729),
    [anon_sym_case] = ACTIONS(5729),
    [anon_sym_CASE] = ACTIONS(5729),
    [anon_sym_Case] = ACTIONS(5729),
    [anon_sym_for] = ACTIONS(5729),
    [anon_sym_FOR] = ACTIONS(5729),
    [anon_sym_For] = ACTIONS(5729),
    [anon_sym_foreach] = ACTIONS(5729),
    [anon_sym_FOREACH] = ACTIONS(5729),
    [anon_sym_Foreach] = ACTIONS(5729),
    [anon_sym_while] = ACTIONS(5729),
    [anon_sym_WHILE] = ACTIONS(5729),
    [anon_sym_While] = ACTIONS(5729),
    [anon_sym_repeat] = ACTIONS(5729),
    [anon_sym_REPEAT] = ACTIONS(5729),
    [anon_sym_Repeat] = ACTIONS(5729),
    [anon_sym_until] = ACTIONS(5729),
    [anon_sym_UNTIL] = ACTIONS(5729),
    [anon_sym_Until] = ACTIONS(5729),
    [anon_sym_exit] = ACTIONS(5729),
    [anon_sym_EXIT] = ACTIONS(5729),
    [anon_sym_Exit] = ACTIONS(5729),
    [anon_sym_continue] = ACTIONS(5729),
    [anon_sym_CONTINUE] = ACTIONS(5729),
    [anon_sym_Continue] = ACTIONS(5729),
    [anon_sym_break] = ACTIONS(5729),
    [anon_sym_BREAK] = ACTIONS(5729),
    [anon_sym_Break] = ACTIONS(5729),
    [anon_sym_with] = ACTIONS(5729),
    [anon_sym_WITH] = ACTIONS(5729),
    [anon_sym_With] = ACTIONS(5729),
    [sym_asserterror_keyword] = ACTIONS(5731),
    [sym_page_keyword] = ACTIONS(5729),
    [anon_sym_codeunit] = ACTIONS(5729),
    [anon_sym_CODEUNIT] = ACTIONS(5729),
    [anon_sym_Codeunit] = ACTIONS(5729),
    [anon_sym_CodeUnit] = ACTIONS(5729),
    [anon_sym_COdeunit] = ACTIONS(5729),
    [anon_sym_codeUnit] = ACTIONS(5729),
    [sym_report_keyword] = ACTIONS(5729),
    [sym_query_keyword] = ACTIONS(5729),
    [anon_sym_xmlport] = ACTIONS(5729),
    [anon_sym_XMLPORT] = ACTIONS(5729),
    [anon_sym_Xmlport] = ACTIONS(5729),
    [anon_sym_XMLport] = ACTIONS(5729),
    [anon_sym_XMLPort] = ACTIONS(5729),
    [anon_sym_XmlPort] = ACTIONS(5729),
    [anon_sym_enum] = ACTIONS(5729),
    [anon_sym_ENUM] = ACTIONS(5729),
    [anon_sym_Enum] = ACTIONS(5729),
    [anon_sym_eNUM] = ACTIONS(5729),
    [anon_sym_eNum] = ACTIONS(5729),
    [anon_sym_ENum] = ACTIONS(5729),
    [sym_quoted_identifier] = ACTIONS(5731),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5731),
    [sym_verbatim_string] = ACTIONS(5731),
    [sym_integer] = ACTIONS(5729),
    [sym_continue_as_identifier] = ACTIONS(5731),
    [sym_preproc_open] = ACTIONS(5731),
  },
  [STATE(3019)] = {
    [sym_identifier] = ACTIONS(5733),
    [anon_sym_SEMI] = ACTIONS(5735),
    [anon_sym_DASH] = ACTIONS(5735),
    [aux_sym_boolean_token1] = ACTIONS(5733),
    [aux_sym_boolean_token2] = ACTIONS(5733),
    [sym_decimal] = ACTIONS(5733),
    [anon_sym_LPAREN] = ACTIONS(5735),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5733),
    [anon_sym_LBRACK] = ACTIONS(5735),
    [aux_sym_record_type_token1] = ACTIONS(5733),
    [aux_sym_basic_type_token21] = ACTIONS(5733),
    [aux_sym_basic_type_token22] = ACTIONS(5733),
    [aux_sym_basic_type_token48] = ACTIONS(5733),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5733),
    [anon_sym_POUNDif] = ACTIONS(5735),
    [anon_sym_POUNDIF] = ACTIONS(5735),
    [anon_sym_POUNDIf] = ACTIONS(5735),
    [anon_sym_not] = ACTIONS(5733),
    [anon_sym_NOT] = ACTIONS(5733),
    [anon_sym_Not] = ACTIONS(5733),
    [anon_sym_POUNDelse] = ACTIONS(5735),
    [anon_sym_POUNDELSE] = ACTIONS(5735),
    [anon_sym_POUNDElse] = ACTIONS(5735),
    [anon_sym_POUNDelse2] = ACTIONS(5735),
    [anon_sym_POUNDELSE2] = ACTIONS(5735),
    [anon_sym_POUNDElse2] = ACTIONS(5735),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5733),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5733),
    [anon_sym_PLUS] = ACTIONS(5735),
    [sym_datetime_literal] = ACTIONS(5735),
    [sym_date_literal] = ACTIONS(5733),
    [sym_time_literal] = ACTIONS(5733),
    [sym_biginteger_literal] = ACTIONS(5735),
    [anon_sym_if] = ACTIONS(5733),
    [anon_sym_IF] = ACTIONS(5733),
    [anon_sym_If] = ACTIONS(5733),
    [anon_sym_else] = ACTIONS(5733),
    [anon_sym_ELSE] = ACTIONS(5733),
    [anon_sym_Else] = ACTIONS(5733),
    [anon_sym_case] = ACTIONS(5733),
    [anon_sym_CASE] = ACTIONS(5733),
    [anon_sym_Case] = ACTIONS(5733),
    [anon_sym_for] = ACTIONS(5733),
    [anon_sym_FOR] = ACTIONS(5733),
    [anon_sym_For] = ACTIONS(5733),
    [anon_sym_foreach] = ACTIONS(5733),
    [anon_sym_FOREACH] = ACTIONS(5733),
    [anon_sym_Foreach] = ACTIONS(5733),
    [anon_sym_while] = ACTIONS(5733),
    [anon_sym_WHILE] = ACTIONS(5733),
    [anon_sym_While] = ACTIONS(5733),
    [anon_sym_repeat] = ACTIONS(5733),
    [anon_sym_REPEAT] = ACTIONS(5733),
    [anon_sym_Repeat] = ACTIONS(5733),
    [anon_sym_until] = ACTIONS(5733),
    [anon_sym_UNTIL] = ACTIONS(5733),
    [anon_sym_Until] = ACTIONS(5733),
    [anon_sym_exit] = ACTIONS(5733),
    [anon_sym_EXIT] = ACTIONS(5733),
    [anon_sym_Exit] = ACTIONS(5733),
    [anon_sym_continue] = ACTIONS(5733),
    [anon_sym_CONTINUE] = ACTIONS(5733),
    [anon_sym_Continue] = ACTIONS(5733),
    [anon_sym_break] = ACTIONS(5733),
    [anon_sym_BREAK] = ACTIONS(5733),
    [anon_sym_Break] = ACTIONS(5733),
    [anon_sym_with] = ACTIONS(5733),
    [anon_sym_WITH] = ACTIONS(5733),
    [anon_sym_With] = ACTIONS(5733),
    [sym_asserterror_keyword] = ACTIONS(5735),
    [sym_page_keyword] = ACTIONS(5733),
    [anon_sym_codeunit] = ACTIONS(5733),
    [anon_sym_CODEUNIT] = ACTIONS(5733),
    [anon_sym_Codeunit] = ACTIONS(5733),
    [anon_sym_CodeUnit] = ACTIONS(5733),
    [anon_sym_COdeunit] = ACTIONS(5733),
    [anon_sym_codeUnit] = ACTIONS(5733),
    [sym_report_keyword] = ACTIONS(5733),
    [sym_query_keyword] = ACTIONS(5733),
    [anon_sym_xmlport] = ACTIONS(5733),
    [anon_sym_XMLPORT] = ACTIONS(5733),
    [anon_sym_Xmlport] = ACTIONS(5733),
    [anon_sym_XMLport] = ACTIONS(5733),
    [anon_sym_XMLPort] = ACTIONS(5733),
    [anon_sym_XmlPort] = ACTIONS(5733),
    [anon_sym_enum] = ACTIONS(5733),
    [anon_sym_ENUM] = ACTIONS(5733),
    [anon_sym_Enum] = ACTIONS(5733),
    [anon_sym_eNUM] = ACTIONS(5733),
    [anon_sym_eNum] = ACTIONS(5733),
    [anon_sym_ENum] = ACTIONS(5733),
    [sym_quoted_identifier] = ACTIONS(5735),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5735),
    [sym_verbatim_string] = ACTIONS(5735),
    [sym_integer] = ACTIONS(5733),
    [sym_continue_as_identifier] = ACTIONS(5735),
    [sym_preproc_open] = ACTIONS(5735),
  },
  [STATE(3020)] = {
    [sym_identifier] = ACTIONS(5737),
    [anon_sym_SEMI] = ACTIONS(5739),
    [anon_sym_DASH] = ACTIONS(5739),
    [aux_sym_boolean_token1] = ACTIONS(5737),
    [aux_sym_boolean_token2] = ACTIONS(5737),
    [sym_decimal] = ACTIONS(5737),
    [anon_sym_LPAREN] = ACTIONS(5739),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5737),
    [anon_sym_LBRACK] = ACTIONS(5739),
    [aux_sym_record_type_token1] = ACTIONS(5737),
    [aux_sym_basic_type_token21] = ACTIONS(5737),
    [aux_sym_basic_type_token22] = ACTIONS(5737),
    [aux_sym_basic_type_token48] = ACTIONS(5737),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5737),
    [anon_sym_POUNDif] = ACTIONS(5739),
    [anon_sym_POUNDIF] = ACTIONS(5739),
    [anon_sym_POUNDIf] = ACTIONS(5739),
    [anon_sym_not] = ACTIONS(5737),
    [anon_sym_NOT] = ACTIONS(5737),
    [anon_sym_Not] = ACTIONS(5737),
    [anon_sym_POUNDelse] = ACTIONS(5739),
    [anon_sym_POUNDELSE] = ACTIONS(5739),
    [anon_sym_POUNDElse] = ACTIONS(5739),
    [anon_sym_POUNDelse2] = ACTIONS(5739),
    [anon_sym_POUNDELSE2] = ACTIONS(5739),
    [anon_sym_POUNDElse2] = ACTIONS(5739),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5737),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5737),
    [anon_sym_PLUS] = ACTIONS(5739),
    [sym_datetime_literal] = ACTIONS(5739),
    [sym_date_literal] = ACTIONS(5737),
    [sym_time_literal] = ACTIONS(5737),
    [sym_biginteger_literal] = ACTIONS(5739),
    [anon_sym_if] = ACTIONS(5737),
    [anon_sym_IF] = ACTIONS(5737),
    [anon_sym_If] = ACTIONS(5737),
    [anon_sym_else] = ACTIONS(5737),
    [anon_sym_ELSE] = ACTIONS(5737),
    [anon_sym_Else] = ACTIONS(5737),
    [anon_sym_case] = ACTIONS(5737),
    [anon_sym_CASE] = ACTIONS(5737),
    [anon_sym_Case] = ACTIONS(5737),
    [anon_sym_for] = ACTIONS(5737),
    [anon_sym_FOR] = ACTIONS(5737),
    [anon_sym_For] = ACTIONS(5737),
    [anon_sym_foreach] = ACTIONS(5737),
    [anon_sym_FOREACH] = ACTIONS(5737),
    [anon_sym_Foreach] = ACTIONS(5737),
    [anon_sym_while] = ACTIONS(5737),
    [anon_sym_WHILE] = ACTIONS(5737),
    [anon_sym_While] = ACTIONS(5737),
    [anon_sym_repeat] = ACTIONS(5737),
    [anon_sym_REPEAT] = ACTIONS(5737),
    [anon_sym_Repeat] = ACTIONS(5737),
    [anon_sym_until] = ACTIONS(5737),
    [anon_sym_UNTIL] = ACTIONS(5737),
    [anon_sym_Until] = ACTIONS(5737),
    [anon_sym_exit] = ACTIONS(5737),
    [anon_sym_EXIT] = ACTIONS(5737),
    [anon_sym_Exit] = ACTIONS(5737),
    [anon_sym_continue] = ACTIONS(5737),
    [anon_sym_CONTINUE] = ACTIONS(5737),
    [anon_sym_Continue] = ACTIONS(5737),
    [anon_sym_break] = ACTIONS(5737),
    [anon_sym_BREAK] = ACTIONS(5737),
    [anon_sym_Break] = ACTIONS(5737),
    [anon_sym_with] = ACTIONS(5737),
    [anon_sym_WITH] = ACTIONS(5737),
    [anon_sym_With] = ACTIONS(5737),
    [sym_asserterror_keyword] = ACTIONS(5739),
    [sym_page_keyword] = ACTIONS(5737),
    [anon_sym_codeunit] = ACTIONS(5737),
    [anon_sym_CODEUNIT] = ACTIONS(5737),
    [anon_sym_Codeunit] = ACTIONS(5737),
    [anon_sym_CodeUnit] = ACTIONS(5737),
    [anon_sym_COdeunit] = ACTIONS(5737),
    [anon_sym_codeUnit] = ACTIONS(5737),
    [sym_report_keyword] = ACTIONS(5737),
    [sym_query_keyword] = ACTIONS(5737),
    [anon_sym_xmlport] = ACTIONS(5737),
    [anon_sym_XMLPORT] = ACTIONS(5737),
    [anon_sym_Xmlport] = ACTIONS(5737),
    [anon_sym_XMLport] = ACTIONS(5737),
    [anon_sym_XMLPort] = ACTIONS(5737),
    [anon_sym_XmlPort] = ACTIONS(5737),
    [anon_sym_enum] = ACTIONS(5737),
    [anon_sym_ENUM] = ACTIONS(5737),
    [anon_sym_Enum] = ACTIONS(5737),
    [anon_sym_eNUM] = ACTIONS(5737),
    [anon_sym_eNum] = ACTIONS(5737),
    [anon_sym_ENum] = ACTIONS(5737),
    [sym_quoted_identifier] = ACTIONS(5739),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5739),
    [sym_verbatim_string] = ACTIONS(5739),
    [sym_integer] = ACTIONS(5737),
    [sym_continue_as_identifier] = ACTIONS(5739),
    [sym_preproc_open] = ACTIONS(5739),
  },
  [STATE(3021)] = {
    [sym_identifier] = ACTIONS(5741),
    [anon_sym_SEMI] = ACTIONS(5743),
    [anon_sym_DASH] = ACTIONS(5743),
    [aux_sym_boolean_token1] = ACTIONS(5741),
    [aux_sym_boolean_token2] = ACTIONS(5741),
    [sym_decimal] = ACTIONS(5741),
    [anon_sym_LPAREN] = ACTIONS(5743),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5741),
    [anon_sym_LBRACK] = ACTIONS(5743),
    [aux_sym_record_type_token1] = ACTIONS(5741),
    [aux_sym_basic_type_token21] = ACTIONS(5741),
    [aux_sym_basic_type_token22] = ACTIONS(5741),
    [aux_sym_basic_type_token48] = ACTIONS(5741),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5741),
    [anon_sym_POUNDif] = ACTIONS(5743),
    [anon_sym_POUNDIF] = ACTIONS(5743),
    [anon_sym_POUNDIf] = ACTIONS(5743),
    [anon_sym_not] = ACTIONS(5741),
    [anon_sym_NOT] = ACTIONS(5741),
    [anon_sym_Not] = ACTIONS(5741),
    [anon_sym_POUNDelse] = ACTIONS(5743),
    [anon_sym_POUNDELSE] = ACTIONS(5743),
    [anon_sym_POUNDElse] = ACTIONS(5743),
    [anon_sym_POUNDelse2] = ACTIONS(5743),
    [anon_sym_POUNDELSE2] = ACTIONS(5743),
    [anon_sym_POUNDElse2] = ACTIONS(5743),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5741),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5741),
    [anon_sym_PLUS] = ACTIONS(5743),
    [sym_datetime_literal] = ACTIONS(5743),
    [sym_date_literal] = ACTIONS(5741),
    [sym_time_literal] = ACTIONS(5741),
    [sym_biginteger_literal] = ACTIONS(5743),
    [anon_sym_if] = ACTIONS(5741),
    [anon_sym_IF] = ACTIONS(5741),
    [anon_sym_If] = ACTIONS(5741),
    [anon_sym_else] = ACTIONS(5741),
    [anon_sym_ELSE] = ACTIONS(5741),
    [anon_sym_Else] = ACTIONS(5741),
    [anon_sym_case] = ACTIONS(5741),
    [anon_sym_CASE] = ACTIONS(5741),
    [anon_sym_Case] = ACTIONS(5741),
    [anon_sym_for] = ACTIONS(5741),
    [anon_sym_FOR] = ACTIONS(5741),
    [anon_sym_For] = ACTIONS(5741),
    [anon_sym_foreach] = ACTIONS(5741),
    [anon_sym_FOREACH] = ACTIONS(5741),
    [anon_sym_Foreach] = ACTIONS(5741),
    [anon_sym_while] = ACTIONS(5741),
    [anon_sym_WHILE] = ACTIONS(5741),
    [anon_sym_While] = ACTIONS(5741),
    [anon_sym_repeat] = ACTIONS(5741),
    [anon_sym_REPEAT] = ACTIONS(5741),
    [anon_sym_Repeat] = ACTIONS(5741),
    [anon_sym_until] = ACTIONS(5741),
    [anon_sym_UNTIL] = ACTIONS(5741),
    [anon_sym_Until] = ACTIONS(5741),
    [anon_sym_exit] = ACTIONS(5741),
    [anon_sym_EXIT] = ACTIONS(5741),
    [anon_sym_Exit] = ACTIONS(5741),
    [anon_sym_continue] = ACTIONS(5741),
    [anon_sym_CONTINUE] = ACTIONS(5741),
    [anon_sym_Continue] = ACTIONS(5741),
    [anon_sym_break] = ACTIONS(5741),
    [anon_sym_BREAK] = ACTIONS(5741),
    [anon_sym_Break] = ACTIONS(5741),
    [anon_sym_with] = ACTIONS(5741),
    [anon_sym_WITH] = ACTIONS(5741),
    [anon_sym_With] = ACTIONS(5741),
    [sym_asserterror_keyword] = ACTIONS(5743),
    [sym_page_keyword] = ACTIONS(5741),
    [anon_sym_codeunit] = ACTIONS(5741),
    [anon_sym_CODEUNIT] = ACTIONS(5741),
    [anon_sym_Codeunit] = ACTIONS(5741),
    [anon_sym_CodeUnit] = ACTIONS(5741),
    [anon_sym_COdeunit] = ACTIONS(5741),
    [anon_sym_codeUnit] = ACTIONS(5741),
    [sym_report_keyword] = ACTIONS(5741),
    [sym_query_keyword] = ACTIONS(5741),
    [anon_sym_xmlport] = ACTIONS(5741),
    [anon_sym_XMLPORT] = ACTIONS(5741),
    [anon_sym_Xmlport] = ACTIONS(5741),
    [anon_sym_XMLport] = ACTIONS(5741),
    [anon_sym_XMLPort] = ACTIONS(5741),
    [anon_sym_XmlPort] = ACTIONS(5741),
    [anon_sym_enum] = ACTIONS(5741),
    [anon_sym_ENUM] = ACTIONS(5741),
    [anon_sym_Enum] = ACTIONS(5741),
    [anon_sym_eNUM] = ACTIONS(5741),
    [anon_sym_eNum] = ACTIONS(5741),
    [anon_sym_ENum] = ACTIONS(5741),
    [sym_quoted_identifier] = ACTIONS(5743),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5743),
    [sym_verbatim_string] = ACTIONS(5743),
    [sym_integer] = ACTIONS(5741),
    [sym_continue_as_identifier] = ACTIONS(5743),
    [sym_preproc_open] = ACTIONS(5743),
  },
  [STATE(3022)] = {
    [sym_identifier] = ACTIONS(5745),
    [anon_sym_SEMI] = ACTIONS(5747),
    [anon_sym_DASH] = ACTIONS(5747),
    [aux_sym_boolean_token1] = ACTIONS(5745),
    [aux_sym_boolean_token2] = ACTIONS(5745),
    [sym_decimal] = ACTIONS(5745),
    [anon_sym_LPAREN] = ACTIONS(5747),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5745),
    [anon_sym_LBRACK] = ACTIONS(5747),
    [aux_sym_record_type_token1] = ACTIONS(5745),
    [aux_sym_basic_type_token21] = ACTIONS(5745),
    [aux_sym_basic_type_token22] = ACTIONS(5745),
    [aux_sym_basic_type_token48] = ACTIONS(5745),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5745),
    [anon_sym_POUNDif] = ACTIONS(5747),
    [anon_sym_POUNDIF] = ACTIONS(5747),
    [anon_sym_POUNDIf] = ACTIONS(5747),
    [anon_sym_not] = ACTIONS(5745),
    [anon_sym_NOT] = ACTIONS(5745),
    [anon_sym_Not] = ACTIONS(5745),
    [anon_sym_POUNDelse] = ACTIONS(5747),
    [anon_sym_POUNDELSE] = ACTIONS(5747),
    [anon_sym_POUNDElse] = ACTIONS(5747),
    [anon_sym_POUNDelse2] = ACTIONS(5747),
    [anon_sym_POUNDELSE2] = ACTIONS(5747),
    [anon_sym_POUNDElse2] = ACTIONS(5747),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5745),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5745),
    [anon_sym_PLUS] = ACTIONS(5747),
    [sym_datetime_literal] = ACTIONS(5747),
    [sym_date_literal] = ACTIONS(5745),
    [sym_time_literal] = ACTIONS(5745),
    [sym_biginteger_literal] = ACTIONS(5747),
    [anon_sym_if] = ACTIONS(5745),
    [anon_sym_IF] = ACTIONS(5745),
    [anon_sym_If] = ACTIONS(5745),
    [anon_sym_else] = ACTIONS(5745),
    [anon_sym_ELSE] = ACTIONS(5745),
    [anon_sym_Else] = ACTIONS(5745),
    [anon_sym_case] = ACTIONS(5745),
    [anon_sym_CASE] = ACTIONS(5745),
    [anon_sym_Case] = ACTIONS(5745),
    [anon_sym_for] = ACTIONS(5745),
    [anon_sym_FOR] = ACTIONS(5745),
    [anon_sym_For] = ACTIONS(5745),
    [anon_sym_foreach] = ACTIONS(5745),
    [anon_sym_FOREACH] = ACTIONS(5745),
    [anon_sym_Foreach] = ACTIONS(5745),
    [anon_sym_while] = ACTIONS(5745),
    [anon_sym_WHILE] = ACTIONS(5745),
    [anon_sym_While] = ACTIONS(5745),
    [anon_sym_repeat] = ACTIONS(5745),
    [anon_sym_REPEAT] = ACTIONS(5745),
    [anon_sym_Repeat] = ACTIONS(5745),
    [anon_sym_until] = ACTIONS(5745),
    [anon_sym_UNTIL] = ACTIONS(5745),
    [anon_sym_Until] = ACTIONS(5745),
    [anon_sym_exit] = ACTIONS(5745),
    [anon_sym_EXIT] = ACTIONS(5745),
    [anon_sym_Exit] = ACTIONS(5745),
    [anon_sym_continue] = ACTIONS(5745),
    [anon_sym_CONTINUE] = ACTIONS(5745),
    [anon_sym_Continue] = ACTIONS(5745),
    [anon_sym_break] = ACTIONS(5745),
    [anon_sym_BREAK] = ACTIONS(5745),
    [anon_sym_Break] = ACTIONS(5745),
    [anon_sym_with] = ACTIONS(5745),
    [anon_sym_WITH] = ACTIONS(5745),
    [anon_sym_With] = ACTIONS(5745),
    [sym_asserterror_keyword] = ACTIONS(5747),
    [sym_page_keyword] = ACTIONS(5745),
    [anon_sym_codeunit] = ACTIONS(5745),
    [anon_sym_CODEUNIT] = ACTIONS(5745),
    [anon_sym_Codeunit] = ACTIONS(5745),
    [anon_sym_CodeUnit] = ACTIONS(5745),
    [anon_sym_COdeunit] = ACTIONS(5745),
    [anon_sym_codeUnit] = ACTIONS(5745),
    [sym_report_keyword] = ACTIONS(5745),
    [sym_query_keyword] = ACTIONS(5745),
    [anon_sym_xmlport] = ACTIONS(5745),
    [anon_sym_XMLPORT] = ACTIONS(5745),
    [anon_sym_Xmlport] = ACTIONS(5745),
    [anon_sym_XMLport] = ACTIONS(5745),
    [anon_sym_XMLPort] = ACTIONS(5745),
    [anon_sym_XmlPort] = ACTIONS(5745),
    [anon_sym_enum] = ACTIONS(5745),
    [anon_sym_ENUM] = ACTIONS(5745),
    [anon_sym_Enum] = ACTIONS(5745),
    [anon_sym_eNUM] = ACTIONS(5745),
    [anon_sym_eNum] = ACTIONS(5745),
    [anon_sym_ENum] = ACTIONS(5745),
    [sym_quoted_identifier] = ACTIONS(5747),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5747),
    [sym_verbatim_string] = ACTIONS(5747),
    [sym_integer] = ACTIONS(5745),
    [sym_continue_as_identifier] = ACTIONS(5747),
    [sym_preproc_open] = ACTIONS(5747),
  },
  [STATE(3023)] = {
    [sym_identifier] = ACTIONS(5749),
    [anon_sym_SEMI] = ACTIONS(5751),
    [anon_sym_DASH] = ACTIONS(5751),
    [aux_sym_boolean_token1] = ACTIONS(5749),
    [aux_sym_boolean_token2] = ACTIONS(5749),
    [sym_decimal] = ACTIONS(5749),
    [anon_sym_LPAREN] = ACTIONS(5751),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5749),
    [anon_sym_LBRACK] = ACTIONS(5751),
    [aux_sym_record_type_token1] = ACTIONS(5749),
    [aux_sym_basic_type_token21] = ACTIONS(5749),
    [aux_sym_basic_type_token22] = ACTIONS(5749),
    [aux_sym_basic_type_token48] = ACTIONS(5749),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5749),
    [anon_sym_POUNDif] = ACTIONS(5751),
    [anon_sym_POUNDIF] = ACTIONS(5751),
    [anon_sym_POUNDIf] = ACTIONS(5751),
    [anon_sym_not] = ACTIONS(5749),
    [anon_sym_NOT] = ACTIONS(5749),
    [anon_sym_Not] = ACTIONS(5749),
    [anon_sym_POUNDelse] = ACTIONS(5751),
    [anon_sym_POUNDELSE] = ACTIONS(5751),
    [anon_sym_POUNDElse] = ACTIONS(5751),
    [anon_sym_POUNDelse2] = ACTIONS(5751),
    [anon_sym_POUNDELSE2] = ACTIONS(5751),
    [anon_sym_POUNDElse2] = ACTIONS(5751),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5749),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5749),
    [anon_sym_PLUS] = ACTIONS(5751),
    [sym_datetime_literal] = ACTIONS(5751),
    [sym_date_literal] = ACTIONS(5749),
    [sym_time_literal] = ACTIONS(5749),
    [sym_biginteger_literal] = ACTIONS(5751),
    [anon_sym_if] = ACTIONS(5749),
    [anon_sym_IF] = ACTIONS(5749),
    [anon_sym_If] = ACTIONS(5749),
    [anon_sym_else] = ACTIONS(5749),
    [anon_sym_ELSE] = ACTIONS(5749),
    [anon_sym_Else] = ACTIONS(5749),
    [anon_sym_case] = ACTIONS(5749),
    [anon_sym_CASE] = ACTIONS(5749),
    [anon_sym_Case] = ACTIONS(5749),
    [anon_sym_for] = ACTIONS(5749),
    [anon_sym_FOR] = ACTIONS(5749),
    [anon_sym_For] = ACTIONS(5749),
    [anon_sym_foreach] = ACTIONS(5749),
    [anon_sym_FOREACH] = ACTIONS(5749),
    [anon_sym_Foreach] = ACTIONS(5749),
    [anon_sym_while] = ACTIONS(5749),
    [anon_sym_WHILE] = ACTIONS(5749),
    [anon_sym_While] = ACTIONS(5749),
    [anon_sym_repeat] = ACTIONS(5749),
    [anon_sym_REPEAT] = ACTIONS(5749),
    [anon_sym_Repeat] = ACTIONS(5749),
    [anon_sym_until] = ACTIONS(5749),
    [anon_sym_UNTIL] = ACTIONS(5749),
    [anon_sym_Until] = ACTIONS(5749),
    [anon_sym_exit] = ACTIONS(5749),
    [anon_sym_EXIT] = ACTIONS(5749),
    [anon_sym_Exit] = ACTIONS(5749),
    [anon_sym_continue] = ACTIONS(5749),
    [anon_sym_CONTINUE] = ACTIONS(5749),
    [anon_sym_Continue] = ACTIONS(5749),
    [anon_sym_break] = ACTIONS(5749),
    [anon_sym_BREAK] = ACTIONS(5749),
    [anon_sym_Break] = ACTIONS(5749),
    [anon_sym_with] = ACTIONS(5749),
    [anon_sym_WITH] = ACTIONS(5749),
    [anon_sym_With] = ACTIONS(5749),
    [sym_asserterror_keyword] = ACTIONS(5751),
    [sym_page_keyword] = ACTIONS(5749),
    [anon_sym_codeunit] = ACTIONS(5749),
    [anon_sym_CODEUNIT] = ACTIONS(5749),
    [anon_sym_Codeunit] = ACTIONS(5749),
    [anon_sym_CodeUnit] = ACTIONS(5749),
    [anon_sym_COdeunit] = ACTIONS(5749),
    [anon_sym_codeUnit] = ACTIONS(5749),
    [sym_report_keyword] = ACTIONS(5749),
    [sym_query_keyword] = ACTIONS(5749),
    [anon_sym_xmlport] = ACTIONS(5749),
    [anon_sym_XMLPORT] = ACTIONS(5749),
    [anon_sym_Xmlport] = ACTIONS(5749),
    [anon_sym_XMLport] = ACTIONS(5749),
    [anon_sym_XMLPort] = ACTIONS(5749),
    [anon_sym_XmlPort] = ACTIONS(5749),
    [anon_sym_enum] = ACTIONS(5749),
    [anon_sym_ENUM] = ACTIONS(5749),
    [anon_sym_Enum] = ACTIONS(5749),
    [anon_sym_eNUM] = ACTIONS(5749),
    [anon_sym_eNum] = ACTIONS(5749),
    [anon_sym_ENum] = ACTIONS(5749),
    [sym_quoted_identifier] = ACTIONS(5751),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5751),
    [sym_verbatim_string] = ACTIONS(5751),
    [sym_integer] = ACTIONS(5749),
    [sym_continue_as_identifier] = ACTIONS(5751),
    [sym_preproc_open] = ACTIONS(5751),
  },
  [STATE(3024)] = {
    [sym_identifier] = ACTIONS(5753),
    [anon_sym_SEMI] = ACTIONS(5755),
    [anon_sym_DASH] = ACTIONS(5755),
    [aux_sym_boolean_token1] = ACTIONS(5753),
    [aux_sym_boolean_token2] = ACTIONS(5753),
    [sym_decimal] = ACTIONS(5753),
    [anon_sym_LPAREN] = ACTIONS(5755),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5753),
    [anon_sym_LBRACK] = ACTIONS(5755),
    [aux_sym_record_type_token1] = ACTIONS(5753),
    [aux_sym_basic_type_token21] = ACTIONS(5753),
    [aux_sym_basic_type_token22] = ACTIONS(5753),
    [aux_sym_basic_type_token48] = ACTIONS(5753),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5753),
    [anon_sym_POUNDif] = ACTIONS(5755),
    [anon_sym_POUNDIF] = ACTIONS(5755),
    [anon_sym_POUNDIf] = ACTIONS(5755),
    [anon_sym_not] = ACTIONS(5753),
    [anon_sym_NOT] = ACTIONS(5753),
    [anon_sym_Not] = ACTIONS(5753),
    [anon_sym_POUNDelse] = ACTIONS(5755),
    [anon_sym_POUNDELSE] = ACTIONS(5755),
    [anon_sym_POUNDElse] = ACTIONS(5755),
    [anon_sym_POUNDelse2] = ACTIONS(5755),
    [anon_sym_POUNDELSE2] = ACTIONS(5755),
    [anon_sym_POUNDElse2] = ACTIONS(5755),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5753),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5753),
    [anon_sym_PLUS] = ACTIONS(5755),
    [sym_datetime_literal] = ACTIONS(5755),
    [sym_date_literal] = ACTIONS(5753),
    [sym_time_literal] = ACTIONS(5753),
    [sym_biginteger_literal] = ACTIONS(5755),
    [anon_sym_if] = ACTIONS(5753),
    [anon_sym_IF] = ACTIONS(5753),
    [anon_sym_If] = ACTIONS(5753),
    [anon_sym_else] = ACTIONS(5753),
    [anon_sym_ELSE] = ACTIONS(5753),
    [anon_sym_Else] = ACTIONS(5753),
    [anon_sym_case] = ACTIONS(5753),
    [anon_sym_CASE] = ACTIONS(5753),
    [anon_sym_Case] = ACTIONS(5753),
    [anon_sym_for] = ACTIONS(5753),
    [anon_sym_FOR] = ACTIONS(5753),
    [anon_sym_For] = ACTIONS(5753),
    [anon_sym_foreach] = ACTIONS(5753),
    [anon_sym_FOREACH] = ACTIONS(5753),
    [anon_sym_Foreach] = ACTIONS(5753),
    [anon_sym_while] = ACTIONS(5753),
    [anon_sym_WHILE] = ACTIONS(5753),
    [anon_sym_While] = ACTIONS(5753),
    [anon_sym_repeat] = ACTIONS(5753),
    [anon_sym_REPEAT] = ACTIONS(5753),
    [anon_sym_Repeat] = ACTIONS(5753),
    [anon_sym_until] = ACTIONS(5753),
    [anon_sym_UNTIL] = ACTIONS(5753),
    [anon_sym_Until] = ACTIONS(5753),
    [anon_sym_exit] = ACTIONS(5753),
    [anon_sym_EXIT] = ACTIONS(5753),
    [anon_sym_Exit] = ACTIONS(5753),
    [anon_sym_continue] = ACTIONS(5753),
    [anon_sym_CONTINUE] = ACTIONS(5753),
    [anon_sym_Continue] = ACTIONS(5753),
    [anon_sym_break] = ACTIONS(5753),
    [anon_sym_BREAK] = ACTIONS(5753),
    [anon_sym_Break] = ACTIONS(5753),
    [anon_sym_with] = ACTIONS(5753),
    [anon_sym_WITH] = ACTIONS(5753),
    [anon_sym_With] = ACTIONS(5753),
    [sym_asserterror_keyword] = ACTIONS(5755),
    [sym_page_keyword] = ACTIONS(5753),
    [anon_sym_codeunit] = ACTIONS(5753),
    [anon_sym_CODEUNIT] = ACTIONS(5753),
    [anon_sym_Codeunit] = ACTIONS(5753),
    [anon_sym_CodeUnit] = ACTIONS(5753),
    [anon_sym_COdeunit] = ACTIONS(5753),
    [anon_sym_codeUnit] = ACTIONS(5753),
    [sym_report_keyword] = ACTIONS(5753),
    [sym_query_keyword] = ACTIONS(5753),
    [anon_sym_xmlport] = ACTIONS(5753),
    [anon_sym_XMLPORT] = ACTIONS(5753),
    [anon_sym_Xmlport] = ACTIONS(5753),
    [anon_sym_XMLport] = ACTIONS(5753),
    [anon_sym_XMLPort] = ACTIONS(5753),
    [anon_sym_XmlPort] = ACTIONS(5753),
    [anon_sym_enum] = ACTIONS(5753),
    [anon_sym_ENUM] = ACTIONS(5753),
    [anon_sym_Enum] = ACTIONS(5753),
    [anon_sym_eNUM] = ACTIONS(5753),
    [anon_sym_eNum] = ACTIONS(5753),
    [anon_sym_ENum] = ACTIONS(5753),
    [sym_quoted_identifier] = ACTIONS(5755),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5755),
    [sym_verbatim_string] = ACTIONS(5755),
    [sym_integer] = ACTIONS(5753),
    [sym_continue_as_identifier] = ACTIONS(5755),
    [sym_preproc_open] = ACTIONS(5755),
  },
  [STATE(3025)] = {
    [sym_identifier] = ACTIONS(5757),
    [anon_sym_SEMI] = ACTIONS(5759),
    [anon_sym_DASH] = ACTIONS(5759),
    [aux_sym_boolean_token1] = ACTIONS(5757),
    [aux_sym_boolean_token2] = ACTIONS(5757),
    [sym_decimal] = ACTIONS(5757),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5757),
    [anon_sym_LBRACK] = ACTIONS(5759),
    [aux_sym_record_type_token1] = ACTIONS(5757),
    [aux_sym_basic_type_token21] = ACTIONS(5757),
    [aux_sym_basic_type_token22] = ACTIONS(5757),
    [aux_sym_basic_type_token48] = ACTIONS(5757),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5757),
    [anon_sym_POUNDif] = ACTIONS(5759),
    [anon_sym_POUNDIF] = ACTIONS(5759),
    [anon_sym_POUNDIf] = ACTIONS(5759),
    [anon_sym_not] = ACTIONS(5757),
    [anon_sym_NOT] = ACTIONS(5757),
    [anon_sym_Not] = ACTIONS(5757),
    [anon_sym_POUNDelse] = ACTIONS(5759),
    [anon_sym_POUNDELSE] = ACTIONS(5759),
    [anon_sym_POUNDElse] = ACTIONS(5759),
    [anon_sym_POUNDelse2] = ACTIONS(5759),
    [anon_sym_POUNDELSE2] = ACTIONS(5759),
    [anon_sym_POUNDElse2] = ACTIONS(5759),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5757),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5757),
    [anon_sym_PLUS] = ACTIONS(5759),
    [sym_datetime_literal] = ACTIONS(5759),
    [sym_date_literal] = ACTIONS(5757),
    [sym_time_literal] = ACTIONS(5757),
    [sym_biginteger_literal] = ACTIONS(5759),
    [anon_sym_if] = ACTIONS(5757),
    [anon_sym_IF] = ACTIONS(5757),
    [anon_sym_If] = ACTIONS(5757),
    [anon_sym_else] = ACTIONS(5757),
    [anon_sym_ELSE] = ACTIONS(5757),
    [anon_sym_Else] = ACTIONS(5757),
    [anon_sym_case] = ACTIONS(5757),
    [anon_sym_CASE] = ACTIONS(5757),
    [anon_sym_Case] = ACTIONS(5757),
    [anon_sym_for] = ACTIONS(5757),
    [anon_sym_FOR] = ACTIONS(5757),
    [anon_sym_For] = ACTIONS(5757),
    [anon_sym_foreach] = ACTIONS(5757),
    [anon_sym_FOREACH] = ACTIONS(5757),
    [anon_sym_Foreach] = ACTIONS(5757),
    [anon_sym_while] = ACTIONS(5757),
    [anon_sym_WHILE] = ACTIONS(5757),
    [anon_sym_While] = ACTIONS(5757),
    [anon_sym_repeat] = ACTIONS(5757),
    [anon_sym_REPEAT] = ACTIONS(5757),
    [anon_sym_Repeat] = ACTIONS(5757),
    [anon_sym_until] = ACTIONS(5757),
    [anon_sym_UNTIL] = ACTIONS(5757),
    [anon_sym_Until] = ACTIONS(5757),
    [anon_sym_exit] = ACTIONS(5757),
    [anon_sym_EXIT] = ACTIONS(5757),
    [anon_sym_Exit] = ACTIONS(5757),
    [anon_sym_continue] = ACTIONS(5757),
    [anon_sym_CONTINUE] = ACTIONS(5757),
    [anon_sym_Continue] = ACTIONS(5757),
    [anon_sym_break] = ACTIONS(5757),
    [anon_sym_BREAK] = ACTIONS(5757),
    [anon_sym_Break] = ACTIONS(5757),
    [anon_sym_with] = ACTIONS(5757),
    [anon_sym_WITH] = ACTIONS(5757),
    [anon_sym_With] = ACTIONS(5757),
    [sym_asserterror_keyword] = ACTIONS(5759),
    [sym_page_keyword] = ACTIONS(5757),
    [anon_sym_codeunit] = ACTIONS(5757),
    [anon_sym_CODEUNIT] = ACTIONS(5757),
    [anon_sym_Codeunit] = ACTIONS(5757),
    [anon_sym_CodeUnit] = ACTIONS(5757),
    [anon_sym_COdeunit] = ACTIONS(5757),
    [anon_sym_codeUnit] = ACTIONS(5757),
    [sym_report_keyword] = ACTIONS(5757),
    [sym_query_keyword] = ACTIONS(5757),
    [anon_sym_xmlport] = ACTIONS(5757),
    [anon_sym_XMLPORT] = ACTIONS(5757),
    [anon_sym_Xmlport] = ACTIONS(5757),
    [anon_sym_XMLport] = ACTIONS(5757),
    [anon_sym_XMLPort] = ACTIONS(5757),
    [anon_sym_XmlPort] = ACTIONS(5757),
    [anon_sym_enum] = ACTIONS(5757),
    [anon_sym_ENUM] = ACTIONS(5757),
    [anon_sym_Enum] = ACTIONS(5757),
    [anon_sym_eNUM] = ACTIONS(5757),
    [anon_sym_eNum] = ACTIONS(5757),
    [anon_sym_ENum] = ACTIONS(5757),
    [sym_quoted_identifier] = ACTIONS(5759),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5759),
    [sym_verbatim_string] = ACTIONS(5759),
    [sym_integer] = ACTIONS(5757),
    [sym_continue_as_identifier] = ACTIONS(5759),
    [sym_preproc_open] = ACTIONS(5759),
  },
  [STATE(3026)] = {
    [sym_identifier] = ACTIONS(5761),
    [anon_sym_SEMI] = ACTIONS(5763),
    [anon_sym_DASH] = ACTIONS(5763),
    [aux_sym_boolean_token1] = ACTIONS(5761),
    [aux_sym_boolean_token2] = ACTIONS(5761),
    [sym_decimal] = ACTIONS(5761),
    [anon_sym_LPAREN] = ACTIONS(5763),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5761),
    [anon_sym_LBRACK] = ACTIONS(5763),
    [aux_sym_record_type_token1] = ACTIONS(5761),
    [aux_sym_basic_type_token21] = ACTIONS(5761),
    [aux_sym_basic_type_token22] = ACTIONS(5761),
    [aux_sym_basic_type_token48] = ACTIONS(5761),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5761),
    [anon_sym_POUNDif] = ACTIONS(5763),
    [anon_sym_POUNDIF] = ACTIONS(5763),
    [anon_sym_POUNDIf] = ACTIONS(5763),
    [anon_sym_not] = ACTIONS(5761),
    [anon_sym_NOT] = ACTIONS(5761),
    [anon_sym_Not] = ACTIONS(5761),
    [anon_sym_POUNDelse] = ACTIONS(5763),
    [anon_sym_POUNDELSE] = ACTIONS(5763),
    [anon_sym_POUNDElse] = ACTIONS(5763),
    [anon_sym_POUNDelse2] = ACTIONS(5763),
    [anon_sym_POUNDELSE2] = ACTIONS(5763),
    [anon_sym_POUNDElse2] = ACTIONS(5763),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5761),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5761),
    [anon_sym_PLUS] = ACTIONS(5763),
    [sym_datetime_literal] = ACTIONS(5763),
    [sym_date_literal] = ACTIONS(5761),
    [sym_time_literal] = ACTIONS(5761),
    [sym_biginteger_literal] = ACTIONS(5763),
    [anon_sym_if] = ACTIONS(5761),
    [anon_sym_IF] = ACTIONS(5761),
    [anon_sym_If] = ACTIONS(5761),
    [anon_sym_else] = ACTIONS(5761),
    [anon_sym_ELSE] = ACTIONS(5761),
    [anon_sym_Else] = ACTIONS(5761),
    [anon_sym_case] = ACTIONS(5761),
    [anon_sym_CASE] = ACTIONS(5761),
    [anon_sym_Case] = ACTIONS(5761),
    [anon_sym_for] = ACTIONS(5761),
    [anon_sym_FOR] = ACTIONS(5761),
    [anon_sym_For] = ACTIONS(5761),
    [anon_sym_foreach] = ACTIONS(5761),
    [anon_sym_FOREACH] = ACTIONS(5761),
    [anon_sym_Foreach] = ACTIONS(5761),
    [anon_sym_while] = ACTIONS(5761),
    [anon_sym_WHILE] = ACTIONS(5761),
    [anon_sym_While] = ACTIONS(5761),
    [anon_sym_repeat] = ACTIONS(5761),
    [anon_sym_REPEAT] = ACTIONS(5761),
    [anon_sym_Repeat] = ACTIONS(5761),
    [anon_sym_until] = ACTIONS(5761),
    [anon_sym_UNTIL] = ACTIONS(5761),
    [anon_sym_Until] = ACTIONS(5761),
    [anon_sym_exit] = ACTIONS(5761),
    [anon_sym_EXIT] = ACTIONS(5761),
    [anon_sym_Exit] = ACTIONS(5761),
    [anon_sym_continue] = ACTIONS(5761),
    [anon_sym_CONTINUE] = ACTIONS(5761),
    [anon_sym_Continue] = ACTIONS(5761),
    [anon_sym_break] = ACTIONS(5761),
    [anon_sym_BREAK] = ACTIONS(5761),
    [anon_sym_Break] = ACTIONS(5761),
    [anon_sym_with] = ACTIONS(5761),
    [anon_sym_WITH] = ACTIONS(5761),
    [anon_sym_With] = ACTIONS(5761),
    [sym_asserterror_keyword] = ACTIONS(5763),
    [sym_page_keyword] = ACTIONS(5761),
    [anon_sym_codeunit] = ACTIONS(5761),
    [anon_sym_CODEUNIT] = ACTIONS(5761),
    [anon_sym_Codeunit] = ACTIONS(5761),
    [anon_sym_CodeUnit] = ACTIONS(5761),
    [anon_sym_COdeunit] = ACTIONS(5761),
    [anon_sym_codeUnit] = ACTIONS(5761),
    [sym_report_keyword] = ACTIONS(5761),
    [sym_query_keyword] = ACTIONS(5761),
    [anon_sym_xmlport] = ACTIONS(5761),
    [anon_sym_XMLPORT] = ACTIONS(5761),
    [anon_sym_Xmlport] = ACTIONS(5761),
    [anon_sym_XMLport] = ACTIONS(5761),
    [anon_sym_XMLPort] = ACTIONS(5761),
    [anon_sym_XmlPort] = ACTIONS(5761),
    [anon_sym_enum] = ACTIONS(5761),
    [anon_sym_ENUM] = ACTIONS(5761),
    [anon_sym_Enum] = ACTIONS(5761),
    [anon_sym_eNUM] = ACTIONS(5761),
    [anon_sym_eNum] = ACTIONS(5761),
    [anon_sym_ENum] = ACTIONS(5761),
    [sym_quoted_identifier] = ACTIONS(5763),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5763),
    [sym_verbatim_string] = ACTIONS(5763),
    [sym_integer] = ACTIONS(5761),
    [sym_continue_as_identifier] = ACTIONS(5763),
    [sym_preproc_open] = ACTIONS(5763),
  },
  [STATE(3027)] = {
    [sym_identifier] = ACTIONS(5765),
    [anon_sym_SEMI] = ACTIONS(5767),
    [anon_sym_DASH] = ACTIONS(5767),
    [aux_sym_boolean_token1] = ACTIONS(5765),
    [aux_sym_boolean_token2] = ACTIONS(5765),
    [sym_decimal] = ACTIONS(5765),
    [anon_sym_LPAREN] = ACTIONS(5767),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5765),
    [anon_sym_LBRACK] = ACTIONS(5767),
    [aux_sym_record_type_token1] = ACTIONS(5765),
    [aux_sym_basic_type_token21] = ACTIONS(5765),
    [aux_sym_basic_type_token22] = ACTIONS(5765),
    [aux_sym_basic_type_token48] = ACTIONS(5765),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5765),
    [anon_sym_POUNDif] = ACTIONS(5767),
    [anon_sym_POUNDIF] = ACTIONS(5767),
    [anon_sym_POUNDIf] = ACTIONS(5767),
    [anon_sym_not] = ACTIONS(5765),
    [anon_sym_NOT] = ACTIONS(5765),
    [anon_sym_Not] = ACTIONS(5765),
    [anon_sym_POUNDelse] = ACTIONS(5767),
    [anon_sym_POUNDELSE] = ACTIONS(5767),
    [anon_sym_POUNDElse] = ACTIONS(5767),
    [anon_sym_POUNDelse2] = ACTIONS(5767),
    [anon_sym_POUNDELSE2] = ACTIONS(5767),
    [anon_sym_POUNDElse2] = ACTIONS(5767),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5765),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5765),
    [anon_sym_PLUS] = ACTIONS(5767),
    [sym_datetime_literal] = ACTIONS(5767),
    [sym_date_literal] = ACTIONS(5765),
    [sym_time_literal] = ACTIONS(5765),
    [sym_biginteger_literal] = ACTIONS(5767),
    [anon_sym_if] = ACTIONS(5765),
    [anon_sym_IF] = ACTIONS(5765),
    [anon_sym_If] = ACTIONS(5765),
    [anon_sym_else] = ACTIONS(5765),
    [anon_sym_ELSE] = ACTIONS(5765),
    [anon_sym_Else] = ACTIONS(5765),
    [anon_sym_case] = ACTIONS(5765),
    [anon_sym_CASE] = ACTIONS(5765),
    [anon_sym_Case] = ACTIONS(5765),
    [anon_sym_for] = ACTIONS(5765),
    [anon_sym_FOR] = ACTIONS(5765),
    [anon_sym_For] = ACTIONS(5765),
    [anon_sym_foreach] = ACTIONS(5765),
    [anon_sym_FOREACH] = ACTIONS(5765),
    [anon_sym_Foreach] = ACTIONS(5765),
    [anon_sym_while] = ACTIONS(5765),
    [anon_sym_WHILE] = ACTIONS(5765),
    [anon_sym_While] = ACTIONS(5765),
    [anon_sym_repeat] = ACTIONS(5765),
    [anon_sym_REPEAT] = ACTIONS(5765),
    [anon_sym_Repeat] = ACTIONS(5765),
    [anon_sym_until] = ACTIONS(5765),
    [anon_sym_UNTIL] = ACTIONS(5765),
    [anon_sym_Until] = ACTIONS(5765),
    [anon_sym_exit] = ACTIONS(5765),
    [anon_sym_EXIT] = ACTIONS(5765),
    [anon_sym_Exit] = ACTIONS(5765),
    [anon_sym_continue] = ACTIONS(5765),
    [anon_sym_CONTINUE] = ACTIONS(5765),
    [anon_sym_Continue] = ACTIONS(5765),
    [anon_sym_break] = ACTIONS(5765),
    [anon_sym_BREAK] = ACTIONS(5765),
    [anon_sym_Break] = ACTIONS(5765),
    [anon_sym_with] = ACTIONS(5765),
    [anon_sym_WITH] = ACTIONS(5765),
    [anon_sym_With] = ACTIONS(5765),
    [sym_asserterror_keyword] = ACTIONS(5767),
    [sym_page_keyword] = ACTIONS(5765),
    [anon_sym_codeunit] = ACTIONS(5765),
    [anon_sym_CODEUNIT] = ACTIONS(5765),
    [anon_sym_Codeunit] = ACTIONS(5765),
    [anon_sym_CodeUnit] = ACTIONS(5765),
    [anon_sym_COdeunit] = ACTIONS(5765),
    [anon_sym_codeUnit] = ACTIONS(5765),
    [sym_report_keyword] = ACTIONS(5765),
    [sym_query_keyword] = ACTIONS(5765),
    [anon_sym_xmlport] = ACTIONS(5765),
    [anon_sym_XMLPORT] = ACTIONS(5765),
    [anon_sym_Xmlport] = ACTIONS(5765),
    [anon_sym_XMLport] = ACTIONS(5765),
    [anon_sym_XMLPort] = ACTIONS(5765),
    [anon_sym_XmlPort] = ACTIONS(5765),
    [anon_sym_enum] = ACTIONS(5765),
    [anon_sym_ENUM] = ACTIONS(5765),
    [anon_sym_Enum] = ACTIONS(5765),
    [anon_sym_eNUM] = ACTIONS(5765),
    [anon_sym_eNum] = ACTIONS(5765),
    [anon_sym_ENum] = ACTIONS(5765),
    [sym_quoted_identifier] = ACTIONS(5767),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5767),
    [sym_verbatim_string] = ACTIONS(5767),
    [sym_integer] = ACTIONS(5765),
    [sym_continue_as_identifier] = ACTIONS(5767),
    [sym_preproc_open] = ACTIONS(5767),
  },
  [STATE(3028)] = {
    [sym_identifier] = ACTIONS(5769),
    [anon_sym_SEMI] = ACTIONS(5771),
    [anon_sym_DASH] = ACTIONS(5771),
    [aux_sym_boolean_token1] = ACTIONS(5769),
    [aux_sym_boolean_token2] = ACTIONS(5769),
    [sym_decimal] = ACTIONS(5769),
    [anon_sym_LPAREN] = ACTIONS(5771),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5769),
    [anon_sym_LBRACK] = ACTIONS(5771),
    [aux_sym_record_type_token1] = ACTIONS(5769),
    [aux_sym_basic_type_token21] = ACTIONS(5769),
    [aux_sym_basic_type_token22] = ACTIONS(5769),
    [aux_sym_basic_type_token48] = ACTIONS(5769),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5769),
    [anon_sym_POUNDif] = ACTIONS(5771),
    [anon_sym_POUNDIF] = ACTIONS(5771),
    [anon_sym_POUNDIf] = ACTIONS(5771),
    [anon_sym_not] = ACTIONS(5769),
    [anon_sym_NOT] = ACTIONS(5769),
    [anon_sym_Not] = ACTIONS(5769),
    [anon_sym_POUNDelse] = ACTIONS(5771),
    [anon_sym_POUNDELSE] = ACTIONS(5771),
    [anon_sym_POUNDElse] = ACTIONS(5771),
    [anon_sym_POUNDelse2] = ACTIONS(5771),
    [anon_sym_POUNDELSE2] = ACTIONS(5771),
    [anon_sym_POUNDElse2] = ACTIONS(5771),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5769),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5769),
    [anon_sym_PLUS] = ACTIONS(5771),
    [sym_datetime_literal] = ACTIONS(5771),
    [sym_date_literal] = ACTIONS(5769),
    [sym_time_literal] = ACTIONS(5769),
    [sym_biginteger_literal] = ACTIONS(5771),
    [anon_sym_if] = ACTIONS(5769),
    [anon_sym_IF] = ACTIONS(5769),
    [anon_sym_If] = ACTIONS(5769),
    [anon_sym_else] = ACTIONS(5769),
    [anon_sym_ELSE] = ACTIONS(5769),
    [anon_sym_Else] = ACTIONS(5769),
    [anon_sym_case] = ACTIONS(5769),
    [anon_sym_CASE] = ACTIONS(5769),
    [anon_sym_Case] = ACTIONS(5769),
    [anon_sym_for] = ACTIONS(5769),
    [anon_sym_FOR] = ACTIONS(5769),
    [anon_sym_For] = ACTIONS(5769),
    [anon_sym_foreach] = ACTIONS(5769),
    [anon_sym_FOREACH] = ACTIONS(5769),
    [anon_sym_Foreach] = ACTIONS(5769),
    [anon_sym_while] = ACTIONS(5769),
    [anon_sym_WHILE] = ACTIONS(5769),
    [anon_sym_While] = ACTIONS(5769),
    [anon_sym_repeat] = ACTIONS(5769),
    [anon_sym_REPEAT] = ACTIONS(5769),
    [anon_sym_Repeat] = ACTIONS(5769),
    [anon_sym_until] = ACTIONS(5769),
    [anon_sym_UNTIL] = ACTIONS(5769),
    [anon_sym_Until] = ACTIONS(5769),
    [anon_sym_exit] = ACTIONS(5769),
    [anon_sym_EXIT] = ACTIONS(5769),
    [anon_sym_Exit] = ACTIONS(5769),
    [anon_sym_continue] = ACTIONS(5769),
    [anon_sym_CONTINUE] = ACTIONS(5769),
    [anon_sym_Continue] = ACTIONS(5769),
    [anon_sym_break] = ACTIONS(5769),
    [anon_sym_BREAK] = ACTIONS(5769),
    [anon_sym_Break] = ACTIONS(5769),
    [anon_sym_with] = ACTIONS(5769),
    [anon_sym_WITH] = ACTIONS(5769),
    [anon_sym_With] = ACTIONS(5769),
    [sym_asserterror_keyword] = ACTIONS(5771),
    [sym_page_keyword] = ACTIONS(5769),
    [anon_sym_codeunit] = ACTIONS(5769),
    [anon_sym_CODEUNIT] = ACTIONS(5769),
    [anon_sym_Codeunit] = ACTIONS(5769),
    [anon_sym_CodeUnit] = ACTIONS(5769),
    [anon_sym_COdeunit] = ACTIONS(5769),
    [anon_sym_codeUnit] = ACTIONS(5769),
    [sym_report_keyword] = ACTIONS(5769),
    [sym_query_keyword] = ACTIONS(5769),
    [anon_sym_xmlport] = ACTIONS(5769),
    [anon_sym_XMLPORT] = ACTIONS(5769),
    [anon_sym_Xmlport] = ACTIONS(5769),
    [anon_sym_XMLport] = ACTIONS(5769),
    [anon_sym_XMLPort] = ACTIONS(5769),
    [anon_sym_XmlPort] = ACTIONS(5769),
    [anon_sym_enum] = ACTIONS(5769),
    [anon_sym_ENUM] = ACTIONS(5769),
    [anon_sym_Enum] = ACTIONS(5769),
    [anon_sym_eNUM] = ACTIONS(5769),
    [anon_sym_eNum] = ACTIONS(5769),
    [anon_sym_ENum] = ACTIONS(5769),
    [sym_quoted_identifier] = ACTIONS(5771),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5771),
    [sym_verbatim_string] = ACTIONS(5771),
    [sym_integer] = ACTIONS(5769),
    [sym_continue_as_identifier] = ACTIONS(5771),
    [sym_preproc_open] = ACTIONS(5771),
  },
  [STATE(3029)] = {
    [sym_identifier] = ACTIONS(5773),
    [anon_sym_SEMI] = ACTIONS(5775),
    [anon_sym_DASH] = ACTIONS(5775),
    [aux_sym_boolean_token1] = ACTIONS(5773),
    [aux_sym_boolean_token2] = ACTIONS(5773),
    [sym_decimal] = ACTIONS(5773),
    [anon_sym_LPAREN] = ACTIONS(5775),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5773),
    [anon_sym_LBRACK] = ACTIONS(5775),
    [aux_sym_record_type_token1] = ACTIONS(5773),
    [aux_sym_basic_type_token21] = ACTIONS(5773),
    [aux_sym_basic_type_token22] = ACTIONS(5773),
    [aux_sym_basic_type_token48] = ACTIONS(5773),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5773),
    [anon_sym_POUNDif] = ACTIONS(5775),
    [anon_sym_POUNDIF] = ACTIONS(5775),
    [anon_sym_POUNDIf] = ACTIONS(5775),
    [anon_sym_not] = ACTIONS(5773),
    [anon_sym_NOT] = ACTIONS(5773),
    [anon_sym_Not] = ACTIONS(5773),
    [anon_sym_POUNDelse] = ACTIONS(5775),
    [anon_sym_POUNDELSE] = ACTIONS(5775),
    [anon_sym_POUNDElse] = ACTIONS(5775),
    [anon_sym_POUNDelse2] = ACTIONS(5775),
    [anon_sym_POUNDELSE2] = ACTIONS(5775),
    [anon_sym_POUNDElse2] = ACTIONS(5775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5773),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5773),
    [anon_sym_PLUS] = ACTIONS(5775),
    [sym_datetime_literal] = ACTIONS(5775),
    [sym_date_literal] = ACTIONS(5773),
    [sym_time_literal] = ACTIONS(5773),
    [sym_biginteger_literal] = ACTIONS(5775),
    [anon_sym_if] = ACTIONS(5773),
    [anon_sym_IF] = ACTIONS(5773),
    [anon_sym_If] = ACTIONS(5773),
    [anon_sym_else] = ACTIONS(5773),
    [anon_sym_ELSE] = ACTIONS(5773),
    [anon_sym_Else] = ACTIONS(5773),
    [anon_sym_case] = ACTIONS(5773),
    [anon_sym_CASE] = ACTIONS(5773),
    [anon_sym_Case] = ACTIONS(5773),
    [anon_sym_for] = ACTIONS(5773),
    [anon_sym_FOR] = ACTIONS(5773),
    [anon_sym_For] = ACTIONS(5773),
    [anon_sym_foreach] = ACTIONS(5773),
    [anon_sym_FOREACH] = ACTIONS(5773),
    [anon_sym_Foreach] = ACTIONS(5773),
    [anon_sym_while] = ACTIONS(5773),
    [anon_sym_WHILE] = ACTIONS(5773),
    [anon_sym_While] = ACTIONS(5773),
    [anon_sym_repeat] = ACTIONS(5773),
    [anon_sym_REPEAT] = ACTIONS(5773),
    [anon_sym_Repeat] = ACTIONS(5773),
    [anon_sym_until] = ACTIONS(5773),
    [anon_sym_UNTIL] = ACTIONS(5773),
    [anon_sym_Until] = ACTIONS(5773),
    [anon_sym_exit] = ACTIONS(5773),
    [anon_sym_EXIT] = ACTIONS(5773),
    [anon_sym_Exit] = ACTIONS(5773),
    [anon_sym_continue] = ACTIONS(5773),
    [anon_sym_CONTINUE] = ACTIONS(5773),
    [anon_sym_Continue] = ACTIONS(5773),
    [anon_sym_break] = ACTIONS(5773),
    [anon_sym_BREAK] = ACTIONS(5773),
    [anon_sym_Break] = ACTIONS(5773),
    [anon_sym_with] = ACTIONS(5773),
    [anon_sym_WITH] = ACTIONS(5773),
    [anon_sym_With] = ACTIONS(5773),
    [sym_asserterror_keyword] = ACTIONS(5775),
    [sym_page_keyword] = ACTIONS(5773),
    [anon_sym_codeunit] = ACTIONS(5773),
    [anon_sym_CODEUNIT] = ACTIONS(5773),
    [anon_sym_Codeunit] = ACTIONS(5773),
    [anon_sym_CodeUnit] = ACTIONS(5773),
    [anon_sym_COdeunit] = ACTIONS(5773),
    [anon_sym_codeUnit] = ACTIONS(5773),
    [sym_report_keyword] = ACTIONS(5773),
    [sym_query_keyword] = ACTIONS(5773),
    [anon_sym_xmlport] = ACTIONS(5773),
    [anon_sym_XMLPORT] = ACTIONS(5773),
    [anon_sym_Xmlport] = ACTIONS(5773),
    [anon_sym_XMLport] = ACTIONS(5773),
    [anon_sym_XMLPort] = ACTIONS(5773),
    [anon_sym_XmlPort] = ACTIONS(5773),
    [anon_sym_enum] = ACTIONS(5773),
    [anon_sym_ENUM] = ACTIONS(5773),
    [anon_sym_Enum] = ACTIONS(5773),
    [anon_sym_eNUM] = ACTIONS(5773),
    [anon_sym_eNum] = ACTIONS(5773),
    [anon_sym_ENum] = ACTIONS(5773),
    [sym_quoted_identifier] = ACTIONS(5775),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5775),
    [sym_verbatim_string] = ACTIONS(5775),
    [sym_integer] = ACTIONS(5773),
    [sym_continue_as_identifier] = ACTIONS(5775),
    [sym_preproc_open] = ACTIONS(5775),
  },
  [STATE(3030)] = {
    [sym_identifier] = ACTIONS(5777),
    [anon_sym_SEMI] = ACTIONS(5779),
    [anon_sym_DASH] = ACTIONS(5779),
    [aux_sym_boolean_token1] = ACTIONS(5777),
    [aux_sym_boolean_token2] = ACTIONS(5777),
    [sym_decimal] = ACTIONS(5777),
    [anon_sym_LPAREN] = ACTIONS(5779),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5777),
    [anon_sym_LBRACK] = ACTIONS(5779),
    [aux_sym_record_type_token1] = ACTIONS(5777),
    [aux_sym_basic_type_token21] = ACTIONS(5777),
    [aux_sym_basic_type_token22] = ACTIONS(5777),
    [aux_sym_basic_type_token48] = ACTIONS(5777),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5777),
    [anon_sym_POUNDif] = ACTIONS(5779),
    [anon_sym_POUNDIF] = ACTIONS(5779),
    [anon_sym_POUNDIf] = ACTIONS(5779),
    [anon_sym_not] = ACTIONS(5777),
    [anon_sym_NOT] = ACTIONS(5777),
    [anon_sym_Not] = ACTIONS(5777),
    [anon_sym_POUNDelse] = ACTIONS(5779),
    [anon_sym_POUNDELSE] = ACTIONS(5779),
    [anon_sym_POUNDElse] = ACTIONS(5779),
    [anon_sym_POUNDelse2] = ACTIONS(5779),
    [anon_sym_POUNDELSE2] = ACTIONS(5779),
    [anon_sym_POUNDElse2] = ACTIONS(5779),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5777),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5777),
    [anon_sym_PLUS] = ACTIONS(5779),
    [sym_datetime_literal] = ACTIONS(5779),
    [sym_date_literal] = ACTIONS(5777),
    [sym_time_literal] = ACTIONS(5777),
    [sym_biginteger_literal] = ACTIONS(5779),
    [anon_sym_if] = ACTIONS(5777),
    [anon_sym_IF] = ACTIONS(5777),
    [anon_sym_If] = ACTIONS(5777),
    [anon_sym_else] = ACTIONS(5777),
    [anon_sym_ELSE] = ACTIONS(5777),
    [anon_sym_Else] = ACTIONS(5777),
    [anon_sym_case] = ACTIONS(5777),
    [anon_sym_CASE] = ACTIONS(5777),
    [anon_sym_Case] = ACTIONS(5777),
    [anon_sym_for] = ACTIONS(5777),
    [anon_sym_FOR] = ACTIONS(5777),
    [anon_sym_For] = ACTIONS(5777),
    [anon_sym_foreach] = ACTIONS(5777),
    [anon_sym_FOREACH] = ACTIONS(5777),
    [anon_sym_Foreach] = ACTIONS(5777),
    [anon_sym_while] = ACTIONS(5777),
    [anon_sym_WHILE] = ACTIONS(5777),
    [anon_sym_While] = ACTIONS(5777),
    [anon_sym_repeat] = ACTIONS(5777),
    [anon_sym_REPEAT] = ACTIONS(5777),
    [anon_sym_Repeat] = ACTIONS(5777),
    [anon_sym_until] = ACTIONS(5777),
    [anon_sym_UNTIL] = ACTIONS(5777),
    [anon_sym_Until] = ACTIONS(5777),
    [anon_sym_exit] = ACTIONS(5777),
    [anon_sym_EXIT] = ACTIONS(5777),
    [anon_sym_Exit] = ACTIONS(5777),
    [anon_sym_continue] = ACTIONS(5777),
    [anon_sym_CONTINUE] = ACTIONS(5777),
    [anon_sym_Continue] = ACTIONS(5777),
    [anon_sym_break] = ACTIONS(5777),
    [anon_sym_BREAK] = ACTIONS(5777),
    [anon_sym_Break] = ACTIONS(5777),
    [anon_sym_with] = ACTIONS(5777),
    [anon_sym_WITH] = ACTIONS(5777),
    [anon_sym_With] = ACTIONS(5777),
    [sym_asserterror_keyword] = ACTIONS(5779),
    [sym_page_keyword] = ACTIONS(5777),
    [anon_sym_codeunit] = ACTIONS(5777),
    [anon_sym_CODEUNIT] = ACTIONS(5777),
    [anon_sym_Codeunit] = ACTIONS(5777),
    [anon_sym_CodeUnit] = ACTIONS(5777),
    [anon_sym_COdeunit] = ACTIONS(5777),
    [anon_sym_codeUnit] = ACTIONS(5777),
    [sym_report_keyword] = ACTIONS(5777),
    [sym_query_keyword] = ACTIONS(5777),
    [anon_sym_xmlport] = ACTIONS(5777),
    [anon_sym_XMLPORT] = ACTIONS(5777),
    [anon_sym_Xmlport] = ACTIONS(5777),
    [anon_sym_XMLport] = ACTIONS(5777),
    [anon_sym_XMLPort] = ACTIONS(5777),
    [anon_sym_XmlPort] = ACTIONS(5777),
    [anon_sym_enum] = ACTIONS(5777),
    [anon_sym_ENUM] = ACTIONS(5777),
    [anon_sym_Enum] = ACTIONS(5777),
    [anon_sym_eNUM] = ACTIONS(5777),
    [anon_sym_eNum] = ACTIONS(5777),
    [anon_sym_ENum] = ACTIONS(5777),
    [sym_quoted_identifier] = ACTIONS(5779),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5779),
    [sym_verbatim_string] = ACTIONS(5779),
    [sym_integer] = ACTIONS(5777),
    [sym_continue_as_identifier] = ACTIONS(5779),
    [sym_preproc_open] = ACTIONS(5779),
  },
  [STATE(3031)] = {
    [sym_identifier] = ACTIONS(5781),
    [anon_sym_SEMI] = ACTIONS(5783),
    [anon_sym_DASH] = ACTIONS(5783),
    [aux_sym_boolean_token1] = ACTIONS(5781),
    [aux_sym_boolean_token2] = ACTIONS(5781),
    [sym_decimal] = ACTIONS(5781),
    [anon_sym_LPAREN] = ACTIONS(5783),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5781),
    [anon_sym_LBRACK] = ACTIONS(5783),
    [aux_sym_record_type_token1] = ACTIONS(5781),
    [aux_sym_basic_type_token21] = ACTIONS(5781),
    [aux_sym_basic_type_token22] = ACTIONS(5781),
    [aux_sym_basic_type_token48] = ACTIONS(5781),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5781),
    [anon_sym_POUNDif] = ACTIONS(5783),
    [anon_sym_POUNDIF] = ACTIONS(5783),
    [anon_sym_POUNDIf] = ACTIONS(5783),
    [anon_sym_not] = ACTIONS(5781),
    [anon_sym_NOT] = ACTIONS(5781),
    [anon_sym_Not] = ACTIONS(5781),
    [anon_sym_POUNDelse] = ACTIONS(5783),
    [anon_sym_POUNDELSE] = ACTIONS(5783),
    [anon_sym_POUNDElse] = ACTIONS(5783),
    [anon_sym_POUNDelse2] = ACTIONS(5783),
    [anon_sym_POUNDELSE2] = ACTIONS(5783),
    [anon_sym_POUNDElse2] = ACTIONS(5783),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5781),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5781),
    [anon_sym_PLUS] = ACTIONS(5783),
    [sym_datetime_literal] = ACTIONS(5783),
    [sym_date_literal] = ACTIONS(5781),
    [sym_time_literal] = ACTIONS(5781),
    [sym_biginteger_literal] = ACTIONS(5783),
    [anon_sym_if] = ACTIONS(5781),
    [anon_sym_IF] = ACTIONS(5781),
    [anon_sym_If] = ACTIONS(5781),
    [anon_sym_else] = ACTIONS(5781),
    [anon_sym_ELSE] = ACTIONS(5781),
    [anon_sym_Else] = ACTIONS(5781),
    [anon_sym_case] = ACTIONS(5781),
    [anon_sym_CASE] = ACTIONS(5781),
    [anon_sym_Case] = ACTIONS(5781),
    [anon_sym_for] = ACTIONS(5781),
    [anon_sym_FOR] = ACTIONS(5781),
    [anon_sym_For] = ACTIONS(5781),
    [anon_sym_foreach] = ACTIONS(5781),
    [anon_sym_FOREACH] = ACTIONS(5781),
    [anon_sym_Foreach] = ACTIONS(5781),
    [anon_sym_while] = ACTIONS(5781),
    [anon_sym_WHILE] = ACTIONS(5781),
    [anon_sym_While] = ACTIONS(5781),
    [anon_sym_repeat] = ACTIONS(5781),
    [anon_sym_REPEAT] = ACTIONS(5781),
    [anon_sym_Repeat] = ACTIONS(5781),
    [anon_sym_until] = ACTIONS(5781),
    [anon_sym_UNTIL] = ACTIONS(5781),
    [anon_sym_Until] = ACTIONS(5781),
    [anon_sym_exit] = ACTIONS(5781),
    [anon_sym_EXIT] = ACTIONS(5781),
    [anon_sym_Exit] = ACTIONS(5781),
    [anon_sym_continue] = ACTIONS(5781),
    [anon_sym_CONTINUE] = ACTIONS(5781),
    [anon_sym_Continue] = ACTIONS(5781),
    [anon_sym_break] = ACTIONS(5781),
    [anon_sym_BREAK] = ACTIONS(5781),
    [anon_sym_Break] = ACTIONS(5781),
    [anon_sym_with] = ACTIONS(5781),
    [anon_sym_WITH] = ACTIONS(5781),
    [anon_sym_With] = ACTIONS(5781),
    [sym_asserterror_keyword] = ACTIONS(5783),
    [sym_page_keyword] = ACTIONS(5781),
    [anon_sym_codeunit] = ACTIONS(5781),
    [anon_sym_CODEUNIT] = ACTIONS(5781),
    [anon_sym_Codeunit] = ACTIONS(5781),
    [anon_sym_CodeUnit] = ACTIONS(5781),
    [anon_sym_COdeunit] = ACTIONS(5781),
    [anon_sym_codeUnit] = ACTIONS(5781),
    [sym_report_keyword] = ACTIONS(5781),
    [sym_query_keyword] = ACTIONS(5781),
    [anon_sym_xmlport] = ACTIONS(5781),
    [anon_sym_XMLPORT] = ACTIONS(5781),
    [anon_sym_Xmlport] = ACTIONS(5781),
    [anon_sym_XMLport] = ACTIONS(5781),
    [anon_sym_XMLPort] = ACTIONS(5781),
    [anon_sym_XmlPort] = ACTIONS(5781),
    [anon_sym_enum] = ACTIONS(5781),
    [anon_sym_ENUM] = ACTIONS(5781),
    [anon_sym_Enum] = ACTIONS(5781),
    [anon_sym_eNUM] = ACTIONS(5781),
    [anon_sym_eNum] = ACTIONS(5781),
    [anon_sym_ENum] = ACTIONS(5781),
    [sym_quoted_identifier] = ACTIONS(5783),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5783),
    [sym_verbatim_string] = ACTIONS(5783),
    [sym_integer] = ACTIONS(5781),
    [sym_continue_as_identifier] = ACTIONS(5783),
    [sym_preproc_open] = ACTIONS(5783),
  },
  [STATE(3032)] = {
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(6002),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [anon_sym_POUNDelif] = ACTIONS(6002),
    [anon_sym_POUNDELIF] = ACTIONS(6002),
    [anon_sym_POUNDElif] = ACTIONS(6002),
    [anon_sym_POUNDelse] = ACTIONS(6002),
    [anon_sym_POUNDELSE] = ACTIONS(6002),
    [anon_sym_POUNDElse] = ACTIONS(6002),
    [anon_sym_POUNDelse2] = ACTIONS(6002),
    [anon_sym_POUNDELSE2] = ACTIONS(6002),
    [anon_sym_POUNDElse2] = ACTIONS(6002),
    [anon_sym_POUNDendif] = ACTIONS(6002),
    [anon_sym_POUNDENDIF] = ACTIONS(6002),
    [anon_sym_POUNDEndif] = ACTIONS(6002),
    [anon_sym_POUNDendif2] = ACTIONS(6002),
    [anon_sym_POUNDENDIF2] = ACTIONS(6002),
    [anon_sym_POUNDEndif2] = ACTIONS(6002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_close] = ACTIONS(6002),
  },
  [STATE(3033)] = {
    [sym_identifier] = ACTIONS(5795),
    [anon_sym_SEMI] = ACTIONS(5797),
    [anon_sym_DASH] = ACTIONS(5797),
    [aux_sym_boolean_token1] = ACTIONS(5795),
    [aux_sym_boolean_token2] = ACTIONS(5795),
    [sym_decimal] = ACTIONS(5795),
    [anon_sym_LPAREN] = ACTIONS(5797),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5795),
    [anon_sym_LBRACK] = ACTIONS(5797),
    [aux_sym_record_type_token1] = ACTIONS(5795),
    [aux_sym_basic_type_token21] = ACTIONS(5795),
    [aux_sym_basic_type_token22] = ACTIONS(5795),
    [aux_sym_basic_type_token48] = ACTIONS(5795),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5795),
    [anon_sym_POUNDif] = ACTIONS(5797),
    [anon_sym_POUNDIF] = ACTIONS(5797),
    [anon_sym_POUNDIf] = ACTIONS(5797),
    [anon_sym_not] = ACTIONS(5795),
    [anon_sym_NOT] = ACTIONS(5795),
    [anon_sym_Not] = ACTIONS(5795),
    [anon_sym_POUNDelse] = ACTIONS(5797),
    [anon_sym_POUNDELSE] = ACTIONS(5797),
    [anon_sym_POUNDElse] = ACTIONS(5797),
    [anon_sym_POUNDelse2] = ACTIONS(5797),
    [anon_sym_POUNDELSE2] = ACTIONS(5797),
    [anon_sym_POUNDElse2] = ACTIONS(5797),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5795),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5795),
    [anon_sym_PLUS] = ACTIONS(5797),
    [sym_datetime_literal] = ACTIONS(5797),
    [sym_date_literal] = ACTIONS(5795),
    [sym_time_literal] = ACTIONS(5795),
    [sym_biginteger_literal] = ACTIONS(5797),
    [anon_sym_if] = ACTIONS(5795),
    [anon_sym_IF] = ACTIONS(5795),
    [anon_sym_If] = ACTIONS(5795),
    [anon_sym_else] = ACTIONS(5795),
    [anon_sym_ELSE] = ACTIONS(5795),
    [anon_sym_Else] = ACTIONS(5795),
    [anon_sym_case] = ACTIONS(5795),
    [anon_sym_CASE] = ACTIONS(5795),
    [anon_sym_Case] = ACTIONS(5795),
    [anon_sym_for] = ACTIONS(5795),
    [anon_sym_FOR] = ACTIONS(5795),
    [anon_sym_For] = ACTIONS(5795),
    [anon_sym_foreach] = ACTIONS(5795),
    [anon_sym_FOREACH] = ACTIONS(5795),
    [anon_sym_Foreach] = ACTIONS(5795),
    [anon_sym_while] = ACTIONS(5795),
    [anon_sym_WHILE] = ACTIONS(5795),
    [anon_sym_While] = ACTIONS(5795),
    [anon_sym_repeat] = ACTIONS(5795),
    [anon_sym_REPEAT] = ACTIONS(5795),
    [anon_sym_Repeat] = ACTIONS(5795),
    [anon_sym_until] = ACTIONS(5795),
    [anon_sym_UNTIL] = ACTIONS(5795),
    [anon_sym_Until] = ACTIONS(5795),
    [anon_sym_exit] = ACTIONS(5795),
    [anon_sym_EXIT] = ACTIONS(5795),
    [anon_sym_Exit] = ACTIONS(5795),
    [anon_sym_continue] = ACTIONS(5795),
    [anon_sym_CONTINUE] = ACTIONS(5795),
    [anon_sym_Continue] = ACTIONS(5795),
    [anon_sym_break] = ACTIONS(5795),
    [anon_sym_BREAK] = ACTIONS(5795),
    [anon_sym_Break] = ACTIONS(5795),
    [anon_sym_with] = ACTIONS(5795),
    [anon_sym_WITH] = ACTIONS(5795),
    [anon_sym_With] = ACTIONS(5795),
    [sym_asserterror_keyword] = ACTIONS(5797),
    [sym_page_keyword] = ACTIONS(5795),
    [anon_sym_codeunit] = ACTIONS(5795),
    [anon_sym_CODEUNIT] = ACTIONS(5795),
    [anon_sym_Codeunit] = ACTIONS(5795),
    [anon_sym_CodeUnit] = ACTIONS(5795),
    [anon_sym_COdeunit] = ACTIONS(5795),
    [anon_sym_codeUnit] = ACTIONS(5795),
    [sym_report_keyword] = ACTIONS(5795),
    [sym_query_keyword] = ACTIONS(5795),
    [anon_sym_xmlport] = ACTIONS(5795),
    [anon_sym_XMLPORT] = ACTIONS(5795),
    [anon_sym_Xmlport] = ACTIONS(5795),
    [anon_sym_XMLport] = ACTIONS(5795),
    [anon_sym_XMLPort] = ACTIONS(5795),
    [anon_sym_XmlPort] = ACTIONS(5795),
    [anon_sym_enum] = ACTIONS(5795),
    [anon_sym_ENUM] = ACTIONS(5795),
    [anon_sym_Enum] = ACTIONS(5795),
    [anon_sym_eNUM] = ACTIONS(5795),
    [anon_sym_eNum] = ACTIONS(5795),
    [anon_sym_ENum] = ACTIONS(5795),
    [sym_quoted_identifier] = ACTIONS(5797),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5797),
    [sym_verbatim_string] = ACTIONS(5797),
    [sym_integer] = ACTIONS(5795),
    [sym_continue_as_identifier] = ACTIONS(5797),
    [sym_preproc_open] = ACTIONS(5797),
  },
  [STATE(3034)] = {
    [sym_identifier] = ACTIONS(5799),
    [anon_sym_SEMI] = ACTIONS(5801),
    [anon_sym_DASH] = ACTIONS(5801),
    [aux_sym_boolean_token1] = ACTIONS(5799),
    [aux_sym_boolean_token2] = ACTIONS(5799),
    [sym_decimal] = ACTIONS(5799),
    [anon_sym_LPAREN] = ACTIONS(5801),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5799),
    [anon_sym_LBRACK] = ACTIONS(5801),
    [aux_sym_record_type_token1] = ACTIONS(5799),
    [aux_sym_basic_type_token21] = ACTIONS(5799),
    [aux_sym_basic_type_token22] = ACTIONS(5799),
    [aux_sym_basic_type_token48] = ACTIONS(5799),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5799),
    [anon_sym_POUNDif] = ACTIONS(5801),
    [anon_sym_POUNDIF] = ACTIONS(5801),
    [anon_sym_POUNDIf] = ACTIONS(5801),
    [anon_sym_not] = ACTIONS(5799),
    [anon_sym_NOT] = ACTIONS(5799),
    [anon_sym_Not] = ACTIONS(5799),
    [anon_sym_POUNDelse] = ACTIONS(5801),
    [anon_sym_POUNDELSE] = ACTIONS(5801),
    [anon_sym_POUNDElse] = ACTIONS(5801),
    [anon_sym_POUNDelse2] = ACTIONS(5801),
    [anon_sym_POUNDELSE2] = ACTIONS(5801),
    [anon_sym_POUNDElse2] = ACTIONS(5801),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5799),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5799),
    [anon_sym_PLUS] = ACTIONS(5801),
    [sym_datetime_literal] = ACTIONS(5801),
    [sym_date_literal] = ACTIONS(5799),
    [sym_time_literal] = ACTIONS(5799),
    [sym_biginteger_literal] = ACTIONS(5801),
    [anon_sym_if] = ACTIONS(5799),
    [anon_sym_IF] = ACTIONS(5799),
    [anon_sym_If] = ACTIONS(5799),
    [anon_sym_else] = ACTIONS(5799),
    [anon_sym_ELSE] = ACTIONS(5799),
    [anon_sym_Else] = ACTIONS(5799),
    [anon_sym_case] = ACTIONS(5799),
    [anon_sym_CASE] = ACTIONS(5799),
    [anon_sym_Case] = ACTIONS(5799),
    [anon_sym_for] = ACTIONS(5799),
    [anon_sym_FOR] = ACTIONS(5799),
    [anon_sym_For] = ACTIONS(5799),
    [anon_sym_foreach] = ACTIONS(5799),
    [anon_sym_FOREACH] = ACTIONS(5799),
    [anon_sym_Foreach] = ACTIONS(5799),
    [anon_sym_while] = ACTIONS(5799),
    [anon_sym_WHILE] = ACTIONS(5799),
    [anon_sym_While] = ACTIONS(5799),
    [anon_sym_repeat] = ACTIONS(5799),
    [anon_sym_REPEAT] = ACTIONS(5799),
    [anon_sym_Repeat] = ACTIONS(5799),
    [anon_sym_until] = ACTIONS(5799),
    [anon_sym_UNTIL] = ACTIONS(5799),
    [anon_sym_Until] = ACTIONS(5799),
    [anon_sym_exit] = ACTIONS(5799),
    [anon_sym_EXIT] = ACTIONS(5799),
    [anon_sym_Exit] = ACTIONS(5799),
    [anon_sym_continue] = ACTIONS(5799),
    [anon_sym_CONTINUE] = ACTIONS(5799),
    [anon_sym_Continue] = ACTIONS(5799),
    [anon_sym_break] = ACTIONS(5799),
    [anon_sym_BREAK] = ACTIONS(5799),
    [anon_sym_Break] = ACTIONS(5799),
    [anon_sym_with] = ACTIONS(5799),
    [anon_sym_WITH] = ACTIONS(5799),
    [anon_sym_With] = ACTIONS(5799),
    [sym_asserterror_keyword] = ACTIONS(5801),
    [sym_page_keyword] = ACTIONS(5799),
    [anon_sym_codeunit] = ACTIONS(5799),
    [anon_sym_CODEUNIT] = ACTIONS(5799),
    [anon_sym_Codeunit] = ACTIONS(5799),
    [anon_sym_CodeUnit] = ACTIONS(5799),
    [anon_sym_COdeunit] = ACTIONS(5799),
    [anon_sym_codeUnit] = ACTIONS(5799),
    [sym_report_keyword] = ACTIONS(5799),
    [sym_query_keyword] = ACTIONS(5799),
    [anon_sym_xmlport] = ACTIONS(5799),
    [anon_sym_XMLPORT] = ACTIONS(5799),
    [anon_sym_Xmlport] = ACTIONS(5799),
    [anon_sym_XMLport] = ACTIONS(5799),
    [anon_sym_XMLPort] = ACTIONS(5799),
    [anon_sym_XmlPort] = ACTIONS(5799),
    [anon_sym_enum] = ACTIONS(5799),
    [anon_sym_ENUM] = ACTIONS(5799),
    [anon_sym_Enum] = ACTIONS(5799),
    [anon_sym_eNUM] = ACTIONS(5799),
    [anon_sym_eNum] = ACTIONS(5799),
    [anon_sym_ENum] = ACTIONS(5799),
    [sym_quoted_identifier] = ACTIONS(5801),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5801),
    [sym_verbatim_string] = ACTIONS(5801),
    [sym_integer] = ACTIONS(5799),
    [sym_continue_as_identifier] = ACTIONS(5801),
    [sym_preproc_open] = ACTIONS(5801),
  },
  [STATE(3035)] = {
    [sym_identifier] = ACTIONS(5803),
    [anon_sym_SEMI] = ACTIONS(5805),
    [anon_sym_DASH] = ACTIONS(5805),
    [aux_sym_boolean_token1] = ACTIONS(5803),
    [aux_sym_boolean_token2] = ACTIONS(5803),
    [sym_decimal] = ACTIONS(5803),
    [anon_sym_LPAREN] = ACTIONS(5805),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5803),
    [anon_sym_LBRACK] = ACTIONS(5805),
    [aux_sym_record_type_token1] = ACTIONS(5803),
    [aux_sym_basic_type_token21] = ACTIONS(5803),
    [aux_sym_basic_type_token22] = ACTIONS(5803),
    [aux_sym_basic_type_token48] = ACTIONS(5803),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5803),
    [anon_sym_POUNDif] = ACTIONS(5805),
    [anon_sym_POUNDIF] = ACTIONS(5805),
    [anon_sym_POUNDIf] = ACTIONS(5805),
    [anon_sym_not] = ACTIONS(5803),
    [anon_sym_NOT] = ACTIONS(5803),
    [anon_sym_Not] = ACTIONS(5803),
    [anon_sym_POUNDelse] = ACTIONS(5805),
    [anon_sym_POUNDELSE] = ACTIONS(5805),
    [anon_sym_POUNDElse] = ACTIONS(5805),
    [anon_sym_POUNDelse2] = ACTIONS(5805),
    [anon_sym_POUNDELSE2] = ACTIONS(5805),
    [anon_sym_POUNDElse2] = ACTIONS(5805),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5803),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5803),
    [anon_sym_PLUS] = ACTIONS(5805),
    [sym_datetime_literal] = ACTIONS(5805),
    [sym_date_literal] = ACTIONS(5803),
    [sym_time_literal] = ACTIONS(5803),
    [sym_biginteger_literal] = ACTIONS(5805),
    [anon_sym_if] = ACTIONS(5803),
    [anon_sym_IF] = ACTIONS(5803),
    [anon_sym_If] = ACTIONS(5803),
    [anon_sym_else] = ACTIONS(5803),
    [anon_sym_ELSE] = ACTIONS(5803),
    [anon_sym_Else] = ACTIONS(5803),
    [anon_sym_case] = ACTIONS(5803),
    [anon_sym_CASE] = ACTIONS(5803),
    [anon_sym_Case] = ACTIONS(5803),
    [anon_sym_for] = ACTIONS(5803),
    [anon_sym_FOR] = ACTIONS(5803),
    [anon_sym_For] = ACTIONS(5803),
    [anon_sym_foreach] = ACTIONS(5803),
    [anon_sym_FOREACH] = ACTIONS(5803),
    [anon_sym_Foreach] = ACTIONS(5803),
    [anon_sym_while] = ACTIONS(5803),
    [anon_sym_WHILE] = ACTIONS(5803),
    [anon_sym_While] = ACTIONS(5803),
    [anon_sym_repeat] = ACTIONS(5803),
    [anon_sym_REPEAT] = ACTIONS(5803),
    [anon_sym_Repeat] = ACTIONS(5803),
    [anon_sym_until] = ACTIONS(5803),
    [anon_sym_UNTIL] = ACTIONS(5803),
    [anon_sym_Until] = ACTIONS(5803),
    [anon_sym_exit] = ACTIONS(5803),
    [anon_sym_EXIT] = ACTIONS(5803),
    [anon_sym_Exit] = ACTIONS(5803),
    [anon_sym_continue] = ACTIONS(5803),
    [anon_sym_CONTINUE] = ACTIONS(5803),
    [anon_sym_Continue] = ACTIONS(5803),
    [anon_sym_break] = ACTIONS(5803),
    [anon_sym_BREAK] = ACTIONS(5803),
    [anon_sym_Break] = ACTIONS(5803),
    [anon_sym_with] = ACTIONS(5803),
    [anon_sym_WITH] = ACTIONS(5803),
    [anon_sym_With] = ACTIONS(5803),
    [sym_asserterror_keyword] = ACTIONS(5805),
    [sym_page_keyword] = ACTIONS(5803),
    [anon_sym_codeunit] = ACTIONS(5803),
    [anon_sym_CODEUNIT] = ACTIONS(5803),
    [anon_sym_Codeunit] = ACTIONS(5803),
    [anon_sym_CodeUnit] = ACTIONS(5803),
    [anon_sym_COdeunit] = ACTIONS(5803),
    [anon_sym_codeUnit] = ACTIONS(5803),
    [sym_report_keyword] = ACTIONS(5803),
    [sym_query_keyword] = ACTIONS(5803),
    [anon_sym_xmlport] = ACTIONS(5803),
    [anon_sym_XMLPORT] = ACTIONS(5803),
    [anon_sym_Xmlport] = ACTIONS(5803),
    [anon_sym_XMLport] = ACTIONS(5803),
    [anon_sym_XMLPort] = ACTIONS(5803),
    [anon_sym_XmlPort] = ACTIONS(5803),
    [anon_sym_enum] = ACTIONS(5803),
    [anon_sym_ENUM] = ACTIONS(5803),
    [anon_sym_Enum] = ACTIONS(5803),
    [anon_sym_eNUM] = ACTIONS(5803),
    [anon_sym_eNum] = ACTIONS(5803),
    [anon_sym_ENum] = ACTIONS(5803),
    [sym_quoted_identifier] = ACTIONS(5805),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5805),
    [sym_verbatim_string] = ACTIONS(5805),
    [sym_integer] = ACTIONS(5803),
    [sym_continue_as_identifier] = ACTIONS(5805),
    [sym_preproc_open] = ACTIONS(5805),
  },
  [STATE(3036)] = {
    [sym_identifier] = ACTIONS(5807),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_DASH] = ACTIONS(5809),
    [aux_sym_boolean_token1] = ACTIONS(5807),
    [aux_sym_boolean_token2] = ACTIONS(5807),
    [sym_decimal] = ACTIONS(5807),
    [anon_sym_LPAREN] = ACTIONS(5809),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5809),
    [aux_sym_record_type_token1] = ACTIONS(5807),
    [aux_sym_basic_type_token21] = ACTIONS(5807),
    [aux_sym_basic_type_token22] = ACTIONS(5807),
    [aux_sym_basic_type_token48] = ACTIONS(5807),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5807),
    [anon_sym_POUNDif] = ACTIONS(5809),
    [anon_sym_POUNDIF] = ACTIONS(5809),
    [anon_sym_POUNDIf] = ACTIONS(5809),
    [anon_sym_not] = ACTIONS(5807),
    [anon_sym_NOT] = ACTIONS(5807),
    [anon_sym_Not] = ACTIONS(5807),
    [anon_sym_POUNDelse] = ACTIONS(5809),
    [anon_sym_POUNDELSE] = ACTIONS(5809),
    [anon_sym_POUNDElse] = ACTIONS(5809),
    [anon_sym_POUNDelse2] = ACTIONS(5809),
    [anon_sym_POUNDELSE2] = ACTIONS(5809),
    [anon_sym_POUNDElse2] = ACTIONS(5809),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5807),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5807),
    [anon_sym_PLUS] = ACTIONS(5809),
    [sym_datetime_literal] = ACTIONS(5809),
    [sym_date_literal] = ACTIONS(5807),
    [sym_time_literal] = ACTIONS(5807),
    [sym_biginteger_literal] = ACTIONS(5809),
    [anon_sym_if] = ACTIONS(5807),
    [anon_sym_IF] = ACTIONS(5807),
    [anon_sym_If] = ACTIONS(5807),
    [anon_sym_else] = ACTIONS(5807),
    [anon_sym_ELSE] = ACTIONS(5807),
    [anon_sym_Else] = ACTIONS(5807),
    [anon_sym_case] = ACTIONS(5807),
    [anon_sym_CASE] = ACTIONS(5807),
    [anon_sym_Case] = ACTIONS(5807),
    [anon_sym_for] = ACTIONS(5807),
    [anon_sym_FOR] = ACTIONS(5807),
    [anon_sym_For] = ACTIONS(5807),
    [anon_sym_foreach] = ACTIONS(5807),
    [anon_sym_FOREACH] = ACTIONS(5807),
    [anon_sym_Foreach] = ACTIONS(5807),
    [anon_sym_while] = ACTIONS(5807),
    [anon_sym_WHILE] = ACTIONS(5807),
    [anon_sym_While] = ACTIONS(5807),
    [anon_sym_repeat] = ACTIONS(5807),
    [anon_sym_REPEAT] = ACTIONS(5807),
    [anon_sym_Repeat] = ACTIONS(5807),
    [anon_sym_until] = ACTIONS(5807),
    [anon_sym_UNTIL] = ACTIONS(5807),
    [anon_sym_Until] = ACTIONS(5807),
    [anon_sym_exit] = ACTIONS(5807),
    [anon_sym_EXIT] = ACTIONS(5807),
    [anon_sym_Exit] = ACTIONS(5807),
    [anon_sym_continue] = ACTIONS(5807),
    [anon_sym_CONTINUE] = ACTIONS(5807),
    [anon_sym_Continue] = ACTIONS(5807),
    [anon_sym_break] = ACTIONS(5807),
    [anon_sym_BREAK] = ACTIONS(5807),
    [anon_sym_Break] = ACTIONS(5807),
    [anon_sym_with] = ACTIONS(5807),
    [anon_sym_WITH] = ACTIONS(5807),
    [anon_sym_With] = ACTIONS(5807),
    [sym_asserterror_keyword] = ACTIONS(5809),
    [sym_page_keyword] = ACTIONS(5807),
    [anon_sym_codeunit] = ACTIONS(5807),
    [anon_sym_CODEUNIT] = ACTIONS(5807),
    [anon_sym_Codeunit] = ACTIONS(5807),
    [anon_sym_CodeUnit] = ACTIONS(5807),
    [anon_sym_COdeunit] = ACTIONS(5807),
    [anon_sym_codeUnit] = ACTIONS(5807),
    [sym_report_keyword] = ACTIONS(5807),
    [sym_query_keyword] = ACTIONS(5807),
    [anon_sym_xmlport] = ACTIONS(5807),
    [anon_sym_XMLPORT] = ACTIONS(5807),
    [anon_sym_Xmlport] = ACTIONS(5807),
    [anon_sym_XMLport] = ACTIONS(5807),
    [anon_sym_XMLPort] = ACTIONS(5807),
    [anon_sym_XmlPort] = ACTIONS(5807),
    [anon_sym_enum] = ACTIONS(5807),
    [anon_sym_ENUM] = ACTIONS(5807),
    [anon_sym_Enum] = ACTIONS(5807),
    [anon_sym_eNUM] = ACTIONS(5807),
    [anon_sym_eNum] = ACTIONS(5807),
    [anon_sym_ENum] = ACTIONS(5807),
    [sym_quoted_identifier] = ACTIONS(5809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5809),
    [sym_verbatim_string] = ACTIONS(5809),
    [sym_integer] = ACTIONS(5807),
    [sym_continue_as_identifier] = ACTIONS(5809),
    [sym_preproc_open] = ACTIONS(5809),
  },
  [STATE(3037)] = {
    [sym_identifier] = ACTIONS(5811),
    [anon_sym_SEMI] = ACTIONS(5813),
    [anon_sym_DASH] = ACTIONS(5813),
    [aux_sym_boolean_token1] = ACTIONS(5811),
    [aux_sym_boolean_token2] = ACTIONS(5811),
    [sym_decimal] = ACTIONS(5811),
    [anon_sym_LPAREN] = ACTIONS(5813),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5811),
    [anon_sym_LBRACK] = ACTIONS(5813),
    [aux_sym_record_type_token1] = ACTIONS(5811),
    [aux_sym_basic_type_token21] = ACTIONS(5811),
    [aux_sym_basic_type_token22] = ACTIONS(5811),
    [aux_sym_basic_type_token48] = ACTIONS(5811),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5811),
    [anon_sym_POUNDif] = ACTIONS(5813),
    [anon_sym_POUNDIF] = ACTIONS(5813),
    [anon_sym_POUNDIf] = ACTIONS(5813),
    [anon_sym_not] = ACTIONS(5811),
    [anon_sym_NOT] = ACTIONS(5811),
    [anon_sym_Not] = ACTIONS(5811),
    [anon_sym_POUNDelse] = ACTIONS(5813),
    [anon_sym_POUNDELSE] = ACTIONS(5813),
    [anon_sym_POUNDElse] = ACTIONS(5813),
    [anon_sym_POUNDelse2] = ACTIONS(5813),
    [anon_sym_POUNDELSE2] = ACTIONS(5813),
    [anon_sym_POUNDElse2] = ACTIONS(5813),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5811),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5811),
    [anon_sym_PLUS] = ACTIONS(5813),
    [sym_datetime_literal] = ACTIONS(5813),
    [sym_date_literal] = ACTIONS(5811),
    [sym_time_literal] = ACTIONS(5811),
    [sym_biginteger_literal] = ACTIONS(5813),
    [anon_sym_if] = ACTIONS(5811),
    [anon_sym_IF] = ACTIONS(5811),
    [anon_sym_If] = ACTIONS(5811),
    [anon_sym_else] = ACTIONS(5811),
    [anon_sym_ELSE] = ACTIONS(5811),
    [anon_sym_Else] = ACTIONS(5811),
    [anon_sym_case] = ACTIONS(5811),
    [anon_sym_CASE] = ACTIONS(5811),
    [anon_sym_Case] = ACTIONS(5811),
    [anon_sym_for] = ACTIONS(5811),
    [anon_sym_FOR] = ACTIONS(5811),
    [anon_sym_For] = ACTIONS(5811),
    [anon_sym_foreach] = ACTIONS(5811),
    [anon_sym_FOREACH] = ACTIONS(5811),
    [anon_sym_Foreach] = ACTIONS(5811),
    [anon_sym_while] = ACTIONS(5811),
    [anon_sym_WHILE] = ACTIONS(5811),
    [anon_sym_While] = ACTIONS(5811),
    [anon_sym_repeat] = ACTIONS(5811),
    [anon_sym_REPEAT] = ACTIONS(5811),
    [anon_sym_Repeat] = ACTIONS(5811),
    [anon_sym_until] = ACTIONS(5811),
    [anon_sym_UNTIL] = ACTIONS(5811),
    [anon_sym_Until] = ACTIONS(5811),
    [anon_sym_exit] = ACTIONS(5811),
    [anon_sym_EXIT] = ACTIONS(5811),
    [anon_sym_Exit] = ACTIONS(5811),
    [anon_sym_continue] = ACTIONS(5811),
    [anon_sym_CONTINUE] = ACTIONS(5811),
    [anon_sym_Continue] = ACTIONS(5811),
    [anon_sym_break] = ACTIONS(5811),
    [anon_sym_BREAK] = ACTIONS(5811),
    [anon_sym_Break] = ACTIONS(5811),
    [anon_sym_with] = ACTIONS(5811),
    [anon_sym_WITH] = ACTIONS(5811),
    [anon_sym_With] = ACTIONS(5811),
    [sym_asserterror_keyword] = ACTIONS(5813),
    [sym_page_keyword] = ACTIONS(5811),
    [anon_sym_codeunit] = ACTIONS(5811),
    [anon_sym_CODEUNIT] = ACTIONS(5811),
    [anon_sym_Codeunit] = ACTIONS(5811),
    [anon_sym_CodeUnit] = ACTIONS(5811),
    [anon_sym_COdeunit] = ACTIONS(5811),
    [anon_sym_codeUnit] = ACTIONS(5811),
    [sym_report_keyword] = ACTIONS(5811),
    [sym_query_keyword] = ACTIONS(5811),
    [anon_sym_xmlport] = ACTIONS(5811),
    [anon_sym_XMLPORT] = ACTIONS(5811),
    [anon_sym_Xmlport] = ACTIONS(5811),
    [anon_sym_XMLport] = ACTIONS(5811),
    [anon_sym_XMLPort] = ACTIONS(5811),
    [anon_sym_XmlPort] = ACTIONS(5811),
    [anon_sym_enum] = ACTIONS(5811),
    [anon_sym_ENUM] = ACTIONS(5811),
    [anon_sym_Enum] = ACTIONS(5811),
    [anon_sym_eNUM] = ACTIONS(5811),
    [anon_sym_eNum] = ACTIONS(5811),
    [anon_sym_ENum] = ACTIONS(5811),
    [sym_quoted_identifier] = ACTIONS(5813),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5813),
    [sym_verbatim_string] = ACTIONS(5813),
    [sym_integer] = ACTIONS(5811),
    [sym_continue_as_identifier] = ACTIONS(5813),
    [sym_preproc_open] = ACTIONS(5813),
  },
  [STATE(3038)] = {
    [sym_identifier] = ACTIONS(5815),
    [anon_sym_SEMI] = ACTIONS(5817),
    [anon_sym_DASH] = ACTIONS(5817),
    [aux_sym_boolean_token1] = ACTIONS(5815),
    [aux_sym_boolean_token2] = ACTIONS(5815),
    [sym_decimal] = ACTIONS(5815),
    [anon_sym_LPAREN] = ACTIONS(5817),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(5817),
    [aux_sym_record_type_token1] = ACTIONS(5815),
    [aux_sym_basic_type_token21] = ACTIONS(5815),
    [aux_sym_basic_type_token22] = ACTIONS(5815),
    [aux_sym_basic_type_token48] = ACTIONS(5815),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5815),
    [anon_sym_POUNDif] = ACTIONS(5817),
    [anon_sym_POUNDIF] = ACTIONS(5817),
    [anon_sym_POUNDIf] = ACTIONS(5817),
    [anon_sym_not] = ACTIONS(5815),
    [anon_sym_NOT] = ACTIONS(5815),
    [anon_sym_Not] = ACTIONS(5815),
    [anon_sym_POUNDelse] = ACTIONS(5817),
    [anon_sym_POUNDELSE] = ACTIONS(5817),
    [anon_sym_POUNDElse] = ACTIONS(5817),
    [anon_sym_POUNDelse2] = ACTIONS(5817),
    [anon_sym_POUNDELSE2] = ACTIONS(5817),
    [anon_sym_POUNDElse2] = ACTIONS(5817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5815),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5815),
    [anon_sym_PLUS] = ACTIONS(5817),
    [sym_datetime_literal] = ACTIONS(5817),
    [sym_date_literal] = ACTIONS(5815),
    [sym_time_literal] = ACTIONS(5815),
    [sym_biginteger_literal] = ACTIONS(5817),
    [anon_sym_if] = ACTIONS(5815),
    [anon_sym_IF] = ACTIONS(5815),
    [anon_sym_If] = ACTIONS(5815),
    [anon_sym_else] = ACTIONS(5815),
    [anon_sym_ELSE] = ACTIONS(5815),
    [anon_sym_Else] = ACTIONS(5815),
    [anon_sym_case] = ACTIONS(5815),
    [anon_sym_CASE] = ACTIONS(5815),
    [anon_sym_Case] = ACTIONS(5815),
    [anon_sym_for] = ACTIONS(5815),
    [anon_sym_FOR] = ACTIONS(5815),
    [anon_sym_For] = ACTIONS(5815),
    [anon_sym_foreach] = ACTIONS(5815),
    [anon_sym_FOREACH] = ACTIONS(5815),
    [anon_sym_Foreach] = ACTIONS(5815),
    [anon_sym_while] = ACTIONS(5815),
    [anon_sym_WHILE] = ACTIONS(5815),
    [anon_sym_While] = ACTIONS(5815),
    [anon_sym_repeat] = ACTIONS(5815),
    [anon_sym_REPEAT] = ACTIONS(5815),
    [anon_sym_Repeat] = ACTIONS(5815),
    [anon_sym_until] = ACTIONS(5815),
    [anon_sym_UNTIL] = ACTIONS(5815),
    [anon_sym_Until] = ACTIONS(5815),
    [anon_sym_exit] = ACTIONS(5815),
    [anon_sym_EXIT] = ACTIONS(5815),
    [anon_sym_Exit] = ACTIONS(5815),
    [anon_sym_continue] = ACTIONS(5815),
    [anon_sym_CONTINUE] = ACTIONS(5815),
    [anon_sym_Continue] = ACTIONS(5815),
    [anon_sym_break] = ACTIONS(5815),
    [anon_sym_BREAK] = ACTIONS(5815),
    [anon_sym_Break] = ACTIONS(5815),
    [anon_sym_with] = ACTIONS(5815),
    [anon_sym_WITH] = ACTIONS(5815),
    [anon_sym_With] = ACTIONS(5815),
    [sym_asserterror_keyword] = ACTIONS(5817),
    [sym_page_keyword] = ACTIONS(5815),
    [anon_sym_codeunit] = ACTIONS(5815),
    [anon_sym_CODEUNIT] = ACTIONS(5815),
    [anon_sym_Codeunit] = ACTIONS(5815),
    [anon_sym_CodeUnit] = ACTIONS(5815),
    [anon_sym_COdeunit] = ACTIONS(5815),
    [anon_sym_codeUnit] = ACTIONS(5815),
    [sym_report_keyword] = ACTIONS(5815),
    [sym_query_keyword] = ACTIONS(5815),
    [anon_sym_xmlport] = ACTIONS(5815),
    [anon_sym_XMLPORT] = ACTIONS(5815),
    [anon_sym_Xmlport] = ACTIONS(5815),
    [anon_sym_XMLport] = ACTIONS(5815),
    [anon_sym_XMLPort] = ACTIONS(5815),
    [anon_sym_XmlPort] = ACTIONS(5815),
    [anon_sym_enum] = ACTIONS(5815),
    [anon_sym_ENUM] = ACTIONS(5815),
    [anon_sym_Enum] = ACTIONS(5815),
    [anon_sym_eNUM] = ACTIONS(5815),
    [anon_sym_eNum] = ACTIONS(5815),
    [anon_sym_ENum] = ACTIONS(5815),
    [sym_quoted_identifier] = ACTIONS(5817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5817),
    [sym_verbatim_string] = ACTIONS(5817),
    [sym_integer] = ACTIONS(5815),
    [sym_continue_as_identifier] = ACTIONS(5817),
    [sym_preproc_open] = ACTIONS(5817),
  },
  [STATE(3039)] = {
    [sym_identifier] = ACTIONS(5819),
    [anon_sym_SEMI] = ACTIONS(5821),
    [anon_sym_DASH] = ACTIONS(5821),
    [aux_sym_boolean_token1] = ACTIONS(5819),
    [aux_sym_boolean_token2] = ACTIONS(5819),
    [sym_decimal] = ACTIONS(5819),
    [anon_sym_LPAREN] = ACTIONS(5821),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5819),
    [anon_sym_LBRACK] = ACTIONS(5821),
    [aux_sym_record_type_token1] = ACTIONS(5819),
    [aux_sym_basic_type_token21] = ACTIONS(5819),
    [aux_sym_basic_type_token22] = ACTIONS(5819),
    [aux_sym_basic_type_token48] = ACTIONS(5819),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5819),
    [anon_sym_POUNDif] = ACTIONS(5821),
    [anon_sym_POUNDIF] = ACTIONS(5821),
    [anon_sym_POUNDIf] = ACTIONS(5821),
    [anon_sym_not] = ACTIONS(5819),
    [anon_sym_NOT] = ACTIONS(5819),
    [anon_sym_Not] = ACTIONS(5819),
    [anon_sym_POUNDelse] = ACTIONS(5821),
    [anon_sym_POUNDELSE] = ACTIONS(5821),
    [anon_sym_POUNDElse] = ACTIONS(5821),
    [anon_sym_POUNDelse2] = ACTIONS(5821),
    [anon_sym_POUNDELSE2] = ACTIONS(5821),
    [anon_sym_POUNDElse2] = ACTIONS(5821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5819),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5819),
    [anon_sym_PLUS] = ACTIONS(5821),
    [sym_datetime_literal] = ACTIONS(5821),
    [sym_date_literal] = ACTIONS(5819),
    [sym_time_literal] = ACTIONS(5819),
    [sym_biginteger_literal] = ACTIONS(5821),
    [anon_sym_if] = ACTIONS(5819),
    [anon_sym_IF] = ACTIONS(5819),
    [anon_sym_If] = ACTIONS(5819),
    [anon_sym_else] = ACTIONS(5819),
    [anon_sym_ELSE] = ACTIONS(5819),
    [anon_sym_Else] = ACTIONS(5819),
    [anon_sym_case] = ACTIONS(5819),
    [anon_sym_CASE] = ACTIONS(5819),
    [anon_sym_Case] = ACTIONS(5819),
    [anon_sym_for] = ACTIONS(5819),
    [anon_sym_FOR] = ACTIONS(5819),
    [anon_sym_For] = ACTIONS(5819),
    [anon_sym_foreach] = ACTIONS(5819),
    [anon_sym_FOREACH] = ACTIONS(5819),
    [anon_sym_Foreach] = ACTIONS(5819),
    [anon_sym_while] = ACTIONS(5819),
    [anon_sym_WHILE] = ACTIONS(5819),
    [anon_sym_While] = ACTIONS(5819),
    [anon_sym_repeat] = ACTIONS(5819),
    [anon_sym_REPEAT] = ACTIONS(5819),
    [anon_sym_Repeat] = ACTIONS(5819),
    [anon_sym_until] = ACTIONS(5819),
    [anon_sym_UNTIL] = ACTIONS(5819),
    [anon_sym_Until] = ACTIONS(5819),
    [anon_sym_exit] = ACTIONS(5819),
    [anon_sym_EXIT] = ACTIONS(5819),
    [anon_sym_Exit] = ACTIONS(5819),
    [anon_sym_continue] = ACTIONS(5819),
    [anon_sym_CONTINUE] = ACTIONS(5819),
    [anon_sym_Continue] = ACTIONS(5819),
    [anon_sym_break] = ACTIONS(5819),
    [anon_sym_BREAK] = ACTIONS(5819),
    [anon_sym_Break] = ACTIONS(5819),
    [anon_sym_with] = ACTIONS(5819),
    [anon_sym_WITH] = ACTIONS(5819),
    [anon_sym_With] = ACTIONS(5819),
    [sym_asserterror_keyword] = ACTIONS(5821),
    [sym_page_keyword] = ACTIONS(5819),
    [anon_sym_codeunit] = ACTIONS(5819),
    [anon_sym_CODEUNIT] = ACTIONS(5819),
    [anon_sym_Codeunit] = ACTIONS(5819),
    [anon_sym_CodeUnit] = ACTIONS(5819),
    [anon_sym_COdeunit] = ACTIONS(5819),
    [anon_sym_codeUnit] = ACTIONS(5819),
    [sym_report_keyword] = ACTIONS(5819),
    [sym_query_keyword] = ACTIONS(5819),
    [anon_sym_xmlport] = ACTIONS(5819),
    [anon_sym_XMLPORT] = ACTIONS(5819),
    [anon_sym_Xmlport] = ACTIONS(5819),
    [anon_sym_XMLport] = ACTIONS(5819),
    [anon_sym_XMLPort] = ACTIONS(5819),
    [anon_sym_XmlPort] = ACTIONS(5819),
    [anon_sym_enum] = ACTIONS(5819),
    [anon_sym_ENUM] = ACTIONS(5819),
    [anon_sym_Enum] = ACTIONS(5819),
    [anon_sym_eNUM] = ACTIONS(5819),
    [anon_sym_eNum] = ACTIONS(5819),
    [anon_sym_ENum] = ACTIONS(5819),
    [sym_quoted_identifier] = ACTIONS(5821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5821),
    [sym_verbatim_string] = ACTIONS(5821),
    [sym_integer] = ACTIONS(5819),
    [sym_continue_as_identifier] = ACTIONS(5821),
    [sym_preproc_open] = ACTIONS(5821),
  },
  [STATE(3040)] = {
    [sym_identifier] = ACTIONS(5823),
    [anon_sym_SEMI] = ACTIONS(5825),
    [anon_sym_DASH] = ACTIONS(5825),
    [aux_sym_boolean_token1] = ACTIONS(5823),
    [aux_sym_boolean_token2] = ACTIONS(5823),
    [sym_decimal] = ACTIONS(5823),
    [anon_sym_LPAREN] = ACTIONS(5825),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5823),
    [anon_sym_LBRACK] = ACTIONS(5825),
    [aux_sym_record_type_token1] = ACTIONS(5823),
    [aux_sym_basic_type_token21] = ACTIONS(5823),
    [aux_sym_basic_type_token22] = ACTIONS(5823),
    [aux_sym_basic_type_token48] = ACTIONS(5823),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5823),
    [anon_sym_POUNDif] = ACTIONS(5825),
    [anon_sym_POUNDIF] = ACTIONS(5825),
    [anon_sym_POUNDIf] = ACTIONS(5825),
    [anon_sym_not] = ACTIONS(5823),
    [anon_sym_NOT] = ACTIONS(5823),
    [anon_sym_Not] = ACTIONS(5823),
    [anon_sym_POUNDelse] = ACTIONS(5825),
    [anon_sym_POUNDELSE] = ACTIONS(5825),
    [anon_sym_POUNDElse] = ACTIONS(5825),
    [anon_sym_POUNDelse2] = ACTIONS(5825),
    [anon_sym_POUNDELSE2] = ACTIONS(5825),
    [anon_sym_POUNDElse2] = ACTIONS(5825),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5823),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5823),
    [anon_sym_PLUS] = ACTIONS(5825),
    [sym_datetime_literal] = ACTIONS(5825),
    [sym_date_literal] = ACTIONS(5823),
    [sym_time_literal] = ACTIONS(5823),
    [sym_biginteger_literal] = ACTIONS(5825),
    [anon_sym_if] = ACTIONS(5823),
    [anon_sym_IF] = ACTIONS(5823),
    [anon_sym_If] = ACTIONS(5823),
    [anon_sym_else] = ACTIONS(5823),
    [anon_sym_ELSE] = ACTIONS(5823),
    [anon_sym_Else] = ACTIONS(5823),
    [anon_sym_case] = ACTIONS(5823),
    [anon_sym_CASE] = ACTIONS(5823),
    [anon_sym_Case] = ACTIONS(5823),
    [anon_sym_for] = ACTIONS(5823),
    [anon_sym_FOR] = ACTIONS(5823),
    [anon_sym_For] = ACTIONS(5823),
    [anon_sym_foreach] = ACTIONS(5823),
    [anon_sym_FOREACH] = ACTIONS(5823),
    [anon_sym_Foreach] = ACTIONS(5823),
    [anon_sym_while] = ACTIONS(5823),
    [anon_sym_WHILE] = ACTIONS(5823),
    [anon_sym_While] = ACTIONS(5823),
    [anon_sym_repeat] = ACTIONS(5823),
    [anon_sym_REPEAT] = ACTIONS(5823),
    [anon_sym_Repeat] = ACTIONS(5823),
    [anon_sym_until] = ACTIONS(5823),
    [anon_sym_UNTIL] = ACTIONS(5823),
    [anon_sym_Until] = ACTIONS(5823),
    [anon_sym_exit] = ACTIONS(5823),
    [anon_sym_EXIT] = ACTIONS(5823),
    [anon_sym_Exit] = ACTIONS(5823),
    [anon_sym_continue] = ACTIONS(5823),
    [anon_sym_CONTINUE] = ACTIONS(5823),
    [anon_sym_Continue] = ACTIONS(5823),
    [anon_sym_break] = ACTIONS(5823),
    [anon_sym_BREAK] = ACTIONS(5823),
    [anon_sym_Break] = ACTIONS(5823),
    [anon_sym_with] = ACTIONS(5823),
    [anon_sym_WITH] = ACTIONS(5823),
    [anon_sym_With] = ACTIONS(5823),
    [sym_asserterror_keyword] = ACTIONS(5825),
    [sym_page_keyword] = ACTIONS(5823),
    [anon_sym_codeunit] = ACTIONS(5823),
    [anon_sym_CODEUNIT] = ACTIONS(5823),
    [anon_sym_Codeunit] = ACTIONS(5823),
    [anon_sym_CodeUnit] = ACTIONS(5823),
    [anon_sym_COdeunit] = ACTIONS(5823),
    [anon_sym_codeUnit] = ACTIONS(5823),
    [sym_report_keyword] = ACTIONS(5823),
    [sym_query_keyword] = ACTIONS(5823),
    [anon_sym_xmlport] = ACTIONS(5823),
    [anon_sym_XMLPORT] = ACTIONS(5823),
    [anon_sym_Xmlport] = ACTIONS(5823),
    [anon_sym_XMLport] = ACTIONS(5823),
    [anon_sym_XMLPort] = ACTIONS(5823),
    [anon_sym_XmlPort] = ACTIONS(5823),
    [anon_sym_enum] = ACTIONS(5823),
    [anon_sym_ENUM] = ACTIONS(5823),
    [anon_sym_Enum] = ACTIONS(5823),
    [anon_sym_eNUM] = ACTIONS(5823),
    [anon_sym_eNum] = ACTIONS(5823),
    [anon_sym_ENum] = ACTIONS(5823),
    [sym_quoted_identifier] = ACTIONS(5825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5825),
    [sym_verbatim_string] = ACTIONS(5825),
    [sym_integer] = ACTIONS(5823),
    [sym_continue_as_identifier] = ACTIONS(5825),
    [sym_preproc_open] = ACTIONS(5825),
  },
  [STATE(3041)] = {
    [sym_identifier] = ACTIONS(5827),
    [anon_sym_SEMI] = ACTIONS(5829),
    [anon_sym_DASH] = ACTIONS(5829),
    [aux_sym_boolean_token1] = ACTIONS(5827),
    [aux_sym_boolean_token2] = ACTIONS(5827),
    [sym_decimal] = ACTIONS(5827),
    [anon_sym_LPAREN] = ACTIONS(5829),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5827),
    [anon_sym_LBRACK] = ACTIONS(5829),
    [aux_sym_record_type_token1] = ACTIONS(5827),
    [aux_sym_basic_type_token21] = ACTIONS(5827),
    [aux_sym_basic_type_token22] = ACTIONS(5827),
    [aux_sym_basic_type_token48] = ACTIONS(5827),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5827),
    [anon_sym_POUNDif] = ACTIONS(5829),
    [anon_sym_POUNDIF] = ACTIONS(5829),
    [anon_sym_POUNDIf] = ACTIONS(5829),
    [anon_sym_not] = ACTIONS(5827),
    [anon_sym_NOT] = ACTIONS(5827),
    [anon_sym_Not] = ACTIONS(5827),
    [anon_sym_POUNDelse] = ACTIONS(5829),
    [anon_sym_POUNDELSE] = ACTIONS(5829),
    [anon_sym_POUNDElse] = ACTIONS(5829),
    [anon_sym_POUNDelse2] = ACTIONS(5829),
    [anon_sym_POUNDELSE2] = ACTIONS(5829),
    [anon_sym_POUNDElse2] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5827),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5827),
    [anon_sym_PLUS] = ACTIONS(5829),
    [sym_datetime_literal] = ACTIONS(5829),
    [sym_date_literal] = ACTIONS(5827),
    [sym_time_literal] = ACTIONS(5827),
    [sym_biginteger_literal] = ACTIONS(5829),
    [anon_sym_if] = ACTIONS(5827),
    [anon_sym_IF] = ACTIONS(5827),
    [anon_sym_If] = ACTIONS(5827),
    [anon_sym_else] = ACTIONS(5827),
    [anon_sym_ELSE] = ACTIONS(5827),
    [anon_sym_Else] = ACTIONS(5827),
    [anon_sym_case] = ACTIONS(5827),
    [anon_sym_CASE] = ACTIONS(5827),
    [anon_sym_Case] = ACTIONS(5827),
    [anon_sym_for] = ACTIONS(5827),
    [anon_sym_FOR] = ACTIONS(5827),
    [anon_sym_For] = ACTIONS(5827),
    [anon_sym_foreach] = ACTIONS(5827),
    [anon_sym_FOREACH] = ACTIONS(5827),
    [anon_sym_Foreach] = ACTIONS(5827),
    [anon_sym_while] = ACTIONS(5827),
    [anon_sym_WHILE] = ACTIONS(5827),
    [anon_sym_While] = ACTIONS(5827),
    [anon_sym_repeat] = ACTIONS(5827),
    [anon_sym_REPEAT] = ACTIONS(5827),
    [anon_sym_Repeat] = ACTIONS(5827),
    [anon_sym_until] = ACTIONS(5827),
    [anon_sym_UNTIL] = ACTIONS(5827),
    [anon_sym_Until] = ACTIONS(5827),
    [anon_sym_exit] = ACTIONS(5827),
    [anon_sym_EXIT] = ACTIONS(5827),
    [anon_sym_Exit] = ACTIONS(5827),
    [anon_sym_continue] = ACTIONS(5827),
    [anon_sym_CONTINUE] = ACTIONS(5827),
    [anon_sym_Continue] = ACTIONS(5827),
    [anon_sym_break] = ACTIONS(5827),
    [anon_sym_BREAK] = ACTIONS(5827),
    [anon_sym_Break] = ACTIONS(5827),
    [anon_sym_with] = ACTIONS(5827),
    [anon_sym_WITH] = ACTIONS(5827),
    [anon_sym_With] = ACTIONS(5827),
    [sym_asserterror_keyword] = ACTIONS(5829),
    [sym_page_keyword] = ACTIONS(5827),
    [anon_sym_codeunit] = ACTIONS(5827),
    [anon_sym_CODEUNIT] = ACTIONS(5827),
    [anon_sym_Codeunit] = ACTIONS(5827),
    [anon_sym_CodeUnit] = ACTIONS(5827),
    [anon_sym_COdeunit] = ACTIONS(5827),
    [anon_sym_codeUnit] = ACTIONS(5827),
    [sym_report_keyword] = ACTIONS(5827),
    [sym_query_keyword] = ACTIONS(5827),
    [anon_sym_xmlport] = ACTIONS(5827),
    [anon_sym_XMLPORT] = ACTIONS(5827),
    [anon_sym_Xmlport] = ACTIONS(5827),
    [anon_sym_XMLport] = ACTIONS(5827),
    [anon_sym_XMLPort] = ACTIONS(5827),
    [anon_sym_XmlPort] = ACTIONS(5827),
    [anon_sym_enum] = ACTIONS(5827),
    [anon_sym_ENUM] = ACTIONS(5827),
    [anon_sym_Enum] = ACTIONS(5827),
    [anon_sym_eNUM] = ACTIONS(5827),
    [anon_sym_eNum] = ACTIONS(5827),
    [anon_sym_ENum] = ACTIONS(5827),
    [sym_quoted_identifier] = ACTIONS(5829),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5829),
    [sym_verbatim_string] = ACTIONS(5829),
    [sym_integer] = ACTIONS(5827),
    [sym_continue_as_identifier] = ACTIONS(5829),
    [sym_preproc_open] = ACTIONS(5829),
  },
  [STATE(3042)] = {
    [sym_identifier] = ACTIONS(5831),
    [anon_sym_SEMI] = ACTIONS(5833),
    [anon_sym_DASH] = ACTIONS(5833),
    [aux_sym_boolean_token1] = ACTIONS(5831),
    [aux_sym_boolean_token2] = ACTIONS(5831),
    [sym_decimal] = ACTIONS(5831),
    [anon_sym_LPAREN] = ACTIONS(5833),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5831),
    [anon_sym_LBRACK] = ACTIONS(5833),
    [aux_sym_record_type_token1] = ACTIONS(5831),
    [aux_sym_basic_type_token21] = ACTIONS(5831),
    [aux_sym_basic_type_token22] = ACTIONS(5831),
    [aux_sym_basic_type_token48] = ACTIONS(5831),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5831),
    [anon_sym_POUNDif] = ACTIONS(5833),
    [anon_sym_POUNDIF] = ACTIONS(5833),
    [anon_sym_POUNDIf] = ACTIONS(5833),
    [anon_sym_not] = ACTIONS(5831),
    [anon_sym_NOT] = ACTIONS(5831),
    [anon_sym_Not] = ACTIONS(5831),
    [anon_sym_POUNDelse] = ACTIONS(5833),
    [anon_sym_POUNDELSE] = ACTIONS(5833),
    [anon_sym_POUNDElse] = ACTIONS(5833),
    [anon_sym_POUNDelse2] = ACTIONS(5833),
    [anon_sym_POUNDELSE2] = ACTIONS(5833),
    [anon_sym_POUNDElse2] = ACTIONS(5833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5831),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5831),
    [anon_sym_PLUS] = ACTIONS(5833),
    [sym_datetime_literal] = ACTIONS(5833),
    [sym_date_literal] = ACTIONS(5831),
    [sym_time_literal] = ACTIONS(5831),
    [sym_biginteger_literal] = ACTIONS(5833),
    [anon_sym_if] = ACTIONS(5831),
    [anon_sym_IF] = ACTIONS(5831),
    [anon_sym_If] = ACTIONS(5831),
    [anon_sym_else] = ACTIONS(5831),
    [anon_sym_ELSE] = ACTIONS(5831),
    [anon_sym_Else] = ACTIONS(5831),
    [anon_sym_case] = ACTIONS(5831),
    [anon_sym_CASE] = ACTIONS(5831),
    [anon_sym_Case] = ACTIONS(5831),
    [anon_sym_for] = ACTIONS(5831),
    [anon_sym_FOR] = ACTIONS(5831),
    [anon_sym_For] = ACTIONS(5831),
    [anon_sym_foreach] = ACTIONS(5831),
    [anon_sym_FOREACH] = ACTIONS(5831),
    [anon_sym_Foreach] = ACTIONS(5831),
    [anon_sym_while] = ACTIONS(5831),
    [anon_sym_WHILE] = ACTIONS(5831),
    [anon_sym_While] = ACTIONS(5831),
    [anon_sym_repeat] = ACTIONS(5831),
    [anon_sym_REPEAT] = ACTIONS(5831),
    [anon_sym_Repeat] = ACTIONS(5831),
    [anon_sym_until] = ACTIONS(5831),
    [anon_sym_UNTIL] = ACTIONS(5831),
    [anon_sym_Until] = ACTIONS(5831),
    [anon_sym_exit] = ACTIONS(5831),
    [anon_sym_EXIT] = ACTIONS(5831),
    [anon_sym_Exit] = ACTIONS(5831),
    [anon_sym_continue] = ACTIONS(5831),
    [anon_sym_CONTINUE] = ACTIONS(5831),
    [anon_sym_Continue] = ACTIONS(5831),
    [anon_sym_break] = ACTIONS(5831),
    [anon_sym_BREAK] = ACTIONS(5831),
    [anon_sym_Break] = ACTIONS(5831),
    [anon_sym_with] = ACTIONS(5831),
    [anon_sym_WITH] = ACTIONS(5831),
    [anon_sym_With] = ACTIONS(5831),
    [sym_asserterror_keyword] = ACTIONS(5833),
    [sym_page_keyword] = ACTIONS(5831),
    [anon_sym_codeunit] = ACTIONS(5831),
    [anon_sym_CODEUNIT] = ACTIONS(5831),
    [anon_sym_Codeunit] = ACTIONS(5831),
    [anon_sym_CodeUnit] = ACTIONS(5831),
    [anon_sym_COdeunit] = ACTIONS(5831),
    [anon_sym_codeUnit] = ACTIONS(5831),
    [sym_report_keyword] = ACTIONS(5831),
    [sym_query_keyword] = ACTIONS(5831),
    [anon_sym_xmlport] = ACTIONS(5831),
    [anon_sym_XMLPORT] = ACTIONS(5831),
    [anon_sym_Xmlport] = ACTIONS(5831),
    [anon_sym_XMLport] = ACTIONS(5831),
    [anon_sym_XMLPort] = ACTIONS(5831),
    [anon_sym_XmlPort] = ACTIONS(5831),
    [anon_sym_enum] = ACTIONS(5831),
    [anon_sym_ENUM] = ACTIONS(5831),
    [anon_sym_Enum] = ACTIONS(5831),
    [anon_sym_eNUM] = ACTIONS(5831),
    [anon_sym_eNum] = ACTIONS(5831),
    [anon_sym_ENum] = ACTIONS(5831),
    [sym_quoted_identifier] = ACTIONS(5833),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5833),
    [sym_verbatim_string] = ACTIONS(5833),
    [sym_integer] = ACTIONS(5831),
    [sym_continue_as_identifier] = ACTIONS(5833),
    [sym_preproc_open] = ACTIONS(5833),
  },
  [STATE(3043)] = {
    [sym_identifier] = ACTIONS(5839),
    [anon_sym_SEMI] = ACTIONS(5841),
    [anon_sym_DASH] = ACTIONS(5841),
    [aux_sym_boolean_token1] = ACTIONS(5839),
    [aux_sym_boolean_token2] = ACTIONS(5839),
    [sym_decimal] = ACTIONS(5839),
    [anon_sym_LPAREN] = ACTIONS(5841),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5839),
    [anon_sym_LBRACK] = ACTIONS(5841),
    [aux_sym_record_type_token1] = ACTIONS(5839),
    [aux_sym_basic_type_token21] = ACTIONS(5839),
    [aux_sym_basic_type_token22] = ACTIONS(5839),
    [aux_sym_basic_type_token48] = ACTIONS(5839),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5839),
    [anon_sym_POUNDif] = ACTIONS(5841),
    [anon_sym_POUNDIF] = ACTIONS(5841),
    [anon_sym_POUNDIf] = ACTIONS(5841),
    [anon_sym_not] = ACTIONS(5839),
    [anon_sym_NOT] = ACTIONS(5839),
    [anon_sym_Not] = ACTIONS(5839),
    [anon_sym_POUNDelse] = ACTIONS(5841),
    [anon_sym_POUNDELSE] = ACTIONS(5841),
    [anon_sym_POUNDElse] = ACTIONS(5841),
    [anon_sym_POUNDelse2] = ACTIONS(5841),
    [anon_sym_POUNDELSE2] = ACTIONS(5841),
    [anon_sym_POUNDElse2] = ACTIONS(5841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5839),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5839),
    [anon_sym_PLUS] = ACTIONS(5841),
    [sym_datetime_literal] = ACTIONS(5841),
    [sym_date_literal] = ACTIONS(5839),
    [sym_time_literal] = ACTIONS(5839),
    [sym_biginteger_literal] = ACTIONS(5841),
    [anon_sym_if] = ACTIONS(5839),
    [anon_sym_IF] = ACTIONS(5839),
    [anon_sym_If] = ACTIONS(5839),
    [anon_sym_else] = ACTIONS(5839),
    [anon_sym_ELSE] = ACTIONS(5839),
    [anon_sym_Else] = ACTIONS(5839),
    [anon_sym_case] = ACTIONS(5839),
    [anon_sym_CASE] = ACTIONS(5839),
    [anon_sym_Case] = ACTIONS(5839),
    [anon_sym_for] = ACTIONS(5839),
    [anon_sym_FOR] = ACTIONS(5839),
    [anon_sym_For] = ACTIONS(5839),
    [anon_sym_foreach] = ACTIONS(5839),
    [anon_sym_FOREACH] = ACTIONS(5839),
    [anon_sym_Foreach] = ACTIONS(5839),
    [anon_sym_while] = ACTIONS(5839),
    [anon_sym_WHILE] = ACTIONS(5839),
    [anon_sym_While] = ACTIONS(5839),
    [anon_sym_repeat] = ACTIONS(5839),
    [anon_sym_REPEAT] = ACTIONS(5839),
    [anon_sym_Repeat] = ACTIONS(5839),
    [anon_sym_until] = ACTIONS(5839),
    [anon_sym_UNTIL] = ACTIONS(5839),
    [anon_sym_Until] = ACTIONS(5839),
    [anon_sym_exit] = ACTIONS(5839),
    [anon_sym_EXIT] = ACTIONS(5839),
    [anon_sym_Exit] = ACTIONS(5839),
    [anon_sym_continue] = ACTIONS(5839),
    [anon_sym_CONTINUE] = ACTIONS(5839),
    [anon_sym_Continue] = ACTIONS(5839),
    [anon_sym_break] = ACTIONS(5839),
    [anon_sym_BREAK] = ACTIONS(5839),
    [anon_sym_Break] = ACTIONS(5839),
    [anon_sym_with] = ACTIONS(5839),
    [anon_sym_WITH] = ACTIONS(5839),
    [anon_sym_With] = ACTIONS(5839),
    [sym_asserterror_keyword] = ACTIONS(5841),
    [sym_page_keyword] = ACTIONS(5839),
    [anon_sym_codeunit] = ACTIONS(5839),
    [anon_sym_CODEUNIT] = ACTIONS(5839),
    [anon_sym_Codeunit] = ACTIONS(5839),
    [anon_sym_CodeUnit] = ACTIONS(5839),
    [anon_sym_COdeunit] = ACTIONS(5839),
    [anon_sym_codeUnit] = ACTIONS(5839),
    [sym_report_keyword] = ACTIONS(5839),
    [sym_query_keyword] = ACTIONS(5839),
    [anon_sym_xmlport] = ACTIONS(5839),
    [anon_sym_XMLPORT] = ACTIONS(5839),
    [anon_sym_Xmlport] = ACTIONS(5839),
    [anon_sym_XMLport] = ACTIONS(5839),
    [anon_sym_XMLPort] = ACTIONS(5839),
    [anon_sym_XmlPort] = ACTIONS(5839),
    [anon_sym_enum] = ACTIONS(5839),
    [anon_sym_ENUM] = ACTIONS(5839),
    [anon_sym_Enum] = ACTIONS(5839),
    [anon_sym_eNUM] = ACTIONS(5839),
    [anon_sym_eNum] = ACTIONS(5839),
    [anon_sym_ENum] = ACTIONS(5839),
    [sym_quoted_identifier] = ACTIONS(5841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5841),
    [sym_verbatim_string] = ACTIONS(5841),
    [sym_integer] = ACTIONS(5839),
    [sym_continue_as_identifier] = ACTIONS(5841),
    [sym_preproc_open] = ACTIONS(5841),
  },
  [STATE(3044)] = {
    [sym_identifier] = ACTIONS(5843),
    [anon_sym_SEMI] = ACTIONS(5845),
    [anon_sym_DASH] = ACTIONS(5845),
    [aux_sym_boolean_token1] = ACTIONS(5843),
    [aux_sym_boolean_token2] = ACTIONS(5843),
    [sym_decimal] = ACTIONS(5843),
    [anon_sym_LPAREN] = ACTIONS(5845),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5843),
    [anon_sym_LBRACK] = ACTIONS(5845),
    [aux_sym_record_type_token1] = ACTIONS(5843),
    [aux_sym_basic_type_token21] = ACTIONS(5843),
    [aux_sym_basic_type_token22] = ACTIONS(5843),
    [aux_sym_basic_type_token48] = ACTIONS(5843),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5843),
    [anon_sym_POUNDif] = ACTIONS(5845),
    [anon_sym_POUNDIF] = ACTIONS(5845),
    [anon_sym_POUNDIf] = ACTIONS(5845),
    [anon_sym_not] = ACTIONS(5843),
    [anon_sym_NOT] = ACTIONS(5843),
    [anon_sym_Not] = ACTIONS(5843),
    [anon_sym_POUNDelse] = ACTIONS(5845),
    [anon_sym_POUNDELSE] = ACTIONS(5845),
    [anon_sym_POUNDElse] = ACTIONS(5845),
    [anon_sym_POUNDelse2] = ACTIONS(5845),
    [anon_sym_POUNDELSE2] = ACTIONS(5845),
    [anon_sym_POUNDElse2] = ACTIONS(5845),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5843),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5843),
    [anon_sym_PLUS] = ACTIONS(5845),
    [sym_datetime_literal] = ACTIONS(5845),
    [sym_date_literal] = ACTIONS(5843),
    [sym_time_literal] = ACTIONS(5843),
    [sym_biginteger_literal] = ACTIONS(5845),
    [anon_sym_if] = ACTIONS(5843),
    [anon_sym_IF] = ACTIONS(5843),
    [anon_sym_If] = ACTIONS(5843),
    [anon_sym_else] = ACTIONS(5843),
    [anon_sym_ELSE] = ACTIONS(5843),
    [anon_sym_Else] = ACTIONS(5843),
    [anon_sym_case] = ACTIONS(5843),
    [anon_sym_CASE] = ACTIONS(5843),
    [anon_sym_Case] = ACTIONS(5843),
    [anon_sym_for] = ACTIONS(5843),
    [anon_sym_FOR] = ACTIONS(5843),
    [anon_sym_For] = ACTIONS(5843),
    [anon_sym_foreach] = ACTIONS(5843),
    [anon_sym_FOREACH] = ACTIONS(5843),
    [anon_sym_Foreach] = ACTIONS(5843),
    [anon_sym_while] = ACTIONS(5843),
    [anon_sym_WHILE] = ACTIONS(5843),
    [anon_sym_While] = ACTIONS(5843),
    [anon_sym_repeat] = ACTIONS(5843),
    [anon_sym_REPEAT] = ACTIONS(5843),
    [anon_sym_Repeat] = ACTIONS(5843),
    [anon_sym_until] = ACTIONS(5843),
    [anon_sym_UNTIL] = ACTIONS(5843),
    [anon_sym_Until] = ACTIONS(5843),
    [anon_sym_exit] = ACTIONS(5843),
    [anon_sym_EXIT] = ACTIONS(5843),
    [anon_sym_Exit] = ACTIONS(5843),
    [anon_sym_continue] = ACTIONS(5843),
    [anon_sym_CONTINUE] = ACTIONS(5843),
    [anon_sym_Continue] = ACTIONS(5843),
    [anon_sym_break] = ACTIONS(5843),
    [anon_sym_BREAK] = ACTIONS(5843),
    [anon_sym_Break] = ACTIONS(5843),
    [anon_sym_with] = ACTIONS(5843),
    [anon_sym_WITH] = ACTIONS(5843),
    [anon_sym_With] = ACTIONS(5843),
    [sym_asserterror_keyword] = ACTIONS(5845),
    [sym_page_keyword] = ACTIONS(5843),
    [anon_sym_codeunit] = ACTIONS(5843),
    [anon_sym_CODEUNIT] = ACTIONS(5843),
    [anon_sym_Codeunit] = ACTIONS(5843),
    [anon_sym_CodeUnit] = ACTIONS(5843),
    [anon_sym_COdeunit] = ACTIONS(5843),
    [anon_sym_codeUnit] = ACTIONS(5843),
    [sym_report_keyword] = ACTIONS(5843),
    [sym_query_keyword] = ACTIONS(5843),
    [anon_sym_xmlport] = ACTIONS(5843),
    [anon_sym_XMLPORT] = ACTIONS(5843),
    [anon_sym_Xmlport] = ACTIONS(5843),
    [anon_sym_XMLport] = ACTIONS(5843),
    [anon_sym_XMLPort] = ACTIONS(5843),
    [anon_sym_XmlPort] = ACTIONS(5843),
    [anon_sym_enum] = ACTIONS(5843),
    [anon_sym_ENUM] = ACTIONS(5843),
    [anon_sym_Enum] = ACTIONS(5843),
    [anon_sym_eNUM] = ACTIONS(5843),
    [anon_sym_eNum] = ACTIONS(5843),
    [anon_sym_ENum] = ACTIONS(5843),
    [sym_quoted_identifier] = ACTIONS(5845),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5845),
    [sym_verbatim_string] = ACTIONS(5845),
    [sym_integer] = ACTIONS(5843),
    [sym_continue_as_identifier] = ACTIONS(5845),
    [sym_preproc_open] = ACTIONS(5845),
  },
  [STATE(3045)] = {
    [sym_identifier] = ACTIONS(5847),
    [anon_sym_SEMI] = ACTIONS(5849),
    [anon_sym_DASH] = ACTIONS(5849),
    [aux_sym_boolean_token1] = ACTIONS(5847),
    [aux_sym_boolean_token2] = ACTIONS(5847),
    [sym_decimal] = ACTIONS(5847),
    [anon_sym_LPAREN] = ACTIONS(5849),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5847),
    [anon_sym_LBRACK] = ACTIONS(5849),
    [aux_sym_record_type_token1] = ACTIONS(5847),
    [aux_sym_basic_type_token21] = ACTIONS(5847),
    [aux_sym_basic_type_token22] = ACTIONS(5847),
    [aux_sym_basic_type_token48] = ACTIONS(5847),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5847),
    [anon_sym_POUNDif] = ACTIONS(5849),
    [anon_sym_POUNDIF] = ACTIONS(5849),
    [anon_sym_POUNDIf] = ACTIONS(5849),
    [anon_sym_not] = ACTIONS(5847),
    [anon_sym_NOT] = ACTIONS(5847),
    [anon_sym_Not] = ACTIONS(5847),
    [anon_sym_POUNDelse] = ACTIONS(5849),
    [anon_sym_POUNDELSE] = ACTIONS(5849),
    [anon_sym_POUNDElse] = ACTIONS(5849),
    [anon_sym_POUNDelse2] = ACTIONS(5849),
    [anon_sym_POUNDELSE2] = ACTIONS(5849),
    [anon_sym_POUNDElse2] = ACTIONS(5849),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5847),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5847),
    [anon_sym_PLUS] = ACTIONS(5849),
    [sym_datetime_literal] = ACTIONS(5849),
    [sym_date_literal] = ACTIONS(5847),
    [sym_time_literal] = ACTIONS(5847),
    [sym_biginteger_literal] = ACTIONS(5849),
    [anon_sym_if] = ACTIONS(5847),
    [anon_sym_IF] = ACTIONS(5847),
    [anon_sym_If] = ACTIONS(5847),
    [anon_sym_else] = ACTIONS(5847),
    [anon_sym_ELSE] = ACTIONS(5847),
    [anon_sym_Else] = ACTIONS(5847),
    [anon_sym_case] = ACTIONS(5847),
    [anon_sym_CASE] = ACTIONS(5847),
    [anon_sym_Case] = ACTIONS(5847),
    [anon_sym_for] = ACTIONS(5847),
    [anon_sym_FOR] = ACTIONS(5847),
    [anon_sym_For] = ACTIONS(5847),
    [anon_sym_foreach] = ACTIONS(5847),
    [anon_sym_FOREACH] = ACTIONS(5847),
    [anon_sym_Foreach] = ACTIONS(5847),
    [anon_sym_while] = ACTIONS(5847),
    [anon_sym_WHILE] = ACTIONS(5847),
    [anon_sym_While] = ACTIONS(5847),
    [anon_sym_repeat] = ACTIONS(5847),
    [anon_sym_REPEAT] = ACTIONS(5847),
    [anon_sym_Repeat] = ACTIONS(5847),
    [anon_sym_until] = ACTIONS(5847),
    [anon_sym_UNTIL] = ACTIONS(5847),
    [anon_sym_Until] = ACTIONS(5847),
    [anon_sym_exit] = ACTIONS(5847),
    [anon_sym_EXIT] = ACTIONS(5847),
    [anon_sym_Exit] = ACTIONS(5847),
    [anon_sym_continue] = ACTIONS(5847),
    [anon_sym_CONTINUE] = ACTIONS(5847),
    [anon_sym_Continue] = ACTIONS(5847),
    [anon_sym_break] = ACTIONS(5847),
    [anon_sym_BREAK] = ACTIONS(5847),
    [anon_sym_Break] = ACTIONS(5847),
    [anon_sym_with] = ACTIONS(5847),
    [anon_sym_WITH] = ACTIONS(5847),
    [anon_sym_With] = ACTIONS(5847),
    [sym_asserterror_keyword] = ACTIONS(5849),
    [sym_page_keyword] = ACTIONS(5847),
    [anon_sym_codeunit] = ACTIONS(5847),
    [anon_sym_CODEUNIT] = ACTIONS(5847),
    [anon_sym_Codeunit] = ACTIONS(5847),
    [anon_sym_CodeUnit] = ACTIONS(5847),
    [anon_sym_COdeunit] = ACTIONS(5847),
    [anon_sym_codeUnit] = ACTIONS(5847),
    [sym_report_keyword] = ACTIONS(5847),
    [sym_query_keyword] = ACTIONS(5847),
    [anon_sym_xmlport] = ACTIONS(5847),
    [anon_sym_XMLPORT] = ACTIONS(5847),
    [anon_sym_Xmlport] = ACTIONS(5847),
    [anon_sym_XMLport] = ACTIONS(5847),
    [anon_sym_XMLPort] = ACTIONS(5847),
    [anon_sym_XmlPort] = ACTIONS(5847),
    [anon_sym_enum] = ACTIONS(5847),
    [anon_sym_ENUM] = ACTIONS(5847),
    [anon_sym_Enum] = ACTIONS(5847),
    [anon_sym_eNUM] = ACTIONS(5847),
    [anon_sym_eNum] = ACTIONS(5847),
    [anon_sym_ENum] = ACTIONS(5847),
    [sym_quoted_identifier] = ACTIONS(5849),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5849),
    [sym_verbatim_string] = ACTIONS(5849),
    [sym_integer] = ACTIONS(5847),
    [sym_continue_as_identifier] = ACTIONS(5849),
    [sym_preproc_open] = ACTIONS(5849),
  },
  [STATE(3046)] = {
    [sym_identifier] = ACTIONS(5851),
    [anon_sym_SEMI] = ACTIONS(5853),
    [anon_sym_DASH] = ACTIONS(5853),
    [aux_sym_boolean_token1] = ACTIONS(5851),
    [aux_sym_boolean_token2] = ACTIONS(5851),
    [sym_decimal] = ACTIONS(5851),
    [anon_sym_LPAREN] = ACTIONS(5853),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5851),
    [anon_sym_LBRACK] = ACTIONS(5853),
    [aux_sym_record_type_token1] = ACTIONS(5851),
    [aux_sym_basic_type_token21] = ACTIONS(5851),
    [aux_sym_basic_type_token22] = ACTIONS(5851),
    [aux_sym_basic_type_token48] = ACTIONS(5851),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5851),
    [anon_sym_POUNDif] = ACTIONS(5853),
    [anon_sym_POUNDIF] = ACTIONS(5853),
    [anon_sym_POUNDIf] = ACTIONS(5853),
    [anon_sym_not] = ACTIONS(5851),
    [anon_sym_NOT] = ACTIONS(5851),
    [anon_sym_Not] = ACTIONS(5851),
    [anon_sym_POUNDelse] = ACTIONS(5853),
    [anon_sym_POUNDELSE] = ACTIONS(5853),
    [anon_sym_POUNDElse] = ACTIONS(5853),
    [anon_sym_POUNDelse2] = ACTIONS(5853),
    [anon_sym_POUNDELSE2] = ACTIONS(5853),
    [anon_sym_POUNDElse2] = ACTIONS(5853),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5851),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5851),
    [anon_sym_PLUS] = ACTIONS(5853),
    [sym_datetime_literal] = ACTIONS(5853),
    [sym_date_literal] = ACTIONS(5851),
    [sym_time_literal] = ACTIONS(5851),
    [sym_biginteger_literal] = ACTIONS(5853),
    [anon_sym_if] = ACTIONS(5851),
    [anon_sym_IF] = ACTIONS(5851),
    [anon_sym_If] = ACTIONS(5851),
    [anon_sym_else] = ACTIONS(5851),
    [anon_sym_ELSE] = ACTIONS(5851),
    [anon_sym_Else] = ACTIONS(5851),
    [anon_sym_case] = ACTIONS(5851),
    [anon_sym_CASE] = ACTIONS(5851),
    [anon_sym_Case] = ACTIONS(5851),
    [anon_sym_for] = ACTIONS(5851),
    [anon_sym_FOR] = ACTIONS(5851),
    [anon_sym_For] = ACTIONS(5851),
    [anon_sym_foreach] = ACTIONS(5851),
    [anon_sym_FOREACH] = ACTIONS(5851),
    [anon_sym_Foreach] = ACTIONS(5851),
    [anon_sym_while] = ACTIONS(5851),
    [anon_sym_WHILE] = ACTIONS(5851),
    [anon_sym_While] = ACTIONS(5851),
    [anon_sym_repeat] = ACTIONS(5851),
    [anon_sym_REPEAT] = ACTIONS(5851),
    [anon_sym_Repeat] = ACTIONS(5851),
    [anon_sym_until] = ACTIONS(5851),
    [anon_sym_UNTIL] = ACTIONS(5851),
    [anon_sym_Until] = ACTIONS(5851),
    [anon_sym_exit] = ACTIONS(5851),
    [anon_sym_EXIT] = ACTIONS(5851),
    [anon_sym_Exit] = ACTIONS(5851),
    [anon_sym_continue] = ACTIONS(5851),
    [anon_sym_CONTINUE] = ACTIONS(5851),
    [anon_sym_Continue] = ACTIONS(5851),
    [anon_sym_break] = ACTIONS(5851),
    [anon_sym_BREAK] = ACTIONS(5851),
    [anon_sym_Break] = ACTIONS(5851),
    [anon_sym_with] = ACTIONS(5851),
    [anon_sym_WITH] = ACTIONS(5851),
    [anon_sym_With] = ACTIONS(5851),
    [sym_asserterror_keyword] = ACTIONS(5853),
    [sym_page_keyword] = ACTIONS(5851),
    [anon_sym_codeunit] = ACTIONS(5851),
    [anon_sym_CODEUNIT] = ACTIONS(5851),
    [anon_sym_Codeunit] = ACTIONS(5851),
    [anon_sym_CodeUnit] = ACTIONS(5851),
    [anon_sym_COdeunit] = ACTIONS(5851),
    [anon_sym_codeUnit] = ACTIONS(5851),
    [sym_report_keyword] = ACTIONS(5851),
    [sym_query_keyword] = ACTIONS(5851),
    [anon_sym_xmlport] = ACTIONS(5851),
    [anon_sym_XMLPORT] = ACTIONS(5851),
    [anon_sym_Xmlport] = ACTIONS(5851),
    [anon_sym_XMLport] = ACTIONS(5851),
    [anon_sym_XMLPort] = ACTIONS(5851),
    [anon_sym_XmlPort] = ACTIONS(5851),
    [anon_sym_enum] = ACTIONS(5851),
    [anon_sym_ENUM] = ACTIONS(5851),
    [anon_sym_Enum] = ACTIONS(5851),
    [anon_sym_eNUM] = ACTIONS(5851),
    [anon_sym_eNum] = ACTIONS(5851),
    [anon_sym_ENum] = ACTIONS(5851),
    [sym_quoted_identifier] = ACTIONS(5853),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5853),
    [sym_verbatim_string] = ACTIONS(5853),
    [sym_integer] = ACTIONS(5851),
    [sym_continue_as_identifier] = ACTIONS(5853),
    [sym_preproc_open] = ACTIONS(5853),
  },
  [STATE(3047)] = {
    [sym_identifier] = ACTIONS(5493),
    [anon_sym_SEMI] = ACTIONS(5495),
    [anon_sym_DASH] = ACTIONS(5495),
    [aux_sym_boolean_token1] = ACTIONS(5493),
    [aux_sym_boolean_token2] = ACTIONS(5493),
    [sym_decimal] = ACTIONS(5493),
    [anon_sym_LPAREN] = ACTIONS(5495),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5493),
    [anon_sym_LBRACK] = ACTIONS(5495),
    [aux_sym_record_type_token1] = ACTIONS(5493),
    [aux_sym_basic_type_token21] = ACTIONS(5493),
    [aux_sym_basic_type_token22] = ACTIONS(5493),
    [aux_sym_basic_type_token48] = ACTIONS(5493),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5493),
    [anon_sym_POUNDif] = ACTIONS(5495),
    [anon_sym_POUNDIF] = ACTIONS(5495),
    [anon_sym_POUNDIf] = ACTIONS(5495),
    [anon_sym_not] = ACTIONS(5493),
    [anon_sym_NOT] = ACTIONS(5493),
    [anon_sym_Not] = ACTIONS(5493),
    [anon_sym_POUNDelse] = ACTIONS(5495),
    [anon_sym_POUNDELSE] = ACTIONS(5495),
    [anon_sym_POUNDElse] = ACTIONS(5495),
    [anon_sym_POUNDelse2] = ACTIONS(5495),
    [anon_sym_POUNDELSE2] = ACTIONS(5495),
    [anon_sym_POUNDElse2] = ACTIONS(5495),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5493),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5493),
    [anon_sym_PLUS] = ACTIONS(5495),
    [sym_datetime_literal] = ACTIONS(5495),
    [sym_date_literal] = ACTIONS(5493),
    [sym_time_literal] = ACTIONS(5493),
    [sym_biginteger_literal] = ACTIONS(5495),
    [anon_sym_if] = ACTIONS(5493),
    [anon_sym_IF] = ACTIONS(5493),
    [anon_sym_If] = ACTIONS(5493),
    [anon_sym_else] = ACTIONS(5493),
    [anon_sym_ELSE] = ACTIONS(5493),
    [anon_sym_Else] = ACTIONS(5493),
    [anon_sym_case] = ACTIONS(5493),
    [anon_sym_CASE] = ACTIONS(5493),
    [anon_sym_Case] = ACTIONS(5493),
    [anon_sym_for] = ACTIONS(5493),
    [anon_sym_FOR] = ACTIONS(5493),
    [anon_sym_For] = ACTIONS(5493),
    [anon_sym_foreach] = ACTIONS(5493),
    [anon_sym_FOREACH] = ACTIONS(5493),
    [anon_sym_Foreach] = ACTIONS(5493),
    [anon_sym_while] = ACTIONS(5493),
    [anon_sym_WHILE] = ACTIONS(5493),
    [anon_sym_While] = ACTIONS(5493),
    [anon_sym_repeat] = ACTIONS(5493),
    [anon_sym_REPEAT] = ACTIONS(5493),
    [anon_sym_Repeat] = ACTIONS(5493),
    [anon_sym_until] = ACTIONS(5493),
    [anon_sym_UNTIL] = ACTIONS(5493),
    [anon_sym_Until] = ACTIONS(5493),
    [anon_sym_exit] = ACTIONS(5493),
    [anon_sym_EXIT] = ACTIONS(5493),
    [anon_sym_Exit] = ACTIONS(5493),
    [anon_sym_continue] = ACTIONS(5493),
    [anon_sym_CONTINUE] = ACTIONS(5493),
    [anon_sym_Continue] = ACTIONS(5493),
    [anon_sym_break] = ACTIONS(5493),
    [anon_sym_BREAK] = ACTIONS(5493),
    [anon_sym_Break] = ACTIONS(5493),
    [anon_sym_with] = ACTIONS(5493),
    [anon_sym_WITH] = ACTIONS(5493),
    [anon_sym_With] = ACTIONS(5493),
    [sym_asserterror_keyword] = ACTIONS(5495),
    [sym_page_keyword] = ACTIONS(5493),
    [anon_sym_codeunit] = ACTIONS(5493),
    [anon_sym_CODEUNIT] = ACTIONS(5493),
    [anon_sym_Codeunit] = ACTIONS(5493),
    [anon_sym_CodeUnit] = ACTIONS(5493),
    [anon_sym_COdeunit] = ACTIONS(5493),
    [anon_sym_codeUnit] = ACTIONS(5493),
    [sym_report_keyword] = ACTIONS(5493),
    [sym_query_keyword] = ACTIONS(5493),
    [anon_sym_xmlport] = ACTIONS(5493),
    [anon_sym_XMLPORT] = ACTIONS(5493),
    [anon_sym_Xmlport] = ACTIONS(5493),
    [anon_sym_XMLport] = ACTIONS(5493),
    [anon_sym_XMLPort] = ACTIONS(5493),
    [anon_sym_XmlPort] = ACTIONS(5493),
    [anon_sym_enum] = ACTIONS(5493),
    [anon_sym_ENUM] = ACTIONS(5493),
    [anon_sym_Enum] = ACTIONS(5493),
    [anon_sym_eNUM] = ACTIONS(5493),
    [anon_sym_eNum] = ACTIONS(5493),
    [anon_sym_ENum] = ACTIONS(5493),
    [sym_quoted_identifier] = ACTIONS(5495),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5495),
    [sym_verbatim_string] = ACTIONS(5495),
    [sym_integer] = ACTIONS(5493),
    [sym_continue_as_identifier] = ACTIONS(5495),
    [sym_preproc_open] = ACTIONS(5495),
  },
  [STATE(3048)] = {
    [sym_identifier] = ACTIONS(5859),
    [anon_sym_SEMI] = ACTIONS(5861),
    [anon_sym_DASH] = ACTIONS(5861),
    [aux_sym_boolean_token1] = ACTIONS(5859),
    [aux_sym_boolean_token2] = ACTIONS(5859),
    [sym_decimal] = ACTIONS(5859),
    [anon_sym_LPAREN] = ACTIONS(5861),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5859),
    [anon_sym_LBRACK] = ACTIONS(5861),
    [aux_sym_record_type_token1] = ACTIONS(5859),
    [aux_sym_basic_type_token21] = ACTIONS(5859),
    [aux_sym_basic_type_token22] = ACTIONS(5859),
    [aux_sym_basic_type_token48] = ACTIONS(5859),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5859),
    [anon_sym_POUNDif] = ACTIONS(5861),
    [anon_sym_POUNDIF] = ACTIONS(5861),
    [anon_sym_POUNDIf] = ACTIONS(5861),
    [anon_sym_not] = ACTIONS(5859),
    [anon_sym_NOT] = ACTIONS(5859),
    [anon_sym_Not] = ACTIONS(5859),
    [anon_sym_POUNDelse] = ACTIONS(5861),
    [anon_sym_POUNDELSE] = ACTIONS(5861),
    [anon_sym_POUNDElse] = ACTIONS(5861),
    [anon_sym_POUNDelse2] = ACTIONS(5861),
    [anon_sym_POUNDELSE2] = ACTIONS(5861),
    [anon_sym_POUNDElse2] = ACTIONS(5861),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5859),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5859),
    [anon_sym_PLUS] = ACTIONS(5861),
    [sym_datetime_literal] = ACTIONS(5861),
    [sym_date_literal] = ACTIONS(5859),
    [sym_time_literal] = ACTIONS(5859),
    [sym_biginteger_literal] = ACTIONS(5861),
    [anon_sym_if] = ACTIONS(5859),
    [anon_sym_IF] = ACTIONS(5859),
    [anon_sym_If] = ACTIONS(5859),
    [anon_sym_else] = ACTIONS(5859),
    [anon_sym_ELSE] = ACTIONS(5859),
    [anon_sym_Else] = ACTIONS(5859),
    [anon_sym_case] = ACTIONS(5859),
    [anon_sym_CASE] = ACTIONS(5859),
    [anon_sym_Case] = ACTIONS(5859),
    [anon_sym_for] = ACTIONS(5859),
    [anon_sym_FOR] = ACTIONS(5859),
    [anon_sym_For] = ACTIONS(5859),
    [anon_sym_foreach] = ACTIONS(5859),
    [anon_sym_FOREACH] = ACTIONS(5859),
    [anon_sym_Foreach] = ACTIONS(5859),
    [anon_sym_while] = ACTIONS(5859),
    [anon_sym_WHILE] = ACTIONS(5859),
    [anon_sym_While] = ACTIONS(5859),
    [anon_sym_repeat] = ACTIONS(5859),
    [anon_sym_REPEAT] = ACTIONS(5859),
    [anon_sym_Repeat] = ACTIONS(5859),
    [anon_sym_until] = ACTIONS(5859),
    [anon_sym_UNTIL] = ACTIONS(5859),
    [anon_sym_Until] = ACTIONS(5859),
    [anon_sym_exit] = ACTIONS(5859),
    [anon_sym_EXIT] = ACTIONS(5859),
    [anon_sym_Exit] = ACTIONS(5859),
    [anon_sym_continue] = ACTIONS(5859),
    [anon_sym_CONTINUE] = ACTIONS(5859),
    [anon_sym_Continue] = ACTIONS(5859),
    [anon_sym_break] = ACTIONS(5859),
    [anon_sym_BREAK] = ACTIONS(5859),
    [anon_sym_Break] = ACTIONS(5859),
    [anon_sym_with] = ACTIONS(5859),
    [anon_sym_WITH] = ACTIONS(5859),
    [anon_sym_With] = ACTIONS(5859),
    [sym_asserterror_keyword] = ACTIONS(5861),
    [sym_page_keyword] = ACTIONS(5859),
    [anon_sym_codeunit] = ACTIONS(5859),
    [anon_sym_CODEUNIT] = ACTIONS(5859),
    [anon_sym_Codeunit] = ACTIONS(5859),
    [anon_sym_CodeUnit] = ACTIONS(5859),
    [anon_sym_COdeunit] = ACTIONS(5859),
    [anon_sym_codeUnit] = ACTIONS(5859),
    [sym_report_keyword] = ACTIONS(5859),
    [sym_query_keyword] = ACTIONS(5859),
    [anon_sym_xmlport] = ACTIONS(5859),
    [anon_sym_XMLPORT] = ACTIONS(5859),
    [anon_sym_Xmlport] = ACTIONS(5859),
    [anon_sym_XMLport] = ACTIONS(5859),
    [anon_sym_XMLPort] = ACTIONS(5859),
    [anon_sym_XmlPort] = ACTIONS(5859),
    [anon_sym_enum] = ACTIONS(5859),
    [anon_sym_ENUM] = ACTIONS(5859),
    [anon_sym_Enum] = ACTIONS(5859),
    [anon_sym_eNUM] = ACTIONS(5859),
    [anon_sym_eNum] = ACTIONS(5859),
    [anon_sym_ENum] = ACTIONS(5859),
    [sym_quoted_identifier] = ACTIONS(5861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5861),
    [sym_verbatim_string] = ACTIONS(5861),
    [sym_integer] = ACTIONS(5859),
    [sym_continue_as_identifier] = ACTIONS(5861),
    [sym_preproc_open] = ACTIONS(5861),
  },
  [STATE(3049)] = {
    [sym_identifier] = ACTIONS(5863),
    [anon_sym_SEMI] = ACTIONS(5865),
    [anon_sym_DASH] = ACTIONS(5865),
    [aux_sym_boolean_token1] = ACTIONS(5863),
    [aux_sym_boolean_token2] = ACTIONS(5863),
    [sym_decimal] = ACTIONS(5863),
    [anon_sym_LPAREN] = ACTIONS(5865),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5863),
    [anon_sym_LBRACK] = ACTIONS(5865),
    [aux_sym_record_type_token1] = ACTIONS(5863),
    [aux_sym_basic_type_token21] = ACTIONS(5863),
    [aux_sym_basic_type_token22] = ACTIONS(5863),
    [aux_sym_basic_type_token48] = ACTIONS(5863),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5863),
    [anon_sym_POUNDif] = ACTIONS(5865),
    [anon_sym_POUNDIF] = ACTIONS(5865),
    [anon_sym_POUNDIf] = ACTIONS(5865),
    [anon_sym_not] = ACTIONS(5863),
    [anon_sym_NOT] = ACTIONS(5863),
    [anon_sym_Not] = ACTIONS(5863),
    [anon_sym_POUNDelse] = ACTIONS(5865),
    [anon_sym_POUNDELSE] = ACTIONS(5865),
    [anon_sym_POUNDElse] = ACTIONS(5865),
    [anon_sym_POUNDelse2] = ACTIONS(5865),
    [anon_sym_POUNDELSE2] = ACTIONS(5865),
    [anon_sym_POUNDElse2] = ACTIONS(5865),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5863),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5863),
    [anon_sym_PLUS] = ACTIONS(5865),
    [sym_datetime_literal] = ACTIONS(5865),
    [sym_date_literal] = ACTIONS(5863),
    [sym_time_literal] = ACTIONS(5863),
    [sym_biginteger_literal] = ACTIONS(5865),
    [anon_sym_if] = ACTIONS(5863),
    [anon_sym_IF] = ACTIONS(5863),
    [anon_sym_If] = ACTIONS(5863),
    [anon_sym_else] = ACTIONS(5863),
    [anon_sym_ELSE] = ACTIONS(5863),
    [anon_sym_Else] = ACTIONS(5863),
    [anon_sym_case] = ACTIONS(5863),
    [anon_sym_CASE] = ACTIONS(5863),
    [anon_sym_Case] = ACTIONS(5863),
    [anon_sym_for] = ACTIONS(5863),
    [anon_sym_FOR] = ACTIONS(5863),
    [anon_sym_For] = ACTIONS(5863),
    [anon_sym_foreach] = ACTIONS(5863),
    [anon_sym_FOREACH] = ACTIONS(5863),
    [anon_sym_Foreach] = ACTIONS(5863),
    [anon_sym_while] = ACTIONS(5863),
    [anon_sym_WHILE] = ACTIONS(5863),
    [anon_sym_While] = ACTIONS(5863),
    [anon_sym_repeat] = ACTIONS(5863),
    [anon_sym_REPEAT] = ACTIONS(5863),
    [anon_sym_Repeat] = ACTIONS(5863),
    [anon_sym_until] = ACTIONS(5863),
    [anon_sym_UNTIL] = ACTIONS(5863),
    [anon_sym_Until] = ACTIONS(5863),
    [anon_sym_exit] = ACTIONS(5863),
    [anon_sym_EXIT] = ACTIONS(5863),
    [anon_sym_Exit] = ACTIONS(5863),
    [anon_sym_continue] = ACTIONS(5863),
    [anon_sym_CONTINUE] = ACTIONS(5863),
    [anon_sym_Continue] = ACTIONS(5863),
    [anon_sym_break] = ACTIONS(5863),
    [anon_sym_BREAK] = ACTIONS(5863),
    [anon_sym_Break] = ACTIONS(5863),
    [anon_sym_with] = ACTIONS(5863),
    [anon_sym_WITH] = ACTIONS(5863),
    [anon_sym_With] = ACTIONS(5863),
    [sym_asserterror_keyword] = ACTIONS(5865),
    [sym_page_keyword] = ACTIONS(5863),
    [anon_sym_codeunit] = ACTIONS(5863),
    [anon_sym_CODEUNIT] = ACTIONS(5863),
    [anon_sym_Codeunit] = ACTIONS(5863),
    [anon_sym_CodeUnit] = ACTIONS(5863),
    [anon_sym_COdeunit] = ACTIONS(5863),
    [anon_sym_codeUnit] = ACTIONS(5863),
    [sym_report_keyword] = ACTIONS(5863),
    [sym_query_keyword] = ACTIONS(5863),
    [anon_sym_xmlport] = ACTIONS(5863),
    [anon_sym_XMLPORT] = ACTIONS(5863),
    [anon_sym_Xmlport] = ACTIONS(5863),
    [anon_sym_XMLport] = ACTIONS(5863),
    [anon_sym_XMLPort] = ACTIONS(5863),
    [anon_sym_XmlPort] = ACTIONS(5863),
    [anon_sym_enum] = ACTIONS(5863),
    [anon_sym_ENUM] = ACTIONS(5863),
    [anon_sym_Enum] = ACTIONS(5863),
    [anon_sym_eNUM] = ACTIONS(5863),
    [anon_sym_eNum] = ACTIONS(5863),
    [anon_sym_ENum] = ACTIONS(5863),
    [sym_quoted_identifier] = ACTIONS(5865),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5865),
    [sym_verbatim_string] = ACTIONS(5865),
    [sym_integer] = ACTIONS(5863),
    [sym_continue_as_identifier] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5865),
  },
  [STATE(3050)] = {
    [sym_identifier] = ACTIONS(5867),
    [anon_sym_SEMI] = ACTIONS(5869),
    [anon_sym_DASH] = ACTIONS(5869),
    [aux_sym_boolean_token1] = ACTIONS(5867),
    [aux_sym_boolean_token2] = ACTIONS(5867),
    [sym_decimal] = ACTIONS(5867),
    [anon_sym_LPAREN] = ACTIONS(5869),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5867),
    [anon_sym_LBRACK] = ACTIONS(5869),
    [aux_sym_record_type_token1] = ACTIONS(5867),
    [aux_sym_basic_type_token21] = ACTIONS(5867),
    [aux_sym_basic_type_token22] = ACTIONS(5867),
    [aux_sym_basic_type_token48] = ACTIONS(5867),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5867),
    [anon_sym_POUNDif] = ACTIONS(5869),
    [anon_sym_POUNDIF] = ACTIONS(5869),
    [anon_sym_POUNDIf] = ACTIONS(5869),
    [anon_sym_not] = ACTIONS(5867),
    [anon_sym_NOT] = ACTIONS(5867),
    [anon_sym_Not] = ACTIONS(5867),
    [anon_sym_POUNDelse] = ACTIONS(5869),
    [anon_sym_POUNDELSE] = ACTIONS(5869),
    [anon_sym_POUNDElse] = ACTIONS(5869),
    [anon_sym_POUNDelse2] = ACTIONS(5869),
    [anon_sym_POUNDELSE2] = ACTIONS(5869),
    [anon_sym_POUNDElse2] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5867),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5867),
    [anon_sym_PLUS] = ACTIONS(5869),
    [sym_datetime_literal] = ACTIONS(5869),
    [sym_date_literal] = ACTIONS(5867),
    [sym_time_literal] = ACTIONS(5867),
    [sym_biginteger_literal] = ACTIONS(5869),
    [anon_sym_if] = ACTIONS(5867),
    [anon_sym_IF] = ACTIONS(5867),
    [anon_sym_If] = ACTIONS(5867),
    [anon_sym_else] = ACTIONS(5867),
    [anon_sym_ELSE] = ACTIONS(5867),
    [anon_sym_Else] = ACTIONS(5867),
    [anon_sym_case] = ACTIONS(5867),
    [anon_sym_CASE] = ACTIONS(5867),
    [anon_sym_Case] = ACTIONS(5867),
    [anon_sym_for] = ACTIONS(5867),
    [anon_sym_FOR] = ACTIONS(5867),
    [anon_sym_For] = ACTIONS(5867),
    [anon_sym_foreach] = ACTIONS(5867),
    [anon_sym_FOREACH] = ACTIONS(5867),
    [anon_sym_Foreach] = ACTIONS(5867),
    [anon_sym_while] = ACTIONS(5867),
    [anon_sym_WHILE] = ACTIONS(5867),
    [anon_sym_While] = ACTIONS(5867),
    [anon_sym_repeat] = ACTIONS(5867),
    [anon_sym_REPEAT] = ACTIONS(5867),
    [anon_sym_Repeat] = ACTIONS(5867),
    [anon_sym_until] = ACTIONS(5867),
    [anon_sym_UNTIL] = ACTIONS(5867),
    [anon_sym_Until] = ACTIONS(5867),
    [anon_sym_exit] = ACTIONS(5867),
    [anon_sym_EXIT] = ACTIONS(5867),
    [anon_sym_Exit] = ACTIONS(5867),
    [anon_sym_continue] = ACTIONS(5867),
    [anon_sym_CONTINUE] = ACTIONS(5867),
    [anon_sym_Continue] = ACTIONS(5867),
    [anon_sym_break] = ACTIONS(5867),
    [anon_sym_BREAK] = ACTIONS(5867),
    [anon_sym_Break] = ACTIONS(5867),
    [anon_sym_with] = ACTIONS(5867),
    [anon_sym_WITH] = ACTIONS(5867),
    [anon_sym_With] = ACTIONS(5867),
    [sym_asserterror_keyword] = ACTIONS(5869),
    [sym_page_keyword] = ACTIONS(5867),
    [anon_sym_codeunit] = ACTIONS(5867),
    [anon_sym_CODEUNIT] = ACTIONS(5867),
    [anon_sym_Codeunit] = ACTIONS(5867),
    [anon_sym_CodeUnit] = ACTIONS(5867),
    [anon_sym_COdeunit] = ACTIONS(5867),
    [anon_sym_codeUnit] = ACTIONS(5867),
    [sym_report_keyword] = ACTIONS(5867),
    [sym_query_keyword] = ACTIONS(5867),
    [anon_sym_xmlport] = ACTIONS(5867),
    [anon_sym_XMLPORT] = ACTIONS(5867),
    [anon_sym_Xmlport] = ACTIONS(5867),
    [anon_sym_XMLport] = ACTIONS(5867),
    [anon_sym_XMLPort] = ACTIONS(5867),
    [anon_sym_XmlPort] = ACTIONS(5867),
    [anon_sym_enum] = ACTIONS(5867),
    [anon_sym_ENUM] = ACTIONS(5867),
    [anon_sym_Enum] = ACTIONS(5867),
    [anon_sym_eNUM] = ACTIONS(5867),
    [anon_sym_eNum] = ACTIONS(5867),
    [anon_sym_ENum] = ACTIONS(5867),
    [sym_quoted_identifier] = ACTIONS(5869),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5869),
    [sym_verbatim_string] = ACTIONS(5869),
    [sym_integer] = ACTIONS(5867),
    [sym_continue_as_identifier] = ACTIONS(5869),
    [sym_preproc_open] = ACTIONS(5869),
  },
  [STATE(3051)] = {
    [sym_identifier] = ACTIONS(5871),
    [anon_sym_SEMI] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [aux_sym_boolean_token1] = ACTIONS(5871),
    [aux_sym_boolean_token2] = ACTIONS(5871),
    [sym_decimal] = ACTIONS(5871),
    [anon_sym_LPAREN] = ACTIONS(5873),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5871),
    [anon_sym_LBRACK] = ACTIONS(5873),
    [aux_sym_record_type_token1] = ACTIONS(5871),
    [aux_sym_basic_type_token21] = ACTIONS(5871),
    [aux_sym_basic_type_token22] = ACTIONS(5871),
    [aux_sym_basic_type_token48] = ACTIONS(5871),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5871),
    [anon_sym_POUNDif] = ACTIONS(5873),
    [anon_sym_POUNDIF] = ACTIONS(5873),
    [anon_sym_POUNDIf] = ACTIONS(5873),
    [anon_sym_not] = ACTIONS(5871),
    [anon_sym_NOT] = ACTIONS(5871),
    [anon_sym_Not] = ACTIONS(5871),
    [anon_sym_POUNDelse] = ACTIONS(5873),
    [anon_sym_POUNDELSE] = ACTIONS(5873),
    [anon_sym_POUNDElse] = ACTIONS(5873),
    [anon_sym_POUNDelse2] = ACTIONS(5873),
    [anon_sym_POUNDELSE2] = ACTIONS(5873),
    [anon_sym_POUNDElse2] = ACTIONS(5873),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5871),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5871),
    [anon_sym_PLUS] = ACTIONS(5873),
    [sym_datetime_literal] = ACTIONS(5873),
    [sym_date_literal] = ACTIONS(5871),
    [sym_time_literal] = ACTIONS(5871),
    [sym_biginteger_literal] = ACTIONS(5873),
    [anon_sym_if] = ACTIONS(5871),
    [anon_sym_IF] = ACTIONS(5871),
    [anon_sym_If] = ACTIONS(5871),
    [anon_sym_else] = ACTIONS(5871),
    [anon_sym_ELSE] = ACTIONS(5871),
    [anon_sym_Else] = ACTIONS(5871),
    [anon_sym_case] = ACTIONS(5871),
    [anon_sym_CASE] = ACTIONS(5871),
    [anon_sym_Case] = ACTIONS(5871),
    [anon_sym_for] = ACTIONS(5871),
    [anon_sym_FOR] = ACTIONS(5871),
    [anon_sym_For] = ACTIONS(5871),
    [anon_sym_foreach] = ACTIONS(5871),
    [anon_sym_FOREACH] = ACTIONS(5871),
    [anon_sym_Foreach] = ACTIONS(5871),
    [anon_sym_while] = ACTIONS(5871),
    [anon_sym_WHILE] = ACTIONS(5871),
    [anon_sym_While] = ACTIONS(5871),
    [anon_sym_repeat] = ACTIONS(5871),
    [anon_sym_REPEAT] = ACTIONS(5871),
    [anon_sym_Repeat] = ACTIONS(5871),
    [anon_sym_until] = ACTIONS(5871),
    [anon_sym_UNTIL] = ACTIONS(5871),
    [anon_sym_Until] = ACTIONS(5871),
    [anon_sym_exit] = ACTIONS(5871),
    [anon_sym_EXIT] = ACTIONS(5871),
    [anon_sym_Exit] = ACTIONS(5871),
    [anon_sym_continue] = ACTIONS(5871),
    [anon_sym_CONTINUE] = ACTIONS(5871),
    [anon_sym_Continue] = ACTIONS(5871),
    [anon_sym_break] = ACTIONS(5871),
    [anon_sym_BREAK] = ACTIONS(5871),
    [anon_sym_Break] = ACTIONS(5871),
    [anon_sym_with] = ACTIONS(5871),
    [anon_sym_WITH] = ACTIONS(5871),
    [anon_sym_With] = ACTIONS(5871),
    [sym_asserterror_keyword] = ACTIONS(5873),
    [sym_page_keyword] = ACTIONS(5871),
    [anon_sym_codeunit] = ACTIONS(5871),
    [anon_sym_CODEUNIT] = ACTIONS(5871),
    [anon_sym_Codeunit] = ACTIONS(5871),
    [anon_sym_CodeUnit] = ACTIONS(5871),
    [anon_sym_COdeunit] = ACTIONS(5871),
    [anon_sym_codeUnit] = ACTIONS(5871),
    [sym_report_keyword] = ACTIONS(5871),
    [sym_query_keyword] = ACTIONS(5871),
    [anon_sym_xmlport] = ACTIONS(5871),
    [anon_sym_XMLPORT] = ACTIONS(5871),
    [anon_sym_Xmlport] = ACTIONS(5871),
    [anon_sym_XMLport] = ACTIONS(5871),
    [anon_sym_XMLPort] = ACTIONS(5871),
    [anon_sym_XmlPort] = ACTIONS(5871),
    [anon_sym_enum] = ACTIONS(5871),
    [anon_sym_ENUM] = ACTIONS(5871),
    [anon_sym_Enum] = ACTIONS(5871),
    [anon_sym_eNUM] = ACTIONS(5871),
    [anon_sym_eNum] = ACTIONS(5871),
    [anon_sym_ENum] = ACTIONS(5871),
    [sym_quoted_identifier] = ACTIONS(5873),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5873),
    [sym_verbatim_string] = ACTIONS(5873),
    [sym_integer] = ACTIONS(5871),
    [sym_continue_as_identifier] = ACTIONS(5873),
    [sym_preproc_open] = ACTIONS(5873),
  },
  [STATE(3052)] = {
    [sym_identifier] = ACTIONS(5875),
    [anon_sym_SEMI] = ACTIONS(5877),
    [anon_sym_DASH] = ACTIONS(5877),
    [aux_sym_boolean_token1] = ACTIONS(5875),
    [aux_sym_boolean_token2] = ACTIONS(5875),
    [sym_decimal] = ACTIONS(5875),
    [anon_sym_LPAREN] = ACTIONS(5877),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5875),
    [anon_sym_LBRACK] = ACTIONS(5877),
    [aux_sym_record_type_token1] = ACTIONS(5875),
    [aux_sym_basic_type_token21] = ACTIONS(5875),
    [aux_sym_basic_type_token22] = ACTIONS(5875),
    [aux_sym_basic_type_token48] = ACTIONS(5875),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5875),
    [anon_sym_POUNDif] = ACTIONS(5877),
    [anon_sym_POUNDIF] = ACTIONS(5877),
    [anon_sym_POUNDIf] = ACTIONS(5877),
    [anon_sym_not] = ACTIONS(5875),
    [anon_sym_NOT] = ACTIONS(5875),
    [anon_sym_Not] = ACTIONS(5875),
    [anon_sym_POUNDelse] = ACTIONS(5877),
    [anon_sym_POUNDELSE] = ACTIONS(5877),
    [anon_sym_POUNDElse] = ACTIONS(5877),
    [anon_sym_POUNDelse2] = ACTIONS(5877),
    [anon_sym_POUNDELSE2] = ACTIONS(5877),
    [anon_sym_POUNDElse2] = ACTIONS(5877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5875),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5875),
    [anon_sym_PLUS] = ACTIONS(5877),
    [sym_datetime_literal] = ACTIONS(5877),
    [sym_date_literal] = ACTIONS(5875),
    [sym_time_literal] = ACTIONS(5875),
    [sym_biginteger_literal] = ACTIONS(5877),
    [anon_sym_if] = ACTIONS(5875),
    [anon_sym_IF] = ACTIONS(5875),
    [anon_sym_If] = ACTIONS(5875),
    [anon_sym_else] = ACTIONS(5875),
    [anon_sym_ELSE] = ACTIONS(5875),
    [anon_sym_Else] = ACTIONS(5875),
    [anon_sym_case] = ACTIONS(5875),
    [anon_sym_CASE] = ACTIONS(5875),
    [anon_sym_Case] = ACTIONS(5875),
    [anon_sym_for] = ACTIONS(5875),
    [anon_sym_FOR] = ACTIONS(5875),
    [anon_sym_For] = ACTIONS(5875),
    [anon_sym_foreach] = ACTIONS(5875),
    [anon_sym_FOREACH] = ACTIONS(5875),
    [anon_sym_Foreach] = ACTIONS(5875),
    [anon_sym_while] = ACTIONS(5875),
    [anon_sym_WHILE] = ACTIONS(5875),
    [anon_sym_While] = ACTIONS(5875),
    [anon_sym_repeat] = ACTIONS(5875),
    [anon_sym_REPEAT] = ACTIONS(5875),
    [anon_sym_Repeat] = ACTIONS(5875),
    [anon_sym_until] = ACTIONS(5875),
    [anon_sym_UNTIL] = ACTIONS(5875),
    [anon_sym_Until] = ACTIONS(5875),
    [anon_sym_exit] = ACTIONS(5875),
    [anon_sym_EXIT] = ACTIONS(5875),
    [anon_sym_Exit] = ACTIONS(5875),
    [anon_sym_continue] = ACTIONS(5875),
    [anon_sym_CONTINUE] = ACTIONS(5875),
    [anon_sym_Continue] = ACTIONS(5875),
    [anon_sym_break] = ACTIONS(5875),
    [anon_sym_BREAK] = ACTIONS(5875),
    [anon_sym_Break] = ACTIONS(5875),
    [anon_sym_with] = ACTIONS(5875),
    [anon_sym_WITH] = ACTIONS(5875),
    [anon_sym_With] = ACTIONS(5875),
    [sym_asserterror_keyword] = ACTIONS(5877),
    [sym_page_keyword] = ACTIONS(5875),
    [anon_sym_codeunit] = ACTIONS(5875),
    [anon_sym_CODEUNIT] = ACTIONS(5875),
    [anon_sym_Codeunit] = ACTIONS(5875),
    [anon_sym_CodeUnit] = ACTIONS(5875),
    [anon_sym_COdeunit] = ACTIONS(5875),
    [anon_sym_codeUnit] = ACTIONS(5875),
    [sym_report_keyword] = ACTIONS(5875),
    [sym_query_keyword] = ACTIONS(5875),
    [anon_sym_xmlport] = ACTIONS(5875),
    [anon_sym_XMLPORT] = ACTIONS(5875),
    [anon_sym_Xmlport] = ACTIONS(5875),
    [anon_sym_XMLport] = ACTIONS(5875),
    [anon_sym_XMLPort] = ACTIONS(5875),
    [anon_sym_XmlPort] = ACTIONS(5875),
    [anon_sym_enum] = ACTIONS(5875),
    [anon_sym_ENUM] = ACTIONS(5875),
    [anon_sym_Enum] = ACTIONS(5875),
    [anon_sym_eNUM] = ACTIONS(5875),
    [anon_sym_eNum] = ACTIONS(5875),
    [anon_sym_ENum] = ACTIONS(5875),
    [sym_quoted_identifier] = ACTIONS(5877),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5877),
    [sym_verbatim_string] = ACTIONS(5877),
    [sym_integer] = ACTIONS(5875),
    [sym_continue_as_identifier] = ACTIONS(5877),
    [sym_preproc_open] = ACTIONS(5877),
  },
  [STATE(3053)] = {
    [sym_identifier] = ACTIONS(5879),
    [anon_sym_SEMI] = ACTIONS(5881),
    [anon_sym_DASH] = ACTIONS(5881),
    [aux_sym_boolean_token1] = ACTIONS(5879),
    [aux_sym_boolean_token2] = ACTIONS(5879),
    [sym_decimal] = ACTIONS(5879),
    [anon_sym_LPAREN] = ACTIONS(5881),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5879),
    [anon_sym_LBRACK] = ACTIONS(5881),
    [aux_sym_record_type_token1] = ACTIONS(5879),
    [aux_sym_basic_type_token21] = ACTIONS(5879),
    [aux_sym_basic_type_token22] = ACTIONS(5879),
    [aux_sym_basic_type_token48] = ACTIONS(5879),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5879),
    [anon_sym_POUNDif] = ACTIONS(5881),
    [anon_sym_POUNDIF] = ACTIONS(5881),
    [anon_sym_POUNDIf] = ACTIONS(5881),
    [anon_sym_not] = ACTIONS(5879),
    [anon_sym_NOT] = ACTIONS(5879),
    [anon_sym_Not] = ACTIONS(5879),
    [anon_sym_POUNDelse] = ACTIONS(5881),
    [anon_sym_POUNDELSE] = ACTIONS(5881),
    [anon_sym_POUNDElse] = ACTIONS(5881),
    [anon_sym_POUNDelse2] = ACTIONS(5881),
    [anon_sym_POUNDELSE2] = ACTIONS(5881),
    [anon_sym_POUNDElse2] = ACTIONS(5881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5879),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5879),
    [anon_sym_PLUS] = ACTIONS(5881),
    [sym_datetime_literal] = ACTIONS(5881),
    [sym_date_literal] = ACTIONS(5879),
    [sym_time_literal] = ACTIONS(5879),
    [sym_biginteger_literal] = ACTIONS(5881),
    [anon_sym_if] = ACTIONS(5879),
    [anon_sym_IF] = ACTIONS(5879),
    [anon_sym_If] = ACTIONS(5879),
    [anon_sym_else] = ACTIONS(5879),
    [anon_sym_ELSE] = ACTIONS(5879),
    [anon_sym_Else] = ACTIONS(5879),
    [anon_sym_case] = ACTIONS(5879),
    [anon_sym_CASE] = ACTIONS(5879),
    [anon_sym_Case] = ACTIONS(5879),
    [anon_sym_for] = ACTIONS(5879),
    [anon_sym_FOR] = ACTIONS(5879),
    [anon_sym_For] = ACTIONS(5879),
    [anon_sym_foreach] = ACTIONS(5879),
    [anon_sym_FOREACH] = ACTIONS(5879),
    [anon_sym_Foreach] = ACTIONS(5879),
    [anon_sym_while] = ACTIONS(5879),
    [anon_sym_WHILE] = ACTIONS(5879),
    [anon_sym_While] = ACTIONS(5879),
    [anon_sym_repeat] = ACTIONS(5879),
    [anon_sym_REPEAT] = ACTIONS(5879),
    [anon_sym_Repeat] = ACTIONS(5879),
    [anon_sym_until] = ACTIONS(5879),
    [anon_sym_UNTIL] = ACTIONS(5879),
    [anon_sym_Until] = ACTIONS(5879),
    [anon_sym_exit] = ACTIONS(5879),
    [anon_sym_EXIT] = ACTIONS(5879),
    [anon_sym_Exit] = ACTIONS(5879),
    [anon_sym_continue] = ACTIONS(5879),
    [anon_sym_CONTINUE] = ACTIONS(5879),
    [anon_sym_Continue] = ACTIONS(5879),
    [anon_sym_break] = ACTIONS(5879),
    [anon_sym_BREAK] = ACTIONS(5879),
    [anon_sym_Break] = ACTIONS(5879),
    [anon_sym_with] = ACTIONS(5879),
    [anon_sym_WITH] = ACTIONS(5879),
    [anon_sym_With] = ACTIONS(5879),
    [sym_asserterror_keyword] = ACTIONS(5881),
    [sym_page_keyword] = ACTIONS(5879),
    [anon_sym_codeunit] = ACTIONS(5879),
    [anon_sym_CODEUNIT] = ACTIONS(5879),
    [anon_sym_Codeunit] = ACTIONS(5879),
    [anon_sym_CodeUnit] = ACTIONS(5879),
    [anon_sym_COdeunit] = ACTIONS(5879),
    [anon_sym_codeUnit] = ACTIONS(5879),
    [sym_report_keyword] = ACTIONS(5879),
    [sym_query_keyword] = ACTIONS(5879),
    [anon_sym_xmlport] = ACTIONS(5879),
    [anon_sym_XMLPORT] = ACTIONS(5879),
    [anon_sym_Xmlport] = ACTIONS(5879),
    [anon_sym_XMLport] = ACTIONS(5879),
    [anon_sym_XMLPort] = ACTIONS(5879),
    [anon_sym_XmlPort] = ACTIONS(5879),
    [anon_sym_enum] = ACTIONS(5879),
    [anon_sym_ENUM] = ACTIONS(5879),
    [anon_sym_Enum] = ACTIONS(5879),
    [anon_sym_eNUM] = ACTIONS(5879),
    [anon_sym_eNum] = ACTIONS(5879),
    [anon_sym_ENum] = ACTIONS(5879),
    [sym_quoted_identifier] = ACTIONS(5881),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5881),
    [sym_verbatim_string] = ACTIONS(5881),
    [sym_integer] = ACTIONS(5879),
    [sym_continue_as_identifier] = ACTIONS(5881),
    [sym_preproc_open] = ACTIONS(5881),
  },
  [STATE(3054)] = {
    [sym_identifier] = ACTIONS(5883),
    [anon_sym_SEMI] = ACTIONS(5885),
    [anon_sym_DASH] = ACTIONS(5885),
    [aux_sym_boolean_token1] = ACTIONS(5883),
    [aux_sym_boolean_token2] = ACTIONS(5883),
    [sym_decimal] = ACTIONS(5883),
    [anon_sym_LPAREN] = ACTIONS(5885),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5883),
    [anon_sym_LBRACK] = ACTIONS(5885),
    [aux_sym_record_type_token1] = ACTIONS(5883),
    [aux_sym_basic_type_token21] = ACTIONS(5883),
    [aux_sym_basic_type_token22] = ACTIONS(5883),
    [aux_sym_basic_type_token48] = ACTIONS(5883),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5883),
    [anon_sym_POUNDif] = ACTIONS(5885),
    [anon_sym_POUNDIF] = ACTIONS(5885),
    [anon_sym_POUNDIf] = ACTIONS(5885),
    [anon_sym_not] = ACTIONS(5883),
    [anon_sym_NOT] = ACTIONS(5883),
    [anon_sym_Not] = ACTIONS(5883),
    [anon_sym_POUNDelse] = ACTIONS(5885),
    [anon_sym_POUNDELSE] = ACTIONS(5885),
    [anon_sym_POUNDElse] = ACTIONS(5885),
    [anon_sym_POUNDelse2] = ACTIONS(5885),
    [anon_sym_POUNDELSE2] = ACTIONS(5885),
    [anon_sym_POUNDElse2] = ACTIONS(5885),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5883),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5883),
    [anon_sym_PLUS] = ACTIONS(5885),
    [sym_datetime_literal] = ACTIONS(5885),
    [sym_date_literal] = ACTIONS(5883),
    [sym_time_literal] = ACTIONS(5883),
    [sym_biginteger_literal] = ACTIONS(5885),
    [anon_sym_if] = ACTIONS(5883),
    [anon_sym_IF] = ACTIONS(5883),
    [anon_sym_If] = ACTIONS(5883),
    [anon_sym_else] = ACTIONS(5883),
    [anon_sym_ELSE] = ACTIONS(5883),
    [anon_sym_Else] = ACTIONS(5883),
    [anon_sym_case] = ACTIONS(5883),
    [anon_sym_CASE] = ACTIONS(5883),
    [anon_sym_Case] = ACTIONS(5883),
    [anon_sym_for] = ACTIONS(5883),
    [anon_sym_FOR] = ACTIONS(5883),
    [anon_sym_For] = ACTIONS(5883),
    [anon_sym_foreach] = ACTIONS(5883),
    [anon_sym_FOREACH] = ACTIONS(5883),
    [anon_sym_Foreach] = ACTIONS(5883),
    [anon_sym_while] = ACTIONS(5883),
    [anon_sym_WHILE] = ACTIONS(5883),
    [anon_sym_While] = ACTIONS(5883),
    [anon_sym_repeat] = ACTIONS(5883),
    [anon_sym_REPEAT] = ACTIONS(5883),
    [anon_sym_Repeat] = ACTIONS(5883),
    [anon_sym_until] = ACTIONS(5883),
    [anon_sym_UNTIL] = ACTIONS(5883),
    [anon_sym_Until] = ACTIONS(5883),
    [anon_sym_exit] = ACTIONS(5883),
    [anon_sym_EXIT] = ACTIONS(5883),
    [anon_sym_Exit] = ACTIONS(5883),
    [anon_sym_continue] = ACTIONS(5883),
    [anon_sym_CONTINUE] = ACTIONS(5883),
    [anon_sym_Continue] = ACTIONS(5883),
    [anon_sym_break] = ACTIONS(5883),
    [anon_sym_BREAK] = ACTIONS(5883),
    [anon_sym_Break] = ACTIONS(5883),
    [anon_sym_with] = ACTIONS(5883),
    [anon_sym_WITH] = ACTIONS(5883),
    [anon_sym_With] = ACTIONS(5883),
    [sym_asserterror_keyword] = ACTIONS(5885),
    [sym_page_keyword] = ACTIONS(5883),
    [anon_sym_codeunit] = ACTIONS(5883),
    [anon_sym_CODEUNIT] = ACTIONS(5883),
    [anon_sym_Codeunit] = ACTIONS(5883),
    [anon_sym_CodeUnit] = ACTIONS(5883),
    [anon_sym_COdeunit] = ACTIONS(5883),
    [anon_sym_codeUnit] = ACTIONS(5883),
    [sym_report_keyword] = ACTIONS(5883),
    [sym_query_keyword] = ACTIONS(5883),
    [anon_sym_xmlport] = ACTIONS(5883),
    [anon_sym_XMLPORT] = ACTIONS(5883),
    [anon_sym_Xmlport] = ACTIONS(5883),
    [anon_sym_XMLport] = ACTIONS(5883),
    [anon_sym_XMLPort] = ACTIONS(5883),
    [anon_sym_XmlPort] = ACTIONS(5883),
    [anon_sym_enum] = ACTIONS(5883),
    [anon_sym_ENUM] = ACTIONS(5883),
    [anon_sym_Enum] = ACTIONS(5883),
    [anon_sym_eNUM] = ACTIONS(5883),
    [anon_sym_eNum] = ACTIONS(5883),
    [anon_sym_ENum] = ACTIONS(5883),
    [sym_quoted_identifier] = ACTIONS(5885),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5885),
    [sym_verbatim_string] = ACTIONS(5885),
    [sym_integer] = ACTIONS(5883),
    [sym_continue_as_identifier] = ACTIONS(5885),
    [sym_preproc_open] = ACTIONS(5885),
  },
  [STATE(3055)] = {
    [sym_identifier] = ACTIONS(5887),
    [anon_sym_SEMI] = ACTIONS(5889),
    [anon_sym_DASH] = ACTIONS(5889),
    [aux_sym_boolean_token1] = ACTIONS(5887),
    [aux_sym_boolean_token2] = ACTIONS(5887),
    [sym_decimal] = ACTIONS(5887),
    [anon_sym_LPAREN] = ACTIONS(5889),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5887),
    [anon_sym_LBRACK] = ACTIONS(5889),
    [aux_sym_record_type_token1] = ACTIONS(5887),
    [aux_sym_basic_type_token21] = ACTIONS(5887),
    [aux_sym_basic_type_token22] = ACTIONS(5887),
    [aux_sym_basic_type_token48] = ACTIONS(5887),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5887),
    [anon_sym_POUNDif] = ACTIONS(5889),
    [anon_sym_POUNDIF] = ACTIONS(5889),
    [anon_sym_POUNDIf] = ACTIONS(5889),
    [anon_sym_not] = ACTIONS(5887),
    [anon_sym_NOT] = ACTIONS(5887),
    [anon_sym_Not] = ACTIONS(5887),
    [anon_sym_POUNDelse] = ACTIONS(5889),
    [anon_sym_POUNDELSE] = ACTIONS(5889),
    [anon_sym_POUNDElse] = ACTIONS(5889),
    [anon_sym_POUNDelse2] = ACTIONS(5889),
    [anon_sym_POUNDELSE2] = ACTIONS(5889),
    [anon_sym_POUNDElse2] = ACTIONS(5889),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5887),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5887),
    [anon_sym_PLUS] = ACTIONS(5889),
    [sym_datetime_literal] = ACTIONS(5889),
    [sym_date_literal] = ACTIONS(5887),
    [sym_time_literal] = ACTIONS(5887),
    [sym_biginteger_literal] = ACTIONS(5889),
    [anon_sym_if] = ACTIONS(5887),
    [anon_sym_IF] = ACTIONS(5887),
    [anon_sym_If] = ACTIONS(5887),
    [anon_sym_else] = ACTIONS(5887),
    [anon_sym_ELSE] = ACTIONS(5887),
    [anon_sym_Else] = ACTIONS(5887),
    [anon_sym_case] = ACTIONS(5887),
    [anon_sym_CASE] = ACTIONS(5887),
    [anon_sym_Case] = ACTIONS(5887),
    [anon_sym_for] = ACTIONS(5887),
    [anon_sym_FOR] = ACTIONS(5887),
    [anon_sym_For] = ACTIONS(5887),
    [anon_sym_foreach] = ACTIONS(5887),
    [anon_sym_FOREACH] = ACTIONS(5887),
    [anon_sym_Foreach] = ACTIONS(5887),
    [anon_sym_while] = ACTIONS(5887),
    [anon_sym_WHILE] = ACTIONS(5887),
    [anon_sym_While] = ACTIONS(5887),
    [anon_sym_repeat] = ACTIONS(5887),
    [anon_sym_REPEAT] = ACTIONS(5887),
    [anon_sym_Repeat] = ACTIONS(5887),
    [anon_sym_until] = ACTIONS(5887),
    [anon_sym_UNTIL] = ACTIONS(5887),
    [anon_sym_Until] = ACTIONS(5887),
    [anon_sym_exit] = ACTIONS(5887),
    [anon_sym_EXIT] = ACTIONS(5887),
    [anon_sym_Exit] = ACTIONS(5887),
    [anon_sym_continue] = ACTIONS(5887),
    [anon_sym_CONTINUE] = ACTIONS(5887),
    [anon_sym_Continue] = ACTIONS(5887),
    [anon_sym_break] = ACTIONS(5887),
    [anon_sym_BREAK] = ACTIONS(5887),
    [anon_sym_Break] = ACTIONS(5887),
    [anon_sym_with] = ACTIONS(5887),
    [anon_sym_WITH] = ACTIONS(5887),
    [anon_sym_With] = ACTIONS(5887),
    [sym_asserterror_keyword] = ACTIONS(5889),
    [sym_page_keyword] = ACTIONS(5887),
    [anon_sym_codeunit] = ACTIONS(5887),
    [anon_sym_CODEUNIT] = ACTIONS(5887),
    [anon_sym_Codeunit] = ACTIONS(5887),
    [anon_sym_CodeUnit] = ACTIONS(5887),
    [anon_sym_COdeunit] = ACTIONS(5887),
    [anon_sym_codeUnit] = ACTIONS(5887),
    [sym_report_keyword] = ACTIONS(5887),
    [sym_query_keyword] = ACTIONS(5887),
    [anon_sym_xmlport] = ACTIONS(5887),
    [anon_sym_XMLPORT] = ACTIONS(5887),
    [anon_sym_Xmlport] = ACTIONS(5887),
    [anon_sym_XMLport] = ACTIONS(5887),
    [anon_sym_XMLPort] = ACTIONS(5887),
    [anon_sym_XmlPort] = ACTIONS(5887),
    [anon_sym_enum] = ACTIONS(5887),
    [anon_sym_ENUM] = ACTIONS(5887),
    [anon_sym_Enum] = ACTIONS(5887),
    [anon_sym_eNUM] = ACTIONS(5887),
    [anon_sym_eNum] = ACTIONS(5887),
    [anon_sym_ENum] = ACTIONS(5887),
    [sym_quoted_identifier] = ACTIONS(5889),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5889),
    [sym_verbatim_string] = ACTIONS(5889),
    [sym_integer] = ACTIONS(5887),
    [sym_continue_as_identifier] = ACTIONS(5889),
    [sym_preproc_open] = ACTIONS(5889),
  },
  [STATE(3056)] = {
    [sym_identifier] = ACTIONS(5891),
    [anon_sym_SEMI] = ACTIONS(5893),
    [anon_sym_DASH] = ACTIONS(5893),
    [aux_sym_boolean_token1] = ACTIONS(5891),
    [aux_sym_boolean_token2] = ACTIONS(5891),
    [sym_decimal] = ACTIONS(5891),
    [anon_sym_LPAREN] = ACTIONS(5893),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5891),
    [anon_sym_LBRACK] = ACTIONS(5893),
    [aux_sym_record_type_token1] = ACTIONS(5891),
    [aux_sym_basic_type_token21] = ACTIONS(5891),
    [aux_sym_basic_type_token22] = ACTIONS(5891),
    [aux_sym_basic_type_token48] = ACTIONS(5891),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5891),
    [anon_sym_POUNDif] = ACTIONS(5893),
    [anon_sym_POUNDIF] = ACTIONS(5893),
    [anon_sym_POUNDIf] = ACTIONS(5893),
    [anon_sym_not] = ACTIONS(5891),
    [anon_sym_NOT] = ACTIONS(5891),
    [anon_sym_Not] = ACTIONS(5891),
    [anon_sym_POUNDelse] = ACTIONS(5893),
    [anon_sym_POUNDELSE] = ACTIONS(5893),
    [anon_sym_POUNDElse] = ACTIONS(5893),
    [anon_sym_POUNDelse2] = ACTIONS(5893),
    [anon_sym_POUNDELSE2] = ACTIONS(5893),
    [anon_sym_POUNDElse2] = ACTIONS(5893),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5891),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5891),
    [anon_sym_PLUS] = ACTIONS(5893),
    [sym_datetime_literal] = ACTIONS(5893),
    [sym_date_literal] = ACTIONS(5891),
    [sym_time_literal] = ACTIONS(5891),
    [sym_biginteger_literal] = ACTIONS(5893),
    [anon_sym_if] = ACTIONS(5891),
    [anon_sym_IF] = ACTIONS(5891),
    [anon_sym_If] = ACTIONS(5891),
    [anon_sym_else] = ACTIONS(5891),
    [anon_sym_ELSE] = ACTIONS(5891),
    [anon_sym_Else] = ACTIONS(5891),
    [anon_sym_case] = ACTIONS(5891),
    [anon_sym_CASE] = ACTIONS(5891),
    [anon_sym_Case] = ACTIONS(5891),
    [anon_sym_for] = ACTIONS(5891),
    [anon_sym_FOR] = ACTIONS(5891),
    [anon_sym_For] = ACTIONS(5891),
    [anon_sym_foreach] = ACTIONS(5891),
    [anon_sym_FOREACH] = ACTIONS(5891),
    [anon_sym_Foreach] = ACTIONS(5891),
    [anon_sym_while] = ACTIONS(5891),
    [anon_sym_WHILE] = ACTIONS(5891),
    [anon_sym_While] = ACTIONS(5891),
    [anon_sym_repeat] = ACTIONS(5891),
    [anon_sym_REPEAT] = ACTIONS(5891),
    [anon_sym_Repeat] = ACTIONS(5891),
    [anon_sym_until] = ACTIONS(5891),
    [anon_sym_UNTIL] = ACTIONS(5891),
    [anon_sym_Until] = ACTIONS(5891),
    [anon_sym_exit] = ACTIONS(5891),
    [anon_sym_EXIT] = ACTIONS(5891),
    [anon_sym_Exit] = ACTIONS(5891),
    [anon_sym_continue] = ACTIONS(5891),
    [anon_sym_CONTINUE] = ACTIONS(5891),
    [anon_sym_Continue] = ACTIONS(5891),
    [anon_sym_break] = ACTIONS(5891),
    [anon_sym_BREAK] = ACTIONS(5891),
    [anon_sym_Break] = ACTIONS(5891),
    [anon_sym_with] = ACTIONS(5891),
    [anon_sym_WITH] = ACTIONS(5891),
    [anon_sym_With] = ACTIONS(5891),
    [sym_asserterror_keyword] = ACTIONS(5893),
    [sym_page_keyword] = ACTIONS(5891),
    [anon_sym_codeunit] = ACTIONS(5891),
    [anon_sym_CODEUNIT] = ACTIONS(5891),
    [anon_sym_Codeunit] = ACTIONS(5891),
    [anon_sym_CodeUnit] = ACTIONS(5891),
    [anon_sym_COdeunit] = ACTIONS(5891),
    [anon_sym_codeUnit] = ACTIONS(5891),
    [sym_report_keyword] = ACTIONS(5891),
    [sym_query_keyword] = ACTIONS(5891),
    [anon_sym_xmlport] = ACTIONS(5891),
    [anon_sym_XMLPORT] = ACTIONS(5891),
    [anon_sym_Xmlport] = ACTIONS(5891),
    [anon_sym_XMLport] = ACTIONS(5891),
    [anon_sym_XMLPort] = ACTIONS(5891),
    [anon_sym_XmlPort] = ACTIONS(5891),
    [anon_sym_enum] = ACTIONS(5891),
    [anon_sym_ENUM] = ACTIONS(5891),
    [anon_sym_Enum] = ACTIONS(5891),
    [anon_sym_eNUM] = ACTIONS(5891),
    [anon_sym_eNum] = ACTIONS(5891),
    [anon_sym_ENum] = ACTIONS(5891),
    [sym_quoted_identifier] = ACTIONS(5893),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5893),
    [sym_verbatim_string] = ACTIONS(5893),
    [sym_integer] = ACTIONS(5891),
    [sym_continue_as_identifier] = ACTIONS(5893),
    [sym_preproc_open] = ACTIONS(5893),
  },
  [STATE(3057)] = {
    [sym_identifier] = ACTIONS(5895),
    [anon_sym_SEMI] = ACTIONS(5897),
    [anon_sym_DASH] = ACTIONS(5897),
    [aux_sym_boolean_token1] = ACTIONS(5895),
    [aux_sym_boolean_token2] = ACTIONS(5895),
    [sym_decimal] = ACTIONS(5895),
    [anon_sym_LPAREN] = ACTIONS(5897),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5895),
    [anon_sym_LBRACK] = ACTIONS(5897),
    [aux_sym_record_type_token1] = ACTIONS(5895),
    [aux_sym_basic_type_token21] = ACTIONS(5895),
    [aux_sym_basic_type_token22] = ACTIONS(5895),
    [aux_sym_basic_type_token48] = ACTIONS(5895),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5895),
    [anon_sym_POUNDif] = ACTIONS(5897),
    [anon_sym_POUNDIF] = ACTIONS(5897),
    [anon_sym_POUNDIf] = ACTIONS(5897),
    [anon_sym_not] = ACTIONS(5895),
    [anon_sym_NOT] = ACTIONS(5895),
    [anon_sym_Not] = ACTIONS(5895),
    [anon_sym_POUNDelse] = ACTIONS(5897),
    [anon_sym_POUNDELSE] = ACTIONS(5897),
    [anon_sym_POUNDElse] = ACTIONS(5897),
    [anon_sym_POUNDelse2] = ACTIONS(5897),
    [anon_sym_POUNDELSE2] = ACTIONS(5897),
    [anon_sym_POUNDElse2] = ACTIONS(5897),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5895),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5895),
    [anon_sym_PLUS] = ACTIONS(5897),
    [sym_datetime_literal] = ACTIONS(5897),
    [sym_date_literal] = ACTIONS(5895),
    [sym_time_literal] = ACTIONS(5895),
    [sym_biginteger_literal] = ACTIONS(5897),
    [anon_sym_if] = ACTIONS(5895),
    [anon_sym_IF] = ACTIONS(5895),
    [anon_sym_If] = ACTIONS(5895),
    [anon_sym_else] = ACTIONS(5895),
    [anon_sym_ELSE] = ACTIONS(5895),
    [anon_sym_Else] = ACTIONS(5895),
    [anon_sym_case] = ACTIONS(5895),
    [anon_sym_CASE] = ACTIONS(5895),
    [anon_sym_Case] = ACTIONS(5895),
    [anon_sym_for] = ACTIONS(5895),
    [anon_sym_FOR] = ACTIONS(5895),
    [anon_sym_For] = ACTIONS(5895),
    [anon_sym_foreach] = ACTIONS(5895),
    [anon_sym_FOREACH] = ACTIONS(5895),
    [anon_sym_Foreach] = ACTIONS(5895),
    [anon_sym_while] = ACTIONS(5895),
    [anon_sym_WHILE] = ACTIONS(5895),
    [anon_sym_While] = ACTIONS(5895),
    [anon_sym_repeat] = ACTIONS(5895),
    [anon_sym_REPEAT] = ACTIONS(5895),
    [anon_sym_Repeat] = ACTIONS(5895),
    [anon_sym_until] = ACTIONS(5895),
    [anon_sym_UNTIL] = ACTIONS(5895),
    [anon_sym_Until] = ACTIONS(5895),
    [anon_sym_exit] = ACTIONS(5895),
    [anon_sym_EXIT] = ACTIONS(5895),
    [anon_sym_Exit] = ACTIONS(5895),
    [anon_sym_continue] = ACTIONS(5895),
    [anon_sym_CONTINUE] = ACTIONS(5895),
    [anon_sym_Continue] = ACTIONS(5895),
    [anon_sym_break] = ACTIONS(5895),
    [anon_sym_BREAK] = ACTIONS(5895),
    [anon_sym_Break] = ACTIONS(5895),
    [anon_sym_with] = ACTIONS(5895),
    [anon_sym_WITH] = ACTIONS(5895),
    [anon_sym_With] = ACTIONS(5895),
    [sym_asserterror_keyword] = ACTIONS(5897),
    [sym_page_keyword] = ACTIONS(5895),
    [anon_sym_codeunit] = ACTIONS(5895),
    [anon_sym_CODEUNIT] = ACTIONS(5895),
    [anon_sym_Codeunit] = ACTIONS(5895),
    [anon_sym_CodeUnit] = ACTIONS(5895),
    [anon_sym_COdeunit] = ACTIONS(5895),
    [anon_sym_codeUnit] = ACTIONS(5895),
    [sym_report_keyword] = ACTIONS(5895),
    [sym_query_keyword] = ACTIONS(5895),
    [anon_sym_xmlport] = ACTIONS(5895),
    [anon_sym_XMLPORT] = ACTIONS(5895),
    [anon_sym_Xmlport] = ACTIONS(5895),
    [anon_sym_XMLport] = ACTIONS(5895),
    [anon_sym_XMLPort] = ACTIONS(5895),
    [anon_sym_XmlPort] = ACTIONS(5895),
    [anon_sym_enum] = ACTIONS(5895),
    [anon_sym_ENUM] = ACTIONS(5895),
    [anon_sym_Enum] = ACTIONS(5895),
    [anon_sym_eNUM] = ACTIONS(5895),
    [anon_sym_eNum] = ACTIONS(5895),
    [anon_sym_ENum] = ACTIONS(5895),
    [sym_quoted_identifier] = ACTIONS(5897),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5897),
    [sym_verbatim_string] = ACTIONS(5897),
    [sym_integer] = ACTIONS(5895),
    [sym_continue_as_identifier] = ACTIONS(5897),
    [sym_preproc_open] = ACTIONS(5897),
  },
  [STATE(3058)] = {
    [sym_identifier] = ACTIONS(5899),
    [anon_sym_SEMI] = ACTIONS(5901),
    [anon_sym_DASH] = ACTIONS(5901),
    [aux_sym_boolean_token1] = ACTIONS(5899),
    [aux_sym_boolean_token2] = ACTIONS(5899),
    [sym_decimal] = ACTIONS(5899),
    [anon_sym_LPAREN] = ACTIONS(5901),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5899),
    [anon_sym_LBRACK] = ACTIONS(5901),
    [aux_sym_record_type_token1] = ACTIONS(5899),
    [aux_sym_basic_type_token21] = ACTIONS(5899),
    [aux_sym_basic_type_token22] = ACTIONS(5899),
    [aux_sym_basic_type_token48] = ACTIONS(5899),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5899),
    [anon_sym_POUNDif] = ACTIONS(5901),
    [anon_sym_POUNDIF] = ACTIONS(5901),
    [anon_sym_POUNDIf] = ACTIONS(5901),
    [anon_sym_not] = ACTIONS(5899),
    [anon_sym_NOT] = ACTIONS(5899),
    [anon_sym_Not] = ACTIONS(5899),
    [anon_sym_POUNDelse] = ACTIONS(5901),
    [anon_sym_POUNDELSE] = ACTIONS(5901),
    [anon_sym_POUNDElse] = ACTIONS(5901),
    [anon_sym_POUNDelse2] = ACTIONS(5901),
    [anon_sym_POUNDELSE2] = ACTIONS(5901),
    [anon_sym_POUNDElse2] = ACTIONS(5901),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5899),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5899),
    [anon_sym_PLUS] = ACTIONS(5901),
    [sym_datetime_literal] = ACTIONS(5901),
    [sym_date_literal] = ACTIONS(5899),
    [sym_time_literal] = ACTIONS(5899),
    [sym_biginteger_literal] = ACTIONS(5901),
    [anon_sym_if] = ACTIONS(5899),
    [anon_sym_IF] = ACTIONS(5899),
    [anon_sym_If] = ACTIONS(5899),
    [anon_sym_else] = ACTIONS(5899),
    [anon_sym_ELSE] = ACTIONS(5899),
    [anon_sym_Else] = ACTIONS(5899),
    [anon_sym_case] = ACTIONS(5899),
    [anon_sym_CASE] = ACTIONS(5899),
    [anon_sym_Case] = ACTIONS(5899),
    [anon_sym_for] = ACTIONS(5899),
    [anon_sym_FOR] = ACTIONS(5899),
    [anon_sym_For] = ACTIONS(5899),
    [anon_sym_foreach] = ACTIONS(5899),
    [anon_sym_FOREACH] = ACTIONS(5899),
    [anon_sym_Foreach] = ACTIONS(5899),
    [anon_sym_while] = ACTIONS(5899),
    [anon_sym_WHILE] = ACTIONS(5899),
    [anon_sym_While] = ACTIONS(5899),
    [anon_sym_repeat] = ACTIONS(5899),
    [anon_sym_REPEAT] = ACTIONS(5899),
    [anon_sym_Repeat] = ACTIONS(5899),
    [anon_sym_until] = ACTIONS(5899),
    [anon_sym_UNTIL] = ACTIONS(5899),
    [anon_sym_Until] = ACTIONS(5899),
    [anon_sym_exit] = ACTIONS(5899),
    [anon_sym_EXIT] = ACTIONS(5899),
    [anon_sym_Exit] = ACTIONS(5899),
    [anon_sym_continue] = ACTIONS(5899),
    [anon_sym_CONTINUE] = ACTIONS(5899),
    [anon_sym_Continue] = ACTIONS(5899),
    [anon_sym_break] = ACTIONS(5899),
    [anon_sym_BREAK] = ACTIONS(5899),
    [anon_sym_Break] = ACTIONS(5899),
    [anon_sym_with] = ACTIONS(5899),
    [anon_sym_WITH] = ACTIONS(5899),
    [anon_sym_With] = ACTIONS(5899),
    [sym_asserterror_keyword] = ACTIONS(5901),
    [sym_page_keyword] = ACTIONS(5899),
    [anon_sym_codeunit] = ACTIONS(5899),
    [anon_sym_CODEUNIT] = ACTIONS(5899),
    [anon_sym_Codeunit] = ACTIONS(5899),
    [anon_sym_CodeUnit] = ACTIONS(5899),
    [anon_sym_COdeunit] = ACTIONS(5899),
    [anon_sym_codeUnit] = ACTIONS(5899),
    [sym_report_keyword] = ACTIONS(5899),
    [sym_query_keyword] = ACTIONS(5899),
    [anon_sym_xmlport] = ACTIONS(5899),
    [anon_sym_XMLPORT] = ACTIONS(5899),
    [anon_sym_Xmlport] = ACTIONS(5899),
    [anon_sym_XMLport] = ACTIONS(5899),
    [anon_sym_XMLPort] = ACTIONS(5899),
    [anon_sym_XmlPort] = ACTIONS(5899),
    [anon_sym_enum] = ACTIONS(5899),
    [anon_sym_ENUM] = ACTIONS(5899),
    [anon_sym_Enum] = ACTIONS(5899),
    [anon_sym_eNUM] = ACTIONS(5899),
    [anon_sym_eNum] = ACTIONS(5899),
    [anon_sym_ENum] = ACTIONS(5899),
    [sym_quoted_identifier] = ACTIONS(5901),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5901),
    [sym_verbatim_string] = ACTIONS(5901),
    [sym_integer] = ACTIONS(5899),
    [sym_continue_as_identifier] = ACTIONS(5901),
    [sym_preproc_open] = ACTIONS(5901),
  },
  [STATE(3059)] = {
    [sym_identifier] = ACTIONS(5903),
    [anon_sym_SEMI] = ACTIONS(5905),
    [anon_sym_DASH] = ACTIONS(5905),
    [aux_sym_boolean_token1] = ACTIONS(5903),
    [aux_sym_boolean_token2] = ACTIONS(5903),
    [sym_decimal] = ACTIONS(5903),
    [anon_sym_LPAREN] = ACTIONS(5905),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5903),
    [anon_sym_LBRACK] = ACTIONS(5905),
    [aux_sym_record_type_token1] = ACTIONS(5903),
    [aux_sym_basic_type_token21] = ACTIONS(5903),
    [aux_sym_basic_type_token22] = ACTIONS(5903),
    [aux_sym_basic_type_token48] = ACTIONS(5903),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5903),
    [anon_sym_POUNDif] = ACTIONS(5905),
    [anon_sym_POUNDIF] = ACTIONS(5905),
    [anon_sym_POUNDIf] = ACTIONS(5905),
    [anon_sym_not] = ACTIONS(5903),
    [anon_sym_NOT] = ACTIONS(5903),
    [anon_sym_Not] = ACTIONS(5903),
    [anon_sym_POUNDelse] = ACTIONS(5905),
    [anon_sym_POUNDELSE] = ACTIONS(5905),
    [anon_sym_POUNDElse] = ACTIONS(5905),
    [anon_sym_POUNDelse2] = ACTIONS(5905),
    [anon_sym_POUNDELSE2] = ACTIONS(5905),
    [anon_sym_POUNDElse2] = ACTIONS(5905),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5903),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5903),
    [anon_sym_PLUS] = ACTIONS(5905),
    [sym_datetime_literal] = ACTIONS(5905),
    [sym_date_literal] = ACTIONS(5903),
    [sym_time_literal] = ACTIONS(5903),
    [sym_biginteger_literal] = ACTIONS(5905),
    [anon_sym_if] = ACTIONS(5903),
    [anon_sym_IF] = ACTIONS(5903),
    [anon_sym_If] = ACTIONS(5903),
    [anon_sym_else] = ACTIONS(5903),
    [anon_sym_ELSE] = ACTIONS(5903),
    [anon_sym_Else] = ACTIONS(5903),
    [anon_sym_case] = ACTIONS(5903),
    [anon_sym_CASE] = ACTIONS(5903),
    [anon_sym_Case] = ACTIONS(5903),
    [anon_sym_for] = ACTIONS(5903),
    [anon_sym_FOR] = ACTIONS(5903),
    [anon_sym_For] = ACTIONS(5903),
    [anon_sym_foreach] = ACTIONS(5903),
    [anon_sym_FOREACH] = ACTIONS(5903),
    [anon_sym_Foreach] = ACTIONS(5903),
    [anon_sym_while] = ACTIONS(5903),
    [anon_sym_WHILE] = ACTIONS(5903),
    [anon_sym_While] = ACTIONS(5903),
    [anon_sym_repeat] = ACTIONS(5903),
    [anon_sym_REPEAT] = ACTIONS(5903),
    [anon_sym_Repeat] = ACTIONS(5903),
    [anon_sym_until] = ACTIONS(5903),
    [anon_sym_UNTIL] = ACTIONS(5903),
    [anon_sym_Until] = ACTIONS(5903),
    [anon_sym_exit] = ACTIONS(5903),
    [anon_sym_EXIT] = ACTIONS(5903),
    [anon_sym_Exit] = ACTIONS(5903),
    [anon_sym_continue] = ACTIONS(5903),
    [anon_sym_CONTINUE] = ACTIONS(5903),
    [anon_sym_Continue] = ACTIONS(5903),
    [anon_sym_break] = ACTIONS(5903),
    [anon_sym_BREAK] = ACTIONS(5903),
    [anon_sym_Break] = ACTIONS(5903),
    [anon_sym_with] = ACTIONS(5903),
    [anon_sym_WITH] = ACTIONS(5903),
    [anon_sym_With] = ACTIONS(5903),
    [sym_asserterror_keyword] = ACTIONS(5905),
    [sym_page_keyword] = ACTIONS(5903),
    [anon_sym_codeunit] = ACTIONS(5903),
    [anon_sym_CODEUNIT] = ACTIONS(5903),
    [anon_sym_Codeunit] = ACTIONS(5903),
    [anon_sym_CodeUnit] = ACTIONS(5903),
    [anon_sym_COdeunit] = ACTIONS(5903),
    [anon_sym_codeUnit] = ACTIONS(5903),
    [sym_report_keyword] = ACTIONS(5903),
    [sym_query_keyword] = ACTIONS(5903),
    [anon_sym_xmlport] = ACTIONS(5903),
    [anon_sym_XMLPORT] = ACTIONS(5903),
    [anon_sym_Xmlport] = ACTIONS(5903),
    [anon_sym_XMLport] = ACTIONS(5903),
    [anon_sym_XMLPort] = ACTIONS(5903),
    [anon_sym_XmlPort] = ACTIONS(5903),
    [anon_sym_enum] = ACTIONS(5903),
    [anon_sym_ENUM] = ACTIONS(5903),
    [anon_sym_Enum] = ACTIONS(5903),
    [anon_sym_eNUM] = ACTIONS(5903),
    [anon_sym_eNum] = ACTIONS(5903),
    [anon_sym_ENum] = ACTIONS(5903),
    [sym_quoted_identifier] = ACTIONS(5905),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5905),
    [sym_verbatim_string] = ACTIONS(5905),
    [sym_integer] = ACTIONS(5903),
    [sym_continue_as_identifier] = ACTIONS(5905),
    [sym_preproc_open] = ACTIONS(5905),
  },
  [STATE(3060)] = {
    [sym_identifier] = ACTIONS(5907),
    [anon_sym_SEMI] = ACTIONS(5909),
    [anon_sym_DASH] = ACTIONS(5909),
    [aux_sym_boolean_token1] = ACTIONS(5907),
    [aux_sym_boolean_token2] = ACTIONS(5907),
    [sym_decimal] = ACTIONS(5907),
    [anon_sym_LPAREN] = ACTIONS(5909),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5907),
    [anon_sym_LBRACK] = ACTIONS(5909),
    [aux_sym_record_type_token1] = ACTIONS(5907),
    [aux_sym_basic_type_token21] = ACTIONS(5907),
    [aux_sym_basic_type_token22] = ACTIONS(5907),
    [aux_sym_basic_type_token48] = ACTIONS(5907),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5907),
    [anon_sym_POUNDif] = ACTIONS(5909),
    [anon_sym_POUNDIF] = ACTIONS(5909),
    [anon_sym_POUNDIf] = ACTIONS(5909),
    [anon_sym_not] = ACTIONS(5907),
    [anon_sym_NOT] = ACTIONS(5907),
    [anon_sym_Not] = ACTIONS(5907),
    [anon_sym_POUNDelse] = ACTIONS(5909),
    [anon_sym_POUNDELSE] = ACTIONS(5909),
    [anon_sym_POUNDElse] = ACTIONS(5909),
    [anon_sym_POUNDelse2] = ACTIONS(5909),
    [anon_sym_POUNDELSE2] = ACTIONS(5909),
    [anon_sym_POUNDElse2] = ACTIONS(5909),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5907),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5907),
    [anon_sym_PLUS] = ACTIONS(5909),
    [sym_datetime_literal] = ACTIONS(5909),
    [sym_date_literal] = ACTIONS(5907),
    [sym_time_literal] = ACTIONS(5907),
    [sym_biginteger_literal] = ACTIONS(5909),
    [anon_sym_if] = ACTIONS(5907),
    [anon_sym_IF] = ACTIONS(5907),
    [anon_sym_If] = ACTIONS(5907),
    [anon_sym_else] = ACTIONS(5907),
    [anon_sym_ELSE] = ACTIONS(5907),
    [anon_sym_Else] = ACTIONS(5907),
    [anon_sym_case] = ACTIONS(5907),
    [anon_sym_CASE] = ACTIONS(5907),
    [anon_sym_Case] = ACTIONS(5907),
    [anon_sym_for] = ACTIONS(5907),
    [anon_sym_FOR] = ACTIONS(5907),
    [anon_sym_For] = ACTIONS(5907),
    [anon_sym_foreach] = ACTIONS(5907),
    [anon_sym_FOREACH] = ACTIONS(5907),
    [anon_sym_Foreach] = ACTIONS(5907),
    [anon_sym_while] = ACTIONS(5907),
    [anon_sym_WHILE] = ACTIONS(5907),
    [anon_sym_While] = ACTIONS(5907),
    [anon_sym_repeat] = ACTIONS(5907),
    [anon_sym_REPEAT] = ACTIONS(5907),
    [anon_sym_Repeat] = ACTIONS(5907),
    [anon_sym_until] = ACTIONS(5907),
    [anon_sym_UNTIL] = ACTIONS(5907),
    [anon_sym_Until] = ACTIONS(5907),
    [anon_sym_exit] = ACTIONS(5907),
    [anon_sym_EXIT] = ACTIONS(5907),
    [anon_sym_Exit] = ACTIONS(5907),
    [anon_sym_continue] = ACTIONS(5907),
    [anon_sym_CONTINUE] = ACTIONS(5907),
    [anon_sym_Continue] = ACTIONS(5907),
    [anon_sym_break] = ACTIONS(5907),
    [anon_sym_BREAK] = ACTIONS(5907),
    [anon_sym_Break] = ACTIONS(5907),
    [anon_sym_with] = ACTIONS(5907),
    [anon_sym_WITH] = ACTIONS(5907),
    [anon_sym_With] = ACTIONS(5907),
    [sym_asserterror_keyword] = ACTIONS(5909),
    [sym_page_keyword] = ACTIONS(5907),
    [anon_sym_codeunit] = ACTIONS(5907),
    [anon_sym_CODEUNIT] = ACTIONS(5907),
    [anon_sym_Codeunit] = ACTIONS(5907),
    [anon_sym_CodeUnit] = ACTIONS(5907),
    [anon_sym_COdeunit] = ACTIONS(5907),
    [anon_sym_codeUnit] = ACTIONS(5907),
    [sym_report_keyword] = ACTIONS(5907),
    [sym_query_keyword] = ACTIONS(5907),
    [anon_sym_xmlport] = ACTIONS(5907),
    [anon_sym_XMLPORT] = ACTIONS(5907),
    [anon_sym_Xmlport] = ACTIONS(5907),
    [anon_sym_XMLport] = ACTIONS(5907),
    [anon_sym_XMLPort] = ACTIONS(5907),
    [anon_sym_XmlPort] = ACTIONS(5907),
    [anon_sym_enum] = ACTIONS(5907),
    [anon_sym_ENUM] = ACTIONS(5907),
    [anon_sym_Enum] = ACTIONS(5907),
    [anon_sym_eNUM] = ACTIONS(5907),
    [anon_sym_eNum] = ACTIONS(5907),
    [anon_sym_ENum] = ACTIONS(5907),
    [sym_quoted_identifier] = ACTIONS(5909),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5909),
    [sym_verbatim_string] = ACTIONS(5909),
    [sym_integer] = ACTIONS(5907),
    [sym_continue_as_identifier] = ACTIONS(5909),
    [sym_preproc_open] = ACTIONS(5909),
  },
  [STATE(3061)] = {
    [sym_identifier] = ACTIONS(5911),
    [anon_sym_SEMI] = ACTIONS(5913),
    [anon_sym_DASH] = ACTIONS(5913),
    [aux_sym_boolean_token1] = ACTIONS(5911),
    [aux_sym_boolean_token2] = ACTIONS(5911),
    [sym_decimal] = ACTIONS(5911),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5911),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [aux_sym_record_type_token1] = ACTIONS(5911),
    [aux_sym_basic_type_token21] = ACTIONS(5911),
    [aux_sym_basic_type_token22] = ACTIONS(5911),
    [aux_sym_basic_type_token48] = ACTIONS(5911),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5911),
    [anon_sym_POUNDif] = ACTIONS(5913),
    [anon_sym_POUNDIF] = ACTIONS(5913),
    [anon_sym_POUNDIf] = ACTIONS(5913),
    [anon_sym_not] = ACTIONS(5911),
    [anon_sym_NOT] = ACTIONS(5911),
    [anon_sym_Not] = ACTIONS(5911),
    [anon_sym_POUNDelse] = ACTIONS(5913),
    [anon_sym_POUNDELSE] = ACTIONS(5913),
    [anon_sym_POUNDElse] = ACTIONS(5913),
    [anon_sym_POUNDelse2] = ACTIONS(5913),
    [anon_sym_POUNDELSE2] = ACTIONS(5913),
    [anon_sym_POUNDElse2] = ACTIONS(5913),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5911),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5911),
    [anon_sym_PLUS] = ACTIONS(5913),
    [sym_datetime_literal] = ACTIONS(5913),
    [sym_date_literal] = ACTIONS(5911),
    [sym_time_literal] = ACTIONS(5911),
    [sym_biginteger_literal] = ACTIONS(5913),
    [anon_sym_if] = ACTIONS(5911),
    [anon_sym_IF] = ACTIONS(5911),
    [anon_sym_If] = ACTIONS(5911),
    [anon_sym_else] = ACTIONS(5911),
    [anon_sym_ELSE] = ACTIONS(5911),
    [anon_sym_Else] = ACTIONS(5911),
    [anon_sym_case] = ACTIONS(5911),
    [anon_sym_CASE] = ACTIONS(5911),
    [anon_sym_Case] = ACTIONS(5911),
    [anon_sym_for] = ACTIONS(5911),
    [anon_sym_FOR] = ACTIONS(5911),
    [anon_sym_For] = ACTIONS(5911),
    [anon_sym_foreach] = ACTIONS(5911),
    [anon_sym_FOREACH] = ACTIONS(5911),
    [anon_sym_Foreach] = ACTIONS(5911),
    [anon_sym_while] = ACTIONS(5911),
    [anon_sym_WHILE] = ACTIONS(5911),
    [anon_sym_While] = ACTIONS(5911),
    [anon_sym_repeat] = ACTIONS(5911),
    [anon_sym_REPEAT] = ACTIONS(5911),
    [anon_sym_Repeat] = ACTIONS(5911),
    [anon_sym_until] = ACTIONS(5911),
    [anon_sym_UNTIL] = ACTIONS(5911),
    [anon_sym_Until] = ACTIONS(5911),
    [anon_sym_exit] = ACTIONS(5911),
    [anon_sym_EXIT] = ACTIONS(5911),
    [anon_sym_Exit] = ACTIONS(5911),
    [anon_sym_continue] = ACTIONS(5911),
    [anon_sym_CONTINUE] = ACTIONS(5911),
    [anon_sym_Continue] = ACTIONS(5911),
    [anon_sym_break] = ACTIONS(5911),
    [anon_sym_BREAK] = ACTIONS(5911),
    [anon_sym_Break] = ACTIONS(5911),
    [anon_sym_with] = ACTIONS(5911),
    [anon_sym_WITH] = ACTIONS(5911),
    [anon_sym_With] = ACTIONS(5911),
    [sym_asserterror_keyword] = ACTIONS(5913),
    [sym_page_keyword] = ACTIONS(5911),
    [anon_sym_codeunit] = ACTIONS(5911),
    [anon_sym_CODEUNIT] = ACTIONS(5911),
    [anon_sym_Codeunit] = ACTIONS(5911),
    [anon_sym_CodeUnit] = ACTIONS(5911),
    [anon_sym_COdeunit] = ACTIONS(5911),
    [anon_sym_codeUnit] = ACTIONS(5911),
    [sym_report_keyword] = ACTIONS(5911),
    [sym_query_keyword] = ACTIONS(5911),
    [anon_sym_xmlport] = ACTIONS(5911),
    [anon_sym_XMLPORT] = ACTIONS(5911),
    [anon_sym_Xmlport] = ACTIONS(5911),
    [anon_sym_XMLport] = ACTIONS(5911),
    [anon_sym_XMLPort] = ACTIONS(5911),
    [anon_sym_XmlPort] = ACTIONS(5911),
    [anon_sym_enum] = ACTIONS(5911),
    [anon_sym_ENUM] = ACTIONS(5911),
    [anon_sym_Enum] = ACTIONS(5911),
    [anon_sym_eNUM] = ACTIONS(5911),
    [anon_sym_eNum] = ACTIONS(5911),
    [anon_sym_ENum] = ACTIONS(5911),
    [sym_quoted_identifier] = ACTIONS(5913),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5913),
    [sym_verbatim_string] = ACTIONS(5913),
    [sym_integer] = ACTIONS(5911),
    [sym_continue_as_identifier] = ACTIONS(5913),
    [sym_preproc_open] = ACTIONS(5913),
  },
  [STATE(3062)] = {
    [sym_identifier] = ACTIONS(5915),
    [anon_sym_SEMI] = ACTIONS(5917),
    [anon_sym_DASH] = ACTIONS(5917),
    [aux_sym_boolean_token1] = ACTIONS(5915),
    [aux_sym_boolean_token2] = ACTIONS(5915),
    [sym_decimal] = ACTIONS(5915),
    [anon_sym_LPAREN] = ACTIONS(5917),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5915),
    [anon_sym_LBRACK] = ACTIONS(5917),
    [aux_sym_record_type_token1] = ACTIONS(5915),
    [aux_sym_basic_type_token21] = ACTIONS(5915),
    [aux_sym_basic_type_token22] = ACTIONS(5915),
    [aux_sym_basic_type_token48] = ACTIONS(5915),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5915),
    [anon_sym_POUNDif] = ACTIONS(5917),
    [anon_sym_POUNDIF] = ACTIONS(5917),
    [anon_sym_POUNDIf] = ACTIONS(5917),
    [anon_sym_not] = ACTIONS(5915),
    [anon_sym_NOT] = ACTIONS(5915),
    [anon_sym_Not] = ACTIONS(5915),
    [anon_sym_POUNDelse] = ACTIONS(5917),
    [anon_sym_POUNDELSE] = ACTIONS(5917),
    [anon_sym_POUNDElse] = ACTIONS(5917),
    [anon_sym_POUNDelse2] = ACTIONS(5917),
    [anon_sym_POUNDELSE2] = ACTIONS(5917),
    [anon_sym_POUNDElse2] = ACTIONS(5917),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5915),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5915),
    [anon_sym_PLUS] = ACTIONS(5917),
    [sym_datetime_literal] = ACTIONS(5917),
    [sym_date_literal] = ACTIONS(5915),
    [sym_time_literal] = ACTIONS(5915),
    [sym_biginteger_literal] = ACTIONS(5917),
    [anon_sym_if] = ACTIONS(5915),
    [anon_sym_IF] = ACTIONS(5915),
    [anon_sym_If] = ACTIONS(5915),
    [anon_sym_else] = ACTIONS(5915),
    [anon_sym_ELSE] = ACTIONS(5915),
    [anon_sym_Else] = ACTIONS(5915),
    [anon_sym_case] = ACTIONS(5915),
    [anon_sym_CASE] = ACTIONS(5915),
    [anon_sym_Case] = ACTIONS(5915),
    [anon_sym_for] = ACTIONS(5915),
    [anon_sym_FOR] = ACTIONS(5915),
    [anon_sym_For] = ACTIONS(5915),
    [anon_sym_foreach] = ACTIONS(5915),
    [anon_sym_FOREACH] = ACTIONS(5915),
    [anon_sym_Foreach] = ACTIONS(5915),
    [anon_sym_while] = ACTIONS(5915),
    [anon_sym_WHILE] = ACTIONS(5915),
    [anon_sym_While] = ACTIONS(5915),
    [anon_sym_repeat] = ACTIONS(5915),
    [anon_sym_REPEAT] = ACTIONS(5915),
    [anon_sym_Repeat] = ACTIONS(5915),
    [anon_sym_until] = ACTIONS(5915),
    [anon_sym_UNTIL] = ACTIONS(5915),
    [anon_sym_Until] = ACTIONS(5915),
    [anon_sym_exit] = ACTIONS(5915),
    [anon_sym_EXIT] = ACTIONS(5915),
    [anon_sym_Exit] = ACTIONS(5915),
    [anon_sym_continue] = ACTIONS(5915),
    [anon_sym_CONTINUE] = ACTIONS(5915),
    [anon_sym_Continue] = ACTIONS(5915),
    [anon_sym_break] = ACTIONS(5915),
    [anon_sym_BREAK] = ACTIONS(5915),
    [anon_sym_Break] = ACTIONS(5915),
    [anon_sym_with] = ACTIONS(5915),
    [anon_sym_WITH] = ACTIONS(5915),
    [anon_sym_With] = ACTIONS(5915),
    [sym_asserterror_keyword] = ACTIONS(5917),
    [sym_page_keyword] = ACTIONS(5915),
    [anon_sym_codeunit] = ACTIONS(5915),
    [anon_sym_CODEUNIT] = ACTIONS(5915),
    [anon_sym_Codeunit] = ACTIONS(5915),
    [anon_sym_CodeUnit] = ACTIONS(5915),
    [anon_sym_COdeunit] = ACTIONS(5915),
    [anon_sym_codeUnit] = ACTIONS(5915),
    [sym_report_keyword] = ACTIONS(5915),
    [sym_query_keyword] = ACTIONS(5915),
    [anon_sym_xmlport] = ACTIONS(5915),
    [anon_sym_XMLPORT] = ACTIONS(5915),
    [anon_sym_Xmlport] = ACTIONS(5915),
    [anon_sym_XMLport] = ACTIONS(5915),
    [anon_sym_XMLPort] = ACTIONS(5915),
    [anon_sym_XmlPort] = ACTIONS(5915),
    [anon_sym_enum] = ACTIONS(5915),
    [anon_sym_ENUM] = ACTIONS(5915),
    [anon_sym_Enum] = ACTIONS(5915),
    [anon_sym_eNUM] = ACTIONS(5915),
    [anon_sym_eNum] = ACTIONS(5915),
    [anon_sym_ENum] = ACTIONS(5915),
    [sym_quoted_identifier] = ACTIONS(5917),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5917),
    [sym_verbatim_string] = ACTIONS(5917),
    [sym_integer] = ACTIONS(5915),
    [sym_continue_as_identifier] = ACTIONS(5917),
    [sym_preproc_open] = ACTIONS(5917),
  },
  [STATE(3063)] = {
    [sym_identifier] = ACTIONS(5919),
    [anon_sym_SEMI] = ACTIONS(5921),
    [anon_sym_DASH] = ACTIONS(5921),
    [aux_sym_boolean_token1] = ACTIONS(5919),
    [aux_sym_boolean_token2] = ACTIONS(5919),
    [sym_decimal] = ACTIONS(5919),
    [anon_sym_LPAREN] = ACTIONS(5921),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5919),
    [anon_sym_LBRACK] = ACTIONS(5921),
    [aux_sym_record_type_token1] = ACTIONS(5919),
    [aux_sym_basic_type_token21] = ACTIONS(5919),
    [aux_sym_basic_type_token22] = ACTIONS(5919),
    [aux_sym_basic_type_token48] = ACTIONS(5919),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5919),
    [anon_sym_POUNDif] = ACTIONS(5921),
    [anon_sym_POUNDIF] = ACTIONS(5921),
    [anon_sym_POUNDIf] = ACTIONS(5921),
    [anon_sym_not] = ACTIONS(5919),
    [anon_sym_NOT] = ACTIONS(5919),
    [anon_sym_Not] = ACTIONS(5919),
    [anon_sym_POUNDelse] = ACTIONS(5921),
    [anon_sym_POUNDELSE] = ACTIONS(5921),
    [anon_sym_POUNDElse] = ACTIONS(5921),
    [anon_sym_POUNDelse2] = ACTIONS(5921),
    [anon_sym_POUNDELSE2] = ACTIONS(5921),
    [anon_sym_POUNDElse2] = ACTIONS(5921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5919),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5919),
    [anon_sym_PLUS] = ACTIONS(5921),
    [sym_datetime_literal] = ACTIONS(5921),
    [sym_date_literal] = ACTIONS(5919),
    [sym_time_literal] = ACTIONS(5919),
    [sym_biginteger_literal] = ACTIONS(5921),
    [anon_sym_if] = ACTIONS(5919),
    [anon_sym_IF] = ACTIONS(5919),
    [anon_sym_If] = ACTIONS(5919),
    [anon_sym_else] = ACTIONS(5919),
    [anon_sym_ELSE] = ACTIONS(5919),
    [anon_sym_Else] = ACTIONS(5919),
    [anon_sym_case] = ACTIONS(5919),
    [anon_sym_CASE] = ACTIONS(5919),
    [anon_sym_Case] = ACTIONS(5919),
    [anon_sym_for] = ACTIONS(5919),
    [anon_sym_FOR] = ACTIONS(5919),
    [anon_sym_For] = ACTIONS(5919),
    [anon_sym_foreach] = ACTIONS(5919),
    [anon_sym_FOREACH] = ACTIONS(5919),
    [anon_sym_Foreach] = ACTIONS(5919),
    [anon_sym_while] = ACTIONS(5919),
    [anon_sym_WHILE] = ACTIONS(5919),
    [anon_sym_While] = ACTIONS(5919),
    [anon_sym_repeat] = ACTIONS(5919),
    [anon_sym_REPEAT] = ACTIONS(5919),
    [anon_sym_Repeat] = ACTIONS(5919),
    [anon_sym_until] = ACTIONS(5919),
    [anon_sym_UNTIL] = ACTIONS(5919),
    [anon_sym_Until] = ACTIONS(5919),
    [anon_sym_exit] = ACTIONS(5919),
    [anon_sym_EXIT] = ACTIONS(5919),
    [anon_sym_Exit] = ACTIONS(5919),
    [anon_sym_continue] = ACTIONS(5919),
    [anon_sym_CONTINUE] = ACTIONS(5919),
    [anon_sym_Continue] = ACTIONS(5919),
    [anon_sym_break] = ACTIONS(5919),
    [anon_sym_BREAK] = ACTIONS(5919),
    [anon_sym_Break] = ACTIONS(5919),
    [anon_sym_with] = ACTIONS(5919),
    [anon_sym_WITH] = ACTIONS(5919),
    [anon_sym_With] = ACTIONS(5919),
    [sym_asserterror_keyword] = ACTIONS(5921),
    [sym_page_keyword] = ACTIONS(5919),
    [anon_sym_codeunit] = ACTIONS(5919),
    [anon_sym_CODEUNIT] = ACTIONS(5919),
    [anon_sym_Codeunit] = ACTIONS(5919),
    [anon_sym_CodeUnit] = ACTIONS(5919),
    [anon_sym_COdeunit] = ACTIONS(5919),
    [anon_sym_codeUnit] = ACTIONS(5919),
    [sym_report_keyword] = ACTIONS(5919),
    [sym_query_keyword] = ACTIONS(5919),
    [anon_sym_xmlport] = ACTIONS(5919),
    [anon_sym_XMLPORT] = ACTIONS(5919),
    [anon_sym_Xmlport] = ACTIONS(5919),
    [anon_sym_XMLport] = ACTIONS(5919),
    [anon_sym_XMLPort] = ACTIONS(5919),
    [anon_sym_XmlPort] = ACTIONS(5919),
    [anon_sym_enum] = ACTIONS(5919),
    [anon_sym_ENUM] = ACTIONS(5919),
    [anon_sym_Enum] = ACTIONS(5919),
    [anon_sym_eNUM] = ACTIONS(5919),
    [anon_sym_eNum] = ACTIONS(5919),
    [anon_sym_ENum] = ACTIONS(5919),
    [sym_quoted_identifier] = ACTIONS(5921),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5921),
    [sym_verbatim_string] = ACTIONS(5921),
    [sym_integer] = ACTIONS(5919),
    [sym_continue_as_identifier] = ACTIONS(5921),
    [sym_preproc_open] = ACTIONS(5921),
  },
  [STATE(3064)] = {
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_SEMI] = ACTIONS(5925),
    [anon_sym_DASH] = ACTIONS(5925),
    [aux_sym_boolean_token1] = ACTIONS(5923),
    [aux_sym_boolean_token2] = ACTIONS(5923),
    [sym_decimal] = ACTIONS(5923),
    [anon_sym_LPAREN] = ACTIONS(5925),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5923),
    [anon_sym_LBRACK] = ACTIONS(5925),
    [aux_sym_record_type_token1] = ACTIONS(5923),
    [aux_sym_basic_type_token21] = ACTIONS(5923),
    [aux_sym_basic_type_token22] = ACTIONS(5923),
    [aux_sym_basic_type_token48] = ACTIONS(5923),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5923),
    [anon_sym_POUNDif] = ACTIONS(5925),
    [anon_sym_POUNDIF] = ACTIONS(5925),
    [anon_sym_POUNDIf] = ACTIONS(5925),
    [anon_sym_not] = ACTIONS(5923),
    [anon_sym_NOT] = ACTIONS(5923),
    [anon_sym_Not] = ACTIONS(5923),
    [anon_sym_POUNDelse] = ACTIONS(5925),
    [anon_sym_POUNDELSE] = ACTIONS(5925),
    [anon_sym_POUNDElse] = ACTIONS(5925),
    [anon_sym_POUNDelse2] = ACTIONS(5925),
    [anon_sym_POUNDELSE2] = ACTIONS(5925),
    [anon_sym_POUNDElse2] = ACTIONS(5925),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5923),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5923),
    [anon_sym_PLUS] = ACTIONS(5925),
    [sym_datetime_literal] = ACTIONS(5925),
    [sym_date_literal] = ACTIONS(5923),
    [sym_time_literal] = ACTIONS(5923),
    [sym_biginteger_literal] = ACTIONS(5925),
    [anon_sym_if] = ACTIONS(5923),
    [anon_sym_IF] = ACTIONS(5923),
    [anon_sym_If] = ACTIONS(5923),
    [anon_sym_else] = ACTIONS(5923),
    [anon_sym_ELSE] = ACTIONS(5923),
    [anon_sym_Else] = ACTIONS(5923),
    [anon_sym_case] = ACTIONS(5923),
    [anon_sym_CASE] = ACTIONS(5923),
    [anon_sym_Case] = ACTIONS(5923),
    [anon_sym_for] = ACTIONS(5923),
    [anon_sym_FOR] = ACTIONS(5923),
    [anon_sym_For] = ACTIONS(5923),
    [anon_sym_foreach] = ACTIONS(5923),
    [anon_sym_FOREACH] = ACTIONS(5923),
    [anon_sym_Foreach] = ACTIONS(5923),
    [anon_sym_while] = ACTIONS(5923),
    [anon_sym_WHILE] = ACTIONS(5923),
    [anon_sym_While] = ACTIONS(5923),
    [anon_sym_repeat] = ACTIONS(5923),
    [anon_sym_REPEAT] = ACTIONS(5923),
    [anon_sym_Repeat] = ACTIONS(5923),
    [anon_sym_until] = ACTIONS(5923),
    [anon_sym_UNTIL] = ACTIONS(5923),
    [anon_sym_Until] = ACTIONS(5923),
    [anon_sym_exit] = ACTIONS(5923),
    [anon_sym_EXIT] = ACTIONS(5923),
    [anon_sym_Exit] = ACTIONS(5923),
    [anon_sym_continue] = ACTIONS(5923),
    [anon_sym_CONTINUE] = ACTIONS(5923),
    [anon_sym_Continue] = ACTIONS(5923),
    [anon_sym_break] = ACTIONS(5923),
    [anon_sym_BREAK] = ACTIONS(5923),
    [anon_sym_Break] = ACTIONS(5923),
    [anon_sym_with] = ACTIONS(5923),
    [anon_sym_WITH] = ACTIONS(5923),
    [anon_sym_With] = ACTIONS(5923),
    [sym_asserterror_keyword] = ACTIONS(5925),
    [sym_page_keyword] = ACTIONS(5923),
    [anon_sym_codeunit] = ACTIONS(5923),
    [anon_sym_CODEUNIT] = ACTIONS(5923),
    [anon_sym_Codeunit] = ACTIONS(5923),
    [anon_sym_CodeUnit] = ACTIONS(5923),
    [anon_sym_COdeunit] = ACTIONS(5923),
    [anon_sym_codeUnit] = ACTIONS(5923),
    [sym_report_keyword] = ACTIONS(5923),
    [sym_query_keyword] = ACTIONS(5923),
    [anon_sym_xmlport] = ACTIONS(5923),
    [anon_sym_XMLPORT] = ACTIONS(5923),
    [anon_sym_Xmlport] = ACTIONS(5923),
    [anon_sym_XMLport] = ACTIONS(5923),
    [anon_sym_XMLPort] = ACTIONS(5923),
    [anon_sym_XmlPort] = ACTIONS(5923),
    [anon_sym_enum] = ACTIONS(5923),
    [anon_sym_ENUM] = ACTIONS(5923),
    [anon_sym_Enum] = ACTIONS(5923),
    [anon_sym_eNUM] = ACTIONS(5923),
    [anon_sym_eNum] = ACTIONS(5923),
    [anon_sym_ENum] = ACTIONS(5923),
    [sym_quoted_identifier] = ACTIONS(5925),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5925),
    [sym_verbatim_string] = ACTIONS(5925),
    [sym_integer] = ACTIONS(5923),
    [sym_continue_as_identifier] = ACTIONS(5925),
    [sym_preproc_open] = ACTIONS(5925),
  },
  [STATE(3065)] = {
    [sym_argument_list] = STATE(7165),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_RBRACE] = ACTIONS(5405),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [aux_sym_where_condition_token1] = ACTIONS(5410),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5405),
    [anon_sym_STAR] = ACTIONS(3681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5405),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5405),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_basic_type_token6] = ACTIONS(5410),
    [aux_sym_basic_type_token22] = ACTIONS(5410),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5405),
    [aux_sym_addafter_modification_token1] = ACTIONS(5405),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5405),
    [aux_sym_modify_modification_token1] = ACTIONS(5405),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5405),
    [aux_sym_movelast_modification_token1] = ACTIONS(5405),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5405),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5405),
    [aux_sym_separator_action_token1] = ACTIONS(5405),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5405),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5405),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5405),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5405),
    [sym_trigger_keyword] = ACTIONS(5405),
    [sym_var_keyword] = ACTIONS(5405),
    [sym_local_keyword] = ACTIONS(5405),
    [sym_internal_keyword] = ACTIONS(5405),
    [sym_protected_keyword] = ACTIONS(5405),
    [sym_event_keyword] = ACTIONS(5405),
    [sym_fields_keyword] = ACTIONS(5405),
    [sym_keys_keyword] = ACTIONS(5405),
    [sym_fieldgroups_keyword] = ACTIONS(5405),
    [sym_actions_keyword] = ACTIONS(5405),
    [sym_layout_keyword] = ACTIONS(5405),
    [sym_area_keyword] = ACTIONS(5405),
    [sym_group_keyword] = ACTIONS(5405),
    [sym_repeater_keyword] = ACTIONS(5405),
    [sym_cuegroup_keyword] = ACTIONS(5405),
    [sym_fixed_keyword] = ACTIONS(5405),
    [sym_grid_keyword] = ACTIONS(5405),
    [sym_part_keyword] = ACTIONS(5405),
    [sym_systempart_keyword] = ACTIONS(5405),
    [sym_usercontrol_keyword] = ACTIONS(5405),
    [sym_dataset_keyword] = ACTIONS(5405),
    [sym_elements_keyword] = ACTIONS(5405),
    [sym_dataitem_keyword] = ACTIONS(5405),
    [sym_column_keyword] = ACTIONS(5405),
    [sym_filter_keyword] = ACTIONS(5405),
    [sym_labels_keyword] = ACTIONS(5405),
    [sym_rendering_keyword] = ACTIONS(5405),
    [sym_requestpage_keyword] = ACTIONS(5405),
    [sym_schema_keyword] = ACTIONS(5405),
    [sym_views_keyword] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
  },
  [STATE(3066)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(3067)] = {
    [sym_boolean] = STATE(2354),
    [sym_code_block] = STATE(2488),
    [sym_assignment_expression] = STATE(2354),
    [sym__expression] = STATE(2354),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2354),
    [sym_multiplicative_expression] = STATE(2354),
    [sym_additive_expression] = STATE(2354),
    [sym_comparison_expression] = STATE(2354),
    [sym_logical_expression] = STATE(2354),
    [sym_ternary_expression] = STATE(2354),
    [sym_unary_expression] = STATE(2354),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2354),
    [sym_list_literal] = STATE(2354),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2354),
    [sym__literal_value] = STATE(2354),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(7203),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(337),
    [anon_sym_POUNDif] = ACTIONS(4318),
    [anon_sym_POUNDIF] = ACTIONS(4318),
    [anon_sym_POUNDIf] = ACTIONS(4318),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [anon_sym_POUNDelif] = ACTIONS(4318),
    [anon_sym_POUNDELIF] = ACTIONS(4318),
    [anon_sym_POUNDElif] = ACTIONS(4318),
    [anon_sym_POUNDelse] = ACTIONS(4318),
    [anon_sym_POUNDELSE] = ACTIONS(4318),
    [anon_sym_POUNDElse] = ACTIONS(4318),
    [anon_sym_POUNDelse2] = ACTIONS(4318),
    [anon_sym_POUNDELSE2] = ACTIONS(4318),
    [anon_sym_POUNDElse2] = ACTIONS(4318),
    [anon_sym_POUNDendif] = ACTIONS(4318),
    [anon_sym_POUNDENDIF] = ACTIONS(4318),
    [anon_sym_POUNDEndif] = ACTIONS(4318),
    [anon_sym_POUNDendif2] = ACTIONS(4318),
    [anon_sym_POUNDENDIF2] = ACTIONS(4318),
    [anon_sym_POUNDEndif2] = ACTIONS(4318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(7205),
    [sym_date_literal] = ACTIONS(7203),
    [sym_time_literal] = ACTIONS(7203),
    [sym_biginteger_literal] = ACTIONS(7205),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_ELSE] = ACTIONS(4322),
    [anon_sym_Else] = ACTIONS(4322),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7205),
    [sym_verbatim_string] = ACTIONS(7205),
    [sym_integer] = ACTIONS(7203),
    [sym_continue_as_identifier] = ACTIONS(7205),
    [sym_preproc_open] = ACTIONS(4318),
    [sym_preproc_close] = ACTIONS(4318),
    [sym_begin_keyword] = ACTIONS(345),
  },
  [STATE(3068)] = {
    [sym_identifier] = ACTIONS(3921),
    [anon_sym_DOT] = ACTIONS(3921),
    [anon_sym_EQ] = ACTIONS(3923),
    [anon_sym_COMMA] = ACTIONS(3923),
    [anon_sym_DASH] = ACTIONS(3921),
    [aux_sym_boolean_token1] = ACTIONS(3921),
    [aux_sym_boolean_token2] = ACTIONS(3921),
    [sym_decimal] = ACTIONS(3921),
    [anon_sym_LPAREN] = ACTIONS(3923),
    [anon_sym_DOT_DOT] = ACTIONS(3923),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3921),
    [anon_sym_STAR] = ACTIONS(3921),
    [anon_sym_LBRACK] = ACTIONS(3923),
    [aux_sym_record_type_token1] = ACTIONS(3921),
    [aux_sym_basic_type_token21] = ACTIONS(3921),
    [aux_sym_basic_type_token22] = ACTIONS(3921),
    [aux_sym_basic_type_token48] = ACTIONS(3921),
    [anon_sym_not] = ACTIONS(3921),
    [anon_sym_NOT] = ACTIONS(3921),
    [anon_sym_Not] = ACTIONS(3921),
    [anon_sym_POUNDelif] = ACTIONS(3923),
    [anon_sym_POUNDELIF] = ACTIONS(3923),
    [anon_sym_POUNDElif] = ACTIONS(3923),
    [anon_sym_POUNDelse] = ACTIONS(3923),
    [anon_sym_POUNDELSE] = ACTIONS(3923),
    [anon_sym_POUNDElse] = ACTIONS(3923),
    [anon_sym_POUNDelse2] = ACTIONS(3923),
    [anon_sym_POUNDELSE2] = ACTIONS(3923),
    [anon_sym_POUNDElse2] = ACTIONS(3923),
    [anon_sym_POUNDendif] = ACTIONS(3923),
    [anon_sym_POUNDENDIF] = ACTIONS(3923),
    [anon_sym_POUNDEndif] = ACTIONS(3923),
    [anon_sym_POUNDendif2] = ACTIONS(3923),
    [anon_sym_POUNDENDIF2] = ACTIONS(3923),
    [anon_sym_POUNDEndif2] = ACTIONS(3923),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3923),
    [aux_sym__expression_token1] = ACTIONS(3923),
    [aux_sym__expression_token2] = ACTIONS(3923),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3921),
    [anon_sym_SLASH] = ACTIONS(3921),
    [anon_sym_div] = ACTIONS(3921),
    [anon_sym_DIV] = ACTIONS(3921),
    [anon_sym_Div] = ACTIONS(3921),
    [anon_sym_mod] = ACTIONS(3921),
    [anon_sym_MOD] = ACTIONS(3921),
    [anon_sym_Mod] = ACTIONS(3921),
    [anon_sym_PLUS] = ACTIONS(3921),
    [anon_sym_GT_EQ] = ACTIONS(3923),
    [anon_sym_LT_EQ] = ACTIONS(3923),
    [anon_sym_GT] = ACTIONS(3921),
    [anon_sym_LT] = ACTIONS(3921),
    [anon_sym_LT_GT] = ACTIONS(3923),
    [anon_sym_and] = ACTIONS(3921),
    [anon_sym_AND] = ACTIONS(3921),
    [anon_sym_And] = ACTIONS(3921),
    [anon_sym_or] = ACTIONS(3921),
    [anon_sym_OR] = ACTIONS(3921),
    [anon_sym_Or] = ACTIONS(3921),
    [anon_sym_xor] = ACTIONS(3921),
    [anon_sym_XOR] = ACTIONS(3921),
    [anon_sym_Xor] = ACTIONS(3921),
    [anon_sym_QMARK] = ACTIONS(3923),
    [sym_datetime_literal] = ACTIONS(3923),
    [sym_date_literal] = ACTIONS(3921),
    [sym_time_literal] = ACTIONS(3921),
    [sym_biginteger_literal] = ACTIONS(3923),
    [anon_sym_in] = ACTIONS(3921),
    [anon_sym_IN] = ACTIONS(3921),
    [anon_sym_In] = ACTIONS(3921),
    [sym_page_keyword] = ACTIONS(3921),
    [anon_sym_codeunit] = ACTIONS(3921),
    [anon_sym_CODEUNIT] = ACTIONS(3921),
    [anon_sym_Codeunit] = ACTIONS(3921),
    [anon_sym_CodeUnit] = ACTIONS(3921),
    [anon_sym_COdeunit] = ACTIONS(3921),
    [anon_sym_codeUnit] = ACTIONS(3921),
    [sym_report_keyword] = ACTIONS(3921),
    [sym_query_keyword] = ACTIONS(3921),
    [anon_sym_xmlport] = ACTIONS(3921),
    [anon_sym_XMLPORT] = ACTIONS(3921),
    [anon_sym_Xmlport] = ACTIONS(3921),
    [anon_sym_XMLport] = ACTIONS(3921),
    [anon_sym_XMLPort] = ACTIONS(3921),
    [anon_sym_XmlPort] = ACTIONS(3921),
    [anon_sym_enum] = ACTIONS(3921),
    [anon_sym_ENUM] = ACTIONS(3921),
    [anon_sym_Enum] = ACTIONS(3921),
    [anon_sym_eNUM] = ACTIONS(3921),
    [anon_sym_eNum] = ACTIONS(3921),
    [anon_sym_ENum] = ACTIONS(3921),
    [sym_quoted_identifier] = ACTIONS(3923),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3923),
    [sym_verbatim_string] = ACTIONS(3923),
    [sym_integer] = ACTIONS(3921),
    [sym_continue_as_identifier] = ACTIONS(3923),
    [sym_preproc_close] = ACTIONS(3923),
  },
  [STATE(3069)] = {
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_SEMI] = ACTIONS(6282),
    [anon_sym_DASH] = ACTIONS(6282),
    [aux_sym_boolean_token1] = ACTIONS(6280),
    [aux_sym_boolean_token2] = ACTIONS(6280),
    [sym_decimal] = ACTIONS(6280),
    [anon_sym_LPAREN] = ACTIONS(6282),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6280),
    [anon_sym_LBRACK] = ACTIONS(6282),
    [aux_sym_record_type_token1] = ACTIONS(6280),
    [aux_sym_basic_type_token21] = ACTIONS(6280),
    [aux_sym_basic_type_token22] = ACTIONS(6280),
    [aux_sym_basic_type_token48] = ACTIONS(6280),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6280),
    [anon_sym_POUNDif] = ACTIONS(6282),
    [anon_sym_POUNDIF] = ACTIONS(6282),
    [anon_sym_POUNDIf] = ACTIONS(6282),
    [anon_sym_not] = ACTIONS(6280),
    [anon_sym_NOT] = ACTIONS(6280),
    [anon_sym_Not] = ACTIONS(6280),
    [anon_sym_POUNDelse] = ACTIONS(6282),
    [anon_sym_POUNDELSE] = ACTIONS(6282),
    [anon_sym_POUNDElse] = ACTIONS(6282),
    [anon_sym_POUNDelse2] = ACTIONS(6282),
    [anon_sym_POUNDELSE2] = ACTIONS(6282),
    [anon_sym_POUNDElse2] = ACTIONS(6282),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6280),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6280),
    [anon_sym_PLUS] = ACTIONS(6282),
    [sym_datetime_literal] = ACTIONS(6282),
    [sym_date_literal] = ACTIONS(6280),
    [sym_time_literal] = ACTIONS(6280),
    [sym_biginteger_literal] = ACTIONS(6282),
    [anon_sym_if] = ACTIONS(6280),
    [anon_sym_IF] = ACTIONS(6280),
    [anon_sym_If] = ACTIONS(6280),
    [anon_sym_else] = ACTIONS(6280),
    [anon_sym_ELSE] = ACTIONS(6280),
    [anon_sym_Else] = ACTIONS(6280),
    [anon_sym_case] = ACTIONS(6280),
    [anon_sym_CASE] = ACTIONS(6280),
    [anon_sym_Case] = ACTIONS(6280),
    [anon_sym_for] = ACTIONS(6280),
    [anon_sym_FOR] = ACTIONS(6280),
    [anon_sym_For] = ACTIONS(6280),
    [anon_sym_foreach] = ACTIONS(6280),
    [anon_sym_FOREACH] = ACTIONS(6280),
    [anon_sym_Foreach] = ACTIONS(6280),
    [anon_sym_while] = ACTIONS(6280),
    [anon_sym_WHILE] = ACTIONS(6280),
    [anon_sym_While] = ACTIONS(6280),
    [anon_sym_repeat] = ACTIONS(6280),
    [anon_sym_REPEAT] = ACTIONS(6280),
    [anon_sym_Repeat] = ACTIONS(6280),
    [anon_sym_until] = ACTIONS(6280),
    [anon_sym_UNTIL] = ACTIONS(6280),
    [anon_sym_Until] = ACTIONS(6280),
    [anon_sym_exit] = ACTIONS(6280),
    [anon_sym_EXIT] = ACTIONS(6280),
    [anon_sym_Exit] = ACTIONS(6280),
    [anon_sym_continue] = ACTIONS(6280),
    [anon_sym_CONTINUE] = ACTIONS(6280),
    [anon_sym_Continue] = ACTIONS(6280),
    [anon_sym_break] = ACTIONS(6280),
    [anon_sym_BREAK] = ACTIONS(6280),
    [anon_sym_Break] = ACTIONS(6280),
    [anon_sym_with] = ACTIONS(6280),
    [anon_sym_WITH] = ACTIONS(6280),
    [anon_sym_With] = ACTIONS(6280),
    [sym_asserterror_keyword] = ACTIONS(6282),
    [sym_page_keyword] = ACTIONS(6280),
    [anon_sym_codeunit] = ACTIONS(6280),
    [anon_sym_CODEUNIT] = ACTIONS(6280),
    [anon_sym_Codeunit] = ACTIONS(6280),
    [anon_sym_CodeUnit] = ACTIONS(6280),
    [anon_sym_COdeunit] = ACTIONS(6280),
    [anon_sym_codeUnit] = ACTIONS(6280),
    [sym_report_keyword] = ACTIONS(6280),
    [sym_query_keyword] = ACTIONS(6280),
    [anon_sym_xmlport] = ACTIONS(6280),
    [anon_sym_XMLPORT] = ACTIONS(6280),
    [anon_sym_Xmlport] = ACTIONS(6280),
    [anon_sym_XMLport] = ACTIONS(6280),
    [anon_sym_XMLPort] = ACTIONS(6280),
    [anon_sym_XmlPort] = ACTIONS(6280),
    [anon_sym_enum] = ACTIONS(6280),
    [anon_sym_ENUM] = ACTIONS(6280),
    [anon_sym_Enum] = ACTIONS(6280),
    [anon_sym_eNUM] = ACTIONS(6280),
    [anon_sym_eNum] = ACTIONS(6280),
    [anon_sym_ENum] = ACTIONS(6280),
    [sym_quoted_identifier] = ACTIONS(6282),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6282),
    [sym_verbatim_string] = ACTIONS(6282),
    [sym_integer] = ACTIONS(6280),
    [sym_continue_as_identifier] = ACTIONS(6282),
    [sym_preproc_open] = ACTIONS(6282),
  },
  [STATE(3070)] = {
    [sym_identifier] = ACTIONS(5609),
    [anon_sym_SEMI] = ACTIONS(5611),
    [anon_sym_DASH] = ACTIONS(5611),
    [aux_sym_boolean_token1] = ACTIONS(5609),
    [aux_sym_boolean_token2] = ACTIONS(5609),
    [sym_decimal] = ACTIONS(5609),
    [anon_sym_LPAREN] = ACTIONS(5611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5609),
    [anon_sym_LBRACK] = ACTIONS(5611),
    [aux_sym_record_type_token1] = ACTIONS(5609),
    [aux_sym_basic_type_token21] = ACTIONS(5609),
    [aux_sym_basic_type_token22] = ACTIONS(5609),
    [aux_sym_basic_type_token48] = ACTIONS(5609),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5609),
    [anon_sym_POUNDif] = ACTIONS(5611),
    [anon_sym_POUNDIF] = ACTIONS(5611),
    [anon_sym_POUNDIf] = ACTIONS(5611),
    [anon_sym_not] = ACTIONS(5609),
    [anon_sym_NOT] = ACTIONS(5609),
    [anon_sym_Not] = ACTIONS(5609),
    [anon_sym_POUNDelse] = ACTIONS(5611),
    [anon_sym_POUNDELSE] = ACTIONS(5611),
    [anon_sym_POUNDElse] = ACTIONS(5611),
    [anon_sym_POUNDelse2] = ACTIONS(5611),
    [anon_sym_POUNDELSE2] = ACTIONS(5611),
    [anon_sym_POUNDElse2] = ACTIONS(5611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5609),
    [anon_sym_PLUS] = ACTIONS(5611),
    [sym_datetime_literal] = ACTIONS(5611),
    [sym_date_literal] = ACTIONS(5609),
    [sym_time_literal] = ACTIONS(5609),
    [sym_biginteger_literal] = ACTIONS(5611),
    [anon_sym_if] = ACTIONS(5609),
    [anon_sym_IF] = ACTIONS(5609),
    [anon_sym_If] = ACTIONS(5609),
    [anon_sym_else] = ACTIONS(5609),
    [anon_sym_ELSE] = ACTIONS(5609),
    [anon_sym_Else] = ACTIONS(5609),
    [anon_sym_case] = ACTIONS(5609),
    [anon_sym_CASE] = ACTIONS(5609),
    [anon_sym_Case] = ACTIONS(5609),
    [anon_sym_for] = ACTIONS(5609),
    [anon_sym_FOR] = ACTIONS(5609),
    [anon_sym_For] = ACTIONS(5609),
    [anon_sym_foreach] = ACTIONS(5609),
    [anon_sym_FOREACH] = ACTIONS(5609),
    [anon_sym_Foreach] = ACTIONS(5609),
    [anon_sym_while] = ACTIONS(5609),
    [anon_sym_WHILE] = ACTIONS(5609),
    [anon_sym_While] = ACTIONS(5609),
    [anon_sym_repeat] = ACTIONS(5609),
    [anon_sym_REPEAT] = ACTIONS(5609),
    [anon_sym_Repeat] = ACTIONS(5609),
    [anon_sym_until] = ACTIONS(5609),
    [anon_sym_UNTIL] = ACTIONS(5609),
    [anon_sym_Until] = ACTIONS(5609),
    [anon_sym_exit] = ACTIONS(5609),
    [anon_sym_EXIT] = ACTIONS(5609),
    [anon_sym_Exit] = ACTIONS(5609),
    [anon_sym_continue] = ACTIONS(5609),
    [anon_sym_CONTINUE] = ACTIONS(5609),
    [anon_sym_Continue] = ACTIONS(5609),
    [anon_sym_break] = ACTIONS(5609),
    [anon_sym_BREAK] = ACTIONS(5609),
    [anon_sym_Break] = ACTIONS(5609),
    [anon_sym_with] = ACTIONS(5609),
    [anon_sym_WITH] = ACTIONS(5609),
    [anon_sym_With] = ACTIONS(5609),
    [sym_asserterror_keyword] = ACTIONS(5611),
    [sym_page_keyword] = ACTIONS(5609),
    [anon_sym_codeunit] = ACTIONS(5609),
    [anon_sym_CODEUNIT] = ACTIONS(5609),
    [anon_sym_Codeunit] = ACTIONS(5609),
    [anon_sym_CodeUnit] = ACTIONS(5609),
    [anon_sym_COdeunit] = ACTIONS(5609),
    [anon_sym_codeUnit] = ACTIONS(5609),
    [sym_report_keyword] = ACTIONS(5609),
    [sym_query_keyword] = ACTIONS(5609),
    [anon_sym_xmlport] = ACTIONS(5609),
    [anon_sym_XMLPORT] = ACTIONS(5609),
    [anon_sym_Xmlport] = ACTIONS(5609),
    [anon_sym_XMLport] = ACTIONS(5609),
    [anon_sym_XMLPort] = ACTIONS(5609),
    [anon_sym_XmlPort] = ACTIONS(5609),
    [anon_sym_enum] = ACTIONS(5609),
    [anon_sym_ENUM] = ACTIONS(5609),
    [anon_sym_Enum] = ACTIONS(5609),
    [anon_sym_eNUM] = ACTIONS(5609),
    [anon_sym_eNum] = ACTIONS(5609),
    [anon_sym_ENum] = ACTIONS(5609),
    [sym_quoted_identifier] = ACTIONS(5611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5611),
    [sym_verbatim_string] = ACTIONS(5611),
    [sym_integer] = ACTIONS(5609),
    [sym_continue_as_identifier] = ACTIONS(5611),
    [sym_preproc_open] = ACTIONS(5611),
  },
  [STATE(3071)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(3072)] = {
    [sym_identifier] = ACTIONS(6359),
    [anon_sym_SEMI] = ACTIONS(6361),
    [anon_sym_DASH] = ACTIONS(6361),
    [aux_sym_boolean_token1] = ACTIONS(6359),
    [aux_sym_boolean_token2] = ACTIONS(6359),
    [sym_decimal] = ACTIONS(6359),
    [anon_sym_LPAREN] = ACTIONS(6361),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6359),
    [anon_sym_LBRACK] = ACTIONS(6361),
    [aux_sym_record_type_token1] = ACTIONS(6359),
    [aux_sym_basic_type_token21] = ACTIONS(6359),
    [aux_sym_basic_type_token22] = ACTIONS(6359),
    [aux_sym_basic_type_token48] = ACTIONS(6359),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6359),
    [anon_sym_POUNDif] = ACTIONS(6361),
    [anon_sym_POUNDIF] = ACTIONS(6361),
    [anon_sym_POUNDIf] = ACTIONS(6361),
    [anon_sym_not] = ACTIONS(6359),
    [anon_sym_NOT] = ACTIONS(6359),
    [anon_sym_Not] = ACTIONS(6359),
    [anon_sym_POUNDelse] = ACTIONS(6361),
    [anon_sym_POUNDELSE] = ACTIONS(6361),
    [anon_sym_POUNDElse] = ACTIONS(6361),
    [anon_sym_POUNDelse2] = ACTIONS(6361),
    [anon_sym_POUNDELSE2] = ACTIONS(6361),
    [anon_sym_POUNDElse2] = ACTIONS(6361),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6359),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6359),
    [anon_sym_PLUS] = ACTIONS(6361),
    [sym_datetime_literal] = ACTIONS(6361),
    [sym_date_literal] = ACTIONS(6359),
    [sym_time_literal] = ACTIONS(6359),
    [sym_biginteger_literal] = ACTIONS(6361),
    [anon_sym_if] = ACTIONS(6359),
    [anon_sym_IF] = ACTIONS(6359),
    [anon_sym_If] = ACTIONS(6359),
    [anon_sym_else] = ACTIONS(6359),
    [anon_sym_ELSE] = ACTIONS(6359),
    [anon_sym_Else] = ACTIONS(6359),
    [anon_sym_case] = ACTIONS(6359),
    [anon_sym_CASE] = ACTIONS(6359),
    [anon_sym_Case] = ACTIONS(6359),
    [anon_sym_for] = ACTIONS(6359),
    [anon_sym_FOR] = ACTIONS(6359),
    [anon_sym_For] = ACTIONS(6359),
    [anon_sym_foreach] = ACTIONS(6359),
    [anon_sym_FOREACH] = ACTIONS(6359),
    [anon_sym_Foreach] = ACTIONS(6359),
    [anon_sym_while] = ACTIONS(6359),
    [anon_sym_WHILE] = ACTIONS(6359),
    [anon_sym_While] = ACTIONS(6359),
    [anon_sym_repeat] = ACTIONS(6359),
    [anon_sym_REPEAT] = ACTIONS(6359),
    [anon_sym_Repeat] = ACTIONS(6359),
    [anon_sym_until] = ACTIONS(6359),
    [anon_sym_UNTIL] = ACTIONS(6359),
    [anon_sym_Until] = ACTIONS(6359),
    [anon_sym_exit] = ACTIONS(6359),
    [anon_sym_EXIT] = ACTIONS(6359),
    [anon_sym_Exit] = ACTIONS(6359),
    [anon_sym_continue] = ACTIONS(6359),
    [anon_sym_CONTINUE] = ACTIONS(6359),
    [anon_sym_Continue] = ACTIONS(6359),
    [anon_sym_break] = ACTIONS(6359),
    [anon_sym_BREAK] = ACTIONS(6359),
    [anon_sym_Break] = ACTIONS(6359),
    [anon_sym_with] = ACTIONS(6359),
    [anon_sym_WITH] = ACTIONS(6359),
    [anon_sym_With] = ACTIONS(6359),
    [sym_asserterror_keyword] = ACTIONS(6361),
    [sym_page_keyword] = ACTIONS(6359),
    [anon_sym_codeunit] = ACTIONS(6359),
    [anon_sym_CODEUNIT] = ACTIONS(6359),
    [anon_sym_Codeunit] = ACTIONS(6359),
    [anon_sym_CodeUnit] = ACTIONS(6359),
    [anon_sym_COdeunit] = ACTIONS(6359),
    [anon_sym_codeUnit] = ACTIONS(6359),
    [sym_report_keyword] = ACTIONS(6359),
    [sym_query_keyword] = ACTIONS(6359),
    [anon_sym_xmlport] = ACTIONS(6359),
    [anon_sym_XMLPORT] = ACTIONS(6359),
    [anon_sym_Xmlport] = ACTIONS(6359),
    [anon_sym_XMLport] = ACTIONS(6359),
    [anon_sym_XMLPort] = ACTIONS(6359),
    [anon_sym_XmlPort] = ACTIONS(6359),
    [anon_sym_enum] = ACTIONS(6359),
    [anon_sym_ENUM] = ACTIONS(6359),
    [anon_sym_Enum] = ACTIONS(6359),
    [anon_sym_eNUM] = ACTIONS(6359),
    [anon_sym_eNum] = ACTIONS(6359),
    [anon_sym_ENum] = ACTIONS(6359),
    [sym_quoted_identifier] = ACTIONS(6361),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6361),
    [sym_verbatim_string] = ACTIONS(6361),
    [sym_integer] = ACTIONS(6359),
    [sym_continue_as_identifier] = ACTIONS(6361),
    [sym_preproc_open] = ACTIONS(6361),
  },
  [STATE(3073)] = {
    [sym_identifier] = ACTIONS(3742),
    [anon_sym_DOT] = ACTIONS(3742),
    [anon_sym_EQ] = ACTIONS(3744),
    [anon_sym_COMMA] = ACTIONS(3744),
    [anon_sym_DASH] = ACTIONS(3742),
    [aux_sym_boolean_token1] = ACTIONS(3742),
    [aux_sym_boolean_token2] = ACTIONS(3742),
    [sym_decimal] = ACTIONS(3742),
    [anon_sym_LPAREN] = ACTIONS(3744),
    [anon_sym_DOT_DOT] = ACTIONS(3744),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3742),
    [anon_sym_STAR] = ACTIONS(3742),
    [anon_sym_LBRACK] = ACTIONS(3744),
    [aux_sym_record_type_token1] = ACTIONS(3742),
    [aux_sym_basic_type_token21] = ACTIONS(3742),
    [aux_sym_basic_type_token22] = ACTIONS(3742),
    [aux_sym_basic_type_token48] = ACTIONS(3742),
    [anon_sym_not] = ACTIONS(3742),
    [anon_sym_NOT] = ACTIONS(3742),
    [anon_sym_Not] = ACTIONS(3742),
    [anon_sym_POUNDelif] = ACTIONS(3744),
    [anon_sym_POUNDELIF] = ACTIONS(3744),
    [anon_sym_POUNDElif] = ACTIONS(3744),
    [anon_sym_POUNDelse] = ACTIONS(3744),
    [anon_sym_POUNDELSE] = ACTIONS(3744),
    [anon_sym_POUNDElse] = ACTIONS(3744),
    [anon_sym_POUNDelse2] = ACTIONS(3744),
    [anon_sym_POUNDELSE2] = ACTIONS(3744),
    [anon_sym_POUNDElse2] = ACTIONS(3744),
    [anon_sym_POUNDendif] = ACTIONS(3744),
    [anon_sym_POUNDENDIF] = ACTIONS(3744),
    [anon_sym_POUNDEndif] = ACTIONS(3744),
    [anon_sym_POUNDendif2] = ACTIONS(3744),
    [anon_sym_POUNDENDIF2] = ACTIONS(3744),
    [anon_sym_POUNDEndif2] = ACTIONS(3744),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3744),
    [aux_sym__expression_token1] = ACTIONS(3744),
    [aux_sym__expression_token2] = ACTIONS(3744),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3742),
    [anon_sym_SLASH] = ACTIONS(3742),
    [anon_sym_div] = ACTIONS(3742),
    [anon_sym_DIV] = ACTIONS(3742),
    [anon_sym_Div] = ACTIONS(3742),
    [anon_sym_mod] = ACTIONS(3742),
    [anon_sym_MOD] = ACTIONS(3742),
    [anon_sym_Mod] = ACTIONS(3742),
    [anon_sym_PLUS] = ACTIONS(3742),
    [anon_sym_GT_EQ] = ACTIONS(3744),
    [anon_sym_LT_EQ] = ACTIONS(3744),
    [anon_sym_GT] = ACTIONS(3742),
    [anon_sym_LT] = ACTIONS(3742),
    [anon_sym_LT_GT] = ACTIONS(3744),
    [anon_sym_and] = ACTIONS(3742),
    [anon_sym_AND] = ACTIONS(3742),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3742),
    [anon_sym_OR] = ACTIONS(3742),
    [anon_sym_Or] = ACTIONS(3742),
    [anon_sym_xor] = ACTIONS(3742),
    [anon_sym_XOR] = ACTIONS(3742),
    [anon_sym_Xor] = ACTIONS(3742),
    [anon_sym_QMARK] = ACTIONS(3744),
    [sym_datetime_literal] = ACTIONS(3744),
    [sym_date_literal] = ACTIONS(3742),
    [sym_time_literal] = ACTIONS(3742),
    [sym_biginteger_literal] = ACTIONS(3744),
    [anon_sym_in] = ACTIONS(3742),
    [anon_sym_IN] = ACTIONS(3742),
    [anon_sym_In] = ACTIONS(3742),
    [sym_page_keyword] = ACTIONS(3742),
    [anon_sym_codeunit] = ACTIONS(3742),
    [anon_sym_CODEUNIT] = ACTIONS(3742),
    [anon_sym_Codeunit] = ACTIONS(3742),
    [anon_sym_CodeUnit] = ACTIONS(3742),
    [anon_sym_COdeunit] = ACTIONS(3742),
    [anon_sym_codeUnit] = ACTIONS(3742),
    [sym_report_keyword] = ACTIONS(3742),
    [sym_query_keyword] = ACTIONS(3742),
    [anon_sym_xmlport] = ACTIONS(3742),
    [anon_sym_XMLPORT] = ACTIONS(3742),
    [anon_sym_Xmlport] = ACTIONS(3742),
    [anon_sym_XMLport] = ACTIONS(3742),
    [anon_sym_XMLPort] = ACTIONS(3742),
    [anon_sym_XmlPort] = ACTIONS(3742),
    [anon_sym_enum] = ACTIONS(3742),
    [anon_sym_ENUM] = ACTIONS(3742),
    [anon_sym_Enum] = ACTIONS(3742),
    [anon_sym_eNUM] = ACTIONS(3742),
    [anon_sym_eNum] = ACTIONS(3742),
    [anon_sym_ENum] = ACTIONS(3742),
    [sym_quoted_identifier] = ACTIONS(3744),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3744),
    [sym_verbatim_string] = ACTIONS(3744),
    [sym_integer] = ACTIONS(3742),
    [sym_continue_as_identifier] = ACTIONS(3744),
    [sym_preproc_close] = ACTIONS(3744),
  },
  [STATE(3074)] = {
    [sym_boolean] = STATE(8034),
    [sym_option_member] = STATE(8002),
    [sym_keyword_identifier] = STATE(8034),
    [sym_codeunit_keyword] = STATE(8062),
    [sym_xmlport_keyword] = STATE(8062),
    [sym_enum_keyword] = STATE(8062),
    [sym_keyword_as_identifier] = STATE(8034),
    [aux_sym_option_member_list_repeat2] = STATE(3558),
    [sym_identifier] = ACTIONS(7061),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(7207),
    [anon_sym_DASH] = ACTIONS(7065),
    [aux_sym_boolean_token1] = ACTIONS(7067),
    [aux_sym_boolean_token2] = ACTIONS(7067),
    [aux_sym_where_condition_token1] = ACTIONS(7069),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7071),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(7071),
    [aux_sym_basic_type_token21] = ACTIONS(7071),
    [aux_sym_basic_type_token22] = ACTIONS(7073),
    [aux_sym_basic_type_token48] = ACTIONS(7071),
    [aux_sym_basic_type_token53] = ACTIONS(7069),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7069),
    [aux_sym_modify_modification_token1] = ACTIONS(602),
    [aux_sym_separator_action_token1] = ACTIONS(7069),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7069),
    [aux_sym_type_declaration_token1] = ACTIONS(7069),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7071),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7071),
    [sym_table_keyword] = ACTIONS(7069),
    [sym_page_keyword] = ACTIONS(7071),
    [anon_sym_codeunit] = ACTIONS(7075),
    [anon_sym_CODEUNIT] = ACTIONS(7075),
    [anon_sym_Codeunit] = ACTIONS(7075),
    [anon_sym_CodeUnit] = ACTIONS(7075),
    [anon_sym_COdeunit] = ACTIONS(7075),
    [anon_sym_codeUnit] = ACTIONS(7075),
    [sym_report_keyword] = ACTIONS(7071),
    [sym_query_keyword] = ACTIONS(7071),
    [anon_sym_xmlport] = ACTIONS(7077),
    [anon_sym_XMLPORT] = ACTIONS(7077),
    [anon_sym_Xmlport] = ACTIONS(7077),
    [anon_sym_XMLport] = ACTIONS(7077),
    [anon_sym_XMLPort] = ACTIONS(7077),
    [anon_sym_XmlPort] = ACTIONS(7077),
    [anon_sym_enum] = ACTIONS(7079),
    [anon_sym_ENUM] = ACTIONS(7079),
    [anon_sym_Enum] = ACTIONS(7079),
    [anon_sym_eNUM] = ACTIONS(7079),
    [anon_sym_eNum] = ACTIONS(7079),
    [anon_sym_ENum] = ACTIONS(7079),
    [sym_procedure_keyword] = ACTIONS(602),
    [sym_trigger_keyword] = ACTIONS(602),
    [sym_var_keyword] = ACTIONS(602),
    [sym_local_keyword] = ACTIONS(7061),
    [sym_internal_keyword] = ACTIONS(7061),
    [sym_protected_keyword] = ACTIONS(7061),
    [sym_event_keyword] = ACTIONS(602),
    [sym_fields_keyword] = ACTIONS(602),
    [sym_keys_keyword] = ACTIONS(602),
    [sym_key_keyword] = ACTIONS(7069),
    [sym_fieldgroups_keyword] = ACTIONS(602),
    [sym_actions_keyword] = ACTIONS(602),
    [sym_layout_keyword] = ACTIONS(602),
    [sym_dataset_keyword] = ACTIONS(7069),
    [sym_elements_keyword] = ACTIONS(602),
    [sym_labels_keyword] = ACTIONS(602),
    [sym_rendering_keyword] = ACTIONS(602),
    [sym_requestpage_keyword] = ACTIONS(602),
    [sym_schema_keyword] = ACTIONS(602),
    [sym_views_keyword] = ACTIONS(602),
    [sym_quoted_identifier] = ACTIONS(7081),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7081),
    [sym_integer] = ACTIONS(7081),
    [sym_property_name] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
    [sym_begin_keyword] = ACTIONS(600),
  },
  [STATE(3075)] = {
    [sym_identifier] = ACTIONS(5835),
    [anon_sym_SEMI] = ACTIONS(5837),
    [anon_sym_DASH] = ACTIONS(5837),
    [aux_sym_boolean_token1] = ACTIONS(5835),
    [aux_sym_boolean_token2] = ACTIONS(5835),
    [sym_decimal] = ACTIONS(5835),
    [anon_sym_LPAREN] = ACTIONS(5837),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5835),
    [anon_sym_LBRACK] = ACTIONS(5837),
    [aux_sym_record_type_token1] = ACTIONS(5835),
    [aux_sym_basic_type_token21] = ACTIONS(5835),
    [aux_sym_basic_type_token22] = ACTIONS(5835),
    [aux_sym_basic_type_token48] = ACTIONS(5835),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5835),
    [anon_sym_POUNDif] = ACTIONS(5837),
    [anon_sym_POUNDIF] = ACTIONS(5837),
    [anon_sym_POUNDIf] = ACTIONS(5837),
    [anon_sym_not] = ACTIONS(5835),
    [anon_sym_NOT] = ACTIONS(5835),
    [anon_sym_Not] = ACTIONS(5835),
    [anon_sym_POUNDelse] = ACTIONS(5837),
    [anon_sym_POUNDELSE] = ACTIONS(5837),
    [anon_sym_POUNDElse] = ACTIONS(5837),
    [anon_sym_POUNDelse2] = ACTIONS(5837),
    [anon_sym_POUNDELSE2] = ACTIONS(5837),
    [anon_sym_POUNDElse2] = ACTIONS(5837),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5835),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5835),
    [anon_sym_PLUS] = ACTIONS(5837),
    [sym_datetime_literal] = ACTIONS(5837),
    [sym_date_literal] = ACTIONS(5835),
    [sym_time_literal] = ACTIONS(5835),
    [sym_biginteger_literal] = ACTIONS(5837),
    [anon_sym_if] = ACTIONS(5835),
    [anon_sym_IF] = ACTIONS(5835),
    [anon_sym_If] = ACTIONS(5835),
    [anon_sym_else] = ACTIONS(5835),
    [anon_sym_ELSE] = ACTIONS(5835),
    [anon_sym_Else] = ACTIONS(5835),
    [anon_sym_case] = ACTIONS(5835),
    [anon_sym_CASE] = ACTIONS(5835),
    [anon_sym_Case] = ACTIONS(5835),
    [anon_sym_for] = ACTIONS(5835),
    [anon_sym_FOR] = ACTIONS(5835),
    [anon_sym_For] = ACTIONS(5835),
    [anon_sym_foreach] = ACTIONS(5835),
    [anon_sym_FOREACH] = ACTIONS(5835),
    [anon_sym_Foreach] = ACTIONS(5835),
    [anon_sym_while] = ACTIONS(5835),
    [anon_sym_WHILE] = ACTIONS(5835),
    [anon_sym_While] = ACTIONS(5835),
    [anon_sym_repeat] = ACTIONS(5835),
    [anon_sym_REPEAT] = ACTIONS(5835),
    [anon_sym_Repeat] = ACTIONS(5835),
    [anon_sym_until] = ACTIONS(5835),
    [anon_sym_UNTIL] = ACTIONS(5835),
    [anon_sym_Until] = ACTIONS(5835),
    [anon_sym_exit] = ACTIONS(5835),
    [anon_sym_EXIT] = ACTIONS(5835),
    [anon_sym_Exit] = ACTIONS(5835),
    [anon_sym_continue] = ACTIONS(5835),
    [anon_sym_CONTINUE] = ACTIONS(5835),
    [anon_sym_Continue] = ACTIONS(5835),
    [anon_sym_break] = ACTIONS(5835),
    [anon_sym_BREAK] = ACTIONS(5835),
    [anon_sym_Break] = ACTIONS(5835),
    [anon_sym_with] = ACTIONS(5835),
    [anon_sym_WITH] = ACTIONS(5835),
    [anon_sym_With] = ACTIONS(5835),
    [sym_asserterror_keyword] = ACTIONS(5837),
    [sym_page_keyword] = ACTIONS(5835),
    [anon_sym_codeunit] = ACTIONS(5835),
    [anon_sym_CODEUNIT] = ACTIONS(5835),
    [anon_sym_Codeunit] = ACTIONS(5835),
    [anon_sym_CodeUnit] = ACTIONS(5835),
    [anon_sym_COdeunit] = ACTIONS(5835),
    [anon_sym_codeUnit] = ACTIONS(5835),
    [sym_report_keyword] = ACTIONS(5835),
    [sym_query_keyword] = ACTIONS(5835),
    [anon_sym_xmlport] = ACTIONS(5835),
    [anon_sym_XMLPORT] = ACTIONS(5835),
    [anon_sym_Xmlport] = ACTIONS(5835),
    [anon_sym_XMLport] = ACTIONS(5835),
    [anon_sym_XMLPort] = ACTIONS(5835),
    [anon_sym_XmlPort] = ACTIONS(5835),
    [anon_sym_enum] = ACTIONS(5835),
    [anon_sym_ENUM] = ACTIONS(5835),
    [anon_sym_Enum] = ACTIONS(5835),
    [anon_sym_eNUM] = ACTIONS(5835),
    [anon_sym_eNum] = ACTIONS(5835),
    [anon_sym_ENum] = ACTIONS(5835),
    [sym_quoted_identifier] = ACTIONS(5837),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5837),
    [sym_verbatim_string] = ACTIONS(5837),
    [sym_integer] = ACTIONS(5835),
    [sym_continue_as_identifier] = ACTIONS(5837),
    [sym_preproc_open] = ACTIONS(5837),
  },
  [STATE(3076)] = {
    [sym_identifier] = ACTIONS(3937),
    [anon_sym_DOT] = ACTIONS(3937),
    [anon_sym_EQ] = ACTIONS(3939),
    [anon_sym_COMMA] = ACTIONS(3939),
    [anon_sym_DASH] = ACTIONS(3937),
    [aux_sym_boolean_token1] = ACTIONS(3937),
    [aux_sym_boolean_token2] = ACTIONS(3937),
    [sym_decimal] = ACTIONS(3937),
    [anon_sym_LPAREN] = ACTIONS(3939),
    [anon_sym_DOT_DOT] = ACTIONS(3939),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3937),
    [anon_sym_STAR] = ACTIONS(3937),
    [anon_sym_LBRACK] = ACTIONS(3939),
    [aux_sym_record_type_token1] = ACTIONS(3937),
    [aux_sym_basic_type_token21] = ACTIONS(3937),
    [aux_sym_basic_type_token22] = ACTIONS(3937),
    [aux_sym_basic_type_token48] = ACTIONS(3937),
    [anon_sym_not] = ACTIONS(3937),
    [anon_sym_NOT] = ACTIONS(3937),
    [anon_sym_Not] = ACTIONS(3937),
    [anon_sym_POUNDelif] = ACTIONS(3939),
    [anon_sym_POUNDELIF] = ACTIONS(3939),
    [anon_sym_POUNDElif] = ACTIONS(3939),
    [anon_sym_POUNDelse] = ACTIONS(3939),
    [anon_sym_POUNDELSE] = ACTIONS(3939),
    [anon_sym_POUNDElse] = ACTIONS(3939),
    [anon_sym_POUNDelse2] = ACTIONS(3939),
    [anon_sym_POUNDELSE2] = ACTIONS(3939),
    [anon_sym_POUNDElse2] = ACTIONS(3939),
    [anon_sym_POUNDendif] = ACTIONS(3939),
    [anon_sym_POUNDENDIF] = ACTIONS(3939),
    [anon_sym_POUNDEndif] = ACTIONS(3939),
    [anon_sym_POUNDendif2] = ACTIONS(3939),
    [anon_sym_POUNDENDIF2] = ACTIONS(3939),
    [anon_sym_POUNDEndif2] = ACTIONS(3939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3939),
    [aux_sym__expression_token1] = ACTIONS(3939),
    [aux_sym__expression_token2] = ACTIONS(3939),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3937),
    [anon_sym_SLASH] = ACTIONS(3937),
    [anon_sym_div] = ACTIONS(3937),
    [anon_sym_DIV] = ACTIONS(3937),
    [anon_sym_Div] = ACTIONS(3937),
    [anon_sym_mod] = ACTIONS(3937),
    [anon_sym_MOD] = ACTIONS(3937),
    [anon_sym_Mod] = ACTIONS(3937),
    [anon_sym_PLUS] = ACTIONS(3937),
    [anon_sym_GT_EQ] = ACTIONS(3939),
    [anon_sym_LT_EQ] = ACTIONS(3939),
    [anon_sym_GT] = ACTIONS(3937),
    [anon_sym_LT] = ACTIONS(3937),
    [anon_sym_LT_GT] = ACTIONS(3939),
    [anon_sym_and] = ACTIONS(3937),
    [anon_sym_AND] = ACTIONS(3937),
    [anon_sym_And] = ACTIONS(3937),
    [anon_sym_or] = ACTIONS(3937),
    [anon_sym_OR] = ACTIONS(3937),
    [anon_sym_Or] = ACTIONS(3937),
    [anon_sym_xor] = ACTIONS(3937),
    [anon_sym_XOR] = ACTIONS(3937),
    [anon_sym_Xor] = ACTIONS(3937),
    [anon_sym_QMARK] = ACTIONS(3939),
    [sym_datetime_literal] = ACTIONS(3939),
    [sym_date_literal] = ACTIONS(3937),
    [sym_time_literal] = ACTIONS(3937),
    [sym_biginteger_literal] = ACTIONS(3939),
    [anon_sym_in] = ACTIONS(3937),
    [anon_sym_IN] = ACTIONS(3937),
    [anon_sym_In] = ACTIONS(3937),
    [sym_page_keyword] = ACTIONS(3937),
    [anon_sym_codeunit] = ACTIONS(3937),
    [anon_sym_CODEUNIT] = ACTIONS(3937),
    [anon_sym_Codeunit] = ACTIONS(3937),
    [anon_sym_CodeUnit] = ACTIONS(3937),
    [anon_sym_COdeunit] = ACTIONS(3937),
    [anon_sym_codeUnit] = ACTIONS(3937),
    [sym_report_keyword] = ACTIONS(3937),
    [sym_query_keyword] = ACTIONS(3937),
    [anon_sym_xmlport] = ACTIONS(3937),
    [anon_sym_XMLPORT] = ACTIONS(3937),
    [anon_sym_Xmlport] = ACTIONS(3937),
    [anon_sym_XMLport] = ACTIONS(3937),
    [anon_sym_XMLPort] = ACTIONS(3937),
    [anon_sym_XmlPort] = ACTIONS(3937),
    [anon_sym_enum] = ACTIONS(3937),
    [anon_sym_ENUM] = ACTIONS(3937),
    [anon_sym_Enum] = ACTIONS(3937),
    [anon_sym_eNUM] = ACTIONS(3937),
    [anon_sym_eNum] = ACTIONS(3937),
    [anon_sym_ENum] = ACTIONS(3937),
    [sym_quoted_identifier] = ACTIONS(3939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3939),
    [sym_verbatim_string] = ACTIONS(3939),
    [sym_integer] = ACTIONS(3937),
    [sym_continue_as_identifier] = ACTIONS(3939),
    [sym_preproc_close] = ACTIONS(3939),
  },
  [STATE(3077)] = {
    [sym_identifier] = ACTIONS(5855),
    [anon_sym_SEMI] = ACTIONS(5857),
    [anon_sym_DASH] = ACTIONS(5857),
    [aux_sym_boolean_token1] = ACTIONS(5855),
    [aux_sym_boolean_token2] = ACTIONS(5855),
    [sym_decimal] = ACTIONS(5855),
    [anon_sym_LPAREN] = ACTIONS(5857),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5855),
    [anon_sym_LBRACK] = ACTIONS(5857),
    [aux_sym_record_type_token1] = ACTIONS(5855),
    [aux_sym_basic_type_token21] = ACTIONS(5855),
    [aux_sym_basic_type_token22] = ACTIONS(5855),
    [aux_sym_basic_type_token48] = ACTIONS(5855),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5855),
    [anon_sym_POUNDif] = ACTIONS(5857),
    [anon_sym_POUNDIF] = ACTIONS(5857),
    [anon_sym_POUNDIf] = ACTIONS(5857),
    [anon_sym_not] = ACTIONS(5855),
    [anon_sym_NOT] = ACTIONS(5855),
    [anon_sym_Not] = ACTIONS(5855),
    [anon_sym_POUNDelse] = ACTIONS(5857),
    [anon_sym_POUNDELSE] = ACTIONS(5857),
    [anon_sym_POUNDElse] = ACTIONS(5857),
    [anon_sym_POUNDelse2] = ACTIONS(5857),
    [anon_sym_POUNDELSE2] = ACTIONS(5857),
    [anon_sym_POUNDElse2] = ACTIONS(5857),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5855),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5855),
    [anon_sym_PLUS] = ACTIONS(5857),
    [sym_datetime_literal] = ACTIONS(5857),
    [sym_date_literal] = ACTIONS(5855),
    [sym_time_literal] = ACTIONS(5855),
    [sym_biginteger_literal] = ACTIONS(5857),
    [anon_sym_if] = ACTIONS(5855),
    [anon_sym_IF] = ACTIONS(5855),
    [anon_sym_If] = ACTIONS(5855),
    [anon_sym_else] = ACTIONS(5855),
    [anon_sym_ELSE] = ACTIONS(5855),
    [anon_sym_Else] = ACTIONS(5855),
    [anon_sym_case] = ACTIONS(5855),
    [anon_sym_CASE] = ACTIONS(5855),
    [anon_sym_Case] = ACTIONS(5855),
    [anon_sym_for] = ACTIONS(5855),
    [anon_sym_FOR] = ACTIONS(5855),
    [anon_sym_For] = ACTIONS(5855),
    [anon_sym_foreach] = ACTIONS(5855),
    [anon_sym_FOREACH] = ACTIONS(5855),
    [anon_sym_Foreach] = ACTIONS(5855),
    [anon_sym_while] = ACTIONS(5855),
    [anon_sym_WHILE] = ACTIONS(5855),
    [anon_sym_While] = ACTIONS(5855),
    [anon_sym_repeat] = ACTIONS(5855),
    [anon_sym_REPEAT] = ACTIONS(5855),
    [anon_sym_Repeat] = ACTIONS(5855),
    [anon_sym_until] = ACTIONS(5855),
    [anon_sym_UNTIL] = ACTIONS(5855),
    [anon_sym_Until] = ACTIONS(5855),
    [anon_sym_exit] = ACTIONS(5855),
    [anon_sym_EXIT] = ACTIONS(5855),
    [anon_sym_Exit] = ACTIONS(5855),
    [anon_sym_continue] = ACTIONS(5855),
    [anon_sym_CONTINUE] = ACTIONS(5855),
    [anon_sym_Continue] = ACTIONS(5855),
    [anon_sym_break] = ACTIONS(5855),
    [anon_sym_BREAK] = ACTIONS(5855),
    [anon_sym_Break] = ACTIONS(5855),
    [anon_sym_with] = ACTIONS(5855),
    [anon_sym_WITH] = ACTIONS(5855),
    [anon_sym_With] = ACTIONS(5855),
    [sym_asserterror_keyword] = ACTIONS(5857),
    [sym_page_keyword] = ACTIONS(5855),
    [anon_sym_codeunit] = ACTIONS(5855),
    [anon_sym_CODEUNIT] = ACTIONS(5855),
    [anon_sym_Codeunit] = ACTIONS(5855),
    [anon_sym_CodeUnit] = ACTIONS(5855),
    [anon_sym_COdeunit] = ACTIONS(5855),
    [anon_sym_codeUnit] = ACTIONS(5855),
    [sym_report_keyword] = ACTIONS(5855),
    [sym_query_keyword] = ACTIONS(5855),
    [anon_sym_xmlport] = ACTIONS(5855),
    [anon_sym_XMLPORT] = ACTIONS(5855),
    [anon_sym_Xmlport] = ACTIONS(5855),
    [anon_sym_XMLport] = ACTIONS(5855),
    [anon_sym_XMLPort] = ACTIONS(5855),
    [anon_sym_XmlPort] = ACTIONS(5855),
    [anon_sym_enum] = ACTIONS(5855),
    [anon_sym_ENUM] = ACTIONS(5855),
    [anon_sym_Enum] = ACTIONS(5855),
    [anon_sym_eNUM] = ACTIONS(5855),
    [anon_sym_eNum] = ACTIONS(5855),
    [anon_sym_ENum] = ACTIONS(5855),
    [sym_quoted_identifier] = ACTIONS(5857),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5857),
    [sym_verbatim_string] = ACTIONS(5857),
    [sym_integer] = ACTIONS(5855),
    [sym_continue_as_identifier] = ACTIONS(5857),
    [sym_preproc_open] = ACTIONS(5857),
  },
  [STATE(3078)] = {
    [sym_identifier] = ACTIONS(3941),
    [anon_sym_DOT] = ACTIONS(3941),
    [anon_sym_EQ] = ACTIONS(3943),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_DASH] = ACTIONS(3941),
    [aux_sym_boolean_token1] = ACTIONS(3941),
    [aux_sym_boolean_token2] = ACTIONS(3941),
    [sym_decimal] = ACTIONS(3941),
    [anon_sym_LPAREN] = ACTIONS(3943),
    [anon_sym_DOT_DOT] = ACTIONS(3943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3941),
    [anon_sym_STAR] = ACTIONS(3941),
    [anon_sym_LBRACK] = ACTIONS(3943),
    [aux_sym_record_type_token1] = ACTIONS(3941),
    [aux_sym_basic_type_token21] = ACTIONS(3941),
    [aux_sym_basic_type_token22] = ACTIONS(3941),
    [aux_sym_basic_type_token48] = ACTIONS(3941),
    [anon_sym_not] = ACTIONS(3941),
    [anon_sym_NOT] = ACTIONS(3941),
    [anon_sym_Not] = ACTIONS(3941),
    [anon_sym_POUNDelif] = ACTIONS(3943),
    [anon_sym_POUNDELIF] = ACTIONS(3943),
    [anon_sym_POUNDElif] = ACTIONS(3943),
    [anon_sym_POUNDelse] = ACTIONS(3943),
    [anon_sym_POUNDELSE] = ACTIONS(3943),
    [anon_sym_POUNDElse] = ACTIONS(3943),
    [anon_sym_POUNDelse2] = ACTIONS(3943),
    [anon_sym_POUNDELSE2] = ACTIONS(3943),
    [anon_sym_POUNDElse2] = ACTIONS(3943),
    [anon_sym_POUNDendif] = ACTIONS(3943),
    [anon_sym_POUNDENDIF] = ACTIONS(3943),
    [anon_sym_POUNDEndif] = ACTIONS(3943),
    [anon_sym_POUNDendif2] = ACTIONS(3943),
    [anon_sym_POUNDENDIF2] = ACTIONS(3943),
    [anon_sym_POUNDEndif2] = ACTIONS(3943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3943),
    [aux_sym__expression_token1] = ACTIONS(3943),
    [aux_sym__expression_token2] = ACTIONS(3943),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3941),
    [anon_sym_SLASH] = ACTIONS(3941),
    [anon_sym_div] = ACTIONS(3941),
    [anon_sym_DIV] = ACTIONS(3941),
    [anon_sym_Div] = ACTIONS(3941),
    [anon_sym_mod] = ACTIONS(3941),
    [anon_sym_MOD] = ACTIONS(3941),
    [anon_sym_Mod] = ACTIONS(3941),
    [anon_sym_PLUS] = ACTIONS(3941),
    [anon_sym_GT_EQ] = ACTIONS(3943),
    [anon_sym_LT_EQ] = ACTIONS(3943),
    [anon_sym_GT] = ACTIONS(3941),
    [anon_sym_LT] = ACTIONS(3941),
    [anon_sym_LT_GT] = ACTIONS(3943),
    [anon_sym_and] = ACTIONS(3941),
    [anon_sym_AND] = ACTIONS(3941),
    [anon_sym_And] = ACTIONS(3941),
    [anon_sym_or] = ACTIONS(3941),
    [anon_sym_OR] = ACTIONS(3941),
    [anon_sym_Or] = ACTIONS(3941),
    [anon_sym_xor] = ACTIONS(3941),
    [anon_sym_XOR] = ACTIONS(3941),
    [anon_sym_Xor] = ACTIONS(3941),
    [anon_sym_QMARK] = ACTIONS(3943),
    [sym_datetime_literal] = ACTIONS(3943),
    [sym_date_literal] = ACTIONS(3941),
    [sym_time_literal] = ACTIONS(3941),
    [sym_biginteger_literal] = ACTIONS(3943),
    [anon_sym_in] = ACTIONS(3941),
    [anon_sym_IN] = ACTIONS(3941),
    [anon_sym_In] = ACTIONS(3941),
    [sym_page_keyword] = ACTIONS(3941),
    [anon_sym_codeunit] = ACTIONS(3941),
    [anon_sym_CODEUNIT] = ACTIONS(3941),
    [anon_sym_Codeunit] = ACTIONS(3941),
    [anon_sym_CodeUnit] = ACTIONS(3941),
    [anon_sym_COdeunit] = ACTIONS(3941),
    [anon_sym_codeUnit] = ACTIONS(3941),
    [sym_report_keyword] = ACTIONS(3941),
    [sym_query_keyword] = ACTIONS(3941),
    [anon_sym_xmlport] = ACTIONS(3941),
    [anon_sym_XMLPORT] = ACTIONS(3941),
    [anon_sym_Xmlport] = ACTIONS(3941),
    [anon_sym_XMLport] = ACTIONS(3941),
    [anon_sym_XMLPort] = ACTIONS(3941),
    [anon_sym_XmlPort] = ACTIONS(3941),
    [anon_sym_enum] = ACTIONS(3941),
    [anon_sym_ENUM] = ACTIONS(3941),
    [anon_sym_Enum] = ACTIONS(3941),
    [anon_sym_eNUM] = ACTIONS(3941),
    [anon_sym_eNum] = ACTIONS(3941),
    [anon_sym_ENum] = ACTIONS(3941),
    [sym_quoted_identifier] = ACTIONS(3943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3943),
    [sym_verbatim_string] = ACTIONS(3943),
    [sym_integer] = ACTIONS(3941),
    [sym_continue_as_identifier] = ACTIONS(3943),
    [sym_preproc_close] = ACTIONS(3943),
  },
  [STATE(3079)] = {
    [sym_identifier] = ACTIONS(3945),
    [anon_sym_DOT] = ACTIONS(3945),
    [anon_sym_EQ] = ACTIONS(3947),
    [anon_sym_COMMA] = ACTIONS(3947),
    [anon_sym_DASH] = ACTIONS(3945),
    [aux_sym_boolean_token1] = ACTIONS(3945),
    [aux_sym_boolean_token2] = ACTIONS(3945),
    [sym_decimal] = ACTIONS(3945),
    [anon_sym_LPAREN] = ACTIONS(3947),
    [anon_sym_DOT_DOT] = ACTIONS(3947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3945),
    [anon_sym_STAR] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(3947),
    [aux_sym_record_type_token1] = ACTIONS(3945),
    [aux_sym_basic_type_token21] = ACTIONS(3945),
    [aux_sym_basic_type_token22] = ACTIONS(3945),
    [aux_sym_basic_type_token48] = ACTIONS(3945),
    [anon_sym_not] = ACTIONS(3945),
    [anon_sym_NOT] = ACTIONS(3945),
    [anon_sym_Not] = ACTIONS(3945),
    [anon_sym_POUNDelif] = ACTIONS(3947),
    [anon_sym_POUNDELIF] = ACTIONS(3947),
    [anon_sym_POUNDElif] = ACTIONS(3947),
    [anon_sym_POUNDelse] = ACTIONS(3947),
    [anon_sym_POUNDELSE] = ACTIONS(3947),
    [anon_sym_POUNDElse] = ACTIONS(3947),
    [anon_sym_POUNDelse2] = ACTIONS(3947),
    [anon_sym_POUNDELSE2] = ACTIONS(3947),
    [anon_sym_POUNDElse2] = ACTIONS(3947),
    [anon_sym_POUNDendif] = ACTIONS(3947),
    [anon_sym_POUNDENDIF] = ACTIONS(3947),
    [anon_sym_POUNDEndif] = ACTIONS(3947),
    [anon_sym_POUNDendif2] = ACTIONS(3947),
    [anon_sym_POUNDENDIF2] = ACTIONS(3947),
    [anon_sym_POUNDEndif2] = ACTIONS(3947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3947),
    [aux_sym__expression_token1] = ACTIONS(3947),
    [aux_sym__expression_token2] = ACTIONS(3947),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3945),
    [anon_sym_SLASH] = ACTIONS(3945),
    [anon_sym_div] = ACTIONS(3945),
    [anon_sym_DIV] = ACTIONS(3945),
    [anon_sym_Div] = ACTIONS(3945),
    [anon_sym_mod] = ACTIONS(3945),
    [anon_sym_MOD] = ACTIONS(3945),
    [anon_sym_Mod] = ACTIONS(3945),
    [anon_sym_PLUS] = ACTIONS(3945),
    [anon_sym_GT_EQ] = ACTIONS(3947),
    [anon_sym_LT_EQ] = ACTIONS(3947),
    [anon_sym_GT] = ACTIONS(3945),
    [anon_sym_LT] = ACTIONS(3945),
    [anon_sym_LT_GT] = ACTIONS(3947),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_AND] = ACTIONS(3945),
    [anon_sym_And] = ACTIONS(3945),
    [anon_sym_or] = ACTIONS(3945),
    [anon_sym_OR] = ACTIONS(3945),
    [anon_sym_Or] = ACTIONS(3945),
    [anon_sym_xor] = ACTIONS(3945),
    [anon_sym_XOR] = ACTIONS(3945),
    [anon_sym_Xor] = ACTIONS(3945),
    [anon_sym_QMARK] = ACTIONS(3947),
    [sym_datetime_literal] = ACTIONS(3947),
    [sym_date_literal] = ACTIONS(3945),
    [sym_time_literal] = ACTIONS(3945),
    [sym_biginteger_literal] = ACTIONS(3947),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_IN] = ACTIONS(3945),
    [anon_sym_In] = ACTIONS(3945),
    [sym_page_keyword] = ACTIONS(3945),
    [anon_sym_codeunit] = ACTIONS(3945),
    [anon_sym_CODEUNIT] = ACTIONS(3945),
    [anon_sym_Codeunit] = ACTIONS(3945),
    [anon_sym_CodeUnit] = ACTIONS(3945),
    [anon_sym_COdeunit] = ACTIONS(3945),
    [anon_sym_codeUnit] = ACTIONS(3945),
    [sym_report_keyword] = ACTIONS(3945),
    [sym_query_keyword] = ACTIONS(3945),
    [anon_sym_xmlport] = ACTIONS(3945),
    [anon_sym_XMLPORT] = ACTIONS(3945),
    [anon_sym_Xmlport] = ACTIONS(3945),
    [anon_sym_XMLport] = ACTIONS(3945),
    [anon_sym_XMLPort] = ACTIONS(3945),
    [anon_sym_XmlPort] = ACTIONS(3945),
    [anon_sym_enum] = ACTIONS(3945),
    [anon_sym_ENUM] = ACTIONS(3945),
    [anon_sym_Enum] = ACTIONS(3945),
    [anon_sym_eNUM] = ACTIONS(3945),
    [anon_sym_eNum] = ACTIONS(3945),
    [anon_sym_ENum] = ACTIONS(3945),
    [sym_quoted_identifier] = ACTIONS(3947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3947),
    [sym_verbatim_string] = ACTIONS(3947),
    [sym_integer] = ACTIONS(3945),
    [sym_continue_as_identifier] = ACTIONS(3947),
    [sym_preproc_close] = ACTIONS(3947),
  },
  [STATE(3080)] = {
    [sym_identifier] = ACTIONS(3881),
    [anon_sym_DOT] = ACTIONS(3881),
    [anon_sym_EQ] = ACTIONS(3883),
    [anon_sym_COMMA] = ACTIONS(3883),
    [anon_sym_DASH] = ACTIONS(3881),
    [aux_sym_boolean_token1] = ACTIONS(3881),
    [aux_sym_boolean_token2] = ACTIONS(3881),
    [sym_decimal] = ACTIONS(3881),
    [anon_sym_LPAREN] = ACTIONS(3883),
    [anon_sym_DOT_DOT] = ACTIONS(3883),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3881),
    [anon_sym_STAR] = ACTIONS(3881),
    [anon_sym_LBRACK] = ACTIONS(3883),
    [aux_sym_record_type_token1] = ACTIONS(3881),
    [aux_sym_basic_type_token21] = ACTIONS(3881),
    [aux_sym_basic_type_token22] = ACTIONS(3881),
    [aux_sym_basic_type_token48] = ACTIONS(3881),
    [anon_sym_not] = ACTIONS(3881),
    [anon_sym_NOT] = ACTIONS(3881),
    [anon_sym_Not] = ACTIONS(3881),
    [anon_sym_POUNDelif] = ACTIONS(3883),
    [anon_sym_POUNDELIF] = ACTIONS(3883),
    [anon_sym_POUNDElif] = ACTIONS(3883),
    [anon_sym_POUNDelse] = ACTIONS(3883),
    [anon_sym_POUNDELSE] = ACTIONS(3883),
    [anon_sym_POUNDElse] = ACTIONS(3883),
    [anon_sym_POUNDelse2] = ACTIONS(3883),
    [anon_sym_POUNDELSE2] = ACTIONS(3883),
    [anon_sym_POUNDElse2] = ACTIONS(3883),
    [anon_sym_POUNDendif] = ACTIONS(3883),
    [anon_sym_POUNDENDIF] = ACTIONS(3883),
    [anon_sym_POUNDEndif] = ACTIONS(3883),
    [anon_sym_POUNDendif2] = ACTIONS(3883),
    [anon_sym_POUNDENDIF2] = ACTIONS(3883),
    [anon_sym_POUNDEndif2] = ACTIONS(3883),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3883),
    [aux_sym__expression_token1] = ACTIONS(3883),
    [aux_sym__expression_token2] = ACTIONS(3883),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3881),
    [anon_sym_SLASH] = ACTIONS(3881),
    [anon_sym_div] = ACTIONS(3881),
    [anon_sym_DIV] = ACTIONS(3881),
    [anon_sym_Div] = ACTIONS(3881),
    [anon_sym_mod] = ACTIONS(3881),
    [anon_sym_MOD] = ACTIONS(3881),
    [anon_sym_Mod] = ACTIONS(3881),
    [anon_sym_PLUS] = ACTIONS(3881),
    [anon_sym_GT_EQ] = ACTIONS(3883),
    [anon_sym_LT_EQ] = ACTIONS(3883),
    [anon_sym_GT] = ACTIONS(3881),
    [anon_sym_LT] = ACTIONS(3881),
    [anon_sym_LT_GT] = ACTIONS(3883),
    [anon_sym_and] = ACTIONS(3881),
    [anon_sym_AND] = ACTIONS(3881),
    [anon_sym_And] = ACTIONS(3881),
    [anon_sym_or] = ACTIONS(3881),
    [anon_sym_OR] = ACTIONS(3881),
    [anon_sym_Or] = ACTIONS(3881),
    [anon_sym_xor] = ACTIONS(3881),
    [anon_sym_XOR] = ACTIONS(3881),
    [anon_sym_Xor] = ACTIONS(3881),
    [anon_sym_QMARK] = ACTIONS(3883),
    [sym_datetime_literal] = ACTIONS(3883),
    [sym_date_literal] = ACTIONS(3881),
    [sym_time_literal] = ACTIONS(3881),
    [sym_biginteger_literal] = ACTIONS(3883),
    [anon_sym_in] = ACTIONS(3881),
    [anon_sym_IN] = ACTIONS(3881),
    [anon_sym_In] = ACTIONS(3881),
    [sym_page_keyword] = ACTIONS(3881),
    [anon_sym_codeunit] = ACTIONS(3881),
    [anon_sym_CODEUNIT] = ACTIONS(3881),
    [anon_sym_Codeunit] = ACTIONS(3881),
    [anon_sym_CodeUnit] = ACTIONS(3881),
    [anon_sym_COdeunit] = ACTIONS(3881),
    [anon_sym_codeUnit] = ACTIONS(3881),
    [sym_report_keyword] = ACTIONS(3881),
    [sym_query_keyword] = ACTIONS(3881),
    [anon_sym_xmlport] = ACTIONS(3881),
    [anon_sym_XMLPORT] = ACTIONS(3881),
    [anon_sym_Xmlport] = ACTIONS(3881),
    [anon_sym_XMLport] = ACTIONS(3881),
    [anon_sym_XMLPort] = ACTIONS(3881),
    [anon_sym_XmlPort] = ACTIONS(3881),
    [anon_sym_enum] = ACTIONS(3881),
    [anon_sym_ENUM] = ACTIONS(3881),
    [anon_sym_Enum] = ACTIONS(3881),
    [anon_sym_eNUM] = ACTIONS(3881),
    [anon_sym_eNum] = ACTIONS(3881),
    [anon_sym_ENum] = ACTIONS(3881),
    [sym_quoted_identifier] = ACTIONS(3883),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3883),
    [sym_verbatim_string] = ACTIONS(3883),
    [sym_integer] = ACTIONS(3881),
    [sym_continue_as_identifier] = ACTIONS(3883),
    [sym_preproc_close] = ACTIONS(3883),
  },
  [STATE(3081)] = {
    [sym_identifier] = ACTIONS(3889),
    [anon_sym_DOT] = ACTIONS(3889),
    [anon_sym_EQ] = ACTIONS(3891),
    [anon_sym_COMMA] = ACTIONS(3891),
    [anon_sym_DASH] = ACTIONS(3889),
    [aux_sym_boolean_token1] = ACTIONS(3889),
    [aux_sym_boolean_token2] = ACTIONS(3889),
    [sym_decimal] = ACTIONS(3889),
    [anon_sym_LPAREN] = ACTIONS(3891),
    [anon_sym_DOT_DOT] = ACTIONS(3891),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3889),
    [anon_sym_STAR] = ACTIONS(3889),
    [anon_sym_LBRACK] = ACTIONS(3891),
    [aux_sym_record_type_token1] = ACTIONS(3889),
    [aux_sym_basic_type_token21] = ACTIONS(3889),
    [aux_sym_basic_type_token22] = ACTIONS(3889),
    [aux_sym_basic_type_token48] = ACTIONS(3889),
    [anon_sym_not] = ACTIONS(3889),
    [anon_sym_NOT] = ACTIONS(3889),
    [anon_sym_Not] = ACTIONS(3889),
    [anon_sym_POUNDelif] = ACTIONS(3891),
    [anon_sym_POUNDELIF] = ACTIONS(3891),
    [anon_sym_POUNDElif] = ACTIONS(3891),
    [anon_sym_POUNDelse] = ACTIONS(3891),
    [anon_sym_POUNDELSE] = ACTIONS(3891),
    [anon_sym_POUNDElse] = ACTIONS(3891),
    [anon_sym_POUNDelse2] = ACTIONS(3891),
    [anon_sym_POUNDELSE2] = ACTIONS(3891),
    [anon_sym_POUNDElse2] = ACTIONS(3891),
    [anon_sym_POUNDendif] = ACTIONS(3891),
    [anon_sym_POUNDENDIF] = ACTIONS(3891),
    [anon_sym_POUNDEndif] = ACTIONS(3891),
    [anon_sym_POUNDendif2] = ACTIONS(3891),
    [anon_sym_POUNDENDIF2] = ACTIONS(3891),
    [anon_sym_POUNDEndif2] = ACTIONS(3891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3891),
    [aux_sym__expression_token1] = ACTIONS(3891),
    [aux_sym__expression_token2] = ACTIONS(3891),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3889),
    [anon_sym_SLASH] = ACTIONS(3889),
    [anon_sym_div] = ACTIONS(3889),
    [anon_sym_DIV] = ACTIONS(3889),
    [anon_sym_Div] = ACTIONS(3889),
    [anon_sym_mod] = ACTIONS(3889),
    [anon_sym_MOD] = ACTIONS(3889),
    [anon_sym_Mod] = ACTIONS(3889),
    [anon_sym_PLUS] = ACTIONS(3889),
    [anon_sym_GT_EQ] = ACTIONS(3891),
    [anon_sym_LT_EQ] = ACTIONS(3891),
    [anon_sym_GT] = ACTIONS(3889),
    [anon_sym_LT] = ACTIONS(3889),
    [anon_sym_LT_GT] = ACTIONS(3891),
    [anon_sym_and] = ACTIONS(3889),
    [anon_sym_AND] = ACTIONS(3889),
    [anon_sym_And] = ACTIONS(3889),
    [anon_sym_or] = ACTIONS(3889),
    [anon_sym_OR] = ACTIONS(3889),
    [anon_sym_Or] = ACTIONS(3889),
    [anon_sym_xor] = ACTIONS(3889),
    [anon_sym_XOR] = ACTIONS(3889),
    [anon_sym_Xor] = ACTIONS(3889),
    [anon_sym_QMARK] = ACTIONS(3891),
    [sym_datetime_literal] = ACTIONS(3891),
    [sym_date_literal] = ACTIONS(3889),
    [sym_time_literal] = ACTIONS(3889),
    [sym_biginteger_literal] = ACTIONS(3891),
    [anon_sym_in] = ACTIONS(3889),
    [anon_sym_IN] = ACTIONS(3889),
    [anon_sym_In] = ACTIONS(3889),
    [sym_page_keyword] = ACTIONS(3889),
    [anon_sym_codeunit] = ACTIONS(3889),
    [anon_sym_CODEUNIT] = ACTIONS(3889),
    [anon_sym_Codeunit] = ACTIONS(3889),
    [anon_sym_CodeUnit] = ACTIONS(3889),
    [anon_sym_COdeunit] = ACTIONS(3889),
    [anon_sym_codeUnit] = ACTIONS(3889),
    [sym_report_keyword] = ACTIONS(3889),
    [sym_query_keyword] = ACTIONS(3889),
    [anon_sym_xmlport] = ACTIONS(3889),
    [anon_sym_XMLPORT] = ACTIONS(3889),
    [anon_sym_Xmlport] = ACTIONS(3889),
    [anon_sym_XMLport] = ACTIONS(3889),
    [anon_sym_XMLPort] = ACTIONS(3889),
    [anon_sym_XmlPort] = ACTIONS(3889),
    [anon_sym_enum] = ACTIONS(3889),
    [anon_sym_ENUM] = ACTIONS(3889),
    [anon_sym_Enum] = ACTIONS(3889),
    [anon_sym_eNUM] = ACTIONS(3889),
    [anon_sym_eNum] = ACTIONS(3889),
    [anon_sym_ENum] = ACTIONS(3889),
    [sym_quoted_identifier] = ACTIONS(3891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3891),
    [sym_verbatim_string] = ACTIONS(3891),
    [sym_integer] = ACTIONS(3889),
    [sym_continue_as_identifier] = ACTIONS(3891),
    [sym_preproc_close] = ACTIONS(3891),
  },
  [STATE(3082)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(3083)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(3084)] = {
    [sym_identifier] = ACTIONS(3893),
    [anon_sym_DOT] = ACTIONS(3893),
    [anon_sym_EQ] = ACTIONS(3895),
    [anon_sym_COMMA] = ACTIONS(3895),
    [anon_sym_DASH] = ACTIONS(3893),
    [aux_sym_boolean_token1] = ACTIONS(3893),
    [aux_sym_boolean_token2] = ACTIONS(3893),
    [sym_decimal] = ACTIONS(3893),
    [anon_sym_LPAREN] = ACTIONS(3895),
    [anon_sym_DOT_DOT] = ACTIONS(3895),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3893),
    [anon_sym_STAR] = ACTIONS(3893),
    [anon_sym_LBRACK] = ACTIONS(3895),
    [aux_sym_record_type_token1] = ACTIONS(3893),
    [aux_sym_basic_type_token21] = ACTIONS(3893),
    [aux_sym_basic_type_token22] = ACTIONS(3893),
    [aux_sym_basic_type_token48] = ACTIONS(3893),
    [anon_sym_not] = ACTIONS(3893),
    [anon_sym_NOT] = ACTIONS(3893),
    [anon_sym_Not] = ACTIONS(3893),
    [anon_sym_POUNDelif] = ACTIONS(3895),
    [anon_sym_POUNDELIF] = ACTIONS(3895),
    [anon_sym_POUNDElif] = ACTIONS(3895),
    [anon_sym_POUNDelse] = ACTIONS(3895),
    [anon_sym_POUNDELSE] = ACTIONS(3895),
    [anon_sym_POUNDElse] = ACTIONS(3895),
    [anon_sym_POUNDelse2] = ACTIONS(3895),
    [anon_sym_POUNDELSE2] = ACTIONS(3895),
    [anon_sym_POUNDElse2] = ACTIONS(3895),
    [anon_sym_POUNDendif] = ACTIONS(3895),
    [anon_sym_POUNDENDIF] = ACTIONS(3895),
    [anon_sym_POUNDEndif] = ACTIONS(3895),
    [anon_sym_POUNDendif2] = ACTIONS(3895),
    [anon_sym_POUNDENDIF2] = ACTIONS(3895),
    [anon_sym_POUNDEndif2] = ACTIONS(3895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3895),
    [aux_sym__expression_token1] = ACTIONS(3895),
    [aux_sym__expression_token2] = ACTIONS(3895),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3893),
    [anon_sym_SLASH] = ACTIONS(3893),
    [anon_sym_div] = ACTIONS(3893),
    [anon_sym_DIV] = ACTIONS(3893),
    [anon_sym_Div] = ACTIONS(3893),
    [anon_sym_mod] = ACTIONS(3893),
    [anon_sym_MOD] = ACTIONS(3893),
    [anon_sym_Mod] = ACTIONS(3893),
    [anon_sym_PLUS] = ACTIONS(3893),
    [anon_sym_GT_EQ] = ACTIONS(3895),
    [anon_sym_LT_EQ] = ACTIONS(3895),
    [anon_sym_GT] = ACTIONS(3893),
    [anon_sym_LT] = ACTIONS(3893),
    [anon_sym_LT_GT] = ACTIONS(3895),
    [anon_sym_and] = ACTIONS(3893),
    [anon_sym_AND] = ACTIONS(3893),
    [anon_sym_And] = ACTIONS(3893),
    [anon_sym_or] = ACTIONS(3893),
    [anon_sym_OR] = ACTIONS(3893),
    [anon_sym_Or] = ACTIONS(3893),
    [anon_sym_xor] = ACTIONS(3893),
    [anon_sym_XOR] = ACTIONS(3893),
    [anon_sym_Xor] = ACTIONS(3893),
    [anon_sym_QMARK] = ACTIONS(3895),
    [sym_datetime_literal] = ACTIONS(3895),
    [sym_date_literal] = ACTIONS(3893),
    [sym_time_literal] = ACTIONS(3893),
    [sym_biginteger_literal] = ACTIONS(3895),
    [anon_sym_in] = ACTIONS(3893),
    [anon_sym_IN] = ACTIONS(3893),
    [anon_sym_In] = ACTIONS(3893),
    [sym_page_keyword] = ACTIONS(3893),
    [anon_sym_codeunit] = ACTIONS(3893),
    [anon_sym_CODEUNIT] = ACTIONS(3893),
    [anon_sym_Codeunit] = ACTIONS(3893),
    [anon_sym_CodeUnit] = ACTIONS(3893),
    [anon_sym_COdeunit] = ACTIONS(3893),
    [anon_sym_codeUnit] = ACTIONS(3893),
    [sym_report_keyword] = ACTIONS(3893),
    [sym_query_keyword] = ACTIONS(3893),
    [anon_sym_xmlport] = ACTIONS(3893),
    [anon_sym_XMLPORT] = ACTIONS(3893),
    [anon_sym_Xmlport] = ACTIONS(3893),
    [anon_sym_XMLport] = ACTIONS(3893),
    [anon_sym_XMLPort] = ACTIONS(3893),
    [anon_sym_XmlPort] = ACTIONS(3893),
    [anon_sym_enum] = ACTIONS(3893),
    [anon_sym_ENUM] = ACTIONS(3893),
    [anon_sym_Enum] = ACTIONS(3893),
    [anon_sym_eNUM] = ACTIONS(3893),
    [anon_sym_eNum] = ACTIONS(3893),
    [anon_sym_ENum] = ACTIONS(3893),
    [sym_quoted_identifier] = ACTIONS(3895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3895),
    [sym_verbatim_string] = ACTIONS(3895),
    [sym_integer] = ACTIONS(3893),
    [sym_continue_as_identifier] = ACTIONS(3895),
    [sym_preproc_close] = ACTIONS(3895),
  },
  [STATE(3085)] = {
    [sym_identifier] = ACTIONS(3897),
    [anon_sym_DOT] = ACTIONS(3897),
    [anon_sym_EQ] = ACTIONS(3899),
    [anon_sym_COMMA] = ACTIONS(3899),
    [anon_sym_DASH] = ACTIONS(3897),
    [aux_sym_boolean_token1] = ACTIONS(3897),
    [aux_sym_boolean_token2] = ACTIONS(3897),
    [sym_decimal] = ACTIONS(3897),
    [anon_sym_LPAREN] = ACTIONS(3899),
    [anon_sym_DOT_DOT] = ACTIONS(3899),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3897),
    [anon_sym_STAR] = ACTIONS(3897),
    [anon_sym_LBRACK] = ACTIONS(3899),
    [aux_sym_record_type_token1] = ACTIONS(3897),
    [aux_sym_basic_type_token21] = ACTIONS(3897),
    [aux_sym_basic_type_token22] = ACTIONS(3897),
    [aux_sym_basic_type_token48] = ACTIONS(3897),
    [anon_sym_not] = ACTIONS(3897),
    [anon_sym_NOT] = ACTIONS(3897),
    [anon_sym_Not] = ACTIONS(3897),
    [anon_sym_POUNDelif] = ACTIONS(3899),
    [anon_sym_POUNDELIF] = ACTIONS(3899),
    [anon_sym_POUNDElif] = ACTIONS(3899),
    [anon_sym_POUNDelse] = ACTIONS(3899),
    [anon_sym_POUNDELSE] = ACTIONS(3899),
    [anon_sym_POUNDElse] = ACTIONS(3899),
    [anon_sym_POUNDelse2] = ACTIONS(3899),
    [anon_sym_POUNDELSE2] = ACTIONS(3899),
    [anon_sym_POUNDElse2] = ACTIONS(3899),
    [anon_sym_POUNDendif] = ACTIONS(3899),
    [anon_sym_POUNDENDIF] = ACTIONS(3899),
    [anon_sym_POUNDEndif] = ACTIONS(3899),
    [anon_sym_POUNDendif2] = ACTIONS(3899),
    [anon_sym_POUNDENDIF2] = ACTIONS(3899),
    [anon_sym_POUNDEndif2] = ACTIONS(3899),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3899),
    [aux_sym__expression_token1] = ACTIONS(3899),
    [aux_sym__expression_token2] = ACTIONS(3899),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3897),
    [anon_sym_SLASH] = ACTIONS(3897),
    [anon_sym_div] = ACTIONS(3897),
    [anon_sym_DIV] = ACTIONS(3897),
    [anon_sym_Div] = ACTIONS(3897),
    [anon_sym_mod] = ACTIONS(3897),
    [anon_sym_MOD] = ACTIONS(3897),
    [anon_sym_Mod] = ACTIONS(3897),
    [anon_sym_PLUS] = ACTIONS(3897),
    [anon_sym_GT_EQ] = ACTIONS(3899),
    [anon_sym_LT_EQ] = ACTIONS(3899),
    [anon_sym_GT] = ACTIONS(3897),
    [anon_sym_LT] = ACTIONS(3897),
    [anon_sym_LT_GT] = ACTIONS(3899),
    [anon_sym_and] = ACTIONS(3897),
    [anon_sym_AND] = ACTIONS(3897),
    [anon_sym_And] = ACTIONS(3897),
    [anon_sym_or] = ACTIONS(3897),
    [anon_sym_OR] = ACTIONS(3897),
    [anon_sym_Or] = ACTIONS(3897),
    [anon_sym_xor] = ACTIONS(3897),
    [anon_sym_XOR] = ACTIONS(3897),
    [anon_sym_Xor] = ACTIONS(3897),
    [anon_sym_QMARK] = ACTIONS(3899),
    [sym_datetime_literal] = ACTIONS(3899),
    [sym_date_literal] = ACTIONS(3897),
    [sym_time_literal] = ACTIONS(3897),
    [sym_biginteger_literal] = ACTIONS(3899),
    [anon_sym_in] = ACTIONS(3897),
    [anon_sym_IN] = ACTIONS(3897),
    [anon_sym_In] = ACTIONS(3897),
    [sym_page_keyword] = ACTIONS(3897),
    [anon_sym_codeunit] = ACTIONS(3897),
    [anon_sym_CODEUNIT] = ACTIONS(3897),
    [anon_sym_Codeunit] = ACTIONS(3897),
    [anon_sym_CodeUnit] = ACTIONS(3897),
    [anon_sym_COdeunit] = ACTIONS(3897),
    [anon_sym_codeUnit] = ACTIONS(3897),
    [sym_report_keyword] = ACTIONS(3897),
    [sym_query_keyword] = ACTIONS(3897),
    [anon_sym_xmlport] = ACTIONS(3897),
    [anon_sym_XMLPORT] = ACTIONS(3897),
    [anon_sym_Xmlport] = ACTIONS(3897),
    [anon_sym_XMLport] = ACTIONS(3897),
    [anon_sym_XMLPort] = ACTIONS(3897),
    [anon_sym_XmlPort] = ACTIONS(3897),
    [anon_sym_enum] = ACTIONS(3897),
    [anon_sym_ENUM] = ACTIONS(3897),
    [anon_sym_Enum] = ACTIONS(3897),
    [anon_sym_eNUM] = ACTIONS(3897),
    [anon_sym_eNum] = ACTIONS(3897),
    [anon_sym_ENum] = ACTIONS(3897),
    [sym_quoted_identifier] = ACTIONS(3899),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3899),
    [sym_verbatim_string] = ACTIONS(3899),
    [sym_integer] = ACTIONS(3897),
    [sym_continue_as_identifier] = ACTIONS(3899),
    [sym_preproc_close] = ACTIONS(3899),
  },
  [STATE(3086)] = {
    [sym_identifier] = ACTIONS(3901),
    [anon_sym_DOT] = ACTIONS(3901),
    [anon_sym_EQ] = ACTIONS(3903),
    [anon_sym_COMMA] = ACTIONS(3903),
    [anon_sym_DASH] = ACTIONS(3901),
    [aux_sym_boolean_token1] = ACTIONS(3901),
    [aux_sym_boolean_token2] = ACTIONS(3901),
    [sym_decimal] = ACTIONS(3901),
    [anon_sym_LPAREN] = ACTIONS(3903),
    [anon_sym_DOT_DOT] = ACTIONS(3903),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3901),
    [anon_sym_STAR] = ACTIONS(3901),
    [anon_sym_LBRACK] = ACTIONS(3903),
    [aux_sym_record_type_token1] = ACTIONS(3901),
    [aux_sym_basic_type_token21] = ACTIONS(3901),
    [aux_sym_basic_type_token22] = ACTIONS(3901),
    [aux_sym_basic_type_token48] = ACTIONS(3901),
    [anon_sym_not] = ACTIONS(3901),
    [anon_sym_NOT] = ACTIONS(3901),
    [anon_sym_Not] = ACTIONS(3901),
    [anon_sym_POUNDelif] = ACTIONS(3903),
    [anon_sym_POUNDELIF] = ACTIONS(3903),
    [anon_sym_POUNDElif] = ACTIONS(3903),
    [anon_sym_POUNDelse] = ACTIONS(3903),
    [anon_sym_POUNDELSE] = ACTIONS(3903),
    [anon_sym_POUNDElse] = ACTIONS(3903),
    [anon_sym_POUNDelse2] = ACTIONS(3903),
    [anon_sym_POUNDELSE2] = ACTIONS(3903),
    [anon_sym_POUNDElse2] = ACTIONS(3903),
    [anon_sym_POUNDendif] = ACTIONS(3903),
    [anon_sym_POUNDENDIF] = ACTIONS(3903),
    [anon_sym_POUNDEndif] = ACTIONS(3903),
    [anon_sym_POUNDendif2] = ACTIONS(3903),
    [anon_sym_POUNDENDIF2] = ACTIONS(3903),
    [anon_sym_POUNDEndif2] = ACTIONS(3903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3903),
    [aux_sym__expression_token1] = ACTIONS(3903),
    [aux_sym__expression_token2] = ACTIONS(3903),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3901),
    [anon_sym_SLASH] = ACTIONS(3901),
    [anon_sym_div] = ACTIONS(3901),
    [anon_sym_DIV] = ACTIONS(3901),
    [anon_sym_Div] = ACTIONS(3901),
    [anon_sym_mod] = ACTIONS(3901),
    [anon_sym_MOD] = ACTIONS(3901),
    [anon_sym_Mod] = ACTIONS(3901),
    [anon_sym_PLUS] = ACTIONS(3901),
    [anon_sym_GT_EQ] = ACTIONS(3903),
    [anon_sym_LT_EQ] = ACTIONS(3903),
    [anon_sym_GT] = ACTIONS(3901),
    [anon_sym_LT] = ACTIONS(3901),
    [anon_sym_LT_GT] = ACTIONS(3903),
    [anon_sym_and] = ACTIONS(3901),
    [anon_sym_AND] = ACTIONS(3901),
    [anon_sym_And] = ACTIONS(3901),
    [anon_sym_or] = ACTIONS(3901),
    [anon_sym_OR] = ACTIONS(3901),
    [anon_sym_Or] = ACTIONS(3901),
    [anon_sym_xor] = ACTIONS(3901),
    [anon_sym_XOR] = ACTIONS(3901),
    [anon_sym_Xor] = ACTIONS(3901),
    [anon_sym_QMARK] = ACTIONS(3903),
    [sym_datetime_literal] = ACTIONS(3903),
    [sym_date_literal] = ACTIONS(3901),
    [sym_time_literal] = ACTIONS(3901),
    [sym_biginteger_literal] = ACTIONS(3903),
    [anon_sym_in] = ACTIONS(3901),
    [anon_sym_IN] = ACTIONS(3901),
    [anon_sym_In] = ACTIONS(3901),
    [sym_page_keyword] = ACTIONS(3901),
    [anon_sym_codeunit] = ACTIONS(3901),
    [anon_sym_CODEUNIT] = ACTIONS(3901),
    [anon_sym_Codeunit] = ACTIONS(3901),
    [anon_sym_CodeUnit] = ACTIONS(3901),
    [anon_sym_COdeunit] = ACTIONS(3901),
    [anon_sym_codeUnit] = ACTIONS(3901),
    [sym_report_keyword] = ACTIONS(3901),
    [sym_query_keyword] = ACTIONS(3901),
    [anon_sym_xmlport] = ACTIONS(3901),
    [anon_sym_XMLPORT] = ACTIONS(3901),
    [anon_sym_Xmlport] = ACTIONS(3901),
    [anon_sym_XMLport] = ACTIONS(3901),
    [anon_sym_XMLPort] = ACTIONS(3901),
    [anon_sym_XmlPort] = ACTIONS(3901),
    [anon_sym_enum] = ACTIONS(3901),
    [anon_sym_ENUM] = ACTIONS(3901),
    [anon_sym_Enum] = ACTIONS(3901),
    [anon_sym_eNUM] = ACTIONS(3901),
    [anon_sym_eNum] = ACTIONS(3901),
    [anon_sym_ENum] = ACTIONS(3901),
    [sym_quoted_identifier] = ACTIONS(3903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3903),
    [sym_verbatim_string] = ACTIONS(3903),
    [sym_integer] = ACTIONS(3901),
    [sym_continue_as_identifier] = ACTIONS(3903),
    [sym_preproc_close] = ACTIONS(3903),
  },
  [STATE(3087)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(3088)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [anon_sym_POUNDelif] = ACTIONS(3875),
    [anon_sym_POUNDELIF] = ACTIONS(3875),
    [anon_sym_POUNDElif] = ACTIONS(3875),
    [anon_sym_POUNDelse] = ACTIONS(3875),
    [anon_sym_POUNDELSE] = ACTIONS(3875),
    [anon_sym_POUNDElse] = ACTIONS(3875),
    [anon_sym_POUNDelse2] = ACTIONS(3875),
    [anon_sym_POUNDELSE2] = ACTIONS(3875),
    [anon_sym_POUNDElse2] = ACTIONS(3875),
    [anon_sym_POUNDendif] = ACTIONS(3875),
    [anon_sym_POUNDENDIF] = ACTIONS(3875),
    [anon_sym_POUNDEndif] = ACTIONS(3875),
    [anon_sym_POUNDendif2] = ACTIONS(3875),
    [anon_sym_POUNDENDIF2] = ACTIONS(3875),
    [anon_sym_POUNDEndif2] = ACTIONS(3875),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_close] = ACTIONS(3875),
  },
  [STATE(3089)] = {
    [sym_identifier] = ACTIONS(3905),
    [anon_sym_DOT] = ACTIONS(3905),
    [anon_sym_EQ] = ACTIONS(3907),
    [anon_sym_COMMA] = ACTIONS(3907),
    [anon_sym_DASH] = ACTIONS(3905),
    [aux_sym_boolean_token1] = ACTIONS(3905),
    [aux_sym_boolean_token2] = ACTIONS(3905),
    [sym_decimal] = ACTIONS(3905),
    [anon_sym_LPAREN] = ACTIONS(3907),
    [anon_sym_DOT_DOT] = ACTIONS(3907),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3905),
    [anon_sym_STAR] = ACTIONS(3905),
    [anon_sym_LBRACK] = ACTIONS(3907),
    [aux_sym_record_type_token1] = ACTIONS(3905),
    [aux_sym_basic_type_token21] = ACTIONS(3905),
    [aux_sym_basic_type_token22] = ACTIONS(3905),
    [aux_sym_basic_type_token48] = ACTIONS(3905),
    [anon_sym_not] = ACTIONS(3905),
    [anon_sym_NOT] = ACTIONS(3905),
    [anon_sym_Not] = ACTIONS(3905),
    [anon_sym_POUNDelif] = ACTIONS(3907),
    [anon_sym_POUNDELIF] = ACTIONS(3907),
    [anon_sym_POUNDElif] = ACTIONS(3907),
    [anon_sym_POUNDelse] = ACTIONS(3907),
    [anon_sym_POUNDELSE] = ACTIONS(3907),
    [anon_sym_POUNDElse] = ACTIONS(3907),
    [anon_sym_POUNDelse2] = ACTIONS(3907),
    [anon_sym_POUNDELSE2] = ACTIONS(3907),
    [anon_sym_POUNDElse2] = ACTIONS(3907),
    [anon_sym_POUNDendif] = ACTIONS(3907),
    [anon_sym_POUNDENDIF] = ACTIONS(3907),
    [anon_sym_POUNDEndif] = ACTIONS(3907),
    [anon_sym_POUNDendif2] = ACTIONS(3907),
    [anon_sym_POUNDENDIF2] = ACTIONS(3907),
    [anon_sym_POUNDEndif2] = ACTIONS(3907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3907),
    [aux_sym__expression_token1] = ACTIONS(3907),
    [aux_sym__expression_token2] = ACTIONS(3907),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3905),
    [anon_sym_SLASH] = ACTIONS(3905),
    [anon_sym_div] = ACTIONS(3905),
    [anon_sym_DIV] = ACTIONS(3905),
    [anon_sym_Div] = ACTIONS(3905),
    [anon_sym_mod] = ACTIONS(3905),
    [anon_sym_MOD] = ACTIONS(3905),
    [anon_sym_Mod] = ACTIONS(3905),
    [anon_sym_PLUS] = ACTIONS(3905),
    [anon_sym_GT_EQ] = ACTIONS(3907),
    [anon_sym_LT_EQ] = ACTIONS(3907),
    [anon_sym_GT] = ACTIONS(3905),
    [anon_sym_LT] = ACTIONS(3905),
    [anon_sym_LT_GT] = ACTIONS(3907),
    [anon_sym_and] = ACTIONS(3905),
    [anon_sym_AND] = ACTIONS(3905),
    [anon_sym_And] = ACTIONS(3905),
    [anon_sym_or] = ACTIONS(3905),
    [anon_sym_OR] = ACTIONS(3905),
    [anon_sym_Or] = ACTIONS(3905),
    [anon_sym_xor] = ACTIONS(3905),
    [anon_sym_XOR] = ACTIONS(3905),
    [anon_sym_Xor] = ACTIONS(3905),
    [anon_sym_QMARK] = ACTIONS(3907),
    [sym_datetime_literal] = ACTIONS(3907),
    [sym_date_literal] = ACTIONS(3905),
    [sym_time_literal] = ACTIONS(3905),
    [sym_biginteger_literal] = ACTIONS(3907),
    [anon_sym_in] = ACTIONS(3905),
    [anon_sym_IN] = ACTIONS(3905),
    [anon_sym_In] = ACTIONS(3905),
    [sym_page_keyword] = ACTIONS(3905),
    [anon_sym_codeunit] = ACTIONS(3905),
    [anon_sym_CODEUNIT] = ACTIONS(3905),
    [anon_sym_Codeunit] = ACTIONS(3905),
    [anon_sym_CodeUnit] = ACTIONS(3905),
    [anon_sym_COdeunit] = ACTIONS(3905),
    [anon_sym_codeUnit] = ACTIONS(3905),
    [sym_report_keyword] = ACTIONS(3905),
    [sym_query_keyword] = ACTIONS(3905),
    [anon_sym_xmlport] = ACTIONS(3905),
    [anon_sym_XMLPORT] = ACTIONS(3905),
    [anon_sym_Xmlport] = ACTIONS(3905),
    [anon_sym_XMLport] = ACTIONS(3905),
    [anon_sym_XMLPort] = ACTIONS(3905),
    [anon_sym_XmlPort] = ACTIONS(3905),
    [anon_sym_enum] = ACTIONS(3905),
    [anon_sym_ENUM] = ACTIONS(3905),
    [anon_sym_Enum] = ACTIONS(3905),
    [anon_sym_eNUM] = ACTIONS(3905),
    [anon_sym_eNum] = ACTIONS(3905),
    [anon_sym_ENum] = ACTIONS(3905),
    [sym_quoted_identifier] = ACTIONS(3907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3907),
    [sym_verbatim_string] = ACTIONS(3907),
    [sym_integer] = ACTIONS(3905),
    [sym_continue_as_identifier] = ACTIONS(3907),
    [sym_preproc_close] = ACTIONS(3907),
  },
  [STATE(3090)] = {
    [sym_identifier] = ACTIONS(3877),
    [anon_sym_DOT] = ACTIONS(3877),
    [anon_sym_EQ] = ACTIONS(3879),
    [anon_sym_COMMA] = ACTIONS(3879),
    [anon_sym_DASH] = ACTIONS(3877),
    [aux_sym_boolean_token1] = ACTIONS(3877),
    [aux_sym_boolean_token2] = ACTIONS(3877),
    [sym_decimal] = ACTIONS(3877),
    [anon_sym_LPAREN] = ACTIONS(3879),
    [anon_sym_DOT_DOT] = ACTIONS(3879),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3877),
    [anon_sym_STAR] = ACTIONS(3877),
    [anon_sym_LBRACK] = ACTIONS(3879),
    [aux_sym_record_type_token1] = ACTIONS(3877),
    [aux_sym_basic_type_token21] = ACTIONS(3877),
    [aux_sym_basic_type_token22] = ACTIONS(3877),
    [aux_sym_basic_type_token48] = ACTIONS(3877),
    [anon_sym_not] = ACTIONS(3877),
    [anon_sym_NOT] = ACTIONS(3877),
    [anon_sym_Not] = ACTIONS(3877),
    [anon_sym_POUNDelif] = ACTIONS(3879),
    [anon_sym_POUNDELIF] = ACTIONS(3879),
    [anon_sym_POUNDElif] = ACTIONS(3879),
    [anon_sym_POUNDelse] = ACTIONS(3879),
    [anon_sym_POUNDELSE] = ACTIONS(3879),
    [anon_sym_POUNDElse] = ACTIONS(3879),
    [anon_sym_POUNDelse2] = ACTIONS(3879),
    [anon_sym_POUNDELSE2] = ACTIONS(3879),
    [anon_sym_POUNDElse2] = ACTIONS(3879),
    [anon_sym_POUNDendif] = ACTIONS(3879),
    [anon_sym_POUNDENDIF] = ACTIONS(3879),
    [anon_sym_POUNDEndif] = ACTIONS(3879),
    [anon_sym_POUNDendif2] = ACTIONS(3879),
    [anon_sym_POUNDENDIF2] = ACTIONS(3879),
    [anon_sym_POUNDEndif2] = ACTIONS(3879),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3879),
    [aux_sym__expression_token1] = ACTIONS(3879),
    [aux_sym__expression_token2] = ACTIONS(3879),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3877),
    [anon_sym_SLASH] = ACTIONS(3877),
    [anon_sym_div] = ACTIONS(3877),
    [anon_sym_DIV] = ACTIONS(3877),
    [anon_sym_Div] = ACTIONS(3877),
    [anon_sym_mod] = ACTIONS(3877),
    [anon_sym_MOD] = ACTIONS(3877),
    [anon_sym_Mod] = ACTIONS(3877),
    [anon_sym_PLUS] = ACTIONS(3877),
    [anon_sym_GT_EQ] = ACTIONS(3879),
    [anon_sym_LT_EQ] = ACTIONS(3879),
    [anon_sym_GT] = ACTIONS(3877),
    [anon_sym_LT] = ACTIONS(3877),
    [anon_sym_LT_GT] = ACTIONS(3879),
    [anon_sym_and] = ACTIONS(3877),
    [anon_sym_AND] = ACTIONS(3877),
    [anon_sym_And] = ACTIONS(3877),
    [anon_sym_or] = ACTIONS(3877),
    [anon_sym_OR] = ACTIONS(3877),
    [anon_sym_Or] = ACTIONS(3877),
    [anon_sym_xor] = ACTIONS(3877),
    [anon_sym_XOR] = ACTIONS(3877),
    [anon_sym_Xor] = ACTIONS(3877),
    [anon_sym_QMARK] = ACTIONS(3879),
    [sym_datetime_literal] = ACTIONS(3879),
    [sym_date_literal] = ACTIONS(3877),
    [sym_time_literal] = ACTIONS(3877),
    [sym_biginteger_literal] = ACTIONS(3879),
    [anon_sym_in] = ACTIONS(3877),
    [anon_sym_IN] = ACTIONS(3877),
    [anon_sym_In] = ACTIONS(3877),
    [sym_page_keyword] = ACTIONS(3877),
    [anon_sym_codeunit] = ACTIONS(3877),
    [anon_sym_CODEUNIT] = ACTIONS(3877),
    [anon_sym_Codeunit] = ACTIONS(3877),
    [anon_sym_CodeUnit] = ACTIONS(3877),
    [anon_sym_COdeunit] = ACTIONS(3877),
    [anon_sym_codeUnit] = ACTIONS(3877),
    [sym_report_keyword] = ACTIONS(3877),
    [sym_query_keyword] = ACTIONS(3877),
    [anon_sym_xmlport] = ACTIONS(3877),
    [anon_sym_XMLPORT] = ACTIONS(3877),
    [anon_sym_Xmlport] = ACTIONS(3877),
    [anon_sym_XMLport] = ACTIONS(3877),
    [anon_sym_XMLPort] = ACTIONS(3877),
    [anon_sym_XmlPort] = ACTIONS(3877),
    [anon_sym_enum] = ACTIONS(3877),
    [anon_sym_ENUM] = ACTIONS(3877),
    [anon_sym_Enum] = ACTIONS(3877),
    [anon_sym_eNUM] = ACTIONS(3877),
    [anon_sym_eNum] = ACTIONS(3877),
    [anon_sym_ENum] = ACTIONS(3877),
    [sym_quoted_identifier] = ACTIONS(3879),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3879),
    [sym_verbatim_string] = ACTIONS(3879),
    [sym_integer] = ACTIONS(3877),
    [sym_continue_as_identifier] = ACTIONS(3879),
    [sym_preproc_close] = ACTIONS(3879),
  },
  [STATE(3091)] = {
    [sym_identifier] = ACTIONS(5927),
    [anon_sym_SEMI] = ACTIONS(5929),
    [anon_sym_DASH] = ACTIONS(5929),
    [aux_sym_boolean_token1] = ACTIONS(5927),
    [aux_sym_boolean_token2] = ACTIONS(5927),
    [sym_decimal] = ACTIONS(5927),
    [anon_sym_LPAREN] = ACTIONS(5929),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5927),
    [anon_sym_LBRACK] = ACTIONS(5929),
    [aux_sym_record_type_token1] = ACTIONS(5927),
    [aux_sym_basic_type_token21] = ACTIONS(5927),
    [aux_sym_basic_type_token22] = ACTIONS(5927),
    [aux_sym_basic_type_token48] = ACTIONS(5927),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5927),
    [anon_sym_POUNDif] = ACTIONS(5929),
    [anon_sym_POUNDIF] = ACTIONS(5929),
    [anon_sym_POUNDIf] = ACTIONS(5929),
    [anon_sym_not] = ACTIONS(5927),
    [anon_sym_NOT] = ACTIONS(5927),
    [anon_sym_Not] = ACTIONS(5927),
    [anon_sym_POUNDelse] = ACTIONS(5929),
    [anon_sym_POUNDELSE] = ACTIONS(5929),
    [anon_sym_POUNDElse] = ACTIONS(5929),
    [anon_sym_POUNDelse2] = ACTIONS(5929),
    [anon_sym_POUNDELSE2] = ACTIONS(5929),
    [anon_sym_POUNDElse2] = ACTIONS(5929),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5927),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5927),
    [anon_sym_PLUS] = ACTIONS(5929),
    [sym_datetime_literal] = ACTIONS(5929),
    [sym_date_literal] = ACTIONS(5927),
    [sym_time_literal] = ACTIONS(5927),
    [sym_biginteger_literal] = ACTIONS(5929),
    [anon_sym_if] = ACTIONS(5927),
    [anon_sym_IF] = ACTIONS(5927),
    [anon_sym_If] = ACTIONS(5927),
    [anon_sym_else] = ACTIONS(5927),
    [anon_sym_ELSE] = ACTIONS(5927),
    [anon_sym_Else] = ACTIONS(5927),
    [anon_sym_case] = ACTIONS(5927),
    [anon_sym_CASE] = ACTIONS(5927),
    [anon_sym_Case] = ACTIONS(5927),
    [anon_sym_for] = ACTIONS(5927),
    [anon_sym_FOR] = ACTIONS(5927),
    [anon_sym_For] = ACTIONS(5927),
    [anon_sym_foreach] = ACTIONS(5927),
    [anon_sym_FOREACH] = ACTIONS(5927),
    [anon_sym_Foreach] = ACTIONS(5927),
    [anon_sym_while] = ACTIONS(5927),
    [anon_sym_WHILE] = ACTIONS(5927),
    [anon_sym_While] = ACTIONS(5927),
    [anon_sym_repeat] = ACTIONS(5927),
    [anon_sym_REPEAT] = ACTIONS(5927),
    [anon_sym_Repeat] = ACTIONS(5927),
    [anon_sym_until] = ACTIONS(5927),
    [anon_sym_UNTIL] = ACTIONS(5927),
    [anon_sym_Until] = ACTIONS(5927),
    [anon_sym_exit] = ACTIONS(5927),
    [anon_sym_EXIT] = ACTIONS(5927),
    [anon_sym_Exit] = ACTIONS(5927),
    [anon_sym_continue] = ACTIONS(5927),
    [anon_sym_CONTINUE] = ACTIONS(5927),
    [anon_sym_Continue] = ACTIONS(5927),
    [anon_sym_break] = ACTIONS(5927),
    [anon_sym_BREAK] = ACTIONS(5927),
    [anon_sym_Break] = ACTIONS(5927),
    [anon_sym_with] = ACTIONS(5927),
    [anon_sym_WITH] = ACTIONS(5927),
    [anon_sym_With] = ACTIONS(5927),
    [sym_asserterror_keyword] = ACTIONS(5929),
    [sym_page_keyword] = ACTIONS(5927),
    [anon_sym_codeunit] = ACTIONS(5927),
    [anon_sym_CODEUNIT] = ACTIONS(5927),
    [anon_sym_Codeunit] = ACTIONS(5927),
    [anon_sym_CodeUnit] = ACTIONS(5927),
    [anon_sym_COdeunit] = ACTIONS(5927),
    [anon_sym_codeUnit] = ACTIONS(5927),
    [sym_report_keyword] = ACTIONS(5927),
    [sym_query_keyword] = ACTIONS(5927),
    [anon_sym_xmlport] = ACTIONS(5927),
    [anon_sym_XMLPORT] = ACTIONS(5927),
    [anon_sym_Xmlport] = ACTIONS(5927),
    [anon_sym_XMLport] = ACTIONS(5927),
    [anon_sym_XMLPort] = ACTIONS(5927),
    [anon_sym_XmlPort] = ACTIONS(5927),
    [anon_sym_enum] = ACTIONS(5927),
    [anon_sym_ENUM] = ACTIONS(5927),
    [anon_sym_Enum] = ACTIONS(5927),
    [anon_sym_eNUM] = ACTIONS(5927),
    [anon_sym_eNum] = ACTIONS(5927),
    [anon_sym_ENum] = ACTIONS(5927),
    [sym_quoted_identifier] = ACTIONS(5929),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5929),
    [sym_verbatim_string] = ACTIONS(5929),
    [sym_integer] = ACTIONS(5927),
    [sym_continue_as_identifier] = ACTIONS(5929),
    [sym_preproc_open] = ACTIONS(5929),
  },
  [STATE(3092)] = {
    [sym_identifier] = ACTIONS(3909),
    [anon_sym_DOT] = ACTIONS(3909),
    [anon_sym_EQ] = ACTIONS(3911),
    [anon_sym_COMMA] = ACTIONS(3911),
    [anon_sym_DASH] = ACTIONS(3909),
    [aux_sym_boolean_token1] = ACTIONS(3909),
    [aux_sym_boolean_token2] = ACTIONS(3909),
    [sym_decimal] = ACTIONS(3909),
    [anon_sym_LPAREN] = ACTIONS(3911),
    [anon_sym_DOT_DOT] = ACTIONS(3911),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3909),
    [anon_sym_STAR] = ACTIONS(3909),
    [anon_sym_LBRACK] = ACTIONS(3911),
    [aux_sym_record_type_token1] = ACTIONS(3909),
    [aux_sym_basic_type_token21] = ACTIONS(3909),
    [aux_sym_basic_type_token22] = ACTIONS(3909),
    [aux_sym_basic_type_token48] = ACTIONS(3909),
    [anon_sym_not] = ACTIONS(3909),
    [anon_sym_NOT] = ACTIONS(3909),
    [anon_sym_Not] = ACTIONS(3909),
    [anon_sym_POUNDelif] = ACTIONS(3911),
    [anon_sym_POUNDELIF] = ACTIONS(3911),
    [anon_sym_POUNDElif] = ACTIONS(3911),
    [anon_sym_POUNDelse] = ACTIONS(3911),
    [anon_sym_POUNDELSE] = ACTIONS(3911),
    [anon_sym_POUNDElse] = ACTIONS(3911),
    [anon_sym_POUNDelse2] = ACTIONS(3911),
    [anon_sym_POUNDELSE2] = ACTIONS(3911),
    [anon_sym_POUNDElse2] = ACTIONS(3911),
    [anon_sym_POUNDendif] = ACTIONS(3911),
    [anon_sym_POUNDENDIF] = ACTIONS(3911),
    [anon_sym_POUNDEndif] = ACTIONS(3911),
    [anon_sym_POUNDendif2] = ACTIONS(3911),
    [anon_sym_POUNDENDIF2] = ACTIONS(3911),
    [anon_sym_POUNDEndif2] = ACTIONS(3911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3911),
    [aux_sym__expression_token1] = ACTIONS(3911),
    [aux_sym__expression_token2] = ACTIONS(3911),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3909),
    [anon_sym_SLASH] = ACTIONS(3909),
    [anon_sym_div] = ACTIONS(3909),
    [anon_sym_DIV] = ACTIONS(3909),
    [anon_sym_Div] = ACTIONS(3909),
    [anon_sym_mod] = ACTIONS(3909),
    [anon_sym_MOD] = ACTIONS(3909),
    [anon_sym_Mod] = ACTIONS(3909),
    [anon_sym_PLUS] = ACTIONS(3909),
    [anon_sym_GT_EQ] = ACTIONS(3911),
    [anon_sym_LT_EQ] = ACTIONS(3911),
    [anon_sym_GT] = ACTIONS(3909),
    [anon_sym_LT] = ACTIONS(3909),
    [anon_sym_LT_GT] = ACTIONS(3911),
    [anon_sym_and] = ACTIONS(3909),
    [anon_sym_AND] = ACTIONS(3909),
    [anon_sym_And] = ACTIONS(3909),
    [anon_sym_or] = ACTIONS(3909),
    [anon_sym_OR] = ACTIONS(3909),
    [anon_sym_Or] = ACTIONS(3909),
    [anon_sym_xor] = ACTIONS(3909),
    [anon_sym_XOR] = ACTIONS(3909),
    [anon_sym_Xor] = ACTIONS(3909),
    [anon_sym_QMARK] = ACTIONS(3911),
    [sym_datetime_literal] = ACTIONS(3911),
    [sym_date_literal] = ACTIONS(3909),
    [sym_time_literal] = ACTIONS(3909),
    [sym_biginteger_literal] = ACTIONS(3911),
    [anon_sym_in] = ACTIONS(3909),
    [anon_sym_IN] = ACTIONS(3909),
    [anon_sym_In] = ACTIONS(3909),
    [sym_page_keyword] = ACTIONS(3909),
    [anon_sym_codeunit] = ACTIONS(3909),
    [anon_sym_CODEUNIT] = ACTIONS(3909),
    [anon_sym_Codeunit] = ACTIONS(3909),
    [anon_sym_CodeUnit] = ACTIONS(3909),
    [anon_sym_COdeunit] = ACTIONS(3909),
    [anon_sym_codeUnit] = ACTIONS(3909),
    [sym_report_keyword] = ACTIONS(3909),
    [sym_query_keyword] = ACTIONS(3909),
    [anon_sym_xmlport] = ACTIONS(3909),
    [anon_sym_XMLPORT] = ACTIONS(3909),
    [anon_sym_Xmlport] = ACTIONS(3909),
    [anon_sym_XMLport] = ACTIONS(3909),
    [anon_sym_XMLPort] = ACTIONS(3909),
    [anon_sym_XmlPort] = ACTIONS(3909),
    [anon_sym_enum] = ACTIONS(3909),
    [anon_sym_ENUM] = ACTIONS(3909),
    [anon_sym_Enum] = ACTIONS(3909),
    [anon_sym_eNUM] = ACTIONS(3909),
    [anon_sym_eNum] = ACTIONS(3909),
    [anon_sym_ENum] = ACTIONS(3909),
    [sym_quoted_identifier] = ACTIONS(3911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3911),
    [sym_verbatim_string] = ACTIONS(3911),
    [sym_integer] = ACTIONS(3909),
    [sym_continue_as_identifier] = ACTIONS(3911),
    [sym_preproc_close] = ACTIONS(3911),
  },
  [STATE(3093)] = {
    [sym_identifier] = ACTIONS(3913),
    [anon_sym_DOT] = ACTIONS(3913),
    [anon_sym_EQ] = ACTIONS(3915),
    [anon_sym_COMMA] = ACTIONS(3915),
    [anon_sym_DASH] = ACTIONS(3913),
    [aux_sym_boolean_token1] = ACTIONS(3913),
    [aux_sym_boolean_token2] = ACTIONS(3913),
    [sym_decimal] = ACTIONS(3913),
    [anon_sym_LPAREN] = ACTIONS(3915),
    [anon_sym_DOT_DOT] = ACTIONS(3915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3913),
    [anon_sym_STAR] = ACTIONS(3913),
    [anon_sym_LBRACK] = ACTIONS(3915),
    [aux_sym_record_type_token1] = ACTIONS(3913),
    [aux_sym_basic_type_token21] = ACTIONS(3913),
    [aux_sym_basic_type_token22] = ACTIONS(3913),
    [aux_sym_basic_type_token48] = ACTIONS(3913),
    [anon_sym_not] = ACTIONS(3913),
    [anon_sym_NOT] = ACTIONS(3913),
    [anon_sym_Not] = ACTIONS(3913),
    [anon_sym_POUNDelif] = ACTIONS(3915),
    [anon_sym_POUNDELIF] = ACTIONS(3915),
    [anon_sym_POUNDElif] = ACTIONS(3915),
    [anon_sym_POUNDelse] = ACTIONS(3915),
    [anon_sym_POUNDELSE] = ACTIONS(3915),
    [anon_sym_POUNDElse] = ACTIONS(3915),
    [anon_sym_POUNDelse2] = ACTIONS(3915),
    [anon_sym_POUNDELSE2] = ACTIONS(3915),
    [anon_sym_POUNDElse2] = ACTIONS(3915),
    [anon_sym_POUNDendif] = ACTIONS(3915),
    [anon_sym_POUNDENDIF] = ACTIONS(3915),
    [anon_sym_POUNDEndif] = ACTIONS(3915),
    [anon_sym_POUNDendif2] = ACTIONS(3915),
    [anon_sym_POUNDENDIF2] = ACTIONS(3915),
    [anon_sym_POUNDEndif2] = ACTIONS(3915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3915),
    [aux_sym__expression_token1] = ACTIONS(3915),
    [aux_sym__expression_token2] = ACTIONS(3915),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3913),
    [anon_sym_SLASH] = ACTIONS(3913),
    [anon_sym_div] = ACTIONS(3913),
    [anon_sym_DIV] = ACTIONS(3913),
    [anon_sym_Div] = ACTIONS(3913),
    [anon_sym_mod] = ACTIONS(3913),
    [anon_sym_MOD] = ACTIONS(3913),
    [anon_sym_Mod] = ACTIONS(3913),
    [anon_sym_PLUS] = ACTIONS(3913),
    [anon_sym_GT_EQ] = ACTIONS(3915),
    [anon_sym_LT_EQ] = ACTIONS(3915),
    [anon_sym_GT] = ACTIONS(3913),
    [anon_sym_LT] = ACTIONS(3913),
    [anon_sym_LT_GT] = ACTIONS(3915),
    [anon_sym_and] = ACTIONS(3913),
    [anon_sym_AND] = ACTIONS(3913),
    [anon_sym_And] = ACTIONS(3913),
    [anon_sym_or] = ACTIONS(3913),
    [anon_sym_OR] = ACTIONS(3913),
    [anon_sym_Or] = ACTIONS(3913),
    [anon_sym_xor] = ACTIONS(3913),
    [anon_sym_XOR] = ACTIONS(3913),
    [anon_sym_Xor] = ACTIONS(3913),
    [anon_sym_QMARK] = ACTIONS(3915),
    [sym_datetime_literal] = ACTIONS(3915),
    [sym_date_literal] = ACTIONS(3913),
    [sym_time_literal] = ACTIONS(3913),
    [sym_biginteger_literal] = ACTIONS(3915),
    [anon_sym_in] = ACTIONS(3913),
    [anon_sym_IN] = ACTIONS(3913),
    [anon_sym_In] = ACTIONS(3913),
    [sym_page_keyword] = ACTIONS(3913),
    [anon_sym_codeunit] = ACTIONS(3913),
    [anon_sym_CODEUNIT] = ACTIONS(3913),
    [anon_sym_Codeunit] = ACTIONS(3913),
    [anon_sym_CodeUnit] = ACTIONS(3913),
    [anon_sym_COdeunit] = ACTIONS(3913),
    [anon_sym_codeUnit] = ACTIONS(3913),
    [sym_report_keyword] = ACTIONS(3913),
    [sym_query_keyword] = ACTIONS(3913),
    [anon_sym_xmlport] = ACTIONS(3913),
    [anon_sym_XMLPORT] = ACTIONS(3913),
    [anon_sym_Xmlport] = ACTIONS(3913),
    [anon_sym_XMLport] = ACTIONS(3913),
    [anon_sym_XMLPort] = ACTIONS(3913),
    [anon_sym_XmlPort] = ACTIONS(3913),
    [anon_sym_enum] = ACTIONS(3913),
    [anon_sym_ENUM] = ACTIONS(3913),
    [anon_sym_Enum] = ACTIONS(3913),
    [anon_sym_eNUM] = ACTIONS(3913),
    [anon_sym_eNum] = ACTIONS(3913),
    [anon_sym_ENum] = ACTIONS(3913),
    [sym_quoted_identifier] = ACTIONS(3915),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3915),
    [sym_verbatim_string] = ACTIONS(3915),
    [sym_integer] = ACTIONS(3913),
    [sym_continue_as_identifier] = ACTIONS(3915),
    [sym_preproc_close] = ACTIONS(3915),
  },
  [STATE(3094)] = {
    [sym_identifier] = ACTIONS(3917),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_EQ] = ACTIONS(3919),
    [anon_sym_COMMA] = ACTIONS(3919),
    [anon_sym_DASH] = ACTIONS(3917),
    [aux_sym_boolean_token1] = ACTIONS(3917),
    [aux_sym_boolean_token2] = ACTIONS(3917),
    [sym_decimal] = ACTIONS(3917),
    [anon_sym_LPAREN] = ACTIONS(3919),
    [anon_sym_DOT_DOT] = ACTIONS(3919),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3919),
    [aux_sym_record_type_token1] = ACTIONS(3917),
    [aux_sym_basic_type_token21] = ACTIONS(3917),
    [aux_sym_basic_type_token22] = ACTIONS(3917),
    [aux_sym_basic_type_token48] = ACTIONS(3917),
    [anon_sym_not] = ACTIONS(3917),
    [anon_sym_NOT] = ACTIONS(3917),
    [anon_sym_Not] = ACTIONS(3917),
    [anon_sym_POUNDelif] = ACTIONS(3919),
    [anon_sym_POUNDELIF] = ACTIONS(3919),
    [anon_sym_POUNDElif] = ACTIONS(3919),
    [anon_sym_POUNDelse] = ACTIONS(3919),
    [anon_sym_POUNDELSE] = ACTIONS(3919),
    [anon_sym_POUNDElse] = ACTIONS(3919),
    [anon_sym_POUNDelse2] = ACTIONS(3919),
    [anon_sym_POUNDELSE2] = ACTIONS(3919),
    [anon_sym_POUNDElse2] = ACTIONS(3919),
    [anon_sym_POUNDendif] = ACTIONS(3919),
    [anon_sym_POUNDENDIF] = ACTIONS(3919),
    [anon_sym_POUNDEndif] = ACTIONS(3919),
    [anon_sym_POUNDendif2] = ACTIONS(3919),
    [anon_sym_POUNDENDIF2] = ACTIONS(3919),
    [anon_sym_POUNDEndif2] = ACTIONS(3919),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3919),
    [aux_sym__expression_token1] = ACTIONS(3919),
    [aux_sym__expression_token2] = ACTIONS(3919),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_div] = ACTIONS(3917),
    [anon_sym_DIV] = ACTIONS(3917),
    [anon_sym_Div] = ACTIONS(3917),
    [anon_sym_mod] = ACTIONS(3917),
    [anon_sym_MOD] = ACTIONS(3917),
    [anon_sym_Mod] = ACTIONS(3917),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3919),
    [anon_sym_LT_EQ] = ACTIONS(3919),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_LT_GT] = ACTIONS(3919),
    [anon_sym_and] = ACTIONS(3917),
    [anon_sym_AND] = ACTIONS(3917),
    [anon_sym_And] = ACTIONS(3917),
    [anon_sym_or] = ACTIONS(3917),
    [anon_sym_OR] = ACTIONS(3917),
    [anon_sym_Or] = ACTIONS(3917),
    [anon_sym_xor] = ACTIONS(3917),
    [anon_sym_XOR] = ACTIONS(3917),
    [anon_sym_Xor] = ACTIONS(3917),
    [anon_sym_QMARK] = ACTIONS(3919),
    [sym_datetime_literal] = ACTIONS(3919),
    [sym_date_literal] = ACTIONS(3917),
    [sym_time_literal] = ACTIONS(3917),
    [sym_biginteger_literal] = ACTIONS(3919),
    [anon_sym_in] = ACTIONS(3917),
    [anon_sym_IN] = ACTIONS(3917),
    [anon_sym_In] = ACTIONS(3917),
    [sym_page_keyword] = ACTIONS(3917),
    [anon_sym_codeunit] = ACTIONS(3917),
    [anon_sym_CODEUNIT] = ACTIONS(3917),
    [anon_sym_Codeunit] = ACTIONS(3917),
    [anon_sym_CodeUnit] = ACTIONS(3917),
    [anon_sym_COdeunit] = ACTIONS(3917),
    [anon_sym_codeUnit] = ACTIONS(3917),
    [sym_report_keyword] = ACTIONS(3917),
    [sym_query_keyword] = ACTIONS(3917),
    [anon_sym_xmlport] = ACTIONS(3917),
    [anon_sym_XMLPORT] = ACTIONS(3917),
    [anon_sym_Xmlport] = ACTIONS(3917),
    [anon_sym_XMLport] = ACTIONS(3917),
    [anon_sym_XMLPort] = ACTIONS(3917),
    [anon_sym_XmlPort] = ACTIONS(3917),
    [anon_sym_enum] = ACTIONS(3917),
    [anon_sym_ENUM] = ACTIONS(3917),
    [anon_sym_Enum] = ACTIONS(3917),
    [anon_sym_eNUM] = ACTIONS(3917),
    [anon_sym_eNum] = ACTIONS(3917),
    [anon_sym_ENum] = ACTIONS(3917),
    [sym_quoted_identifier] = ACTIONS(3919),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3919),
    [sym_verbatim_string] = ACTIONS(3919),
    [sym_integer] = ACTIONS(3917),
    [sym_continue_as_identifier] = ACTIONS(3919),
    [sym_preproc_close] = ACTIONS(3919),
  },
  [STATE(3095)] = {
    [sym_identifier] = ACTIONS(5931),
    [anon_sym_SEMI] = ACTIONS(5933),
    [anon_sym_DASH] = ACTIONS(5933),
    [aux_sym_boolean_token1] = ACTIONS(5931),
    [aux_sym_boolean_token2] = ACTIONS(5931),
    [sym_decimal] = ACTIONS(5931),
    [anon_sym_LPAREN] = ACTIONS(5933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5931),
    [anon_sym_LBRACK] = ACTIONS(5933),
    [aux_sym_record_type_token1] = ACTIONS(5931),
    [aux_sym_basic_type_token21] = ACTIONS(5931),
    [aux_sym_basic_type_token22] = ACTIONS(5931),
    [aux_sym_basic_type_token48] = ACTIONS(5931),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5931),
    [anon_sym_POUNDif] = ACTIONS(5933),
    [anon_sym_POUNDIF] = ACTIONS(5933),
    [anon_sym_POUNDIf] = ACTIONS(5933),
    [anon_sym_not] = ACTIONS(5931),
    [anon_sym_NOT] = ACTIONS(5931),
    [anon_sym_Not] = ACTIONS(5931),
    [anon_sym_POUNDelse] = ACTIONS(5933),
    [anon_sym_POUNDELSE] = ACTIONS(5933),
    [anon_sym_POUNDElse] = ACTIONS(5933),
    [anon_sym_POUNDelse2] = ACTIONS(5933),
    [anon_sym_POUNDELSE2] = ACTIONS(5933),
    [anon_sym_POUNDElse2] = ACTIONS(5933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5931),
    [anon_sym_PLUS] = ACTIONS(5933),
    [sym_datetime_literal] = ACTIONS(5933),
    [sym_date_literal] = ACTIONS(5931),
    [sym_time_literal] = ACTIONS(5931),
    [sym_biginteger_literal] = ACTIONS(5933),
    [anon_sym_if] = ACTIONS(5931),
    [anon_sym_IF] = ACTIONS(5931),
    [anon_sym_If] = ACTIONS(5931),
    [anon_sym_else] = ACTIONS(5931),
    [anon_sym_ELSE] = ACTIONS(5931),
    [anon_sym_Else] = ACTIONS(5931),
    [anon_sym_case] = ACTIONS(5931),
    [anon_sym_CASE] = ACTIONS(5931),
    [anon_sym_Case] = ACTIONS(5931),
    [anon_sym_for] = ACTIONS(5931),
    [anon_sym_FOR] = ACTIONS(5931),
    [anon_sym_For] = ACTIONS(5931),
    [anon_sym_foreach] = ACTIONS(5931),
    [anon_sym_FOREACH] = ACTIONS(5931),
    [anon_sym_Foreach] = ACTIONS(5931),
    [anon_sym_while] = ACTIONS(5931),
    [anon_sym_WHILE] = ACTIONS(5931),
    [anon_sym_While] = ACTIONS(5931),
    [anon_sym_repeat] = ACTIONS(5931),
    [anon_sym_REPEAT] = ACTIONS(5931),
    [anon_sym_Repeat] = ACTIONS(5931),
    [anon_sym_until] = ACTIONS(5931),
    [anon_sym_UNTIL] = ACTIONS(5931),
    [anon_sym_Until] = ACTIONS(5931),
    [anon_sym_exit] = ACTIONS(5931),
    [anon_sym_EXIT] = ACTIONS(5931),
    [anon_sym_Exit] = ACTIONS(5931),
    [anon_sym_continue] = ACTIONS(5931),
    [anon_sym_CONTINUE] = ACTIONS(5931),
    [anon_sym_Continue] = ACTIONS(5931),
    [anon_sym_break] = ACTIONS(5931),
    [anon_sym_BREAK] = ACTIONS(5931),
    [anon_sym_Break] = ACTIONS(5931),
    [anon_sym_with] = ACTIONS(5931),
    [anon_sym_WITH] = ACTIONS(5931),
    [anon_sym_With] = ACTIONS(5931),
    [sym_asserterror_keyword] = ACTIONS(5933),
    [sym_page_keyword] = ACTIONS(5931),
    [anon_sym_codeunit] = ACTIONS(5931),
    [anon_sym_CODEUNIT] = ACTIONS(5931),
    [anon_sym_Codeunit] = ACTIONS(5931),
    [anon_sym_CodeUnit] = ACTIONS(5931),
    [anon_sym_COdeunit] = ACTIONS(5931),
    [anon_sym_codeUnit] = ACTIONS(5931),
    [sym_report_keyword] = ACTIONS(5931),
    [sym_query_keyword] = ACTIONS(5931),
    [anon_sym_xmlport] = ACTIONS(5931),
    [anon_sym_XMLPORT] = ACTIONS(5931),
    [anon_sym_Xmlport] = ACTIONS(5931),
    [anon_sym_XMLport] = ACTIONS(5931),
    [anon_sym_XMLPort] = ACTIONS(5931),
    [anon_sym_XmlPort] = ACTIONS(5931),
    [anon_sym_enum] = ACTIONS(5931),
    [anon_sym_ENUM] = ACTIONS(5931),
    [anon_sym_Enum] = ACTIONS(5931),
    [anon_sym_eNUM] = ACTIONS(5931),
    [anon_sym_eNum] = ACTIONS(5931),
    [anon_sym_ENum] = ACTIONS(5931),
    [sym_quoted_identifier] = ACTIONS(5933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5933),
    [sym_verbatim_string] = ACTIONS(5933),
    [sym_integer] = ACTIONS(5931),
    [sym_continue_as_identifier] = ACTIONS(5933),
    [sym_preproc_open] = ACTIONS(5933),
  },
  [STATE(3096)] = {
    [sym_identifier] = ACTIONS(5949),
    [anon_sym_SEMI] = ACTIONS(5951),
    [anon_sym_DASH] = ACTIONS(5951),
    [aux_sym_boolean_token1] = ACTIONS(5949),
    [aux_sym_boolean_token2] = ACTIONS(5949),
    [sym_decimal] = ACTIONS(5949),
    [anon_sym_LPAREN] = ACTIONS(5951),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5949),
    [anon_sym_LBRACK] = ACTIONS(5951),
    [aux_sym_record_type_token1] = ACTIONS(5949),
    [aux_sym_basic_type_token21] = ACTIONS(5949),
    [aux_sym_basic_type_token22] = ACTIONS(5949),
    [aux_sym_basic_type_token48] = ACTIONS(5949),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5949),
    [anon_sym_POUNDif] = ACTIONS(5951),
    [anon_sym_POUNDIF] = ACTIONS(5951),
    [anon_sym_POUNDIf] = ACTIONS(5951),
    [anon_sym_not] = ACTIONS(5949),
    [anon_sym_NOT] = ACTIONS(5949),
    [anon_sym_Not] = ACTIONS(5949),
    [anon_sym_POUNDelse] = ACTIONS(5951),
    [anon_sym_POUNDELSE] = ACTIONS(5951),
    [anon_sym_POUNDElse] = ACTIONS(5951),
    [anon_sym_POUNDelse2] = ACTIONS(5951),
    [anon_sym_POUNDELSE2] = ACTIONS(5951),
    [anon_sym_POUNDElse2] = ACTIONS(5951),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5949),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5949),
    [anon_sym_PLUS] = ACTIONS(5951),
    [sym_datetime_literal] = ACTIONS(5951),
    [sym_date_literal] = ACTIONS(5949),
    [sym_time_literal] = ACTIONS(5949),
    [sym_biginteger_literal] = ACTIONS(5951),
    [anon_sym_if] = ACTIONS(5949),
    [anon_sym_IF] = ACTIONS(5949),
    [anon_sym_If] = ACTIONS(5949),
    [anon_sym_else] = ACTIONS(5949),
    [anon_sym_ELSE] = ACTIONS(5949),
    [anon_sym_Else] = ACTIONS(5949),
    [anon_sym_case] = ACTIONS(5949),
    [anon_sym_CASE] = ACTIONS(5949),
    [anon_sym_Case] = ACTIONS(5949),
    [anon_sym_for] = ACTIONS(5949),
    [anon_sym_FOR] = ACTIONS(5949),
    [anon_sym_For] = ACTIONS(5949),
    [anon_sym_foreach] = ACTIONS(5949),
    [anon_sym_FOREACH] = ACTIONS(5949),
    [anon_sym_Foreach] = ACTIONS(5949),
    [anon_sym_while] = ACTIONS(5949),
    [anon_sym_WHILE] = ACTIONS(5949),
    [anon_sym_While] = ACTIONS(5949),
    [anon_sym_repeat] = ACTIONS(5949),
    [anon_sym_REPEAT] = ACTIONS(5949),
    [anon_sym_Repeat] = ACTIONS(5949),
    [anon_sym_until] = ACTIONS(5949),
    [anon_sym_UNTIL] = ACTIONS(5949),
    [anon_sym_Until] = ACTIONS(5949),
    [anon_sym_exit] = ACTIONS(5949),
    [anon_sym_EXIT] = ACTIONS(5949),
    [anon_sym_Exit] = ACTIONS(5949),
    [anon_sym_continue] = ACTIONS(5949),
    [anon_sym_CONTINUE] = ACTIONS(5949),
    [anon_sym_Continue] = ACTIONS(5949),
    [anon_sym_break] = ACTIONS(5949),
    [anon_sym_BREAK] = ACTIONS(5949),
    [anon_sym_Break] = ACTIONS(5949),
    [anon_sym_with] = ACTIONS(5949),
    [anon_sym_WITH] = ACTIONS(5949),
    [anon_sym_With] = ACTIONS(5949),
    [sym_asserterror_keyword] = ACTIONS(5951),
    [sym_page_keyword] = ACTIONS(5949),
    [anon_sym_codeunit] = ACTIONS(5949),
    [anon_sym_CODEUNIT] = ACTIONS(5949),
    [anon_sym_Codeunit] = ACTIONS(5949),
    [anon_sym_CodeUnit] = ACTIONS(5949),
    [anon_sym_COdeunit] = ACTIONS(5949),
    [anon_sym_codeUnit] = ACTIONS(5949),
    [sym_report_keyword] = ACTIONS(5949),
    [sym_query_keyword] = ACTIONS(5949),
    [anon_sym_xmlport] = ACTIONS(5949),
    [anon_sym_XMLPORT] = ACTIONS(5949),
    [anon_sym_Xmlport] = ACTIONS(5949),
    [anon_sym_XMLport] = ACTIONS(5949),
    [anon_sym_XMLPort] = ACTIONS(5949),
    [anon_sym_XmlPort] = ACTIONS(5949),
    [anon_sym_enum] = ACTIONS(5949),
    [anon_sym_ENUM] = ACTIONS(5949),
    [anon_sym_Enum] = ACTIONS(5949),
    [anon_sym_eNUM] = ACTIONS(5949),
    [anon_sym_eNum] = ACTIONS(5949),
    [anon_sym_ENum] = ACTIONS(5949),
    [sym_quoted_identifier] = ACTIONS(5951),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5951),
    [sym_verbatim_string] = ACTIONS(5951),
    [sym_integer] = ACTIONS(5949),
    [sym_continue_as_identifier] = ACTIONS(5951),
    [sym_preproc_open] = ACTIONS(5951),
  },
  [STATE(3097)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [anon_sym_POUNDelif] = ACTIONS(3665),
    [anon_sym_POUNDELIF] = ACTIONS(3665),
    [anon_sym_POUNDElif] = ACTIONS(3665),
    [anon_sym_POUNDelse] = ACTIONS(3665),
    [anon_sym_POUNDELSE] = ACTIONS(3665),
    [anon_sym_POUNDElse] = ACTIONS(3665),
    [anon_sym_POUNDelse2] = ACTIONS(3665),
    [anon_sym_POUNDELSE2] = ACTIONS(3665),
    [anon_sym_POUNDElse2] = ACTIONS(3665),
    [anon_sym_POUNDendif] = ACTIONS(3665),
    [anon_sym_POUNDENDIF] = ACTIONS(3665),
    [anon_sym_POUNDEndif] = ACTIONS(3665),
    [anon_sym_POUNDendif2] = ACTIONS(3665),
    [anon_sym_POUNDENDIF2] = ACTIONS(3665),
    [anon_sym_POUNDEndif2] = ACTIONS(3665),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_close] = ACTIONS(3665),
  },
  [STATE(3098)] = {
    [sym_identifier] = ACTIONS(5939),
    [anon_sym_SEMI] = ACTIONS(7209),
    [anon_sym_DASH] = ACTIONS(5943),
    [aux_sym_boolean_token1] = ACTIONS(5939),
    [aux_sym_boolean_token2] = ACTIONS(5939),
    [sym_decimal] = ACTIONS(5939),
    [anon_sym_LPAREN] = ACTIONS(5943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5939),
    [anon_sym_LBRACK] = ACTIONS(5943),
    [aux_sym_record_type_token1] = ACTIONS(5939),
    [aux_sym_basic_type_token21] = ACTIONS(5939),
    [aux_sym_basic_type_token22] = ACTIONS(5939),
    [aux_sym_basic_type_token48] = ACTIONS(5939),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5939),
    [anon_sym_POUNDif] = ACTIONS(5943),
    [anon_sym_POUNDIF] = ACTIONS(5943),
    [anon_sym_POUNDIf] = ACTIONS(5943),
    [anon_sym_not] = ACTIONS(5939),
    [anon_sym_NOT] = ACTIONS(5939),
    [anon_sym_Not] = ACTIONS(5939),
    [anon_sym_POUNDelse] = ACTIONS(5943),
    [anon_sym_POUNDELSE] = ACTIONS(5943),
    [anon_sym_POUNDElse] = ACTIONS(5943),
    [anon_sym_POUNDelse2] = ACTIONS(5943),
    [anon_sym_POUNDELSE2] = ACTIONS(5943),
    [anon_sym_POUNDElse2] = ACTIONS(5943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5939),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5939),
    [anon_sym_PLUS] = ACTIONS(5943),
    [sym_datetime_literal] = ACTIONS(5943),
    [sym_date_literal] = ACTIONS(5939),
    [sym_time_literal] = ACTIONS(5939),
    [sym_biginteger_literal] = ACTIONS(5943),
    [anon_sym_if] = ACTIONS(5939),
    [anon_sym_IF] = ACTIONS(5939),
    [anon_sym_If] = ACTIONS(5939),
    [anon_sym_else] = ACTIONS(5939),
    [anon_sym_ELSE] = ACTIONS(5939),
    [anon_sym_Else] = ACTIONS(5939),
    [anon_sym_case] = ACTIONS(5939),
    [anon_sym_CASE] = ACTIONS(5939),
    [anon_sym_Case] = ACTIONS(5939),
    [anon_sym_for] = ACTIONS(5939),
    [anon_sym_FOR] = ACTIONS(5939),
    [anon_sym_For] = ACTIONS(5939),
    [anon_sym_foreach] = ACTIONS(5939),
    [anon_sym_FOREACH] = ACTIONS(5939),
    [anon_sym_Foreach] = ACTIONS(5939),
    [anon_sym_while] = ACTIONS(5939),
    [anon_sym_WHILE] = ACTIONS(5939),
    [anon_sym_While] = ACTIONS(5939),
    [anon_sym_repeat] = ACTIONS(5939),
    [anon_sym_REPEAT] = ACTIONS(5939),
    [anon_sym_Repeat] = ACTIONS(5939),
    [anon_sym_until] = ACTIONS(5939),
    [anon_sym_UNTIL] = ACTIONS(5939),
    [anon_sym_Until] = ACTIONS(5939),
    [anon_sym_exit] = ACTIONS(5939),
    [anon_sym_EXIT] = ACTIONS(5939),
    [anon_sym_Exit] = ACTIONS(5939),
    [anon_sym_continue] = ACTIONS(5939),
    [anon_sym_CONTINUE] = ACTIONS(5939),
    [anon_sym_Continue] = ACTIONS(5939),
    [anon_sym_break] = ACTIONS(5939),
    [anon_sym_BREAK] = ACTIONS(5939),
    [anon_sym_Break] = ACTIONS(5939),
    [anon_sym_with] = ACTIONS(5939),
    [anon_sym_WITH] = ACTIONS(5939),
    [anon_sym_With] = ACTIONS(5939),
    [sym_asserterror_keyword] = ACTIONS(5943),
    [sym_page_keyword] = ACTIONS(5939),
    [anon_sym_codeunit] = ACTIONS(5939),
    [anon_sym_CODEUNIT] = ACTIONS(5939),
    [anon_sym_Codeunit] = ACTIONS(5939),
    [anon_sym_CodeUnit] = ACTIONS(5939),
    [anon_sym_COdeunit] = ACTIONS(5939),
    [anon_sym_codeUnit] = ACTIONS(5939),
    [sym_report_keyword] = ACTIONS(5939),
    [sym_query_keyword] = ACTIONS(5939),
    [anon_sym_xmlport] = ACTIONS(5939),
    [anon_sym_XMLPORT] = ACTIONS(5939),
    [anon_sym_Xmlport] = ACTIONS(5939),
    [anon_sym_XMLport] = ACTIONS(5939),
    [anon_sym_XMLPort] = ACTIONS(5939),
    [anon_sym_XmlPort] = ACTIONS(5939),
    [anon_sym_enum] = ACTIONS(5939),
    [anon_sym_ENUM] = ACTIONS(5939),
    [anon_sym_Enum] = ACTIONS(5939),
    [anon_sym_eNUM] = ACTIONS(5939),
    [anon_sym_eNum] = ACTIONS(5939),
    [anon_sym_ENum] = ACTIONS(5939),
    [sym_quoted_identifier] = ACTIONS(5943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5943),
    [sym_verbatim_string] = ACTIONS(5943),
    [sym_integer] = ACTIONS(5939),
    [sym_continue_as_identifier] = ACTIONS(5943),
    [sym_preproc_open] = ACTIONS(5943),
  },
  [STATE(3099)] = {
    [sym_identifier] = ACTIONS(3885),
    [anon_sym_DOT] = ACTIONS(3885),
    [anon_sym_EQ] = ACTIONS(3887),
    [anon_sym_COMMA] = ACTIONS(3887),
    [anon_sym_DASH] = ACTIONS(3885),
    [aux_sym_boolean_token1] = ACTIONS(3885),
    [aux_sym_boolean_token2] = ACTIONS(3885),
    [sym_decimal] = ACTIONS(3885),
    [anon_sym_LPAREN] = ACTIONS(3887),
    [anon_sym_DOT_DOT] = ACTIONS(3887),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3885),
    [anon_sym_STAR] = ACTIONS(3885),
    [anon_sym_LBRACK] = ACTIONS(3887),
    [aux_sym_record_type_token1] = ACTIONS(3885),
    [aux_sym_basic_type_token21] = ACTIONS(3885),
    [aux_sym_basic_type_token22] = ACTIONS(3885),
    [aux_sym_basic_type_token48] = ACTIONS(3885),
    [anon_sym_not] = ACTIONS(3885),
    [anon_sym_NOT] = ACTIONS(3885),
    [anon_sym_Not] = ACTIONS(3885),
    [anon_sym_POUNDelif] = ACTIONS(3887),
    [anon_sym_POUNDELIF] = ACTIONS(3887),
    [anon_sym_POUNDElif] = ACTIONS(3887),
    [anon_sym_POUNDelse] = ACTIONS(3887),
    [anon_sym_POUNDELSE] = ACTIONS(3887),
    [anon_sym_POUNDElse] = ACTIONS(3887),
    [anon_sym_POUNDelse2] = ACTIONS(3887),
    [anon_sym_POUNDELSE2] = ACTIONS(3887),
    [anon_sym_POUNDElse2] = ACTIONS(3887),
    [anon_sym_POUNDendif] = ACTIONS(3887),
    [anon_sym_POUNDENDIF] = ACTIONS(3887),
    [anon_sym_POUNDEndif] = ACTIONS(3887),
    [anon_sym_POUNDendif2] = ACTIONS(3887),
    [anon_sym_POUNDENDIF2] = ACTIONS(3887),
    [anon_sym_POUNDEndif2] = ACTIONS(3887),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3887),
    [aux_sym__expression_token1] = ACTIONS(3887),
    [aux_sym__expression_token2] = ACTIONS(3887),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3885),
    [anon_sym_SLASH] = ACTIONS(3885),
    [anon_sym_div] = ACTIONS(3885),
    [anon_sym_DIV] = ACTIONS(3885),
    [anon_sym_Div] = ACTIONS(3885),
    [anon_sym_mod] = ACTIONS(3885),
    [anon_sym_MOD] = ACTIONS(3885),
    [anon_sym_Mod] = ACTIONS(3885),
    [anon_sym_PLUS] = ACTIONS(3885),
    [anon_sym_GT_EQ] = ACTIONS(3887),
    [anon_sym_LT_EQ] = ACTIONS(3887),
    [anon_sym_GT] = ACTIONS(3885),
    [anon_sym_LT] = ACTIONS(3885),
    [anon_sym_LT_GT] = ACTIONS(3887),
    [anon_sym_and] = ACTIONS(3885),
    [anon_sym_AND] = ACTIONS(3885),
    [anon_sym_And] = ACTIONS(3885),
    [anon_sym_or] = ACTIONS(3885),
    [anon_sym_OR] = ACTIONS(3885),
    [anon_sym_Or] = ACTIONS(3885),
    [anon_sym_xor] = ACTIONS(3885),
    [anon_sym_XOR] = ACTIONS(3885),
    [anon_sym_Xor] = ACTIONS(3885),
    [anon_sym_QMARK] = ACTIONS(3887),
    [sym_datetime_literal] = ACTIONS(3887),
    [sym_date_literal] = ACTIONS(3885),
    [sym_time_literal] = ACTIONS(3885),
    [sym_biginteger_literal] = ACTIONS(3887),
    [anon_sym_in] = ACTIONS(3885),
    [anon_sym_IN] = ACTIONS(3885),
    [anon_sym_In] = ACTIONS(3885),
    [sym_page_keyword] = ACTIONS(3885),
    [anon_sym_codeunit] = ACTIONS(3885),
    [anon_sym_CODEUNIT] = ACTIONS(3885),
    [anon_sym_Codeunit] = ACTIONS(3885),
    [anon_sym_CodeUnit] = ACTIONS(3885),
    [anon_sym_COdeunit] = ACTIONS(3885),
    [anon_sym_codeUnit] = ACTIONS(3885),
    [sym_report_keyword] = ACTIONS(3885),
    [sym_query_keyword] = ACTIONS(3885),
    [anon_sym_xmlport] = ACTIONS(3885),
    [anon_sym_XMLPORT] = ACTIONS(3885),
    [anon_sym_Xmlport] = ACTIONS(3885),
    [anon_sym_XMLport] = ACTIONS(3885),
    [anon_sym_XMLPort] = ACTIONS(3885),
    [anon_sym_XmlPort] = ACTIONS(3885),
    [anon_sym_enum] = ACTIONS(3885),
    [anon_sym_ENUM] = ACTIONS(3885),
    [anon_sym_Enum] = ACTIONS(3885),
    [anon_sym_eNUM] = ACTIONS(3885),
    [anon_sym_eNum] = ACTIONS(3885),
    [anon_sym_ENum] = ACTIONS(3885),
    [sym_quoted_identifier] = ACTIONS(3887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3887),
    [sym_verbatim_string] = ACTIONS(3887),
    [sym_integer] = ACTIONS(3885),
    [sym_continue_as_identifier] = ACTIONS(3887),
    [sym_preproc_close] = ACTIONS(3887),
  },
  [STATE(3100)] = {
    [sym_identifier] = ACTIONS(5953),
    [anon_sym_SEMI] = ACTIONS(5955),
    [anon_sym_DASH] = ACTIONS(5955),
    [aux_sym_boolean_token1] = ACTIONS(5953),
    [aux_sym_boolean_token2] = ACTIONS(5953),
    [sym_decimal] = ACTIONS(5953),
    [anon_sym_LPAREN] = ACTIONS(5955),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5953),
    [anon_sym_LBRACK] = ACTIONS(5955),
    [aux_sym_record_type_token1] = ACTIONS(5953),
    [aux_sym_basic_type_token21] = ACTIONS(5953),
    [aux_sym_basic_type_token22] = ACTIONS(5953),
    [aux_sym_basic_type_token48] = ACTIONS(5953),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5953),
    [anon_sym_POUNDif] = ACTIONS(5955),
    [anon_sym_POUNDIF] = ACTIONS(5955),
    [anon_sym_POUNDIf] = ACTIONS(5955),
    [anon_sym_not] = ACTIONS(5953),
    [anon_sym_NOT] = ACTIONS(5953),
    [anon_sym_Not] = ACTIONS(5953),
    [anon_sym_POUNDelse] = ACTIONS(5955),
    [anon_sym_POUNDELSE] = ACTIONS(5955),
    [anon_sym_POUNDElse] = ACTIONS(5955),
    [anon_sym_POUNDelse2] = ACTIONS(5955),
    [anon_sym_POUNDELSE2] = ACTIONS(5955),
    [anon_sym_POUNDElse2] = ACTIONS(5955),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5953),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5953),
    [anon_sym_PLUS] = ACTIONS(5955),
    [sym_datetime_literal] = ACTIONS(5955),
    [sym_date_literal] = ACTIONS(5953),
    [sym_time_literal] = ACTIONS(5953),
    [sym_biginteger_literal] = ACTIONS(5955),
    [anon_sym_if] = ACTIONS(5953),
    [anon_sym_IF] = ACTIONS(5953),
    [anon_sym_If] = ACTIONS(5953),
    [anon_sym_else] = ACTIONS(5953),
    [anon_sym_ELSE] = ACTIONS(5953),
    [anon_sym_Else] = ACTIONS(5953),
    [anon_sym_case] = ACTIONS(5953),
    [anon_sym_CASE] = ACTIONS(5953),
    [anon_sym_Case] = ACTIONS(5953),
    [anon_sym_for] = ACTIONS(5953),
    [anon_sym_FOR] = ACTIONS(5953),
    [anon_sym_For] = ACTIONS(5953),
    [anon_sym_foreach] = ACTIONS(5953),
    [anon_sym_FOREACH] = ACTIONS(5953),
    [anon_sym_Foreach] = ACTIONS(5953),
    [anon_sym_while] = ACTIONS(5953),
    [anon_sym_WHILE] = ACTIONS(5953),
    [anon_sym_While] = ACTIONS(5953),
    [anon_sym_repeat] = ACTIONS(5953),
    [anon_sym_REPEAT] = ACTIONS(5953),
    [anon_sym_Repeat] = ACTIONS(5953),
    [anon_sym_until] = ACTIONS(5953),
    [anon_sym_UNTIL] = ACTIONS(5953),
    [anon_sym_Until] = ACTIONS(5953),
    [anon_sym_exit] = ACTIONS(5953),
    [anon_sym_EXIT] = ACTIONS(5953),
    [anon_sym_Exit] = ACTIONS(5953),
    [anon_sym_continue] = ACTIONS(5953),
    [anon_sym_CONTINUE] = ACTIONS(5953),
    [anon_sym_Continue] = ACTIONS(5953),
    [anon_sym_break] = ACTIONS(5953),
    [anon_sym_BREAK] = ACTIONS(5953),
    [anon_sym_Break] = ACTIONS(5953),
    [anon_sym_with] = ACTIONS(5953),
    [anon_sym_WITH] = ACTIONS(5953),
    [anon_sym_With] = ACTIONS(5953),
    [sym_asserterror_keyword] = ACTIONS(5955),
    [sym_page_keyword] = ACTIONS(5953),
    [anon_sym_codeunit] = ACTIONS(5953),
    [anon_sym_CODEUNIT] = ACTIONS(5953),
    [anon_sym_Codeunit] = ACTIONS(5953),
    [anon_sym_CodeUnit] = ACTIONS(5953),
    [anon_sym_COdeunit] = ACTIONS(5953),
    [anon_sym_codeUnit] = ACTIONS(5953),
    [sym_report_keyword] = ACTIONS(5953),
    [sym_query_keyword] = ACTIONS(5953),
    [anon_sym_xmlport] = ACTIONS(5953),
    [anon_sym_XMLPORT] = ACTIONS(5953),
    [anon_sym_Xmlport] = ACTIONS(5953),
    [anon_sym_XMLport] = ACTIONS(5953),
    [anon_sym_XMLPort] = ACTIONS(5953),
    [anon_sym_XmlPort] = ACTIONS(5953),
    [anon_sym_enum] = ACTIONS(5953),
    [anon_sym_ENUM] = ACTIONS(5953),
    [anon_sym_Enum] = ACTIONS(5953),
    [anon_sym_eNUM] = ACTIONS(5953),
    [anon_sym_eNum] = ACTIONS(5953),
    [anon_sym_ENum] = ACTIONS(5953),
    [sym_quoted_identifier] = ACTIONS(5955),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5955),
    [sym_verbatim_string] = ACTIONS(5955),
    [sym_integer] = ACTIONS(5953),
    [sym_continue_as_identifier] = ACTIONS(5955),
    [sym_preproc_open] = ACTIONS(5955),
  },
  [STATE(3101)] = {
    [sym_identifier] = ACTIONS(5957),
    [anon_sym_SEMI] = ACTIONS(5959),
    [anon_sym_DASH] = ACTIONS(5959),
    [aux_sym_boolean_token1] = ACTIONS(5957),
    [aux_sym_boolean_token2] = ACTIONS(5957),
    [sym_decimal] = ACTIONS(5957),
    [anon_sym_LPAREN] = ACTIONS(5959),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5957),
    [anon_sym_LBRACK] = ACTIONS(5959),
    [aux_sym_record_type_token1] = ACTIONS(5957),
    [aux_sym_basic_type_token21] = ACTIONS(5957),
    [aux_sym_basic_type_token22] = ACTIONS(5957),
    [aux_sym_basic_type_token48] = ACTIONS(5957),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5957),
    [anon_sym_POUNDif] = ACTIONS(5959),
    [anon_sym_POUNDIF] = ACTIONS(5959),
    [anon_sym_POUNDIf] = ACTIONS(5959),
    [anon_sym_not] = ACTIONS(5957),
    [anon_sym_NOT] = ACTIONS(5957),
    [anon_sym_Not] = ACTIONS(5957),
    [anon_sym_POUNDelse] = ACTIONS(5959),
    [anon_sym_POUNDELSE] = ACTIONS(5959),
    [anon_sym_POUNDElse] = ACTIONS(5959),
    [anon_sym_POUNDelse2] = ACTIONS(5959),
    [anon_sym_POUNDELSE2] = ACTIONS(5959),
    [anon_sym_POUNDElse2] = ACTIONS(5959),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5957),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5957),
    [anon_sym_PLUS] = ACTIONS(5959),
    [sym_datetime_literal] = ACTIONS(5959),
    [sym_date_literal] = ACTIONS(5957),
    [sym_time_literal] = ACTIONS(5957),
    [sym_biginteger_literal] = ACTIONS(5959),
    [anon_sym_if] = ACTIONS(5957),
    [anon_sym_IF] = ACTIONS(5957),
    [anon_sym_If] = ACTIONS(5957),
    [anon_sym_else] = ACTIONS(5957),
    [anon_sym_ELSE] = ACTIONS(5957),
    [anon_sym_Else] = ACTIONS(5957),
    [anon_sym_case] = ACTIONS(5957),
    [anon_sym_CASE] = ACTIONS(5957),
    [anon_sym_Case] = ACTIONS(5957),
    [anon_sym_for] = ACTIONS(5957),
    [anon_sym_FOR] = ACTIONS(5957),
    [anon_sym_For] = ACTIONS(5957),
    [anon_sym_foreach] = ACTIONS(5957),
    [anon_sym_FOREACH] = ACTIONS(5957),
    [anon_sym_Foreach] = ACTIONS(5957),
    [anon_sym_while] = ACTIONS(5957),
    [anon_sym_WHILE] = ACTIONS(5957),
    [anon_sym_While] = ACTIONS(5957),
    [anon_sym_repeat] = ACTIONS(5957),
    [anon_sym_REPEAT] = ACTIONS(5957),
    [anon_sym_Repeat] = ACTIONS(5957),
    [anon_sym_until] = ACTIONS(5957),
    [anon_sym_UNTIL] = ACTIONS(5957),
    [anon_sym_Until] = ACTIONS(5957),
    [anon_sym_exit] = ACTIONS(5957),
    [anon_sym_EXIT] = ACTIONS(5957),
    [anon_sym_Exit] = ACTIONS(5957),
    [anon_sym_continue] = ACTIONS(5957),
    [anon_sym_CONTINUE] = ACTIONS(5957),
    [anon_sym_Continue] = ACTIONS(5957),
    [anon_sym_break] = ACTIONS(5957),
    [anon_sym_BREAK] = ACTIONS(5957),
    [anon_sym_Break] = ACTIONS(5957),
    [anon_sym_with] = ACTIONS(5957),
    [anon_sym_WITH] = ACTIONS(5957),
    [anon_sym_With] = ACTIONS(5957),
    [sym_asserterror_keyword] = ACTIONS(5959),
    [sym_page_keyword] = ACTIONS(5957),
    [anon_sym_codeunit] = ACTIONS(5957),
    [anon_sym_CODEUNIT] = ACTIONS(5957),
    [anon_sym_Codeunit] = ACTIONS(5957),
    [anon_sym_CodeUnit] = ACTIONS(5957),
    [anon_sym_COdeunit] = ACTIONS(5957),
    [anon_sym_codeUnit] = ACTIONS(5957),
    [sym_report_keyword] = ACTIONS(5957),
    [sym_query_keyword] = ACTIONS(5957),
    [anon_sym_xmlport] = ACTIONS(5957),
    [anon_sym_XMLPORT] = ACTIONS(5957),
    [anon_sym_Xmlport] = ACTIONS(5957),
    [anon_sym_XMLport] = ACTIONS(5957),
    [anon_sym_XMLPort] = ACTIONS(5957),
    [anon_sym_XmlPort] = ACTIONS(5957),
    [anon_sym_enum] = ACTIONS(5957),
    [anon_sym_ENUM] = ACTIONS(5957),
    [anon_sym_Enum] = ACTIONS(5957),
    [anon_sym_eNUM] = ACTIONS(5957),
    [anon_sym_eNum] = ACTIONS(5957),
    [anon_sym_ENum] = ACTIONS(5957),
    [sym_quoted_identifier] = ACTIONS(5959),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5959),
    [sym_verbatim_string] = ACTIONS(5959),
    [sym_integer] = ACTIONS(5957),
    [sym_continue_as_identifier] = ACTIONS(5959),
    [sym_preproc_open] = ACTIONS(5959),
  },
  [STATE(3102)] = {
    [sym_identifier] = ACTIONS(5957),
    [anon_sym_SEMI] = ACTIONS(5959),
    [anon_sym_DASH] = ACTIONS(5959),
    [aux_sym_boolean_token1] = ACTIONS(5957),
    [aux_sym_boolean_token2] = ACTIONS(5957),
    [sym_decimal] = ACTIONS(5957),
    [anon_sym_LPAREN] = ACTIONS(5959),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5957),
    [anon_sym_LBRACK] = ACTIONS(5959),
    [aux_sym_record_type_token1] = ACTIONS(5957),
    [aux_sym_basic_type_token21] = ACTIONS(5957),
    [aux_sym_basic_type_token22] = ACTIONS(5957),
    [aux_sym_basic_type_token48] = ACTIONS(5957),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5957),
    [anon_sym_POUNDif] = ACTIONS(5959),
    [anon_sym_POUNDIF] = ACTIONS(5959),
    [anon_sym_POUNDIf] = ACTIONS(5959),
    [anon_sym_not] = ACTIONS(5957),
    [anon_sym_NOT] = ACTIONS(5957),
    [anon_sym_Not] = ACTIONS(5957),
    [anon_sym_POUNDelse] = ACTIONS(5959),
    [anon_sym_POUNDELSE] = ACTIONS(5959),
    [anon_sym_POUNDElse] = ACTIONS(5959),
    [anon_sym_POUNDelse2] = ACTIONS(5959),
    [anon_sym_POUNDELSE2] = ACTIONS(5959),
    [anon_sym_POUNDElse2] = ACTIONS(5959),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5957),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5957),
    [anon_sym_PLUS] = ACTIONS(5959),
    [sym_datetime_literal] = ACTIONS(5959),
    [sym_date_literal] = ACTIONS(5957),
    [sym_time_literal] = ACTIONS(5957),
    [sym_biginteger_literal] = ACTIONS(5959),
    [anon_sym_if] = ACTIONS(5957),
    [anon_sym_IF] = ACTIONS(5957),
    [anon_sym_If] = ACTIONS(5957),
    [anon_sym_else] = ACTIONS(5957),
    [anon_sym_ELSE] = ACTIONS(5957),
    [anon_sym_Else] = ACTIONS(5957),
    [anon_sym_case] = ACTIONS(5957),
    [anon_sym_CASE] = ACTIONS(5957),
    [anon_sym_Case] = ACTIONS(5957),
    [anon_sym_for] = ACTIONS(5957),
    [anon_sym_FOR] = ACTIONS(5957),
    [anon_sym_For] = ACTIONS(5957),
    [anon_sym_foreach] = ACTIONS(5957),
    [anon_sym_FOREACH] = ACTIONS(5957),
    [anon_sym_Foreach] = ACTIONS(5957),
    [anon_sym_while] = ACTIONS(5957),
    [anon_sym_WHILE] = ACTIONS(5957),
    [anon_sym_While] = ACTIONS(5957),
    [anon_sym_repeat] = ACTIONS(5957),
    [anon_sym_REPEAT] = ACTIONS(5957),
    [anon_sym_Repeat] = ACTIONS(5957),
    [anon_sym_until] = ACTIONS(5957),
    [anon_sym_UNTIL] = ACTIONS(5957),
    [anon_sym_Until] = ACTIONS(5957),
    [anon_sym_exit] = ACTIONS(5957),
    [anon_sym_EXIT] = ACTIONS(5957),
    [anon_sym_Exit] = ACTIONS(5957),
    [anon_sym_continue] = ACTIONS(5957),
    [anon_sym_CONTINUE] = ACTIONS(5957),
    [anon_sym_Continue] = ACTIONS(5957),
    [anon_sym_break] = ACTIONS(5957),
    [anon_sym_BREAK] = ACTIONS(5957),
    [anon_sym_Break] = ACTIONS(5957),
    [anon_sym_with] = ACTIONS(5957),
    [anon_sym_WITH] = ACTIONS(5957),
    [anon_sym_With] = ACTIONS(5957),
    [sym_asserterror_keyword] = ACTIONS(5959),
    [sym_page_keyword] = ACTIONS(5957),
    [anon_sym_codeunit] = ACTIONS(5957),
    [anon_sym_CODEUNIT] = ACTIONS(5957),
    [anon_sym_Codeunit] = ACTIONS(5957),
    [anon_sym_CodeUnit] = ACTIONS(5957),
    [anon_sym_COdeunit] = ACTIONS(5957),
    [anon_sym_codeUnit] = ACTIONS(5957),
    [sym_report_keyword] = ACTIONS(5957),
    [sym_query_keyword] = ACTIONS(5957),
    [anon_sym_xmlport] = ACTIONS(5957),
    [anon_sym_XMLPORT] = ACTIONS(5957),
    [anon_sym_Xmlport] = ACTIONS(5957),
    [anon_sym_XMLport] = ACTIONS(5957),
    [anon_sym_XMLPort] = ACTIONS(5957),
    [anon_sym_XmlPort] = ACTIONS(5957),
    [anon_sym_enum] = ACTIONS(5957),
    [anon_sym_ENUM] = ACTIONS(5957),
    [anon_sym_Enum] = ACTIONS(5957),
    [anon_sym_eNUM] = ACTIONS(5957),
    [anon_sym_eNum] = ACTIONS(5957),
    [anon_sym_ENum] = ACTIONS(5957),
    [sym_quoted_identifier] = ACTIONS(5959),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5959),
    [sym_verbatim_string] = ACTIONS(5959),
    [sym_integer] = ACTIONS(5957),
    [sym_continue_as_identifier] = ACTIONS(5959),
    [sym_preproc_open] = ACTIONS(5959),
  },
  [STATE(3103)] = {
    [sym_identifier] = ACTIONS(5945),
    [anon_sym_SEMI] = ACTIONS(5947),
    [anon_sym_DASH] = ACTIONS(5947),
    [aux_sym_boolean_token1] = ACTIONS(5945),
    [aux_sym_boolean_token2] = ACTIONS(5945),
    [sym_decimal] = ACTIONS(5945),
    [anon_sym_LPAREN] = ACTIONS(5947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5945),
    [anon_sym_LBRACK] = ACTIONS(5947),
    [aux_sym_record_type_token1] = ACTIONS(5945),
    [aux_sym_basic_type_token21] = ACTIONS(5945),
    [aux_sym_basic_type_token22] = ACTIONS(5945),
    [aux_sym_basic_type_token48] = ACTIONS(5945),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5945),
    [anon_sym_POUNDif] = ACTIONS(5947),
    [anon_sym_POUNDIF] = ACTIONS(5947),
    [anon_sym_POUNDIf] = ACTIONS(5947),
    [anon_sym_not] = ACTIONS(5945),
    [anon_sym_NOT] = ACTIONS(5945),
    [anon_sym_Not] = ACTIONS(5945),
    [anon_sym_POUNDelse] = ACTIONS(5947),
    [anon_sym_POUNDELSE] = ACTIONS(5947),
    [anon_sym_POUNDElse] = ACTIONS(5947),
    [anon_sym_POUNDelse2] = ACTIONS(5947),
    [anon_sym_POUNDELSE2] = ACTIONS(5947),
    [anon_sym_POUNDElse2] = ACTIONS(5947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5945),
    [anon_sym_PLUS] = ACTIONS(5947),
    [sym_datetime_literal] = ACTIONS(5947),
    [sym_date_literal] = ACTIONS(5945),
    [sym_time_literal] = ACTIONS(5945),
    [sym_biginteger_literal] = ACTIONS(5947),
    [anon_sym_if] = ACTIONS(5945),
    [anon_sym_IF] = ACTIONS(5945),
    [anon_sym_If] = ACTIONS(5945),
    [anon_sym_else] = ACTIONS(5945),
    [anon_sym_ELSE] = ACTIONS(5945),
    [anon_sym_Else] = ACTIONS(5945),
    [anon_sym_case] = ACTIONS(5945),
    [anon_sym_CASE] = ACTIONS(5945),
    [anon_sym_Case] = ACTIONS(5945),
    [anon_sym_for] = ACTIONS(5945),
    [anon_sym_FOR] = ACTIONS(5945),
    [anon_sym_For] = ACTIONS(5945),
    [anon_sym_foreach] = ACTIONS(5945),
    [anon_sym_FOREACH] = ACTIONS(5945),
    [anon_sym_Foreach] = ACTIONS(5945),
    [anon_sym_while] = ACTIONS(5945),
    [anon_sym_WHILE] = ACTIONS(5945),
    [anon_sym_While] = ACTIONS(5945),
    [anon_sym_repeat] = ACTIONS(5945),
    [anon_sym_REPEAT] = ACTIONS(5945),
    [anon_sym_Repeat] = ACTIONS(5945),
    [anon_sym_until] = ACTIONS(5945),
    [anon_sym_UNTIL] = ACTIONS(5945),
    [anon_sym_Until] = ACTIONS(5945),
    [anon_sym_exit] = ACTIONS(5945),
    [anon_sym_EXIT] = ACTIONS(5945),
    [anon_sym_Exit] = ACTIONS(5945),
    [anon_sym_continue] = ACTIONS(5945),
    [anon_sym_CONTINUE] = ACTIONS(5945),
    [anon_sym_Continue] = ACTIONS(5945),
    [anon_sym_break] = ACTIONS(5945),
    [anon_sym_BREAK] = ACTIONS(5945),
    [anon_sym_Break] = ACTIONS(5945),
    [anon_sym_with] = ACTIONS(5945),
    [anon_sym_WITH] = ACTIONS(5945),
    [anon_sym_With] = ACTIONS(5945),
    [sym_asserterror_keyword] = ACTIONS(5947),
    [sym_page_keyword] = ACTIONS(5945),
    [anon_sym_codeunit] = ACTIONS(5945),
    [anon_sym_CODEUNIT] = ACTIONS(5945),
    [anon_sym_Codeunit] = ACTIONS(5945),
    [anon_sym_CodeUnit] = ACTIONS(5945),
    [anon_sym_COdeunit] = ACTIONS(5945),
    [anon_sym_codeUnit] = ACTIONS(5945),
    [sym_report_keyword] = ACTIONS(5945),
    [sym_query_keyword] = ACTIONS(5945),
    [anon_sym_xmlport] = ACTIONS(5945),
    [anon_sym_XMLPORT] = ACTIONS(5945),
    [anon_sym_Xmlport] = ACTIONS(5945),
    [anon_sym_XMLport] = ACTIONS(5945),
    [anon_sym_XMLPort] = ACTIONS(5945),
    [anon_sym_XmlPort] = ACTIONS(5945),
    [anon_sym_enum] = ACTIONS(5945),
    [anon_sym_ENUM] = ACTIONS(5945),
    [anon_sym_Enum] = ACTIONS(5945),
    [anon_sym_eNUM] = ACTIONS(5945),
    [anon_sym_eNum] = ACTIONS(5945),
    [anon_sym_ENum] = ACTIONS(5945),
    [sym_quoted_identifier] = ACTIONS(5947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5947),
    [sym_verbatim_string] = ACTIONS(5947),
    [sym_integer] = ACTIONS(5945),
    [sym_continue_as_identifier] = ACTIONS(5947),
    [sym_preproc_open] = ACTIONS(5947),
  },
  [STATE(3104)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(7211),
    [anon_sym_DASH] = ACTIONS(6122),
    [aux_sym_boolean_token1] = ACTIONS(6118),
    [aux_sym_boolean_token2] = ACTIONS(6118),
    [sym_decimal] = ACTIONS(6118),
    [anon_sym_LPAREN] = ACTIONS(6122),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_record_type_token1] = ACTIONS(6118),
    [aux_sym_basic_type_token21] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token48] = ACTIONS(6118),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_not] = ACTIONS(6118),
    [anon_sym_NOT] = ACTIONS(6118),
    [anon_sym_Not] = ACTIONS(6118),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6118),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6118),
    [anon_sym_PLUS] = ACTIONS(6122),
    [sym_datetime_literal] = ACTIONS(6122),
    [sym_date_literal] = ACTIONS(6118),
    [sym_time_literal] = ACTIONS(6118),
    [sym_biginteger_literal] = ACTIONS(6122),
    [anon_sym_if] = ACTIONS(6118),
    [anon_sym_IF] = ACTIONS(6118),
    [anon_sym_If] = ACTIONS(6118),
    [anon_sym_else] = ACTIONS(6118),
    [anon_sym_ELSE] = ACTIONS(6118),
    [anon_sym_Else] = ACTIONS(6118),
    [anon_sym_case] = ACTIONS(6118),
    [anon_sym_CASE] = ACTIONS(6118),
    [anon_sym_Case] = ACTIONS(6118),
    [anon_sym_for] = ACTIONS(6118),
    [anon_sym_FOR] = ACTIONS(6118),
    [anon_sym_For] = ACTIONS(6118),
    [anon_sym_foreach] = ACTIONS(6118),
    [anon_sym_FOREACH] = ACTIONS(6118),
    [anon_sym_Foreach] = ACTIONS(6118),
    [anon_sym_while] = ACTIONS(6118),
    [anon_sym_WHILE] = ACTIONS(6118),
    [anon_sym_While] = ACTIONS(6118),
    [anon_sym_repeat] = ACTIONS(6118),
    [anon_sym_REPEAT] = ACTIONS(6118),
    [anon_sym_Repeat] = ACTIONS(6118),
    [anon_sym_until] = ACTIONS(6118),
    [anon_sym_UNTIL] = ACTIONS(6118),
    [anon_sym_Until] = ACTIONS(6118),
    [anon_sym_exit] = ACTIONS(6118),
    [anon_sym_EXIT] = ACTIONS(6118),
    [anon_sym_Exit] = ACTIONS(6118),
    [anon_sym_continue] = ACTIONS(6118),
    [anon_sym_CONTINUE] = ACTIONS(6118),
    [anon_sym_Continue] = ACTIONS(6118),
    [anon_sym_break] = ACTIONS(6118),
    [anon_sym_BREAK] = ACTIONS(6118),
    [anon_sym_Break] = ACTIONS(6118),
    [anon_sym_with] = ACTIONS(6118),
    [anon_sym_WITH] = ACTIONS(6118),
    [anon_sym_With] = ACTIONS(6118),
    [sym_asserterror_keyword] = ACTIONS(6122),
    [sym_page_keyword] = ACTIONS(6118),
    [anon_sym_codeunit] = ACTIONS(6118),
    [anon_sym_CODEUNIT] = ACTIONS(6118),
    [anon_sym_Codeunit] = ACTIONS(6118),
    [anon_sym_CodeUnit] = ACTIONS(6118),
    [anon_sym_COdeunit] = ACTIONS(6118),
    [anon_sym_codeUnit] = ACTIONS(6118),
    [sym_report_keyword] = ACTIONS(6118),
    [sym_query_keyword] = ACTIONS(6118),
    [anon_sym_xmlport] = ACTIONS(6118),
    [anon_sym_XMLPORT] = ACTIONS(6118),
    [anon_sym_Xmlport] = ACTIONS(6118),
    [anon_sym_XMLport] = ACTIONS(6118),
    [anon_sym_XMLPort] = ACTIONS(6118),
    [anon_sym_XmlPort] = ACTIONS(6118),
    [anon_sym_enum] = ACTIONS(6118),
    [anon_sym_ENUM] = ACTIONS(6118),
    [anon_sym_Enum] = ACTIONS(6118),
    [anon_sym_eNUM] = ACTIONS(6118),
    [anon_sym_eNum] = ACTIONS(6118),
    [anon_sym_ENum] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6122),
    [sym_verbatim_string] = ACTIONS(6122),
    [sym_integer] = ACTIONS(6118),
    [sym_continue_as_identifier] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
  },
  [STATE(3105)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(6122),
    [anon_sym_DASH] = ACTIONS(6122),
    [aux_sym_boolean_token1] = ACTIONS(6118),
    [aux_sym_boolean_token2] = ACTIONS(6118),
    [sym_decimal] = ACTIONS(6118),
    [anon_sym_LPAREN] = ACTIONS(6122),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_record_type_token1] = ACTIONS(6118),
    [aux_sym_basic_type_token21] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token48] = ACTIONS(6118),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_not] = ACTIONS(6118),
    [anon_sym_NOT] = ACTIONS(6118),
    [anon_sym_Not] = ACTIONS(6118),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6118),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6118),
    [anon_sym_PLUS] = ACTIONS(6122),
    [sym_datetime_literal] = ACTIONS(6122),
    [sym_date_literal] = ACTIONS(6118),
    [sym_time_literal] = ACTIONS(6118),
    [sym_biginteger_literal] = ACTIONS(6122),
    [anon_sym_if] = ACTIONS(6118),
    [anon_sym_IF] = ACTIONS(6118),
    [anon_sym_If] = ACTIONS(6118),
    [anon_sym_else] = ACTIONS(6118),
    [anon_sym_ELSE] = ACTIONS(6118),
    [anon_sym_Else] = ACTIONS(6118),
    [anon_sym_case] = ACTIONS(6118),
    [anon_sym_CASE] = ACTIONS(6118),
    [anon_sym_Case] = ACTIONS(6118),
    [anon_sym_for] = ACTIONS(6118),
    [anon_sym_FOR] = ACTIONS(6118),
    [anon_sym_For] = ACTIONS(6118),
    [anon_sym_foreach] = ACTIONS(6118),
    [anon_sym_FOREACH] = ACTIONS(6118),
    [anon_sym_Foreach] = ACTIONS(6118),
    [anon_sym_while] = ACTIONS(6118),
    [anon_sym_WHILE] = ACTIONS(6118),
    [anon_sym_While] = ACTIONS(6118),
    [anon_sym_repeat] = ACTIONS(6118),
    [anon_sym_REPEAT] = ACTIONS(6118),
    [anon_sym_Repeat] = ACTIONS(6118),
    [anon_sym_until] = ACTIONS(6118),
    [anon_sym_UNTIL] = ACTIONS(6118),
    [anon_sym_Until] = ACTIONS(6118),
    [anon_sym_exit] = ACTIONS(6118),
    [anon_sym_EXIT] = ACTIONS(6118),
    [anon_sym_Exit] = ACTIONS(6118),
    [anon_sym_continue] = ACTIONS(6118),
    [anon_sym_CONTINUE] = ACTIONS(6118),
    [anon_sym_Continue] = ACTIONS(6118),
    [anon_sym_break] = ACTIONS(6118),
    [anon_sym_BREAK] = ACTIONS(6118),
    [anon_sym_Break] = ACTIONS(6118),
    [anon_sym_with] = ACTIONS(6118),
    [anon_sym_WITH] = ACTIONS(6118),
    [anon_sym_With] = ACTIONS(6118),
    [sym_asserterror_keyword] = ACTIONS(6122),
    [sym_page_keyword] = ACTIONS(6118),
    [anon_sym_codeunit] = ACTIONS(6118),
    [anon_sym_CODEUNIT] = ACTIONS(6118),
    [anon_sym_Codeunit] = ACTIONS(6118),
    [anon_sym_CodeUnit] = ACTIONS(6118),
    [anon_sym_COdeunit] = ACTIONS(6118),
    [anon_sym_codeUnit] = ACTIONS(6118),
    [sym_report_keyword] = ACTIONS(6118),
    [sym_query_keyword] = ACTIONS(6118),
    [anon_sym_xmlport] = ACTIONS(6118),
    [anon_sym_XMLPORT] = ACTIONS(6118),
    [anon_sym_Xmlport] = ACTIONS(6118),
    [anon_sym_XMLport] = ACTIONS(6118),
    [anon_sym_XMLPort] = ACTIONS(6118),
    [anon_sym_XmlPort] = ACTIONS(6118),
    [anon_sym_enum] = ACTIONS(6118),
    [anon_sym_ENUM] = ACTIONS(6118),
    [anon_sym_Enum] = ACTIONS(6118),
    [anon_sym_eNUM] = ACTIONS(6118),
    [anon_sym_eNum] = ACTIONS(6118),
    [anon_sym_ENum] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6122),
    [sym_verbatim_string] = ACTIONS(6122),
    [sym_integer] = ACTIONS(6118),
    [sym_continue_as_identifier] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
  },
  [STATE(3106)] = {
    [sym_identifier] = ACTIONS(6124),
    [anon_sym_SEMI] = ACTIONS(6126),
    [anon_sym_DASH] = ACTIONS(6126),
    [aux_sym_boolean_token1] = ACTIONS(6124),
    [aux_sym_boolean_token2] = ACTIONS(6124),
    [sym_decimal] = ACTIONS(6124),
    [anon_sym_LPAREN] = ACTIONS(6126),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6124),
    [anon_sym_LBRACK] = ACTIONS(6126),
    [aux_sym_record_type_token1] = ACTIONS(6124),
    [aux_sym_basic_type_token21] = ACTIONS(6124),
    [aux_sym_basic_type_token22] = ACTIONS(6124),
    [aux_sym_basic_type_token48] = ACTIONS(6124),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6124),
    [anon_sym_POUNDif] = ACTIONS(6126),
    [anon_sym_POUNDIF] = ACTIONS(6126),
    [anon_sym_POUNDIf] = ACTIONS(6126),
    [anon_sym_not] = ACTIONS(6124),
    [anon_sym_NOT] = ACTIONS(6124),
    [anon_sym_Not] = ACTIONS(6124),
    [anon_sym_POUNDelse] = ACTIONS(6126),
    [anon_sym_POUNDELSE] = ACTIONS(6126),
    [anon_sym_POUNDElse] = ACTIONS(6126),
    [anon_sym_POUNDelse2] = ACTIONS(6126),
    [anon_sym_POUNDELSE2] = ACTIONS(6126),
    [anon_sym_POUNDElse2] = ACTIONS(6126),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6124),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6124),
    [anon_sym_PLUS] = ACTIONS(6126),
    [sym_datetime_literal] = ACTIONS(6126),
    [sym_date_literal] = ACTIONS(6124),
    [sym_time_literal] = ACTIONS(6124),
    [sym_biginteger_literal] = ACTIONS(6126),
    [anon_sym_if] = ACTIONS(6124),
    [anon_sym_IF] = ACTIONS(6124),
    [anon_sym_If] = ACTIONS(6124),
    [anon_sym_else] = ACTIONS(6124),
    [anon_sym_ELSE] = ACTIONS(6124),
    [anon_sym_Else] = ACTIONS(6124),
    [anon_sym_case] = ACTIONS(6124),
    [anon_sym_CASE] = ACTIONS(6124),
    [anon_sym_Case] = ACTIONS(6124),
    [anon_sym_for] = ACTIONS(6124),
    [anon_sym_FOR] = ACTIONS(6124),
    [anon_sym_For] = ACTIONS(6124),
    [anon_sym_foreach] = ACTIONS(6124),
    [anon_sym_FOREACH] = ACTIONS(6124),
    [anon_sym_Foreach] = ACTIONS(6124),
    [anon_sym_while] = ACTIONS(6124),
    [anon_sym_WHILE] = ACTIONS(6124),
    [anon_sym_While] = ACTIONS(6124),
    [anon_sym_repeat] = ACTIONS(6124),
    [anon_sym_REPEAT] = ACTIONS(6124),
    [anon_sym_Repeat] = ACTIONS(6124),
    [anon_sym_until] = ACTIONS(6124),
    [anon_sym_UNTIL] = ACTIONS(6124),
    [anon_sym_Until] = ACTIONS(6124),
    [anon_sym_exit] = ACTIONS(6124),
    [anon_sym_EXIT] = ACTIONS(6124),
    [anon_sym_Exit] = ACTIONS(6124),
    [anon_sym_continue] = ACTIONS(6124),
    [anon_sym_CONTINUE] = ACTIONS(6124),
    [anon_sym_Continue] = ACTIONS(6124),
    [anon_sym_break] = ACTIONS(6124),
    [anon_sym_BREAK] = ACTIONS(6124),
    [anon_sym_Break] = ACTIONS(6124),
    [anon_sym_with] = ACTIONS(6124),
    [anon_sym_WITH] = ACTIONS(6124),
    [anon_sym_With] = ACTIONS(6124),
    [sym_asserterror_keyword] = ACTIONS(6126),
    [sym_page_keyword] = ACTIONS(6124),
    [anon_sym_codeunit] = ACTIONS(6124),
    [anon_sym_CODEUNIT] = ACTIONS(6124),
    [anon_sym_Codeunit] = ACTIONS(6124),
    [anon_sym_CodeUnit] = ACTIONS(6124),
    [anon_sym_COdeunit] = ACTIONS(6124),
    [anon_sym_codeUnit] = ACTIONS(6124),
    [sym_report_keyword] = ACTIONS(6124),
    [sym_query_keyword] = ACTIONS(6124),
    [anon_sym_xmlport] = ACTIONS(6124),
    [anon_sym_XMLPORT] = ACTIONS(6124),
    [anon_sym_Xmlport] = ACTIONS(6124),
    [anon_sym_XMLport] = ACTIONS(6124),
    [anon_sym_XMLPort] = ACTIONS(6124),
    [anon_sym_XmlPort] = ACTIONS(6124),
    [anon_sym_enum] = ACTIONS(6124),
    [anon_sym_ENUM] = ACTIONS(6124),
    [anon_sym_Enum] = ACTIONS(6124),
    [anon_sym_eNUM] = ACTIONS(6124),
    [anon_sym_eNum] = ACTIONS(6124),
    [anon_sym_ENum] = ACTIONS(6124),
    [sym_quoted_identifier] = ACTIONS(6126),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6126),
    [sym_verbatim_string] = ACTIONS(6126),
    [sym_integer] = ACTIONS(6124),
    [sym_continue_as_identifier] = ACTIONS(6126),
    [sym_preproc_open] = ACTIONS(6126),
  },
  [STATE(3107)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(7213),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_until] = ACTIONS(5961),
    [anon_sym_UNTIL] = ACTIONS(5961),
    [anon_sym_Until] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
  },
  [STATE(3108)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(7215),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_until] = ACTIONS(5961),
    [anon_sym_UNTIL] = ACTIONS(5961),
    [anon_sym_Until] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
  },
  [STATE(3109)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5965),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_until] = ACTIONS(5961),
    [anon_sym_UNTIL] = ACTIONS(5961),
    [anon_sym_Until] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
  },
  [STATE(3110)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_DASH] = ACTIONS(5937),
    [aux_sym_boolean_token1] = ACTIONS(5935),
    [aux_sym_boolean_token2] = ACTIONS(5935),
    [sym_decimal] = ACTIONS(5935),
    [anon_sym_LPAREN] = ACTIONS(5937),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_record_type_token1] = ACTIONS(5935),
    [aux_sym_basic_type_token21] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token48] = ACTIONS(5935),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_not] = ACTIONS(5935),
    [anon_sym_NOT] = ACTIONS(5935),
    [anon_sym_Not] = ACTIONS(5935),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5935),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5935),
    [anon_sym_PLUS] = ACTIONS(5937),
    [sym_datetime_literal] = ACTIONS(5937),
    [sym_date_literal] = ACTIONS(5935),
    [sym_time_literal] = ACTIONS(5935),
    [sym_biginteger_literal] = ACTIONS(5937),
    [anon_sym_if] = ACTIONS(5935),
    [anon_sym_IF] = ACTIONS(5935),
    [anon_sym_If] = ACTIONS(5935),
    [anon_sym_else] = ACTIONS(5935),
    [anon_sym_ELSE] = ACTIONS(5935),
    [anon_sym_Else] = ACTIONS(5935),
    [anon_sym_case] = ACTIONS(5935),
    [anon_sym_CASE] = ACTIONS(5935),
    [anon_sym_Case] = ACTIONS(5935),
    [anon_sym_for] = ACTIONS(5935),
    [anon_sym_FOR] = ACTIONS(5935),
    [anon_sym_For] = ACTIONS(5935),
    [anon_sym_foreach] = ACTIONS(5935),
    [anon_sym_FOREACH] = ACTIONS(5935),
    [anon_sym_Foreach] = ACTIONS(5935),
    [anon_sym_while] = ACTIONS(5935),
    [anon_sym_WHILE] = ACTIONS(5935),
    [anon_sym_While] = ACTIONS(5935),
    [anon_sym_repeat] = ACTIONS(5935),
    [anon_sym_REPEAT] = ACTIONS(5935),
    [anon_sym_Repeat] = ACTIONS(5935),
    [anon_sym_until] = ACTIONS(5935),
    [anon_sym_UNTIL] = ACTIONS(5935),
    [anon_sym_Until] = ACTIONS(5935),
    [anon_sym_exit] = ACTIONS(5935),
    [anon_sym_EXIT] = ACTIONS(5935),
    [anon_sym_Exit] = ACTIONS(5935),
    [anon_sym_continue] = ACTIONS(5935),
    [anon_sym_CONTINUE] = ACTIONS(5935),
    [anon_sym_Continue] = ACTIONS(5935),
    [anon_sym_break] = ACTIONS(5935),
    [anon_sym_BREAK] = ACTIONS(5935),
    [anon_sym_Break] = ACTIONS(5935),
    [anon_sym_with] = ACTIONS(5935),
    [anon_sym_WITH] = ACTIONS(5935),
    [anon_sym_With] = ACTIONS(5935),
    [sym_asserterror_keyword] = ACTIONS(5937),
    [sym_page_keyword] = ACTIONS(5935),
    [anon_sym_codeunit] = ACTIONS(5935),
    [anon_sym_CODEUNIT] = ACTIONS(5935),
    [anon_sym_Codeunit] = ACTIONS(5935),
    [anon_sym_CodeUnit] = ACTIONS(5935),
    [anon_sym_COdeunit] = ACTIONS(5935),
    [anon_sym_codeUnit] = ACTIONS(5935),
    [sym_report_keyword] = ACTIONS(5935),
    [sym_query_keyword] = ACTIONS(5935),
    [anon_sym_xmlport] = ACTIONS(5935),
    [anon_sym_XMLPORT] = ACTIONS(5935),
    [anon_sym_Xmlport] = ACTIONS(5935),
    [anon_sym_XMLport] = ACTIONS(5935),
    [anon_sym_XMLPort] = ACTIONS(5935),
    [anon_sym_XmlPort] = ACTIONS(5935),
    [anon_sym_enum] = ACTIONS(5935),
    [anon_sym_ENUM] = ACTIONS(5935),
    [anon_sym_Enum] = ACTIONS(5935),
    [anon_sym_eNUM] = ACTIONS(5935),
    [anon_sym_eNum] = ACTIONS(5935),
    [anon_sym_ENum] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5937),
    [sym_verbatim_string] = ACTIONS(5937),
    [sym_integer] = ACTIONS(5935),
    [sym_continue_as_identifier] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
  },
  [STATE(3111)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_DASH] = ACTIONS(5937),
    [aux_sym_boolean_token1] = ACTIONS(5935),
    [aux_sym_boolean_token2] = ACTIONS(5935),
    [sym_decimal] = ACTIONS(5935),
    [anon_sym_LPAREN] = ACTIONS(5937),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_record_type_token1] = ACTIONS(5935),
    [aux_sym_basic_type_token21] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token48] = ACTIONS(5935),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_not] = ACTIONS(5935),
    [anon_sym_NOT] = ACTIONS(5935),
    [anon_sym_Not] = ACTIONS(5935),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5935),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5935),
    [anon_sym_PLUS] = ACTIONS(5937),
    [sym_datetime_literal] = ACTIONS(5937),
    [sym_date_literal] = ACTIONS(5935),
    [sym_time_literal] = ACTIONS(5935),
    [sym_biginteger_literal] = ACTIONS(5937),
    [anon_sym_if] = ACTIONS(5935),
    [anon_sym_IF] = ACTIONS(5935),
    [anon_sym_If] = ACTIONS(5935),
    [anon_sym_else] = ACTIONS(5935),
    [anon_sym_ELSE] = ACTIONS(5935),
    [anon_sym_Else] = ACTIONS(5935),
    [anon_sym_case] = ACTIONS(5935),
    [anon_sym_CASE] = ACTIONS(5935),
    [anon_sym_Case] = ACTIONS(5935),
    [anon_sym_for] = ACTIONS(5935),
    [anon_sym_FOR] = ACTIONS(5935),
    [anon_sym_For] = ACTIONS(5935),
    [anon_sym_foreach] = ACTIONS(5935),
    [anon_sym_FOREACH] = ACTIONS(5935),
    [anon_sym_Foreach] = ACTIONS(5935),
    [anon_sym_while] = ACTIONS(5935),
    [anon_sym_WHILE] = ACTIONS(5935),
    [anon_sym_While] = ACTIONS(5935),
    [anon_sym_repeat] = ACTIONS(5935),
    [anon_sym_REPEAT] = ACTIONS(5935),
    [anon_sym_Repeat] = ACTIONS(5935),
    [anon_sym_until] = ACTIONS(5935),
    [anon_sym_UNTIL] = ACTIONS(5935),
    [anon_sym_Until] = ACTIONS(5935),
    [anon_sym_exit] = ACTIONS(5935),
    [anon_sym_EXIT] = ACTIONS(5935),
    [anon_sym_Exit] = ACTIONS(5935),
    [anon_sym_continue] = ACTIONS(5935),
    [anon_sym_CONTINUE] = ACTIONS(5935),
    [anon_sym_Continue] = ACTIONS(5935),
    [anon_sym_break] = ACTIONS(5935),
    [anon_sym_BREAK] = ACTIONS(5935),
    [anon_sym_Break] = ACTIONS(5935),
    [anon_sym_with] = ACTIONS(5935),
    [anon_sym_WITH] = ACTIONS(5935),
    [anon_sym_With] = ACTIONS(5935),
    [sym_asserterror_keyword] = ACTIONS(5937),
    [sym_page_keyword] = ACTIONS(5935),
    [anon_sym_codeunit] = ACTIONS(5935),
    [anon_sym_CODEUNIT] = ACTIONS(5935),
    [anon_sym_Codeunit] = ACTIONS(5935),
    [anon_sym_CodeUnit] = ACTIONS(5935),
    [anon_sym_COdeunit] = ACTIONS(5935),
    [anon_sym_codeUnit] = ACTIONS(5935),
    [sym_report_keyword] = ACTIONS(5935),
    [sym_query_keyword] = ACTIONS(5935),
    [anon_sym_xmlport] = ACTIONS(5935),
    [anon_sym_XMLPORT] = ACTIONS(5935),
    [anon_sym_Xmlport] = ACTIONS(5935),
    [anon_sym_XMLport] = ACTIONS(5935),
    [anon_sym_XMLPort] = ACTIONS(5935),
    [anon_sym_XmlPort] = ACTIONS(5935),
    [anon_sym_enum] = ACTIONS(5935),
    [anon_sym_ENUM] = ACTIONS(5935),
    [anon_sym_Enum] = ACTIONS(5935),
    [anon_sym_eNUM] = ACTIONS(5935),
    [anon_sym_eNum] = ACTIONS(5935),
    [anon_sym_ENum] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5937),
    [sym_verbatim_string] = ACTIONS(5937),
    [sym_integer] = ACTIONS(5935),
    [sym_continue_as_identifier] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
  },
  [STATE(3112)] = {
    [sym_identifier] = ACTIONS(5967),
    [anon_sym_SEMI] = ACTIONS(5969),
    [anon_sym_DASH] = ACTIONS(5969),
    [aux_sym_boolean_token1] = ACTIONS(5967),
    [aux_sym_boolean_token2] = ACTIONS(5967),
    [sym_decimal] = ACTIONS(5967),
    [anon_sym_LPAREN] = ACTIONS(5969),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5967),
    [anon_sym_LBRACK] = ACTIONS(5969),
    [aux_sym_record_type_token1] = ACTIONS(5967),
    [aux_sym_basic_type_token21] = ACTIONS(5967),
    [aux_sym_basic_type_token22] = ACTIONS(5967),
    [aux_sym_basic_type_token48] = ACTIONS(5967),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5967),
    [anon_sym_POUNDif] = ACTIONS(5969),
    [anon_sym_POUNDIF] = ACTIONS(5969),
    [anon_sym_POUNDIf] = ACTIONS(5969),
    [anon_sym_not] = ACTIONS(5967),
    [anon_sym_NOT] = ACTIONS(5967),
    [anon_sym_Not] = ACTIONS(5967),
    [anon_sym_POUNDelse] = ACTIONS(5969),
    [anon_sym_POUNDELSE] = ACTIONS(5969),
    [anon_sym_POUNDElse] = ACTIONS(5969),
    [anon_sym_POUNDelse2] = ACTIONS(5969),
    [anon_sym_POUNDELSE2] = ACTIONS(5969),
    [anon_sym_POUNDElse2] = ACTIONS(5969),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5967),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5967),
    [anon_sym_PLUS] = ACTIONS(5969),
    [sym_datetime_literal] = ACTIONS(5969),
    [sym_date_literal] = ACTIONS(5967),
    [sym_time_literal] = ACTIONS(5967),
    [sym_biginteger_literal] = ACTIONS(5969),
    [anon_sym_if] = ACTIONS(5967),
    [anon_sym_IF] = ACTIONS(5967),
    [anon_sym_If] = ACTIONS(5967),
    [anon_sym_else] = ACTIONS(5967),
    [anon_sym_ELSE] = ACTIONS(5967),
    [anon_sym_Else] = ACTIONS(5967),
    [anon_sym_case] = ACTIONS(5967),
    [anon_sym_CASE] = ACTIONS(5967),
    [anon_sym_Case] = ACTIONS(5967),
    [anon_sym_for] = ACTIONS(5967),
    [anon_sym_FOR] = ACTIONS(5967),
    [anon_sym_For] = ACTIONS(5967),
    [anon_sym_foreach] = ACTIONS(5967),
    [anon_sym_FOREACH] = ACTIONS(5967),
    [anon_sym_Foreach] = ACTIONS(5967),
    [anon_sym_while] = ACTIONS(5967),
    [anon_sym_WHILE] = ACTIONS(5967),
    [anon_sym_While] = ACTIONS(5967),
    [anon_sym_repeat] = ACTIONS(5967),
    [anon_sym_REPEAT] = ACTIONS(5967),
    [anon_sym_Repeat] = ACTIONS(5967),
    [anon_sym_until] = ACTIONS(5967),
    [anon_sym_UNTIL] = ACTIONS(5967),
    [anon_sym_Until] = ACTIONS(5967),
    [anon_sym_exit] = ACTIONS(5967),
    [anon_sym_EXIT] = ACTIONS(5967),
    [anon_sym_Exit] = ACTIONS(5967),
    [anon_sym_continue] = ACTIONS(5967),
    [anon_sym_CONTINUE] = ACTIONS(5967),
    [anon_sym_Continue] = ACTIONS(5967),
    [anon_sym_break] = ACTIONS(5967),
    [anon_sym_BREAK] = ACTIONS(5967),
    [anon_sym_Break] = ACTIONS(5967),
    [anon_sym_with] = ACTIONS(5967),
    [anon_sym_WITH] = ACTIONS(5967),
    [anon_sym_With] = ACTIONS(5967),
    [sym_asserterror_keyword] = ACTIONS(5969),
    [sym_page_keyword] = ACTIONS(5967),
    [anon_sym_codeunit] = ACTIONS(5967),
    [anon_sym_CODEUNIT] = ACTIONS(5967),
    [anon_sym_Codeunit] = ACTIONS(5967),
    [anon_sym_CodeUnit] = ACTIONS(5967),
    [anon_sym_COdeunit] = ACTIONS(5967),
    [anon_sym_codeUnit] = ACTIONS(5967),
    [sym_report_keyword] = ACTIONS(5967),
    [sym_query_keyword] = ACTIONS(5967),
    [anon_sym_xmlport] = ACTIONS(5967),
    [anon_sym_XMLPORT] = ACTIONS(5967),
    [anon_sym_Xmlport] = ACTIONS(5967),
    [anon_sym_XMLport] = ACTIONS(5967),
    [anon_sym_XMLPort] = ACTIONS(5967),
    [anon_sym_XmlPort] = ACTIONS(5967),
    [anon_sym_enum] = ACTIONS(5967),
    [anon_sym_ENUM] = ACTIONS(5967),
    [anon_sym_Enum] = ACTIONS(5967),
    [anon_sym_eNUM] = ACTIONS(5967),
    [anon_sym_eNum] = ACTIONS(5967),
    [anon_sym_ENum] = ACTIONS(5967),
    [sym_quoted_identifier] = ACTIONS(5969),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5969),
    [sym_verbatim_string] = ACTIONS(5969),
    [sym_integer] = ACTIONS(5967),
    [sym_continue_as_identifier] = ACTIONS(5969),
    [sym_preproc_open] = ACTIONS(5969),
  },
  [STATE(3113)] = {
    [sym_identifier] = ACTIONS(3738),
    [anon_sym_DOT] = ACTIONS(3738),
    [anon_sym_EQ] = ACTIONS(3740),
    [anon_sym_COMMA] = ACTIONS(3740),
    [anon_sym_DASH] = ACTIONS(3738),
    [aux_sym_boolean_token1] = ACTIONS(3738),
    [aux_sym_boolean_token2] = ACTIONS(3738),
    [sym_decimal] = ACTIONS(3738),
    [anon_sym_LPAREN] = ACTIONS(3740),
    [anon_sym_DOT_DOT] = ACTIONS(3740),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3738),
    [anon_sym_STAR] = ACTIONS(3738),
    [anon_sym_LBRACK] = ACTIONS(3740),
    [aux_sym_record_type_token1] = ACTIONS(3738),
    [aux_sym_basic_type_token21] = ACTIONS(3738),
    [aux_sym_basic_type_token22] = ACTIONS(3738),
    [aux_sym_basic_type_token48] = ACTIONS(3738),
    [anon_sym_not] = ACTIONS(3738),
    [anon_sym_NOT] = ACTIONS(3738),
    [anon_sym_Not] = ACTIONS(3738),
    [anon_sym_POUNDelif] = ACTIONS(3740),
    [anon_sym_POUNDELIF] = ACTIONS(3740),
    [anon_sym_POUNDElif] = ACTIONS(3740),
    [anon_sym_POUNDelse] = ACTIONS(3740),
    [anon_sym_POUNDELSE] = ACTIONS(3740),
    [anon_sym_POUNDElse] = ACTIONS(3740),
    [anon_sym_POUNDelse2] = ACTIONS(3740),
    [anon_sym_POUNDELSE2] = ACTIONS(3740),
    [anon_sym_POUNDElse2] = ACTIONS(3740),
    [anon_sym_POUNDendif] = ACTIONS(3740),
    [anon_sym_POUNDENDIF] = ACTIONS(3740),
    [anon_sym_POUNDEndif] = ACTIONS(3740),
    [anon_sym_POUNDendif2] = ACTIONS(3740),
    [anon_sym_POUNDENDIF2] = ACTIONS(3740),
    [anon_sym_POUNDEndif2] = ACTIONS(3740),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3740),
    [aux_sym__expression_token1] = ACTIONS(3740),
    [aux_sym__expression_token2] = ACTIONS(3740),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3738),
    [anon_sym_SLASH] = ACTIONS(3738),
    [anon_sym_div] = ACTIONS(3738),
    [anon_sym_DIV] = ACTIONS(3738),
    [anon_sym_Div] = ACTIONS(3738),
    [anon_sym_mod] = ACTIONS(3738),
    [anon_sym_MOD] = ACTIONS(3738),
    [anon_sym_Mod] = ACTIONS(3738),
    [anon_sym_PLUS] = ACTIONS(3738),
    [anon_sym_GT_EQ] = ACTIONS(3740),
    [anon_sym_LT_EQ] = ACTIONS(3740),
    [anon_sym_GT] = ACTIONS(3738),
    [anon_sym_LT] = ACTIONS(3738),
    [anon_sym_LT_GT] = ACTIONS(3740),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3738),
    [anon_sym_And] = ACTIONS(3738),
    [anon_sym_or] = ACTIONS(3738),
    [anon_sym_OR] = ACTIONS(3738),
    [anon_sym_Or] = ACTIONS(3738),
    [anon_sym_xor] = ACTIONS(3738),
    [anon_sym_XOR] = ACTIONS(3738),
    [anon_sym_Xor] = ACTIONS(3738),
    [anon_sym_QMARK] = ACTIONS(3740),
    [sym_datetime_literal] = ACTIONS(3740),
    [sym_date_literal] = ACTIONS(3738),
    [sym_time_literal] = ACTIONS(3738),
    [sym_biginteger_literal] = ACTIONS(3740),
    [anon_sym_in] = ACTIONS(3738),
    [anon_sym_IN] = ACTIONS(3738),
    [anon_sym_In] = ACTIONS(3738),
    [sym_page_keyword] = ACTIONS(3738),
    [anon_sym_codeunit] = ACTIONS(3738),
    [anon_sym_CODEUNIT] = ACTIONS(3738),
    [anon_sym_Codeunit] = ACTIONS(3738),
    [anon_sym_CodeUnit] = ACTIONS(3738),
    [anon_sym_COdeunit] = ACTIONS(3738),
    [anon_sym_codeUnit] = ACTIONS(3738),
    [sym_report_keyword] = ACTIONS(3738),
    [sym_query_keyword] = ACTIONS(3738),
    [anon_sym_xmlport] = ACTIONS(3738),
    [anon_sym_XMLPORT] = ACTIONS(3738),
    [anon_sym_Xmlport] = ACTIONS(3738),
    [anon_sym_XMLport] = ACTIONS(3738),
    [anon_sym_XMLPort] = ACTIONS(3738),
    [anon_sym_XmlPort] = ACTIONS(3738),
    [anon_sym_enum] = ACTIONS(3738),
    [anon_sym_ENUM] = ACTIONS(3738),
    [anon_sym_Enum] = ACTIONS(3738),
    [anon_sym_eNUM] = ACTIONS(3738),
    [anon_sym_eNum] = ACTIONS(3738),
    [anon_sym_ENum] = ACTIONS(3738),
    [sym_quoted_identifier] = ACTIONS(3740),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3740),
    [sym_verbatim_string] = ACTIONS(3740),
    [sym_integer] = ACTIONS(3738),
    [sym_continue_as_identifier] = ACTIONS(3740),
    [sym_preproc_close] = ACTIONS(3740),
  },
  [STATE(3114)] = {
    [sym_identifier] = ACTIONS(6136),
    [anon_sym_SEMI] = ACTIONS(6138),
    [anon_sym_DASH] = ACTIONS(6138),
    [aux_sym_boolean_token1] = ACTIONS(6136),
    [aux_sym_boolean_token2] = ACTIONS(6136),
    [sym_decimal] = ACTIONS(6136),
    [anon_sym_LPAREN] = ACTIONS(6138),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6136),
    [anon_sym_LBRACK] = ACTIONS(6138),
    [aux_sym_record_type_token1] = ACTIONS(6136),
    [aux_sym_basic_type_token21] = ACTIONS(6136),
    [aux_sym_basic_type_token22] = ACTIONS(6136),
    [aux_sym_basic_type_token48] = ACTIONS(6136),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6136),
    [anon_sym_POUNDif] = ACTIONS(6138),
    [anon_sym_POUNDIF] = ACTIONS(6138),
    [anon_sym_POUNDIf] = ACTIONS(6138),
    [anon_sym_not] = ACTIONS(6136),
    [anon_sym_NOT] = ACTIONS(6136),
    [anon_sym_Not] = ACTIONS(6136),
    [anon_sym_POUNDelse] = ACTIONS(6138),
    [anon_sym_POUNDELSE] = ACTIONS(6138),
    [anon_sym_POUNDElse] = ACTIONS(6138),
    [anon_sym_POUNDelse2] = ACTIONS(6138),
    [anon_sym_POUNDELSE2] = ACTIONS(6138),
    [anon_sym_POUNDElse2] = ACTIONS(6138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6136),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6136),
    [anon_sym_PLUS] = ACTIONS(6138),
    [sym_datetime_literal] = ACTIONS(6138),
    [sym_date_literal] = ACTIONS(6136),
    [sym_time_literal] = ACTIONS(6136),
    [sym_biginteger_literal] = ACTIONS(6138),
    [anon_sym_if] = ACTIONS(6136),
    [anon_sym_IF] = ACTIONS(6136),
    [anon_sym_If] = ACTIONS(6136),
    [anon_sym_else] = ACTIONS(6136),
    [anon_sym_ELSE] = ACTIONS(6136),
    [anon_sym_Else] = ACTIONS(6136),
    [anon_sym_case] = ACTIONS(6136),
    [anon_sym_CASE] = ACTIONS(6136),
    [anon_sym_Case] = ACTIONS(6136),
    [anon_sym_for] = ACTIONS(6136),
    [anon_sym_FOR] = ACTIONS(6136),
    [anon_sym_For] = ACTIONS(6136),
    [anon_sym_foreach] = ACTIONS(6136),
    [anon_sym_FOREACH] = ACTIONS(6136),
    [anon_sym_Foreach] = ACTIONS(6136),
    [anon_sym_while] = ACTIONS(6136),
    [anon_sym_WHILE] = ACTIONS(6136),
    [anon_sym_While] = ACTIONS(6136),
    [anon_sym_repeat] = ACTIONS(6136),
    [anon_sym_REPEAT] = ACTIONS(6136),
    [anon_sym_Repeat] = ACTIONS(6136),
    [anon_sym_until] = ACTIONS(6136),
    [anon_sym_UNTIL] = ACTIONS(6136),
    [anon_sym_Until] = ACTIONS(6136),
    [anon_sym_exit] = ACTIONS(6136),
    [anon_sym_EXIT] = ACTIONS(6136),
    [anon_sym_Exit] = ACTIONS(6136),
    [anon_sym_continue] = ACTIONS(6136),
    [anon_sym_CONTINUE] = ACTIONS(6136),
    [anon_sym_Continue] = ACTIONS(6136),
    [anon_sym_break] = ACTIONS(6136),
    [anon_sym_BREAK] = ACTIONS(6136),
    [anon_sym_Break] = ACTIONS(6136),
    [anon_sym_with] = ACTIONS(6136),
    [anon_sym_WITH] = ACTIONS(6136),
    [anon_sym_With] = ACTIONS(6136),
    [sym_asserterror_keyword] = ACTIONS(6138),
    [sym_page_keyword] = ACTIONS(6136),
    [anon_sym_codeunit] = ACTIONS(6136),
    [anon_sym_CODEUNIT] = ACTIONS(6136),
    [anon_sym_Codeunit] = ACTIONS(6136),
    [anon_sym_CodeUnit] = ACTIONS(6136),
    [anon_sym_COdeunit] = ACTIONS(6136),
    [anon_sym_codeUnit] = ACTIONS(6136),
    [sym_report_keyword] = ACTIONS(6136),
    [sym_query_keyword] = ACTIONS(6136),
    [anon_sym_xmlport] = ACTIONS(6136),
    [anon_sym_XMLPORT] = ACTIONS(6136),
    [anon_sym_Xmlport] = ACTIONS(6136),
    [anon_sym_XMLport] = ACTIONS(6136),
    [anon_sym_XMLPort] = ACTIONS(6136),
    [anon_sym_XmlPort] = ACTIONS(6136),
    [anon_sym_enum] = ACTIONS(6136),
    [anon_sym_ENUM] = ACTIONS(6136),
    [anon_sym_Enum] = ACTIONS(6136),
    [anon_sym_eNUM] = ACTIONS(6136),
    [anon_sym_eNum] = ACTIONS(6136),
    [anon_sym_ENum] = ACTIONS(6136),
    [sym_quoted_identifier] = ACTIONS(6138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6138),
    [sym_verbatim_string] = ACTIONS(6138),
    [sym_integer] = ACTIONS(6136),
    [sym_continue_as_identifier] = ACTIONS(6138),
    [sym_preproc_open] = ACTIONS(6138),
  },
  [STATE(3115)] = {
    [sym_identifier] = ACTIONS(6140),
    [anon_sym_SEMI] = ACTIONS(6142),
    [anon_sym_DASH] = ACTIONS(6142),
    [aux_sym_boolean_token1] = ACTIONS(6140),
    [aux_sym_boolean_token2] = ACTIONS(6140),
    [sym_decimal] = ACTIONS(6140),
    [anon_sym_LPAREN] = ACTIONS(6142),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6140),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [aux_sym_record_type_token1] = ACTIONS(6140),
    [aux_sym_basic_type_token21] = ACTIONS(6140),
    [aux_sym_basic_type_token22] = ACTIONS(6140),
    [aux_sym_basic_type_token48] = ACTIONS(6140),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6140),
    [anon_sym_POUNDif] = ACTIONS(6142),
    [anon_sym_POUNDIF] = ACTIONS(6142),
    [anon_sym_POUNDIf] = ACTIONS(6142),
    [anon_sym_not] = ACTIONS(6140),
    [anon_sym_NOT] = ACTIONS(6140),
    [anon_sym_Not] = ACTIONS(6140),
    [anon_sym_POUNDelse] = ACTIONS(6142),
    [anon_sym_POUNDELSE] = ACTIONS(6142),
    [anon_sym_POUNDElse] = ACTIONS(6142),
    [anon_sym_POUNDelse2] = ACTIONS(6142),
    [anon_sym_POUNDELSE2] = ACTIONS(6142),
    [anon_sym_POUNDElse2] = ACTIONS(6142),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6140),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6140),
    [anon_sym_PLUS] = ACTIONS(6142),
    [sym_datetime_literal] = ACTIONS(6142),
    [sym_date_literal] = ACTIONS(6140),
    [sym_time_literal] = ACTIONS(6140),
    [sym_biginteger_literal] = ACTIONS(6142),
    [anon_sym_if] = ACTIONS(6140),
    [anon_sym_IF] = ACTIONS(6140),
    [anon_sym_If] = ACTIONS(6140),
    [anon_sym_else] = ACTIONS(6140),
    [anon_sym_ELSE] = ACTIONS(6140),
    [anon_sym_Else] = ACTIONS(6140),
    [anon_sym_case] = ACTIONS(6140),
    [anon_sym_CASE] = ACTIONS(6140),
    [anon_sym_Case] = ACTIONS(6140),
    [anon_sym_for] = ACTIONS(6140),
    [anon_sym_FOR] = ACTIONS(6140),
    [anon_sym_For] = ACTIONS(6140),
    [anon_sym_foreach] = ACTIONS(6140),
    [anon_sym_FOREACH] = ACTIONS(6140),
    [anon_sym_Foreach] = ACTIONS(6140),
    [anon_sym_while] = ACTIONS(6140),
    [anon_sym_WHILE] = ACTIONS(6140),
    [anon_sym_While] = ACTIONS(6140),
    [anon_sym_repeat] = ACTIONS(6140),
    [anon_sym_REPEAT] = ACTIONS(6140),
    [anon_sym_Repeat] = ACTIONS(6140),
    [anon_sym_until] = ACTIONS(6140),
    [anon_sym_UNTIL] = ACTIONS(6140),
    [anon_sym_Until] = ACTIONS(6140),
    [anon_sym_exit] = ACTIONS(6140),
    [anon_sym_EXIT] = ACTIONS(6140),
    [anon_sym_Exit] = ACTIONS(6140),
    [anon_sym_continue] = ACTIONS(6140),
    [anon_sym_CONTINUE] = ACTIONS(6140),
    [anon_sym_Continue] = ACTIONS(6140),
    [anon_sym_break] = ACTIONS(6140),
    [anon_sym_BREAK] = ACTIONS(6140),
    [anon_sym_Break] = ACTIONS(6140),
    [anon_sym_with] = ACTIONS(6140),
    [anon_sym_WITH] = ACTIONS(6140),
    [anon_sym_With] = ACTIONS(6140),
    [sym_asserterror_keyword] = ACTIONS(6142),
    [sym_page_keyword] = ACTIONS(6140),
    [anon_sym_codeunit] = ACTIONS(6140),
    [anon_sym_CODEUNIT] = ACTIONS(6140),
    [anon_sym_Codeunit] = ACTIONS(6140),
    [anon_sym_CodeUnit] = ACTIONS(6140),
    [anon_sym_COdeunit] = ACTIONS(6140),
    [anon_sym_codeUnit] = ACTIONS(6140),
    [sym_report_keyword] = ACTIONS(6140),
    [sym_query_keyword] = ACTIONS(6140),
    [anon_sym_xmlport] = ACTIONS(6140),
    [anon_sym_XMLPORT] = ACTIONS(6140),
    [anon_sym_Xmlport] = ACTIONS(6140),
    [anon_sym_XMLport] = ACTIONS(6140),
    [anon_sym_XMLPort] = ACTIONS(6140),
    [anon_sym_XmlPort] = ACTIONS(6140),
    [anon_sym_enum] = ACTIONS(6140),
    [anon_sym_ENUM] = ACTIONS(6140),
    [anon_sym_Enum] = ACTIONS(6140),
    [anon_sym_eNUM] = ACTIONS(6140),
    [anon_sym_eNum] = ACTIONS(6140),
    [anon_sym_ENum] = ACTIONS(6140),
    [sym_quoted_identifier] = ACTIONS(6142),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6142),
    [sym_verbatim_string] = ACTIONS(6142),
    [sym_integer] = ACTIONS(6140),
    [sym_continue_as_identifier] = ACTIONS(6142),
    [sym_preproc_open] = ACTIONS(6142),
  },
  [STATE(3116)] = {
    [sym_identifier] = ACTIONS(6144),
    [anon_sym_SEMI] = ACTIONS(6146),
    [anon_sym_DASH] = ACTIONS(6146),
    [aux_sym_boolean_token1] = ACTIONS(6144),
    [aux_sym_boolean_token2] = ACTIONS(6144),
    [sym_decimal] = ACTIONS(6144),
    [anon_sym_LPAREN] = ACTIONS(6146),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6144),
    [anon_sym_LBRACK] = ACTIONS(6146),
    [aux_sym_record_type_token1] = ACTIONS(6144),
    [aux_sym_basic_type_token21] = ACTIONS(6144),
    [aux_sym_basic_type_token22] = ACTIONS(6144),
    [aux_sym_basic_type_token48] = ACTIONS(6144),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6144),
    [anon_sym_POUNDif] = ACTIONS(6146),
    [anon_sym_POUNDIF] = ACTIONS(6146),
    [anon_sym_POUNDIf] = ACTIONS(6146),
    [anon_sym_not] = ACTIONS(6144),
    [anon_sym_NOT] = ACTIONS(6144),
    [anon_sym_Not] = ACTIONS(6144),
    [anon_sym_POUNDelse] = ACTIONS(6146),
    [anon_sym_POUNDELSE] = ACTIONS(6146),
    [anon_sym_POUNDElse] = ACTIONS(6146),
    [anon_sym_POUNDelse2] = ACTIONS(6146),
    [anon_sym_POUNDELSE2] = ACTIONS(6146),
    [anon_sym_POUNDElse2] = ACTIONS(6146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6144),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6144),
    [anon_sym_PLUS] = ACTIONS(6146),
    [sym_datetime_literal] = ACTIONS(6146),
    [sym_date_literal] = ACTIONS(6144),
    [sym_time_literal] = ACTIONS(6144),
    [sym_biginteger_literal] = ACTIONS(6146),
    [anon_sym_if] = ACTIONS(6144),
    [anon_sym_IF] = ACTIONS(6144),
    [anon_sym_If] = ACTIONS(6144),
    [anon_sym_else] = ACTIONS(6144),
    [anon_sym_ELSE] = ACTIONS(6144),
    [anon_sym_Else] = ACTIONS(6144),
    [anon_sym_case] = ACTIONS(6144),
    [anon_sym_CASE] = ACTIONS(6144),
    [anon_sym_Case] = ACTIONS(6144),
    [anon_sym_for] = ACTIONS(6144),
    [anon_sym_FOR] = ACTIONS(6144),
    [anon_sym_For] = ACTIONS(6144),
    [anon_sym_foreach] = ACTIONS(6144),
    [anon_sym_FOREACH] = ACTIONS(6144),
    [anon_sym_Foreach] = ACTIONS(6144),
    [anon_sym_while] = ACTIONS(6144),
    [anon_sym_WHILE] = ACTIONS(6144),
    [anon_sym_While] = ACTIONS(6144),
    [anon_sym_repeat] = ACTIONS(6144),
    [anon_sym_REPEAT] = ACTIONS(6144),
    [anon_sym_Repeat] = ACTIONS(6144),
    [anon_sym_until] = ACTIONS(6144),
    [anon_sym_UNTIL] = ACTIONS(6144),
    [anon_sym_Until] = ACTIONS(6144),
    [anon_sym_exit] = ACTIONS(6144),
    [anon_sym_EXIT] = ACTIONS(6144),
    [anon_sym_Exit] = ACTIONS(6144),
    [anon_sym_continue] = ACTIONS(6144),
    [anon_sym_CONTINUE] = ACTIONS(6144),
    [anon_sym_Continue] = ACTIONS(6144),
    [anon_sym_break] = ACTIONS(6144),
    [anon_sym_BREAK] = ACTIONS(6144),
    [anon_sym_Break] = ACTIONS(6144),
    [anon_sym_with] = ACTIONS(6144),
    [anon_sym_WITH] = ACTIONS(6144),
    [anon_sym_With] = ACTIONS(6144),
    [sym_asserterror_keyword] = ACTIONS(6146),
    [sym_page_keyword] = ACTIONS(6144),
    [anon_sym_codeunit] = ACTIONS(6144),
    [anon_sym_CODEUNIT] = ACTIONS(6144),
    [anon_sym_Codeunit] = ACTIONS(6144),
    [anon_sym_CodeUnit] = ACTIONS(6144),
    [anon_sym_COdeunit] = ACTIONS(6144),
    [anon_sym_codeUnit] = ACTIONS(6144),
    [sym_report_keyword] = ACTIONS(6144),
    [sym_query_keyword] = ACTIONS(6144),
    [anon_sym_xmlport] = ACTIONS(6144),
    [anon_sym_XMLPORT] = ACTIONS(6144),
    [anon_sym_Xmlport] = ACTIONS(6144),
    [anon_sym_XMLport] = ACTIONS(6144),
    [anon_sym_XMLPort] = ACTIONS(6144),
    [anon_sym_XmlPort] = ACTIONS(6144),
    [anon_sym_enum] = ACTIONS(6144),
    [anon_sym_ENUM] = ACTIONS(6144),
    [anon_sym_Enum] = ACTIONS(6144),
    [anon_sym_eNUM] = ACTIONS(6144),
    [anon_sym_eNum] = ACTIONS(6144),
    [anon_sym_ENum] = ACTIONS(6144),
    [sym_quoted_identifier] = ACTIONS(6146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6146),
    [sym_verbatim_string] = ACTIONS(6146),
    [sym_integer] = ACTIONS(6144),
    [sym_continue_as_identifier] = ACTIONS(6146),
    [sym_preproc_open] = ACTIONS(6146),
  },
  [STATE(3117)] = {
    [sym_identifier] = ACTIONS(6148),
    [anon_sym_SEMI] = ACTIONS(6150),
    [anon_sym_DASH] = ACTIONS(6150),
    [aux_sym_boolean_token1] = ACTIONS(6148),
    [aux_sym_boolean_token2] = ACTIONS(6148),
    [sym_decimal] = ACTIONS(6148),
    [anon_sym_LPAREN] = ACTIONS(6150),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6148),
    [anon_sym_LBRACK] = ACTIONS(6150),
    [aux_sym_record_type_token1] = ACTIONS(6148),
    [aux_sym_basic_type_token21] = ACTIONS(6148),
    [aux_sym_basic_type_token22] = ACTIONS(6148),
    [aux_sym_basic_type_token48] = ACTIONS(6148),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6148),
    [anon_sym_POUNDif] = ACTIONS(6150),
    [anon_sym_POUNDIF] = ACTIONS(6150),
    [anon_sym_POUNDIf] = ACTIONS(6150),
    [anon_sym_not] = ACTIONS(6148),
    [anon_sym_NOT] = ACTIONS(6148),
    [anon_sym_Not] = ACTIONS(6148),
    [anon_sym_POUNDelse] = ACTIONS(6150),
    [anon_sym_POUNDELSE] = ACTIONS(6150),
    [anon_sym_POUNDElse] = ACTIONS(6150),
    [anon_sym_POUNDelse2] = ACTIONS(6150),
    [anon_sym_POUNDELSE2] = ACTIONS(6150),
    [anon_sym_POUNDElse2] = ACTIONS(6150),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6148),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6148),
    [anon_sym_PLUS] = ACTIONS(6150),
    [sym_datetime_literal] = ACTIONS(6150),
    [sym_date_literal] = ACTIONS(6148),
    [sym_time_literal] = ACTIONS(6148),
    [sym_biginteger_literal] = ACTIONS(6150),
    [anon_sym_if] = ACTIONS(6148),
    [anon_sym_IF] = ACTIONS(6148),
    [anon_sym_If] = ACTIONS(6148),
    [anon_sym_else] = ACTIONS(6148),
    [anon_sym_ELSE] = ACTIONS(6148),
    [anon_sym_Else] = ACTIONS(6148),
    [anon_sym_case] = ACTIONS(6148),
    [anon_sym_CASE] = ACTIONS(6148),
    [anon_sym_Case] = ACTIONS(6148),
    [anon_sym_for] = ACTIONS(6148),
    [anon_sym_FOR] = ACTIONS(6148),
    [anon_sym_For] = ACTIONS(6148),
    [anon_sym_foreach] = ACTIONS(6148),
    [anon_sym_FOREACH] = ACTIONS(6148),
    [anon_sym_Foreach] = ACTIONS(6148),
    [anon_sym_while] = ACTIONS(6148),
    [anon_sym_WHILE] = ACTIONS(6148),
    [anon_sym_While] = ACTIONS(6148),
    [anon_sym_repeat] = ACTIONS(6148),
    [anon_sym_REPEAT] = ACTIONS(6148),
    [anon_sym_Repeat] = ACTIONS(6148),
    [anon_sym_until] = ACTIONS(6148),
    [anon_sym_UNTIL] = ACTIONS(6148),
    [anon_sym_Until] = ACTIONS(6148),
    [anon_sym_exit] = ACTIONS(6148),
    [anon_sym_EXIT] = ACTIONS(6148),
    [anon_sym_Exit] = ACTIONS(6148),
    [anon_sym_continue] = ACTIONS(6148),
    [anon_sym_CONTINUE] = ACTIONS(6148),
    [anon_sym_Continue] = ACTIONS(6148),
    [anon_sym_break] = ACTIONS(6148),
    [anon_sym_BREAK] = ACTIONS(6148),
    [anon_sym_Break] = ACTIONS(6148),
    [anon_sym_with] = ACTIONS(6148),
    [anon_sym_WITH] = ACTIONS(6148),
    [anon_sym_With] = ACTIONS(6148),
    [sym_asserterror_keyword] = ACTIONS(6150),
    [sym_page_keyword] = ACTIONS(6148),
    [anon_sym_codeunit] = ACTIONS(6148),
    [anon_sym_CODEUNIT] = ACTIONS(6148),
    [anon_sym_Codeunit] = ACTIONS(6148),
    [anon_sym_CodeUnit] = ACTIONS(6148),
    [anon_sym_COdeunit] = ACTIONS(6148),
    [anon_sym_codeUnit] = ACTIONS(6148),
    [sym_report_keyword] = ACTIONS(6148),
    [sym_query_keyword] = ACTIONS(6148),
    [anon_sym_xmlport] = ACTIONS(6148),
    [anon_sym_XMLPORT] = ACTIONS(6148),
    [anon_sym_Xmlport] = ACTIONS(6148),
    [anon_sym_XMLport] = ACTIONS(6148),
    [anon_sym_XMLPort] = ACTIONS(6148),
    [anon_sym_XmlPort] = ACTIONS(6148),
    [anon_sym_enum] = ACTIONS(6148),
    [anon_sym_ENUM] = ACTIONS(6148),
    [anon_sym_Enum] = ACTIONS(6148),
    [anon_sym_eNUM] = ACTIONS(6148),
    [anon_sym_eNum] = ACTIONS(6148),
    [anon_sym_ENum] = ACTIONS(6148),
    [sym_quoted_identifier] = ACTIONS(6150),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6150),
    [sym_verbatim_string] = ACTIONS(6150),
    [sym_integer] = ACTIONS(6148),
    [sym_continue_as_identifier] = ACTIONS(6150),
    [sym_preproc_open] = ACTIONS(6150),
  },
  [STATE(3118)] = {
    [sym_identifier] = ACTIONS(6152),
    [anon_sym_SEMI] = ACTIONS(6154),
    [anon_sym_DASH] = ACTIONS(6154),
    [aux_sym_boolean_token1] = ACTIONS(6152),
    [aux_sym_boolean_token2] = ACTIONS(6152),
    [sym_decimal] = ACTIONS(6152),
    [anon_sym_LPAREN] = ACTIONS(6154),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6152),
    [anon_sym_LBRACK] = ACTIONS(6154),
    [aux_sym_record_type_token1] = ACTIONS(6152),
    [aux_sym_basic_type_token21] = ACTIONS(6152),
    [aux_sym_basic_type_token22] = ACTIONS(6152),
    [aux_sym_basic_type_token48] = ACTIONS(6152),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6152),
    [anon_sym_POUNDif] = ACTIONS(6154),
    [anon_sym_POUNDIF] = ACTIONS(6154),
    [anon_sym_POUNDIf] = ACTIONS(6154),
    [anon_sym_not] = ACTIONS(6152),
    [anon_sym_NOT] = ACTIONS(6152),
    [anon_sym_Not] = ACTIONS(6152),
    [anon_sym_POUNDelse] = ACTIONS(6154),
    [anon_sym_POUNDELSE] = ACTIONS(6154),
    [anon_sym_POUNDElse] = ACTIONS(6154),
    [anon_sym_POUNDelse2] = ACTIONS(6154),
    [anon_sym_POUNDELSE2] = ACTIONS(6154),
    [anon_sym_POUNDElse2] = ACTIONS(6154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6152),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6152),
    [anon_sym_PLUS] = ACTIONS(6154),
    [sym_datetime_literal] = ACTIONS(6154),
    [sym_date_literal] = ACTIONS(6152),
    [sym_time_literal] = ACTIONS(6152),
    [sym_biginteger_literal] = ACTIONS(6154),
    [anon_sym_if] = ACTIONS(6152),
    [anon_sym_IF] = ACTIONS(6152),
    [anon_sym_If] = ACTIONS(6152),
    [anon_sym_else] = ACTIONS(6152),
    [anon_sym_ELSE] = ACTIONS(6152),
    [anon_sym_Else] = ACTIONS(6152),
    [anon_sym_case] = ACTIONS(6152),
    [anon_sym_CASE] = ACTIONS(6152),
    [anon_sym_Case] = ACTIONS(6152),
    [anon_sym_for] = ACTIONS(6152),
    [anon_sym_FOR] = ACTIONS(6152),
    [anon_sym_For] = ACTIONS(6152),
    [anon_sym_foreach] = ACTIONS(6152),
    [anon_sym_FOREACH] = ACTIONS(6152),
    [anon_sym_Foreach] = ACTIONS(6152),
    [anon_sym_while] = ACTIONS(6152),
    [anon_sym_WHILE] = ACTIONS(6152),
    [anon_sym_While] = ACTIONS(6152),
    [anon_sym_repeat] = ACTIONS(6152),
    [anon_sym_REPEAT] = ACTIONS(6152),
    [anon_sym_Repeat] = ACTIONS(6152),
    [anon_sym_until] = ACTIONS(6152),
    [anon_sym_UNTIL] = ACTIONS(6152),
    [anon_sym_Until] = ACTIONS(6152),
    [anon_sym_exit] = ACTIONS(6152),
    [anon_sym_EXIT] = ACTIONS(6152),
    [anon_sym_Exit] = ACTIONS(6152),
    [anon_sym_continue] = ACTIONS(6152),
    [anon_sym_CONTINUE] = ACTIONS(6152),
    [anon_sym_Continue] = ACTIONS(6152),
    [anon_sym_break] = ACTIONS(6152),
    [anon_sym_BREAK] = ACTIONS(6152),
    [anon_sym_Break] = ACTIONS(6152),
    [anon_sym_with] = ACTIONS(6152),
    [anon_sym_WITH] = ACTIONS(6152),
    [anon_sym_With] = ACTIONS(6152),
    [sym_asserterror_keyword] = ACTIONS(6154),
    [sym_page_keyword] = ACTIONS(6152),
    [anon_sym_codeunit] = ACTIONS(6152),
    [anon_sym_CODEUNIT] = ACTIONS(6152),
    [anon_sym_Codeunit] = ACTIONS(6152),
    [anon_sym_CodeUnit] = ACTIONS(6152),
    [anon_sym_COdeunit] = ACTIONS(6152),
    [anon_sym_codeUnit] = ACTIONS(6152),
    [sym_report_keyword] = ACTIONS(6152),
    [sym_query_keyword] = ACTIONS(6152),
    [anon_sym_xmlport] = ACTIONS(6152),
    [anon_sym_XMLPORT] = ACTIONS(6152),
    [anon_sym_Xmlport] = ACTIONS(6152),
    [anon_sym_XMLport] = ACTIONS(6152),
    [anon_sym_XMLPort] = ACTIONS(6152),
    [anon_sym_XmlPort] = ACTIONS(6152),
    [anon_sym_enum] = ACTIONS(6152),
    [anon_sym_ENUM] = ACTIONS(6152),
    [anon_sym_Enum] = ACTIONS(6152),
    [anon_sym_eNUM] = ACTIONS(6152),
    [anon_sym_eNum] = ACTIONS(6152),
    [anon_sym_ENum] = ACTIONS(6152),
    [sym_quoted_identifier] = ACTIONS(6154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6154),
    [sym_verbatim_string] = ACTIONS(6154),
    [sym_integer] = ACTIONS(6152),
    [sym_continue_as_identifier] = ACTIONS(6154),
    [sym_preproc_open] = ACTIONS(6154),
  },
  [STATE(3119)] = {
    [sym_identifier] = ACTIONS(6156),
    [anon_sym_SEMI] = ACTIONS(6158),
    [anon_sym_DASH] = ACTIONS(6158),
    [aux_sym_boolean_token1] = ACTIONS(6156),
    [aux_sym_boolean_token2] = ACTIONS(6156),
    [sym_decimal] = ACTIONS(6156),
    [anon_sym_LPAREN] = ACTIONS(6158),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6156),
    [anon_sym_LBRACK] = ACTIONS(6158),
    [aux_sym_record_type_token1] = ACTIONS(6156),
    [aux_sym_basic_type_token21] = ACTIONS(6156),
    [aux_sym_basic_type_token22] = ACTIONS(6156),
    [aux_sym_basic_type_token48] = ACTIONS(6156),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6156),
    [anon_sym_POUNDif] = ACTIONS(6158),
    [anon_sym_POUNDIF] = ACTIONS(6158),
    [anon_sym_POUNDIf] = ACTIONS(6158),
    [anon_sym_not] = ACTIONS(6156),
    [anon_sym_NOT] = ACTIONS(6156),
    [anon_sym_Not] = ACTIONS(6156),
    [anon_sym_POUNDelse] = ACTIONS(6158),
    [anon_sym_POUNDELSE] = ACTIONS(6158),
    [anon_sym_POUNDElse] = ACTIONS(6158),
    [anon_sym_POUNDelse2] = ACTIONS(6158),
    [anon_sym_POUNDELSE2] = ACTIONS(6158),
    [anon_sym_POUNDElse2] = ACTIONS(6158),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6156),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6156),
    [anon_sym_PLUS] = ACTIONS(6158),
    [sym_datetime_literal] = ACTIONS(6158),
    [sym_date_literal] = ACTIONS(6156),
    [sym_time_literal] = ACTIONS(6156),
    [sym_biginteger_literal] = ACTIONS(6158),
    [anon_sym_if] = ACTIONS(6156),
    [anon_sym_IF] = ACTIONS(6156),
    [anon_sym_If] = ACTIONS(6156),
    [anon_sym_else] = ACTIONS(6156),
    [anon_sym_ELSE] = ACTIONS(6156),
    [anon_sym_Else] = ACTIONS(6156),
    [anon_sym_case] = ACTIONS(6156),
    [anon_sym_CASE] = ACTIONS(6156),
    [anon_sym_Case] = ACTIONS(6156),
    [anon_sym_for] = ACTIONS(6156),
    [anon_sym_FOR] = ACTIONS(6156),
    [anon_sym_For] = ACTIONS(6156),
    [anon_sym_foreach] = ACTIONS(6156),
    [anon_sym_FOREACH] = ACTIONS(6156),
    [anon_sym_Foreach] = ACTIONS(6156),
    [anon_sym_while] = ACTIONS(6156),
    [anon_sym_WHILE] = ACTIONS(6156),
    [anon_sym_While] = ACTIONS(6156),
    [anon_sym_repeat] = ACTIONS(6156),
    [anon_sym_REPEAT] = ACTIONS(6156),
    [anon_sym_Repeat] = ACTIONS(6156),
    [anon_sym_until] = ACTIONS(6156),
    [anon_sym_UNTIL] = ACTIONS(6156),
    [anon_sym_Until] = ACTIONS(6156),
    [anon_sym_exit] = ACTIONS(6156),
    [anon_sym_EXIT] = ACTIONS(6156),
    [anon_sym_Exit] = ACTIONS(6156),
    [anon_sym_continue] = ACTIONS(6156),
    [anon_sym_CONTINUE] = ACTIONS(6156),
    [anon_sym_Continue] = ACTIONS(6156),
    [anon_sym_break] = ACTIONS(6156),
    [anon_sym_BREAK] = ACTIONS(6156),
    [anon_sym_Break] = ACTIONS(6156),
    [anon_sym_with] = ACTIONS(6156),
    [anon_sym_WITH] = ACTIONS(6156),
    [anon_sym_With] = ACTIONS(6156),
    [sym_asserterror_keyword] = ACTIONS(6158),
    [sym_page_keyword] = ACTIONS(6156),
    [anon_sym_codeunit] = ACTIONS(6156),
    [anon_sym_CODEUNIT] = ACTIONS(6156),
    [anon_sym_Codeunit] = ACTIONS(6156),
    [anon_sym_CodeUnit] = ACTIONS(6156),
    [anon_sym_COdeunit] = ACTIONS(6156),
    [anon_sym_codeUnit] = ACTIONS(6156),
    [sym_report_keyword] = ACTIONS(6156),
    [sym_query_keyword] = ACTIONS(6156),
    [anon_sym_xmlport] = ACTIONS(6156),
    [anon_sym_XMLPORT] = ACTIONS(6156),
    [anon_sym_Xmlport] = ACTIONS(6156),
    [anon_sym_XMLport] = ACTIONS(6156),
    [anon_sym_XMLPort] = ACTIONS(6156),
    [anon_sym_XmlPort] = ACTIONS(6156),
    [anon_sym_enum] = ACTIONS(6156),
    [anon_sym_ENUM] = ACTIONS(6156),
    [anon_sym_Enum] = ACTIONS(6156),
    [anon_sym_eNUM] = ACTIONS(6156),
    [anon_sym_eNum] = ACTIONS(6156),
    [anon_sym_ENum] = ACTIONS(6156),
    [sym_quoted_identifier] = ACTIONS(6158),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6158),
    [sym_verbatim_string] = ACTIONS(6158),
    [sym_integer] = ACTIONS(6156),
    [sym_continue_as_identifier] = ACTIONS(6158),
    [sym_preproc_open] = ACTIONS(6158),
  },
  [STATE(3120)] = {
    [sym_identifier] = ACTIONS(6160),
    [anon_sym_SEMI] = ACTIONS(6162),
    [anon_sym_DASH] = ACTIONS(6162),
    [aux_sym_boolean_token1] = ACTIONS(6160),
    [aux_sym_boolean_token2] = ACTIONS(6160),
    [sym_decimal] = ACTIONS(6160),
    [anon_sym_LPAREN] = ACTIONS(6162),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6160),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [aux_sym_record_type_token1] = ACTIONS(6160),
    [aux_sym_basic_type_token21] = ACTIONS(6160),
    [aux_sym_basic_type_token22] = ACTIONS(6160),
    [aux_sym_basic_type_token48] = ACTIONS(6160),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6160),
    [anon_sym_POUNDif] = ACTIONS(6162),
    [anon_sym_POUNDIF] = ACTIONS(6162),
    [anon_sym_POUNDIf] = ACTIONS(6162),
    [anon_sym_not] = ACTIONS(6160),
    [anon_sym_NOT] = ACTIONS(6160),
    [anon_sym_Not] = ACTIONS(6160),
    [anon_sym_POUNDelse] = ACTIONS(6162),
    [anon_sym_POUNDELSE] = ACTIONS(6162),
    [anon_sym_POUNDElse] = ACTIONS(6162),
    [anon_sym_POUNDelse2] = ACTIONS(6162),
    [anon_sym_POUNDELSE2] = ACTIONS(6162),
    [anon_sym_POUNDElse2] = ACTIONS(6162),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6160),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6162),
    [sym_datetime_literal] = ACTIONS(6162),
    [sym_date_literal] = ACTIONS(6160),
    [sym_time_literal] = ACTIONS(6160),
    [sym_biginteger_literal] = ACTIONS(6162),
    [anon_sym_if] = ACTIONS(6160),
    [anon_sym_IF] = ACTIONS(6160),
    [anon_sym_If] = ACTIONS(6160),
    [anon_sym_else] = ACTIONS(6160),
    [anon_sym_ELSE] = ACTIONS(6160),
    [anon_sym_Else] = ACTIONS(6160),
    [anon_sym_case] = ACTIONS(6160),
    [anon_sym_CASE] = ACTIONS(6160),
    [anon_sym_Case] = ACTIONS(6160),
    [anon_sym_for] = ACTIONS(6160),
    [anon_sym_FOR] = ACTIONS(6160),
    [anon_sym_For] = ACTIONS(6160),
    [anon_sym_foreach] = ACTIONS(6160),
    [anon_sym_FOREACH] = ACTIONS(6160),
    [anon_sym_Foreach] = ACTIONS(6160),
    [anon_sym_while] = ACTIONS(6160),
    [anon_sym_WHILE] = ACTIONS(6160),
    [anon_sym_While] = ACTIONS(6160),
    [anon_sym_repeat] = ACTIONS(6160),
    [anon_sym_REPEAT] = ACTIONS(6160),
    [anon_sym_Repeat] = ACTIONS(6160),
    [anon_sym_until] = ACTIONS(6160),
    [anon_sym_UNTIL] = ACTIONS(6160),
    [anon_sym_Until] = ACTIONS(6160),
    [anon_sym_exit] = ACTIONS(6160),
    [anon_sym_EXIT] = ACTIONS(6160),
    [anon_sym_Exit] = ACTIONS(6160),
    [anon_sym_continue] = ACTIONS(6160),
    [anon_sym_CONTINUE] = ACTIONS(6160),
    [anon_sym_Continue] = ACTIONS(6160),
    [anon_sym_break] = ACTIONS(6160),
    [anon_sym_BREAK] = ACTIONS(6160),
    [anon_sym_Break] = ACTIONS(6160),
    [anon_sym_with] = ACTIONS(6160),
    [anon_sym_WITH] = ACTIONS(6160),
    [anon_sym_With] = ACTIONS(6160),
    [sym_asserterror_keyword] = ACTIONS(6162),
    [sym_page_keyword] = ACTIONS(6160),
    [anon_sym_codeunit] = ACTIONS(6160),
    [anon_sym_CODEUNIT] = ACTIONS(6160),
    [anon_sym_Codeunit] = ACTIONS(6160),
    [anon_sym_CodeUnit] = ACTIONS(6160),
    [anon_sym_COdeunit] = ACTIONS(6160),
    [anon_sym_codeUnit] = ACTIONS(6160),
    [sym_report_keyword] = ACTIONS(6160),
    [sym_query_keyword] = ACTIONS(6160),
    [anon_sym_xmlport] = ACTIONS(6160),
    [anon_sym_XMLPORT] = ACTIONS(6160),
    [anon_sym_Xmlport] = ACTIONS(6160),
    [anon_sym_XMLport] = ACTIONS(6160),
    [anon_sym_XMLPort] = ACTIONS(6160),
    [anon_sym_XmlPort] = ACTIONS(6160),
    [anon_sym_enum] = ACTIONS(6160),
    [anon_sym_ENUM] = ACTIONS(6160),
    [anon_sym_Enum] = ACTIONS(6160),
    [anon_sym_eNUM] = ACTIONS(6160),
    [anon_sym_eNum] = ACTIONS(6160),
    [anon_sym_ENum] = ACTIONS(6160),
    [sym_quoted_identifier] = ACTIONS(6162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6162),
    [sym_verbatim_string] = ACTIONS(6162),
    [sym_integer] = ACTIONS(6160),
    [sym_continue_as_identifier] = ACTIONS(6162),
    [sym_preproc_open] = ACTIONS(6162),
  },
  [STATE(3121)] = {
    [sym_identifier] = ACTIONS(6164),
    [anon_sym_SEMI] = ACTIONS(6166),
    [anon_sym_DASH] = ACTIONS(6166),
    [aux_sym_boolean_token1] = ACTIONS(6164),
    [aux_sym_boolean_token2] = ACTIONS(6164),
    [sym_decimal] = ACTIONS(6164),
    [anon_sym_LPAREN] = ACTIONS(6166),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6164),
    [anon_sym_LBRACK] = ACTIONS(6166),
    [aux_sym_record_type_token1] = ACTIONS(6164),
    [aux_sym_basic_type_token21] = ACTIONS(6164),
    [aux_sym_basic_type_token22] = ACTIONS(6164),
    [aux_sym_basic_type_token48] = ACTIONS(6164),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6164),
    [anon_sym_POUNDif] = ACTIONS(6166),
    [anon_sym_POUNDIF] = ACTIONS(6166),
    [anon_sym_POUNDIf] = ACTIONS(6166),
    [anon_sym_not] = ACTIONS(6164),
    [anon_sym_NOT] = ACTIONS(6164),
    [anon_sym_Not] = ACTIONS(6164),
    [anon_sym_POUNDelse] = ACTIONS(6166),
    [anon_sym_POUNDELSE] = ACTIONS(6166),
    [anon_sym_POUNDElse] = ACTIONS(6166),
    [anon_sym_POUNDelse2] = ACTIONS(6166),
    [anon_sym_POUNDELSE2] = ACTIONS(6166),
    [anon_sym_POUNDElse2] = ACTIONS(6166),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6164),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6164),
    [anon_sym_PLUS] = ACTIONS(6166),
    [sym_datetime_literal] = ACTIONS(6166),
    [sym_date_literal] = ACTIONS(6164),
    [sym_time_literal] = ACTIONS(6164),
    [sym_biginteger_literal] = ACTIONS(6166),
    [anon_sym_if] = ACTIONS(6164),
    [anon_sym_IF] = ACTIONS(6164),
    [anon_sym_If] = ACTIONS(6164),
    [anon_sym_else] = ACTIONS(6164),
    [anon_sym_ELSE] = ACTIONS(6164),
    [anon_sym_Else] = ACTIONS(6164),
    [anon_sym_case] = ACTIONS(6164),
    [anon_sym_CASE] = ACTIONS(6164),
    [anon_sym_Case] = ACTIONS(6164),
    [anon_sym_for] = ACTIONS(6164),
    [anon_sym_FOR] = ACTIONS(6164),
    [anon_sym_For] = ACTIONS(6164),
    [anon_sym_foreach] = ACTIONS(6164),
    [anon_sym_FOREACH] = ACTIONS(6164),
    [anon_sym_Foreach] = ACTIONS(6164),
    [anon_sym_while] = ACTIONS(6164),
    [anon_sym_WHILE] = ACTIONS(6164),
    [anon_sym_While] = ACTIONS(6164),
    [anon_sym_repeat] = ACTIONS(6164),
    [anon_sym_REPEAT] = ACTIONS(6164),
    [anon_sym_Repeat] = ACTIONS(6164),
    [anon_sym_until] = ACTIONS(6164),
    [anon_sym_UNTIL] = ACTIONS(6164),
    [anon_sym_Until] = ACTIONS(6164),
    [anon_sym_exit] = ACTIONS(6164),
    [anon_sym_EXIT] = ACTIONS(6164),
    [anon_sym_Exit] = ACTIONS(6164),
    [anon_sym_continue] = ACTIONS(6164),
    [anon_sym_CONTINUE] = ACTIONS(6164),
    [anon_sym_Continue] = ACTIONS(6164),
    [anon_sym_break] = ACTIONS(6164),
    [anon_sym_BREAK] = ACTIONS(6164),
    [anon_sym_Break] = ACTIONS(6164),
    [anon_sym_with] = ACTIONS(6164),
    [anon_sym_WITH] = ACTIONS(6164),
    [anon_sym_With] = ACTIONS(6164),
    [sym_asserterror_keyword] = ACTIONS(6166),
    [sym_page_keyword] = ACTIONS(6164),
    [anon_sym_codeunit] = ACTIONS(6164),
    [anon_sym_CODEUNIT] = ACTIONS(6164),
    [anon_sym_Codeunit] = ACTIONS(6164),
    [anon_sym_CodeUnit] = ACTIONS(6164),
    [anon_sym_COdeunit] = ACTIONS(6164),
    [anon_sym_codeUnit] = ACTIONS(6164),
    [sym_report_keyword] = ACTIONS(6164),
    [sym_query_keyword] = ACTIONS(6164),
    [anon_sym_xmlport] = ACTIONS(6164),
    [anon_sym_XMLPORT] = ACTIONS(6164),
    [anon_sym_Xmlport] = ACTIONS(6164),
    [anon_sym_XMLport] = ACTIONS(6164),
    [anon_sym_XMLPort] = ACTIONS(6164),
    [anon_sym_XmlPort] = ACTIONS(6164),
    [anon_sym_enum] = ACTIONS(6164),
    [anon_sym_ENUM] = ACTIONS(6164),
    [anon_sym_Enum] = ACTIONS(6164),
    [anon_sym_eNUM] = ACTIONS(6164),
    [anon_sym_eNum] = ACTIONS(6164),
    [anon_sym_ENum] = ACTIONS(6164),
    [sym_quoted_identifier] = ACTIONS(6166),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6166),
    [sym_verbatim_string] = ACTIONS(6166),
    [sym_integer] = ACTIONS(6164),
    [sym_continue_as_identifier] = ACTIONS(6166),
    [sym_preproc_open] = ACTIONS(6166),
  },
  [STATE(3122)] = {
    [sym_identifier] = ACTIONS(6168),
    [anon_sym_SEMI] = ACTIONS(6170),
    [anon_sym_DASH] = ACTIONS(6170),
    [aux_sym_boolean_token1] = ACTIONS(6168),
    [aux_sym_boolean_token2] = ACTIONS(6168),
    [sym_decimal] = ACTIONS(6168),
    [anon_sym_LPAREN] = ACTIONS(6170),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6168),
    [anon_sym_LBRACK] = ACTIONS(6170),
    [aux_sym_record_type_token1] = ACTIONS(6168),
    [aux_sym_basic_type_token21] = ACTIONS(6168),
    [aux_sym_basic_type_token22] = ACTIONS(6168),
    [aux_sym_basic_type_token48] = ACTIONS(6168),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6168),
    [anon_sym_POUNDif] = ACTIONS(6170),
    [anon_sym_POUNDIF] = ACTIONS(6170),
    [anon_sym_POUNDIf] = ACTIONS(6170),
    [anon_sym_not] = ACTIONS(6168),
    [anon_sym_NOT] = ACTIONS(6168),
    [anon_sym_Not] = ACTIONS(6168),
    [anon_sym_POUNDelse] = ACTIONS(6170),
    [anon_sym_POUNDELSE] = ACTIONS(6170),
    [anon_sym_POUNDElse] = ACTIONS(6170),
    [anon_sym_POUNDelse2] = ACTIONS(6170),
    [anon_sym_POUNDELSE2] = ACTIONS(6170),
    [anon_sym_POUNDElse2] = ACTIONS(6170),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6168),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6168),
    [anon_sym_PLUS] = ACTIONS(6170),
    [sym_datetime_literal] = ACTIONS(6170),
    [sym_date_literal] = ACTIONS(6168),
    [sym_time_literal] = ACTIONS(6168),
    [sym_biginteger_literal] = ACTIONS(6170),
    [anon_sym_if] = ACTIONS(6168),
    [anon_sym_IF] = ACTIONS(6168),
    [anon_sym_If] = ACTIONS(6168),
    [anon_sym_else] = ACTIONS(6168),
    [anon_sym_ELSE] = ACTIONS(6168),
    [anon_sym_Else] = ACTIONS(6168),
    [anon_sym_case] = ACTIONS(6168),
    [anon_sym_CASE] = ACTIONS(6168),
    [anon_sym_Case] = ACTIONS(6168),
    [anon_sym_for] = ACTIONS(6168),
    [anon_sym_FOR] = ACTIONS(6168),
    [anon_sym_For] = ACTIONS(6168),
    [anon_sym_foreach] = ACTIONS(6168),
    [anon_sym_FOREACH] = ACTIONS(6168),
    [anon_sym_Foreach] = ACTIONS(6168),
    [anon_sym_while] = ACTIONS(6168),
    [anon_sym_WHILE] = ACTIONS(6168),
    [anon_sym_While] = ACTIONS(6168),
    [anon_sym_repeat] = ACTIONS(6168),
    [anon_sym_REPEAT] = ACTIONS(6168),
    [anon_sym_Repeat] = ACTIONS(6168),
    [anon_sym_until] = ACTIONS(6168),
    [anon_sym_UNTIL] = ACTIONS(6168),
    [anon_sym_Until] = ACTIONS(6168),
    [anon_sym_exit] = ACTIONS(6168),
    [anon_sym_EXIT] = ACTIONS(6168),
    [anon_sym_Exit] = ACTIONS(6168),
    [anon_sym_continue] = ACTIONS(6168),
    [anon_sym_CONTINUE] = ACTIONS(6168),
    [anon_sym_Continue] = ACTIONS(6168),
    [anon_sym_break] = ACTIONS(6168),
    [anon_sym_BREAK] = ACTIONS(6168),
    [anon_sym_Break] = ACTIONS(6168),
    [anon_sym_with] = ACTIONS(6168),
    [anon_sym_WITH] = ACTIONS(6168),
    [anon_sym_With] = ACTIONS(6168),
    [sym_asserterror_keyword] = ACTIONS(6170),
    [sym_page_keyword] = ACTIONS(6168),
    [anon_sym_codeunit] = ACTIONS(6168),
    [anon_sym_CODEUNIT] = ACTIONS(6168),
    [anon_sym_Codeunit] = ACTIONS(6168),
    [anon_sym_CodeUnit] = ACTIONS(6168),
    [anon_sym_COdeunit] = ACTIONS(6168),
    [anon_sym_codeUnit] = ACTIONS(6168),
    [sym_report_keyword] = ACTIONS(6168),
    [sym_query_keyword] = ACTIONS(6168),
    [anon_sym_xmlport] = ACTIONS(6168),
    [anon_sym_XMLPORT] = ACTIONS(6168),
    [anon_sym_Xmlport] = ACTIONS(6168),
    [anon_sym_XMLport] = ACTIONS(6168),
    [anon_sym_XMLPort] = ACTIONS(6168),
    [anon_sym_XmlPort] = ACTIONS(6168),
    [anon_sym_enum] = ACTIONS(6168),
    [anon_sym_ENUM] = ACTIONS(6168),
    [anon_sym_Enum] = ACTIONS(6168),
    [anon_sym_eNUM] = ACTIONS(6168),
    [anon_sym_eNum] = ACTIONS(6168),
    [anon_sym_ENum] = ACTIONS(6168),
    [sym_quoted_identifier] = ACTIONS(6170),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6170),
    [sym_verbatim_string] = ACTIONS(6170),
    [sym_integer] = ACTIONS(6168),
    [sym_continue_as_identifier] = ACTIONS(6170),
    [sym_preproc_open] = ACTIONS(6170),
  },
  [STATE(3123)] = {
    [sym_identifier] = ACTIONS(6172),
    [anon_sym_SEMI] = ACTIONS(6174),
    [anon_sym_DASH] = ACTIONS(6174),
    [aux_sym_boolean_token1] = ACTIONS(6172),
    [aux_sym_boolean_token2] = ACTIONS(6172),
    [sym_decimal] = ACTIONS(6172),
    [anon_sym_LPAREN] = ACTIONS(6174),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6172),
    [anon_sym_LBRACK] = ACTIONS(6174),
    [aux_sym_record_type_token1] = ACTIONS(6172),
    [aux_sym_basic_type_token21] = ACTIONS(6172),
    [aux_sym_basic_type_token22] = ACTIONS(6172),
    [aux_sym_basic_type_token48] = ACTIONS(6172),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6172),
    [anon_sym_POUNDif] = ACTIONS(6174),
    [anon_sym_POUNDIF] = ACTIONS(6174),
    [anon_sym_POUNDIf] = ACTIONS(6174),
    [anon_sym_not] = ACTIONS(6172),
    [anon_sym_NOT] = ACTIONS(6172),
    [anon_sym_Not] = ACTIONS(6172),
    [anon_sym_POUNDelse] = ACTIONS(6174),
    [anon_sym_POUNDELSE] = ACTIONS(6174),
    [anon_sym_POUNDElse] = ACTIONS(6174),
    [anon_sym_POUNDelse2] = ACTIONS(6174),
    [anon_sym_POUNDELSE2] = ACTIONS(6174),
    [anon_sym_POUNDElse2] = ACTIONS(6174),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6172),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6172),
    [anon_sym_PLUS] = ACTIONS(6174),
    [sym_datetime_literal] = ACTIONS(6174),
    [sym_date_literal] = ACTIONS(6172),
    [sym_time_literal] = ACTIONS(6172),
    [sym_biginteger_literal] = ACTIONS(6174),
    [anon_sym_if] = ACTIONS(6172),
    [anon_sym_IF] = ACTIONS(6172),
    [anon_sym_If] = ACTIONS(6172),
    [anon_sym_else] = ACTIONS(6172),
    [anon_sym_ELSE] = ACTIONS(6172),
    [anon_sym_Else] = ACTIONS(6172),
    [anon_sym_case] = ACTIONS(6172),
    [anon_sym_CASE] = ACTIONS(6172),
    [anon_sym_Case] = ACTIONS(6172),
    [anon_sym_for] = ACTIONS(6172),
    [anon_sym_FOR] = ACTIONS(6172),
    [anon_sym_For] = ACTIONS(6172),
    [anon_sym_foreach] = ACTIONS(6172),
    [anon_sym_FOREACH] = ACTIONS(6172),
    [anon_sym_Foreach] = ACTIONS(6172),
    [anon_sym_while] = ACTIONS(6172),
    [anon_sym_WHILE] = ACTIONS(6172),
    [anon_sym_While] = ACTIONS(6172),
    [anon_sym_repeat] = ACTIONS(6172),
    [anon_sym_REPEAT] = ACTIONS(6172),
    [anon_sym_Repeat] = ACTIONS(6172),
    [anon_sym_until] = ACTIONS(6172),
    [anon_sym_UNTIL] = ACTIONS(6172),
    [anon_sym_Until] = ACTIONS(6172),
    [anon_sym_exit] = ACTIONS(6172),
    [anon_sym_EXIT] = ACTIONS(6172),
    [anon_sym_Exit] = ACTIONS(6172),
    [anon_sym_continue] = ACTIONS(6172),
    [anon_sym_CONTINUE] = ACTIONS(6172),
    [anon_sym_Continue] = ACTIONS(6172),
    [anon_sym_break] = ACTIONS(6172),
    [anon_sym_BREAK] = ACTIONS(6172),
    [anon_sym_Break] = ACTIONS(6172),
    [anon_sym_with] = ACTIONS(6172),
    [anon_sym_WITH] = ACTIONS(6172),
    [anon_sym_With] = ACTIONS(6172),
    [sym_asserterror_keyword] = ACTIONS(6174),
    [sym_page_keyword] = ACTIONS(6172),
    [anon_sym_codeunit] = ACTIONS(6172),
    [anon_sym_CODEUNIT] = ACTIONS(6172),
    [anon_sym_Codeunit] = ACTIONS(6172),
    [anon_sym_CodeUnit] = ACTIONS(6172),
    [anon_sym_COdeunit] = ACTIONS(6172),
    [anon_sym_codeUnit] = ACTIONS(6172),
    [sym_report_keyword] = ACTIONS(6172),
    [sym_query_keyword] = ACTIONS(6172),
    [anon_sym_xmlport] = ACTIONS(6172),
    [anon_sym_XMLPORT] = ACTIONS(6172),
    [anon_sym_Xmlport] = ACTIONS(6172),
    [anon_sym_XMLport] = ACTIONS(6172),
    [anon_sym_XMLPort] = ACTIONS(6172),
    [anon_sym_XmlPort] = ACTIONS(6172),
    [anon_sym_enum] = ACTIONS(6172),
    [anon_sym_ENUM] = ACTIONS(6172),
    [anon_sym_Enum] = ACTIONS(6172),
    [anon_sym_eNUM] = ACTIONS(6172),
    [anon_sym_eNum] = ACTIONS(6172),
    [anon_sym_ENum] = ACTIONS(6172),
    [sym_quoted_identifier] = ACTIONS(6174),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6174),
    [sym_verbatim_string] = ACTIONS(6174),
    [sym_integer] = ACTIONS(6172),
    [sym_continue_as_identifier] = ACTIONS(6174),
    [sym_preproc_open] = ACTIONS(6174),
  },
  [STATE(3124)] = {
    [sym_identifier] = ACTIONS(6176),
    [anon_sym_SEMI] = ACTIONS(6178),
    [anon_sym_DASH] = ACTIONS(6178),
    [aux_sym_boolean_token1] = ACTIONS(6176),
    [aux_sym_boolean_token2] = ACTIONS(6176),
    [sym_decimal] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6178),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6176),
    [anon_sym_LBRACK] = ACTIONS(6178),
    [aux_sym_record_type_token1] = ACTIONS(6176),
    [aux_sym_basic_type_token21] = ACTIONS(6176),
    [aux_sym_basic_type_token22] = ACTIONS(6176),
    [aux_sym_basic_type_token48] = ACTIONS(6176),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6176),
    [anon_sym_POUNDif] = ACTIONS(6178),
    [anon_sym_POUNDIF] = ACTIONS(6178),
    [anon_sym_POUNDIf] = ACTIONS(6178),
    [anon_sym_not] = ACTIONS(6176),
    [anon_sym_NOT] = ACTIONS(6176),
    [anon_sym_Not] = ACTIONS(6176),
    [anon_sym_POUNDelse] = ACTIONS(6178),
    [anon_sym_POUNDELSE] = ACTIONS(6178),
    [anon_sym_POUNDElse] = ACTIONS(6178),
    [anon_sym_POUNDelse2] = ACTIONS(6178),
    [anon_sym_POUNDELSE2] = ACTIONS(6178),
    [anon_sym_POUNDElse2] = ACTIONS(6178),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6176),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6176),
    [anon_sym_PLUS] = ACTIONS(6178),
    [sym_datetime_literal] = ACTIONS(6178),
    [sym_date_literal] = ACTIONS(6176),
    [sym_time_literal] = ACTIONS(6176),
    [sym_biginteger_literal] = ACTIONS(6178),
    [anon_sym_if] = ACTIONS(6176),
    [anon_sym_IF] = ACTIONS(6176),
    [anon_sym_If] = ACTIONS(6176),
    [anon_sym_else] = ACTIONS(6176),
    [anon_sym_ELSE] = ACTIONS(6176),
    [anon_sym_Else] = ACTIONS(6176),
    [anon_sym_case] = ACTIONS(6176),
    [anon_sym_CASE] = ACTIONS(6176),
    [anon_sym_Case] = ACTIONS(6176),
    [anon_sym_for] = ACTIONS(6176),
    [anon_sym_FOR] = ACTIONS(6176),
    [anon_sym_For] = ACTIONS(6176),
    [anon_sym_foreach] = ACTIONS(6176),
    [anon_sym_FOREACH] = ACTIONS(6176),
    [anon_sym_Foreach] = ACTIONS(6176),
    [anon_sym_while] = ACTIONS(6176),
    [anon_sym_WHILE] = ACTIONS(6176),
    [anon_sym_While] = ACTIONS(6176),
    [anon_sym_repeat] = ACTIONS(6176),
    [anon_sym_REPEAT] = ACTIONS(6176),
    [anon_sym_Repeat] = ACTIONS(6176),
    [anon_sym_until] = ACTIONS(6176),
    [anon_sym_UNTIL] = ACTIONS(6176),
    [anon_sym_Until] = ACTIONS(6176),
    [anon_sym_exit] = ACTIONS(6176),
    [anon_sym_EXIT] = ACTIONS(6176),
    [anon_sym_Exit] = ACTIONS(6176),
    [anon_sym_continue] = ACTIONS(6176),
    [anon_sym_CONTINUE] = ACTIONS(6176),
    [anon_sym_Continue] = ACTIONS(6176),
    [anon_sym_break] = ACTIONS(6176),
    [anon_sym_BREAK] = ACTIONS(6176),
    [anon_sym_Break] = ACTIONS(6176),
    [anon_sym_with] = ACTIONS(6176),
    [anon_sym_WITH] = ACTIONS(6176),
    [anon_sym_With] = ACTIONS(6176),
    [sym_asserterror_keyword] = ACTIONS(6178),
    [sym_page_keyword] = ACTIONS(6176),
    [anon_sym_codeunit] = ACTIONS(6176),
    [anon_sym_CODEUNIT] = ACTIONS(6176),
    [anon_sym_Codeunit] = ACTIONS(6176),
    [anon_sym_CodeUnit] = ACTIONS(6176),
    [anon_sym_COdeunit] = ACTIONS(6176),
    [anon_sym_codeUnit] = ACTIONS(6176),
    [sym_report_keyword] = ACTIONS(6176),
    [sym_query_keyword] = ACTIONS(6176),
    [anon_sym_xmlport] = ACTIONS(6176),
    [anon_sym_XMLPORT] = ACTIONS(6176),
    [anon_sym_Xmlport] = ACTIONS(6176),
    [anon_sym_XMLport] = ACTIONS(6176),
    [anon_sym_XMLPort] = ACTIONS(6176),
    [anon_sym_XmlPort] = ACTIONS(6176),
    [anon_sym_enum] = ACTIONS(6176),
    [anon_sym_ENUM] = ACTIONS(6176),
    [anon_sym_Enum] = ACTIONS(6176),
    [anon_sym_eNUM] = ACTIONS(6176),
    [anon_sym_eNum] = ACTIONS(6176),
    [anon_sym_ENum] = ACTIONS(6176),
    [sym_quoted_identifier] = ACTIONS(6178),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6178),
    [sym_verbatim_string] = ACTIONS(6178),
    [sym_integer] = ACTIONS(6176),
    [sym_continue_as_identifier] = ACTIONS(6178),
    [sym_preproc_open] = ACTIONS(6178),
  },
  [STATE(3125)] = {
    [sym_identifier] = ACTIONS(6180),
    [anon_sym_SEMI] = ACTIONS(6182),
    [anon_sym_DASH] = ACTIONS(6182),
    [aux_sym_boolean_token1] = ACTIONS(6180),
    [aux_sym_boolean_token2] = ACTIONS(6180),
    [sym_decimal] = ACTIONS(6180),
    [anon_sym_LPAREN] = ACTIONS(6182),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6180),
    [anon_sym_LBRACK] = ACTIONS(6182),
    [aux_sym_record_type_token1] = ACTIONS(6180),
    [aux_sym_basic_type_token21] = ACTIONS(6180),
    [aux_sym_basic_type_token22] = ACTIONS(6180),
    [aux_sym_basic_type_token48] = ACTIONS(6180),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6180),
    [anon_sym_POUNDif] = ACTIONS(6182),
    [anon_sym_POUNDIF] = ACTIONS(6182),
    [anon_sym_POUNDIf] = ACTIONS(6182),
    [anon_sym_not] = ACTIONS(6180),
    [anon_sym_NOT] = ACTIONS(6180),
    [anon_sym_Not] = ACTIONS(6180),
    [anon_sym_POUNDelse] = ACTIONS(6182),
    [anon_sym_POUNDELSE] = ACTIONS(6182),
    [anon_sym_POUNDElse] = ACTIONS(6182),
    [anon_sym_POUNDelse2] = ACTIONS(6182),
    [anon_sym_POUNDELSE2] = ACTIONS(6182),
    [anon_sym_POUNDElse2] = ACTIONS(6182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6180),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6180),
    [anon_sym_PLUS] = ACTIONS(6182),
    [sym_datetime_literal] = ACTIONS(6182),
    [sym_date_literal] = ACTIONS(6180),
    [sym_time_literal] = ACTIONS(6180),
    [sym_biginteger_literal] = ACTIONS(6182),
    [anon_sym_if] = ACTIONS(6180),
    [anon_sym_IF] = ACTIONS(6180),
    [anon_sym_If] = ACTIONS(6180),
    [anon_sym_else] = ACTIONS(6180),
    [anon_sym_ELSE] = ACTIONS(6180),
    [anon_sym_Else] = ACTIONS(6180),
    [anon_sym_case] = ACTIONS(6180),
    [anon_sym_CASE] = ACTIONS(6180),
    [anon_sym_Case] = ACTIONS(6180),
    [anon_sym_for] = ACTIONS(6180),
    [anon_sym_FOR] = ACTIONS(6180),
    [anon_sym_For] = ACTIONS(6180),
    [anon_sym_foreach] = ACTIONS(6180),
    [anon_sym_FOREACH] = ACTIONS(6180),
    [anon_sym_Foreach] = ACTIONS(6180),
    [anon_sym_while] = ACTIONS(6180),
    [anon_sym_WHILE] = ACTIONS(6180),
    [anon_sym_While] = ACTIONS(6180),
    [anon_sym_repeat] = ACTIONS(6180),
    [anon_sym_REPEAT] = ACTIONS(6180),
    [anon_sym_Repeat] = ACTIONS(6180),
    [anon_sym_until] = ACTIONS(6180),
    [anon_sym_UNTIL] = ACTIONS(6180),
    [anon_sym_Until] = ACTIONS(6180),
    [anon_sym_exit] = ACTIONS(6180),
    [anon_sym_EXIT] = ACTIONS(6180),
    [anon_sym_Exit] = ACTIONS(6180),
    [anon_sym_continue] = ACTIONS(6180),
    [anon_sym_CONTINUE] = ACTIONS(6180),
    [anon_sym_Continue] = ACTIONS(6180),
    [anon_sym_break] = ACTIONS(6180),
    [anon_sym_BREAK] = ACTIONS(6180),
    [anon_sym_Break] = ACTIONS(6180),
    [anon_sym_with] = ACTIONS(6180),
    [anon_sym_WITH] = ACTIONS(6180),
    [anon_sym_With] = ACTIONS(6180),
    [sym_asserterror_keyword] = ACTIONS(6182),
    [sym_page_keyword] = ACTIONS(6180),
    [anon_sym_codeunit] = ACTIONS(6180),
    [anon_sym_CODEUNIT] = ACTIONS(6180),
    [anon_sym_Codeunit] = ACTIONS(6180),
    [anon_sym_CodeUnit] = ACTIONS(6180),
    [anon_sym_COdeunit] = ACTIONS(6180),
    [anon_sym_codeUnit] = ACTIONS(6180),
    [sym_report_keyword] = ACTIONS(6180),
    [sym_query_keyword] = ACTIONS(6180),
    [anon_sym_xmlport] = ACTIONS(6180),
    [anon_sym_XMLPORT] = ACTIONS(6180),
    [anon_sym_Xmlport] = ACTIONS(6180),
    [anon_sym_XMLport] = ACTIONS(6180),
    [anon_sym_XMLPort] = ACTIONS(6180),
    [anon_sym_XmlPort] = ACTIONS(6180),
    [anon_sym_enum] = ACTIONS(6180),
    [anon_sym_ENUM] = ACTIONS(6180),
    [anon_sym_Enum] = ACTIONS(6180),
    [anon_sym_eNUM] = ACTIONS(6180),
    [anon_sym_eNum] = ACTIONS(6180),
    [anon_sym_ENum] = ACTIONS(6180),
    [sym_quoted_identifier] = ACTIONS(6182),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6182),
    [sym_verbatim_string] = ACTIONS(6182),
    [sym_integer] = ACTIONS(6180),
    [sym_continue_as_identifier] = ACTIONS(6182),
    [sym_preproc_open] = ACTIONS(6182),
  },
  [STATE(3126)] = {
    [sym_identifier] = ACTIONS(6184),
    [anon_sym_SEMI] = ACTIONS(6186),
    [anon_sym_DASH] = ACTIONS(6186),
    [aux_sym_boolean_token1] = ACTIONS(6184),
    [aux_sym_boolean_token2] = ACTIONS(6184),
    [sym_decimal] = ACTIONS(6184),
    [anon_sym_LPAREN] = ACTIONS(6186),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6184),
    [anon_sym_LBRACK] = ACTIONS(6186),
    [aux_sym_record_type_token1] = ACTIONS(6184),
    [aux_sym_basic_type_token21] = ACTIONS(6184),
    [aux_sym_basic_type_token22] = ACTIONS(6184),
    [aux_sym_basic_type_token48] = ACTIONS(6184),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6184),
    [anon_sym_POUNDif] = ACTIONS(6186),
    [anon_sym_POUNDIF] = ACTIONS(6186),
    [anon_sym_POUNDIf] = ACTIONS(6186),
    [anon_sym_not] = ACTIONS(6184),
    [anon_sym_NOT] = ACTIONS(6184),
    [anon_sym_Not] = ACTIONS(6184),
    [anon_sym_POUNDelse] = ACTIONS(6186),
    [anon_sym_POUNDELSE] = ACTIONS(6186),
    [anon_sym_POUNDElse] = ACTIONS(6186),
    [anon_sym_POUNDelse2] = ACTIONS(6186),
    [anon_sym_POUNDELSE2] = ACTIONS(6186),
    [anon_sym_POUNDElse2] = ACTIONS(6186),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6184),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6184),
    [anon_sym_PLUS] = ACTIONS(6186),
    [sym_datetime_literal] = ACTIONS(6186),
    [sym_date_literal] = ACTIONS(6184),
    [sym_time_literal] = ACTIONS(6184),
    [sym_biginteger_literal] = ACTIONS(6186),
    [anon_sym_if] = ACTIONS(6184),
    [anon_sym_IF] = ACTIONS(6184),
    [anon_sym_If] = ACTIONS(6184),
    [anon_sym_else] = ACTIONS(6184),
    [anon_sym_ELSE] = ACTIONS(6184),
    [anon_sym_Else] = ACTIONS(6184),
    [anon_sym_case] = ACTIONS(6184),
    [anon_sym_CASE] = ACTIONS(6184),
    [anon_sym_Case] = ACTIONS(6184),
    [anon_sym_for] = ACTIONS(6184),
    [anon_sym_FOR] = ACTIONS(6184),
    [anon_sym_For] = ACTIONS(6184),
    [anon_sym_foreach] = ACTIONS(6184),
    [anon_sym_FOREACH] = ACTIONS(6184),
    [anon_sym_Foreach] = ACTIONS(6184),
    [anon_sym_while] = ACTIONS(6184),
    [anon_sym_WHILE] = ACTIONS(6184),
    [anon_sym_While] = ACTIONS(6184),
    [anon_sym_repeat] = ACTIONS(6184),
    [anon_sym_REPEAT] = ACTIONS(6184),
    [anon_sym_Repeat] = ACTIONS(6184),
    [anon_sym_until] = ACTIONS(6184),
    [anon_sym_UNTIL] = ACTIONS(6184),
    [anon_sym_Until] = ACTIONS(6184),
    [anon_sym_exit] = ACTIONS(6184),
    [anon_sym_EXIT] = ACTIONS(6184),
    [anon_sym_Exit] = ACTIONS(6184),
    [anon_sym_continue] = ACTIONS(6184),
    [anon_sym_CONTINUE] = ACTIONS(6184),
    [anon_sym_Continue] = ACTIONS(6184),
    [anon_sym_break] = ACTIONS(6184),
    [anon_sym_BREAK] = ACTIONS(6184),
    [anon_sym_Break] = ACTIONS(6184),
    [anon_sym_with] = ACTIONS(6184),
    [anon_sym_WITH] = ACTIONS(6184),
    [anon_sym_With] = ACTIONS(6184),
    [sym_asserterror_keyword] = ACTIONS(6186),
    [sym_page_keyword] = ACTIONS(6184),
    [anon_sym_codeunit] = ACTIONS(6184),
    [anon_sym_CODEUNIT] = ACTIONS(6184),
    [anon_sym_Codeunit] = ACTIONS(6184),
    [anon_sym_CodeUnit] = ACTIONS(6184),
    [anon_sym_COdeunit] = ACTIONS(6184),
    [anon_sym_codeUnit] = ACTIONS(6184),
    [sym_report_keyword] = ACTIONS(6184),
    [sym_query_keyword] = ACTIONS(6184),
    [anon_sym_xmlport] = ACTIONS(6184),
    [anon_sym_XMLPORT] = ACTIONS(6184),
    [anon_sym_Xmlport] = ACTIONS(6184),
    [anon_sym_XMLport] = ACTIONS(6184),
    [anon_sym_XMLPort] = ACTIONS(6184),
    [anon_sym_XmlPort] = ACTIONS(6184),
    [anon_sym_enum] = ACTIONS(6184),
    [anon_sym_ENUM] = ACTIONS(6184),
    [anon_sym_Enum] = ACTIONS(6184),
    [anon_sym_eNUM] = ACTIONS(6184),
    [anon_sym_eNum] = ACTIONS(6184),
    [anon_sym_ENum] = ACTIONS(6184),
    [sym_quoted_identifier] = ACTIONS(6186),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6186),
    [sym_verbatim_string] = ACTIONS(6186),
    [sym_integer] = ACTIONS(6184),
    [sym_continue_as_identifier] = ACTIONS(6186),
    [sym_preproc_open] = ACTIONS(6186),
  },
  [STATE(3127)] = {
    [sym_identifier] = ACTIONS(6188),
    [anon_sym_SEMI] = ACTIONS(6190),
    [anon_sym_DASH] = ACTIONS(6190),
    [aux_sym_boolean_token1] = ACTIONS(6188),
    [aux_sym_boolean_token2] = ACTIONS(6188),
    [sym_decimal] = ACTIONS(6188),
    [anon_sym_LPAREN] = ACTIONS(6190),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6188),
    [anon_sym_LBRACK] = ACTIONS(6190),
    [aux_sym_record_type_token1] = ACTIONS(6188),
    [aux_sym_basic_type_token21] = ACTIONS(6188),
    [aux_sym_basic_type_token22] = ACTIONS(6188),
    [aux_sym_basic_type_token48] = ACTIONS(6188),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6188),
    [anon_sym_POUNDif] = ACTIONS(6190),
    [anon_sym_POUNDIF] = ACTIONS(6190),
    [anon_sym_POUNDIf] = ACTIONS(6190),
    [anon_sym_not] = ACTIONS(6188),
    [anon_sym_NOT] = ACTIONS(6188),
    [anon_sym_Not] = ACTIONS(6188),
    [anon_sym_POUNDelse] = ACTIONS(6190),
    [anon_sym_POUNDELSE] = ACTIONS(6190),
    [anon_sym_POUNDElse] = ACTIONS(6190),
    [anon_sym_POUNDelse2] = ACTIONS(6190),
    [anon_sym_POUNDELSE2] = ACTIONS(6190),
    [anon_sym_POUNDElse2] = ACTIONS(6190),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6188),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6188),
    [anon_sym_PLUS] = ACTIONS(6190),
    [sym_datetime_literal] = ACTIONS(6190),
    [sym_date_literal] = ACTIONS(6188),
    [sym_time_literal] = ACTIONS(6188),
    [sym_biginteger_literal] = ACTIONS(6190),
    [anon_sym_if] = ACTIONS(6188),
    [anon_sym_IF] = ACTIONS(6188),
    [anon_sym_If] = ACTIONS(6188),
    [anon_sym_else] = ACTIONS(6188),
    [anon_sym_ELSE] = ACTIONS(6188),
    [anon_sym_Else] = ACTIONS(6188),
    [anon_sym_case] = ACTIONS(6188),
    [anon_sym_CASE] = ACTIONS(6188),
    [anon_sym_Case] = ACTIONS(6188),
    [anon_sym_for] = ACTIONS(6188),
    [anon_sym_FOR] = ACTIONS(6188),
    [anon_sym_For] = ACTIONS(6188),
    [anon_sym_foreach] = ACTIONS(6188),
    [anon_sym_FOREACH] = ACTIONS(6188),
    [anon_sym_Foreach] = ACTIONS(6188),
    [anon_sym_while] = ACTIONS(6188),
    [anon_sym_WHILE] = ACTIONS(6188),
    [anon_sym_While] = ACTIONS(6188),
    [anon_sym_repeat] = ACTIONS(6188),
    [anon_sym_REPEAT] = ACTIONS(6188),
    [anon_sym_Repeat] = ACTIONS(6188),
    [anon_sym_until] = ACTIONS(6188),
    [anon_sym_UNTIL] = ACTIONS(6188),
    [anon_sym_Until] = ACTIONS(6188),
    [anon_sym_exit] = ACTIONS(6188),
    [anon_sym_EXIT] = ACTIONS(6188),
    [anon_sym_Exit] = ACTIONS(6188),
    [anon_sym_continue] = ACTIONS(6188),
    [anon_sym_CONTINUE] = ACTIONS(6188),
    [anon_sym_Continue] = ACTIONS(6188),
    [anon_sym_break] = ACTIONS(6188),
    [anon_sym_BREAK] = ACTIONS(6188),
    [anon_sym_Break] = ACTIONS(6188),
    [anon_sym_with] = ACTIONS(6188),
    [anon_sym_WITH] = ACTIONS(6188),
    [anon_sym_With] = ACTIONS(6188),
    [sym_asserterror_keyword] = ACTIONS(6190),
    [sym_page_keyword] = ACTIONS(6188),
    [anon_sym_codeunit] = ACTIONS(6188),
    [anon_sym_CODEUNIT] = ACTIONS(6188),
    [anon_sym_Codeunit] = ACTIONS(6188),
    [anon_sym_CodeUnit] = ACTIONS(6188),
    [anon_sym_COdeunit] = ACTIONS(6188),
    [anon_sym_codeUnit] = ACTIONS(6188),
    [sym_report_keyword] = ACTIONS(6188),
    [sym_query_keyword] = ACTIONS(6188),
    [anon_sym_xmlport] = ACTIONS(6188),
    [anon_sym_XMLPORT] = ACTIONS(6188),
    [anon_sym_Xmlport] = ACTIONS(6188),
    [anon_sym_XMLport] = ACTIONS(6188),
    [anon_sym_XMLPort] = ACTIONS(6188),
    [anon_sym_XmlPort] = ACTIONS(6188),
    [anon_sym_enum] = ACTIONS(6188),
    [anon_sym_ENUM] = ACTIONS(6188),
    [anon_sym_Enum] = ACTIONS(6188),
    [anon_sym_eNUM] = ACTIONS(6188),
    [anon_sym_eNum] = ACTIONS(6188),
    [anon_sym_ENum] = ACTIONS(6188),
    [sym_quoted_identifier] = ACTIONS(6190),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6190),
    [sym_verbatim_string] = ACTIONS(6190),
    [sym_integer] = ACTIONS(6188),
    [sym_continue_as_identifier] = ACTIONS(6190),
    [sym_preproc_open] = ACTIONS(6190),
  },
  [STATE(3128)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [anon_sym_DASH] = ACTIONS(6194),
    [aux_sym_boolean_token1] = ACTIONS(6192),
    [aux_sym_boolean_token2] = ACTIONS(6192),
    [sym_decimal] = ACTIONS(6192),
    [anon_sym_LPAREN] = ACTIONS(6194),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [aux_sym_record_type_token1] = ACTIONS(6192),
    [aux_sym_basic_type_token21] = ACTIONS(6192),
    [aux_sym_basic_type_token22] = ACTIONS(6192),
    [aux_sym_basic_type_token48] = ACTIONS(6192),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6192),
    [anon_sym_POUNDif] = ACTIONS(6194),
    [anon_sym_POUNDIF] = ACTIONS(6194),
    [anon_sym_POUNDIf] = ACTIONS(6194),
    [anon_sym_not] = ACTIONS(6192),
    [anon_sym_NOT] = ACTIONS(6192),
    [anon_sym_Not] = ACTIONS(6192),
    [anon_sym_POUNDelse] = ACTIONS(6194),
    [anon_sym_POUNDELSE] = ACTIONS(6194),
    [anon_sym_POUNDElse] = ACTIONS(6194),
    [anon_sym_POUNDelse2] = ACTIONS(6194),
    [anon_sym_POUNDELSE2] = ACTIONS(6194),
    [anon_sym_POUNDElse2] = ACTIONS(6194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6192),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6192),
    [anon_sym_PLUS] = ACTIONS(6194),
    [sym_datetime_literal] = ACTIONS(6194),
    [sym_date_literal] = ACTIONS(6192),
    [sym_time_literal] = ACTIONS(6192),
    [sym_biginteger_literal] = ACTIONS(6194),
    [anon_sym_if] = ACTIONS(6192),
    [anon_sym_IF] = ACTIONS(6192),
    [anon_sym_If] = ACTIONS(6192),
    [anon_sym_else] = ACTIONS(6192),
    [anon_sym_ELSE] = ACTIONS(6192),
    [anon_sym_Else] = ACTIONS(6192),
    [anon_sym_case] = ACTIONS(6192),
    [anon_sym_CASE] = ACTIONS(6192),
    [anon_sym_Case] = ACTIONS(6192),
    [anon_sym_for] = ACTIONS(6192),
    [anon_sym_FOR] = ACTIONS(6192),
    [anon_sym_For] = ACTIONS(6192),
    [anon_sym_foreach] = ACTIONS(6192),
    [anon_sym_FOREACH] = ACTIONS(6192),
    [anon_sym_Foreach] = ACTIONS(6192),
    [anon_sym_while] = ACTIONS(6192),
    [anon_sym_WHILE] = ACTIONS(6192),
    [anon_sym_While] = ACTIONS(6192),
    [anon_sym_repeat] = ACTIONS(6192),
    [anon_sym_REPEAT] = ACTIONS(6192),
    [anon_sym_Repeat] = ACTIONS(6192),
    [anon_sym_until] = ACTIONS(6192),
    [anon_sym_UNTIL] = ACTIONS(6192),
    [anon_sym_Until] = ACTIONS(6192),
    [anon_sym_exit] = ACTIONS(6192),
    [anon_sym_EXIT] = ACTIONS(6192),
    [anon_sym_Exit] = ACTIONS(6192),
    [anon_sym_continue] = ACTIONS(6192),
    [anon_sym_CONTINUE] = ACTIONS(6192),
    [anon_sym_Continue] = ACTIONS(6192),
    [anon_sym_break] = ACTIONS(6192),
    [anon_sym_BREAK] = ACTIONS(6192),
    [anon_sym_Break] = ACTIONS(6192),
    [anon_sym_with] = ACTIONS(6192),
    [anon_sym_WITH] = ACTIONS(6192),
    [anon_sym_With] = ACTIONS(6192),
    [sym_asserterror_keyword] = ACTIONS(6194),
    [sym_page_keyword] = ACTIONS(6192),
    [anon_sym_codeunit] = ACTIONS(6192),
    [anon_sym_CODEUNIT] = ACTIONS(6192),
    [anon_sym_Codeunit] = ACTIONS(6192),
    [anon_sym_CodeUnit] = ACTIONS(6192),
    [anon_sym_COdeunit] = ACTIONS(6192),
    [anon_sym_codeUnit] = ACTIONS(6192),
    [sym_report_keyword] = ACTIONS(6192),
    [sym_query_keyword] = ACTIONS(6192),
    [anon_sym_xmlport] = ACTIONS(6192),
    [anon_sym_XMLPORT] = ACTIONS(6192),
    [anon_sym_Xmlport] = ACTIONS(6192),
    [anon_sym_XMLport] = ACTIONS(6192),
    [anon_sym_XMLPort] = ACTIONS(6192),
    [anon_sym_XmlPort] = ACTIONS(6192),
    [anon_sym_enum] = ACTIONS(6192),
    [anon_sym_ENUM] = ACTIONS(6192),
    [anon_sym_Enum] = ACTIONS(6192),
    [anon_sym_eNUM] = ACTIONS(6192),
    [anon_sym_eNum] = ACTIONS(6192),
    [anon_sym_ENum] = ACTIONS(6192),
    [sym_quoted_identifier] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6194),
    [sym_verbatim_string] = ACTIONS(6194),
    [sym_integer] = ACTIONS(6192),
    [sym_continue_as_identifier] = ACTIONS(6194),
    [sym_preproc_open] = ACTIONS(6194),
  },
  [STATE(3129)] = {
    [sym_identifier] = ACTIONS(5973),
    [anon_sym_SEMI] = ACTIONS(5975),
    [anon_sym_DASH] = ACTIONS(5975),
    [aux_sym_boolean_token1] = ACTIONS(5973),
    [aux_sym_boolean_token2] = ACTIONS(5973),
    [sym_decimal] = ACTIONS(5973),
    [anon_sym_LPAREN] = ACTIONS(5975),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5973),
    [anon_sym_LBRACK] = ACTIONS(5975),
    [aux_sym_record_type_token1] = ACTIONS(5973),
    [aux_sym_basic_type_token21] = ACTIONS(5973),
    [aux_sym_basic_type_token22] = ACTIONS(5973),
    [aux_sym_basic_type_token48] = ACTIONS(5973),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5973),
    [anon_sym_POUNDif] = ACTIONS(5975),
    [anon_sym_POUNDIF] = ACTIONS(5975),
    [anon_sym_POUNDIf] = ACTIONS(5975),
    [anon_sym_not] = ACTIONS(5973),
    [anon_sym_NOT] = ACTIONS(5973),
    [anon_sym_Not] = ACTIONS(5973),
    [anon_sym_POUNDelse] = ACTIONS(5975),
    [anon_sym_POUNDELSE] = ACTIONS(5975),
    [anon_sym_POUNDElse] = ACTIONS(5975),
    [anon_sym_POUNDelse2] = ACTIONS(5975),
    [anon_sym_POUNDELSE2] = ACTIONS(5975),
    [anon_sym_POUNDElse2] = ACTIONS(5975),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5973),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5973),
    [anon_sym_PLUS] = ACTIONS(5975),
    [sym_datetime_literal] = ACTIONS(5975),
    [sym_date_literal] = ACTIONS(5973),
    [sym_time_literal] = ACTIONS(5973),
    [sym_biginteger_literal] = ACTIONS(5975),
    [anon_sym_if] = ACTIONS(5973),
    [anon_sym_IF] = ACTIONS(5973),
    [anon_sym_If] = ACTIONS(5973),
    [anon_sym_else] = ACTIONS(5973),
    [anon_sym_ELSE] = ACTIONS(5973),
    [anon_sym_Else] = ACTIONS(5973),
    [anon_sym_case] = ACTIONS(5973),
    [anon_sym_CASE] = ACTIONS(5973),
    [anon_sym_Case] = ACTIONS(5973),
    [anon_sym_for] = ACTIONS(5973),
    [anon_sym_FOR] = ACTIONS(5973),
    [anon_sym_For] = ACTIONS(5973),
    [anon_sym_foreach] = ACTIONS(5973),
    [anon_sym_FOREACH] = ACTIONS(5973),
    [anon_sym_Foreach] = ACTIONS(5973),
    [anon_sym_while] = ACTIONS(5973),
    [anon_sym_WHILE] = ACTIONS(5973),
    [anon_sym_While] = ACTIONS(5973),
    [anon_sym_repeat] = ACTIONS(5973),
    [anon_sym_REPEAT] = ACTIONS(5973),
    [anon_sym_Repeat] = ACTIONS(5973),
    [anon_sym_until] = ACTIONS(5973),
    [anon_sym_UNTIL] = ACTIONS(5973),
    [anon_sym_Until] = ACTIONS(5973),
    [anon_sym_exit] = ACTIONS(5973),
    [anon_sym_EXIT] = ACTIONS(5973),
    [anon_sym_Exit] = ACTIONS(5973),
    [anon_sym_continue] = ACTIONS(5973),
    [anon_sym_CONTINUE] = ACTIONS(5973),
    [anon_sym_Continue] = ACTIONS(5973),
    [anon_sym_break] = ACTIONS(5973),
    [anon_sym_BREAK] = ACTIONS(5973),
    [anon_sym_Break] = ACTIONS(5973),
    [anon_sym_with] = ACTIONS(5973),
    [anon_sym_WITH] = ACTIONS(5973),
    [anon_sym_With] = ACTIONS(5973),
    [sym_asserterror_keyword] = ACTIONS(5975),
    [sym_page_keyword] = ACTIONS(5973),
    [anon_sym_codeunit] = ACTIONS(5973),
    [anon_sym_CODEUNIT] = ACTIONS(5973),
    [anon_sym_Codeunit] = ACTIONS(5973),
    [anon_sym_CodeUnit] = ACTIONS(5973),
    [anon_sym_COdeunit] = ACTIONS(5973),
    [anon_sym_codeUnit] = ACTIONS(5973),
    [sym_report_keyword] = ACTIONS(5973),
    [sym_query_keyword] = ACTIONS(5973),
    [anon_sym_xmlport] = ACTIONS(5973),
    [anon_sym_XMLPORT] = ACTIONS(5973),
    [anon_sym_Xmlport] = ACTIONS(5973),
    [anon_sym_XMLport] = ACTIONS(5973),
    [anon_sym_XMLPort] = ACTIONS(5973),
    [anon_sym_XmlPort] = ACTIONS(5973),
    [anon_sym_enum] = ACTIONS(5973),
    [anon_sym_ENUM] = ACTIONS(5973),
    [anon_sym_Enum] = ACTIONS(5973),
    [anon_sym_eNUM] = ACTIONS(5973),
    [anon_sym_eNum] = ACTIONS(5973),
    [anon_sym_ENum] = ACTIONS(5973),
    [sym_quoted_identifier] = ACTIONS(5975),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5975),
    [sym_verbatim_string] = ACTIONS(5975),
    [sym_integer] = ACTIONS(5973),
    [sym_continue_as_identifier] = ACTIONS(5975),
    [sym_preproc_open] = ACTIONS(5975),
  },
  [STATE(3130)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [anon_sym_POUNDelif] = ACTIONS(3871),
    [anon_sym_POUNDELIF] = ACTIONS(3871),
    [anon_sym_POUNDElif] = ACTIONS(3871),
    [anon_sym_POUNDelse] = ACTIONS(3871),
    [anon_sym_POUNDELSE] = ACTIONS(3871),
    [anon_sym_POUNDElse] = ACTIONS(3871),
    [anon_sym_POUNDelse2] = ACTIONS(3871),
    [anon_sym_POUNDELSE2] = ACTIONS(3871),
    [anon_sym_POUNDElse2] = ACTIONS(3871),
    [anon_sym_POUNDendif] = ACTIONS(3871),
    [anon_sym_POUNDENDIF] = ACTIONS(3871),
    [anon_sym_POUNDEndif] = ACTIONS(3871),
    [anon_sym_POUNDendif2] = ACTIONS(3871),
    [anon_sym_POUNDENDIF2] = ACTIONS(3871),
    [anon_sym_POUNDEndif2] = ACTIONS(3871),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_close] = ACTIONS(3871),
  },
  [STATE(3131)] = {
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(3634),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [anon_sym_POUNDelif] = ACTIONS(3634),
    [anon_sym_POUNDELIF] = ACTIONS(3634),
    [anon_sym_POUNDElif] = ACTIONS(3634),
    [anon_sym_POUNDelse] = ACTIONS(3634),
    [anon_sym_POUNDELSE] = ACTIONS(3634),
    [anon_sym_POUNDElse] = ACTIONS(3634),
    [anon_sym_POUNDelse2] = ACTIONS(3634),
    [anon_sym_POUNDELSE2] = ACTIONS(3634),
    [anon_sym_POUNDElse2] = ACTIONS(3634),
    [anon_sym_POUNDendif] = ACTIONS(3634),
    [anon_sym_POUNDENDIF] = ACTIONS(3634),
    [anon_sym_POUNDEndif] = ACTIONS(3634),
    [anon_sym_POUNDendif2] = ACTIONS(3634),
    [anon_sym_POUNDENDIF2] = ACTIONS(3634),
    [anon_sym_POUNDEndif2] = ACTIONS(3634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3634),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_close] = ACTIONS(3634),
  },
  [STATE(3132)] = {
    [sym_boolean] = STATE(8303),
    [sym_option_member_list] = STATE(8390),
    [sym_option_member] = STATE(8249),
    [sym_keyword_identifier] = STATE(8303),
    [sym_codeunit_keyword] = STATE(8241),
    [sym_xmlport_keyword] = STATE(8241),
    [sym_enum_keyword] = STATE(8241),
    [sym_keyword_as_identifier] = STATE(8303),
    [aux_sym_option_member_list_repeat2] = STATE(3158),
    [sym_identifier] = ACTIONS(7217),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(7219),
    [anon_sym_DASH] = ACTIONS(7221),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [aux_sym_where_condition_token1] = ACTIONS(7225),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7229),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [aux_sym_basic_type_token53] = ACTIONS(7225),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7225),
    [aux_sym_separator_action_token1] = ACTIONS(7225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7225),
    [aux_sym_type_declaration_token1] = ACTIONS(7225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(582),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7227),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [anon_sym_to] = ACTIONS(584),
    [anon_sym_TO] = ACTIONS(584),
    [anon_sym_To] = ACTIONS(584),
    [anon_sym_downto] = ACTIONS(584),
    [anon_sym_DOWNTO] = ACTIONS(584),
    [anon_sym_Downto] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(7225),
    [sym_page_keyword] = ACTIONS(7227),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(7227),
    [sym_query_keyword] = ACTIONS(7227),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_local_keyword] = ACTIONS(7217),
    [sym_internal_keyword] = ACTIONS(7217),
    [sym_protected_keyword] = ACTIONS(7217),
    [sym_key_keyword] = ACTIONS(7225),
    [sym_dataset_keyword] = ACTIONS(7225),
    [sym_quoted_identifier] = ACTIONS(7237),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7237),
    [sym_integer] = ACTIONS(7237),
  },
  [STATE(3133)] = {
    [sym_identifier] = ACTIONS(5980),
    [anon_sym_SEMI] = ACTIONS(5982),
    [anon_sym_DASH] = ACTIONS(5982),
    [aux_sym_boolean_token1] = ACTIONS(5980),
    [aux_sym_boolean_token2] = ACTIONS(5980),
    [sym_decimal] = ACTIONS(5980),
    [anon_sym_LPAREN] = ACTIONS(5982),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5980),
    [anon_sym_LBRACK] = ACTIONS(5982),
    [aux_sym_record_type_token1] = ACTIONS(5980),
    [aux_sym_basic_type_token21] = ACTIONS(5980),
    [aux_sym_basic_type_token22] = ACTIONS(5980),
    [aux_sym_basic_type_token48] = ACTIONS(5980),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5980),
    [anon_sym_POUNDif] = ACTIONS(5982),
    [anon_sym_POUNDIF] = ACTIONS(5982),
    [anon_sym_POUNDIf] = ACTIONS(5982),
    [anon_sym_not] = ACTIONS(5980),
    [anon_sym_NOT] = ACTIONS(5980),
    [anon_sym_Not] = ACTIONS(5980),
    [anon_sym_POUNDelse] = ACTIONS(5982),
    [anon_sym_POUNDELSE] = ACTIONS(5982),
    [anon_sym_POUNDElse] = ACTIONS(5982),
    [anon_sym_POUNDelse2] = ACTIONS(5982),
    [anon_sym_POUNDELSE2] = ACTIONS(5982),
    [anon_sym_POUNDElse2] = ACTIONS(5982),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5980),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5980),
    [anon_sym_PLUS] = ACTIONS(5982),
    [sym_datetime_literal] = ACTIONS(5982),
    [sym_date_literal] = ACTIONS(5980),
    [sym_time_literal] = ACTIONS(5980),
    [sym_biginteger_literal] = ACTIONS(5982),
    [anon_sym_if] = ACTIONS(5980),
    [anon_sym_IF] = ACTIONS(5980),
    [anon_sym_If] = ACTIONS(5980),
    [anon_sym_else] = ACTIONS(5980),
    [anon_sym_ELSE] = ACTIONS(5980),
    [anon_sym_Else] = ACTIONS(5980),
    [anon_sym_case] = ACTIONS(5980),
    [anon_sym_CASE] = ACTIONS(5980),
    [anon_sym_Case] = ACTIONS(5980),
    [anon_sym_for] = ACTIONS(5980),
    [anon_sym_FOR] = ACTIONS(5980),
    [anon_sym_For] = ACTIONS(5980),
    [anon_sym_foreach] = ACTIONS(5980),
    [anon_sym_FOREACH] = ACTIONS(5980),
    [anon_sym_Foreach] = ACTIONS(5980),
    [anon_sym_while] = ACTIONS(5980),
    [anon_sym_WHILE] = ACTIONS(5980),
    [anon_sym_While] = ACTIONS(5980),
    [anon_sym_repeat] = ACTIONS(5980),
    [anon_sym_REPEAT] = ACTIONS(5980),
    [anon_sym_Repeat] = ACTIONS(5980),
    [anon_sym_until] = ACTIONS(5980),
    [anon_sym_UNTIL] = ACTIONS(5980),
    [anon_sym_Until] = ACTIONS(5980),
    [anon_sym_exit] = ACTIONS(5980),
    [anon_sym_EXIT] = ACTIONS(5980),
    [anon_sym_Exit] = ACTIONS(5980),
    [anon_sym_continue] = ACTIONS(5980),
    [anon_sym_CONTINUE] = ACTIONS(5980),
    [anon_sym_Continue] = ACTIONS(5980),
    [anon_sym_break] = ACTIONS(5980),
    [anon_sym_BREAK] = ACTIONS(5980),
    [anon_sym_Break] = ACTIONS(5980),
    [anon_sym_with] = ACTIONS(5980),
    [anon_sym_WITH] = ACTIONS(5980),
    [anon_sym_With] = ACTIONS(5980),
    [sym_asserterror_keyword] = ACTIONS(5982),
    [sym_page_keyword] = ACTIONS(5980),
    [anon_sym_codeunit] = ACTIONS(5980),
    [anon_sym_CODEUNIT] = ACTIONS(5980),
    [anon_sym_Codeunit] = ACTIONS(5980),
    [anon_sym_CodeUnit] = ACTIONS(5980),
    [anon_sym_COdeunit] = ACTIONS(5980),
    [anon_sym_codeUnit] = ACTIONS(5980),
    [sym_report_keyword] = ACTIONS(5980),
    [sym_query_keyword] = ACTIONS(5980),
    [anon_sym_xmlport] = ACTIONS(5980),
    [anon_sym_XMLPORT] = ACTIONS(5980),
    [anon_sym_Xmlport] = ACTIONS(5980),
    [anon_sym_XMLport] = ACTIONS(5980),
    [anon_sym_XMLPort] = ACTIONS(5980),
    [anon_sym_XmlPort] = ACTIONS(5980),
    [anon_sym_enum] = ACTIONS(5980),
    [anon_sym_ENUM] = ACTIONS(5980),
    [anon_sym_Enum] = ACTIONS(5980),
    [anon_sym_eNUM] = ACTIONS(5980),
    [anon_sym_eNum] = ACTIONS(5980),
    [anon_sym_ENum] = ACTIONS(5980),
    [sym_quoted_identifier] = ACTIONS(5982),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5982),
    [sym_verbatim_string] = ACTIONS(5982),
    [sym_integer] = ACTIONS(5980),
    [sym_continue_as_identifier] = ACTIONS(5982),
    [sym_preproc_open] = ACTIONS(5982),
  },
  [STATE(3134)] = {
    [sym_identifier] = ACTIONS(5984),
    [anon_sym_SEMI] = ACTIONS(5986),
    [anon_sym_DASH] = ACTIONS(5986),
    [aux_sym_boolean_token1] = ACTIONS(5984),
    [aux_sym_boolean_token2] = ACTIONS(5984),
    [sym_decimal] = ACTIONS(5984),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5984),
    [anon_sym_LBRACK] = ACTIONS(5986),
    [aux_sym_record_type_token1] = ACTIONS(5984),
    [aux_sym_basic_type_token21] = ACTIONS(5984),
    [aux_sym_basic_type_token22] = ACTIONS(5984),
    [aux_sym_basic_type_token48] = ACTIONS(5984),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5984),
    [anon_sym_POUNDif] = ACTIONS(5986),
    [anon_sym_POUNDIF] = ACTIONS(5986),
    [anon_sym_POUNDIf] = ACTIONS(5986),
    [anon_sym_not] = ACTIONS(5984),
    [anon_sym_NOT] = ACTIONS(5984),
    [anon_sym_Not] = ACTIONS(5984),
    [anon_sym_POUNDelse] = ACTIONS(5986),
    [anon_sym_POUNDELSE] = ACTIONS(5986),
    [anon_sym_POUNDElse] = ACTIONS(5986),
    [anon_sym_POUNDelse2] = ACTIONS(5986),
    [anon_sym_POUNDELSE2] = ACTIONS(5986),
    [anon_sym_POUNDElse2] = ACTIONS(5986),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5984),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5984),
    [anon_sym_PLUS] = ACTIONS(5986),
    [sym_datetime_literal] = ACTIONS(5986),
    [sym_date_literal] = ACTIONS(5984),
    [sym_time_literal] = ACTIONS(5984),
    [sym_biginteger_literal] = ACTIONS(5986),
    [anon_sym_if] = ACTIONS(5984),
    [anon_sym_IF] = ACTIONS(5984),
    [anon_sym_If] = ACTIONS(5984),
    [anon_sym_else] = ACTIONS(5984),
    [anon_sym_ELSE] = ACTIONS(5984),
    [anon_sym_Else] = ACTIONS(5984),
    [anon_sym_case] = ACTIONS(5984),
    [anon_sym_CASE] = ACTIONS(5984),
    [anon_sym_Case] = ACTIONS(5984),
    [anon_sym_for] = ACTIONS(5984),
    [anon_sym_FOR] = ACTIONS(5984),
    [anon_sym_For] = ACTIONS(5984),
    [anon_sym_foreach] = ACTIONS(5984),
    [anon_sym_FOREACH] = ACTIONS(5984),
    [anon_sym_Foreach] = ACTIONS(5984),
    [anon_sym_while] = ACTIONS(5984),
    [anon_sym_WHILE] = ACTIONS(5984),
    [anon_sym_While] = ACTIONS(5984),
    [anon_sym_repeat] = ACTIONS(5984),
    [anon_sym_REPEAT] = ACTIONS(5984),
    [anon_sym_Repeat] = ACTIONS(5984),
    [anon_sym_until] = ACTIONS(5984),
    [anon_sym_UNTIL] = ACTIONS(5984),
    [anon_sym_Until] = ACTIONS(5984),
    [anon_sym_exit] = ACTIONS(5984),
    [anon_sym_EXIT] = ACTIONS(5984),
    [anon_sym_Exit] = ACTIONS(5984),
    [anon_sym_continue] = ACTIONS(5984),
    [anon_sym_CONTINUE] = ACTIONS(5984),
    [anon_sym_Continue] = ACTIONS(5984),
    [anon_sym_break] = ACTIONS(5984),
    [anon_sym_BREAK] = ACTIONS(5984),
    [anon_sym_Break] = ACTIONS(5984),
    [anon_sym_with] = ACTIONS(5984),
    [anon_sym_WITH] = ACTIONS(5984),
    [anon_sym_With] = ACTIONS(5984),
    [sym_asserterror_keyword] = ACTIONS(5986),
    [sym_page_keyword] = ACTIONS(5984),
    [anon_sym_codeunit] = ACTIONS(5984),
    [anon_sym_CODEUNIT] = ACTIONS(5984),
    [anon_sym_Codeunit] = ACTIONS(5984),
    [anon_sym_CodeUnit] = ACTIONS(5984),
    [anon_sym_COdeunit] = ACTIONS(5984),
    [anon_sym_codeUnit] = ACTIONS(5984),
    [sym_report_keyword] = ACTIONS(5984),
    [sym_query_keyword] = ACTIONS(5984),
    [anon_sym_xmlport] = ACTIONS(5984),
    [anon_sym_XMLPORT] = ACTIONS(5984),
    [anon_sym_Xmlport] = ACTIONS(5984),
    [anon_sym_XMLport] = ACTIONS(5984),
    [anon_sym_XMLPort] = ACTIONS(5984),
    [anon_sym_XmlPort] = ACTIONS(5984),
    [anon_sym_enum] = ACTIONS(5984),
    [anon_sym_ENUM] = ACTIONS(5984),
    [anon_sym_Enum] = ACTIONS(5984),
    [anon_sym_eNUM] = ACTIONS(5984),
    [anon_sym_eNum] = ACTIONS(5984),
    [anon_sym_ENum] = ACTIONS(5984),
    [sym_quoted_identifier] = ACTIONS(5986),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5986),
    [sym_verbatim_string] = ACTIONS(5986),
    [sym_integer] = ACTIONS(5984),
    [sym_continue_as_identifier] = ACTIONS(5986),
    [sym_preproc_open] = ACTIONS(5986),
  },
  [STATE(3135)] = {
    [sym_identifier] = ACTIONS(5988),
    [anon_sym_SEMI] = ACTIONS(5990),
    [anon_sym_DASH] = ACTIONS(5990),
    [aux_sym_boolean_token1] = ACTIONS(5988),
    [aux_sym_boolean_token2] = ACTIONS(5988),
    [sym_decimal] = ACTIONS(5988),
    [anon_sym_LPAREN] = ACTIONS(5990),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5988),
    [anon_sym_LBRACK] = ACTIONS(5990),
    [aux_sym_record_type_token1] = ACTIONS(5988),
    [aux_sym_basic_type_token21] = ACTIONS(5988),
    [aux_sym_basic_type_token22] = ACTIONS(5988),
    [aux_sym_basic_type_token48] = ACTIONS(5988),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5988),
    [anon_sym_POUNDif] = ACTIONS(5990),
    [anon_sym_POUNDIF] = ACTIONS(5990),
    [anon_sym_POUNDIf] = ACTIONS(5990),
    [anon_sym_not] = ACTIONS(5988),
    [anon_sym_NOT] = ACTIONS(5988),
    [anon_sym_Not] = ACTIONS(5988),
    [anon_sym_POUNDelse] = ACTIONS(5990),
    [anon_sym_POUNDELSE] = ACTIONS(5990),
    [anon_sym_POUNDElse] = ACTIONS(5990),
    [anon_sym_POUNDelse2] = ACTIONS(5990),
    [anon_sym_POUNDELSE2] = ACTIONS(5990),
    [anon_sym_POUNDElse2] = ACTIONS(5990),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5988),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5988),
    [anon_sym_PLUS] = ACTIONS(5990),
    [sym_datetime_literal] = ACTIONS(5990),
    [sym_date_literal] = ACTIONS(5988),
    [sym_time_literal] = ACTIONS(5988),
    [sym_biginteger_literal] = ACTIONS(5990),
    [anon_sym_if] = ACTIONS(5988),
    [anon_sym_IF] = ACTIONS(5988),
    [anon_sym_If] = ACTIONS(5988),
    [anon_sym_else] = ACTIONS(5988),
    [anon_sym_ELSE] = ACTIONS(5988),
    [anon_sym_Else] = ACTIONS(5988),
    [anon_sym_case] = ACTIONS(5988),
    [anon_sym_CASE] = ACTIONS(5988),
    [anon_sym_Case] = ACTIONS(5988),
    [anon_sym_for] = ACTIONS(5988),
    [anon_sym_FOR] = ACTIONS(5988),
    [anon_sym_For] = ACTIONS(5988),
    [anon_sym_foreach] = ACTIONS(5988),
    [anon_sym_FOREACH] = ACTIONS(5988),
    [anon_sym_Foreach] = ACTIONS(5988),
    [anon_sym_while] = ACTIONS(5988),
    [anon_sym_WHILE] = ACTIONS(5988),
    [anon_sym_While] = ACTIONS(5988),
    [anon_sym_repeat] = ACTIONS(5988),
    [anon_sym_REPEAT] = ACTIONS(5988),
    [anon_sym_Repeat] = ACTIONS(5988),
    [anon_sym_until] = ACTIONS(5988),
    [anon_sym_UNTIL] = ACTIONS(5988),
    [anon_sym_Until] = ACTIONS(5988),
    [anon_sym_exit] = ACTIONS(5988),
    [anon_sym_EXIT] = ACTIONS(5988),
    [anon_sym_Exit] = ACTIONS(5988),
    [anon_sym_continue] = ACTIONS(5988),
    [anon_sym_CONTINUE] = ACTIONS(5988),
    [anon_sym_Continue] = ACTIONS(5988),
    [anon_sym_break] = ACTIONS(5988),
    [anon_sym_BREAK] = ACTIONS(5988),
    [anon_sym_Break] = ACTIONS(5988),
    [anon_sym_with] = ACTIONS(5988),
    [anon_sym_WITH] = ACTIONS(5988),
    [anon_sym_With] = ACTIONS(5988),
    [sym_asserterror_keyword] = ACTIONS(5990),
    [sym_page_keyword] = ACTIONS(5988),
    [anon_sym_codeunit] = ACTIONS(5988),
    [anon_sym_CODEUNIT] = ACTIONS(5988),
    [anon_sym_Codeunit] = ACTIONS(5988),
    [anon_sym_CodeUnit] = ACTIONS(5988),
    [anon_sym_COdeunit] = ACTIONS(5988),
    [anon_sym_codeUnit] = ACTIONS(5988),
    [sym_report_keyword] = ACTIONS(5988),
    [sym_query_keyword] = ACTIONS(5988),
    [anon_sym_xmlport] = ACTIONS(5988),
    [anon_sym_XMLPORT] = ACTIONS(5988),
    [anon_sym_Xmlport] = ACTIONS(5988),
    [anon_sym_XMLport] = ACTIONS(5988),
    [anon_sym_XMLPort] = ACTIONS(5988),
    [anon_sym_XmlPort] = ACTIONS(5988),
    [anon_sym_enum] = ACTIONS(5988),
    [anon_sym_ENUM] = ACTIONS(5988),
    [anon_sym_Enum] = ACTIONS(5988),
    [anon_sym_eNUM] = ACTIONS(5988),
    [anon_sym_eNum] = ACTIONS(5988),
    [anon_sym_ENum] = ACTIONS(5988),
    [sym_quoted_identifier] = ACTIONS(5990),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5990),
    [sym_verbatim_string] = ACTIONS(5990),
    [sym_integer] = ACTIONS(5988),
    [sym_continue_as_identifier] = ACTIONS(5990),
    [sym_preproc_open] = ACTIONS(5990),
  },
  [STATE(3136)] = {
    [sym_identifier] = ACTIONS(5992),
    [anon_sym_SEMI] = ACTIONS(5994),
    [anon_sym_DASH] = ACTIONS(5994),
    [aux_sym_boolean_token1] = ACTIONS(5992),
    [aux_sym_boolean_token2] = ACTIONS(5992),
    [sym_decimal] = ACTIONS(5992),
    [anon_sym_LPAREN] = ACTIONS(5994),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5992),
    [anon_sym_LBRACK] = ACTIONS(5994),
    [aux_sym_record_type_token1] = ACTIONS(5992),
    [aux_sym_basic_type_token21] = ACTIONS(5992),
    [aux_sym_basic_type_token22] = ACTIONS(5992),
    [aux_sym_basic_type_token48] = ACTIONS(5992),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5992),
    [anon_sym_POUNDif] = ACTIONS(5994),
    [anon_sym_POUNDIF] = ACTIONS(5994),
    [anon_sym_POUNDIf] = ACTIONS(5994),
    [anon_sym_not] = ACTIONS(5992),
    [anon_sym_NOT] = ACTIONS(5992),
    [anon_sym_Not] = ACTIONS(5992),
    [anon_sym_POUNDelse] = ACTIONS(5994),
    [anon_sym_POUNDELSE] = ACTIONS(5994),
    [anon_sym_POUNDElse] = ACTIONS(5994),
    [anon_sym_POUNDelse2] = ACTIONS(5994),
    [anon_sym_POUNDELSE2] = ACTIONS(5994),
    [anon_sym_POUNDElse2] = ACTIONS(5994),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5992),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5992),
    [anon_sym_PLUS] = ACTIONS(5994),
    [sym_datetime_literal] = ACTIONS(5994),
    [sym_date_literal] = ACTIONS(5992),
    [sym_time_literal] = ACTIONS(5992),
    [sym_biginteger_literal] = ACTIONS(5994),
    [anon_sym_if] = ACTIONS(5992),
    [anon_sym_IF] = ACTIONS(5992),
    [anon_sym_If] = ACTIONS(5992),
    [anon_sym_else] = ACTIONS(5992),
    [anon_sym_ELSE] = ACTIONS(5992),
    [anon_sym_Else] = ACTIONS(5992),
    [anon_sym_case] = ACTIONS(5992),
    [anon_sym_CASE] = ACTIONS(5992),
    [anon_sym_Case] = ACTIONS(5992),
    [anon_sym_for] = ACTIONS(5992),
    [anon_sym_FOR] = ACTIONS(5992),
    [anon_sym_For] = ACTIONS(5992),
    [anon_sym_foreach] = ACTIONS(5992),
    [anon_sym_FOREACH] = ACTIONS(5992),
    [anon_sym_Foreach] = ACTIONS(5992),
    [anon_sym_while] = ACTIONS(5992),
    [anon_sym_WHILE] = ACTIONS(5992),
    [anon_sym_While] = ACTIONS(5992),
    [anon_sym_repeat] = ACTIONS(5992),
    [anon_sym_REPEAT] = ACTIONS(5992),
    [anon_sym_Repeat] = ACTIONS(5992),
    [anon_sym_until] = ACTIONS(5992),
    [anon_sym_UNTIL] = ACTIONS(5992),
    [anon_sym_Until] = ACTIONS(5992),
    [anon_sym_exit] = ACTIONS(5992),
    [anon_sym_EXIT] = ACTIONS(5992),
    [anon_sym_Exit] = ACTIONS(5992),
    [anon_sym_continue] = ACTIONS(5992),
    [anon_sym_CONTINUE] = ACTIONS(5992),
    [anon_sym_Continue] = ACTIONS(5992),
    [anon_sym_break] = ACTIONS(5992),
    [anon_sym_BREAK] = ACTIONS(5992),
    [anon_sym_Break] = ACTIONS(5992),
    [anon_sym_with] = ACTIONS(5992),
    [anon_sym_WITH] = ACTIONS(5992),
    [anon_sym_With] = ACTIONS(5992),
    [sym_asserterror_keyword] = ACTIONS(5994),
    [sym_page_keyword] = ACTIONS(5992),
    [anon_sym_codeunit] = ACTIONS(5992),
    [anon_sym_CODEUNIT] = ACTIONS(5992),
    [anon_sym_Codeunit] = ACTIONS(5992),
    [anon_sym_CodeUnit] = ACTIONS(5992),
    [anon_sym_COdeunit] = ACTIONS(5992),
    [anon_sym_codeUnit] = ACTIONS(5992),
    [sym_report_keyword] = ACTIONS(5992),
    [sym_query_keyword] = ACTIONS(5992),
    [anon_sym_xmlport] = ACTIONS(5992),
    [anon_sym_XMLPORT] = ACTIONS(5992),
    [anon_sym_Xmlport] = ACTIONS(5992),
    [anon_sym_XMLport] = ACTIONS(5992),
    [anon_sym_XMLPort] = ACTIONS(5992),
    [anon_sym_XmlPort] = ACTIONS(5992),
    [anon_sym_enum] = ACTIONS(5992),
    [anon_sym_ENUM] = ACTIONS(5992),
    [anon_sym_Enum] = ACTIONS(5992),
    [anon_sym_eNUM] = ACTIONS(5992),
    [anon_sym_eNum] = ACTIONS(5992),
    [anon_sym_ENum] = ACTIONS(5992),
    [sym_quoted_identifier] = ACTIONS(5994),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5994),
    [sym_verbatim_string] = ACTIONS(5994),
    [sym_integer] = ACTIONS(5992),
    [sym_continue_as_identifier] = ACTIONS(5994),
    [sym_preproc_open] = ACTIONS(5994),
  },
  [STATE(3137)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(3138)] = {
    [sym_identifier] = ACTIONS(5988),
    [anon_sym_SEMI] = ACTIONS(5990),
    [anon_sym_DASH] = ACTIONS(5990),
    [aux_sym_boolean_token1] = ACTIONS(5988),
    [aux_sym_boolean_token2] = ACTIONS(5988),
    [sym_decimal] = ACTIONS(5988),
    [anon_sym_LPAREN] = ACTIONS(5990),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5988),
    [anon_sym_LBRACK] = ACTIONS(5990),
    [aux_sym_record_type_token1] = ACTIONS(5988),
    [aux_sym_basic_type_token21] = ACTIONS(5988),
    [aux_sym_basic_type_token22] = ACTIONS(5988),
    [aux_sym_basic_type_token48] = ACTIONS(5988),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5988),
    [anon_sym_POUNDif] = ACTIONS(5990),
    [anon_sym_POUNDIF] = ACTIONS(5990),
    [anon_sym_POUNDIf] = ACTIONS(5990),
    [anon_sym_not] = ACTIONS(5988),
    [anon_sym_NOT] = ACTIONS(5988),
    [anon_sym_Not] = ACTIONS(5988),
    [anon_sym_POUNDelse] = ACTIONS(5990),
    [anon_sym_POUNDELSE] = ACTIONS(5990),
    [anon_sym_POUNDElse] = ACTIONS(5990),
    [anon_sym_POUNDelse2] = ACTIONS(5990),
    [anon_sym_POUNDELSE2] = ACTIONS(5990),
    [anon_sym_POUNDElse2] = ACTIONS(5990),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5988),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5988),
    [anon_sym_PLUS] = ACTIONS(5990),
    [sym_datetime_literal] = ACTIONS(5990),
    [sym_date_literal] = ACTIONS(5988),
    [sym_time_literal] = ACTIONS(5988),
    [sym_biginteger_literal] = ACTIONS(5990),
    [anon_sym_if] = ACTIONS(5988),
    [anon_sym_IF] = ACTIONS(5988),
    [anon_sym_If] = ACTIONS(5988),
    [anon_sym_else] = ACTIONS(5988),
    [anon_sym_ELSE] = ACTIONS(5988),
    [anon_sym_Else] = ACTIONS(5988),
    [anon_sym_case] = ACTIONS(5988),
    [anon_sym_CASE] = ACTIONS(5988),
    [anon_sym_Case] = ACTIONS(5988),
    [anon_sym_for] = ACTIONS(5988),
    [anon_sym_FOR] = ACTIONS(5988),
    [anon_sym_For] = ACTIONS(5988),
    [anon_sym_foreach] = ACTIONS(5988),
    [anon_sym_FOREACH] = ACTIONS(5988),
    [anon_sym_Foreach] = ACTIONS(5988),
    [anon_sym_while] = ACTIONS(5988),
    [anon_sym_WHILE] = ACTIONS(5988),
    [anon_sym_While] = ACTIONS(5988),
    [anon_sym_repeat] = ACTIONS(5988),
    [anon_sym_REPEAT] = ACTIONS(5988),
    [anon_sym_Repeat] = ACTIONS(5988),
    [anon_sym_until] = ACTIONS(5988),
    [anon_sym_UNTIL] = ACTIONS(5988),
    [anon_sym_Until] = ACTIONS(5988),
    [anon_sym_exit] = ACTIONS(5988),
    [anon_sym_EXIT] = ACTIONS(5988),
    [anon_sym_Exit] = ACTIONS(5988),
    [anon_sym_continue] = ACTIONS(5988),
    [anon_sym_CONTINUE] = ACTIONS(5988),
    [anon_sym_Continue] = ACTIONS(5988),
    [anon_sym_break] = ACTIONS(5988),
    [anon_sym_BREAK] = ACTIONS(5988),
    [anon_sym_Break] = ACTIONS(5988),
    [anon_sym_with] = ACTIONS(5988),
    [anon_sym_WITH] = ACTIONS(5988),
    [anon_sym_With] = ACTIONS(5988),
    [sym_asserterror_keyword] = ACTIONS(5990),
    [sym_page_keyword] = ACTIONS(5988),
    [anon_sym_codeunit] = ACTIONS(5988),
    [anon_sym_CODEUNIT] = ACTIONS(5988),
    [anon_sym_Codeunit] = ACTIONS(5988),
    [anon_sym_CodeUnit] = ACTIONS(5988),
    [anon_sym_COdeunit] = ACTIONS(5988),
    [anon_sym_codeUnit] = ACTIONS(5988),
    [sym_report_keyword] = ACTIONS(5988),
    [sym_query_keyword] = ACTIONS(5988),
    [anon_sym_xmlport] = ACTIONS(5988),
    [anon_sym_XMLPORT] = ACTIONS(5988),
    [anon_sym_Xmlport] = ACTIONS(5988),
    [anon_sym_XMLport] = ACTIONS(5988),
    [anon_sym_XMLPort] = ACTIONS(5988),
    [anon_sym_XmlPort] = ACTIONS(5988),
    [anon_sym_enum] = ACTIONS(5988),
    [anon_sym_ENUM] = ACTIONS(5988),
    [anon_sym_Enum] = ACTIONS(5988),
    [anon_sym_eNUM] = ACTIONS(5988),
    [anon_sym_eNum] = ACTIONS(5988),
    [anon_sym_ENum] = ACTIONS(5988),
    [sym_quoted_identifier] = ACTIONS(5990),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5990),
    [sym_verbatim_string] = ACTIONS(5990),
    [sym_integer] = ACTIONS(5988),
    [sym_continue_as_identifier] = ACTIONS(5990),
    [sym_preproc_open] = ACTIONS(5990),
  },
  [STATE(3139)] = {
    [sym_identifier] = ACTIONS(3752),
    [anon_sym_DOT] = ACTIONS(3752),
    [anon_sym_EQ] = ACTIONS(3754),
    [anon_sym_COMMA] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3752),
    [aux_sym_boolean_token1] = ACTIONS(3752),
    [aux_sym_boolean_token2] = ACTIONS(3752),
    [sym_decimal] = ACTIONS(3752),
    [anon_sym_LPAREN] = ACTIONS(3754),
    [anon_sym_DOT_DOT] = ACTIONS(3754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3752),
    [anon_sym_STAR] = ACTIONS(3752),
    [anon_sym_LBRACK] = ACTIONS(3754),
    [aux_sym_record_type_token1] = ACTIONS(3752),
    [aux_sym_basic_type_token21] = ACTIONS(3752),
    [aux_sym_basic_type_token22] = ACTIONS(3752),
    [aux_sym_basic_type_token48] = ACTIONS(3752),
    [anon_sym_not] = ACTIONS(3752),
    [anon_sym_NOT] = ACTIONS(3752),
    [anon_sym_Not] = ACTIONS(3752),
    [anon_sym_POUNDelif] = ACTIONS(3754),
    [anon_sym_POUNDELIF] = ACTIONS(3754),
    [anon_sym_POUNDElif] = ACTIONS(3754),
    [anon_sym_POUNDelse] = ACTIONS(3754),
    [anon_sym_POUNDELSE] = ACTIONS(3754),
    [anon_sym_POUNDElse] = ACTIONS(3754),
    [anon_sym_POUNDelse2] = ACTIONS(3754),
    [anon_sym_POUNDELSE2] = ACTIONS(3754),
    [anon_sym_POUNDElse2] = ACTIONS(3754),
    [anon_sym_POUNDendif] = ACTIONS(3754),
    [anon_sym_POUNDENDIF] = ACTIONS(3754),
    [anon_sym_POUNDEndif] = ACTIONS(3754),
    [anon_sym_POUNDendif2] = ACTIONS(3754),
    [anon_sym_POUNDENDIF2] = ACTIONS(3754),
    [anon_sym_POUNDEndif2] = ACTIONS(3754),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3754),
    [aux_sym__expression_token1] = ACTIONS(3754),
    [aux_sym__expression_token2] = ACTIONS(3754),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3752),
    [anon_sym_SLASH] = ACTIONS(3752),
    [anon_sym_div] = ACTIONS(3752),
    [anon_sym_DIV] = ACTIONS(3752),
    [anon_sym_Div] = ACTIONS(3752),
    [anon_sym_mod] = ACTIONS(3752),
    [anon_sym_MOD] = ACTIONS(3752),
    [anon_sym_Mod] = ACTIONS(3752),
    [anon_sym_PLUS] = ACTIONS(3752),
    [anon_sym_GT_EQ] = ACTIONS(3754),
    [anon_sym_LT_EQ] = ACTIONS(3754),
    [anon_sym_GT] = ACTIONS(3752),
    [anon_sym_LT] = ACTIONS(3752),
    [anon_sym_LT_GT] = ACTIONS(3754),
    [anon_sym_and] = ACTIONS(3752),
    [anon_sym_AND] = ACTIONS(3752),
    [anon_sym_And] = ACTIONS(3752),
    [anon_sym_or] = ACTIONS(3752),
    [anon_sym_OR] = ACTIONS(3752),
    [anon_sym_Or] = ACTIONS(3752),
    [anon_sym_xor] = ACTIONS(3752),
    [anon_sym_XOR] = ACTIONS(3752),
    [anon_sym_Xor] = ACTIONS(3752),
    [anon_sym_QMARK] = ACTIONS(3754),
    [sym_datetime_literal] = ACTIONS(3754),
    [sym_date_literal] = ACTIONS(3752),
    [sym_time_literal] = ACTIONS(3752),
    [sym_biginteger_literal] = ACTIONS(3754),
    [anon_sym_in] = ACTIONS(3752),
    [anon_sym_IN] = ACTIONS(3752),
    [anon_sym_In] = ACTIONS(3752),
    [sym_page_keyword] = ACTIONS(3752),
    [anon_sym_codeunit] = ACTIONS(3752),
    [anon_sym_CODEUNIT] = ACTIONS(3752),
    [anon_sym_Codeunit] = ACTIONS(3752),
    [anon_sym_CodeUnit] = ACTIONS(3752),
    [anon_sym_COdeunit] = ACTIONS(3752),
    [anon_sym_codeUnit] = ACTIONS(3752),
    [sym_report_keyword] = ACTIONS(3752),
    [sym_query_keyword] = ACTIONS(3752),
    [anon_sym_xmlport] = ACTIONS(3752),
    [anon_sym_XMLPORT] = ACTIONS(3752),
    [anon_sym_Xmlport] = ACTIONS(3752),
    [anon_sym_XMLport] = ACTIONS(3752),
    [anon_sym_XMLPort] = ACTIONS(3752),
    [anon_sym_XmlPort] = ACTIONS(3752),
    [anon_sym_enum] = ACTIONS(3752),
    [anon_sym_ENUM] = ACTIONS(3752),
    [anon_sym_Enum] = ACTIONS(3752),
    [anon_sym_eNUM] = ACTIONS(3752),
    [anon_sym_eNum] = ACTIONS(3752),
    [anon_sym_ENum] = ACTIONS(3752),
    [sym_quoted_identifier] = ACTIONS(3754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3754),
    [sym_verbatim_string] = ACTIONS(3754),
    [sym_integer] = ACTIONS(3752),
    [sym_continue_as_identifier] = ACTIONS(3754),
    [sym_preproc_close] = ACTIONS(3754),
  },
  [STATE(3140)] = {
    [sym_identifier] = ACTIONS(5996),
    [anon_sym_SEMI] = ACTIONS(5998),
    [anon_sym_DASH] = ACTIONS(5998),
    [aux_sym_boolean_token1] = ACTIONS(5996),
    [aux_sym_boolean_token2] = ACTIONS(5996),
    [sym_decimal] = ACTIONS(5996),
    [anon_sym_LPAREN] = ACTIONS(5998),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5996),
    [anon_sym_LBRACK] = ACTIONS(5998),
    [aux_sym_record_type_token1] = ACTIONS(5996),
    [aux_sym_basic_type_token21] = ACTIONS(5996),
    [aux_sym_basic_type_token22] = ACTIONS(5996),
    [aux_sym_basic_type_token48] = ACTIONS(5996),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5996),
    [anon_sym_POUNDif] = ACTIONS(5998),
    [anon_sym_POUNDIF] = ACTIONS(5998),
    [anon_sym_POUNDIf] = ACTIONS(5998),
    [anon_sym_not] = ACTIONS(5996),
    [anon_sym_NOT] = ACTIONS(5996),
    [anon_sym_Not] = ACTIONS(5996),
    [anon_sym_POUNDelse] = ACTIONS(5998),
    [anon_sym_POUNDELSE] = ACTIONS(5998),
    [anon_sym_POUNDElse] = ACTIONS(5998),
    [anon_sym_POUNDelse2] = ACTIONS(5998),
    [anon_sym_POUNDELSE2] = ACTIONS(5998),
    [anon_sym_POUNDElse2] = ACTIONS(5998),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5996),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5996),
    [anon_sym_PLUS] = ACTIONS(5998),
    [sym_datetime_literal] = ACTIONS(5998),
    [sym_date_literal] = ACTIONS(5996),
    [sym_time_literal] = ACTIONS(5996),
    [sym_biginteger_literal] = ACTIONS(5998),
    [anon_sym_if] = ACTIONS(5996),
    [anon_sym_IF] = ACTIONS(5996),
    [anon_sym_If] = ACTIONS(5996),
    [anon_sym_else] = ACTIONS(5996),
    [anon_sym_ELSE] = ACTIONS(5996),
    [anon_sym_Else] = ACTIONS(5996),
    [anon_sym_case] = ACTIONS(5996),
    [anon_sym_CASE] = ACTIONS(5996),
    [anon_sym_Case] = ACTIONS(5996),
    [anon_sym_for] = ACTIONS(5996),
    [anon_sym_FOR] = ACTIONS(5996),
    [anon_sym_For] = ACTIONS(5996),
    [anon_sym_foreach] = ACTIONS(5996),
    [anon_sym_FOREACH] = ACTIONS(5996),
    [anon_sym_Foreach] = ACTIONS(5996),
    [anon_sym_while] = ACTIONS(5996),
    [anon_sym_WHILE] = ACTIONS(5996),
    [anon_sym_While] = ACTIONS(5996),
    [anon_sym_repeat] = ACTIONS(5996),
    [anon_sym_REPEAT] = ACTIONS(5996),
    [anon_sym_Repeat] = ACTIONS(5996),
    [anon_sym_until] = ACTIONS(5996),
    [anon_sym_UNTIL] = ACTIONS(5996),
    [anon_sym_Until] = ACTIONS(5996),
    [anon_sym_exit] = ACTIONS(5996),
    [anon_sym_EXIT] = ACTIONS(5996),
    [anon_sym_Exit] = ACTIONS(5996),
    [anon_sym_continue] = ACTIONS(5996),
    [anon_sym_CONTINUE] = ACTIONS(5996),
    [anon_sym_Continue] = ACTIONS(5996),
    [anon_sym_break] = ACTIONS(5996),
    [anon_sym_BREAK] = ACTIONS(5996),
    [anon_sym_Break] = ACTIONS(5996),
    [anon_sym_with] = ACTIONS(5996),
    [anon_sym_WITH] = ACTIONS(5996),
    [anon_sym_With] = ACTIONS(5996),
    [sym_asserterror_keyword] = ACTIONS(5998),
    [sym_page_keyword] = ACTIONS(5996),
    [anon_sym_codeunit] = ACTIONS(5996),
    [anon_sym_CODEUNIT] = ACTIONS(5996),
    [anon_sym_Codeunit] = ACTIONS(5996),
    [anon_sym_CodeUnit] = ACTIONS(5996),
    [anon_sym_COdeunit] = ACTIONS(5996),
    [anon_sym_codeUnit] = ACTIONS(5996),
    [sym_report_keyword] = ACTIONS(5996),
    [sym_query_keyword] = ACTIONS(5996),
    [anon_sym_xmlport] = ACTIONS(5996),
    [anon_sym_XMLPORT] = ACTIONS(5996),
    [anon_sym_Xmlport] = ACTIONS(5996),
    [anon_sym_XMLport] = ACTIONS(5996),
    [anon_sym_XMLPort] = ACTIONS(5996),
    [anon_sym_XmlPort] = ACTIONS(5996),
    [anon_sym_enum] = ACTIONS(5996),
    [anon_sym_ENUM] = ACTIONS(5996),
    [anon_sym_Enum] = ACTIONS(5996),
    [anon_sym_eNUM] = ACTIONS(5996),
    [anon_sym_eNum] = ACTIONS(5996),
    [anon_sym_ENum] = ACTIONS(5996),
    [sym_quoted_identifier] = ACTIONS(5998),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5998),
    [sym_verbatim_string] = ACTIONS(5998),
    [sym_integer] = ACTIONS(5996),
    [sym_continue_as_identifier] = ACTIONS(5998),
    [sym_preproc_open] = ACTIONS(5998),
  },
  [STATE(3141)] = {
    [sym_identifier] = ACTIONS(3925),
    [anon_sym_DOT] = ACTIONS(3925),
    [anon_sym_EQ] = ACTIONS(3927),
    [anon_sym_COMMA] = ACTIONS(3927),
    [anon_sym_DASH] = ACTIONS(3925),
    [aux_sym_boolean_token1] = ACTIONS(3925),
    [aux_sym_boolean_token2] = ACTIONS(3925),
    [sym_decimal] = ACTIONS(3925),
    [anon_sym_LPAREN] = ACTIONS(3927),
    [anon_sym_DOT_DOT] = ACTIONS(3927),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3925),
    [anon_sym_STAR] = ACTIONS(3925),
    [anon_sym_LBRACK] = ACTIONS(7239),
    [aux_sym_record_type_token1] = ACTIONS(3925),
    [aux_sym_basic_type_token21] = ACTIONS(3925),
    [aux_sym_basic_type_token22] = ACTIONS(3925),
    [aux_sym_basic_type_token48] = ACTIONS(3925),
    [anon_sym_not] = ACTIONS(3925),
    [anon_sym_NOT] = ACTIONS(3925),
    [anon_sym_Not] = ACTIONS(3925),
    [anon_sym_POUNDelif] = ACTIONS(3927),
    [anon_sym_POUNDELIF] = ACTIONS(3927),
    [anon_sym_POUNDElif] = ACTIONS(3927),
    [anon_sym_POUNDelse] = ACTIONS(3927),
    [anon_sym_POUNDELSE] = ACTIONS(3927),
    [anon_sym_POUNDElse] = ACTIONS(3927),
    [anon_sym_POUNDelse2] = ACTIONS(3927),
    [anon_sym_POUNDELSE2] = ACTIONS(3927),
    [anon_sym_POUNDElse2] = ACTIONS(3927),
    [anon_sym_POUNDendif] = ACTIONS(3927),
    [anon_sym_POUNDENDIF] = ACTIONS(3927),
    [anon_sym_POUNDEndif] = ACTIONS(3927),
    [anon_sym_POUNDendif2] = ACTIONS(3927),
    [anon_sym_POUNDENDIF2] = ACTIONS(3927),
    [anon_sym_POUNDEndif2] = ACTIONS(3927),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3927),
    [aux_sym__expression_token1] = ACTIONS(3927),
    [aux_sym__expression_token2] = ACTIONS(3927),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3925),
    [anon_sym_SLASH] = ACTIONS(3925),
    [anon_sym_div] = ACTIONS(3925),
    [anon_sym_DIV] = ACTIONS(3925),
    [anon_sym_Div] = ACTIONS(3925),
    [anon_sym_mod] = ACTIONS(3925),
    [anon_sym_MOD] = ACTIONS(3925),
    [anon_sym_Mod] = ACTIONS(3925),
    [anon_sym_PLUS] = ACTIONS(3925),
    [anon_sym_GT_EQ] = ACTIONS(3927),
    [anon_sym_LT_EQ] = ACTIONS(3927),
    [anon_sym_GT] = ACTIONS(3925),
    [anon_sym_LT] = ACTIONS(3925),
    [anon_sym_LT_GT] = ACTIONS(3927),
    [anon_sym_and] = ACTIONS(3925),
    [anon_sym_AND] = ACTIONS(3925),
    [anon_sym_And] = ACTIONS(3925),
    [anon_sym_or] = ACTIONS(3925),
    [anon_sym_OR] = ACTIONS(3925),
    [anon_sym_Or] = ACTIONS(3925),
    [anon_sym_xor] = ACTIONS(3925),
    [anon_sym_XOR] = ACTIONS(3925),
    [anon_sym_Xor] = ACTIONS(3925),
    [anon_sym_QMARK] = ACTIONS(3927),
    [sym_datetime_literal] = ACTIONS(3927),
    [sym_date_literal] = ACTIONS(3925),
    [sym_time_literal] = ACTIONS(3925),
    [sym_biginteger_literal] = ACTIONS(3927),
    [anon_sym_in] = ACTIONS(3925),
    [anon_sym_IN] = ACTIONS(3925),
    [anon_sym_In] = ACTIONS(3925),
    [sym_page_keyword] = ACTIONS(3925),
    [anon_sym_codeunit] = ACTIONS(3925),
    [anon_sym_CODEUNIT] = ACTIONS(3925),
    [anon_sym_Codeunit] = ACTIONS(3925),
    [anon_sym_CodeUnit] = ACTIONS(3925),
    [anon_sym_COdeunit] = ACTIONS(3925),
    [anon_sym_codeUnit] = ACTIONS(3925),
    [sym_report_keyword] = ACTIONS(3925),
    [sym_query_keyword] = ACTIONS(3925),
    [anon_sym_xmlport] = ACTIONS(3925),
    [anon_sym_XMLPORT] = ACTIONS(3925),
    [anon_sym_Xmlport] = ACTIONS(3925),
    [anon_sym_XMLport] = ACTIONS(3925),
    [anon_sym_XMLPort] = ACTIONS(3925),
    [anon_sym_XmlPort] = ACTIONS(3925),
    [anon_sym_enum] = ACTIONS(3925),
    [anon_sym_ENUM] = ACTIONS(3925),
    [anon_sym_Enum] = ACTIONS(3925),
    [anon_sym_eNUM] = ACTIONS(3925),
    [anon_sym_eNum] = ACTIONS(3925),
    [anon_sym_ENum] = ACTIONS(3925),
    [sym_quoted_identifier] = ACTIONS(3927),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3927),
    [sym_verbatim_string] = ACTIONS(3927),
    [sym_integer] = ACTIONS(3925),
    [sym_continue_as_identifier] = ACTIONS(3927),
    [sym_preproc_close] = ACTIONS(3927),
  },
  [STATE(3142)] = {
    [sym_identifier] = ACTIONS(3931),
    [anon_sym_DOT] = ACTIONS(3931),
    [anon_sym_EQ] = ACTIONS(3933),
    [anon_sym_COMMA] = ACTIONS(3933),
    [anon_sym_DASH] = ACTIONS(3931),
    [aux_sym_boolean_token1] = ACTIONS(3931),
    [aux_sym_boolean_token2] = ACTIONS(3931),
    [sym_decimal] = ACTIONS(3931),
    [anon_sym_LPAREN] = ACTIONS(3933),
    [anon_sym_DOT_DOT] = ACTIONS(3933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3931),
    [anon_sym_STAR] = ACTIONS(3931),
    [anon_sym_LBRACK] = ACTIONS(7241),
    [aux_sym_record_type_token1] = ACTIONS(3931),
    [aux_sym_basic_type_token21] = ACTIONS(3931),
    [aux_sym_basic_type_token22] = ACTIONS(3931),
    [aux_sym_basic_type_token48] = ACTIONS(3931),
    [anon_sym_not] = ACTIONS(3931),
    [anon_sym_NOT] = ACTIONS(3931),
    [anon_sym_Not] = ACTIONS(3931),
    [anon_sym_POUNDelif] = ACTIONS(3933),
    [anon_sym_POUNDELIF] = ACTIONS(3933),
    [anon_sym_POUNDElif] = ACTIONS(3933),
    [anon_sym_POUNDelse] = ACTIONS(3933),
    [anon_sym_POUNDELSE] = ACTIONS(3933),
    [anon_sym_POUNDElse] = ACTIONS(3933),
    [anon_sym_POUNDelse2] = ACTIONS(3933),
    [anon_sym_POUNDELSE2] = ACTIONS(3933),
    [anon_sym_POUNDElse2] = ACTIONS(3933),
    [anon_sym_POUNDendif] = ACTIONS(3933),
    [anon_sym_POUNDENDIF] = ACTIONS(3933),
    [anon_sym_POUNDEndif] = ACTIONS(3933),
    [anon_sym_POUNDendif2] = ACTIONS(3933),
    [anon_sym_POUNDENDIF2] = ACTIONS(3933),
    [anon_sym_POUNDEndif2] = ACTIONS(3933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3933),
    [aux_sym__expression_token1] = ACTIONS(3933),
    [aux_sym__expression_token2] = ACTIONS(3933),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3931),
    [anon_sym_SLASH] = ACTIONS(3931),
    [anon_sym_div] = ACTIONS(3931),
    [anon_sym_DIV] = ACTIONS(3931),
    [anon_sym_Div] = ACTIONS(3931),
    [anon_sym_mod] = ACTIONS(3931),
    [anon_sym_MOD] = ACTIONS(3931),
    [anon_sym_Mod] = ACTIONS(3931),
    [anon_sym_PLUS] = ACTIONS(3931),
    [anon_sym_GT_EQ] = ACTIONS(3933),
    [anon_sym_LT_EQ] = ACTIONS(3933),
    [anon_sym_GT] = ACTIONS(3931),
    [anon_sym_LT] = ACTIONS(3931),
    [anon_sym_LT_GT] = ACTIONS(3933),
    [anon_sym_and] = ACTIONS(3931),
    [anon_sym_AND] = ACTIONS(3931),
    [anon_sym_And] = ACTIONS(3931),
    [anon_sym_or] = ACTIONS(3931),
    [anon_sym_OR] = ACTIONS(3931),
    [anon_sym_Or] = ACTIONS(3931),
    [anon_sym_xor] = ACTIONS(3931),
    [anon_sym_XOR] = ACTIONS(3931),
    [anon_sym_Xor] = ACTIONS(3931),
    [anon_sym_QMARK] = ACTIONS(3933),
    [sym_datetime_literal] = ACTIONS(3933),
    [sym_date_literal] = ACTIONS(3931),
    [sym_time_literal] = ACTIONS(3931),
    [sym_biginteger_literal] = ACTIONS(3933),
    [anon_sym_in] = ACTIONS(3931),
    [anon_sym_IN] = ACTIONS(3931),
    [anon_sym_In] = ACTIONS(3931),
    [sym_page_keyword] = ACTIONS(3931),
    [anon_sym_codeunit] = ACTIONS(3931),
    [anon_sym_CODEUNIT] = ACTIONS(3931),
    [anon_sym_Codeunit] = ACTIONS(3931),
    [anon_sym_CodeUnit] = ACTIONS(3931),
    [anon_sym_COdeunit] = ACTIONS(3931),
    [anon_sym_codeUnit] = ACTIONS(3931),
    [sym_report_keyword] = ACTIONS(3931),
    [sym_query_keyword] = ACTIONS(3931),
    [anon_sym_xmlport] = ACTIONS(3931),
    [anon_sym_XMLPORT] = ACTIONS(3931),
    [anon_sym_Xmlport] = ACTIONS(3931),
    [anon_sym_XMLport] = ACTIONS(3931),
    [anon_sym_XMLPort] = ACTIONS(3931),
    [anon_sym_XmlPort] = ACTIONS(3931),
    [anon_sym_enum] = ACTIONS(3931),
    [anon_sym_ENUM] = ACTIONS(3931),
    [anon_sym_Enum] = ACTIONS(3931),
    [anon_sym_eNUM] = ACTIONS(3931),
    [anon_sym_eNum] = ACTIONS(3931),
    [anon_sym_ENum] = ACTIONS(3931),
    [sym_quoted_identifier] = ACTIONS(3933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3933),
    [sym_verbatim_string] = ACTIONS(3933),
    [sym_integer] = ACTIONS(3931),
    [sym_continue_as_identifier] = ACTIONS(3933),
    [sym_preproc_close] = ACTIONS(3933),
  },
  [STATE(3143)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [anon_sym_POUNDelif] = ACTIONS(3867),
    [anon_sym_POUNDELIF] = ACTIONS(3867),
    [anon_sym_POUNDElif] = ACTIONS(3867),
    [anon_sym_POUNDelse] = ACTIONS(3867),
    [anon_sym_POUNDELSE] = ACTIONS(3867),
    [anon_sym_POUNDElse] = ACTIONS(3867),
    [anon_sym_POUNDelse2] = ACTIONS(3867),
    [anon_sym_POUNDELSE2] = ACTIONS(3867),
    [anon_sym_POUNDElse2] = ACTIONS(3867),
    [anon_sym_POUNDendif] = ACTIONS(3867),
    [anon_sym_POUNDENDIF] = ACTIONS(3867),
    [anon_sym_POUNDEndif] = ACTIONS(3867),
    [anon_sym_POUNDendif2] = ACTIONS(3867),
    [anon_sym_POUNDENDIF2] = ACTIONS(3867),
    [anon_sym_POUNDEndif2] = ACTIONS(3867),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_close] = ACTIONS(3867),
  },
  [STATE(3144)] = {
    [sym_identifier] = ACTIONS(5785),
    [anon_sym_SEMI] = ACTIONS(5787),
    [anon_sym_DASH] = ACTIONS(5787),
    [aux_sym_boolean_token1] = ACTIONS(5785),
    [aux_sym_boolean_token2] = ACTIONS(5785),
    [sym_decimal] = ACTIONS(5785),
    [anon_sym_LPAREN] = ACTIONS(5787),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5785),
    [anon_sym_LBRACK] = ACTIONS(5787),
    [aux_sym_record_type_token1] = ACTIONS(5785),
    [aux_sym_basic_type_token21] = ACTIONS(5785),
    [aux_sym_basic_type_token22] = ACTIONS(5785),
    [aux_sym_basic_type_token48] = ACTIONS(5785),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5785),
    [anon_sym_POUNDif] = ACTIONS(5787),
    [anon_sym_POUNDIF] = ACTIONS(5787),
    [anon_sym_POUNDIf] = ACTIONS(5787),
    [anon_sym_not] = ACTIONS(5785),
    [anon_sym_NOT] = ACTIONS(5785),
    [anon_sym_Not] = ACTIONS(5785),
    [anon_sym_POUNDelse] = ACTIONS(5787),
    [anon_sym_POUNDELSE] = ACTIONS(5787),
    [anon_sym_POUNDElse] = ACTIONS(5787),
    [anon_sym_POUNDelse2] = ACTIONS(5787),
    [anon_sym_POUNDELSE2] = ACTIONS(5787),
    [anon_sym_POUNDElse2] = ACTIONS(5787),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5785),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5785),
    [anon_sym_PLUS] = ACTIONS(5787),
    [sym_datetime_literal] = ACTIONS(5787),
    [sym_date_literal] = ACTIONS(5785),
    [sym_time_literal] = ACTIONS(5785),
    [sym_biginteger_literal] = ACTIONS(5787),
    [anon_sym_if] = ACTIONS(5785),
    [anon_sym_IF] = ACTIONS(5785),
    [anon_sym_If] = ACTIONS(5785),
    [anon_sym_else] = ACTIONS(5785),
    [anon_sym_ELSE] = ACTIONS(5785),
    [anon_sym_Else] = ACTIONS(5785),
    [anon_sym_case] = ACTIONS(5785),
    [anon_sym_CASE] = ACTIONS(5785),
    [anon_sym_Case] = ACTIONS(5785),
    [anon_sym_for] = ACTIONS(5785),
    [anon_sym_FOR] = ACTIONS(5785),
    [anon_sym_For] = ACTIONS(5785),
    [anon_sym_foreach] = ACTIONS(5785),
    [anon_sym_FOREACH] = ACTIONS(5785),
    [anon_sym_Foreach] = ACTIONS(5785),
    [anon_sym_while] = ACTIONS(5785),
    [anon_sym_WHILE] = ACTIONS(5785),
    [anon_sym_While] = ACTIONS(5785),
    [anon_sym_repeat] = ACTIONS(5785),
    [anon_sym_REPEAT] = ACTIONS(5785),
    [anon_sym_Repeat] = ACTIONS(5785),
    [anon_sym_until] = ACTIONS(5785),
    [anon_sym_UNTIL] = ACTIONS(5785),
    [anon_sym_Until] = ACTIONS(5785),
    [anon_sym_exit] = ACTIONS(5785),
    [anon_sym_EXIT] = ACTIONS(5785),
    [anon_sym_Exit] = ACTIONS(5785),
    [anon_sym_continue] = ACTIONS(5785),
    [anon_sym_CONTINUE] = ACTIONS(5785),
    [anon_sym_Continue] = ACTIONS(5785),
    [anon_sym_break] = ACTIONS(5785),
    [anon_sym_BREAK] = ACTIONS(5785),
    [anon_sym_Break] = ACTIONS(5785),
    [anon_sym_with] = ACTIONS(5785),
    [anon_sym_WITH] = ACTIONS(5785),
    [anon_sym_With] = ACTIONS(5785),
    [sym_asserterror_keyword] = ACTIONS(5787),
    [sym_page_keyword] = ACTIONS(5785),
    [anon_sym_codeunit] = ACTIONS(5785),
    [anon_sym_CODEUNIT] = ACTIONS(5785),
    [anon_sym_Codeunit] = ACTIONS(5785),
    [anon_sym_CodeUnit] = ACTIONS(5785),
    [anon_sym_COdeunit] = ACTIONS(5785),
    [anon_sym_codeUnit] = ACTIONS(5785),
    [sym_report_keyword] = ACTIONS(5785),
    [sym_query_keyword] = ACTIONS(5785),
    [anon_sym_xmlport] = ACTIONS(5785),
    [anon_sym_XMLPORT] = ACTIONS(5785),
    [anon_sym_Xmlport] = ACTIONS(5785),
    [anon_sym_XMLport] = ACTIONS(5785),
    [anon_sym_XMLPort] = ACTIONS(5785),
    [anon_sym_XmlPort] = ACTIONS(5785),
    [anon_sym_enum] = ACTIONS(5785),
    [anon_sym_ENUM] = ACTIONS(5785),
    [anon_sym_Enum] = ACTIONS(5785),
    [anon_sym_eNUM] = ACTIONS(5785),
    [anon_sym_eNum] = ACTIONS(5785),
    [anon_sym_ENum] = ACTIONS(5785),
    [sym_quoted_identifier] = ACTIONS(5787),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5787),
    [sym_verbatim_string] = ACTIONS(5787),
    [sym_integer] = ACTIONS(5785),
    [sym_continue_as_identifier] = ACTIONS(5787),
    [sym_preproc_open] = ACTIONS(5787),
  },
  [STATE(3145)] = {
    [sym_identifier] = ACTIONS(5445),
    [anon_sym_SEMI] = ACTIONS(5447),
    [anon_sym_DASH] = ACTIONS(5447),
    [aux_sym_boolean_token1] = ACTIONS(5445),
    [aux_sym_boolean_token2] = ACTIONS(5445),
    [sym_decimal] = ACTIONS(5445),
    [anon_sym_LPAREN] = ACTIONS(5445),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5445),
    [anon_sym_LBRACK] = ACTIONS(5447),
    [aux_sym_record_type_token1] = ACTIONS(5445),
    [aux_sym_basic_type_token21] = ACTIONS(5445),
    [aux_sym_basic_type_token22] = ACTIONS(5445),
    [aux_sym_basic_type_token48] = ACTIONS(5445),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5445),
    [anon_sym_POUNDif] = ACTIONS(5447),
    [anon_sym_POUNDIF] = ACTIONS(5447),
    [anon_sym_POUNDIf] = ACTIONS(5447),
    [anon_sym_not] = ACTIONS(5445),
    [anon_sym_NOT] = ACTIONS(5445),
    [anon_sym_Not] = ACTIONS(5445),
    [anon_sym_POUNDelse] = ACTIONS(5447),
    [anon_sym_POUNDELSE] = ACTIONS(5447),
    [anon_sym_POUNDElse] = ACTIONS(5447),
    [anon_sym_POUNDelse2] = ACTIONS(5447),
    [anon_sym_POUNDELSE2] = ACTIONS(5447),
    [anon_sym_POUNDElse2] = ACTIONS(5447),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(5447),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5445),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5445),
    [anon_sym_PLUS] = ACTIONS(5447),
    [sym_datetime_literal] = ACTIONS(5447),
    [sym_date_literal] = ACTIONS(5445),
    [sym_time_literal] = ACTIONS(5445),
    [sym_biginteger_literal] = ACTIONS(5447),
    [anon_sym_if] = ACTIONS(5445),
    [anon_sym_IF] = ACTIONS(5445),
    [anon_sym_If] = ACTIONS(5445),
    [anon_sym_else] = ACTIONS(5445),
    [anon_sym_ELSE] = ACTIONS(5445),
    [anon_sym_Else] = ACTIONS(5445),
    [anon_sym_case] = ACTIONS(5445),
    [anon_sym_CASE] = ACTIONS(5445),
    [anon_sym_Case] = ACTIONS(5445),
    [anon_sym_for] = ACTIONS(5445),
    [anon_sym_FOR] = ACTIONS(5445),
    [anon_sym_For] = ACTIONS(5445),
    [anon_sym_foreach] = ACTIONS(5445),
    [anon_sym_FOREACH] = ACTIONS(5445),
    [anon_sym_Foreach] = ACTIONS(5445),
    [anon_sym_while] = ACTIONS(5445),
    [anon_sym_WHILE] = ACTIONS(5445),
    [anon_sym_While] = ACTIONS(5445),
    [anon_sym_repeat] = ACTIONS(5445),
    [anon_sym_REPEAT] = ACTIONS(5445),
    [anon_sym_Repeat] = ACTIONS(5445),
    [anon_sym_exit] = ACTIONS(5445),
    [anon_sym_EXIT] = ACTIONS(5445),
    [anon_sym_Exit] = ACTIONS(5445),
    [anon_sym_continue] = ACTIONS(5445),
    [anon_sym_CONTINUE] = ACTIONS(5445),
    [anon_sym_Continue] = ACTIONS(5445),
    [anon_sym_break] = ACTIONS(5445),
    [anon_sym_BREAK] = ACTIONS(5445),
    [anon_sym_Break] = ACTIONS(5445),
    [anon_sym_with] = ACTIONS(5445),
    [anon_sym_WITH] = ACTIONS(5445),
    [anon_sym_With] = ACTIONS(5445),
    [sym_asserterror_keyword] = ACTIONS(5447),
    [sym_page_keyword] = ACTIONS(5445),
    [anon_sym_codeunit] = ACTIONS(5445),
    [anon_sym_CODEUNIT] = ACTIONS(5445),
    [anon_sym_Codeunit] = ACTIONS(5445),
    [anon_sym_CodeUnit] = ACTIONS(5445),
    [anon_sym_COdeunit] = ACTIONS(5445),
    [anon_sym_codeUnit] = ACTIONS(5445),
    [sym_report_keyword] = ACTIONS(5445),
    [sym_query_keyword] = ACTIONS(5445),
    [anon_sym_xmlport] = ACTIONS(5445),
    [anon_sym_XMLPORT] = ACTIONS(5445),
    [anon_sym_Xmlport] = ACTIONS(5445),
    [anon_sym_XMLport] = ACTIONS(5445),
    [anon_sym_XMLPort] = ACTIONS(5445),
    [anon_sym_XmlPort] = ACTIONS(5445),
    [anon_sym_enum] = ACTIONS(5445),
    [anon_sym_ENUM] = ACTIONS(5445),
    [anon_sym_Enum] = ACTIONS(5445),
    [anon_sym_eNUM] = ACTIONS(5445),
    [anon_sym_eNum] = ACTIONS(5445),
    [anon_sym_ENum] = ACTIONS(5445),
    [sym_quoted_identifier] = ACTIONS(5447),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5447),
    [sym_verbatim_string] = ACTIONS(5447),
    [sym_integer] = ACTIONS(5445),
    [sym_continue_as_identifier] = ACTIONS(5447),
    [sym_preproc_open] = ACTIONS(5447),
    [sym_end_keyword] = ACTIONS(5447),
  },
  [STATE(3146)] = {
    [sym__body_element] = STATE(3426),
    [sym_empty_statement] = STATE(3426),
    [sym_property] = STATE(3426),
    [sym_permissions_property] = STATE(3426),
    [sym_table_relation_property] = STATE(3426),
    [sym_fields_section] = STATE(3426),
    [sym_keys_section] = STATE(3426),
    [sym_fieldgroups_section] = STATE(3426),
    [sym_enum_value_declaration] = STATE(3426),
    [sym_labels_section] = STATE(3426),
    [sym_layout_section] = STATE(3426),
    [sym_modify_modification] = STATE(3426),
    [sym_actions_section] = STATE(3426),
    [sym_views_section] = STATE(3426),
    [sym_dataset_section] = STATE(3426),
    [sym_requestpage_section] = STATE(3426),
    [sym_rendering_section] = STATE(3426),
    [sym_elements_section] = STATE(3426),
    [sym_schema_section] = STATE(3426),
    [sym_assembly_declaration] = STATE(3426),
    [sym_event_declaration] = STATE(3426),
    [sym_procedure] = STATE(3426),
    [sym_preproc_split_procedure] = STATE(3426),
    [sym_preproc_split_procedure_preamble] = STATE(3426),
    [sym__procedure_header] = STATE(10710),
    [sym_procedure_modifier] = STATE(17047),
    [sym_trigger_declaration] = STATE(3426),
    [sym_var_section] = STATE(3426),
    [sym_var_attribute_item] = STATE(3426),
    [sym_variable_declaration] = STATE(3426),
    [sym_attribute_item] = STATE(6747),
    [sym_preproc_conditional] = STATE(3426),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3780),
    [sym_preproc_endif] = STATE(11139),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym__procedure_header_repeat1] = STATE(14336),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3426),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10713),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7259),
    [anon_sym_POUNDENDIF] = ACTIONS(7259),
    [anon_sym_POUNDEndif] = ACTIONS(7259),
    [anon_sym_POUNDendif2] = ACTIONS(7259),
    [anon_sym_POUNDENDIF2] = ACTIONS(7259),
    [anon_sym_POUNDEndif2] = ACTIONS(7259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7261),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7259),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3147)] = {
    [sym_else_keyword] = STATE(427),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_if] = ACTIONS(5453),
    [anon_sym_IF] = ACTIONS(5453),
    [anon_sym_If] = ACTIONS(5453),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5453),
    [anon_sym_CASE] = ACTIONS(5453),
    [anon_sym_Case] = ACTIONS(5453),
    [anon_sym_for] = ACTIONS(5453),
    [anon_sym_FOR] = ACTIONS(5453),
    [anon_sym_For] = ACTIONS(5453),
    [anon_sym_foreach] = ACTIONS(5453),
    [anon_sym_FOREACH] = ACTIONS(5453),
    [anon_sym_Foreach] = ACTIONS(5453),
    [anon_sym_while] = ACTIONS(5453),
    [anon_sym_WHILE] = ACTIONS(5453),
    [anon_sym_While] = ACTIONS(5453),
    [anon_sym_repeat] = ACTIONS(5453),
    [anon_sym_REPEAT] = ACTIONS(5453),
    [anon_sym_Repeat] = ACTIONS(5453),
    [anon_sym_exit] = ACTIONS(5453),
    [anon_sym_EXIT] = ACTIONS(5453),
    [anon_sym_Exit] = ACTIONS(5453),
    [anon_sym_continue] = ACTIONS(5453),
    [anon_sym_CONTINUE] = ACTIONS(5453),
    [anon_sym_Continue] = ACTIONS(5453),
    [anon_sym_break] = ACTIONS(5453),
    [anon_sym_BREAK] = ACTIONS(5453),
    [anon_sym_Break] = ACTIONS(5453),
    [anon_sym_with] = ACTIONS(5453),
    [anon_sym_WITH] = ACTIONS(5453),
    [anon_sym_With] = ACTIONS(5453),
    [sym_asserterror_keyword] = ACTIONS(5455),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_end_keyword] = ACTIONS(5455),
  },
  [STATE(3148)] = {
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_RBRACE] = ACTIONS(3786),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [aux_sym_where_clause_token1] = ACTIONS(3786),
    [aux_sym_where_condition_token1] = ACTIONS(3784),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3786),
    [anon_sym_STAR] = ACTIONS(3784),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3786),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3786),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_basic_type_token6] = ACTIONS(3784),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3786),
    [aux_sym_addafter_modification_token1] = ACTIONS(3786),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3786),
    [aux_sym_modify_modification_token1] = ACTIONS(3786),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3786),
    [aux_sym_movelast_modification_token1] = ACTIONS(3786),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3786),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3786),
    [aux_sym_separator_action_token1] = ACTIONS(3786),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3786),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3786),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3786),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3786),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3786),
    [anon_sym_DIV] = ACTIONS(3786),
    [anon_sym_Div] = ACTIONS(3786),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3786),
    [anon_sym_AND] = ACTIONS(3786),
    [anon_sym_And] = ACTIONS(3786),
    [anon_sym_or] = ACTIONS(3786),
    [anon_sym_OR] = ACTIONS(3786),
    [anon_sym_Or] = ACTIONS(3786),
    [anon_sym_xor] = ACTIONS(3786),
    [anon_sym_XOR] = ACTIONS(3786),
    [anon_sym_Xor] = ACTIONS(3786),
    [anon_sym_QMARK] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_procedure_keyword] = ACTIONS(3786),
    [sym_trigger_keyword] = ACTIONS(3786),
    [sym_var_keyword] = ACTIONS(3786),
    [sym_local_keyword] = ACTIONS(3786),
    [sym_internal_keyword] = ACTIONS(3786),
    [sym_protected_keyword] = ACTIONS(3786),
    [sym_event_keyword] = ACTIONS(3786),
    [sym_fields_keyword] = ACTIONS(3786),
    [sym_keys_keyword] = ACTIONS(3786),
    [sym_fieldgroups_keyword] = ACTIONS(3786),
    [sym_actions_keyword] = ACTIONS(3786),
    [sym_layout_keyword] = ACTIONS(3786),
    [sym_area_keyword] = ACTIONS(3786),
    [sym_group_keyword] = ACTIONS(3786),
    [sym_repeater_keyword] = ACTIONS(3786),
    [sym_cuegroup_keyword] = ACTIONS(3786),
    [sym_fixed_keyword] = ACTIONS(3786),
    [sym_grid_keyword] = ACTIONS(3786),
    [sym_part_keyword] = ACTIONS(3786),
    [sym_systempart_keyword] = ACTIONS(3786),
    [sym_usercontrol_keyword] = ACTIONS(3786),
    [sym_dataset_keyword] = ACTIONS(3786),
    [sym_elements_keyword] = ACTIONS(3786),
    [sym_dataitem_keyword] = ACTIONS(3786),
    [sym_column_keyword] = ACTIONS(3786),
    [sym_filter_keyword] = ACTIONS(3786),
    [sym_labels_keyword] = ACTIONS(3786),
    [sym_rendering_keyword] = ACTIONS(3786),
    [sym_requestpage_keyword] = ACTIONS(3786),
    [sym_schema_keyword] = ACTIONS(3786),
    [sym_views_keyword] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
  },
  [STATE(3149)] = {
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_RBRACE] = ACTIONS(3564),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3562),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3564),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3564),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_basic_type_token6] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3564),
    [aux_sym_addafter_modification_token1] = ACTIONS(3564),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3564),
    [aux_sym_modify_modification_token1] = ACTIONS(3564),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3564),
    [aux_sym_movelast_modification_token1] = ACTIONS(3564),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3564),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3564),
    [aux_sym_separator_action_token1] = ACTIONS(3564),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3564),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3564),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3564),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3564),
    [anon_sym_DIV] = ACTIONS(3564),
    [anon_sym_Div] = ACTIONS(3564),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3564),
    [anon_sym_AND] = ACTIONS(3564),
    [anon_sym_And] = ACTIONS(3564),
    [anon_sym_or] = ACTIONS(3564),
    [anon_sym_OR] = ACTIONS(3564),
    [anon_sym_Or] = ACTIONS(3564),
    [anon_sym_xor] = ACTIONS(3564),
    [anon_sym_XOR] = ACTIONS(3564),
    [anon_sym_Xor] = ACTIONS(3564),
    [anon_sym_QMARK] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_procedure_keyword] = ACTIONS(3564),
    [sym_trigger_keyword] = ACTIONS(3564),
    [sym_var_keyword] = ACTIONS(3564),
    [sym_local_keyword] = ACTIONS(3564),
    [sym_internal_keyword] = ACTIONS(3564),
    [sym_protected_keyword] = ACTIONS(3564),
    [sym_event_keyword] = ACTIONS(3564),
    [sym_fields_keyword] = ACTIONS(3564),
    [sym_keys_keyword] = ACTIONS(3564),
    [sym_fieldgroups_keyword] = ACTIONS(3564),
    [sym_actions_keyword] = ACTIONS(3564),
    [sym_layout_keyword] = ACTIONS(3564),
    [sym_area_keyword] = ACTIONS(3564),
    [sym_group_keyword] = ACTIONS(3564),
    [sym_repeater_keyword] = ACTIONS(3564),
    [sym_cuegroup_keyword] = ACTIONS(3564),
    [sym_fixed_keyword] = ACTIONS(3564),
    [sym_grid_keyword] = ACTIONS(3564),
    [sym_part_keyword] = ACTIONS(3564),
    [sym_systempart_keyword] = ACTIONS(3564),
    [sym_usercontrol_keyword] = ACTIONS(3564),
    [sym_dataset_keyword] = ACTIONS(3564),
    [sym_elements_keyword] = ACTIONS(3564),
    [sym_dataitem_keyword] = ACTIONS(3564),
    [sym_column_keyword] = ACTIONS(3564),
    [sym_filter_keyword] = ACTIONS(3564),
    [sym_labels_keyword] = ACTIONS(3564),
    [sym_rendering_keyword] = ACTIONS(3564),
    [sym_requestpage_keyword] = ACTIONS(3564),
    [sym_schema_keyword] = ACTIONS(3564),
    [sym_views_keyword] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
  },
  [STATE(3150)] = {
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_RBRACE] = ACTIONS(3564),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3663),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3564),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3564),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_basic_type_token6] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3564),
    [aux_sym_addafter_modification_token1] = ACTIONS(3564),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3564),
    [aux_sym_modify_modification_token1] = ACTIONS(3564),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3564),
    [aux_sym_movelast_modification_token1] = ACTIONS(3564),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3564),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3564),
    [aux_sym_separator_action_token1] = ACTIONS(3564),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3564),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3564),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3564),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3665),
    [anon_sym_DIV] = ACTIONS(3665),
    [anon_sym_Div] = ACTIONS(3665),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3665),
    [anon_sym_AND] = ACTIONS(3665),
    [anon_sym_And] = ACTIONS(3665),
    [anon_sym_or] = ACTIONS(3665),
    [anon_sym_OR] = ACTIONS(3665),
    [anon_sym_Or] = ACTIONS(3665),
    [anon_sym_xor] = ACTIONS(3665),
    [anon_sym_XOR] = ACTIONS(3665),
    [anon_sym_Xor] = ACTIONS(3665),
    [anon_sym_QMARK] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_procedure_keyword] = ACTIONS(3564),
    [sym_trigger_keyword] = ACTIONS(3564),
    [sym_var_keyword] = ACTIONS(3564),
    [sym_local_keyword] = ACTIONS(3564),
    [sym_internal_keyword] = ACTIONS(3564),
    [sym_protected_keyword] = ACTIONS(3564),
    [sym_event_keyword] = ACTIONS(3564),
    [sym_fields_keyword] = ACTIONS(3564),
    [sym_keys_keyword] = ACTIONS(3564),
    [sym_fieldgroups_keyword] = ACTIONS(3564),
    [sym_actions_keyword] = ACTIONS(3564),
    [sym_layout_keyword] = ACTIONS(3564),
    [sym_area_keyword] = ACTIONS(3564),
    [sym_group_keyword] = ACTIONS(3564),
    [sym_repeater_keyword] = ACTIONS(3564),
    [sym_cuegroup_keyword] = ACTIONS(3564),
    [sym_fixed_keyword] = ACTIONS(3564),
    [sym_grid_keyword] = ACTIONS(3564),
    [sym_part_keyword] = ACTIONS(3564),
    [sym_systempart_keyword] = ACTIONS(3564),
    [sym_usercontrol_keyword] = ACTIONS(3564),
    [sym_dataset_keyword] = ACTIONS(3564),
    [sym_elements_keyword] = ACTIONS(3564),
    [sym_dataitem_keyword] = ACTIONS(3564),
    [sym_column_keyword] = ACTIONS(3564),
    [sym_filter_keyword] = ACTIONS(3564),
    [sym_labels_keyword] = ACTIONS(3564),
    [sym_rendering_keyword] = ACTIONS(3564),
    [sym_requestpage_keyword] = ACTIONS(3564),
    [sym_schema_keyword] = ACTIONS(3564),
    [sym_views_keyword] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
  },
  [STATE(3151)] = {
    [sym__body_element] = STATE(3427),
    [sym_empty_statement] = STATE(3427),
    [sym_property] = STATE(3427),
    [sym_permissions_property] = STATE(3427),
    [sym_table_relation_property] = STATE(3427),
    [sym_fields_section] = STATE(3427),
    [sym_keys_section] = STATE(3427),
    [sym_fieldgroups_section] = STATE(3427),
    [sym_enum_value_declaration] = STATE(3427),
    [sym_labels_section] = STATE(3427),
    [sym_layout_section] = STATE(3427),
    [sym_modify_modification] = STATE(3427),
    [sym_actions_section] = STATE(3427),
    [sym_views_section] = STATE(3427),
    [sym_dataset_section] = STATE(3427),
    [sym_requestpage_section] = STATE(3427),
    [sym_rendering_section] = STATE(3427),
    [sym_elements_section] = STATE(3427),
    [sym_schema_section] = STATE(3427),
    [sym_assembly_declaration] = STATE(3427),
    [sym_event_declaration] = STATE(3427),
    [sym_procedure] = STATE(3427),
    [sym_preproc_split_procedure] = STATE(3427),
    [sym_preproc_split_procedure_preamble] = STATE(3427),
    [sym__procedure_header] = STATE(10974),
    [sym_procedure_modifier] = STATE(17047),
    [sym_trigger_declaration] = STATE(3427),
    [sym_var_section] = STATE(3427),
    [sym_var_attribute_item] = STATE(3427),
    [sym_variable_declaration] = STATE(3427),
    [sym_attribute_item] = STATE(6747),
    [sym_preproc_conditional] = STATE(3427),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3804),
    [sym_preproc_endif] = STATE(5538),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym__procedure_header_repeat1] = STATE(14336),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3427),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(11021),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7303),
    [anon_sym_POUNDENDIF] = ACTIONS(7303),
    [anon_sym_POUNDEndif] = ACTIONS(7303),
    [anon_sym_POUNDendif2] = ACTIONS(7303),
    [anon_sym_POUNDENDIF2] = ACTIONS(7303),
    [anon_sym_POUNDEndif2] = ACTIONS(7303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7261),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7303),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3152)] = {
    [sym__body_element] = STATE(3424),
    [sym_empty_statement] = STATE(3424),
    [sym_property] = STATE(3424),
    [sym_permissions_property] = STATE(3424),
    [sym_table_relation_property] = STATE(3424),
    [sym_fields_section] = STATE(3424),
    [sym_keys_section] = STATE(3424),
    [sym_fieldgroups_section] = STATE(3424),
    [sym_enum_value_declaration] = STATE(3424),
    [sym_labels_section] = STATE(3424),
    [sym_layout_section] = STATE(3424),
    [sym_modify_modification] = STATE(3424),
    [sym_actions_section] = STATE(3424),
    [sym_views_section] = STATE(3424),
    [sym_dataset_section] = STATE(3424),
    [sym_requestpage_section] = STATE(3424),
    [sym_rendering_section] = STATE(3424),
    [sym_elements_section] = STATE(3424),
    [sym_schema_section] = STATE(3424),
    [sym_assembly_declaration] = STATE(3424),
    [sym_event_declaration] = STATE(3424),
    [sym_procedure] = STATE(3424),
    [sym_preproc_split_procedure] = STATE(3424),
    [sym_preproc_split_procedure_preamble] = STATE(3424),
    [sym__procedure_header] = STATE(10968),
    [sym_procedure_modifier] = STATE(17047),
    [sym_trigger_declaration] = STATE(3424),
    [sym_var_section] = STATE(3424),
    [sym_var_attribute_item] = STATE(3424),
    [sym_variable_declaration] = STATE(3424),
    [sym_attribute_item] = STATE(6747),
    [sym_preproc_conditional] = STATE(3424),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3759),
    [sym_preproc_endif] = STATE(4011),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym__procedure_header_repeat1] = STATE(14336),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3424),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10663),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7261),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3153)] = {
    [sym_identifier] = ACTIONS(5461),
    [anon_sym_SEMI] = ACTIONS(5463),
    [anon_sym_DASH] = ACTIONS(5463),
    [aux_sym_boolean_token1] = ACTIONS(5461),
    [aux_sym_boolean_token2] = ACTIONS(5461),
    [sym_decimal] = ACTIONS(5461),
    [anon_sym_LPAREN] = ACTIONS(5461),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5461),
    [anon_sym_LBRACK] = ACTIONS(5463),
    [aux_sym_record_type_token1] = ACTIONS(5461),
    [aux_sym_basic_type_token21] = ACTIONS(5461),
    [aux_sym_basic_type_token22] = ACTIONS(5461),
    [aux_sym_basic_type_token48] = ACTIONS(5461),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5461),
    [anon_sym_POUNDif] = ACTIONS(5463),
    [anon_sym_POUNDIF] = ACTIONS(5463),
    [anon_sym_POUNDIf] = ACTIONS(5463),
    [anon_sym_not] = ACTIONS(5461),
    [anon_sym_NOT] = ACTIONS(5461),
    [anon_sym_Not] = ACTIONS(5461),
    [anon_sym_POUNDelse] = ACTIONS(5463),
    [anon_sym_POUNDELSE] = ACTIONS(5463),
    [anon_sym_POUNDElse] = ACTIONS(5463),
    [anon_sym_POUNDelse2] = ACTIONS(5463),
    [anon_sym_POUNDELSE2] = ACTIONS(5463),
    [anon_sym_POUNDElse2] = ACTIONS(5463),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_LPAREN2] = ACTIONS(7305),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5461),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5461),
    [anon_sym_PLUS] = ACTIONS(5463),
    [sym_datetime_literal] = ACTIONS(5463),
    [sym_date_literal] = ACTIONS(5461),
    [sym_time_literal] = ACTIONS(5461),
    [sym_biginteger_literal] = ACTIONS(5463),
    [anon_sym_if] = ACTIONS(5461),
    [anon_sym_IF] = ACTIONS(5461),
    [anon_sym_If] = ACTIONS(5461),
    [anon_sym_else] = ACTIONS(5461),
    [anon_sym_ELSE] = ACTIONS(5461),
    [anon_sym_Else] = ACTIONS(5461),
    [anon_sym_case] = ACTIONS(5461),
    [anon_sym_CASE] = ACTIONS(5461),
    [anon_sym_Case] = ACTIONS(5461),
    [anon_sym_for] = ACTIONS(5461),
    [anon_sym_FOR] = ACTIONS(5461),
    [anon_sym_For] = ACTIONS(5461),
    [anon_sym_foreach] = ACTIONS(5461),
    [anon_sym_FOREACH] = ACTIONS(5461),
    [anon_sym_Foreach] = ACTIONS(5461),
    [anon_sym_while] = ACTIONS(5461),
    [anon_sym_WHILE] = ACTIONS(5461),
    [anon_sym_While] = ACTIONS(5461),
    [anon_sym_repeat] = ACTIONS(5461),
    [anon_sym_REPEAT] = ACTIONS(5461),
    [anon_sym_Repeat] = ACTIONS(5461),
    [anon_sym_exit] = ACTIONS(5461),
    [anon_sym_EXIT] = ACTIONS(5461),
    [anon_sym_Exit] = ACTIONS(5461),
    [anon_sym_continue] = ACTIONS(5461),
    [anon_sym_CONTINUE] = ACTIONS(5461),
    [anon_sym_Continue] = ACTIONS(5461),
    [anon_sym_break] = ACTIONS(5461),
    [anon_sym_BREAK] = ACTIONS(5461),
    [anon_sym_Break] = ACTIONS(5461),
    [anon_sym_with] = ACTIONS(5461),
    [anon_sym_WITH] = ACTIONS(5461),
    [anon_sym_With] = ACTIONS(5461),
    [sym_asserterror_keyword] = ACTIONS(5463),
    [sym_page_keyword] = ACTIONS(5461),
    [anon_sym_codeunit] = ACTIONS(5461),
    [anon_sym_CODEUNIT] = ACTIONS(5461),
    [anon_sym_Codeunit] = ACTIONS(5461),
    [anon_sym_CodeUnit] = ACTIONS(5461),
    [anon_sym_COdeunit] = ACTIONS(5461),
    [anon_sym_codeUnit] = ACTIONS(5461),
    [sym_report_keyword] = ACTIONS(5461),
    [sym_query_keyword] = ACTIONS(5461),
    [anon_sym_xmlport] = ACTIONS(5461),
    [anon_sym_XMLPORT] = ACTIONS(5461),
    [anon_sym_Xmlport] = ACTIONS(5461),
    [anon_sym_XMLport] = ACTIONS(5461),
    [anon_sym_XMLPort] = ACTIONS(5461),
    [anon_sym_XmlPort] = ACTIONS(5461),
    [anon_sym_enum] = ACTIONS(5461),
    [anon_sym_ENUM] = ACTIONS(5461),
    [anon_sym_Enum] = ACTIONS(5461),
    [anon_sym_eNUM] = ACTIONS(5461),
    [anon_sym_eNum] = ACTIONS(5461),
    [anon_sym_ENum] = ACTIONS(5461),
    [sym_quoted_identifier] = ACTIONS(5463),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5463),
    [sym_verbatim_string] = ACTIONS(5463),
    [sym_integer] = ACTIONS(5461),
    [sym_continue_as_identifier] = ACTIONS(5463),
    [sym_preproc_open] = ACTIONS(5463),
    [sym_end_keyword] = ACTIONS(5463),
  },
  [STATE(3154)] = {
    [sym__body_element] = STATE(3422),
    [sym_empty_statement] = STATE(3422),
    [sym_property] = STATE(3422),
    [sym_permissions_property] = STATE(3422),
    [sym_table_relation_property] = STATE(3422),
    [sym_fields_section] = STATE(3422),
    [sym_keys_section] = STATE(3422),
    [sym_fieldgroups_section] = STATE(3422),
    [sym_enum_value_declaration] = STATE(3422),
    [sym_labels_section] = STATE(3422),
    [sym_layout_section] = STATE(3422),
    [sym_modify_modification] = STATE(3422),
    [sym_actions_section] = STATE(3422),
    [sym_views_section] = STATE(3422),
    [sym_dataset_section] = STATE(3422),
    [sym_requestpage_section] = STATE(3422),
    [sym_rendering_section] = STATE(3422),
    [sym_elements_section] = STATE(3422),
    [sym_schema_section] = STATE(3422),
    [sym_assembly_declaration] = STATE(3422),
    [sym_event_declaration] = STATE(3422),
    [sym_procedure] = STATE(3422),
    [sym_preproc_split_procedure] = STATE(3422),
    [sym_preproc_split_procedure_preamble] = STATE(3422),
    [sym__procedure_header] = STATE(10669),
    [sym_procedure_modifier] = STATE(17047),
    [sym_trigger_declaration] = STATE(3422),
    [sym_var_section] = STATE(3422),
    [sym_var_attribute_item] = STATE(3422),
    [sym_variable_declaration] = STATE(3422),
    [sym_attribute_item] = STATE(6747),
    [sym_preproc_conditional] = STATE(3422),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3772),
    [sym_preproc_endif] = STATE(11052),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym__procedure_header_repeat1] = STATE(14336),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3422),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10861),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7307),
    [anon_sym_POUNDENDIF] = ACTIONS(7307),
    [anon_sym_POUNDEndif] = ACTIONS(7307),
    [anon_sym_POUNDendif2] = ACTIONS(7307),
    [anon_sym_POUNDENDIF2] = ACTIONS(7307),
    [anon_sym_POUNDEndif2] = ACTIONS(7307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7261),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7307),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3155)] = {
    [sym_else_keyword] = STATE(602),
    [sym_identifier] = ACTIONS(5431),
    [anon_sym_SEMI] = ACTIONS(5433),
    [anon_sym_DASH] = ACTIONS(5433),
    [aux_sym_boolean_token1] = ACTIONS(5431),
    [aux_sym_boolean_token2] = ACTIONS(5431),
    [sym_decimal] = ACTIONS(5431),
    [anon_sym_LPAREN] = ACTIONS(5433),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5431),
    [anon_sym_LBRACK] = ACTIONS(5433),
    [aux_sym_record_type_token1] = ACTIONS(5431),
    [aux_sym_basic_type_token21] = ACTIONS(5431),
    [aux_sym_basic_type_token22] = ACTIONS(5431),
    [aux_sym_basic_type_token48] = ACTIONS(5431),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5431),
    [anon_sym_POUNDif] = ACTIONS(5433),
    [anon_sym_POUNDIF] = ACTIONS(5433),
    [anon_sym_POUNDIf] = ACTIONS(5433),
    [anon_sym_not] = ACTIONS(5431),
    [anon_sym_NOT] = ACTIONS(5431),
    [anon_sym_Not] = ACTIONS(5431),
    [anon_sym_POUNDelse] = ACTIONS(5433),
    [anon_sym_POUNDELSE] = ACTIONS(5433),
    [anon_sym_POUNDElse] = ACTIONS(5433),
    [anon_sym_POUNDelse2] = ACTIONS(5433),
    [anon_sym_POUNDELSE2] = ACTIONS(5433),
    [anon_sym_POUNDElse2] = ACTIONS(5433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5431),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5431),
    [anon_sym_PLUS] = ACTIONS(5433),
    [sym_datetime_literal] = ACTIONS(5433),
    [sym_date_literal] = ACTIONS(5431),
    [sym_time_literal] = ACTIONS(5431),
    [sym_biginteger_literal] = ACTIONS(5433),
    [anon_sym_if] = ACTIONS(5431),
    [anon_sym_IF] = ACTIONS(5431),
    [anon_sym_If] = ACTIONS(5431),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5431),
    [anon_sym_CASE] = ACTIONS(5431),
    [anon_sym_Case] = ACTIONS(5431),
    [anon_sym_for] = ACTIONS(5431),
    [anon_sym_FOR] = ACTIONS(5431),
    [anon_sym_For] = ACTIONS(5431),
    [anon_sym_foreach] = ACTIONS(5431),
    [anon_sym_FOREACH] = ACTIONS(5431),
    [anon_sym_Foreach] = ACTIONS(5431),
    [anon_sym_while] = ACTIONS(5431),
    [anon_sym_WHILE] = ACTIONS(5431),
    [anon_sym_While] = ACTIONS(5431),
    [anon_sym_repeat] = ACTIONS(5431),
    [anon_sym_REPEAT] = ACTIONS(5431),
    [anon_sym_Repeat] = ACTIONS(5431),
    [anon_sym_exit] = ACTIONS(5431),
    [anon_sym_EXIT] = ACTIONS(5431),
    [anon_sym_Exit] = ACTIONS(5431),
    [anon_sym_continue] = ACTIONS(5431),
    [anon_sym_CONTINUE] = ACTIONS(5431),
    [anon_sym_Continue] = ACTIONS(5431),
    [anon_sym_break] = ACTIONS(5431),
    [anon_sym_BREAK] = ACTIONS(5431),
    [anon_sym_Break] = ACTIONS(5431),
    [anon_sym_with] = ACTIONS(5431),
    [anon_sym_WITH] = ACTIONS(5431),
    [anon_sym_With] = ACTIONS(5431),
    [sym_asserterror_keyword] = ACTIONS(5433),
    [sym_page_keyword] = ACTIONS(5431),
    [anon_sym_codeunit] = ACTIONS(5431),
    [anon_sym_CODEUNIT] = ACTIONS(5431),
    [anon_sym_Codeunit] = ACTIONS(5431),
    [anon_sym_CodeUnit] = ACTIONS(5431),
    [anon_sym_COdeunit] = ACTIONS(5431),
    [anon_sym_codeUnit] = ACTIONS(5431),
    [sym_report_keyword] = ACTIONS(5431),
    [sym_query_keyword] = ACTIONS(5431),
    [anon_sym_xmlport] = ACTIONS(5431),
    [anon_sym_XMLPORT] = ACTIONS(5431),
    [anon_sym_Xmlport] = ACTIONS(5431),
    [anon_sym_XMLport] = ACTIONS(5431),
    [anon_sym_XMLPort] = ACTIONS(5431),
    [anon_sym_XmlPort] = ACTIONS(5431),
    [anon_sym_enum] = ACTIONS(5431),
    [anon_sym_ENUM] = ACTIONS(5431),
    [anon_sym_Enum] = ACTIONS(5431),
    [anon_sym_eNUM] = ACTIONS(5431),
    [anon_sym_eNum] = ACTIONS(5431),
    [anon_sym_ENum] = ACTIONS(5431),
    [sym_quoted_identifier] = ACTIONS(5433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5433),
    [sym_verbatim_string] = ACTIONS(5433),
    [sym_integer] = ACTIONS(5431),
    [sym_continue_as_identifier] = ACTIONS(5433),
    [sym_preproc_open] = ACTIONS(5433),
    [sym_end_keyword] = ACTIONS(5433),
  },
  [STATE(3156)] = {
    [sym_else_keyword] = STATE(606),
    [sym_identifier] = ACTIONS(5481),
    [anon_sym_SEMI] = ACTIONS(5483),
    [anon_sym_DASH] = ACTIONS(5483),
    [aux_sym_boolean_token1] = ACTIONS(5481),
    [aux_sym_boolean_token2] = ACTIONS(5481),
    [sym_decimal] = ACTIONS(5481),
    [anon_sym_LPAREN] = ACTIONS(5483),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5481),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [aux_sym_record_type_token1] = ACTIONS(5481),
    [aux_sym_basic_type_token21] = ACTIONS(5481),
    [aux_sym_basic_type_token22] = ACTIONS(5481),
    [aux_sym_basic_type_token48] = ACTIONS(5481),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5481),
    [anon_sym_POUNDif] = ACTIONS(5483),
    [anon_sym_POUNDIF] = ACTIONS(5483),
    [anon_sym_POUNDIf] = ACTIONS(5483),
    [anon_sym_not] = ACTIONS(5481),
    [anon_sym_NOT] = ACTIONS(5481),
    [anon_sym_Not] = ACTIONS(5481),
    [anon_sym_POUNDelse] = ACTIONS(5483),
    [anon_sym_POUNDELSE] = ACTIONS(5483),
    [anon_sym_POUNDElse] = ACTIONS(5483),
    [anon_sym_POUNDelse2] = ACTIONS(5483),
    [anon_sym_POUNDELSE2] = ACTIONS(5483),
    [anon_sym_POUNDElse2] = ACTIONS(5483),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5481),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5481),
    [anon_sym_PLUS] = ACTIONS(5483),
    [sym_datetime_literal] = ACTIONS(5483),
    [sym_date_literal] = ACTIONS(5481),
    [sym_time_literal] = ACTIONS(5481),
    [sym_biginteger_literal] = ACTIONS(5483),
    [anon_sym_if] = ACTIONS(5481),
    [anon_sym_IF] = ACTIONS(5481),
    [anon_sym_If] = ACTIONS(5481),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5481),
    [anon_sym_CASE] = ACTIONS(5481),
    [anon_sym_Case] = ACTIONS(5481),
    [anon_sym_for] = ACTIONS(5481),
    [anon_sym_FOR] = ACTIONS(5481),
    [anon_sym_For] = ACTIONS(5481),
    [anon_sym_foreach] = ACTIONS(5481),
    [anon_sym_FOREACH] = ACTIONS(5481),
    [anon_sym_Foreach] = ACTIONS(5481),
    [anon_sym_while] = ACTIONS(5481),
    [anon_sym_WHILE] = ACTIONS(5481),
    [anon_sym_While] = ACTIONS(5481),
    [anon_sym_repeat] = ACTIONS(5481),
    [anon_sym_REPEAT] = ACTIONS(5481),
    [anon_sym_Repeat] = ACTIONS(5481),
    [anon_sym_exit] = ACTIONS(5481),
    [anon_sym_EXIT] = ACTIONS(5481),
    [anon_sym_Exit] = ACTIONS(5481),
    [anon_sym_continue] = ACTIONS(5481),
    [anon_sym_CONTINUE] = ACTIONS(5481),
    [anon_sym_Continue] = ACTIONS(5481),
    [anon_sym_break] = ACTIONS(5481),
    [anon_sym_BREAK] = ACTIONS(5481),
    [anon_sym_Break] = ACTIONS(5481),
    [anon_sym_with] = ACTIONS(5481),
    [anon_sym_WITH] = ACTIONS(5481),
    [anon_sym_With] = ACTIONS(5481),
    [sym_asserterror_keyword] = ACTIONS(5483),
    [sym_page_keyword] = ACTIONS(5481),
    [anon_sym_codeunit] = ACTIONS(5481),
    [anon_sym_CODEUNIT] = ACTIONS(5481),
    [anon_sym_Codeunit] = ACTIONS(5481),
    [anon_sym_CodeUnit] = ACTIONS(5481),
    [anon_sym_COdeunit] = ACTIONS(5481),
    [anon_sym_codeUnit] = ACTIONS(5481),
    [sym_report_keyword] = ACTIONS(5481),
    [sym_query_keyword] = ACTIONS(5481),
    [anon_sym_xmlport] = ACTIONS(5481),
    [anon_sym_XMLPORT] = ACTIONS(5481),
    [anon_sym_Xmlport] = ACTIONS(5481),
    [anon_sym_XMLport] = ACTIONS(5481),
    [anon_sym_XMLPort] = ACTIONS(5481),
    [anon_sym_XmlPort] = ACTIONS(5481),
    [anon_sym_enum] = ACTIONS(5481),
    [anon_sym_ENUM] = ACTIONS(5481),
    [anon_sym_Enum] = ACTIONS(5481),
    [anon_sym_eNUM] = ACTIONS(5481),
    [anon_sym_eNum] = ACTIONS(5481),
    [anon_sym_ENum] = ACTIONS(5481),
    [sym_quoted_identifier] = ACTIONS(5483),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5483),
    [sym_verbatim_string] = ACTIONS(5483),
    [sym_integer] = ACTIONS(5481),
    [sym_continue_as_identifier] = ACTIONS(5483),
    [sym_preproc_open] = ACTIONS(5483),
    [sym_end_keyword] = ACTIONS(5483),
  },
  [STATE(3157)] = {
    [sym__body_element] = STATE(3429),
    [sym_empty_statement] = STATE(3429),
    [sym_property] = STATE(3429),
    [sym_permissions_property] = STATE(3429),
    [sym_table_relation_property] = STATE(3429),
    [sym_fields_section] = STATE(3429),
    [sym_keys_section] = STATE(3429),
    [sym_fieldgroups_section] = STATE(3429),
    [sym_enum_value_declaration] = STATE(3429),
    [sym_labels_section] = STATE(3429),
    [sym_layout_section] = STATE(3429),
    [sym_modify_modification] = STATE(3429),
    [sym_actions_section] = STATE(3429),
    [sym_views_section] = STATE(3429),
    [sym_dataset_section] = STATE(3429),
    [sym_requestpage_section] = STATE(3429),
    [sym_rendering_section] = STATE(3429),
    [sym_elements_section] = STATE(3429),
    [sym_schema_section] = STATE(3429),
    [sym_assembly_declaration] = STATE(3429),
    [sym_event_declaration] = STATE(3429),
    [sym_procedure] = STATE(3429),
    [sym_preproc_split_procedure] = STATE(3429),
    [sym_preproc_split_procedure_preamble] = STATE(3429),
    [sym__procedure_header] = STATE(10911),
    [sym_procedure_modifier] = STATE(17047),
    [sym_trigger_declaration] = STATE(3429),
    [sym_var_section] = STATE(3429),
    [sym_var_attribute_item] = STATE(3429),
    [sym_variable_declaration] = STATE(3429),
    [sym_attribute_item] = STATE(6747),
    [sym_preproc_conditional] = STATE(3429),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3766),
    [sym_preproc_endif] = STATE(9741),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym__procedure_header_repeat1] = STATE(14336),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3429),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(11005),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7309),
    [anon_sym_POUNDENDIF] = ACTIONS(7309),
    [anon_sym_POUNDEndif] = ACTIONS(7309),
    [anon_sym_POUNDendif2] = ACTIONS(7309),
    [anon_sym_POUNDENDIF2] = ACTIONS(7309),
    [anon_sym_POUNDEndif2] = ACTIONS(7309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7261),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7309),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3158)] = {
    [sym_boolean] = STATE(8303),
    [sym_option_member] = STATE(8258),
    [sym_keyword_identifier] = STATE(8303),
    [sym_codeunit_keyword] = STATE(8241),
    [sym_xmlport_keyword] = STATE(8241),
    [sym_enum_keyword] = STATE(8241),
    [sym_keyword_as_identifier] = STATE(8303),
    [aux_sym_option_member_list_repeat2] = STATE(3567),
    [sym_identifier] = ACTIONS(7217),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(7311),
    [anon_sym_DASH] = ACTIONS(7221),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [aux_sym_where_condition_token1] = ACTIONS(7225),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7229),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [aux_sym_basic_type_token53] = ACTIONS(7225),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7225),
    [aux_sym_separator_action_token1] = ACTIONS(7225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7225),
    [aux_sym_type_declaration_token1] = ACTIONS(7225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7227),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [anon_sym_to] = ACTIONS(602),
    [anon_sym_TO] = ACTIONS(602),
    [anon_sym_To] = ACTIONS(602),
    [anon_sym_downto] = ACTIONS(602),
    [anon_sym_DOWNTO] = ACTIONS(602),
    [anon_sym_Downto] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(7225),
    [sym_page_keyword] = ACTIONS(7227),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(7227),
    [sym_query_keyword] = ACTIONS(7227),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_local_keyword] = ACTIONS(7217),
    [sym_internal_keyword] = ACTIONS(7217),
    [sym_protected_keyword] = ACTIONS(7217),
    [sym_key_keyword] = ACTIONS(7225),
    [sym_dataset_keyword] = ACTIONS(7225),
    [sym_quoted_identifier] = ACTIONS(7237),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7237),
    [sym_integer] = ACTIONS(7237),
  },
  [STATE(3159)] = {
    [sym__body_element] = STATE(3416),
    [sym_empty_statement] = STATE(3416),
    [sym_property] = STATE(3416),
    [sym_permissions_property] = STATE(3416),
    [sym_table_relation_property] = STATE(3416),
    [sym_fields_section] = STATE(3416),
    [sym_keys_section] = STATE(3416),
    [sym_fieldgroups_section] = STATE(3416),
    [sym_enum_value_declaration] = STATE(3416),
    [sym_labels_section] = STATE(3416),
    [sym_layout_section] = STATE(3416),
    [sym_modify_modification] = STATE(3416),
    [sym_actions_section] = STATE(3416),
    [sym_views_section] = STATE(3416),
    [sym_dataset_section] = STATE(3416),
    [sym_requestpage_section] = STATE(3416),
    [sym_rendering_section] = STATE(3416),
    [sym_elements_section] = STATE(3416),
    [sym_schema_section] = STATE(3416),
    [sym_assembly_declaration] = STATE(3416),
    [sym_event_declaration] = STATE(3416),
    [sym_procedure] = STATE(3416),
    [sym_preproc_split_procedure] = STATE(3416),
    [sym_preproc_split_procedure_preamble] = STATE(3416),
    [sym__procedure_header] = STATE(10732),
    [sym_procedure_modifier] = STATE(17047),
    [sym_trigger_declaration] = STATE(3416),
    [sym_var_section] = STATE(3416),
    [sym_var_attribute_item] = STATE(3416),
    [sym_variable_declaration] = STATE(3416),
    [sym_attribute_item] = STATE(6747),
    [sym_preproc_conditional] = STATE(3416),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3786),
    [sym_preproc_endif] = STATE(7881),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym__procedure_header_repeat1] = STATE(14336),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3416),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10848),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7313),
    [anon_sym_POUNDENDIF] = ACTIONS(7313),
    [anon_sym_POUNDEndif] = ACTIONS(7313),
    [anon_sym_POUNDendif2] = ACTIONS(7313),
    [anon_sym_POUNDENDIF2] = ACTIONS(7313),
    [anon_sym_POUNDEndif2] = ACTIONS(7313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7261),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7313),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3160)] = {
    [sym__body_element] = STATE(4943),
    [sym_empty_statement] = STATE(4943),
    [sym_property] = STATE(6513),
    [sym_permissions_property] = STATE(4943),
    [sym_table_relation_property] = STATE(4943),
    [sym_fields_section] = STATE(4943),
    [sym_keys_section] = STATE(4943),
    [sym_fieldgroups_section] = STATE(4943),
    [sym_enum_value_declaration] = STATE(4943),
    [sym_labels_section] = STATE(4943),
    [sym_layout_section] = STATE(4943),
    [sym_modify_modification] = STATE(4943),
    [sym_actions_section] = STATE(4943),
    [sym__action_element] = STATE(8054),
    [sym_action_area_section] = STATE(8054),
    [sym_action_group_section] = STATE(8054),
    [sym_action_declaration] = STATE(8054),
    [sym_separator_action] = STATE(8054),
    [sym_actionref_declaration] = STATE(8054),
    [sym_systemaction_declaration] = STATE(8054),
    [sym_fileuploadaction_declaration] = STATE(8054),
    [sym_customaction_declaration] = STATE(8054),
    [sym_addfirst_action_modification] = STATE(8054),
    [sym_addlast_action_modification] = STATE(8054),
    [sym_addafter_action_modification] = STATE(8054),
    [sym_addbefore_action_modification] = STATE(8054),
    [sym_modify_action_modification] = STATE(8054),
    [sym_views_section] = STATE(4943),
    [sym_dataset_section] = STATE(4943),
    [sym_requestpage_section] = STATE(4943),
    [sym_rendering_section] = STATE(4943),
    [sym_elements_section] = STATE(4943),
    [sym_schema_section] = STATE(4943),
    [sym_assembly_declaration] = STATE(4943),
    [sym_event_declaration] = STATE(4943),
    [sym_procedure] = STATE(4943),
    [sym_preproc_split_procedure] = STATE(4943),
    [sym_preproc_split_procedure_preamble] = STATE(4943),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(6513),
    [sym_var_section] = STATE(4943),
    [sym_attribute_item] = STATE(6513),
    [sym_preproc_conditional] = STATE(4943),
    [sym_preproc_if] = STATE(2238),
    [sym_preproc_endif] = STATE(8344),
    [sym_preproc_conditional_actions] = STATE(8054),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4943),
    [aux_sym_actions_section_repeat1] = STATE(8054),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(5201),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(3161)] = {
    [sym__body_element] = STATE(3428),
    [sym_empty_statement] = STATE(3428),
    [sym_property] = STATE(3428),
    [sym_permissions_property] = STATE(3428),
    [sym_table_relation_property] = STATE(3428),
    [sym_fields_section] = STATE(3428),
    [sym_keys_section] = STATE(3428),
    [sym_fieldgroups_section] = STATE(3428),
    [sym_enum_value_declaration] = STATE(3428),
    [sym_labels_section] = STATE(3428),
    [sym_layout_section] = STATE(3428),
    [sym_modify_modification] = STATE(3428),
    [sym_actions_section] = STATE(3428),
    [sym_views_section] = STATE(3428),
    [sym_dataset_section] = STATE(3428),
    [sym_requestpage_section] = STATE(3428),
    [sym_rendering_section] = STATE(3428),
    [sym_elements_section] = STATE(3428),
    [sym_schema_section] = STATE(3428),
    [sym_assembly_declaration] = STATE(3428),
    [sym_event_declaration] = STATE(3428),
    [sym_procedure] = STATE(3428),
    [sym_preproc_split_procedure] = STATE(3428),
    [sym_preproc_split_procedure_preamble] = STATE(3428),
    [sym__procedure_header] = STATE(10750),
    [sym_procedure_modifier] = STATE(17047),
    [sym_trigger_declaration] = STATE(3428),
    [sym_var_section] = STATE(3428),
    [sym_var_attribute_item] = STATE(3428),
    [sym_variable_declaration] = STATE(3428),
    [sym_attribute_item] = STATE(6747),
    [sym_preproc_conditional] = STATE(3428),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3792),
    [sym_preproc_endif] = STATE(8221),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym__procedure_header_repeat1] = STATE(14336),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3428),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10909),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7315),
    [anon_sym_POUNDENDIF] = ACTIONS(7315),
    [anon_sym_POUNDEndif] = ACTIONS(7315),
    [anon_sym_POUNDendif2] = ACTIONS(7315),
    [anon_sym_POUNDENDIF2] = ACTIONS(7315),
    [anon_sym_POUNDEndif2] = ACTIONS(7315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7261),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7315),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3162)] = {
    [sym_else_keyword] = STATE(481),
    [sym_identifier] = ACTIONS(5477),
    [anon_sym_SEMI] = ACTIONS(5479),
    [anon_sym_DASH] = ACTIONS(5479),
    [aux_sym_boolean_token1] = ACTIONS(5477),
    [aux_sym_boolean_token2] = ACTIONS(5477),
    [sym_decimal] = ACTIONS(5477),
    [anon_sym_LPAREN] = ACTIONS(5479),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5477),
    [anon_sym_LBRACK] = ACTIONS(5479),
    [aux_sym_record_type_token1] = ACTIONS(5477),
    [aux_sym_basic_type_token21] = ACTIONS(5477),
    [aux_sym_basic_type_token22] = ACTIONS(5477),
    [aux_sym_basic_type_token48] = ACTIONS(5477),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5477),
    [anon_sym_POUNDif] = ACTIONS(5479),
    [anon_sym_POUNDIF] = ACTIONS(5479),
    [anon_sym_POUNDIf] = ACTIONS(5479),
    [anon_sym_not] = ACTIONS(5477),
    [anon_sym_NOT] = ACTIONS(5477),
    [anon_sym_Not] = ACTIONS(5477),
    [anon_sym_POUNDelse] = ACTIONS(5479),
    [anon_sym_POUNDELSE] = ACTIONS(5479),
    [anon_sym_POUNDElse] = ACTIONS(5479),
    [anon_sym_POUNDelse2] = ACTIONS(5479),
    [anon_sym_POUNDELSE2] = ACTIONS(5479),
    [anon_sym_POUNDElse2] = ACTIONS(5479),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5477),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5477),
    [anon_sym_PLUS] = ACTIONS(5479),
    [sym_datetime_literal] = ACTIONS(5479),
    [sym_date_literal] = ACTIONS(5477),
    [sym_time_literal] = ACTIONS(5477),
    [sym_biginteger_literal] = ACTIONS(5479),
    [anon_sym_if] = ACTIONS(5477),
    [anon_sym_IF] = ACTIONS(5477),
    [anon_sym_If] = ACTIONS(5477),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5477),
    [anon_sym_CASE] = ACTIONS(5477),
    [anon_sym_Case] = ACTIONS(5477),
    [anon_sym_for] = ACTIONS(5477),
    [anon_sym_FOR] = ACTIONS(5477),
    [anon_sym_For] = ACTIONS(5477),
    [anon_sym_foreach] = ACTIONS(5477),
    [anon_sym_FOREACH] = ACTIONS(5477),
    [anon_sym_Foreach] = ACTIONS(5477),
    [anon_sym_while] = ACTIONS(5477),
    [anon_sym_WHILE] = ACTIONS(5477),
    [anon_sym_While] = ACTIONS(5477),
    [anon_sym_repeat] = ACTIONS(5477),
    [anon_sym_REPEAT] = ACTIONS(5477),
    [anon_sym_Repeat] = ACTIONS(5477),
    [anon_sym_exit] = ACTIONS(5477),
    [anon_sym_EXIT] = ACTIONS(5477),
    [anon_sym_Exit] = ACTIONS(5477),
    [anon_sym_continue] = ACTIONS(5477),
    [anon_sym_CONTINUE] = ACTIONS(5477),
    [anon_sym_Continue] = ACTIONS(5477),
    [anon_sym_break] = ACTIONS(5477),
    [anon_sym_BREAK] = ACTIONS(5477),
    [anon_sym_Break] = ACTIONS(5477),
    [anon_sym_with] = ACTIONS(5477),
    [anon_sym_WITH] = ACTIONS(5477),
    [anon_sym_With] = ACTIONS(5477),
    [sym_asserterror_keyword] = ACTIONS(5479),
    [sym_page_keyword] = ACTIONS(5477),
    [anon_sym_codeunit] = ACTIONS(5477),
    [anon_sym_CODEUNIT] = ACTIONS(5477),
    [anon_sym_Codeunit] = ACTIONS(5477),
    [anon_sym_CodeUnit] = ACTIONS(5477),
    [anon_sym_COdeunit] = ACTIONS(5477),
    [anon_sym_codeUnit] = ACTIONS(5477),
    [sym_report_keyword] = ACTIONS(5477),
    [sym_query_keyword] = ACTIONS(5477),
    [anon_sym_xmlport] = ACTIONS(5477),
    [anon_sym_XMLPORT] = ACTIONS(5477),
    [anon_sym_Xmlport] = ACTIONS(5477),
    [anon_sym_XMLport] = ACTIONS(5477),
    [anon_sym_XMLPort] = ACTIONS(5477),
    [anon_sym_XmlPort] = ACTIONS(5477),
    [anon_sym_enum] = ACTIONS(5477),
    [anon_sym_ENUM] = ACTIONS(5477),
    [anon_sym_Enum] = ACTIONS(5477),
    [anon_sym_eNUM] = ACTIONS(5477),
    [anon_sym_eNum] = ACTIONS(5477),
    [anon_sym_ENum] = ACTIONS(5477),
    [sym_quoted_identifier] = ACTIONS(5479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5479),
    [sym_verbatim_string] = ACTIONS(5479),
    [sym_integer] = ACTIONS(5477),
    [sym_continue_as_identifier] = ACTIONS(5479),
    [sym_preproc_open] = ACTIONS(5479),
    [sym_end_keyword] = ACTIONS(5479),
  },
  [STATE(3163)] = {
    [sym_else_keyword] = STATE(482),
    [sym_identifier] = ACTIONS(5441),
    [anon_sym_SEMI] = ACTIONS(5443),
    [anon_sym_DASH] = ACTIONS(5443),
    [aux_sym_boolean_token1] = ACTIONS(5441),
    [aux_sym_boolean_token2] = ACTIONS(5441),
    [sym_decimal] = ACTIONS(5441),
    [anon_sym_LPAREN] = ACTIONS(5443),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5441),
    [anon_sym_LBRACK] = ACTIONS(5443),
    [aux_sym_record_type_token1] = ACTIONS(5441),
    [aux_sym_basic_type_token21] = ACTIONS(5441),
    [aux_sym_basic_type_token22] = ACTIONS(5441),
    [aux_sym_basic_type_token48] = ACTIONS(5441),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5441),
    [anon_sym_POUNDif] = ACTIONS(5443),
    [anon_sym_POUNDIF] = ACTIONS(5443),
    [anon_sym_POUNDIf] = ACTIONS(5443),
    [anon_sym_not] = ACTIONS(5441),
    [anon_sym_NOT] = ACTIONS(5441),
    [anon_sym_Not] = ACTIONS(5441),
    [anon_sym_POUNDelse] = ACTIONS(5443),
    [anon_sym_POUNDELSE] = ACTIONS(5443),
    [anon_sym_POUNDElse] = ACTIONS(5443),
    [anon_sym_POUNDelse2] = ACTIONS(5443),
    [anon_sym_POUNDELSE2] = ACTIONS(5443),
    [anon_sym_POUNDElse2] = ACTIONS(5443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5441),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5441),
    [anon_sym_PLUS] = ACTIONS(5443),
    [sym_datetime_literal] = ACTIONS(5443),
    [sym_date_literal] = ACTIONS(5441),
    [sym_time_literal] = ACTIONS(5441),
    [sym_biginteger_literal] = ACTIONS(5443),
    [anon_sym_if] = ACTIONS(5441),
    [anon_sym_IF] = ACTIONS(5441),
    [anon_sym_If] = ACTIONS(5441),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5441),
    [anon_sym_CASE] = ACTIONS(5441),
    [anon_sym_Case] = ACTIONS(5441),
    [anon_sym_for] = ACTIONS(5441),
    [anon_sym_FOR] = ACTIONS(5441),
    [anon_sym_For] = ACTIONS(5441),
    [anon_sym_foreach] = ACTIONS(5441),
    [anon_sym_FOREACH] = ACTIONS(5441),
    [anon_sym_Foreach] = ACTIONS(5441),
    [anon_sym_while] = ACTIONS(5441),
    [anon_sym_WHILE] = ACTIONS(5441),
    [anon_sym_While] = ACTIONS(5441),
    [anon_sym_repeat] = ACTIONS(5441),
    [anon_sym_REPEAT] = ACTIONS(5441),
    [anon_sym_Repeat] = ACTIONS(5441),
    [anon_sym_exit] = ACTIONS(5441),
    [anon_sym_EXIT] = ACTIONS(5441),
    [anon_sym_Exit] = ACTIONS(5441),
    [anon_sym_continue] = ACTIONS(5441),
    [anon_sym_CONTINUE] = ACTIONS(5441),
    [anon_sym_Continue] = ACTIONS(5441),
    [anon_sym_break] = ACTIONS(5441),
    [anon_sym_BREAK] = ACTIONS(5441),
    [anon_sym_Break] = ACTIONS(5441),
    [anon_sym_with] = ACTIONS(5441),
    [anon_sym_WITH] = ACTIONS(5441),
    [anon_sym_With] = ACTIONS(5441),
    [sym_asserterror_keyword] = ACTIONS(5443),
    [sym_page_keyword] = ACTIONS(5441),
    [anon_sym_codeunit] = ACTIONS(5441),
    [anon_sym_CODEUNIT] = ACTIONS(5441),
    [anon_sym_Codeunit] = ACTIONS(5441),
    [anon_sym_CodeUnit] = ACTIONS(5441),
    [anon_sym_COdeunit] = ACTIONS(5441),
    [anon_sym_codeUnit] = ACTIONS(5441),
    [sym_report_keyword] = ACTIONS(5441),
    [sym_query_keyword] = ACTIONS(5441),
    [anon_sym_xmlport] = ACTIONS(5441),
    [anon_sym_XMLPORT] = ACTIONS(5441),
    [anon_sym_Xmlport] = ACTIONS(5441),
    [anon_sym_XMLport] = ACTIONS(5441),
    [anon_sym_XMLPort] = ACTIONS(5441),
    [anon_sym_XmlPort] = ACTIONS(5441),
    [anon_sym_enum] = ACTIONS(5441),
    [anon_sym_ENUM] = ACTIONS(5441),
    [anon_sym_Enum] = ACTIONS(5441),
    [anon_sym_eNUM] = ACTIONS(5441),
    [anon_sym_eNum] = ACTIONS(5441),
    [anon_sym_ENum] = ACTIONS(5441),
    [sym_quoted_identifier] = ACTIONS(5443),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5443),
    [sym_verbatim_string] = ACTIONS(5443),
    [sym_integer] = ACTIONS(5441),
    [sym_continue_as_identifier] = ACTIONS(5443),
    [sym_preproc_open] = ACTIONS(5443),
    [sym_end_keyword] = ACTIONS(5443),
  },
  [STATE(3164)] = {
    [sym_else_keyword] = STATE(624),
    [sym_identifier] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5471),
    [anon_sym_DASH] = ACTIONS(5471),
    [aux_sym_boolean_token1] = ACTIONS(5469),
    [aux_sym_boolean_token2] = ACTIONS(5469),
    [sym_decimal] = ACTIONS(5469),
    [anon_sym_LPAREN] = ACTIONS(5471),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5469),
    [anon_sym_LBRACK] = ACTIONS(5471),
    [aux_sym_record_type_token1] = ACTIONS(5469),
    [aux_sym_basic_type_token21] = ACTIONS(5469),
    [aux_sym_basic_type_token22] = ACTIONS(5469),
    [aux_sym_basic_type_token48] = ACTIONS(5469),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5469),
    [anon_sym_POUNDif] = ACTIONS(5471),
    [anon_sym_POUNDIF] = ACTIONS(5471),
    [anon_sym_POUNDIf] = ACTIONS(5471),
    [anon_sym_not] = ACTIONS(5469),
    [anon_sym_NOT] = ACTIONS(5469),
    [anon_sym_Not] = ACTIONS(5469),
    [anon_sym_POUNDelse] = ACTIONS(5471),
    [anon_sym_POUNDELSE] = ACTIONS(5471),
    [anon_sym_POUNDElse] = ACTIONS(5471),
    [anon_sym_POUNDelse2] = ACTIONS(5471),
    [anon_sym_POUNDELSE2] = ACTIONS(5471),
    [anon_sym_POUNDElse2] = ACTIONS(5471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5469),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5469),
    [anon_sym_PLUS] = ACTIONS(5471),
    [sym_datetime_literal] = ACTIONS(5471),
    [sym_date_literal] = ACTIONS(5469),
    [sym_time_literal] = ACTIONS(5469),
    [sym_biginteger_literal] = ACTIONS(5471),
    [anon_sym_if] = ACTIONS(5469),
    [anon_sym_IF] = ACTIONS(5469),
    [anon_sym_If] = ACTIONS(5469),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5469),
    [anon_sym_CASE] = ACTIONS(5469),
    [anon_sym_Case] = ACTIONS(5469),
    [anon_sym_for] = ACTIONS(5469),
    [anon_sym_FOR] = ACTIONS(5469),
    [anon_sym_For] = ACTIONS(5469),
    [anon_sym_foreach] = ACTIONS(5469),
    [anon_sym_FOREACH] = ACTIONS(5469),
    [anon_sym_Foreach] = ACTIONS(5469),
    [anon_sym_while] = ACTIONS(5469),
    [anon_sym_WHILE] = ACTIONS(5469),
    [anon_sym_While] = ACTIONS(5469),
    [anon_sym_repeat] = ACTIONS(5469),
    [anon_sym_REPEAT] = ACTIONS(5469),
    [anon_sym_Repeat] = ACTIONS(5469),
    [anon_sym_exit] = ACTIONS(5469),
    [anon_sym_EXIT] = ACTIONS(5469),
    [anon_sym_Exit] = ACTIONS(5469),
    [anon_sym_continue] = ACTIONS(5469),
    [anon_sym_CONTINUE] = ACTIONS(5469),
    [anon_sym_Continue] = ACTIONS(5469),
    [anon_sym_break] = ACTIONS(5469),
    [anon_sym_BREAK] = ACTIONS(5469),
    [anon_sym_Break] = ACTIONS(5469),
    [anon_sym_with] = ACTIONS(5469),
    [anon_sym_WITH] = ACTIONS(5469),
    [anon_sym_With] = ACTIONS(5469),
    [sym_asserterror_keyword] = ACTIONS(5471),
    [sym_page_keyword] = ACTIONS(5469),
    [anon_sym_codeunit] = ACTIONS(5469),
    [anon_sym_CODEUNIT] = ACTIONS(5469),
    [anon_sym_Codeunit] = ACTIONS(5469),
    [anon_sym_CodeUnit] = ACTIONS(5469),
    [anon_sym_COdeunit] = ACTIONS(5469),
    [anon_sym_codeUnit] = ACTIONS(5469),
    [sym_report_keyword] = ACTIONS(5469),
    [sym_query_keyword] = ACTIONS(5469),
    [anon_sym_xmlport] = ACTIONS(5469),
    [anon_sym_XMLPORT] = ACTIONS(5469),
    [anon_sym_Xmlport] = ACTIONS(5469),
    [anon_sym_XMLport] = ACTIONS(5469),
    [anon_sym_XMLPort] = ACTIONS(5469),
    [anon_sym_XmlPort] = ACTIONS(5469),
    [anon_sym_enum] = ACTIONS(5469),
    [anon_sym_ENUM] = ACTIONS(5469),
    [anon_sym_Enum] = ACTIONS(5469),
    [anon_sym_eNUM] = ACTIONS(5469),
    [anon_sym_eNum] = ACTIONS(5469),
    [anon_sym_ENum] = ACTIONS(5469),
    [sym_quoted_identifier] = ACTIONS(5471),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5471),
    [sym_verbatim_string] = ACTIONS(5471),
    [sym_integer] = ACTIONS(5469),
    [sym_continue_as_identifier] = ACTIONS(5471),
    [sym_preproc_open] = ACTIONS(5471),
    [sym_end_keyword] = ACTIONS(5471),
  },
  [STATE(3165)] = {
    [sym_boolean] = STATE(8034),
    [sym_option_member] = STATE(8042),
    [sym_keyword_identifier] = STATE(8034),
    [sym_codeunit_keyword] = STATE(8062),
    [sym_xmlport_keyword] = STATE(8062),
    [sym_enum_keyword] = STATE(8062),
    [sym_keyword_as_identifier] = STATE(8034),
    [sym_identifier] = ACTIONS(7061),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(7065),
    [aux_sym_boolean_token1] = ACTIONS(7067),
    [aux_sym_boolean_token2] = ACTIONS(7067),
    [aux_sym_where_condition_token1] = ACTIONS(7069),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7071),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(7071),
    [aux_sym_basic_type_token21] = ACTIONS(7071),
    [aux_sym_basic_type_token22] = ACTIONS(7073),
    [aux_sym_basic_type_token48] = ACTIONS(7071),
    [aux_sym_basic_type_token53] = ACTIONS(7069),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7317),
    [aux_sym_modify_modification_token1] = ACTIONS(613),
    [aux_sym_separator_action_token1] = ACTIONS(7069),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7317),
    [aux_sym_type_declaration_token1] = ACTIONS(7069),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(613),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [anon_sym_POUNDelif] = ACTIONS(611),
    [anon_sym_POUNDELIF] = ACTIONS(611),
    [anon_sym_POUNDElif] = ACTIONS(611),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [anon_sym_POUNDendif] = ACTIONS(611),
    [anon_sym_POUNDENDIF] = ACTIONS(611),
    [anon_sym_POUNDEndif] = ACTIONS(611),
    [anon_sym_POUNDendif2] = ACTIONS(611),
    [anon_sym_POUNDENDIF2] = ACTIONS(611),
    [anon_sym_POUNDEndif2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7071),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7071),
    [sym_table_keyword] = ACTIONS(7069),
    [sym_page_keyword] = ACTIONS(7071),
    [anon_sym_codeunit] = ACTIONS(7075),
    [anon_sym_CODEUNIT] = ACTIONS(7075),
    [anon_sym_Codeunit] = ACTIONS(7075),
    [anon_sym_CodeUnit] = ACTIONS(7075),
    [anon_sym_COdeunit] = ACTIONS(7075),
    [anon_sym_codeUnit] = ACTIONS(7075),
    [sym_report_keyword] = ACTIONS(7071),
    [sym_query_keyword] = ACTIONS(7071),
    [anon_sym_xmlport] = ACTIONS(7077),
    [anon_sym_XMLPORT] = ACTIONS(7077),
    [anon_sym_Xmlport] = ACTIONS(7077),
    [anon_sym_XMLport] = ACTIONS(7077),
    [anon_sym_XMLPort] = ACTIONS(7077),
    [anon_sym_XmlPort] = ACTIONS(7077),
    [anon_sym_enum] = ACTIONS(7079),
    [anon_sym_ENUM] = ACTIONS(7079),
    [anon_sym_Enum] = ACTIONS(7079),
    [anon_sym_eNUM] = ACTIONS(7079),
    [anon_sym_eNum] = ACTIONS(7079),
    [anon_sym_ENum] = ACTIONS(7079),
    [sym_procedure_keyword] = ACTIONS(613),
    [sym_trigger_keyword] = ACTIONS(613),
    [sym_var_keyword] = ACTIONS(613),
    [sym_local_keyword] = ACTIONS(7320),
    [sym_internal_keyword] = ACTIONS(7320),
    [sym_protected_keyword] = ACTIONS(7320),
    [sym_event_keyword] = ACTIONS(613),
    [sym_fields_keyword] = ACTIONS(613),
    [sym_keys_keyword] = ACTIONS(613),
    [sym_key_keyword] = ACTIONS(7069),
    [sym_fieldgroups_keyword] = ACTIONS(613),
    [sym_actions_keyword] = ACTIONS(613),
    [sym_layout_keyword] = ACTIONS(613),
    [sym_dataset_keyword] = ACTIONS(7317),
    [sym_elements_keyword] = ACTIONS(613),
    [sym_labels_keyword] = ACTIONS(613),
    [sym_rendering_keyword] = ACTIONS(613),
    [sym_requestpage_keyword] = ACTIONS(613),
    [sym_schema_keyword] = ACTIONS(613),
    [sym_views_keyword] = ACTIONS(613),
    [sym_quoted_identifier] = ACTIONS(7081),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7081),
    [sym_integer] = ACTIONS(7081),
    [sym_property_name] = ACTIONS(611),
    [sym_preproc_open] = ACTIONS(611),
    [sym_preproc_close] = ACTIONS(611),
    [sym_begin_keyword] = ACTIONS(611),
  },
  [STATE(3166)] = {
    [sym_else_keyword] = STATE(583),
    [sym_identifier] = ACTIONS(5449),
    [anon_sym_SEMI] = ACTIONS(5451),
    [anon_sym_DASH] = ACTIONS(5451),
    [aux_sym_boolean_token1] = ACTIONS(5449),
    [aux_sym_boolean_token2] = ACTIONS(5449),
    [sym_decimal] = ACTIONS(5449),
    [anon_sym_LPAREN] = ACTIONS(5451),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5449),
    [anon_sym_LBRACK] = ACTIONS(5451),
    [aux_sym_record_type_token1] = ACTIONS(5449),
    [aux_sym_basic_type_token21] = ACTIONS(5449),
    [aux_sym_basic_type_token22] = ACTIONS(5449),
    [aux_sym_basic_type_token48] = ACTIONS(5449),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5449),
    [anon_sym_POUNDif] = ACTIONS(5451),
    [anon_sym_POUNDIF] = ACTIONS(5451),
    [anon_sym_POUNDIf] = ACTIONS(5451),
    [anon_sym_not] = ACTIONS(5449),
    [anon_sym_NOT] = ACTIONS(5449),
    [anon_sym_Not] = ACTIONS(5449),
    [anon_sym_POUNDelse] = ACTIONS(5451),
    [anon_sym_POUNDELSE] = ACTIONS(5451),
    [anon_sym_POUNDElse] = ACTIONS(5451),
    [anon_sym_POUNDelse2] = ACTIONS(5451),
    [anon_sym_POUNDELSE2] = ACTIONS(5451),
    [anon_sym_POUNDElse2] = ACTIONS(5451),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5449),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5449),
    [anon_sym_PLUS] = ACTIONS(5451),
    [sym_datetime_literal] = ACTIONS(5451),
    [sym_date_literal] = ACTIONS(5449),
    [sym_time_literal] = ACTIONS(5449),
    [sym_biginteger_literal] = ACTIONS(5451),
    [anon_sym_if] = ACTIONS(5449),
    [anon_sym_IF] = ACTIONS(5449),
    [anon_sym_If] = ACTIONS(5449),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5449),
    [anon_sym_CASE] = ACTIONS(5449),
    [anon_sym_Case] = ACTIONS(5449),
    [anon_sym_for] = ACTIONS(5449),
    [anon_sym_FOR] = ACTIONS(5449),
    [anon_sym_For] = ACTIONS(5449),
    [anon_sym_foreach] = ACTIONS(5449),
    [anon_sym_FOREACH] = ACTIONS(5449),
    [anon_sym_Foreach] = ACTIONS(5449),
    [anon_sym_while] = ACTIONS(5449),
    [anon_sym_WHILE] = ACTIONS(5449),
    [anon_sym_While] = ACTIONS(5449),
    [anon_sym_repeat] = ACTIONS(5449),
    [anon_sym_REPEAT] = ACTIONS(5449),
    [anon_sym_Repeat] = ACTIONS(5449),
    [anon_sym_exit] = ACTIONS(5449),
    [anon_sym_EXIT] = ACTIONS(5449),
    [anon_sym_Exit] = ACTIONS(5449),
    [anon_sym_continue] = ACTIONS(5449),
    [anon_sym_CONTINUE] = ACTIONS(5449),
    [anon_sym_Continue] = ACTIONS(5449),
    [anon_sym_break] = ACTIONS(5449),
    [anon_sym_BREAK] = ACTIONS(5449),
    [anon_sym_Break] = ACTIONS(5449),
    [anon_sym_with] = ACTIONS(5449),
    [anon_sym_WITH] = ACTIONS(5449),
    [anon_sym_With] = ACTIONS(5449),
    [sym_asserterror_keyword] = ACTIONS(5451),
    [sym_page_keyword] = ACTIONS(5449),
    [anon_sym_codeunit] = ACTIONS(5449),
    [anon_sym_CODEUNIT] = ACTIONS(5449),
    [anon_sym_Codeunit] = ACTIONS(5449),
    [anon_sym_CodeUnit] = ACTIONS(5449),
    [anon_sym_COdeunit] = ACTIONS(5449),
    [anon_sym_codeUnit] = ACTIONS(5449),
    [sym_report_keyword] = ACTIONS(5449),
    [sym_query_keyword] = ACTIONS(5449),
    [anon_sym_xmlport] = ACTIONS(5449),
    [anon_sym_XMLPORT] = ACTIONS(5449),
    [anon_sym_Xmlport] = ACTIONS(5449),
    [anon_sym_XMLport] = ACTIONS(5449),
    [anon_sym_XMLPort] = ACTIONS(5449),
    [anon_sym_XmlPort] = ACTIONS(5449),
    [anon_sym_enum] = ACTIONS(5449),
    [anon_sym_ENUM] = ACTIONS(5449),
    [anon_sym_Enum] = ACTIONS(5449),
    [anon_sym_eNUM] = ACTIONS(5449),
    [anon_sym_eNum] = ACTIONS(5449),
    [anon_sym_ENum] = ACTIONS(5449),
    [sym_quoted_identifier] = ACTIONS(5451),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5451),
    [sym_verbatim_string] = ACTIONS(5451),
    [sym_integer] = ACTIONS(5449),
    [sym_continue_as_identifier] = ACTIONS(5451),
    [sym_preproc_open] = ACTIONS(5451),
    [sym_end_keyword] = ACTIONS(5451),
  },
  [STATE(3167)] = {
    [sym__body_element] = STATE(3430),
    [sym_empty_statement] = STATE(3430),
    [sym_property] = STATE(3430),
    [sym_permissions_property] = STATE(3430),
    [sym_table_relation_property] = STATE(3430),
    [sym_fields_section] = STATE(3430),
    [sym_keys_section] = STATE(3430),
    [sym_fieldgroups_section] = STATE(3430),
    [sym_enum_value_declaration] = STATE(3430),
    [sym_labels_section] = STATE(3430),
    [sym_layout_section] = STATE(3430),
    [sym_modify_modification] = STATE(3430),
    [sym_actions_section] = STATE(3430),
    [sym_views_section] = STATE(3430),
    [sym_dataset_section] = STATE(3430),
    [sym_requestpage_section] = STATE(3430),
    [sym_rendering_section] = STATE(3430),
    [sym_elements_section] = STATE(3430),
    [sym_schema_section] = STATE(3430),
    [sym_assembly_declaration] = STATE(3430),
    [sym_event_declaration] = STATE(3430),
    [sym_procedure] = STATE(3430),
    [sym_preproc_split_procedure] = STATE(3430),
    [sym_preproc_split_procedure_preamble] = STATE(3430),
    [sym__procedure_header] = STATE(10770),
    [sym_procedure_modifier] = STATE(17047),
    [sym_trigger_declaration] = STATE(3430),
    [sym_var_section] = STATE(3430),
    [sym_var_attribute_item] = STATE(3430),
    [sym_variable_declaration] = STATE(3430),
    [sym_attribute_item] = STATE(6747),
    [sym_preproc_conditional] = STATE(3430),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3798),
    [sym_preproc_endif] = STATE(5884),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym__procedure_header_repeat1] = STATE(14336),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3430),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10954),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7323),
    [anon_sym_POUNDENDIF] = ACTIONS(7323),
    [anon_sym_POUNDEndif] = ACTIONS(7323),
    [anon_sym_POUNDendif2] = ACTIONS(7323),
    [anon_sym_POUNDENDIF2] = ACTIONS(7323),
    [anon_sym_POUNDEndif2] = ACTIONS(7323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7261),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7323),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3168)] = {
    [sym__body_element] = STATE(4908),
    [sym_empty_statement] = STATE(4908),
    [sym_property] = STATE(6513),
    [sym_permissions_property] = STATE(4908),
    [sym_table_relation_property] = STATE(4908),
    [sym_fields_section] = STATE(4908),
    [sym_keys_section] = STATE(4908),
    [sym_fieldgroups_section] = STATE(4908),
    [sym_enum_value_declaration] = STATE(4908),
    [sym_labels_section] = STATE(4908),
    [sym_layout_section] = STATE(4908),
    [sym_modify_modification] = STATE(4908),
    [sym_actions_section] = STATE(4908),
    [sym__action_element] = STATE(8099),
    [sym_action_area_section] = STATE(8099),
    [sym_action_group_section] = STATE(8099),
    [sym_action_declaration] = STATE(8099),
    [sym_separator_action] = STATE(8099),
    [sym_actionref_declaration] = STATE(8099),
    [sym_systemaction_declaration] = STATE(8099),
    [sym_fileuploadaction_declaration] = STATE(8099),
    [sym_customaction_declaration] = STATE(8099),
    [sym_addfirst_action_modification] = STATE(8099),
    [sym_addlast_action_modification] = STATE(8099),
    [sym_addafter_action_modification] = STATE(8099),
    [sym_addbefore_action_modification] = STATE(8099),
    [sym_modify_action_modification] = STATE(8099),
    [sym_views_section] = STATE(4908),
    [sym_dataset_section] = STATE(4908),
    [sym_requestpage_section] = STATE(4908),
    [sym_rendering_section] = STATE(4908),
    [sym_elements_section] = STATE(4908),
    [sym_schema_section] = STATE(4908),
    [sym_assembly_declaration] = STATE(4908),
    [sym_event_declaration] = STATE(4908),
    [sym_procedure] = STATE(4908),
    [sym_preproc_split_procedure] = STATE(4908),
    [sym_preproc_split_procedure_preamble] = STATE(4908),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(6513),
    [sym_var_section] = STATE(4908),
    [sym_attribute_item] = STATE(6513),
    [sym_preproc_conditional] = STATE(4908),
    [sym_preproc_if] = STATE(2238),
    [sym_preproc_endif] = STATE(6480),
    [sym_preproc_conditional_actions] = STATE(8099),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4908),
    [aux_sym_actions_section_repeat1] = STATE(8099),
    [anon_sym_SEMI] = ACTIONS(4188),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(5201),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4228),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(3169)] = {
    [sym_else_keyword] = STATE(570),
    [sym_identifier] = ACTIONS(5489),
    [anon_sym_SEMI] = ACTIONS(5491),
    [anon_sym_DASH] = ACTIONS(5491),
    [aux_sym_boolean_token1] = ACTIONS(5489),
    [aux_sym_boolean_token2] = ACTIONS(5489),
    [sym_decimal] = ACTIONS(5489),
    [anon_sym_LPAREN] = ACTIONS(5491),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5489),
    [anon_sym_LBRACK] = ACTIONS(5491),
    [aux_sym_record_type_token1] = ACTIONS(5489),
    [aux_sym_basic_type_token21] = ACTIONS(5489),
    [aux_sym_basic_type_token22] = ACTIONS(5489),
    [aux_sym_basic_type_token48] = ACTIONS(5489),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5489),
    [anon_sym_POUNDif] = ACTIONS(5491),
    [anon_sym_POUNDIF] = ACTIONS(5491),
    [anon_sym_POUNDIf] = ACTIONS(5491),
    [anon_sym_not] = ACTIONS(5489),
    [anon_sym_NOT] = ACTIONS(5489),
    [anon_sym_Not] = ACTIONS(5489),
    [anon_sym_POUNDelse] = ACTIONS(5491),
    [anon_sym_POUNDELSE] = ACTIONS(5491),
    [anon_sym_POUNDElse] = ACTIONS(5491),
    [anon_sym_POUNDelse2] = ACTIONS(5491),
    [anon_sym_POUNDELSE2] = ACTIONS(5491),
    [anon_sym_POUNDElse2] = ACTIONS(5491),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5489),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5489),
    [anon_sym_PLUS] = ACTIONS(5491),
    [sym_datetime_literal] = ACTIONS(5491),
    [sym_date_literal] = ACTIONS(5489),
    [sym_time_literal] = ACTIONS(5489),
    [sym_biginteger_literal] = ACTIONS(5491),
    [anon_sym_if] = ACTIONS(5489),
    [anon_sym_IF] = ACTIONS(5489),
    [anon_sym_If] = ACTIONS(5489),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5489),
    [anon_sym_CASE] = ACTIONS(5489),
    [anon_sym_Case] = ACTIONS(5489),
    [anon_sym_for] = ACTIONS(5489),
    [anon_sym_FOR] = ACTIONS(5489),
    [anon_sym_For] = ACTIONS(5489),
    [anon_sym_foreach] = ACTIONS(5489),
    [anon_sym_FOREACH] = ACTIONS(5489),
    [anon_sym_Foreach] = ACTIONS(5489),
    [anon_sym_while] = ACTIONS(5489),
    [anon_sym_WHILE] = ACTIONS(5489),
    [anon_sym_While] = ACTIONS(5489),
    [anon_sym_repeat] = ACTIONS(5489),
    [anon_sym_REPEAT] = ACTIONS(5489),
    [anon_sym_Repeat] = ACTIONS(5489),
    [anon_sym_exit] = ACTIONS(5489),
    [anon_sym_EXIT] = ACTIONS(5489),
    [anon_sym_Exit] = ACTIONS(5489),
    [anon_sym_continue] = ACTIONS(5489),
    [anon_sym_CONTINUE] = ACTIONS(5489),
    [anon_sym_Continue] = ACTIONS(5489),
    [anon_sym_break] = ACTIONS(5489),
    [anon_sym_BREAK] = ACTIONS(5489),
    [anon_sym_Break] = ACTIONS(5489),
    [anon_sym_with] = ACTIONS(5489),
    [anon_sym_WITH] = ACTIONS(5489),
    [anon_sym_With] = ACTIONS(5489),
    [sym_asserterror_keyword] = ACTIONS(5491),
    [sym_page_keyword] = ACTIONS(5489),
    [anon_sym_codeunit] = ACTIONS(5489),
    [anon_sym_CODEUNIT] = ACTIONS(5489),
    [anon_sym_Codeunit] = ACTIONS(5489),
    [anon_sym_CodeUnit] = ACTIONS(5489),
    [anon_sym_COdeunit] = ACTIONS(5489),
    [anon_sym_codeUnit] = ACTIONS(5489),
    [sym_report_keyword] = ACTIONS(5489),
    [sym_query_keyword] = ACTIONS(5489),
    [anon_sym_xmlport] = ACTIONS(5489),
    [anon_sym_XMLPORT] = ACTIONS(5489),
    [anon_sym_Xmlport] = ACTIONS(5489),
    [anon_sym_XMLport] = ACTIONS(5489),
    [anon_sym_XMLPort] = ACTIONS(5489),
    [anon_sym_XmlPort] = ACTIONS(5489),
    [anon_sym_enum] = ACTIONS(5489),
    [anon_sym_ENUM] = ACTIONS(5489),
    [anon_sym_Enum] = ACTIONS(5489),
    [anon_sym_eNUM] = ACTIONS(5489),
    [anon_sym_eNum] = ACTIONS(5489),
    [anon_sym_ENum] = ACTIONS(5489),
    [sym_quoted_identifier] = ACTIONS(5491),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5491),
    [sym_verbatim_string] = ACTIONS(5491),
    [sym_integer] = ACTIONS(5489),
    [sym_continue_as_identifier] = ACTIONS(5491),
    [sym_preproc_open] = ACTIONS(5491),
    [sym_end_keyword] = ACTIONS(5491),
  },
  [STATE(3170)] = {
    [sym_else_keyword] = STATE(582),
    [sym_identifier] = ACTIONS(5437),
    [anon_sym_SEMI] = ACTIONS(5439),
    [anon_sym_DASH] = ACTIONS(5439),
    [aux_sym_boolean_token1] = ACTIONS(5437),
    [aux_sym_boolean_token2] = ACTIONS(5437),
    [sym_decimal] = ACTIONS(5437),
    [anon_sym_LPAREN] = ACTIONS(5439),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5437),
    [anon_sym_LBRACK] = ACTIONS(5439),
    [aux_sym_record_type_token1] = ACTIONS(5437),
    [aux_sym_basic_type_token21] = ACTIONS(5437),
    [aux_sym_basic_type_token22] = ACTIONS(5437),
    [aux_sym_basic_type_token48] = ACTIONS(5437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5437),
    [anon_sym_POUNDif] = ACTIONS(5439),
    [anon_sym_POUNDIF] = ACTIONS(5439),
    [anon_sym_POUNDIf] = ACTIONS(5439),
    [anon_sym_not] = ACTIONS(5437),
    [anon_sym_NOT] = ACTIONS(5437),
    [anon_sym_Not] = ACTIONS(5437),
    [anon_sym_POUNDelse] = ACTIONS(5439),
    [anon_sym_POUNDELSE] = ACTIONS(5439),
    [anon_sym_POUNDElse] = ACTIONS(5439),
    [anon_sym_POUNDelse2] = ACTIONS(5439),
    [anon_sym_POUNDELSE2] = ACTIONS(5439),
    [anon_sym_POUNDElse2] = ACTIONS(5439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5437),
    [anon_sym_PLUS] = ACTIONS(5439),
    [sym_datetime_literal] = ACTIONS(5439),
    [sym_date_literal] = ACTIONS(5437),
    [sym_time_literal] = ACTIONS(5437),
    [sym_biginteger_literal] = ACTIONS(5439),
    [anon_sym_if] = ACTIONS(5437),
    [anon_sym_IF] = ACTIONS(5437),
    [anon_sym_If] = ACTIONS(5437),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5437),
    [anon_sym_CASE] = ACTIONS(5437),
    [anon_sym_Case] = ACTIONS(5437),
    [anon_sym_for] = ACTIONS(5437),
    [anon_sym_FOR] = ACTIONS(5437),
    [anon_sym_For] = ACTIONS(5437),
    [anon_sym_foreach] = ACTIONS(5437),
    [anon_sym_FOREACH] = ACTIONS(5437),
    [anon_sym_Foreach] = ACTIONS(5437),
    [anon_sym_while] = ACTIONS(5437),
    [anon_sym_WHILE] = ACTIONS(5437),
    [anon_sym_While] = ACTIONS(5437),
    [anon_sym_repeat] = ACTIONS(5437),
    [anon_sym_REPEAT] = ACTIONS(5437),
    [anon_sym_Repeat] = ACTIONS(5437),
    [anon_sym_exit] = ACTIONS(5437),
    [anon_sym_EXIT] = ACTIONS(5437),
    [anon_sym_Exit] = ACTIONS(5437),
    [anon_sym_continue] = ACTIONS(5437),
    [anon_sym_CONTINUE] = ACTIONS(5437),
    [anon_sym_Continue] = ACTIONS(5437),
    [anon_sym_break] = ACTIONS(5437),
    [anon_sym_BREAK] = ACTIONS(5437),
    [anon_sym_Break] = ACTIONS(5437),
    [anon_sym_with] = ACTIONS(5437),
    [anon_sym_WITH] = ACTIONS(5437),
    [anon_sym_With] = ACTIONS(5437),
    [sym_asserterror_keyword] = ACTIONS(5439),
    [sym_page_keyword] = ACTIONS(5437),
    [anon_sym_codeunit] = ACTIONS(5437),
    [anon_sym_CODEUNIT] = ACTIONS(5437),
    [anon_sym_Codeunit] = ACTIONS(5437),
    [anon_sym_CodeUnit] = ACTIONS(5437),
    [anon_sym_COdeunit] = ACTIONS(5437),
    [anon_sym_codeUnit] = ACTIONS(5437),
    [sym_report_keyword] = ACTIONS(5437),
    [sym_query_keyword] = ACTIONS(5437),
    [anon_sym_xmlport] = ACTIONS(5437),
    [anon_sym_XMLPORT] = ACTIONS(5437),
    [anon_sym_Xmlport] = ACTIONS(5437),
    [anon_sym_XMLport] = ACTIONS(5437),
    [anon_sym_XMLPort] = ACTIONS(5437),
    [anon_sym_XmlPort] = ACTIONS(5437),
    [anon_sym_enum] = ACTIONS(5437),
    [anon_sym_ENUM] = ACTIONS(5437),
    [anon_sym_Enum] = ACTIONS(5437),
    [anon_sym_eNUM] = ACTIONS(5437),
    [anon_sym_eNum] = ACTIONS(5437),
    [anon_sym_ENum] = ACTIONS(5437),
    [sym_quoted_identifier] = ACTIONS(5439),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5439),
    [sym_verbatim_string] = ACTIONS(5439),
    [sym_integer] = ACTIONS(5437),
    [sym_continue_as_identifier] = ACTIONS(5439),
    [sym_preproc_open] = ACTIONS(5439),
    [sym_end_keyword] = ACTIONS(5439),
  },
  [STATE(3171)] = {
    [sym_else_keyword] = STATE(426),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_if] = ACTIONS(5485),
    [anon_sym_IF] = ACTIONS(5485),
    [anon_sym_If] = ACTIONS(5485),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [anon_sym_case] = ACTIONS(5485),
    [anon_sym_CASE] = ACTIONS(5485),
    [anon_sym_Case] = ACTIONS(5485),
    [anon_sym_for] = ACTIONS(5485),
    [anon_sym_FOR] = ACTIONS(5485),
    [anon_sym_For] = ACTIONS(5485),
    [anon_sym_foreach] = ACTIONS(5485),
    [anon_sym_FOREACH] = ACTIONS(5485),
    [anon_sym_Foreach] = ACTIONS(5485),
    [anon_sym_while] = ACTIONS(5485),
    [anon_sym_WHILE] = ACTIONS(5485),
    [anon_sym_While] = ACTIONS(5485),
    [anon_sym_repeat] = ACTIONS(5485),
    [anon_sym_REPEAT] = ACTIONS(5485),
    [anon_sym_Repeat] = ACTIONS(5485),
    [anon_sym_exit] = ACTIONS(5485),
    [anon_sym_EXIT] = ACTIONS(5485),
    [anon_sym_Exit] = ACTIONS(5485),
    [anon_sym_continue] = ACTIONS(5485),
    [anon_sym_CONTINUE] = ACTIONS(5485),
    [anon_sym_Continue] = ACTIONS(5485),
    [anon_sym_break] = ACTIONS(5485),
    [anon_sym_BREAK] = ACTIONS(5485),
    [anon_sym_Break] = ACTIONS(5485),
    [anon_sym_with] = ACTIONS(5485),
    [anon_sym_WITH] = ACTIONS(5485),
    [anon_sym_With] = ACTIONS(5485),
    [sym_asserterror_keyword] = ACTIONS(5487),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_end_keyword] = ACTIONS(5487),
  },
  [STATE(3172)] = {
    [sym_identifier] = ACTIONS(6086),
    [anon_sym_SEMI] = ACTIONS(6088),
    [anon_sym_DASH] = ACTIONS(6088),
    [aux_sym_boolean_token1] = ACTIONS(6086),
    [aux_sym_boolean_token2] = ACTIONS(6086),
    [sym_decimal] = ACTIONS(6086),
    [anon_sym_LPAREN] = ACTIONS(6088),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6086),
    [anon_sym_LBRACK] = ACTIONS(6088),
    [aux_sym_record_type_token1] = ACTIONS(6086),
    [aux_sym_basic_type_token21] = ACTIONS(6086),
    [aux_sym_basic_type_token22] = ACTIONS(6086),
    [aux_sym_basic_type_token48] = ACTIONS(6086),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6086),
    [anon_sym_POUNDif] = ACTIONS(6088),
    [anon_sym_POUNDIF] = ACTIONS(6088),
    [anon_sym_POUNDIf] = ACTIONS(6088),
    [anon_sym_not] = ACTIONS(6086),
    [anon_sym_NOT] = ACTIONS(6086),
    [anon_sym_Not] = ACTIONS(6086),
    [anon_sym_POUNDelse] = ACTIONS(6088),
    [anon_sym_POUNDELSE] = ACTIONS(6088),
    [anon_sym_POUNDElse] = ACTIONS(6088),
    [anon_sym_POUNDelse2] = ACTIONS(6088),
    [anon_sym_POUNDELSE2] = ACTIONS(6088),
    [anon_sym_POUNDElse2] = ACTIONS(6088),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6086),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6086),
    [anon_sym_PLUS] = ACTIONS(6088),
    [sym_datetime_literal] = ACTIONS(6088),
    [sym_date_literal] = ACTIONS(6086),
    [sym_time_literal] = ACTIONS(6086),
    [sym_biginteger_literal] = ACTIONS(6088),
    [anon_sym_if] = ACTIONS(6086),
    [anon_sym_IF] = ACTIONS(6086),
    [anon_sym_If] = ACTIONS(6086),
    [anon_sym_else] = ACTIONS(6086),
    [anon_sym_ELSE] = ACTIONS(6086),
    [anon_sym_Else] = ACTIONS(6086),
    [anon_sym_case] = ACTIONS(6086),
    [anon_sym_CASE] = ACTIONS(6086),
    [anon_sym_Case] = ACTIONS(6086),
    [anon_sym_for] = ACTIONS(6086),
    [anon_sym_FOR] = ACTIONS(6086),
    [anon_sym_For] = ACTIONS(6086),
    [anon_sym_foreach] = ACTIONS(6086),
    [anon_sym_FOREACH] = ACTIONS(6086),
    [anon_sym_Foreach] = ACTIONS(6086),
    [anon_sym_while] = ACTIONS(6086),
    [anon_sym_WHILE] = ACTIONS(6086),
    [anon_sym_While] = ACTIONS(6086),
    [anon_sym_repeat] = ACTIONS(6086),
    [anon_sym_REPEAT] = ACTIONS(6086),
    [anon_sym_Repeat] = ACTIONS(6086),
    [anon_sym_exit] = ACTIONS(6086),
    [anon_sym_EXIT] = ACTIONS(6086),
    [anon_sym_Exit] = ACTIONS(6086),
    [anon_sym_continue] = ACTIONS(6086),
    [anon_sym_CONTINUE] = ACTIONS(6086),
    [anon_sym_Continue] = ACTIONS(6086),
    [anon_sym_break] = ACTIONS(6086),
    [anon_sym_BREAK] = ACTIONS(6086),
    [anon_sym_Break] = ACTIONS(6086),
    [anon_sym_with] = ACTIONS(6086),
    [anon_sym_WITH] = ACTIONS(6086),
    [anon_sym_With] = ACTIONS(6086),
    [sym_asserterror_keyword] = ACTIONS(6088),
    [sym_page_keyword] = ACTIONS(6086),
    [anon_sym_codeunit] = ACTIONS(6086),
    [anon_sym_CODEUNIT] = ACTIONS(6086),
    [anon_sym_Codeunit] = ACTIONS(6086),
    [anon_sym_CodeUnit] = ACTIONS(6086),
    [anon_sym_COdeunit] = ACTIONS(6086),
    [anon_sym_codeUnit] = ACTIONS(6086),
    [sym_report_keyword] = ACTIONS(6086),
    [sym_query_keyword] = ACTIONS(6086),
    [anon_sym_xmlport] = ACTIONS(6086),
    [anon_sym_XMLPORT] = ACTIONS(6086),
    [anon_sym_Xmlport] = ACTIONS(6086),
    [anon_sym_XMLport] = ACTIONS(6086),
    [anon_sym_XMLPort] = ACTIONS(6086),
    [anon_sym_XmlPort] = ACTIONS(6086),
    [anon_sym_enum] = ACTIONS(6086),
    [anon_sym_ENUM] = ACTIONS(6086),
    [anon_sym_Enum] = ACTIONS(6086),
    [anon_sym_eNUM] = ACTIONS(6086),
    [anon_sym_eNum] = ACTIONS(6086),
    [anon_sym_ENum] = ACTIONS(6086),
    [sym_quoted_identifier] = ACTIONS(6088),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6088),
    [sym_verbatim_string] = ACTIONS(6088),
    [sym_integer] = ACTIONS(6086),
    [sym_continue_as_identifier] = ACTIONS(6088),
    [sym_preproc_open] = ACTIONS(6088),
    [sym_end_keyword] = ACTIONS(6088),
  },
  [STATE(3173)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5965),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_end_keyword] = ACTIONS(5965),
  },
  [STATE(3174)] = {
    [sym_identifier] = ACTIONS(5565),
    [anon_sym_SEMI] = ACTIONS(5567),
    [anon_sym_DASH] = ACTIONS(5567),
    [aux_sym_boolean_token1] = ACTIONS(5565),
    [aux_sym_boolean_token2] = ACTIONS(5565),
    [sym_decimal] = ACTIONS(5565),
    [anon_sym_LPAREN] = ACTIONS(5567),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5565),
    [anon_sym_LBRACK] = ACTIONS(5567),
    [aux_sym_record_type_token1] = ACTIONS(5565),
    [aux_sym_basic_type_token21] = ACTIONS(5565),
    [aux_sym_basic_type_token22] = ACTIONS(5565),
    [aux_sym_basic_type_token48] = ACTIONS(5565),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5565),
    [anon_sym_POUNDif] = ACTIONS(5567),
    [anon_sym_POUNDIF] = ACTIONS(5567),
    [anon_sym_POUNDIf] = ACTIONS(5567),
    [anon_sym_not] = ACTIONS(5565),
    [anon_sym_NOT] = ACTIONS(5565),
    [anon_sym_Not] = ACTIONS(5565),
    [anon_sym_POUNDelse] = ACTIONS(5567),
    [anon_sym_POUNDELSE] = ACTIONS(5567),
    [anon_sym_POUNDElse] = ACTIONS(5567),
    [anon_sym_POUNDelse2] = ACTIONS(5567),
    [anon_sym_POUNDELSE2] = ACTIONS(5567),
    [anon_sym_POUNDElse2] = ACTIONS(5567),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5565),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5565),
    [anon_sym_PLUS] = ACTIONS(5567),
    [sym_datetime_literal] = ACTIONS(5567),
    [sym_date_literal] = ACTIONS(5565),
    [sym_time_literal] = ACTIONS(5565),
    [sym_biginteger_literal] = ACTIONS(5567),
    [anon_sym_if] = ACTIONS(5565),
    [anon_sym_IF] = ACTIONS(5565),
    [anon_sym_If] = ACTIONS(5565),
    [anon_sym_else] = ACTIONS(5565),
    [anon_sym_ELSE] = ACTIONS(5565),
    [anon_sym_Else] = ACTIONS(5565),
    [anon_sym_case] = ACTIONS(5565),
    [anon_sym_CASE] = ACTIONS(5565),
    [anon_sym_Case] = ACTIONS(5565),
    [anon_sym_for] = ACTIONS(5565),
    [anon_sym_FOR] = ACTIONS(5565),
    [anon_sym_For] = ACTIONS(5565),
    [anon_sym_foreach] = ACTIONS(5565),
    [anon_sym_FOREACH] = ACTIONS(5565),
    [anon_sym_Foreach] = ACTIONS(5565),
    [anon_sym_while] = ACTIONS(5565),
    [anon_sym_WHILE] = ACTIONS(5565),
    [anon_sym_While] = ACTIONS(5565),
    [anon_sym_repeat] = ACTIONS(5565),
    [anon_sym_REPEAT] = ACTIONS(5565),
    [anon_sym_Repeat] = ACTIONS(5565),
    [anon_sym_exit] = ACTIONS(5565),
    [anon_sym_EXIT] = ACTIONS(5565),
    [anon_sym_Exit] = ACTIONS(5565),
    [anon_sym_continue] = ACTIONS(5565),
    [anon_sym_CONTINUE] = ACTIONS(5565),
    [anon_sym_Continue] = ACTIONS(5565),
    [anon_sym_break] = ACTIONS(5565),
    [anon_sym_BREAK] = ACTIONS(5565),
    [anon_sym_Break] = ACTIONS(5565),
    [anon_sym_with] = ACTIONS(5565),
    [anon_sym_WITH] = ACTIONS(5565),
    [anon_sym_With] = ACTIONS(5565),
    [sym_asserterror_keyword] = ACTIONS(5567),
    [sym_page_keyword] = ACTIONS(5565),
    [anon_sym_codeunit] = ACTIONS(5565),
    [anon_sym_CODEUNIT] = ACTIONS(5565),
    [anon_sym_Codeunit] = ACTIONS(5565),
    [anon_sym_CodeUnit] = ACTIONS(5565),
    [anon_sym_COdeunit] = ACTIONS(5565),
    [anon_sym_codeUnit] = ACTIONS(5565),
    [sym_report_keyword] = ACTIONS(5565),
    [sym_query_keyword] = ACTIONS(5565),
    [anon_sym_xmlport] = ACTIONS(5565),
    [anon_sym_XMLPORT] = ACTIONS(5565),
    [anon_sym_Xmlport] = ACTIONS(5565),
    [anon_sym_XMLport] = ACTIONS(5565),
    [anon_sym_XMLPort] = ACTIONS(5565),
    [anon_sym_XmlPort] = ACTIONS(5565),
    [anon_sym_enum] = ACTIONS(5565),
    [anon_sym_ENUM] = ACTIONS(5565),
    [anon_sym_Enum] = ACTIONS(5565),
    [anon_sym_eNUM] = ACTIONS(5565),
    [anon_sym_eNum] = ACTIONS(5565),
    [anon_sym_ENum] = ACTIONS(5565),
    [sym_quoted_identifier] = ACTIONS(5567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5567),
    [sym_verbatim_string] = ACTIONS(5567),
    [sym_integer] = ACTIONS(5565),
    [sym_continue_as_identifier] = ACTIONS(5567),
    [sym_preproc_open] = ACTIONS(5567),
    [sym_end_keyword] = ACTIONS(5567),
  },
  [STATE(3175)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_DASH] = ACTIONS(5937),
    [aux_sym_boolean_token1] = ACTIONS(5935),
    [aux_sym_boolean_token2] = ACTIONS(5935),
    [sym_decimal] = ACTIONS(5935),
    [anon_sym_LPAREN] = ACTIONS(5937),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_record_type_token1] = ACTIONS(5935),
    [aux_sym_basic_type_token21] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token48] = ACTIONS(5935),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_not] = ACTIONS(5935),
    [anon_sym_NOT] = ACTIONS(5935),
    [anon_sym_Not] = ACTIONS(5935),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5935),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5935),
    [anon_sym_PLUS] = ACTIONS(5937),
    [sym_datetime_literal] = ACTIONS(5937),
    [sym_date_literal] = ACTIONS(5935),
    [sym_time_literal] = ACTIONS(5935),
    [sym_biginteger_literal] = ACTIONS(5937),
    [anon_sym_if] = ACTIONS(5935),
    [anon_sym_IF] = ACTIONS(5935),
    [anon_sym_If] = ACTIONS(5935),
    [anon_sym_else] = ACTIONS(5935),
    [anon_sym_ELSE] = ACTIONS(5935),
    [anon_sym_Else] = ACTIONS(5935),
    [anon_sym_case] = ACTIONS(5935),
    [anon_sym_CASE] = ACTIONS(5935),
    [anon_sym_Case] = ACTIONS(5935),
    [anon_sym_for] = ACTIONS(5935),
    [anon_sym_FOR] = ACTIONS(5935),
    [anon_sym_For] = ACTIONS(5935),
    [anon_sym_foreach] = ACTIONS(5935),
    [anon_sym_FOREACH] = ACTIONS(5935),
    [anon_sym_Foreach] = ACTIONS(5935),
    [anon_sym_while] = ACTIONS(5935),
    [anon_sym_WHILE] = ACTIONS(5935),
    [anon_sym_While] = ACTIONS(5935),
    [anon_sym_repeat] = ACTIONS(5935),
    [anon_sym_REPEAT] = ACTIONS(5935),
    [anon_sym_Repeat] = ACTIONS(5935),
    [anon_sym_exit] = ACTIONS(5935),
    [anon_sym_EXIT] = ACTIONS(5935),
    [anon_sym_Exit] = ACTIONS(5935),
    [anon_sym_continue] = ACTIONS(5935),
    [anon_sym_CONTINUE] = ACTIONS(5935),
    [anon_sym_Continue] = ACTIONS(5935),
    [anon_sym_break] = ACTIONS(5935),
    [anon_sym_BREAK] = ACTIONS(5935),
    [anon_sym_Break] = ACTIONS(5935),
    [anon_sym_with] = ACTIONS(5935),
    [anon_sym_WITH] = ACTIONS(5935),
    [anon_sym_With] = ACTIONS(5935),
    [sym_asserterror_keyword] = ACTIONS(5937),
    [sym_page_keyword] = ACTIONS(5935),
    [anon_sym_codeunit] = ACTIONS(5935),
    [anon_sym_CODEUNIT] = ACTIONS(5935),
    [anon_sym_Codeunit] = ACTIONS(5935),
    [anon_sym_CodeUnit] = ACTIONS(5935),
    [anon_sym_COdeunit] = ACTIONS(5935),
    [anon_sym_codeUnit] = ACTIONS(5935),
    [sym_report_keyword] = ACTIONS(5935),
    [sym_query_keyword] = ACTIONS(5935),
    [anon_sym_xmlport] = ACTIONS(5935),
    [anon_sym_XMLPORT] = ACTIONS(5935),
    [anon_sym_Xmlport] = ACTIONS(5935),
    [anon_sym_XMLport] = ACTIONS(5935),
    [anon_sym_XMLPort] = ACTIONS(5935),
    [anon_sym_XmlPort] = ACTIONS(5935),
    [anon_sym_enum] = ACTIONS(5935),
    [anon_sym_ENUM] = ACTIONS(5935),
    [anon_sym_Enum] = ACTIONS(5935),
    [anon_sym_eNUM] = ACTIONS(5935),
    [anon_sym_eNum] = ACTIONS(5935),
    [anon_sym_ENum] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5937),
    [sym_verbatim_string] = ACTIONS(5937),
    [sym_integer] = ACTIONS(5935),
    [sym_continue_as_identifier] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_end_keyword] = ACTIONS(5937),
  },
  [STATE(3176)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_DASH] = ACTIONS(5937),
    [aux_sym_boolean_token1] = ACTIONS(5935),
    [aux_sym_boolean_token2] = ACTIONS(5935),
    [sym_decimal] = ACTIONS(5935),
    [anon_sym_LPAREN] = ACTIONS(5937),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_record_type_token1] = ACTIONS(5935),
    [aux_sym_basic_type_token21] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token48] = ACTIONS(5935),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_not] = ACTIONS(5935),
    [anon_sym_NOT] = ACTIONS(5935),
    [anon_sym_Not] = ACTIONS(5935),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5935),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5935),
    [anon_sym_PLUS] = ACTIONS(5937),
    [sym_datetime_literal] = ACTIONS(5937),
    [sym_date_literal] = ACTIONS(5935),
    [sym_time_literal] = ACTIONS(5935),
    [sym_biginteger_literal] = ACTIONS(5937),
    [anon_sym_if] = ACTIONS(5935),
    [anon_sym_IF] = ACTIONS(5935),
    [anon_sym_If] = ACTIONS(5935),
    [anon_sym_else] = ACTIONS(5935),
    [anon_sym_ELSE] = ACTIONS(5935),
    [anon_sym_Else] = ACTIONS(5935),
    [anon_sym_case] = ACTIONS(5935),
    [anon_sym_CASE] = ACTIONS(5935),
    [anon_sym_Case] = ACTIONS(5935),
    [anon_sym_for] = ACTIONS(5935),
    [anon_sym_FOR] = ACTIONS(5935),
    [anon_sym_For] = ACTIONS(5935),
    [anon_sym_foreach] = ACTIONS(5935),
    [anon_sym_FOREACH] = ACTIONS(5935),
    [anon_sym_Foreach] = ACTIONS(5935),
    [anon_sym_while] = ACTIONS(5935),
    [anon_sym_WHILE] = ACTIONS(5935),
    [anon_sym_While] = ACTIONS(5935),
    [anon_sym_repeat] = ACTIONS(5935),
    [anon_sym_REPEAT] = ACTIONS(5935),
    [anon_sym_Repeat] = ACTIONS(5935),
    [anon_sym_exit] = ACTIONS(5935),
    [anon_sym_EXIT] = ACTIONS(5935),
    [anon_sym_Exit] = ACTIONS(5935),
    [anon_sym_continue] = ACTIONS(5935),
    [anon_sym_CONTINUE] = ACTIONS(5935),
    [anon_sym_Continue] = ACTIONS(5935),
    [anon_sym_break] = ACTIONS(5935),
    [anon_sym_BREAK] = ACTIONS(5935),
    [anon_sym_Break] = ACTIONS(5935),
    [anon_sym_with] = ACTIONS(5935),
    [anon_sym_WITH] = ACTIONS(5935),
    [anon_sym_With] = ACTIONS(5935),
    [sym_asserterror_keyword] = ACTIONS(5937),
    [sym_page_keyword] = ACTIONS(5935),
    [anon_sym_codeunit] = ACTIONS(5935),
    [anon_sym_CODEUNIT] = ACTIONS(5935),
    [anon_sym_Codeunit] = ACTIONS(5935),
    [anon_sym_CodeUnit] = ACTIONS(5935),
    [anon_sym_COdeunit] = ACTIONS(5935),
    [anon_sym_codeUnit] = ACTIONS(5935),
    [sym_report_keyword] = ACTIONS(5935),
    [sym_query_keyword] = ACTIONS(5935),
    [anon_sym_xmlport] = ACTIONS(5935),
    [anon_sym_XMLPORT] = ACTIONS(5935),
    [anon_sym_Xmlport] = ACTIONS(5935),
    [anon_sym_XMLport] = ACTIONS(5935),
    [anon_sym_XMLPort] = ACTIONS(5935),
    [anon_sym_XmlPort] = ACTIONS(5935),
    [anon_sym_enum] = ACTIONS(5935),
    [anon_sym_ENUM] = ACTIONS(5935),
    [anon_sym_Enum] = ACTIONS(5935),
    [anon_sym_eNUM] = ACTIONS(5935),
    [anon_sym_eNum] = ACTIONS(5935),
    [anon_sym_ENum] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5937),
    [sym_verbatim_string] = ACTIONS(5937),
    [sym_integer] = ACTIONS(5935),
    [sym_continue_as_identifier] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_end_keyword] = ACTIONS(5937),
  },
  [STATE(3177)] = {
    [sym_identifier] = ACTIONS(6300),
    [anon_sym_SEMI] = ACTIONS(6302),
    [anon_sym_DASH] = ACTIONS(6302),
    [aux_sym_boolean_token1] = ACTIONS(6300),
    [aux_sym_boolean_token2] = ACTIONS(6300),
    [sym_decimal] = ACTIONS(6300),
    [anon_sym_LPAREN] = ACTIONS(6302),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6300),
    [anon_sym_LBRACK] = ACTIONS(6302),
    [aux_sym_record_type_token1] = ACTIONS(6300),
    [aux_sym_basic_type_token21] = ACTIONS(6300),
    [aux_sym_basic_type_token22] = ACTIONS(6300),
    [aux_sym_basic_type_token48] = ACTIONS(6300),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6300),
    [anon_sym_POUNDif] = ACTIONS(6302),
    [anon_sym_POUNDIF] = ACTIONS(6302),
    [anon_sym_POUNDIf] = ACTIONS(6302),
    [anon_sym_not] = ACTIONS(6300),
    [anon_sym_NOT] = ACTIONS(6300),
    [anon_sym_Not] = ACTIONS(6300),
    [anon_sym_POUNDelse] = ACTIONS(6302),
    [anon_sym_POUNDELSE] = ACTIONS(6302),
    [anon_sym_POUNDElse] = ACTIONS(6302),
    [anon_sym_POUNDelse2] = ACTIONS(6302),
    [anon_sym_POUNDELSE2] = ACTIONS(6302),
    [anon_sym_POUNDElse2] = ACTIONS(6302),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6300),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6300),
    [anon_sym_PLUS] = ACTIONS(6302),
    [sym_datetime_literal] = ACTIONS(6302),
    [sym_date_literal] = ACTIONS(6300),
    [sym_time_literal] = ACTIONS(6300),
    [sym_biginteger_literal] = ACTIONS(6302),
    [anon_sym_if] = ACTIONS(6300),
    [anon_sym_IF] = ACTIONS(6300),
    [anon_sym_If] = ACTIONS(6300),
    [anon_sym_else] = ACTIONS(6300),
    [anon_sym_ELSE] = ACTIONS(6300),
    [anon_sym_Else] = ACTIONS(6300),
    [anon_sym_case] = ACTIONS(6300),
    [anon_sym_CASE] = ACTIONS(6300),
    [anon_sym_Case] = ACTIONS(6300),
    [anon_sym_for] = ACTIONS(6300),
    [anon_sym_FOR] = ACTIONS(6300),
    [anon_sym_For] = ACTIONS(6300),
    [anon_sym_foreach] = ACTIONS(6300),
    [anon_sym_FOREACH] = ACTIONS(6300),
    [anon_sym_Foreach] = ACTIONS(6300),
    [anon_sym_while] = ACTIONS(6300),
    [anon_sym_WHILE] = ACTIONS(6300),
    [anon_sym_While] = ACTIONS(6300),
    [anon_sym_repeat] = ACTIONS(6300),
    [anon_sym_REPEAT] = ACTIONS(6300),
    [anon_sym_Repeat] = ACTIONS(6300),
    [anon_sym_exit] = ACTIONS(6300),
    [anon_sym_EXIT] = ACTIONS(6300),
    [anon_sym_Exit] = ACTIONS(6300),
    [anon_sym_continue] = ACTIONS(6300),
    [anon_sym_CONTINUE] = ACTIONS(6300),
    [anon_sym_Continue] = ACTIONS(6300),
    [anon_sym_break] = ACTIONS(6300),
    [anon_sym_BREAK] = ACTIONS(6300),
    [anon_sym_Break] = ACTIONS(6300),
    [anon_sym_with] = ACTIONS(6300),
    [anon_sym_WITH] = ACTIONS(6300),
    [anon_sym_With] = ACTIONS(6300),
    [sym_asserterror_keyword] = ACTIONS(6302),
    [sym_page_keyword] = ACTIONS(6300),
    [anon_sym_codeunit] = ACTIONS(6300),
    [anon_sym_CODEUNIT] = ACTIONS(6300),
    [anon_sym_Codeunit] = ACTIONS(6300),
    [anon_sym_CodeUnit] = ACTIONS(6300),
    [anon_sym_COdeunit] = ACTIONS(6300),
    [anon_sym_codeUnit] = ACTIONS(6300),
    [sym_report_keyword] = ACTIONS(6300),
    [sym_query_keyword] = ACTIONS(6300),
    [anon_sym_xmlport] = ACTIONS(6300),
    [anon_sym_XMLPORT] = ACTIONS(6300),
    [anon_sym_Xmlport] = ACTIONS(6300),
    [anon_sym_XMLport] = ACTIONS(6300),
    [anon_sym_XMLPort] = ACTIONS(6300),
    [anon_sym_XmlPort] = ACTIONS(6300),
    [anon_sym_enum] = ACTIONS(6300),
    [anon_sym_ENUM] = ACTIONS(6300),
    [anon_sym_Enum] = ACTIONS(6300),
    [anon_sym_eNUM] = ACTIONS(6300),
    [anon_sym_eNum] = ACTIONS(6300),
    [anon_sym_ENum] = ACTIONS(6300),
    [sym_quoted_identifier] = ACTIONS(6302),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6302),
    [sym_verbatim_string] = ACTIONS(6302),
    [sym_integer] = ACTIONS(6300),
    [sym_continue_as_identifier] = ACTIONS(6302),
    [sym_preproc_open] = ACTIONS(6302),
    [sym_end_keyword] = ACTIONS(6302),
  },
  [STATE(3178)] = {
    [sym_identifier] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5571),
    [anon_sym_DASH] = ACTIONS(5571),
    [aux_sym_boolean_token1] = ACTIONS(5569),
    [aux_sym_boolean_token2] = ACTIONS(5569),
    [sym_decimal] = ACTIONS(5569),
    [anon_sym_LPAREN] = ACTIONS(5571),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5571),
    [aux_sym_record_type_token1] = ACTIONS(5569),
    [aux_sym_basic_type_token21] = ACTIONS(5569),
    [aux_sym_basic_type_token22] = ACTIONS(5569),
    [aux_sym_basic_type_token48] = ACTIONS(5569),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5569),
    [anon_sym_POUNDif] = ACTIONS(5571),
    [anon_sym_POUNDIF] = ACTIONS(5571),
    [anon_sym_POUNDIf] = ACTIONS(5571),
    [anon_sym_not] = ACTIONS(5569),
    [anon_sym_NOT] = ACTIONS(5569),
    [anon_sym_Not] = ACTIONS(5569),
    [anon_sym_POUNDelse] = ACTIONS(5571),
    [anon_sym_POUNDELSE] = ACTIONS(5571),
    [anon_sym_POUNDElse] = ACTIONS(5571),
    [anon_sym_POUNDelse2] = ACTIONS(5571),
    [anon_sym_POUNDELSE2] = ACTIONS(5571),
    [anon_sym_POUNDElse2] = ACTIONS(5571),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5569),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5569),
    [anon_sym_PLUS] = ACTIONS(5571),
    [sym_datetime_literal] = ACTIONS(5571),
    [sym_date_literal] = ACTIONS(5569),
    [sym_time_literal] = ACTIONS(5569),
    [sym_biginteger_literal] = ACTIONS(5571),
    [anon_sym_if] = ACTIONS(5569),
    [anon_sym_IF] = ACTIONS(5569),
    [anon_sym_If] = ACTIONS(5569),
    [anon_sym_else] = ACTIONS(5569),
    [anon_sym_ELSE] = ACTIONS(5569),
    [anon_sym_Else] = ACTIONS(5569),
    [anon_sym_case] = ACTIONS(5569),
    [anon_sym_CASE] = ACTIONS(5569),
    [anon_sym_Case] = ACTIONS(5569),
    [anon_sym_for] = ACTIONS(5569),
    [anon_sym_FOR] = ACTIONS(5569),
    [anon_sym_For] = ACTIONS(5569),
    [anon_sym_foreach] = ACTIONS(5569),
    [anon_sym_FOREACH] = ACTIONS(5569),
    [anon_sym_Foreach] = ACTIONS(5569),
    [anon_sym_while] = ACTIONS(5569),
    [anon_sym_WHILE] = ACTIONS(5569),
    [anon_sym_While] = ACTIONS(5569),
    [anon_sym_repeat] = ACTIONS(5569),
    [anon_sym_REPEAT] = ACTIONS(5569),
    [anon_sym_Repeat] = ACTIONS(5569),
    [anon_sym_exit] = ACTIONS(5569),
    [anon_sym_EXIT] = ACTIONS(5569),
    [anon_sym_Exit] = ACTIONS(5569),
    [anon_sym_continue] = ACTIONS(5569),
    [anon_sym_CONTINUE] = ACTIONS(5569),
    [anon_sym_Continue] = ACTIONS(5569),
    [anon_sym_break] = ACTIONS(5569),
    [anon_sym_BREAK] = ACTIONS(5569),
    [anon_sym_Break] = ACTIONS(5569),
    [anon_sym_with] = ACTIONS(5569),
    [anon_sym_WITH] = ACTIONS(5569),
    [anon_sym_With] = ACTIONS(5569),
    [sym_asserterror_keyword] = ACTIONS(5571),
    [sym_page_keyword] = ACTIONS(5569),
    [anon_sym_codeunit] = ACTIONS(5569),
    [anon_sym_CODEUNIT] = ACTIONS(5569),
    [anon_sym_Codeunit] = ACTIONS(5569),
    [anon_sym_CodeUnit] = ACTIONS(5569),
    [anon_sym_COdeunit] = ACTIONS(5569),
    [anon_sym_codeUnit] = ACTIONS(5569),
    [sym_report_keyword] = ACTIONS(5569),
    [sym_query_keyword] = ACTIONS(5569),
    [anon_sym_xmlport] = ACTIONS(5569),
    [anon_sym_XMLPORT] = ACTIONS(5569),
    [anon_sym_Xmlport] = ACTIONS(5569),
    [anon_sym_XMLport] = ACTIONS(5569),
    [anon_sym_XMLPort] = ACTIONS(5569),
    [anon_sym_XmlPort] = ACTIONS(5569),
    [anon_sym_enum] = ACTIONS(5569),
    [anon_sym_ENUM] = ACTIONS(5569),
    [anon_sym_Enum] = ACTIONS(5569),
    [anon_sym_eNUM] = ACTIONS(5569),
    [anon_sym_eNum] = ACTIONS(5569),
    [anon_sym_ENum] = ACTIONS(5569),
    [sym_quoted_identifier] = ACTIONS(5571),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5571),
    [sym_verbatim_string] = ACTIONS(5571),
    [sym_integer] = ACTIONS(5569),
    [sym_continue_as_identifier] = ACTIONS(5571),
    [sym_preproc_open] = ACTIONS(5571),
    [sym_end_keyword] = ACTIONS(5571),
  },
  [STATE(3179)] = {
    [sym_identifier] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5575),
    [anon_sym_DASH] = ACTIONS(5575),
    [aux_sym_boolean_token1] = ACTIONS(5573),
    [aux_sym_boolean_token2] = ACTIONS(5573),
    [sym_decimal] = ACTIONS(5573),
    [anon_sym_LPAREN] = ACTIONS(5575),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5575),
    [aux_sym_record_type_token1] = ACTIONS(5573),
    [aux_sym_basic_type_token21] = ACTIONS(5573),
    [aux_sym_basic_type_token22] = ACTIONS(5573),
    [aux_sym_basic_type_token48] = ACTIONS(5573),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5573),
    [anon_sym_POUNDif] = ACTIONS(5575),
    [anon_sym_POUNDIF] = ACTIONS(5575),
    [anon_sym_POUNDIf] = ACTIONS(5575),
    [anon_sym_not] = ACTIONS(5573),
    [anon_sym_NOT] = ACTIONS(5573),
    [anon_sym_Not] = ACTIONS(5573),
    [anon_sym_POUNDelse] = ACTIONS(5575),
    [anon_sym_POUNDELSE] = ACTIONS(5575),
    [anon_sym_POUNDElse] = ACTIONS(5575),
    [anon_sym_POUNDelse2] = ACTIONS(5575),
    [anon_sym_POUNDELSE2] = ACTIONS(5575),
    [anon_sym_POUNDElse2] = ACTIONS(5575),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5573),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5573),
    [anon_sym_PLUS] = ACTIONS(5575),
    [sym_datetime_literal] = ACTIONS(5575),
    [sym_date_literal] = ACTIONS(5573),
    [sym_time_literal] = ACTIONS(5573),
    [sym_biginteger_literal] = ACTIONS(5575),
    [anon_sym_if] = ACTIONS(5573),
    [anon_sym_IF] = ACTIONS(5573),
    [anon_sym_If] = ACTIONS(5573),
    [anon_sym_else] = ACTIONS(5573),
    [anon_sym_ELSE] = ACTIONS(5573),
    [anon_sym_Else] = ACTIONS(5573),
    [anon_sym_case] = ACTIONS(5573),
    [anon_sym_CASE] = ACTIONS(5573),
    [anon_sym_Case] = ACTIONS(5573),
    [anon_sym_for] = ACTIONS(5573),
    [anon_sym_FOR] = ACTIONS(5573),
    [anon_sym_For] = ACTIONS(5573),
    [anon_sym_foreach] = ACTIONS(5573),
    [anon_sym_FOREACH] = ACTIONS(5573),
    [anon_sym_Foreach] = ACTIONS(5573),
    [anon_sym_while] = ACTIONS(5573),
    [anon_sym_WHILE] = ACTIONS(5573),
    [anon_sym_While] = ACTIONS(5573),
    [anon_sym_repeat] = ACTIONS(5573),
    [anon_sym_REPEAT] = ACTIONS(5573),
    [anon_sym_Repeat] = ACTIONS(5573),
    [anon_sym_exit] = ACTIONS(5573),
    [anon_sym_EXIT] = ACTIONS(5573),
    [anon_sym_Exit] = ACTIONS(5573),
    [anon_sym_continue] = ACTIONS(5573),
    [anon_sym_CONTINUE] = ACTIONS(5573),
    [anon_sym_Continue] = ACTIONS(5573),
    [anon_sym_break] = ACTIONS(5573),
    [anon_sym_BREAK] = ACTIONS(5573),
    [anon_sym_Break] = ACTIONS(5573),
    [anon_sym_with] = ACTIONS(5573),
    [anon_sym_WITH] = ACTIONS(5573),
    [anon_sym_With] = ACTIONS(5573),
    [sym_asserterror_keyword] = ACTIONS(5575),
    [sym_page_keyword] = ACTIONS(5573),
    [anon_sym_codeunit] = ACTIONS(5573),
    [anon_sym_CODEUNIT] = ACTIONS(5573),
    [anon_sym_Codeunit] = ACTIONS(5573),
    [anon_sym_CodeUnit] = ACTIONS(5573),
    [anon_sym_COdeunit] = ACTIONS(5573),
    [anon_sym_codeUnit] = ACTIONS(5573),
    [sym_report_keyword] = ACTIONS(5573),
    [sym_query_keyword] = ACTIONS(5573),
    [anon_sym_xmlport] = ACTIONS(5573),
    [anon_sym_XMLPORT] = ACTIONS(5573),
    [anon_sym_Xmlport] = ACTIONS(5573),
    [anon_sym_XMLport] = ACTIONS(5573),
    [anon_sym_XMLPort] = ACTIONS(5573),
    [anon_sym_XmlPort] = ACTIONS(5573),
    [anon_sym_enum] = ACTIONS(5573),
    [anon_sym_ENUM] = ACTIONS(5573),
    [anon_sym_Enum] = ACTIONS(5573),
    [anon_sym_eNUM] = ACTIONS(5573),
    [anon_sym_eNum] = ACTIONS(5573),
    [anon_sym_ENum] = ACTIONS(5573),
    [sym_quoted_identifier] = ACTIONS(5575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5575),
    [sym_verbatim_string] = ACTIONS(5575),
    [sym_integer] = ACTIONS(5573),
    [sym_continue_as_identifier] = ACTIONS(5575),
    [sym_preproc_open] = ACTIONS(5575),
    [sym_end_keyword] = ACTIONS(5575),
  },
  [STATE(3180)] = {
    [sym_identifier] = ACTIONS(6264),
    [anon_sym_SEMI] = ACTIONS(7325),
    [anon_sym_DASH] = ACTIONS(6268),
    [aux_sym_boolean_token1] = ACTIONS(6264),
    [aux_sym_boolean_token2] = ACTIONS(6264),
    [sym_decimal] = ACTIONS(6264),
    [anon_sym_LPAREN] = ACTIONS(6268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6264),
    [anon_sym_LBRACK] = ACTIONS(6268),
    [aux_sym_record_type_token1] = ACTIONS(6264),
    [aux_sym_basic_type_token21] = ACTIONS(6264),
    [aux_sym_basic_type_token22] = ACTIONS(6264),
    [aux_sym_basic_type_token48] = ACTIONS(6264),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6264),
    [anon_sym_POUNDif] = ACTIONS(6268),
    [anon_sym_POUNDIF] = ACTIONS(6268),
    [anon_sym_POUNDIf] = ACTIONS(6268),
    [anon_sym_not] = ACTIONS(6264),
    [anon_sym_NOT] = ACTIONS(6264),
    [anon_sym_Not] = ACTIONS(6264),
    [anon_sym_POUNDelse] = ACTIONS(6268),
    [anon_sym_POUNDELSE] = ACTIONS(6268),
    [anon_sym_POUNDElse] = ACTIONS(6268),
    [anon_sym_POUNDelse2] = ACTIONS(6268),
    [anon_sym_POUNDELSE2] = ACTIONS(6268),
    [anon_sym_POUNDElse2] = ACTIONS(6268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6264),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6268),
    [sym_datetime_literal] = ACTIONS(6268),
    [sym_date_literal] = ACTIONS(6264),
    [sym_time_literal] = ACTIONS(6264),
    [sym_biginteger_literal] = ACTIONS(6268),
    [anon_sym_if] = ACTIONS(6264),
    [anon_sym_IF] = ACTIONS(6264),
    [anon_sym_If] = ACTIONS(6264),
    [anon_sym_else] = ACTIONS(6264),
    [anon_sym_ELSE] = ACTIONS(6264),
    [anon_sym_Else] = ACTIONS(6264),
    [anon_sym_case] = ACTIONS(6264),
    [anon_sym_CASE] = ACTIONS(6264),
    [anon_sym_Case] = ACTIONS(6264),
    [anon_sym_for] = ACTIONS(6264),
    [anon_sym_FOR] = ACTIONS(6264),
    [anon_sym_For] = ACTIONS(6264),
    [anon_sym_foreach] = ACTIONS(6264),
    [anon_sym_FOREACH] = ACTIONS(6264),
    [anon_sym_Foreach] = ACTIONS(6264),
    [anon_sym_while] = ACTIONS(6264),
    [anon_sym_WHILE] = ACTIONS(6264),
    [anon_sym_While] = ACTIONS(6264),
    [anon_sym_repeat] = ACTIONS(6264),
    [anon_sym_REPEAT] = ACTIONS(6264),
    [anon_sym_Repeat] = ACTIONS(6264),
    [anon_sym_exit] = ACTIONS(6264),
    [anon_sym_EXIT] = ACTIONS(6264),
    [anon_sym_Exit] = ACTIONS(6264),
    [anon_sym_continue] = ACTIONS(6264),
    [anon_sym_CONTINUE] = ACTIONS(6264),
    [anon_sym_Continue] = ACTIONS(6264),
    [anon_sym_break] = ACTIONS(6264),
    [anon_sym_BREAK] = ACTIONS(6264),
    [anon_sym_Break] = ACTIONS(6264),
    [anon_sym_with] = ACTIONS(6264),
    [anon_sym_WITH] = ACTIONS(6264),
    [anon_sym_With] = ACTIONS(6264),
    [sym_asserterror_keyword] = ACTIONS(6268),
    [sym_page_keyword] = ACTIONS(6264),
    [anon_sym_codeunit] = ACTIONS(6264),
    [anon_sym_CODEUNIT] = ACTIONS(6264),
    [anon_sym_Codeunit] = ACTIONS(6264),
    [anon_sym_CodeUnit] = ACTIONS(6264),
    [anon_sym_COdeunit] = ACTIONS(6264),
    [anon_sym_codeUnit] = ACTIONS(6264),
    [sym_report_keyword] = ACTIONS(6264),
    [sym_query_keyword] = ACTIONS(6264),
    [anon_sym_xmlport] = ACTIONS(6264),
    [anon_sym_XMLPORT] = ACTIONS(6264),
    [anon_sym_Xmlport] = ACTIONS(6264),
    [anon_sym_XMLport] = ACTIONS(6264),
    [anon_sym_XMLPort] = ACTIONS(6264),
    [anon_sym_XmlPort] = ACTIONS(6264),
    [anon_sym_enum] = ACTIONS(6264),
    [anon_sym_ENUM] = ACTIONS(6264),
    [anon_sym_Enum] = ACTIONS(6264),
    [anon_sym_eNUM] = ACTIONS(6264),
    [anon_sym_eNum] = ACTIONS(6264),
    [anon_sym_ENum] = ACTIONS(6264),
    [sym_quoted_identifier] = ACTIONS(6268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6268),
    [sym_verbatim_string] = ACTIONS(6268),
    [sym_integer] = ACTIONS(6264),
    [sym_continue_as_identifier] = ACTIONS(6268),
    [sym_preproc_open] = ACTIONS(6268),
    [sym_end_keyword] = ACTIONS(6268),
  },
  [STATE(3181)] = {
    [sym_identifier] = ACTIONS(5577),
    [anon_sym_SEMI] = ACTIONS(5579),
    [anon_sym_DASH] = ACTIONS(5579),
    [aux_sym_boolean_token1] = ACTIONS(5577),
    [aux_sym_boolean_token2] = ACTIONS(5577),
    [sym_decimal] = ACTIONS(5577),
    [anon_sym_LPAREN] = ACTIONS(5579),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5577),
    [anon_sym_LBRACK] = ACTIONS(5579),
    [aux_sym_record_type_token1] = ACTIONS(5577),
    [aux_sym_basic_type_token21] = ACTIONS(5577),
    [aux_sym_basic_type_token22] = ACTIONS(5577),
    [aux_sym_basic_type_token48] = ACTIONS(5577),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5577),
    [anon_sym_POUNDif] = ACTIONS(5579),
    [anon_sym_POUNDIF] = ACTIONS(5579),
    [anon_sym_POUNDIf] = ACTIONS(5579),
    [anon_sym_not] = ACTIONS(5577),
    [anon_sym_NOT] = ACTIONS(5577),
    [anon_sym_Not] = ACTIONS(5577),
    [anon_sym_POUNDelse] = ACTIONS(5579),
    [anon_sym_POUNDELSE] = ACTIONS(5579),
    [anon_sym_POUNDElse] = ACTIONS(5579),
    [anon_sym_POUNDelse2] = ACTIONS(5579),
    [anon_sym_POUNDELSE2] = ACTIONS(5579),
    [anon_sym_POUNDElse2] = ACTIONS(5579),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5577),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5577),
    [anon_sym_PLUS] = ACTIONS(5579),
    [sym_datetime_literal] = ACTIONS(5579),
    [sym_date_literal] = ACTIONS(5577),
    [sym_time_literal] = ACTIONS(5577),
    [sym_biginteger_literal] = ACTIONS(5579),
    [anon_sym_if] = ACTIONS(5577),
    [anon_sym_IF] = ACTIONS(5577),
    [anon_sym_If] = ACTIONS(5577),
    [anon_sym_else] = ACTIONS(5577),
    [anon_sym_ELSE] = ACTIONS(5577),
    [anon_sym_Else] = ACTIONS(5577),
    [anon_sym_case] = ACTIONS(5577),
    [anon_sym_CASE] = ACTIONS(5577),
    [anon_sym_Case] = ACTIONS(5577),
    [anon_sym_for] = ACTIONS(5577),
    [anon_sym_FOR] = ACTIONS(5577),
    [anon_sym_For] = ACTIONS(5577),
    [anon_sym_foreach] = ACTIONS(5577),
    [anon_sym_FOREACH] = ACTIONS(5577),
    [anon_sym_Foreach] = ACTIONS(5577),
    [anon_sym_while] = ACTIONS(5577),
    [anon_sym_WHILE] = ACTIONS(5577),
    [anon_sym_While] = ACTIONS(5577),
    [anon_sym_repeat] = ACTIONS(5577),
    [anon_sym_REPEAT] = ACTIONS(5577),
    [anon_sym_Repeat] = ACTIONS(5577),
    [anon_sym_exit] = ACTIONS(5577),
    [anon_sym_EXIT] = ACTIONS(5577),
    [anon_sym_Exit] = ACTIONS(5577),
    [anon_sym_continue] = ACTIONS(5577),
    [anon_sym_CONTINUE] = ACTIONS(5577),
    [anon_sym_Continue] = ACTIONS(5577),
    [anon_sym_break] = ACTIONS(5577),
    [anon_sym_BREAK] = ACTIONS(5577),
    [anon_sym_Break] = ACTIONS(5577),
    [anon_sym_with] = ACTIONS(5577),
    [anon_sym_WITH] = ACTIONS(5577),
    [anon_sym_With] = ACTIONS(5577),
    [sym_asserterror_keyword] = ACTIONS(5579),
    [sym_page_keyword] = ACTIONS(5577),
    [anon_sym_codeunit] = ACTIONS(5577),
    [anon_sym_CODEUNIT] = ACTIONS(5577),
    [anon_sym_Codeunit] = ACTIONS(5577),
    [anon_sym_CodeUnit] = ACTIONS(5577),
    [anon_sym_COdeunit] = ACTIONS(5577),
    [anon_sym_codeUnit] = ACTIONS(5577),
    [sym_report_keyword] = ACTIONS(5577),
    [sym_query_keyword] = ACTIONS(5577),
    [anon_sym_xmlport] = ACTIONS(5577),
    [anon_sym_XMLPORT] = ACTIONS(5577),
    [anon_sym_Xmlport] = ACTIONS(5577),
    [anon_sym_XMLport] = ACTIONS(5577),
    [anon_sym_XMLPort] = ACTIONS(5577),
    [anon_sym_XmlPort] = ACTIONS(5577),
    [anon_sym_enum] = ACTIONS(5577),
    [anon_sym_ENUM] = ACTIONS(5577),
    [anon_sym_Enum] = ACTIONS(5577),
    [anon_sym_eNUM] = ACTIONS(5577),
    [anon_sym_eNum] = ACTIONS(5577),
    [anon_sym_ENum] = ACTIONS(5577),
    [sym_quoted_identifier] = ACTIONS(5579),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5579),
    [sym_verbatim_string] = ACTIONS(5579),
    [sym_integer] = ACTIONS(5577),
    [sym_continue_as_identifier] = ACTIONS(5579),
    [sym_preproc_open] = ACTIONS(5579),
    [sym_end_keyword] = ACTIONS(5579),
  },
  [STATE(3182)] = {
    [sym_identifier] = ACTIONS(5581),
    [anon_sym_SEMI] = ACTIONS(5583),
    [anon_sym_DASH] = ACTIONS(5583),
    [aux_sym_boolean_token1] = ACTIONS(5581),
    [aux_sym_boolean_token2] = ACTIONS(5581),
    [sym_decimal] = ACTIONS(5581),
    [anon_sym_LPAREN] = ACTIONS(5583),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5581),
    [anon_sym_LBRACK] = ACTIONS(5583),
    [aux_sym_record_type_token1] = ACTIONS(5581),
    [aux_sym_basic_type_token21] = ACTIONS(5581),
    [aux_sym_basic_type_token22] = ACTIONS(5581),
    [aux_sym_basic_type_token48] = ACTIONS(5581),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5581),
    [anon_sym_POUNDif] = ACTIONS(5583),
    [anon_sym_POUNDIF] = ACTIONS(5583),
    [anon_sym_POUNDIf] = ACTIONS(5583),
    [anon_sym_not] = ACTIONS(5581),
    [anon_sym_NOT] = ACTIONS(5581),
    [anon_sym_Not] = ACTIONS(5581),
    [anon_sym_POUNDelse] = ACTIONS(5583),
    [anon_sym_POUNDELSE] = ACTIONS(5583),
    [anon_sym_POUNDElse] = ACTIONS(5583),
    [anon_sym_POUNDelse2] = ACTIONS(5583),
    [anon_sym_POUNDELSE2] = ACTIONS(5583),
    [anon_sym_POUNDElse2] = ACTIONS(5583),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5581),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5581),
    [anon_sym_PLUS] = ACTIONS(5583),
    [sym_datetime_literal] = ACTIONS(5583),
    [sym_date_literal] = ACTIONS(5581),
    [sym_time_literal] = ACTIONS(5581),
    [sym_biginteger_literal] = ACTIONS(5583),
    [anon_sym_if] = ACTIONS(5581),
    [anon_sym_IF] = ACTIONS(5581),
    [anon_sym_If] = ACTIONS(5581),
    [anon_sym_else] = ACTIONS(5581),
    [anon_sym_ELSE] = ACTIONS(5581),
    [anon_sym_Else] = ACTIONS(5581),
    [anon_sym_case] = ACTIONS(5581),
    [anon_sym_CASE] = ACTIONS(5581),
    [anon_sym_Case] = ACTIONS(5581),
    [anon_sym_for] = ACTIONS(5581),
    [anon_sym_FOR] = ACTIONS(5581),
    [anon_sym_For] = ACTIONS(5581),
    [anon_sym_foreach] = ACTIONS(5581),
    [anon_sym_FOREACH] = ACTIONS(5581),
    [anon_sym_Foreach] = ACTIONS(5581),
    [anon_sym_while] = ACTIONS(5581),
    [anon_sym_WHILE] = ACTIONS(5581),
    [anon_sym_While] = ACTIONS(5581),
    [anon_sym_repeat] = ACTIONS(5581),
    [anon_sym_REPEAT] = ACTIONS(5581),
    [anon_sym_Repeat] = ACTIONS(5581),
    [anon_sym_exit] = ACTIONS(5581),
    [anon_sym_EXIT] = ACTIONS(5581),
    [anon_sym_Exit] = ACTIONS(5581),
    [anon_sym_continue] = ACTIONS(5581),
    [anon_sym_CONTINUE] = ACTIONS(5581),
    [anon_sym_Continue] = ACTIONS(5581),
    [anon_sym_break] = ACTIONS(5581),
    [anon_sym_BREAK] = ACTIONS(5581),
    [anon_sym_Break] = ACTIONS(5581),
    [anon_sym_with] = ACTIONS(5581),
    [anon_sym_WITH] = ACTIONS(5581),
    [anon_sym_With] = ACTIONS(5581),
    [sym_asserterror_keyword] = ACTIONS(5583),
    [sym_page_keyword] = ACTIONS(5581),
    [anon_sym_codeunit] = ACTIONS(5581),
    [anon_sym_CODEUNIT] = ACTIONS(5581),
    [anon_sym_Codeunit] = ACTIONS(5581),
    [anon_sym_CodeUnit] = ACTIONS(5581),
    [anon_sym_COdeunit] = ACTIONS(5581),
    [anon_sym_codeUnit] = ACTIONS(5581),
    [sym_report_keyword] = ACTIONS(5581),
    [sym_query_keyword] = ACTIONS(5581),
    [anon_sym_xmlport] = ACTIONS(5581),
    [anon_sym_XMLPORT] = ACTIONS(5581),
    [anon_sym_Xmlport] = ACTIONS(5581),
    [anon_sym_XMLport] = ACTIONS(5581),
    [anon_sym_XMLPort] = ACTIONS(5581),
    [anon_sym_XmlPort] = ACTIONS(5581),
    [anon_sym_enum] = ACTIONS(5581),
    [anon_sym_ENUM] = ACTIONS(5581),
    [anon_sym_Enum] = ACTIONS(5581),
    [anon_sym_eNUM] = ACTIONS(5581),
    [anon_sym_eNum] = ACTIONS(5581),
    [anon_sym_ENum] = ACTIONS(5581),
    [sym_quoted_identifier] = ACTIONS(5583),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5583),
    [sym_verbatim_string] = ACTIONS(5583),
    [sym_integer] = ACTIONS(5581),
    [sym_continue_as_identifier] = ACTIONS(5583),
    [sym_preproc_open] = ACTIONS(5583),
    [sym_end_keyword] = ACTIONS(5583),
  },
  [STATE(3183)] = {
    [sym_identifier] = ACTIONS(6264),
    [anon_sym_SEMI] = ACTIONS(7327),
    [anon_sym_DASH] = ACTIONS(6268),
    [aux_sym_boolean_token1] = ACTIONS(6264),
    [aux_sym_boolean_token2] = ACTIONS(6264),
    [sym_decimal] = ACTIONS(6264),
    [anon_sym_LPAREN] = ACTIONS(6268),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6264),
    [anon_sym_LBRACK] = ACTIONS(6268),
    [aux_sym_record_type_token1] = ACTIONS(6264),
    [aux_sym_basic_type_token21] = ACTIONS(6264),
    [aux_sym_basic_type_token22] = ACTIONS(6264),
    [aux_sym_basic_type_token48] = ACTIONS(6264),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6264),
    [anon_sym_POUNDif] = ACTIONS(6268),
    [anon_sym_POUNDIF] = ACTIONS(6268),
    [anon_sym_POUNDIf] = ACTIONS(6268),
    [anon_sym_not] = ACTIONS(6264),
    [anon_sym_NOT] = ACTIONS(6264),
    [anon_sym_Not] = ACTIONS(6264),
    [anon_sym_POUNDelse] = ACTIONS(6268),
    [anon_sym_POUNDELSE] = ACTIONS(6268),
    [anon_sym_POUNDElse] = ACTIONS(6268),
    [anon_sym_POUNDelse2] = ACTIONS(6268),
    [anon_sym_POUNDELSE2] = ACTIONS(6268),
    [anon_sym_POUNDElse2] = ACTIONS(6268),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6264),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6264),
    [anon_sym_PLUS] = ACTIONS(6268),
    [sym_datetime_literal] = ACTIONS(6268),
    [sym_date_literal] = ACTIONS(6264),
    [sym_time_literal] = ACTIONS(6264),
    [sym_biginteger_literal] = ACTIONS(6268),
    [anon_sym_if] = ACTIONS(6264),
    [anon_sym_IF] = ACTIONS(6264),
    [anon_sym_If] = ACTIONS(6264),
    [anon_sym_else] = ACTIONS(6264),
    [anon_sym_ELSE] = ACTIONS(6264),
    [anon_sym_Else] = ACTIONS(6264),
    [anon_sym_case] = ACTIONS(6264),
    [anon_sym_CASE] = ACTIONS(6264),
    [anon_sym_Case] = ACTIONS(6264),
    [anon_sym_for] = ACTIONS(6264),
    [anon_sym_FOR] = ACTIONS(6264),
    [anon_sym_For] = ACTIONS(6264),
    [anon_sym_foreach] = ACTIONS(6264),
    [anon_sym_FOREACH] = ACTIONS(6264),
    [anon_sym_Foreach] = ACTIONS(6264),
    [anon_sym_while] = ACTIONS(6264),
    [anon_sym_WHILE] = ACTIONS(6264),
    [anon_sym_While] = ACTIONS(6264),
    [anon_sym_repeat] = ACTIONS(6264),
    [anon_sym_REPEAT] = ACTIONS(6264),
    [anon_sym_Repeat] = ACTIONS(6264),
    [anon_sym_exit] = ACTIONS(6264),
    [anon_sym_EXIT] = ACTIONS(6264),
    [anon_sym_Exit] = ACTIONS(6264),
    [anon_sym_continue] = ACTIONS(6264),
    [anon_sym_CONTINUE] = ACTIONS(6264),
    [anon_sym_Continue] = ACTIONS(6264),
    [anon_sym_break] = ACTIONS(6264),
    [anon_sym_BREAK] = ACTIONS(6264),
    [anon_sym_Break] = ACTIONS(6264),
    [anon_sym_with] = ACTIONS(6264),
    [anon_sym_WITH] = ACTIONS(6264),
    [anon_sym_With] = ACTIONS(6264),
    [sym_asserterror_keyword] = ACTIONS(6268),
    [sym_page_keyword] = ACTIONS(6264),
    [anon_sym_codeunit] = ACTIONS(6264),
    [anon_sym_CODEUNIT] = ACTIONS(6264),
    [anon_sym_Codeunit] = ACTIONS(6264),
    [anon_sym_CodeUnit] = ACTIONS(6264),
    [anon_sym_COdeunit] = ACTIONS(6264),
    [anon_sym_codeUnit] = ACTIONS(6264),
    [sym_report_keyword] = ACTIONS(6264),
    [sym_query_keyword] = ACTIONS(6264),
    [anon_sym_xmlport] = ACTIONS(6264),
    [anon_sym_XMLPORT] = ACTIONS(6264),
    [anon_sym_Xmlport] = ACTIONS(6264),
    [anon_sym_XMLport] = ACTIONS(6264),
    [anon_sym_XMLPort] = ACTIONS(6264),
    [anon_sym_XmlPort] = ACTIONS(6264),
    [anon_sym_enum] = ACTIONS(6264),
    [anon_sym_ENUM] = ACTIONS(6264),
    [anon_sym_Enum] = ACTIONS(6264),
    [anon_sym_eNUM] = ACTIONS(6264),
    [anon_sym_eNum] = ACTIONS(6264),
    [anon_sym_ENum] = ACTIONS(6264),
    [sym_quoted_identifier] = ACTIONS(6268),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6268),
    [sym_verbatim_string] = ACTIONS(6268),
    [sym_integer] = ACTIONS(6264),
    [sym_continue_as_identifier] = ACTIONS(6268),
    [sym_preproc_open] = ACTIONS(6268),
    [sym_end_keyword] = ACTIONS(6268),
  },
  [STATE(3184)] = {
    [sym_identifier] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5587),
    [anon_sym_DASH] = ACTIONS(5587),
    [aux_sym_boolean_token1] = ACTIONS(5585),
    [aux_sym_boolean_token2] = ACTIONS(5585),
    [sym_decimal] = ACTIONS(5585),
    [anon_sym_LPAREN] = ACTIONS(5587),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5587),
    [aux_sym_record_type_token1] = ACTIONS(5585),
    [aux_sym_basic_type_token21] = ACTIONS(5585),
    [aux_sym_basic_type_token22] = ACTIONS(5585),
    [aux_sym_basic_type_token48] = ACTIONS(5585),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5585),
    [anon_sym_POUNDif] = ACTIONS(5587),
    [anon_sym_POUNDIF] = ACTIONS(5587),
    [anon_sym_POUNDIf] = ACTIONS(5587),
    [anon_sym_not] = ACTIONS(5585),
    [anon_sym_NOT] = ACTIONS(5585),
    [anon_sym_Not] = ACTIONS(5585),
    [anon_sym_POUNDelse] = ACTIONS(5587),
    [anon_sym_POUNDELSE] = ACTIONS(5587),
    [anon_sym_POUNDElse] = ACTIONS(5587),
    [anon_sym_POUNDelse2] = ACTIONS(5587),
    [anon_sym_POUNDELSE2] = ACTIONS(5587),
    [anon_sym_POUNDElse2] = ACTIONS(5587),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5585),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5585),
    [anon_sym_PLUS] = ACTIONS(5587),
    [sym_datetime_literal] = ACTIONS(5587),
    [sym_date_literal] = ACTIONS(5585),
    [sym_time_literal] = ACTIONS(5585),
    [sym_biginteger_literal] = ACTIONS(5587),
    [anon_sym_if] = ACTIONS(5585),
    [anon_sym_IF] = ACTIONS(5585),
    [anon_sym_If] = ACTIONS(5585),
    [anon_sym_else] = ACTIONS(5585),
    [anon_sym_ELSE] = ACTIONS(5585),
    [anon_sym_Else] = ACTIONS(5585),
    [anon_sym_case] = ACTIONS(5585),
    [anon_sym_CASE] = ACTIONS(5585),
    [anon_sym_Case] = ACTIONS(5585),
    [anon_sym_for] = ACTIONS(5585),
    [anon_sym_FOR] = ACTIONS(5585),
    [anon_sym_For] = ACTIONS(5585),
    [anon_sym_foreach] = ACTIONS(5585),
    [anon_sym_FOREACH] = ACTIONS(5585),
    [anon_sym_Foreach] = ACTIONS(5585),
    [anon_sym_while] = ACTIONS(5585),
    [anon_sym_WHILE] = ACTIONS(5585),
    [anon_sym_While] = ACTIONS(5585),
    [anon_sym_repeat] = ACTIONS(5585),
    [anon_sym_REPEAT] = ACTIONS(5585),
    [anon_sym_Repeat] = ACTIONS(5585),
    [anon_sym_exit] = ACTIONS(5585),
    [anon_sym_EXIT] = ACTIONS(5585),
    [anon_sym_Exit] = ACTIONS(5585),
    [anon_sym_continue] = ACTIONS(5585),
    [anon_sym_CONTINUE] = ACTIONS(5585),
    [anon_sym_Continue] = ACTIONS(5585),
    [anon_sym_break] = ACTIONS(5585),
    [anon_sym_BREAK] = ACTIONS(5585),
    [anon_sym_Break] = ACTIONS(5585),
    [anon_sym_with] = ACTIONS(5585),
    [anon_sym_WITH] = ACTIONS(5585),
    [anon_sym_With] = ACTIONS(5585),
    [sym_asserterror_keyword] = ACTIONS(5587),
    [sym_page_keyword] = ACTIONS(5585),
    [anon_sym_codeunit] = ACTIONS(5585),
    [anon_sym_CODEUNIT] = ACTIONS(5585),
    [anon_sym_Codeunit] = ACTIONS(5585),
    [anon_sym_CodeUnit] = ACTIONS(5585),
    [anon_sym_COdeunit] = ACTIONS(5585),
    [anon_sym_codeUnit] = ACTIONS(5585),
    [sym_report_keyword] = ACTIONS(5585),
    [sym_query_keyword] = ACTIONS(5585),
    [anon_sym_xmlport] = ACTIONS(5585),
    [anon_sym_XMLPORT] = ACTIONS(5585),
    [anon_sym_Xmlport] = ACTIONS(5585),
    [anon_sym_XMLport] = ACTIONS(5585),
    [anon_sym_XMLPort] = ACTIONS(5585),
    [anon_sym_XmlPort] = ACTIONS(5585),
    [anon_sym_enum] = ACTIONS(5585),
    [anon_sym_ENUM] = ACTIONS(5585),
    [anon_sym_Enum] = ACTIONS(5585),
    [anon_sym_eNUM] = ACTIONS(5585),
    [anon_sym_eNum] = ACTIONS(5585),
    [anon_sym_ENum] = ACTIONS(5585),
    [sym_quoted_identifier] = ACTIONS(5587),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5587),
    [sym_verbatim_string] = ACTIONS(5587),
    [sym_integer] = ACTIONS(5585),
    [sym_continue_as_identifier] = ACTIONS(5587),
    [sym_preproc_open] = ACTIONS(5587),
    [sym_end_keyword] = ACTIONS(5587),
  },
  [STATE(3185)] = {
    [sym_identifier] = ACTIONS(5589),
    [anon_sym_SEMI] = ACTIONS(5591),
    [anon_sym_DASH] = ACTIONS(5591),
    [aux_sym_boolean_token1] = ACTIONS(5589),
    [aux_sym_boolean_token2] = ACTIONS(5589),
    [sym_decimal] = ACTIONS(5589),
    [anon_sym_LPAREN] = ACTIONS(5591),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5589),
    [anon_sym_LBRACK] = ACTIONS(5591),
    [aux_sym_record_type_token1] = ACTIONS(5589),
    [aux_sym_basic_type_token21] = ACTIONS(5589),
    [aux_sym_basic_type_token22] = ACTIONS(5589),
    [aux_sym_basic_type_token48] = ACTIONS(5589),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5589),
    [anon_sym_POUNDif] = ACTIONS(5591),
    [anon_sym_POUNDIF] = ACTIONS(5591),
    [anon_sym_POUNDIf] = ACTIONS(5591),
    [anon_sym_not] = ACTIONS(5589),
    [anon_sym_NOT] = ACTIONS(5589),
    [anon_sym_Not] = ACTIONS(5589),
    [anon_sym_POUNDelse] = ACTIONS(5591),
    [anon_sym_POUNDELSE] = ACTIONS(5591),
    [anon_sym_POUNDElse] = ACTIONS(5591),
    [anon_sym_POUNDelse2] = ACTIONS(5591),
    [anon_sym_POUNDELSE2] = ACTIONS(5591),
    [anon_sym_POUNDElse2] = ACTIONS(5591),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5589),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5589),
    [anon_sym_PLUS] = ACTIONS(5591),
    [sym_datetime_literal] = ACTIONS(5591),
    [sym_date_literal] = ACTIONS(5589),
    [sym_time_literal] = ACTIONS(5589),
    [sym_biginteger_literal] = ACTIONS(5591),
    [anon_sym_if] = ACTIONS(5589),
    [anon_sym_IF] = ACTIONS(5589),
    [anon_sym_If] = ACTIONS(5589),
    [anon_sym_else] = ACTIONS(5589),
    [anon_sym_ELSE] = ACTIONS(5589),
    [anon_sym_Else] = ACTIONS(5589),
    [anon_sym_case] = ACTIONS(5589),
    [anon_sym_CASE] = ACTIONS(5589),
    [anon_sym_Case] = ACTIONS(5589),
    [anon_sym_for] = ACTIONS(5589),
    [anon_sym_FOR] = ACTIONS(5589),
    [anon_sym_For] = ACTIONS(5589),
    [anon_sym_foreach] = ACTIONS(5589),
    [anon_sym_FOREACH] = ACTIONS(5589),
    [anon_sym_Foreach] = ACTIONS(5589),
    [anon_sym_while] = ACTIONS(5589),
    [anon_sym_WHILE] = ACTIONS(5589),
    [anon_sym_While] = ACTIONS(5589),
    [anon_sym_repeat] = ACTIONS(5589),
    [anon_sym_REPEAT] = ACTIONS(5589),
    [anon_sym_Repeat] = ACTIONS(5589),
    [anon_sym_exit] = ACTIONS(5589),
    [anon_sym_EXIT] = ACTIONS(5589),
    [anon_sym_Exit] = ACTIONS(5589),
    [anon_sym_continue] = ACTIONS(5589),
    [anon_sym_CONTINUE] = ACTIONS(5589),
    [anon_sym_Continue] = ACTIONS(5589),
    [anon_sym_break] = ACTIONS(5589),
    [anon_sym_BREAK] = ACTIONS(5589),
    [anon_sym_Break] = ACTIONS(5589),
    [anon_sym_with] = ACTIONS(5589),
    [anon_sym_WITH] = ACTIONS(5589),
    [anon_sym_With] = ACTIONS(5589),
    [sym_asserterror_keyword] = ACTIONS(5591),
    [sym_page_keyword] = ACTIONS(5589),
    [anon_sym_codeunit] = ACTIONS(5589),
    [anon_sym_CODEUNIT] = ACTIONS(5589),
    [anon_sym_Codeunit] = ACTIONS(5589),
    [anon_sym_CodeUnit] = ACTIONS(5589),
    [anon_sym_COdeunit] = ACTIONS(5589),
    [anon_sym_codeUnit] = ACTIONS(5589),
    [sym_report_keyword] = ACTIONS(5589),
    [sym_query_keyword] = ACTIONS(5589),
    [anon_sym_xmlport] = ACTIONS(5589),
    [anon_sym_XMLPORT] = ACTIONS(5589),
    [anon_sym_Xmlport] = ACTIONS(5589),
    [anon_sym_XMLport] = ACTIONS(5589),
    [anon_sym_XMLPort] = ACTIONS(5589),
    [anon_sym_XmlPort] = ACTIONS(5589),
    [anon_sym_enum] = ACTIONS(5589),
    [anon_sym_ENUM] = ACTIONS(5589),
    [anon_sym_Enum] = ACTIONS(5589),
    [anon_sym_eNUM] = ACTIONS(5589),
    [anon_sym_eNum] = ACTIONS(5589),
    [anon_sym_ENum] = ACTIONS(5589),
    [sym_quoted_identifier] = ACTIONS(5591),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5591),
    [sym_verbatim_string] = ACTIONS(5591),
    [sym_integer] = ACTIONS(5589),
    [sym_continue_as_identifier] = ACTIONS(5591),
    [sym_preproc_open] = ACTIONS(5591),
    [sym_end_keyword] = ACTIONS(5591),
  },
  [STATE(3186)] = {
    [sym_identifier] = ACTIONS(5593),
    [anon_sym_SEMI] = ACTIONS(5595),
    [anon_sym_DASH] = ACTIONS(5595),
    [aux_sym_boolean_token1] = ACTIONS(5593),
    [aux_sym_boolean_token2] = ACTIONS(5593),
    [sym_decimal] = ACTIONS(5593),
    [anon_sym_LPAREN] = ACTIONS(5595),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5593),
    [anon_sym_LBRACK] = ACTIONS(5595),
    [aux_sym_record_type_token1] = ACTIONS(5593),
    [aux_sym_basic_type_token21] = ACTIONS(5593),
    [aux_sym_basic_type_token22] = ACTIONS(5593),
    [aux_sym_basic_type_token48] = ACTIONS(5593),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5593),
    [anon_sym_POUNDif] = ACTIONS(5595),
    [anon_sym_POUNDIF] = ACTIONS(5595),
    [anon_sym_POUNDIf] = ACTIONS(5595),
    [anon_sym_not] = ACTIONS(5593),
    [anon_sym_NOT] = ACTIONS(5593),
    [anon_sym_Not] = ACTIONS(5593),
    [anon_sym_POUNDelse] = ACTIONS(5595),
    [anon_sym_POUNDELSE] = ACTIONS(5595),
    [anon_sym_POUNDElse] = ACTIONS(5595),
    [anon_sym_POUNDelse2] = ACTIONS(5595),
    [anon_sym_POUNDELSE2] = ACTIONS(5595),
    [anon_sym_POUNDElse2] = ACTIONS(5595),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5593),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5593),
    [anon_sym_PLUS] = ACTIONS(5595),
    [sym_datetime_literal] = ACTIONS(5595),
    [sym_date_literal] = ACTIONS(5593),
    [sym_time_literal] = ACTIONS(5593),
    [sym_biginteger_literal] = ACTIONS(5595),
    [anon_sym_if] = ACTIONS(5593),
    [anon_sym_IF] = ACTIONS(5593),
    [anon_sym_If] = ACTIONS(5593),
    [anon_sym_else] = ACTIONS(5593),
    [anon_sym_ELSE] = ACTIONS(5593),
    [anon_sym_Else] = ACTIONS(5593),
    [anon_sym_case] = ACTIONS(5593),
    [anon_sym_CASE] = ACTIONS(5593),
    [anon_sym_Case] = ACTIONS(5593),
    [anon_sym_for] = ACTIONS(5593),
    [anon_sym_FOR] = ACTIONS(5593),
    [anon_sym_For] = ACTIONS(5593),
    [anon_sym_foreach] = ACTIONS(5593),
    [anon_sym_FOREACH] = ACTIONS(5593),
    [anon_sym_Foreach] = ACTIONS(5593),
    [anon_sym_while] = ACTIONS(5593),
    [anon_sym_WHILE] = ACTIONS(5593),
    [anon_sym_While] = ACTIONS(5593),
    [anon_sym_repeat] = ACTIONS(5593),
    [anon_sym_REPEAT] = ACTIONS(5593),
    [anon_sym_Repeat] = ACTIONS(5593),
    [anon_sym_exit] = ACTIONS(5593),
    [anon_sym_EXIT] = ACTIONS(5593),
    [anon_sym_Exit] = ACTIONS(5593),
    [anon_sym_continue] = ACTIONS(5593),
    [anon_sym_CONTINUE] = ACTIONS(5593),
    [anon_sym_Continue] = ACTIONS(5593),
    [anon_sym_break] = ACTIONS(5593),
    [anon_sym_BREAK] = ACTIONS(5593),
    [anon_sym_Break] = ACTIONS(5593),
    [anon_sym_with] = ACTIONS(5593),
    [anon_sym_WITH] = ACTIONS(5593),
    [anon_sym_With] = ACTIONS(5593),
    [sym_asserterror_keyword] = ACTIONS(5595),
    [sym_page_keyword] = ACTIONS(5593),
    [anon_sym_codeunit] = ACTIONS(5593),
    [anon_sym_CODEUNIT] = ACTIONS(5593),
    [anon_sym_Codeunit] = ACTIONS(5593),
    [anon_sym_CodeUnit] = ACTIONS(5593),
    [anon_sym_COdeunit] = ACTIONS(5593),
    [anon_sym_codeUnit] = ACTIONS(5593),
    [sym_report_keyword] = ACTIONS(5593),
    [sym_query_keyword] = ACTIONS(5593),
    [anon_sym_xmlport] = ACTIONS(5593),
    [anon_sym_XMLPORT] = ACTIONS(5593),
    [anon_sym_Xmlport] = ACTIONS(5593),
    [anon_sym_XMLport] = ACTIONS(5593),
    [anon_sym_XMLPort] = ACTIONS(5593),
    [anon_sym_XmlPort] = ACTIONS(5593),
    [anon_sym_enum] = ACTIONS(5593),
    [anon_sym_ENUM] = ACTIONS(5593),
    [anon_sym_Enum] = ACTIONS(5593),
    [anon_sym_eNUM] = ACTIONS(5593),
    [anon_sym_eNum] = ACTIONS(5593),
    [anon_sym_ENum] = ACTIONS(5593),
    [sym_quoted_identifier] = ACTIONS(5595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5595),
    [sym_verbatim_string] = ACTIONS(5595),
    [sym_integer] = ACTIONS(5593),
    [sym_continue_as_identifier] = ACTIONS(5595),
    [sym_preproc_open] = ACTIONS(5595),
    [sym_end_keyword] = ACTIONS(5595),
  },
  [STATE(3187)] = {
    [sym_identifier] = ACTIONS(5597),
    [anon_sym_SEMI] = ACTIONS(5599),
    [anon_sym_DASH] = ACTIONS(5599),
    [aux_sym_boolean_token1] = ACTIONS(5597),
    [aux_sym_boolean_token2] = ACTIONS(5597),
    [sym_decimal] = ACTIONS(5597),
    [anon_sym_LPAREN] = ACTIONS(5599),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5597),
    [anon_sym_LBRACK] = ACTIONS(5599),
    [aux_sym_record_type_token1] = ACTIONS(5597),
    [aux_sym_basic_type_token21] = ACTIONS(5597),
    [aux_sym_basic_type_token22] = ACTIONS(5597),
    [aux_sym_basic_type_token48] = ACTIONS(5597),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5597),
    [anon_sym_POUNDif] = ACTIONS(5599),
    [anon_sym_POUNDIF] = ACTIONS(5599),
    [anon_sym_POUNDIf] = ACTIONS(5599),
    [anon_sym_not] = ACTIONS(5597),
    [anon_sym_NOT] = ACTIONS(5597),
    [anon_sym_Not] = ACTIONS(5597),
    [anon_sym_POUNDelse] = ACTIONS(5599),
    [anon_sym_POUNDELSE] = ACTIONS(5599),
    [anon_sym_POUNDElse] = ACTIONS(5599),
    [anon_sym_POUNDelse2] = ACTIONS(5599),
    [anon_sym_POUNDELSE2] = ACTIONS(5599),
    [anon_sym_POUNDElse2] = ACTIONS(5599),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5597),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5597),
    [anon_sym_PLUS] = ACTIONS(5599),
    [sym_datetime_literal] = ACTIONS(5599),
    [sym_date_literal] = ACTIONS(5597),
    [sym_time_literal] = ACTIONS(5597),
    [sym_biginteger_literal] = ACTIONS(5599),
    [anon_sym_if] = ACTIONS(5597),
    [anon_sym_IF] = ACTIONS(5597),
    [anon_sym_If] = ACTIONS(5597),
    [anon_sym_else] = ACTIONS(5597),
    [anon_sym_ELSE] = ACTIONS(5597),
    [anon_sym_Else] = ACTIONS(5597),
    [anon_sym_case] = ACTIONS(5597),
    [anon_sym_CASE] = ACTIONS(5597),
    [anon_sym_Case] = ACTIONS(5597),
    [anon_sym_for] = ACTIONS(5597),
    [anon_sym_FOR] = ACTIONS(5597),
    [anon_sym_For] = ACTIONS(5597),
    [anon_sym_foreach] = ACTIONS(5597),
    [anon_sym_FOREACH] = ACTIONS(5597),
    [anon_sym_Foreach] = ACTIONS(5597),
    [anon_sym_while] = ACTIONS(5597),
    [anon_sym_WHILE] = ACTIONS(5597),
    [anon_sym_While] = ACTIONS(5597),
    [anon_sym_repeat] = ACTIONS(5597),
    [anon_sym_REPEAT] = ACTIONS(5597),
    [anon_sym_Repeat] = ACTIONS(5597),
    [anon_sym_exit] = ACTIONS(5597),
    [anon_sym_EXIT] = ACTIONS(5597),
    [anon_sym_Exit] = ACTIONS(5597),
    [anon_sym_continue] = ACTIONS(5597),
    [anon_sym_CONTINUE] = ACTIONS(5597),
    [anon_sym_Continue] = ACTIONS(5597),
    [anon_sym_break] = ACTIONS(5597),
    [anon_sym_BREAK] = ACTIONS(5597),
    [anon_sym_Break] = ACTIONS(5597),
    [anon_sym_with] = ACTIONS(5597),
    [anon_sym_WITH] = ACTIONS(5597),
    [anon_sym_With] = ACTIONS(5597),
    [sym_asserterror_keyword] = ACTIONS(5599),
    [sym_page_keyword] = ACTIONS(5597),
    [anon_sym_codeunit] = ACTIONS(5597),
    [anon_sym_CODEUNIT] = ACTIONS(5597),
    [anon_sym_Codeunit] = ACTIONS(5597),
    [anon_sym_CodeUnit] = ACTIONS(5597),
    [anon_sym_COdeunit] = ACTIONS(5597),
    [anon_sym_codeUnit] = ACTIONS(5597),
    [sym_report_keyword] = ACTIONS(5597),
    [sym_query_keyword] = ACTIONS(5597),
    [anon_sym_xmlport] = ACTIONS(5597),
    [anon_sym_XMLPORT] = ACTIONS(5597),
    [anon_sym_Xmlport] = ACTIONS(5597),
    [anon_sym_XMLport] = ACTIONS(5597),
    [anon_sym_XMLPort] = ACTIONS(5597),
    [anon_sym_XmlPort] = ACTIONS(5597),
    [anon_sym_enum] = ACTIONS(5597),
    [anon_sym_ENUM] = ACTIONS(5597),
    [anon_sym_Enum] = ACTIONS(5597),
    [anon_sym_eNUM] = ACTIONS(5597),
    [anon_sym_eNum] = ACTIONS(5597),
    [anon_sym_ENum] = ACTIONS(5597),
    [sym_quoted_identifier] = ACTIONS(5599),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5599),
    [sym_verbatim_string] = ACTIONS(5599),
    [sym_integer] = ACTIONS(5597),
    [sym_continue_as_identifier] = ACTIONS(5599),
    [sym_preproc_open] = ACTIONS(5599),
    [sym_end_keyword] = ACTIONS(5599),
  },
  [STATE(3188)] = {
    [sym_identifier] = ACTIONS(6136),
    [anon_sym_SEMI] = ACTIONS(6138),
    [anon_sym_DASH] = ACTIONS(6138),
    [aux_sym_boolean_token1] = ACTIONS(6136),
    [aux_sym_boolean_token2] = ACTIONS(6136),
    [sym_decimal] = ACTIONS(6136),
    [anon_sym_LPAREN] = ACTIONS(6138),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6136),
    [anon_sym_LBRACK] = ACTIONS(6138),
    [aux_sym_record_type_token1] = ACTIONS(6136),
    [aux_sym_basic_type_token21] = ACTIONS(6136),
    [aux_sym_basic_type_token22] = ACTIONS(6136),
    [aux_sym_basic_type_token48] = ACTIONS(6136),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6136),
    [anon_sym_POUNDif] = ACTIONS(6138),
    [anon_sym_POUNDIF] = ACTIONS(6138),
    [anon_sym_POUNDIf] = ACTIONS(6138),
    [anon_sym_not] = ACTIONS(6136),
    [anon_sym_NOT] = ACTIONS(6136),
    [anon_sym_Not] = ACTIONS(6136),
    [anon_sym_POUNDelse] = ACTIONS(6138),
    [anon_sym_POUNDELSE] = ACTIONS(6138),
    [anon_sym_POUNDElse] = ACTIONS(6138),
    [anon_sym_POUNDelse2] = ACTIONS(6138),
    [anon_sym_POUNDELSE2] = ACTIONS(6138),
    [anon_sym_POUNDElse2] = ACTIONS(6138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6136),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6136),
    [anon_sym_PLUS] = ACTIONS(6138),
    [sym_datetime_literal] = ACTIONS(6138),
    [sym_date_literal] = ACTIONS(6136),
    [sym_time_literal] = ACTIONS(6136),
    [sym_biginteger_literal] = ACTIONS(6138),
    [anon_sym_if] = ACTIONS(6136),
    [anon_sym_IF] = ACTIONS(6136),
    [anon_sym_If] = ACTIONS(6136),
    [anon_sym_else] = ACTIONS(6136),
    [anon_sym_ELSE] = ACTIONS(6136),
    [anon_sym_Else] = ACTIONS(6136),
    [anon_sym_case] = ACTIONS(6136),
    [anon_sym_CASE] = ACTIONS(6136),
    [anon_sym_Case] = ACTIONS(6136),
    [anon_sym_for] = ACTIONS(6136),
    [anon_sym_FOR] = ACTIONS(6136),
    [anon_sym_For] = ACTIONS(6136),
    [anon_sym_foreach] = ACTIONS(6136),
    [anon_sym_FOREACH] = ACTIONS(6136),
    [anon_sym_Foreach] = ACTIONS(6136),
    [anon_sym_while] = ACTIONS(6136),
    [anon_sym_WHILE] = ACTIONS(6136),
    [anon_sym_While] = ACTIONS(6136),
    [anon_sym_repeat] = ACTIONS(6136),
    [anon_sym_REPEAT] = ACTIONS(6136),
    [anon_sym_Repeat] = ACTIONS(6136),
    [anon_sym_exit] = ACTIONS(6136),
    [anon_sym_EXIT] = ACTIONS(6136),
    [anon_sym_Exit] = ACTIONS(6136),
    [anon_sym_continue] = ACTIONS(6136),
    [anon_sym_CONTINUE] = ACTIONS(6136),
    [anon_sym_Continue] = ACTIONS(6136),
    [anon_sym_break] = ACTIONS(6136),
    [anon_sym_BREAK] = ACTIONS(6136),
    [anon_sym_Break] = ACTIONS(6136),
    [anon_sym_with] = ACTIONS(6136),
    [anon_sym_WITH] = ACTIONS(6136),
    [anon_sym_With] = ACTIONS(6136),
    [sym_asserterror_keyword] = ACTIONS(6138),
    [sym_page_keyword] = ACTIONS(6136),
    [anon_sym_codeunit] = ACTIONS(6136),
    [anon_sym_CODEUNIT] = ACTIONS(6136),
    [anon_sym_Codeunit] = ACTIONS(6136),
    [anon_sym_CodeUnit] = ACTIONS(6136),
    [anon_sym_COdeunit] = ACTIONS(6136),
    [anon_sym_codeUnit] = ACTIONS(6136),
    [sym_report_keyword] = ACTIONS(6136),
    [sym_query_keyword] = ACTIONS(6136),
    [anon_sym_xmlport] = ACTIONS(6136),
    [anon_sym_XMLPORT] = ACTIONS(6136),
    [anon_sym_Xmlport] = ACTIONS(6136),
    [anon_sym_XMLport] = ACTIONS(6136),
    [anon_sym_XMLPort] = ACTIONS(6136),
    [anon_sym_XmlPort] = ACTIONS(6136),
    [anon_sym_enum] = ACTIONS(6136),
    [anon_sym_ENUM] = ACTIONS(6136),
    [anon_sym_Enum] = ACTIONS(6136),
    [anon_sym_eNUM] = ACTIONS(6136),
    [anon_sym_eNum] = ACTIONS(6136),
    [anon_sym_ENum] = ACTIONS(6136),
    [sym_quoted_identifier] = ACTIONS(6138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6138),
    [sym_verbatim_string] = ACTIONS(6138),
    [sym_integer] = ACTIONS(6136),
    [sym_continue_as_identifier] = ACTIONS(6138),
    [sym_preproc_open] = ACTIONS(6138),
    [sym_end_keyword] = ACTIONS(6138),
  },
  [STATE(3189)] = {
    [sym_identifier] = ACTIONS(5601),
    [anon_sym_SEMI] = ACTIONS(5603),
    [anon_sym_DASH] = ACTIONS(5603),
    [aux_sym_boolean_token1] = ACTIONS(5601),
    [aux_sym_boolean_token2] = ACTIONS(5601),
    [sym_decimal] = ACTIONS(5601),
    [anon_sym_LPAREN] = ACTIONS(5603),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5601),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [aux_sym_record_type_token1] = ACTIONS(5601),
    [aux_sym_basic_type_token21] = ACTIONS(5601),
    [aux_sym_basic_type_token22] = ACTIONS(5601),
    [aux_sym_basic_type_token48] = ACTIONS(5601),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5601),
    [anon_sym_POUNDif] = ACTIONS(5603),
    [anon_sym_POUNDIF] = ACTIONS(5603),
    [anon_sym_POUNDIf] = ACTIONS(5603),
    [anon_sym_not] = ACTIONS(5601),
    [anon_sym_NOT] = ACTIONS(5601),
    [anon_sym_Not] = ACTIONS(5601),
    [anon_sym_POUNDelse] = ACTIONS(5603),
    [anon_sym_POUNDELSE] = ACTIONS(5603),
    [anon_sym_POUNDElse] = ACTIONS(5603),
    [anon_sym_POUNDelse2] = ACTIONS(5603),
    [anon_sym_POUNDELSE2] = ACTIONS(5603),
    [anon_sym_POUNDElse2] = ACTIONS(5603),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5601),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5601),
    [anon_sym_PLUS] = ACTIONS(5603),
    [sym_datetime_literal] = ACTIONS(5603),
    [sym_date_literal] = ACTIONS(5601),
    [sym_time_literal] = ACTIONS(5601),
    [sym_biginteger_literal] = ACTIONS(5603),
    [anon_sym_if] = ACTIONS(5601),
    [anon_sym_IF] = ACTIONS(5601),
    [anon_sym_If] = ACTIONS(5601),
    [anon_sym_else] = ACTIONS(5601),
    [anon_sym_ELSE] = ACTIONS(5601),
    [anon_sym_Else] = ACTIONS(5601),
    [anon_sym_case] = ACTIONS(5601),
    [anon_sym_CASE] = ACTIONS(5601),
    [anon_sym_Case] = ACTIONS(5601),
    [anon_sym_for] = ACTIONS(5601),
    [anon_sym_FOR] = ACTIONS(5601),
    [anon_sym_For] = ACTIONS(5601),
    [anon_sym_foreach] = ACTIONS(5601),
    [anon_sym_FOREACH] = ACTIONS(5601),
    [anon_sym_Foreach] = ACTIONS(5601),
    [anon_sym_while] = ACTIONS(5601),
    [anon_sym_WHILE] = ACTIONS(5601),
    [anon_sym_While] = ACTIONS(5601),
    [anon_sym_repeat] = ACTIONS(5601),
    [anon_sym_REPEAT] = ACTIONS(5601),
    [anon_sym_Repeat] = ACTIONS(5601),
    [anon_sym_exit] = ACTIONS(5601),
    [anon_sym_EXIT] = ACTIONS(5601),
    [anon_sym_Exit] = ACTIONS(5601),
    [anon_sym_continue] = ACTIONS(5601),
    [anon_sym_CONTINUE] = ACTIONS(5601),
    [anon_sym_Continue] = ACTIONS(5601),
    [anon_sym_break] = ACTIONS(5601),
    [anon_sym_BREAK] = ACTIONS(5601),
    [anon_sym_Break] = ACTIONS(5601),
    [anon_sym_with] = ACTIONS(5601),
    [anon_sym_WITH] = ACTIONS(5601),
    [anon_sym_With] = ACTIONS(5601),
    [sym_asserterror_keyword] = ACTIONS(5603),
    [sym_page_keyword] = ACTIONS(5601),
    [anon_sym_codeunit] = ACTIONS(5601),
    [anon_sym_CODEUNIT] = ACTIONS(5601),
    [anon_sym_Codeunit] = ACTIONS(5601),
    [anon_sym_CodeUnit] = ACTIONS(5601),
    [anon_sym_COdeunit] = ACTIONS(5601),
    [anon_sym_codeUnit] = ACTIONS(5601),
    [sym_report_keyword] = ACTIONS(5601),
    [sym_query_keyword] = ACTIONS(5601),
    [anon_sym_xmlport] = ACTIONS(5601),
    [anon_sym_XMLPORT] = ACTIONS(5601),
    [anon_sym_Xmlport] = ACTIONS(5601),
    [anon_sym_XMLport] = ACTIONS(5601),
    [anon_sym_XMLPort] = ACTIONS(5601),
    [anon_sym_XmlPort] = ACTIONS(5601),
    [anon_sym_enum] = ACTIONS(5601),
    [anon_sym_ENUM] = ACTIONS(5601),
    [anon_sym_Enum] = ACTIONS(5601),
    [anon_sym_eNUM] = ACTIONS(5601),
    [anon_sym_eNum] = ACTIONS(5601),
    [anon_sym_ENum] = ACTIONS(5601),
    [sym_quoted_identifier] = ACTIONS(5603),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5603),
    [sym_verbatim_string] = ACTIONS(5603),
    [sym_integer] = ACTIONS(5601),
    [sym_continue_as_identifier] = ACTIONS(5603),
    [sym_preproc_open] = ACTIONS(5603),
    [sym_end_keyword] = ACTIONS(5603),
  },
  [STATE(3190)] = {
    [sym_identifier] = ACTIONS(6304),
    [anon_sym_SEMI] = ACTIONS(6306),
    [anon_sym_DASH] = ACTIONS(6306),
    [aux_sym_boolean_token1] = ACTIONS(6304),
    [aux_sym_boolean_token2] = ACTIONS(6304),
    [sym_decimal] = ACTIONS(6304),
    [anon_sym_LPAREN] = ACTIONS(6306),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6304),
    [anon_sym_LBRACK] = ACTIONS(6306),
    [aux_sym_record_type_token1] = ACTIONS(6304),
    [aux_sym_basic_type_token21] = ACTIONS(6304),
    [aux_sym_basic_type_token22] = ACTIONS(6304),
    [aux_sym_basic_type_token48] = ACTIONS(6304),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6304),
    [anon_sym_POUNDif] = ACTIONS(6306),
    [anon_sym_POUNDIF] = ACTIONS(6306),
    [anon_sym_POUNDIf] = ACTIONS(6306),
    [anon_sym_not] = ACTIONS(6304),
    [anon_sym_NOT] = ACTIONS(6304),
    [anon_sym_Not] = ACTIONS(6304),
    [anon_sym_POUNDelse] = ACTIONS(6306),
    [anon_sym_POUNDELSE] = ACTIONS(6306),
    [anon_sym_POUNDElse] = ACTIONS(6306),
    [anon_sym_POUNDelse2] = ACTIONS(6306),
    [anon_sym_POUNDELSE2] = ACTIONS(6306),
    [anon_sym_POUNDElse2] = ACTIONS(6306),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6304),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6304),
    [anon_sym_PLUS] = ACTIONS(6306),
    [sym_datetime_literal] = ACTIONS(6306),
    [sym_date_literal] = ACTIONS(6304),
    [sym_time_literal] = ACTIONS(6304),
    [sym_biginteger_literal] = ACTIONS(6306),
    [anon_sym_if] = ACTIONS(6304),
    [anon_sym_IF] = ACTIONS(6304),
    [anon_sym_If] = ACTIONS(6304),
    [anon_sym_else] = ACTIONS(6304),
    [anon_sym_ELSE] = ACTIONS(6304),
    [anon_sym_Else] = ACTIONS(6304),
    [anon_sym_case] = ACTIONS(6304),
    [anon_sym_CASE] = ACTIONS(6304),
    [anon_sym_Case] = ACTIONS(6304),
    [anon_sym_for] = ACTIONS(6304),
    [anon_sym_FOR] = ACTIONS(6304),
    [anon_sym_For] = ACTIONS(6304),
    [anon_sym_foreach] = ACTIONS(6304),
    [anon_sym_FOREACH] = ACTIONS(6304),
    [anon_sym_Foreach] = ACTIONS(6304),
    [anon_sym_while] = ACTIONS(6304),
    [anon_sym_WHILE] = ACTIONS(6304),
    [anon_sym_While] = ACTIONS(6304),
    [anon_sym_repeat] = ACTIONS(6304),
    [anon_sym_REPEAT] = ACTIONS(6304),
    [anon_sym_Repeat] = ACTIONS(6304),
    [anon_sym_exit] = ACTIONS(6304),
    [anon_sym_EXIT] = ACTIONS(6304),
    [anon_sym_Exit] = ACTIONS(6304),
    [anon_sym_continue] = ACTIONS(6304),
    [anon_sym_CONTINUE] = ACTIONS(6304),
    [anon_sym_Continue] = ACTIONS(6304),
    [anon_sym_break] = ACTIONS(6304),
    [anon_sym_BREAK] = ACTIONS(6304),
    [anon_sym_Break] = ACTIONS(6304),
    [anon_sym_with] = ACTIONS(6304),
    [anon_sym_WITH] = ACTIONS(6304),
    [anon_sym_With] = ACTIONS(6304),
    [sym_asserterror_keyword] = ACTIONS(6306),
    [sym_page_keyword] = ACTIONS(6304),
    [anon_sym_codeunit] = ACTIONS(6304),
    [anon_sym_CODEUNIT] = ACTIONS(6304),
    [anon_sym_Codeunit] = ACTIONS(6304),
    [anon_sym_CodeUnit] = ACTIONS(6304),
    [anon_sym_COdeunit] = ACTIONS(6304),
    [anon_sym_codeUnit] = ACTIONS(6304),
    [sym_report_keyword] = ACTIONS(6304),
    [sym_query_keyword] = ACTIONS(6304),
    [anon_sym_xmlport] = ACTIONS(6304),
    [anon_sym_XMLPORT] = ACTIONS(6304),
    [anon_sym_Xmlport] = ACTIONS(6304),
    [anon_sym_XMLport] = ACTIONS(6304),
    [anon_sym_XMLPort] = ACTIONS(6304),
    [anon_sym_XmlPort] = ACTIONS(6304),
    [anon_sym_enum] = ACTIONS(6304),
    [anon_sym_ENUM] = ACTIONS(6304),
    [anon_sym_Enum] = ACTIONS(6304),
    [anon_sym_eNUM] = ACTIONS(6304),
    [anon_sym_eNum] = ACTIONS(6304),
    [anon_sym_ENum] = ACTIONS(6304),
    [sym_quoted_identifier] = ACTIONS(6306),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6306),
    [sym_verbatim_string] = ACTIONS(6306),
    [sym_integer] = ACTIONS(6304),
    [sym_continue_as_identifier] = ACTIONS(6306),
    [sym_preproc_open] = ACTIONS(6306),
    [sym_end_keyword] = ACTIONS(6306),
  },
  [STATE(3191)] = {
    [sym_identifier] = ACTIONS(6140),
    [anon_sym_SEMI] = ACTIONS(6142),
    [anon_sym_DASH] = ACTIONS(6142),
    [aux_sym_boolean_token1] = ACTIONS(6140),
    [aux_sym_boolean_token2] = ACTIONS(6140),
    [sym_decimal] = ACTIONS(6140),
    [anon_sym_LPAREN] = ACTIONS(6142),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6140),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [aux_sym_record_type_token1] = ACTIONS(6140),
    [aux_sym_basic_type_token21] = ACTIONS(6140),
    [aux_sym_basic_type_token22] = ACTIONS(6140),
    [aux_sym_basic_type_token48] = ACTIONS(6140),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6140),
    [anon_sym_POUNDif] = ACTIONS(6142),
    [anon_sym_POUNDIF] = ACTIONS(6142),
    [anon_sym_POUNDIf] = ACTIONS(6142),
    [anon_sym_not] = ACTIONS(6140),
    [anon_sym_NOT] = ACTIONS(6140),
    [anon_sym_Not] = ACTIONS(6140),
    [anon_sym_POUNDelse] = ACTIONS(6142),
    [anon_sym_POUNDELSE] = ACTIONS(6142),
    [anon_sym_POUNDElse] = ACTIONS(6142),
    [anon_sym_POUNDelse2] = ACTIONS(6142),
    [anon_sym_POUNDELSE2] = ACTIONS(6142),
    [anon_sym_POUNDElse2] = ACTIONS(6142),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6140),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6140),
    [anon_sym_PLUS] = ACTIONS(6142),
    [sym_datetime_literal] = ACTIONS(6142),
    [sym_date_literal] = ACTIONS(6140),
    [sym_time_literal] = ACTIONS(6140),
    [sym_biginteger_literal] = ACTIONS(6142),
    [anon_sym_if] = ACTIONS(6140),
    [anon_sym_IF] = ACTIONS(6140),
    [anon_sym_If] = ACTIONS(6140),
    [anon_sym_else] = ACTIONS(6140),
    [anon_sym_ELSE] = ACTIONS(6140),
    [anon_sym_Else] = ACTIONS(6140),
    [anon_sym_case] = ACTIONS(6140),
    [anon_sym_CASE] = ACTIONS(6140),
    [anon_sym_Case] = ACTIONS(6140),
    [anon_sym_for] = ACTIONS(6140),
    [anon_sym_FOR] = ACTIONS(6140),
    [anon_sym_For] = ACTIONS(6140),
    [anon_sym_foreach] = ACTIONS(6140),
    [anon_sym_FOREACH] = ACTIONS(6140),
    [anon_sym_Foreach] = ACTIONS(6140),
    [anon_sym_while] = ACTIONS(6140),
    [anon_sym_WHILE] = ACTIONS(6140),
    [anon_sym_While] = ACTIONS(6140),
    [anon_sym_repeat] = ACTIONS(6140),
    [anon_sym_REPEAT] = ACTIONS(6140),
    [anon_sym_Repeat] = ACTIONS(6140),
    [anon_sym_exit] = ACTIONS(6140),
    [anon_sym_EXIT] = ACTIONS(6140),
    [anon_sym_Exit] = ACTIONS(6140),
    [anon_sym_continue] = ACTIONS(6140),
    [anon_sym_CONTINUE] = ACTIONS(6140),
    [anon_sym_Continue] = ACTIONS(6140),
    [anon_sym_break] = ACTIONS(6140),
    [anon_sym_BREAK] = ACTIONS(6140),
    [anon_sym_Break] = ACTIONS(6140),
    [anon_sym_with] = ACTIONS(6140),
    [anon_sym_WITH] = ACTIONS(6140),
    [anon_sym_With] = ACTIONS(6140),
    [sym_asserterror_keyword] = ACTIONS(6142),
    [sym_page_keyword] = ACTIONS(6140),
    [anon_sym_codeunit] = ACTIONS(6140),
    [anon_sym_CODEUNIT] = ACTIONS(6140),
    [anon_sym_Codeunit] = ACTIONS(6140),
    [anon_sym_CodeUnit] = ACTIONS(6140),
    [anon_sym_COdeunit] = ACTIONS(6140),
    [anon_sym_codeUnit] = ACTIONS(6140),
    [sym_report_keyword] = ACTIONS(6140),
    [sym_query_keyword] = ACTIONS(6140),
    [anon_sym_xmlport] = ACTIONS(6140),
    [anon_sym_XMLPORT] = ACTIONS(6140),
    [anon_sym_Xmlport] = ACTIONS(6140),
    [anon_sym_XMLport] = ACTIONS(6140),
    [anon_sym_XMLPort] = ACTIONS(6140),
    [anon_sym_XmlPort] = ACTIONS(6140),
    [anon_sym_enum] = ACTIONS(6140),
    [anon_sym_ENUM] = ACTIONS(6140),
    [anon_sym_Enum] = ACTIONS(6140),
    [anon_sym_eNUM] = ACTIONS(6140),
    [anon_sym_eNum] = ACTIONS(6140),
    [anon_sym_ENum] = ACTIONS(6140),
    [sym_quoted_identifier] = ACTIONS(6142),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6142),
    [sym_verbatim_string] = ACTIONS(6142),
    [sym_integer] = ACTIONS(6140),
    [sym_continue_as_identifier] = ACTIONS(6142),
    [sym_preproc_open] = ACTIONS(6142),
    [sym_end_keyword] = ACTIONS(6142),
  },
  [STATE(3192)] = {
    [sym_identifier] = ACTIONS(6144),
    [anon_sym_SEMI] = ACTIONS(6146),
    [anon_sym_DASH] = ACTIONS(6146),
    [aux_sym_boolean_token1] = ACTIONS(6144),
    [aux_sym_boolean_token2] = ACTIONS(6144),
    [sym_decimal] = ACTIONS(6144),
    [anon_sym_LPAREN] = ACTIONS(6146),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6144),
    [anon_sym_LBRACK] = ACTIONS(6146),
    [aux_sym_record_type_token1] = ACTIONS(6144),
    [aux_sym_basic_type_token21] = ACTIONS(6144),
    [aux_sym_basic_type_token22] = ACTIONS(6144),
    [aux_sym_basic_type_token48] = ACTIONS(6144),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6144),
    [anon_sym_POUNDif] = ACTIONS(6146),
    [anon_sym_POUNDIF] = ACTIONS(6146),
    [anon_sym_POUNDIf] = ACTIONS(6146),
    [anon_sym_not] = ACTIONS(6144),
    [anon_sym_NOT] = ACTIONS(6144),
    [anon_sym_Not] = ACTIONS(6144),
    [anon_sym_POUNDelse] = ACTIONS(6146),
    [anon_sym_POUNDELSE] = ACTIONS(6146),
    [anon_sym_POUNDElse] = ACTIONS(6146),
    [anon_sym_POUNDelse2] = ACTIONS(6146),
    [anon_sym_POUNDELSE2] = ACTIONS(6146),
    [anon_sym_POUNDElse2] = ACTIONS(6146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6144),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6144),
    [anon_sym_PLUS] = ACTIONS(6146),
    [sym_datetime_literal] = ACTIONS(6146),
    [sym_date_literal] = ACTIONS(6144),
    [sym_time_literal] = ACTIONS(6144),
    [sym_biginteger_literal] = ACTIONS(6146),
    [anon_sym_if] = ACTIONS(6144),
    [anon_sym_IF] = ACTIONS(6144),
    [anon_sym_If] = ACTIONS(6144),
    [anon_sym_else] = ACTIONS(6144),
    [anon_sym_ELSE] = ACTIONS(6144),
    [anon_sym_Else] = ACTIONS(6144),
    [anon_sym_case] = ACTIONS(6144),
    [anon_sym_CASE] = ACTIONS(6144),
    [anon_sym_Case] = ACTIONS(6144),
    [anon_sym_for] = ACTIONS(6144),
    [anon_sym_FOR] = ACTIONS(6144),
    [anon_sym_For] = ACTIONS(6144),
    [anon_sym_foreach] = ACTIONS(6144),
    [anon_sym_FOREACH] = ACTIONS(6144),
    [anon_sym_Foreach] = ACTIONS(6144),
    [anon_sym_while] = ACTIONS(6144),
    [anon_sym_WHILE] = ACTIONS(6144),
    [anon_sym_While] = ACTIONS(6144),
    [anon_sym_repeat] = ACTIONS(6144),
    [anon_sym_REPEAT] = ACTIONS(6144),
    [anon_sym_Repeat] = ACTIONS(6144),
    [anon_sym_exit] = ACTIONS(6144),
    [anon_sym_EXIT] = ACTIONS(6144),
    [anon_sym_Exit] = ACTIONS(6144),
    [anon_sym_continue] = ACTIONS(6144),
    [anon_sym_CONTINUE] = ACTIONS(6144),
    [anon_sym_Continue] = ACTIONS(6144),
    [anon_sym_break] = ACTIONS(6144),
    [anon_sym_BREAK] = ACTIONS(6144),
    [anon_sym_Break] = ACTIONS(6144),
    [anon_sym_with] = ACTIONS(6144),
    [anon_sym_WITH] = ACTIONS(6144),
    [anon_sym_With] = ACTIONS(6144),
    [sym_asserterror_keyword] = ACTIONS(6146),
    [sym_page_keyword] = ACTIONS(6144),
    [anon_sym_codeunit] = ACTIONS(6144),
    [anon_sym_CODEUNIT] = ACTIONS(6144),
    [anon_sym_Codeunit] = ACTIONS(6144),
    [anon_sym_CodeUnit] = ACTIONS(6144),
    [anon_sym_COdeunit] = ACTIONS(6144),
    [anon_sym_codeUnit] = ACTIONS(6144),
    [sym_report_keyword] = ACTIONS(6144),
    [sym_query_keyword] = ACTIONS(6144),
    [anon_sym_xmlport] = ACTIONS(6144),
    [anon_sym_XMLPORT] = ACTIONS(6144),
    [anon_sym_Xmlport] = ACTIONS(6144),
    [anon_sym_XMLport] = ACTIONS(6144),
    [anon_sym_XMLPort] = ACTIONS(6144),
    [anon_sym_XmlPort] = ACTIONS(6144),
    [anon_sym_enum] = ACTIONS(6144),
    [anon_sym_ENUM] = ACTIONS(6144),
    [anon_sym_Enum] = ACTIONS(6144),
    [anon_sym_eNUM] = ACTIONS(6144),
    [anon_sym_eNum] = ACTIONS(6144),
    [anon_sym_ENum] = ACTIONS(6144),
    [sym_quoted_identifier] = ACTIONS(6146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6146),
    [sym_verbatim_string] = ACTIONS(6146),
    [sym_integer] = ACTIONS(6144),
    [sym_continue_as_identifier] = ACTIONS(6146),
    [sym_preproc_open] = ACTIONS(6146),
    [sym_end_keyword] = ACTIONS(6146),
  },
  [STATE(3193)] = {
    [sym_identifier] = ACTIONS(6148),
    [anon_sym_SEMI] = ACTIONS(6150),
    [anon_sym_DASH] = ACTIONS(6150),
    [aux_sym_boolean_token1] = ACTIONS(6148),
    [aux_sym_boolean_token2] = ACTIONS(6148),
    [sym_decimal] = ACTIONS(6148),
    [anon_sym_LPAREN] = ACTIONS(6150),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6148),
    [anon_sym_LBRACK] = ACTIONS(6150),
    [aux_sym_record_type_token1] = ACTIONS(6148),
    [aux_sym_basic_type_token21] = ACTIONS(6148),
    [aux_sym_basic_type_token22] = ACTIONS(6148),
    [aux_sym_basic_type_token48] = ACTIONS(6148),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6148),
    [anon_sym_POUNDif] = ACTIONS(6150),
    [anon_sym_POUNDIF] = ACTIONS(6150),
    [anon_sym_POUNDIf] = ACTIONS(6150),
    [anon_sym_not] = ACTIONS(6148),
    [anon_sym_NOT] = ACTIONS(6148),
    [anon_sym_Not] = ACTIONS(6148),
    [anon_sym_POUNDelse] = ACTIONS(6150),
    [anon_sym_POUNDELSE] = ACTIONS(6150),
    [anon_sym_POUNDElse] = ACTIONS(6150),
    [anon_sym_POUNDelse2] = ACTIONS(6150),
    [anon_sym_POUNDELSE2] = ACTIONS(6150),
    [anon_sym_POUNDElse2] = ACTIONS(6150),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6148),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6148),
    [anon_sym_PLUS] = ACTIONS(6150),
    [sym_datetime_literal] = ACTIONS(6150),
    [sym_date_literal] = ACTIONS(6148),
    [sym_time_literal] = ACTIONS(6148),
    [sym_biginteger_literal] = ACTIONS(6150),
    [anon_sym_if] = ACTIONS(6148),
    [anon_sym_IF] = ACTIONS(6148),
    [anon_sym_If] = ACTIONS(6148),
    [anon_sym_else] = ACTIONS(6148),
    [anon_sym_ELSE] = ACTIONS(6148),
    [anon_sym_Else] = ACTIONS(6148),
    [anon_sym_case] = ACTIONS(6148),
    [anon_sym_CASE] = ACTIONS(6148),
    [anon_sym_Case] = ACTIONS(6148),
    [anon_sym_for] = ACTIONS(6148),
    [anon_sym_FOR] = ACTIONS(6148),
    [anon_sym_For] = ACTIONS(6148),
    [anon_sym_foreach] = ACTIONS(6148),
    [anon_sym_FOREACH] = ACTIONS(6148),
    [anon_sym_Foreach] = ACTIONS(6148),
    [anon_sym_while] = ACTIONS(6148),
    [anon_sym_WHILE] = ACTIONS(6148),
    [anon_sym_While] = ACTIONS(6148),
    [anon_sym_repeat] = ACTIONS(6148),
    [anon_sym_REPEAT] = ACTIONS(6148),
    [anon_sym_Repeat] = ACTIONS(6148),
    [anon_sym_exit] = ACTIONS(6148),
    [anon_sym_EXIT] = ACTIONS(6148),
    [anon_sym_Exit] = ACTIONS(6148),
    [anon_sym_continue] = ACTIONS(6148),
    [anon_sym_CONTINUE] = ACTIONS(6148),
    [anon_sym_Continue] = ACTIONS(6148),
    [anon_sym_break] = ACTIONS(6148),
    [anon_sym_BREAK] = ACTIONS(6148),
    [anon_sym_Break] = ACTIONS(6148),
    [anon_sym_with] = ACTIONS(6148),
    [anon_sym_WITH] = ACTIONS(6148),
    [anon_sym_With] = ACTIONS(6148),
    [sym_asserterror_keyword] = ACTIONS(6150),
    [sym_page_keyword] = ACTIONS(6148),
    [anon_sym_codeunit] = ACTIONS(6148),
    [anon_sym_CODEUNIT] = ACTIONS(6148),
    [anon_sym_Codeunit] = ACTIONS(6148),
    [anon_sym_CodeUnit] = ACTIONS(6148),
    [anon_sym_COdeunit] = ACTIONS(6148),
    [anon_sym_codeUnit] = ACTIONS(6148),
    [sym_report_keyword] = ACTIONS(6148),
    [sym_query_keyword] = ACTIONS(6148),
    [anon_sym_xmlport] = ACTIONS(6148),
    [anon_sym_XMLPORT] = ACTIONS(6148),
    [anon_sym_Xmlport] = ACTIONS(6148),
    [anon_sym_XMLport] = ACTIONS(6148),
    [anon_sym_XMLPort] = ACTIONS(6148),
    [anon_sym_XmlPort] = ACTIONS(6148),
    [anon_sym_enum] = ACTIONS(6148),
    [anon_sym_ENUM] = ACTIONS(6148),
    [anon_sym_Enum] = ACTIONS(6148),
    [anon_sym_eNUM] = ACTIONS(6148),
    [anon_sym_eNum] = ACTIONS(6148),
    [anon_sym_ENum] = ACTIONS(6148),
    [sym_quoted_identifier] = ACTIONS(6150),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6150),
    [sym_verbatim_string] = ACTIONS(6150),
    [sym_integer] = ACTIONS(6148),
    [sym_continue_as_identifier] = ACTIONS(6150),
    [sym_preproc_open] = ACTIONS(6150),
    [sym_end_keyword] = ACTIONS(6150),
  },
  [STATE(3194)] = {
    [sym_identifier] = ACTIONS(6152),
    [anon_sym_SEMI] = ACTIONS(6154),
    [anon_sym_DASH] = ACTIONS(6154),
    [aux_sym_boolean_token1] = ACTIONS(6152),
    [aux_sym_boolean_token2] = ACTIONS(6152),
    [sym_decimal] = ACTIONS(6152),
    [anon_sym_LPAREN] = ACTIONS(6154),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6152),
    [anon_sym_LBRACK] = ACTIONS(6154),
    [aux_sym_record_type_token1] = ACTIONS(6152),
    [aux_sym_basic_type_token21] = ACTIONS(6152),
    [aux_sym_basic_type_token22] = ACTIONS(6152),
    [aux_sym_basic_type_token48] = ACTIONS(6152),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6152),
    [anon_sym_POUNDif] = ACTIONS(6154),
    [anon_sym_POUNDIF] = ACTIONS(6154),
    [anon_sym_POUNDIf] = ACTIONS(6154),
    [anon_sym_not] = ACTIONS(6152),
    [anon_sym_NOT] = ACTIONS(6152),
    [anon_sym_Not] = ACTIONS(6152),
    [anon_sym_POUNDelse] = ACTIONS(6154),
    [anon_sym_POUNDELSE] = ACTIONS(6154),
    [anon_sym_POUNDElse] = ACTIONS(6154),
    [anon_sym_POUNDelse2] = ACTIONS(6154),
    [anon_sym_POUNDELSE2] = ACTIONS(6154),
    [anon_sym_POUNDElse2] = ACTIONS(6154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6152),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6152),
    [anon_sym_PLUS] = ACTIONS(6154),
    [sym_datetime_literal] = ACTIONS(6154),
    [sym_date_literal] = ACTIONS(6152),
    [sym_time_literal] = ACTIONS(6152),
    [sym_biginteger_literal] = ACTIONS(6154),
    [anon_sym_if] = ACTIONS(6152),
    [anon_sym_IF] = ACTIONS(6152),
    [anon_sym_If] = ACTIONS(6152),
    [anon_sym_else] = ACTIONS(6152),
    [anon_sym_ELSE] = ACTIONS(6152),
    [anon_sym_Else] = ACTIONS(6152),
    [anon_sym_case] = ACTIONS(6152),
    [anon_sym_CASE] = ACTIONS(6152),
    [anon_sym_Case] = ACTIONS(6152),
    [anon_sym_for] = ACTIONS(6152),
    [anon_sym_FOR] = ACTIONS(6152),
    [anon_sym_For] = ACTIONS(6152),
    [anon_sym_foreach] = ACTIONS(6152),
    [anon_sym_FOREACH] = ACTIONS(6152),
    [anon_sym_Foreach] = ACTIONS(6152),
    [anon_sym_while] = ACTIONS(6152),
    [anon_sym_WHILE] = ACTIONS(6152),
    [anon_sym_While] = ACTIONS(6152),
    [anon_sym_repeat] = ACTIONS(6152),
    [anon_sym_REPEAT] = ACTIONS(6152),
    [anon_sym_Repeat] = ACTIONS(6152),
    [anon_sym_exit] = ACTIONS(6152),
    [anon_sym_EXIT] = ACTIONS(6152),
    [anon_sym_Exit] = ACTIONS(6152),
    [anon_sym_continue] = ACTIONS(6152),
    [anon_sym_CONTINUE] = ACTIONS(6152),
    [anon_sym_Continue] = ACTIONS(6152),
    [anon_sym_break] = ACTIONS(6152),
    [anon_sym_BREAK] = ACTIONS(6152),
    [anon_sym_Break] = ACTIONS(6152),
    [anon_sym_with] = ACTIONS(6152),
    [anon_sym_WITH] = ACTIONS(6152),
    [anon_sym_With] = ACTIONS(6152),
    [sym_asserterror_keyword] = ACTIONS(6154),
    [sym_page_keyword] = ACTIONS(6152),
    [anon_sym_codeunit] = ACTIONS(6152),
    [anon_sym_CODEUNIT] = ACTIONS(6152),
    [anon_sym_Codeunit] = ACTIONS(6152),
    [anon_sym_CodeUnit] = ACTIONS(6152),
    [anon_sym_COdeunit] = ACTIONS(6152),
    [anon_sym_codeUnit] = ACTIONS(6152),
    [sym_report_keyword] = ACTIONS(6152),
    [sym_query_keyword] = ACTIONS(6152),
    [anon_sym_xmlport] = ACTIONS(6152),
    [anon_sym_XMLPORT] = ACTIONS(6152),
    [anon_sym_Xmlport] = ACTIONS(6152),
    [anon_sym_XMLport] = ACTIONS(6152),
    [anon_sym_XMLPort] = ACTIONS(6152),
    [anon_sym_XmlPort] = ACTIONS(6152),
    [anon_sym_enum] = ACTIONS(6152),
    [anon_sym_ENUM] = ACTIONS(6152),
    [anon_sym_Enum] = ACTIONS(6152),
    [anon_sym_eNUM] = ACTIONS(6152),
    [anon_sym_eNum] = ACTIONS(6152),
    [anon_sym_ENum] = ACTIONS(6152),
    [sym_quoted_identifier] = ACTIONS(6154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6154),
    [sym_verbatim_string] = ACTIONS(6154),
    [sym_integer] = ACTIONS(6152),
    [sym_continue_as_identifier] = ACTIONS(6154),
    [sym_preproc_open] = ACTIONS(6154),
    [sym_end_keyword] = ACTIONS(6154),
  },
  [STATE(3195)] = {
    [sym_identifier] = ACTIONS(6156),
    [anon_sym_SEMI] = ACTIONS(6158),
    [anon_sym_DASH] = ACTIONS(6158),
    [aux_sym_boolean_token1] = ACTIONS(6156),
    [aux_sym_boolean_token2] = ACTIONS(6156),
    [sym_decimal] = ACTIONS(6156),
    [anon_sym_LPAREN] = ACTIONS(6158),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6156),
    [anon_sym_LBRACK] = ACTIONS(6158),
    [aux_sym_record_type_token1] = ACTIONS(6156),
    [aux_sym_basic_type_token21] = ACTIONS(6156),
    [aux_sym_basic_type_token22] = ACTIONS(6156),
    [aux_sym_basic_type_token48] = ACTIONS(6156),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6156),
    [anon_sym_POUNDif] = ACTIONS(6158),
    [anon_sym_POUNDIF] = ACTIONS(6158),
    [anon_sym_POUNDIf] = ACTIONS(6158),
    [anon_sym_not] = ACTIONS(6156),
    [anon_sym_NOT] = ACTIONS(6156),
    [anon_sym_Not] = ACTIONS(6156),
    [anon_sym_POUNDelse] = ACTIONS(6158),
    [anon_sym_POUNDELSE] = ACTIONS(6158),
    [anon_sym_POUNDElse] = ACTIONS(6158),
    [anon_sym_POUNDelse2] = ACTIONS(6158),
    [anon_sym_POUNDELSE2] = ACTIONS(6158),
    [anon_sym_POUNDElse2] = ACTIONS(6158),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6156),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6156),
    [anon_sym_PLUS] = ACTIONS(6158),
    [sym_datetime_literal] = ACTIONS(6158),
    [sym_date_literal] = ACTIONS(6156),
    [sym_time_literal] = ACTIONS(6156),
    [sym_biginteger_literal] = ACTIONS(6158),
    [anon_sym_if] = ACTIONS(6156),
    [anon_sym_IF] = ACTIONS(6156),
    [anon_sym_If] = ACTIONS(6156),
    [anon_sym_else] = ACTIONS(6156),
    [anon_sym_ELSE] = ACTIONS(6156),
    [anon_sym_Else] = ACTIONS(6156),
    [anon_sym_case] = ACTIONS(6156),
    [anon_sym_CASE] = ACTIONS(6156),
    [anon_sym_Case] = ACTIONS(6156),
    [anon_sym_for] = ACTIONS(6156),
    [anon_sym_FOR] = ACTIONS(6156),
    [anon_sym_For] = ACTIONS(6156),
    [anon_sym_foreach] = ACTIONS(6156),
    [anon_sym_FOREACH] = ACTIONS(6156),
    [anon_sym_Foreach] = ACTIONS(6156),
    [anon_sym_while] = ACTIONS(6156),
    [anon_sym_WHILE] = ACTIONS(6156),
    [anon_sym_While] = ACTIONS(6156),
    [anon_sym_repeat] = ACTIONS(6156),
    [anon_sym_REPEAT] = ACTIONS(6156),
    [anon_sym_Repeat] = ACTIONS(6156),
    [anon_sym_exit] = ACTIONS(6156),
    [anon_sym_EXIT] = ACTIONS(6156),
    [anon_sym_Exit] = ACTIONS(6156),
    [anon_sym_continue] = ACTIONS(6156),
    [anon_sym_CONTINUE] = ACTIONS(6156),
    [anon_sym_Continue] = ACTIONS(6156),
    [anon_sym_break] = ACTIONS(6156),
    [anon_sym_BREAK] = ACTIONS(6156),
    [anon_sym_Break] = ACTIONS(6156),
    [anon_sym_with] = ACTIONS(6156),
    [anon_sym_WITH] = ACTIONS(6156),
    [anon_sym_With] = ACTIONS(6156),
    [sym_asserterror_keyword] = ACTIONS(6158),
    [sym_page_keyword] = ACTIONS(6156),
    [anon_sym_codeunit] = ACTIONS(6156),
    [anon_sym_CODEUNIT] = ACTIONS(6156),
    [anon_sym_Codeunit] = ACTIONS(6156),
    [anon_sym_CodeUnit] = ACTIONS(6156),
    [anon_sym_COdeunit] = ACTIONS(6156),
    [anon_sym_codeUnit] = ACTIONS(6156),
    [sym_report_keyword] = ACTIONS(6156),
    [sym_query_keyword] = ACTIONS(6156),
    [anon_sym_xmlport] = ACTIONS(6156),
    [anon_sym_XMLPORT] = ACTIONS(6156),
    [anon_sym_Xmlport] = ACTIONS(6156),
    [anon_sym_XMLport] = ACTIONS(6156),
    [anon_sym_XMLPort] = ACTIONS(6156),
    [anon_sym_XmlPort] = ACTIONS(6156),
    [anon_sym_enum] = ACTIONS(6156),
    [anon_sym_ENUM] = ACTIONS(6156),
    [anon_sym_Enum] = ACTIONS(6156),
    [anon_sym_eNUM] = ACTIONS(6156),
    [anon_sym_eNum] = ACTIONS(6156),
    [anon_sym_ENum] = ACTIONS(6156),
    [sym_quoted_identifier] = ACTIONS(6158),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6158),
    [sym_verbatim_string] = ACTIONS(6158),
    [sym_integer] = ACTIONS(6156),
    [sym_continue_as_identifier] = ACTIONS(6158),
    [sym_preproc_open] = ACTIONS(6158),
    [sym_end_keyword] = ACTIONS(6158),
  },
  [STATE(3196)] = {
    [sym_identifier] = ACTIONS(6160),
    [anon_sym_SEMI] = ACTIONS(6162),
    [anon_sym_DASH] = ACTIONS(6162),
    [aux_sym_boolean_token1] = ACTIONS(6160),
    [aux_sym_boolean_token2] = ACTIONS(6160),
    [sym_decimal] = ACTIONS(6160),
    [anon_sym_LPAREN] = ACTIONS(6162),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6160),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [aux_sym_record_type_token1] = ACTIONS(6160),
    [aux_sym_basic_type_token21] = ACTIONS(6160),
    [aux_sym_basic_type_token22] = ACTIONS(6160),
    [aux_sym_basic_type_token48] = ACTIONS(6160),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6160),
    [anon_sym_POUNDif] = ACTIONS(6162),
    [anon_sym_POUNDIF] = ACTIONS(6162),
    [anon_sym_POUNDIf] = ACTIONS(6162),
    [anon_sym_not] = ACTIONS(6160),
    [anon_sym_NOT] = ACTIONS(6160),
    [anon_sym_Not] = ACTIONS(6160),
    [anon_sym_POUNDelse] = ACTIONS(6162),
    [anon_sym_POUNDELSE] = ACTIONS(6162),
    [anon_sym_POUNDElse] = ACTIONS(6162),
    [anon_sym_POUNDelse2] = ACTIONS(6162),
    [anon_sym_POUNDELSE2] = ACTIONS(6162),
    [anon_sym_POUNDElse2] = ACTIONS(6162),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6160),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6162),
    [sym_datetime_literal] = ACTIONS(6162),
    [sym_date_literal] = ACTIONS(6160),
    [sym_time_literal] = ACTIONS(6160),
    [sym_biginteger_literal] = ACTIONS(6162),
    [anon_sym_if] = ACTIONS(6160),
    [anon_sym_IF] = ACTIONS(6160),
    [anon_sym_If] = ACTIONS(6160),
    [anon_sym_else] = ACTIONS(6160),
    [anon_sym_ELSE] = ACTIONS(6160),
    [anon_sym_Else] = ACTIONS(6160),
    [anon_sym_case] = ACTIONS(6160),
    [anon_sym_CASE] = ACTIONS(6160),
    [anon_sym_Case] = ACTIONS(6160),
    [anon_sym_for] = ACTIONS(6160),
    [anon_sym_FOR] = ACTIONS(6160),
    [anon_sym_For] = ACTIONS(6160),
    [anon_sym_foreach] = ACTIONS(6160),
    [anon_sym_FOREACH] = ACTIONS(6160),
    [anon_sym_Foreach] = ACTIONS(6160),
    [anon_sym_while] = ACTIONS(6160),
    [anon_sym_WHILE] = ACTIONS(6160),
    [anon_sym_While] = ACTIONS(6160),
    [anon_sym_repeat] = ACTIONS(6160),
    [anon_sym_REPEAT] = ACTIONS(6160),
    [anon_sym_Repeat] = ACTIONS(6160),
    [anon_sym_exit] = ACTIONS(6160),
    [anon_sym_EXIT] = ACTIONS(6160),
    [anon_sym_Exit] = ACTIONS(6160),
    [anon_sym_continue] = ACTIONS(6160),
    [anon_sym_CONTINUE] = ACTIONS(6160),
    [anon_sym_Continue] = ACTIONS(6160),
    [anon_sym_break] = ACTIONS(6160),
    [anon_sym_BREAK] = ACTIONS(6160),
    [anon_sym_Break] = ACTIONS(6160),
    [anon_sym_with] = ACTIONS(6160),
    [anon_sym_WITH] = ACTIONS(6160),
    [anon_sym_With] = ACTIONS(6160),
    [sym_asserterror_keyword] = ACTIONS(6162),
    [sym_page_keyword] = ACTIONS(6160),
    [anon_sym_codeunit] = ACTIONS(6160),
    [anon_sym_CODEUNIT] = ACTIONS(6160),
    [anon_sym_Codeunit] = ACTIONS(6160),
    [anon_sym_CodeUnit] = ACTIONS(6160),
    [anon_sym_COdeunit] = ACTIONS(6160),
    [anon_sym_codeUnit] = ACTIONS(6160),
    [sym_report_keyword] = ACTIONS(6160),
    [sym_query_keyword] = ACTIONS(6160),
    [anon_sym_xmlport] = ACTIONS(6160),
    [anon_sym_XMLPORT] = ACTIONS(6160),
    [anon_sym_Xmlport] = ACTIONS(6160),
    [anon_sym_XMLport] = ACTIONS(6160),
    [anon_sym_XMLPort] = ACTIONS(6160),
    [anon_sym_XmlPort] = ACTIONS(6160),
    [anon_sym_enum] = ACTIONS(6160),
    [anon_sym_ENUM] = ACTIONS(6160),
    [anon_sym_Enum] = ACTIONS(6160),
    [anon_sym_eNUM] = ACTIONS(6160),
    [anon_sym_eNum] = ACTIONS(6160),
    [anon_sym_ENum] = ACTIONS(6160),
    [sym_quoted_identifier] = ACTIONS(6162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6162),
    [sym_verbatim_string] = ACTIONS(6162),
    [sym_integer] = ACTIONS(6160),
    [sym_continue_as_identifier] = ACTIONS(6162),
    [sym_preproc_open] = ACTIONS(6162),
    [sym_end_keyword] = ACTIONS(6162),
  },
  [STATE(3197)] = {
    [sym_identifier] = ACTIONS(6164),
    [anon_sym_SEMI] = ACTIONS(6166),
    [anon_sym_DASH] = ACTIONS(6166),
    [aux_sym_boolean_token1] = ACTIONS(6164),
    [aux_sym_boolean_token2] = ACTIONS(6164),
    [sym_decimal] = ACTIONS(6164),
    [anon_sym_LPAREN] = ACTIONS(6166),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6164),
    [anon_sym_LBRACK] = ACTIONS(6166),
    [aux_sym_record_type_token1] = ACTIONS(6164),
    [aux_sym_basic_type_token21] = ACTIONS(6164),
    [aux_sym_basic_type_token22] = ACTIONS(6164),
    [aux_sym_basic_type_token48] = ACTIONS(6164),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6164),
    [anon_sym_POUNDif] = ACTIONS(6166),
    [anon_sym_POUNDIF] = ACTIONS(6166),
    [anon_sym_POUNDIf] = ACTIONS(6166),
    [anon_sym_not] = ACTIONS(6164),
    [anon_sym_NOT] = ACTIONS(6164),
    [anon_sym_Not] = ACTIONS(6164),
    [anon_sym_POUNDelse] = ACTIONS(6166),
    [anon_sym_POUNDELSE] = ACTIONS(6166),
    [anon_sym_POUNDElse] = ACTIONS(6166),
    [anon_sym_POUNDelse2] = ACTIONS(6166),
    [anon_sym_POUNDELSE2] = ACTIONS(6166),
    [anon_sym_POUNDElse2] = ACTIONS(6166),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6164),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6164),
    [anon_sym_PLUS] = ACTIONS(6166),
    [sym_datetime_literal] = ACTIONS(6166),
    [sym_date_literal] = ACTIONS(6164),
    [sym_time_literal] = ACTIONS(6164),
    [sym_biginteger_literal] = ACTIONS(6166),
    [anon_sym_if] = ACTIONS(6164),
    [anon_sym_IF] = ACTIONS(6164),
    [anon_sym_If] = ACTIONS(6164),
    [anon_sym_else] = ACTIONS(6164),
    [anon_sym_ELSE] = ACTIONS(6164),
    [anon_sym_Else] = ACTIONS(6164),
    [anon_sym_case] = ACTIONS(6164),
    [anon_sym_CASE] = ACTIONS(6164),
    [anon_sym_Case] = ACTIONS(6164),
    [anon_sym_for] = ACTIONS(6164),
    [anon_sym_FOR] = ACTIONS(6164),
    [anon_sym_For] = ACTIONS(6164),
    [anon_sym_foreach] = ACTIONS(6164),
    [anon_sym_FOREACH] = ACTIONS(6164),
    [anon_sym_Foreach] = ACTIONS(6164),
    [anon_sym_while] = ACTIONS(6164),
    [anon_sym_WHILE] = ACTIONS(6164),
    [anon_sym_While] = ACTIONS(6164),
    [anon_sym_repeat] = ACTIONS(6164),
    [anon_sym_REPEAT] = ACTIONS(6164),
    [anon_sym_Repeat] = ACTIONS(6164),
    [anon_sym_exit] = ACTIONS(6164),
    [anon_sym_EXIT] = ACTIONS(6164),
    [anon_sym_Exit] = ACTIONS(6164),
    [anon_sym_continue] = ACTIONS(6164),
    [anon_sym_CONTINUE] = ACTIONS(6164),
    [anon_sym_Continue] = ACTIONS(6164),
    [anon_sym_break] = ACTIONS(6164),
    [anon_sym_BREAK] = ACTIONS(6164),
    [anon_sym_Break] = ACTIONS(6164),
    [anon_sym_with] = ACTIONS(6164),
    [anon_sym_WITH] = ACTIONS(6164),
    [anon_sym_With] = ACTIONS(6164),
    [sym_asserterror_keyword] = ACTIONS(6166),
    [sym_page_keyword] = ACTIONS(6164),
    [anon_sym_codeunit] = ACTIONS(6164),
    [anon_sym_CODEUNIT] = ACTIONS(6164),
    [anon_sym_Codeunit] = ACTIONS(6164),
    [anon_sym_CodeUnit] = ACTIONS(6164),
    [anon_sym_COdeunit] = ACTIONS(6164),
    [anon_sym_codeUnit] = ACTIONS(6164),
    [sym_report_keyword] = ACTIONS(6164),
    [sym_query_keyword] = ACTIONS(6164),
    [anon_sym_xmlport] = ACTIONS(6164),
    [anon_sym_XMLPORT] = ACTIONS(6164),
    [anon_sym_Xmlport] = ACTIONS(6164),
    [anon_sym_XMLport] = ACTIONS(6164),
    [anon_sym_XMLPort] = ACTIONS(6164),
    [anon_sym_XmlPort] = ACTIONS(6164),
    [anon_sym_enum] = ACTIONS(6164),
    [anon_sym_ENUM] = ACTIONS(6164),
    [anon_sym_Enum] = ACTIONS(6164),
    [anon_sym_eNUM] = ACTIONS(6164),
    [anon_sym_eNum] = ACTIONS(6164),
    [anon_sym_ENum] = ACTIONS(6164),
    [sym_quoted_identifier] = ACTIONS(6166),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6166),
    [sym_verbatim_string] = ACTIONS(6166),
    [sym_integer] = ACTIONS(6164),
    [sym_continue_as_identifier] = ACTIONS(6166),
    [sym_preproc_open] = ACTIONS(6166),
    [sym_end_keyword] = ACTIONS(6166),
  },
  [STATE(3198)] = {
    [sym_identifier] = ACTIONS(6168),
    [anon_sym_SEMI] = ACTIONS(6170),
    [anon_sym_DASH] = ACTIONS(6170),
    [aux_sym_boolean_token1] = ACTIONS(6168),
    [aux_sym_boolean_token2] = ACTIONS(6168),
    [sym_decimal] = ACTIONS(6168),
    [anon_sym_LPAREN] = ACTIONS(6170),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6168),
    [anon_sym_LBRACK] = ACTIONS(6170),
    [aux_sym_record_type_token1] = ACTIONS(6168),
    [aux_sym_basic_type_token21] = ACTIONS(6168),
    [aux_sym_basic_type_token22] = ACTIONS(6168),
    [aux_sym_basic_type_token48] = ACTIONS(6168),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6168),
    [anon_sym_POUNDif] = ACTIONS(6170),
    [anon_sym_POUNDIF] = ACTIONS(6170),
    [anon_sym_POUNDIf] = ACTIONS(6170),
    [anon_sym_not] = ACTIONS(6168),
    [anon_sym_NOT] = ACTIONS(6168),
    [anon_sym_Not] = ACTIONS(6168),
    [anon_sym_POUNDelse] = ACTIONS(6170),
    [anon_sym_POUNDELSE] = ACTIONS(6170),
    [anon_sym_POUNDElse] = ACTIONS(6170),
    [anon_sym_POUNDelse2] = ACTIONS(6170),
    [anon_sym_POUNDELSE2] = ACTIONS(6170),
    [anon_sym_POUNDElse2] = ACTIONS(6170),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6168),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6168),
    [anon_sym_PLUS] = ACTIONS(6170),
    [sym_datetime_literal] = ACTIONS(6170),
    [sym_date_literal] = ACTIONS(6168),
    [sym_time_literal] = ACTIONS(6168),
    [sym_biginteger_literal] = ACTIONS(6170),
    [anon_sym_if] = ACTIONS(6168),
    [anon_sym_IF] = ACTIONS(6168),
    [anon_sym_If] = ACTIONS(6168),
    [anon_sym_else] = ACTIONS(6168),
    [anon_sym_ELSE] = ACTIONS(6168),
    [anon_sym_Else] = ACTIONS(6168),
    [anon_sym_case] = ACTIONS(6168),
    [anon_sym_CASE] = ACTIONS(6168),
    [anon_sym_Case] = ACTIONS(6168),
    [anon_sym_for] = ACTIONS(6168),
    [anon_sym_FOR] = ACTIONS(6168),
    [anon_sym_For] = ACTIONS(6168),
    [anon_sym_foreach] = ACTIONS(6168),
    [anon_sym_FOREACH] = ACTIONS(6168),
    [anon_sym_Foreach] = ACTIONS(6168),
    [anon_sym_while] = ACTIONS(6168),
    [anon_sym_WHILE] = ACTIONS(6168),
    [anon_sym_While] = ACTIONS(6168),
    [anon_sym_repeat] = ACTIONS(6168),
    [anon_sym_REPEAT] = ACTIONS(6168),
    [anon_sym_Repeat] = ACTIONS(6168),
    [anon_sym_exit] = ACTIONS(6168),
    [anon_sym_EXIT] = ACTIONS(6168),
    [anon_sym_Exit] = ACTIONS(6168),
    [anon_sym_continue] = ACTIONS(6168),
    [anon_sym_CONTINUE] = ACTIONS(6168),
    [anon_sym_Continue] = ACTIONS(6168),
    [anon_sym_break] = ACTIONS(6168),
    [anon_sym_BREAK] = ACTIONS(6168),
    [anon_sym_Break] = ACTIONS(6168),
    [anon_sym_with] = ACTIONS(6168),
    [anon_sym_WITH] = ACTIONS(6168),
    [anon_sym_With] = ACTIONS(6168),
    [sym_asserterror_keyword] = ACTIONS(6170),
    [sym_page_keyword] = ACTIONS(6168),
    [anon_sym_codeunit] = ACTIONS(6168),
    [anon_sym_CODEUNIT] = ACTIONS(6168),
    [anon_sym_Codeunit] = ACTIONS(6168),
    [anon_sym_CodeUnit] = ACTIONS(6168),
    [anon_sym_COdeunit] = ACTIONS(6168),
    [anon_sym_codeUnit] = ACTIONS(6168),
    [sym_report_keyword] = ACTIONS(6168),
    [sym_query_keyword] = ACTIONS(6168),
    [anon_sym_xmlport] = ACTIONS(6168),
    [anon_sym_XMLPORT] = ACTIONS(6168),
    [anon_sym_Xmlport] = ACTIONS(6168),
    [anon_sym_XMLport] = ACTIONS(6168),
    [anon_sym_XMLPort] = ACTIONS(6168),
    [anon_sym_XmlPort] = ACTIONS(6168),
    [anon_sym_enum] = ACTIONS(6168),
    [anon_sym_ENUM] = ACTIONS(6168),
    [anon_sym_Enum] = ACTIONS(6168),
    [anon_sym_eNUM] = ACTIONS(6168),
    [anon_sym_eNum] = ACTIONS(6168),
    [anon_sym_ENum] = ACTIONS(6168),
    [sym_quoted_identifier] = ACTIONS(6170),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6170),
    [sym_verbatim_string] = ACTIONS(6170),
    [sym_integer] = ACTIONS(6168),
    [sym_continue_as_identifier] = ACTIONS(6170),
    [sym_preproc_open] = ACTIONS(6170),
    [sym_end_keyword] = ACTIONS(6170),
  },
  [STATE(3199)] = {
    [sym_identifier] = ACTIONS(6172),
    [anon_sym_SEMI] = ACTIONS(6174),
    [anon_sym_DASH] = ACTIONS(6174),
    [aux_sym_boolean_token1] = ACTIONS(6172),
    [aux_sym_boolean_token2] = ACTIONS(6172),
    [sym_decimal] = ACTIONS(6172),
    [anon_sym_LPAREN] = ACTIONS(6174),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6172),
    [anon_sym_LBRACK] = ACTIONS(6174),
    [aux_sym_record_type_token1] = ACTIONS(6172),
    [aux_sym_basic_type_token21] = ACTIONS(6172),
    [aux_sym_basic_type_token22] = ACTIONS(6172),
    [aux_sym_basic_type_token48] = ACTIONS(6172),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6172),
    [anon_sym_POUNDif] = ACTIONS(6174),
    [anon_sym_POUNDIF] = ACTIONS(6174),
    [anon_sym_POUNDIf] = ACTIONS(6174),
    [anon_sym_not] = ACTIONS(6172),
    [anon_sym_NOT] = ACTIONS(6172),
    [anon_sym_Not] = ACTIONS(6172),
    [anon_sym_POUNDelse] = ACTIONS(6174),
    [anon_sym_POUNDELSE] = ACTIONS(6174),
    [anon_sym_POUNDElse] = ACTIONS(6174),
    [anon_sym_POUNDelse2] = ACTIONS(6174),
    [anon_sym_POUNDELSE2] = ACTIONS(6174),
    [anon_sym_POUNDElse2] = ACTIONS(6174),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6172),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6172),
    [anon_sym_PLUS] = ACTIONS(6174),
    [sym_datetime_literal] = ACTIONS(6174),
    [sym_date_literal] = ACTIONS(6172),
    [sym_time_literal] = ACTIONS(6172),
    [sym_biginteger_literal] = ACTIONS(6174),
    [anon_sym_if] = ACTIONS(6172),
    [anon_sym_IF] = ACTIONS(6172),
    [anon_sym_If] = ACTIONS(6172),
    [anon_sym_else] = ACTIONS(6172),
    [anon_sym_ELSE] = ACTIONS(6172),
    [anon_sym_Else] = ACTIONS(6172),
    [anon_sym_case] = ACTIONS(6172),
    [anon_sym_CASE] = ACTIONS(6172),
    [anon_sym_Case] = ACTIONS(6172),
    [anon_sym_for] = ACTIONS(6172),
    [anon_sym_FOR] = ACTIONS(6172),
    [anon_sym_For] = ACTIONS(6172),
    [anon_sym_foreach] = ACTIONS(6172),
    [anon_sym_FOREACH] = ACTIONS(6172),
    [anon_sym_Foreach] = ACTIONS(6172),
    [anon_sym_while] = ACTIONS(6172),
    [anon_sym_WHILE] = ACTIONS(6172),
    [anon_sym_While] = ACTIONS(6172),
    [anon_sym_repeat] = ACTIONS(6172),
    [anon_sym_REPEAT] = ACTIONS(6172),
    [anon_sym_Repeat] = ACTIONS(6172),
    [anon_sym_exit] = ACTIONS(6172),
    [anon_sym_EXIT] = ACTIONS(6172),
    [anon_sym_Exit] = ACTIONS(6172),
    [anon_sym_continue] = ACTIONS(6172),
    [anon_sym_CONTINUE] = ACTIONS(6172),
    [anon_sym_Continue] = ACTIONS(6172),
    [anon_sym_break] = ACTIONS(6172),
    [anon_sym_BREAK] = ACTIONS(6172),
    [anon_sym_Break] = ACTIONS(6172),
    [anon_sym_with] = ACTIONS(6172),
    [anon_sym_WITH] = ACTIONS(6172),
    [anon_sym_With] = ACTIONS(6172),
    [sym_asserterror_keyword] = ACTIONS(6174),
    [sym_page_keyword] = ACTIONS(6172),
    [anon_sym_codeunit] = ACTIONS(6172),
    [anon_sym_CODEUNIT] = ACTIONS(6172),
    [anon_sym_Codeunit] = ACTIONS(6172),
    [anon_sym_CodeUnit] = ACTIONS(6172),
    [anon_sym_COdeunit] = ACTIONS(6172),
    [anon_sym_codeUnit] = ACTIONS(6172),
    [sym_report_keyword] = ACTIONS(6172),
    [sym_query_keyword] = ACTIONS(6172),
    [anon_sym_xmlport] = ACTIONS(6172),
    [anon_sym_XMLPORT] = ACTIONS(6172),
    [anon_sym_Xmlport] = ACTIONS(6172),
    [anon_sym_XMLport] = ACTIONS(6172),
    [anon_sym_XMLPort] = ACTIONS(6172),
    [anon_sym_XmlPort] = ACTIONS(6172),
    [anon_sym_enum] = ACTIONS(6172),
    [anon_sym_ENUM] = ACTIONS(6172),
    [anon_sym_Enum] = ACTIONS(6172),
    [anon_sym_eNUM] = ACTIONS(6172),
    [anon_sym_eNum] = ACTIONS(6172),
    [anon_sym_ENum] = ACTIONS(6172),
    [sym_quoted_identifier] = ACTIONS(6174),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6174),
    [sym_verbatim_string] = ACTIONS(6174),
    [sym_integer] = ACTIONS(6172),
    [sym_continue_as_identifier] = ACTIONS(6174),
    [sym_preproc_open] = ACTIONS(6174),
    [sym_end_keyword] = ACTIONS(6174),
  },
  [STATE(3200)] = {
    [sym_identifier] = ACTIONS(6176),
    [anon_sym_SEMI] = ACTIONS(6178),
    [anon_sym_DASH] = ACTIONS(6178),
    [aux_sym_boolean_token1] = ACTIONS(6176),
    [aux_sym_boolean_token2] = ACTIONS(6176),
    [sym_decimal] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6178),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6176),
    [anon_sym_LBRACK] = ACTIONS(6178),
    [aux_sym_record_type_token1] = ACTIONS(6176),
    [aux_sym_basic_type_token21] = ACTIONS(6176),
    [aux_sym_basic_type_token22] = ACTIONS(6176),
    [aux_sym_basic_type_token48] = ACTIONS(6176),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6176),
    [anon_sym_POUNDif] = ACTIONS(6178),
    [anon_sym_POUNDIF] = ACTIONS(6178),
    [anon_sym_POUNDIf] = ACTIONS(6178),
    [anon_sym_not] = ACTIONS(6176),
    [anon_sym_NOT] = ACTIONS(6176),
    [anon_sym_Not] = ACTIONS(6176),
    [anon_sym_POUNDelse] = ACTIONS(6178),
    [anon_sym_POUNDELSE] = ACTIONS(6178),
    [anon_sym_POUNDElse] = ACTIONS(6178),
    [anon_sym_POUNDelse2] = ACTIONS(6178),
    [anon_sym_POUNDELSE2] = ACTIONS(6178),
    [anon_sym_POUNDElse2] = ACTIONS(6178),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6176),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6176),
    [anon_sym_PLUS] = ACTIONS(6178),
    [sym_datetime_literal] = ACTIONS(6178),
    [sym_date_literal] = ACTIONS(6176),
    [sym_time_literal] = ACTIONS(6176),
    [sym_biginteger_literal] = ACTIONS(6178),
    [anon_sym_if] = ACTIONS(6176),
    [anon_sym_IF] = ACTIONS(6176),
    [anon_sym_If] = ACTIONS(6176),
    [anon_sym_else] = ACTIONS(6176),
    [anon_sym_ELSE] = ACTIONS(6176),
    [anon_sym_Else] = ACTIONS(6176),
    [anon_sym_case] = ACTIONS(6176),
    [anon_sym_CASE] = ACTIONS(6176),
    [anon_sym_Case] = ACTIONS(6176),
    [anon_sym_for] = ACTIONS(6176),
    [anon_sym_FOR] = ACTIONS(6176),
    [anon_sym_For] = ACTIONS(6176),
    [anon_sym_foreach] = ACTIONS(6176),
    [anon_sym_FOREACH] = ACTIONS(6176),
    [anon_sym_Foreach] = ACTIONS(6176),
    [anon_sym_while] = ACTIONS(6176),
    [anon_sym_WHILE] = ACTIONS(6176),
    [anon_sym_While] = ACTIONS(6176),
    [anon_sym_repeat] = ACTIONS(6176),
    [anon_sym_REPEAT] = ACTIONS(6176),
    [anon_sym_Repeat] = ACTIONS(6176),
    [anon_sym_exit] = ACTIONS(6176),
    [anon_sym_EXIT] = ACTIONS(6176),
    [anon_sym_Exit] = ACTIONS(6176),
    [anon_sym_continue] = ACTIONS(6176),
    [anon_sym_CONTINUE] = ACTIONS(6176),
    [anon_sym_Continue] = ACTIONS(6176),
    [anon_sym_break] = ACTIONS(6176),
    [anon_sym_BREAK] = ACTIONS(6176),
    [anon_sym_Break] = ACTIONS(6176),
    [anon_sym_with] = ACTIONS(6176),
    [anon_sym_WITH] = ACTIONS(6176),
    [anon_sym_With] = ACTIONS(6176),
    [sym_asserterror_keyword] = ACTIONS(6178),
    [sym_page_keyword] = ACTIONS(6176),
    [anon_sym_codeunit] = ACTIONS(6176),
    [anon_sym_CODEUNIT] = ACTIONS(6176),
    [anon_sym_Codeunit] = ACTIONS(6176),
    [anon_sym_CodeUnit] = ACTIONS(6176),
    [anon_sym_COdeunit] = ACTIONS(6176),
    [anon_sym_codeUnit] = ACTIONS(6176),
    [sym_report_keyword] = ACTIONS(6176),
    [sym_query_keyword] = ACTIONS(6176),
    [anon_sym_xmlport] = ACTIONS(6176),
    [anon_sym_XMLPORT] = ACTIONS(6176),
    [anon_sym_Xmlport] = ACTIONS(6176),
    [anon_sym_XMLport] = ACTIONS(6176),
    [anon_sym_XMLPort] = ACTIONS(6176),
    [anon_sym_XmlPort] = ACTIONS(6176),
    [anon_sym_enum] = ACTIONS(6176),
    [anon_sym_ENUM] = ACTIONS(6176),
    [anon_sym_Enum] = ACTIONS(6176),
    [anon_sym_eNUM] = ACTIONS(6176),
    [anon_sym_eNum] = ACTIONS(6176),
    [anon_sym_ENum] = ACTIONS(6176),
    [sym_quoted_identifier] = ACTIONS(6178),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6178),
    [sym_verbatim_string] = ACTIONS(6178),
    [sym_integer] = ACTIONS(6176),
    [sym_continue_as_identifier] = ACTIONS(6178),
    [sym_preproc_open] = ACTIONS(6178),
    [sym_end_keyword] = ACTIONS(6178),
  },
  [STATE(3201)] = {
    [sym_identifier] = ACTIONS(6180),
    [anon_sym_SEMI] = ACTIONS(6182),
    [anon_sym_DASH] = ACTIONS(6182),
    [aux_sym_boolean_token1] = ACTIONS(6180),
    [aux_sym_boolean_token2] = ACTIONS(6180),
    [sym_decimal] = ACTIONS(6180),
    [anon_sym_LPAREN] = ACTIONS(6182),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6180),
    [anon_sym_LBRACK] = ACTIONS(6182),
    [aux_sym_record_type_token1] = ACTIONS(6180),
    [aux_sym_basic_type_token21] = ACTIONS(6180),
    [aux_sym_basic_type_token22] = ACTIONS(6180),
    [aux_sym_basic_type_token48] = ACTIONS(6180),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6180),
    [anon_sym_POUNDif] = ACTIONS(6182),
    [anon_sym_POUNDIF] = ACTIONS(6182),
    [anon_sym_POUNDIf] = ACTIONS(6182),
    [anon_sym_not] = ACTIONS(6180),
    [anon_sym_NOT] = ACTIONS(6180),
    [anon_sym_Not] = ACTIONS(6180),
    [anon_sym_POUNDelse] = ACTIONS(6182),
    [anon_sym_POUNDELSE] = ACTIONS(6182),
    [anon_sym_POUNDElse] = ACTIONS(6182),
    [anon_sym_POUNDelse2] = ACTIONS(6182),
    [anon_sym_POUNDELSE2] = ACTIONS(6182),
    [anon_sym_POUNDElse2] = ACTIONS(6182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6180),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6180),
    [anon_sym_PLUS] = ACTIONS(6182),
    [sym_datetime_literal] = ACTIONS(6182),
    [sym_date_literal] = ACTIONS(6180),
    [sym_time_literal] = ACTIONS(6180),
    [sym_biginteger_literal] = ACTIONS(6182),
    [anon_sym_if] = ACTIONS(6180),
    [anon_sym_IF] = ACTIONS(6180),
    [anon_sym_If] = ACTIONS(6180),
    [anon_sym_else] = ACTIONS(6180),
    [anon_sym_ELSE] = ACTIONS(6180),
    [anon_sym_Else] = ACTIONS(6180),
    [anon_sym_case] = ACTIONS(6180),
    [anon_sym_CASE] = ACTIONS(6180),
    [anon_sym_Case] = ACTIONS(6180),
    [anon_sym_for] = ACTIONS(6180),
    [anon_sym_FOR] = ACTIONS(6180),
    [anon_sym_For] = ACTIONS(6180),
    [anon_sym_foreach] = ACTIONS(6180),
    [anon_sym_FOREACH] = ACTIONS(6180),
    [anon_sym_Foreach] = ACTIONS(6180),
    [anon_sym_while] = ACTIONS(6180),
    [anon_sym_WHILE] = ACTIONS(6180),
    [anon_sym_While] = ACTIONS(6180),
    [anon_sym_repeat] = ACTIONS(6180),
    [anon_sym_REPEAT] = ACTIONS(6180),
    [anon_sym_Repeat] = ACTIONS(6180),
    [anon_sym_exit] = ACTIONS(6180),
    [anon_sym_EXIT] = ACTIONS(6180),
    [anon_sym_Exit] = ACTIONS(6180),
    [anon_sym_continue] = ACTIONS(6180),
    [anon_sym_CONTINUE] = ACTIONS(6180),
    [anon_sym_Continue] = ACTIONS(6180),
    [anon_sym_break] = ACTIONS(6180),
    [anon_sym_BREAK] = ACTIONS(6180),
    [anon_sym_Break] = ACTIONS(6180),
    [anon_sym_with] = ACTIONS(6180),
    [anon_sym_WITH] = ACTIONS(6180),
    [anon_sym_With] = ACTIONS(6180),
    [sym_asserterror_keyword] = ACTIONS(6182),
    [sym_page_keyword] = ACTIONS(6180),
    [anon_sym_codeunit] = ACTIONS(6180),
    [anon_sym_CODEUNIT] = ACTIONS(6180),
    [anon_sym_Codeunit] = ACTIONS(6180),
    [anon_sym_CodeUnit] = ACTIONS(6180),
    [anon_sym_COdeunit] = ACTIONS(6180),
    [anon_sym_codeUnit] = ACTIONS(6180),
    [sym_report_keyword] = ACTIONS(6180),
    [sym_query_keyword] = ACTIONS(6180),
    [anon_sym_xmlport] = ACTIONS(6180),
    [anon_sym_XMLPORT] = ACTIONS(6180),
    [anon_sym_Xmlport] = ACTIONS(6180),
    [anon_sym_XMLport] = ACTIONS(6180),
    [anon_sym_XMLPort] = ACTIONS(6180),
    [anon_sym_XmlPort] = ACTIONS(6180),
    [anon_sym_enum] = ACTIONS(6180),
    [anon_sym_ENUM] = ACTIONS(6180),
    [anon_sym_Enum] = ACTIONS(6180),
    [anon_sym_eNUM] = ACTIONS(6180),
    [anon_sym_eNum] = ACTIONS(6180),
    [anon_sym_ENum] = ACTIONS(6180),
    [sym_quoted_identifier] = ACTIONS(6182),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6182),
    [sym_verbatim_string] = ACTIONS(6182),
    [sym_integer] = ACTIONS(6180),
    [sym_continue_as_identifier] = ACTIONS(6182),
    [sym_preproc_open] = ACTIONS(6182),
    [sym_end_keyword] = ACTIONS(6182),
  },
  [STATE(3202)] = {
    [sym_identifier] = ACTIONS(6184),
    [anon_sym_SEMI] = ACTIONS(6186),
    [anon_sym_DASH] = ACTIONS(6186),
    [aux_sym_boolean_token1] = ACTIONS(6184),
    [aux_sym_boolean_token2] = ACTIONS(6184),
    [sym_decimal] = ACTIONS(6184),
    [anon_sym_LPAREN] = ACTIONS(6186),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6184),
    [anon_sym_LBRACK] = ACTIONS(6186),
    [aux_sym_record_type_token1] = ACTIONS(6184),
    [aux_sym_basic_type_token21] = ACTIONS(6184),
    [aux_sym_basic_type_token22] = ACTIONS(6184),
    [aux_sym_basic_type_token48] = ACTIONS(6184),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6184),
    [anon_sym_POUNDif] = ACTIONS(6186),
    [anon_sym_POUNDIF] = ACTIONS(6186),
    [anon_sym_POUNDIf] = ACTIONS(6186),
    [anon_sym_not] = ACTIONS(6184),
    [anon_sym_NOT] = ACTIONS(6184),
    [anon_sym_Not] = ACTIONS(6184),
    [anon_sym_POUNDelse] = ACTIONS(6186),
    [anon_sym_POUNDELSE] = ACTIONS(6186),
    [anon_sym_POUNDElse] = ACTIONS(6186),
    [anon_sym_POUNDelse2] = ACTIONS(6186),
    [anon_sym_POUNDELSE2] = ACTIONS(6186),
    [anon_sym_POUNDElse2] = ACTIONS(6186),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6184),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6184),
    [anon_sym_PLUS] = ACTIONS(6186),
    [sym_datetime_literal] = ACTIONS(6186),
    [sym_date_literal] = ACTIONS(6184),
    [sym_time_literal] = ACTIONS(6184),
    [sym_biginteger_literal] = ACTIONS(6186),
    [anon_sym_if] = ACTIONS(6184),
    [anon_sym_IF] = ACTIONS(6184),
    [anon_sym_If] = ACTIONS(6184),
    [anon_sym_else] = ACTIONS(6184),
    [anon_sym_ELSE] = ACTIONS(6184),
    [anon_sym_Else] = ACTIONS(6184),
    [anon_sym_case] = ACTIONS(6184),
    [anon_sym_CASE] = ACTIONS(6184),
    [anon_sym_Case] = ACTIONS(6184),
    [anon_sym_for] = ACTIONS(6184),
    [anon_sym_FOR] = ACTIONS(6184),
    [anon_sym_For] = ACTIONS(6184),
    [anon_sym_foreach] = ACTIONS(6184),
    [anon_sym_FOREACH] = ACTIONS(6184),
    [anon_sym_Foreach] = ACTIONS(6184),
    [anon_sym_while] = ACTIONS(6184),
    [anon_sym_WHILE] = ACTIONS(6184),
    [anon_sym_While] = ACTIONS(6184),
    [anon_sym_repeat] = ACTIONS(6184),
    [anon_sym_REPEAT] = ACTIONS(6184),
    [anon_sym_Repeat] = ACTIONS(6184),
    [anon_sym_exit] = ACTIONS(6184),
    [anon_sym_EXIT] = ACTIONS(6184),
    [anon_sym_Exit] = ACTIONS(6184),
    [anon_sym_continue] = ACTIONS(6184),
    [anon_sym_CONTINUE] = ACTIONS(6184),
    [anon_sym_Continue] = ACTIONS(6184),
    [anon_sym_break] = ACTIONS(6184),
    [anon_sym_BREAK] = ACTIONS(6184),
    [anon_sym_Break] = ACTIONS(6184),
    [anon_sym_with] = ACTIONS(6184),
    [anon_sym_WITH] = ACTIONS(6184),
    [anon_sym_With] = ACTIONS(6184),
    [sym_asserterror_keyword] = ACTIONS(6186),
    [sym_page_keyword] = ACTIONS(6184),
    [anon_sym_codeunit] = ACTIONS(6184),
    [anon_sym_CODEUNIT] = ACTIONS(6184),
    [anon_sym_Codeunit] = ACTIONS(6184),
    [anon_sym_CodeUnit] = ACTIONS(6184),
    [anon_sym_COdeunit] = ACTIONS(6184),
    [anon_sym_codeUnit] = ACTIONS(6184),
    [sym_report_keyword] = ACTIONS(6184),
    [sym_query_keyword] = ACTIONS(6184),
    [anon_sym_xmlport] = ACTIONS(6184),
    [anon_sym_XMLPORT] = ACTIONS(6184),
    [anon_sym_Xmlport] = ACTIONS(6184),
    [anon_sym_XMLport] = ACTIONS(6184),
    [anon_sym_XMLPort] = ACTIONS(6184),
    [anon_sym_XmlPort] = ACTIONS(6184),
    [anon_sym_enum] = ACTIONS(6184),
    [anon_sym_ENUM] = ACTIONS(6184),
    [anon_sym_Enum] = ACTIONS(6184),
    [anon_sym_eNUM] = ACTIONS(6184),
    [anon_sym_eNum] = ACTIONS(6184),
    [anon_sym_ENum] = ACTIONS(6184),
    [sym_quoted_identifier] = ACTIONS(6186),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6186),
    [sym_verbatim_string] = ACTIONS(6186),
    [sym_integer] = ACTIONS(6184),
    [sym_continue_as_identifier] = ACTIONS(6186),
    [sym_preproc_open] = ACTIONS(6186),
    [sym_end_keyword] = ACTIONS(6186),
  },
  [STATE(3203)] = {
    [sym_identifier] = ACTIONS(6188),
    [anon_sym_SEMI] = ACTIONS(6190),
    [anon_sym_DASH] = ACTIONS(6190),
    [aux_sym_boolean_token1] = ACTIONS(6188),
    [aux_sym_boolean_token2] = ACTIONS(6188),
    [sym_decimal] = ACTIONS(6188),
    [anon_sym_LPAREN] = ACTIONS(6190),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6188),
    [anon_sym_LBRACK] = ACTIONS(6190),
    [aux_sym_record_type_token1] = ACTIONS(6188),
    [aux_sym_basic_type_token21] = ACTIONS(6188),
    [aux_sym_basic_type_token22] = ACTIONS(6188),
    [aux_sym_basic_type_token48] = ACTIONS(6188),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6188),
    [anon_sym_POUNDif] = ACTIONS(6190),
    [anon_sym_POUNDIF] = ACTIONS(6190),
    [anon_sym_POUNDIf] = ACTIONS(6190),
    [anon_sym_not] = ACTIONS(6188),
    [anon_sym_NOT] = ACTIONS(6188),
    [anon_sym_Not] = ACTIONS(6188),
    [anon_sym_POUNDelse] = ACTIONS(6190),
    [anon_sym_POUNDELSE] = ACTIONS(6190),
    [anon_sym_POUNDElse] = ACTIONS(6190),
    [anon_sym_POUNDelse2] = ACTIONS(6190),
    [anon_sym_POUNDELSE2] = ACTIONS(6190),
    [anon_sym_POUNDElse2] = ACTIONS(6190),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6188),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6188),
    [anon_sym_PLUS] = ACTIONS(6190),
    [sym_datetime_literal] = ACTIONS(6190),
    [sym_date_literal] = ACTIONS(6188),
    [sym_time_literal] = ACTIONS(6188),
    [sym_biginteger_literal] = ACTIONS(6190),
    [anon_sym_if] = ACTIONS(6188),
    [anon_sym_IF] = ACTIONS(6188),
    [anon_sym_If] = ACTIONS(6188),
    [anon_sym_else] = ACTIONS(6188),
    [anon_sym_ELSE] = ACTIONS(6188),
    [anon_sym_Else] = ACTIONS(6188),
    [anon_sym_case] = ACTIONS(6188),
    [anon_sym_CASE] = ACTIONS(6188),
    [anon_sym_Case] = ACTIONS(6188),
    [anon_sym_for] = ACTIONS(6188),
    [anon_sym_FOR] = ACTIONS(6188),
    [anon_sym_For] = ACTIONS(6188),
    [anon_sym_foreach] = ACTIONS(6188),
    [anon_sym_FOREACH] = ACTIONS(6188),
    [anon_sym_Foreach] = ACTIONS(6188),
    [anon_sym_while] = ACTIONS(6188),
    [anon_sym_WHILE] = ACTIONS(6188),
    [anon_sym_While] = ACTIONS(6188),
    [anon_sym_repeat] = ACTIONS(6188),
    [anon_sym_REPEAT] = ACTIONS(6188),
    [anon_sym_Repeat] = ACTIONS(6188),
    [anon_sym_exit] = ACTIONS(6188),
    [anon_sym_EXIT] = ACTIONS(6188),
    [anon_sym_Exit] = ACTIONS(6188),
    [anon_sym_continue] = ACTIONS(6188),
    [anon_sym_CONTINUE] = ACTIONS(6188),
    [anon_sym_Continue] = ACTIONS(6188),
    [anon_sym_break] = ACTIONS(6188),
    [anon_sym_BREAK] = ACTIONS(6188),
    [anon_sym_Break] = ACTIONS(6188),
    [anon_sym_with] = ACTIONS(6188),
    [anon_sym_WITH] = ACTIONS(6188),
    [anon_sym_With] = ACTIONS(6188),
    [sym_asserterror_keyword] = ACTIONS(6190),
    [sym_page_keyword] = ACTIONS(6188),
    [anon_sym_codeunit] = ACTIONS(6188),
    [anon_sym_CODEUNIT] = ACTIONS(6188),
    [anon_sym_Codeunit] = ACTIONS(6188),
    [anon_sym_CodeUnit] = ACTIONS(6188),
    [anon_sym_COdeunit] = ACTIONS(6188),
    [anon_sym_codeUnit] = ACTIONS(6188),
    [sym_report_keyword] = ACTIONS(6188),
    [sym_query_keyword] = ACTIONS(6188),
    [anon_sym_xmlport] = ACTIONS(6188),
    [anon_sym_XMLPORT] = ACTIONS(6188),
    [anon_sym_Xmlport] = ACTIONS(6188),
    [anon_sym_XMLport] = ACTIONS(6188),
    [anon_sym_XMLPort] = ACTIONS(6188),
    [anon_sym_XmlPort] = ACTIONS(6188),
    [anon_sym_enum] = ACTIONS(6188),
    [anon_sym_ENUM] = ACTIONS(6188),
    [anon_sym_Enum] = ACTIONS(6188),
    [anon_sym_eNUM] = ACTIONS(6188),
    [anon_sym_eNum] = ACTIONS(6188),
    [anon_sym_ENum] = ACTIONS(6188),
    [sym_quoted_identifier] = ACTIONS(6190),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6190),
    [sym_verbatim_string] = ACTIONS(6190),
    [sym_integer] = ACTIONS(6188),
    [sym_continue_as_identifier] = ACTIONS(6190),
    [sym_preproc_open] = ACTIONS(6190),
    [sym_end_keyword] = ACTIONS(6190),
  },
  [STATE(3204)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [anon_sym_DASH] = ACTIONS(6194),
    [aux_sym_boolean_token1] = ACTIONS(6192),
    [aux_sym_boolean_token2] = ACTIONS(6192),
    [sym_decimal] = ACTIONS(6192),
    [anon_sym_LPAREN] = ACTIONS(6194),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [aux_sym_record_type_token1] = ACTIONS(6192),
    [aux_sym_basic_type_token21] = ACTIONS(6192),
    [aux_sym_basic_type_token22] = ACTIONS(6192),
    [aux_sym_basic_type_token48] = ACTIONS(6192),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6192),
    [anon_sym_POUNDif] = ACTIONS(6194),
    [anon_sym_POUNDIF] = ACTIONS(6194),
    [anon_sym_POUNDIf] = ACTIONS(6194),
    [anon_sym_not] = ACTIONS(6192),
    [anon_sym_NOT] = ACTIONS(6192),
    [anon_sym_Not] = ACTIONS(6192),
    [anon_sym_POUNDelse] = ACTIONS(6194),
    [anon_sym_POUNDELSE] = ACTIONS(6194),
    [anon_sym_POUNDElse] = ACTIONS(6194),
    [anon_sym_POUNDelse2] = ACTIONS(6194),
    [anon_sym_POUNDELSE2] = ACTIONS(6194),
    [anon_sym_POUNDElse2] = ACTIONS(6194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6192),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6192),
    [anon_sym_PLUS] = ACTIONS(6194),
    [sym_datetime_literal] = ACTIONS(6194),
    [sym_date_literal] = ACTIONS(6192),
    [sym_time_literal] = ACTIONS(6192),
    [sym_biginteger_literal] = ACTIONS(6194),
    [anon_sym_if] = ACTIONS(6192),
    [anon_sym_IF] = ACTIONS(6192),
    [anon_sym_If] = ACTIONS(6192),
    [anon_sym_else] = ACTIONS(6192),
    [anon_sym_ELSE] = ACTIONS(6192),
    [anon_sym_Else] = ACTIONS(6192),
    [anon_sym_case] = ACTIONS(6192),
    [anon_sym_CASE] = ACTIONS(6192),
    [anon_sym_Case] = ACTIONS(6192),
    [anon_sym_for] = ACTIONS(6192),
    [anon_sym_FOR] = ACTIONS(6192),
    [anon_sym_For] = ACTIONS(6192),
    [anon_sym_foreach] = ACTIONS(6192),
    [anon_sym_FOREACH] = ACTIONS(6192),
    [anon_sym_Foreach] = ACTIONS(6192),
    [anon_sym_while] = ACTIONS(6192),
    [anon_sym_WHILE] = ACTIONS(6192),
    [anon_sym_While] = ACTIONS(6192),
    [anon_sym_repeat] = ACTIONS(6192),
    [anon_sym_REPEAT] = ACTIONS(6192),
    [anon_sym_Repeat] = ACTIONS(6192),
    [anon_sym_exit] = ACTIONS(6192),
    [anon_sym_EXIT] = ACTIONS(6192),
    [anon_sym_Exit] = ACTIONS(6192),
    [anon_sym_continue] = ACTIONS(6192),
    [anon_sym_CONTINUE] = ACTIONS(6192),
    [anon_sym_Continue] = ACTIONS(6192),
    [anon_sym_break] = ACTIONS(6192),
    [anon_sym_BREAK] = ACTIONS(6192),
    [anon_sym_Break] = ACTIONS(6192),
    [anon_sym_with] = ACTIONS(6192),
    [anon_sym_WITH] = ACTIONS(6192),
    [anon_sym_With] = ACTIONS(6192),
    [sym_asserterror_keyword] = ACTIONS(6194),
    [sym_page_keyword] = ACTIONS(6192),
    [anon_sym_codeunit] = ACTIONS(6192),
    [anon_sym_CODEUNIT] = ACTIONS(6192),
    [anon_sym_Codeunit] = ACTIONS(6192),
    [anon_sym_CodeUnit] = ACTIONS(6192),
    [anon_sym_COdeunit] = ACTIONS(6192),
    [anon_sym_codeUnit] = ACTIONS(6192),
    [sym_report_keyword] = ACTIONS(6192),
    [sym_query_keyword] = ACTIONS(6192),
    [anon_sym_xmlport] = ACTIONS(6192),
    [anon_sym_XMLPORT] = ACTIONS(6192),
    [anon_sym_Xmlport] = ACTIONS(6192),
    [anon_sym_XMLport] = ACTIONS(6192),
    [anon_sym_XMLPort] = ACTIONS(6192),
    [anon_sym_XmlPort] = ACTIONS(6192),
    [anon_sym_enum] = ACTIONS(6192),
    [anon_sym_ENUM] = ACTIONS(6192),
    [anon_sym_Enum] = ACTIONS(6192),
    [anon_sym_eNUM] = ACTIONS(6192),
    [anon_sym_eNum] = ACTIONS(6192),
    [anon_sym_ENum] = ACTIONS(6192),
    [sym_quoted_identifier] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6194),
    [sym_verbatim_string] = ACTIONS(6194),
    [sym_integer] = ACTIONS(6192),
    [sym_continue_as_identifier] = ACTIONS(6194),
    [sym_preproc_open] = ACTIONS(6194),
    [sym_end_keyword] = ACTIONS(6194),
  },
  [STATE(3205)] = {
    [sym_identifier] = ACTIONS(5605),
    [anon_sym_SEMI] = ACTIONS(5607),
    [anon_sym_DASH] = ACTIONS(5607),
    [aux_sym_boolean_token1] = ACTIONS(5605),
    [aux_sym_boolean_token2] = ACTIONS(5605),
    [sym_decimal] = ACTIONS(5605),
    [anon_sym_LPAREN] = ACTIONS(5607),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5605),
    [anon_sym_LBRACK] = ACTIONS(5607),
    [aux_sym_record_type_token1] = ACTIONS(5605),
    [aux_sym_basic_type_token21] = ACTIONS(5605),
    [aux_sym_basic_type_token22] = ACTIONS(5605),
    [aux_sym_basic_type_token48] = ACTIONS(5605),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5605),
    [anon_sym_POUNDif] = ACTIONS(5607),
    [anon_sym_POUNDIF] = ACTIONS(5607),
    [anon_sym_POUNDIf] = ACTIONS(5607),
    [anon_sym_not] = ACTIONS(5605),
    [anon_sym_NOT] = ACTIONS(5605),
    [anon_sym_Not] = ACTIONS(5605),
    [anon_sym_POUNDelse] = ACTIONS(5607),
    [anon_sym_POUNDELSE] = ACTIONS(5607),
    [anon_sym_POUNDElse] = ACTIONS(5607),
    [anon_sym_POUNDelse2] = ACTIONS(5607),
    [anon_sym_POUNDELSE2] = ACTIONS(5607),
    [anon_sym_POUNDElse2] = ACTIONS(5607),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5605),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5605),
    [anon_sym_PLUS] = ACTIONS(5607),
    [sym_datetime_literal] = ACTIONS(5607),
    [sym_date_literal] = ACTIONS(5605),
    [sym_time_literal] = ACTIONS(5605),
    [sym_biginteger_literal] = ACTIONS(5607),
    [anon_sym_if] = ACTIONS(5605),
    [anon_sym_IF] = ACTIONS(5605),
    [anon_sym_If] = ACTIONS(5605),
    [anon_sym_else] = ACTIONS(5605),
    [anon_sym_ELSE] = ACTIONS(5605),
    [anon_sym_Else] = ACTIONS(5605),
    [anon_sym_case] = ACTIONS(5605),
    [anon_sym_CASE] = ACTIONS(5605),
    [anon_sym_Case] = ACTIONS(5605),
    [anon_sym_for] = ACTIONS(5605),
    [anon_sym_FOR] = ACTIONS(5605),
    [anon_sym_For] = ACTIONS(5605),
    [anon_sym_foreach] = ACTIONS(5605),
    [anon_sym_FOREACH] = ACTIONS(5605),
    [anon_sym_Foreach] = ACTIONS(5605),
    [anon_sym_while] = ACTIONS(5605),
    [anon_sym_WHILE] = ACTIONS(5605),
    [anon_sym_While] = ACTIONS(5605),
    [anon_sym_repeat] = ACTIONS(5605),
    [anon_sym_REPEAT] = ACTIONS(5605),
    [anon_sym_Repeat] = ACTIONS(5605),
    [anon_sym_exit] = ACTIONS(5605),
    [anon_sym_EXIT] = ACTIONS(5605),
    [anon_sym_Exit] = ACTIONS(5605),
    [anon_sym_continue] = ACTIONS(5605),
    [anon_sym_CONTINUE] = ACTIONS(5605),
    [anon_sym_Continue] = ACTIONS(5605),
    [anon_sym_break] = ACTIONS(5605),
    [anon_sym_BREAK] = ACTIONS(5605),
    [anon_sym_Break] = ACTIONS(5605),
    [anon_sym_with] = ACTIONS(5605),
    [anon_sym_WITH] = ACTIONS(5605),
    [anon_sym_With] = ACTIONS(5605),
    [sym_asserterror_keyword] = ACTIONS(5607),
    [sym_page_keyword] = ACTIONS(5605),
    [anon_sym_codeunit] = ACTIONS(5605),
    [anon_sym_CODEUNIT] = ACTIONS(5605),
    [anon_sym_Codeunit] = ACTIONS(5605),
    [anon_sym_CodeUnit] = ACTIONS(5605),
    [anon_sym_COdeunit] = ACTIONS(5605),
    [anon_sym_codeUnit] = ACTIONS(5605),
    [sym_report_keyword] = ACTIONS(5605),
    [sym_query_keyword] = ACTIONS(5605),
    [anon_sym_xmlport] = ACTIONS(5605),
    [anon_sym_XMLPORT] = ACTIONS(5605),
    [anon_sym_Xmlport] = ACTIONS(5605),
    [anon_sym_XMLport] = ACTIONS(5605),
    [anon_sym_XMLPort] = ACTIONS(5605),
    [anon_sym_XmlPort] = ACTIONS(5605),
    [anon_sym_enum] = ACTIONS(5605),
    [anon_sym_ENUM] = ACTIONS(5605),
    [anon_sym_Enum] = ACTIONS(5605),
    [anon_sym_eNUM] = ACTIONS(5605),
    [anon_sym_eNum] = ACTIONS(5605),
    [anon_sym_ENum] = ACTIONS(5605),
    [sym_quoted_identifier] = ACTIONS(5607),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5607),
    [sym_verbatim_string] = ACTIONS(5607),
    [sym_integer] = ACTIONS(5605),
    [sym_continue_as_identifier] = ACTIONS(5607),
    [sym_preproc_open] = ACTIONS(5607),
    [sym_end_keyword] = ACTIONS(5607),
  },
  [STATE(3206)] = {
    [sym_identifier] = ACTIONS(5613),
    [anon_sym_SEMI] = ACTIONS(5615),
    [anon_sym_DASH] = ACTIONS(5615),
    [aux_sym_boolean_token1] = ACTIONS(5613),
    [aux_sym_boolean_token2] = ACTIONS(5613),
    [sym_decimal] = ACTIONS(5613),
    [anon_sym_LPAREN] = ACTIONS(5615),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5613),
    [anon_sym_LBRACK] = ACTIONS(5615),
    [aux_sym_record_type_token1] = ACTIONS(5613),
    [aux_sym_basic_type_token21] = ACTIONS(5613),
    [aux_sym_basic_type_token22] = ACTIONS(5613),
    [aux_sym_basic_type_token48] = ACTIONS(5613),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5613),
    [anon_sym_POUNDif] = ACTIONS(5615),
    [anon_sym_POUNDIF] = ACTIONS(5615),
    [anon_sym_POUNDIf] = ACTIONS(5615),
    [anon_sym_not] = ACTIONS(5613),
    [anon_sym_NOT] = ACTIONS(5613),
    [anon_sym_Not] = ACTIONS(5613),
    [anon_sym_POUNDelse] = ACTIONS(5615),
    [anon_sym_POUNDELSE] = ACTIONS(5615),
    [anon_sym_POUNDElse] = ACTIONS(5615),
    [anon_sym_POUNDelse2] = ACTIONS(5615),
    [anon_sym_POUNDELSE2] = ACTIONS(5615),
    [anon_sym_POUNDElse2] = ACTIONS(5615),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5613),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5613),
    [anon_sym_PLUS] = ACTIONS(5615),
    [sym_datetime_literal] = ACTIONS(5615),
    [sym_date_literal] = ACTIONS(5613),
    [sym_time_literal] = ACTIONS(5613),
    [sym_biginteger_literal] = ACTIONS(5615),
    [anon_sym_if] = ACTIONS(5613),
    [anon_sym_IF] = ACTIONS(5613),
    [anon_sym_If] = ACTIONS(5613),
    [anon_sym_else] = ACTIONS(5613),
    [anon_sym_ELSE] = ACTIONS(5613),
    [anon_sym_Else] = ACTIONS(5613),
    [anon_sym_case] = ACTIONS(5613),
    [anon_sym_CASE] = ACTIONS(5613),
    [anon_sym_Case] = ACTIONS(5613),
    [anon_sym_for] = ACTIONS(5613),
    [anon_sym_FOR] = ACTIONS(5613),
    [anon_sym_For] = ACTIONS(5613),
    [anon_sym_foreach] = ACTIONS(5613),
    [anon_sym_FOREACH] = ACTIONS(5613),
    [anon_sym_Foreach] = ACTIONS(5613),
    [anon_sym_while] = ACTIONS(5613),
    [anon_sym_WHILE] = ACTIONS(5613),
    [anon_sym_While] = ACTIONS(5613),
    [anon_sym_repeat] = ACTIONS(5613),
    [anon_sym_REPEAT] = ACTIONS(5613),
    [anon_sym_Repeat] = ACTIONS(5613),
    [anon_sym_exit] = ACTIONS(5613),
    [anon_sym_EXIT] = ACTIONS(5613),
    [anon_sym_Exit] = ACTIONS(5613),
    [anon_sym_continue] = ACTIONS(5613),
    [anon_sym_CONTINUE] = ACTIONS(5613),
    [anon_sym_Continue] = ACTIONS(5613),
    [anon_sym_break] = ACTIONS(5613),
    [anon_sym_BREAK] = ACTIONS(5613),
    [anon_sym_Break] = ACTIONS(5613),
    [anon_sym_with] = ACTIONS(5613),
    [anon_sym_WITH] = ACTIONS(5613),
    [anon_sym_With] = ACTIONS(5613),
    [sym_asserterror_keyword] = ACTIONS(5615),
    [sym_page_keyword] = ACTIONS(5613),
    [anon_sym_codeunit] = ACTIONS(5613),
    [anon_sym_CODEUNIT] = ACTIONS(5613),
    [anon_sym_Codeunit] = ACTIONS(5613),
    [anon_sym_CodeUnit] = ACTIONS(5613),
    [anon_sym_COdeunit] = ACTIONS(5613),
    [anon_sym_codeUnit] = ACTIONS(5613),
    [sym_report_keyword] = ACTIONS(5613),
    [sym_query_keyword] = ACTIONS(5613),
    [anon_sym_xmlport] = ACTIONS(5613),
    [anon_sym_XMLPORT] = ACTIONS(5613),
    [anon_sym_Xmlport] = ACTIONS(5613),
    [anon_sym_XMLport] = ACTIONS(5613),
    [anon_sym_XMLPort] = ACTIONS(5613),
    [anon_sym_XmlPort] = ACTIONS(5613),
    [anon_sym_enum] = ACTIONS(5613),
    [anon_sym_ENUM] = ACTIONS(5613),
    [anon_sym_Enum] = ACTIONS(5613),
    [anon_sym_eNUM] = ACTIONS(5613),
    [anon_sym_eNum] = ACTIONS(5613),
    [anon_sym_ENum] = ACTIONS(5613),
    [sym_quoted_identifier] = ACTIONS(5615),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5615),
    [sym_verbatim_string] = ACTIONS(5615),
    [sym_integer] = ACTIONS(5613),
    [sym_continue_as_identifier] = ACTIONS(5615),
    [sym_preproc_open] = ACTIONS(5615),
    [sym_end_keyword] = ACTIONS(5615),
  },
  [STATE(3207)] = {
    [sym_identifier] = ACTIONS(5992),
    [anon_sym_SEMI] = ACTIONS(5994),
    [anon_sym_DASH] = ACTIONS(5994),
    [aux_sym_boolean_token1] = ACTIONS(5992),
    [aux_sym_boolean_token2] = ACTIONS(5992),
    [sym_decimal] = ACTIONS(5992),
    [anon_sym_LPAREN] = ACTIONS(5994),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5992),
    [anon_sym_LBRACK] = ACTIONS(5994),
    [aux_sym_record_type_token1] = ACTIONS(5992),
    [aux_sym_basic_type_token21] = ACTIONS(5992),
    [aux_sym_basic_type_token22] = ACTIONS(5992),
    [aux_sym_basic_type_token48] = ACTIONS(5992),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5992),
    [anon_sym_POUNDif] = ACTIONS(5994),
    [anon_sym_POUNDIF] = ACTIONS(5994),
    [anon_sym_POUNDIf] = ACTIONS(5994),
    [anon_sym_not] = ACTIONS(5992),
    [anon_sym_NOT] = ACTIONS(5992),
    [anon_sym_Not] = ACTIONS(5992),
    [anon_sym_POUNDelse] = ACTIONS(5994),
    [anon_sym_POUNDELSE] = ACTIONS(5994),
    [anon_sym_POUNDElse] = ACTIONS(5994),
    [anon_sym_POUNDelse2] = ACTIONS(5994),
    [anon_sym_POUNDELSE2] = ACTIONS(5994),
    [anon_sym_POUNDElse2] = ACTIONS(5994),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5992),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5992),
    [anon_sym_PLUS] = ACTIONS(5994),
    [sym_datetime_literal] = ACTIONS(5994),
    [sym_date_literal] = ACTIONS(5992),
    [sym_time_literal] = ACTIONS(5992),
    [sym_biginteger_literal] = ACTIONS(5994),
    [anon_sym_if] = ACTIONS(5992),
    [anon_sym_IF] = ACTIONS(5992),
    [anon_sym_If] = ACTIONS(5992),
    [anon_sym_else] = ACTIONS(5992),
    [anon_sym_ELSE] = ACTIONS(5992),
    [anon_sym_Else] = ACTIONS(5992),
    [anon_sym_case] = ACTIONS(5992),
    [anon_sym_CASE] = ACTIONS(5992),
    [anon_sym_Case] = ACTIONS(5992),
    [anon_sym_for] = ACTIONS(5992),
    [anon_sym_FOR] = ACTIONS(5992),
    [anon_sym_For] = ACTIONS(5992),
    [anon_sym_foreach] = ACTIONS(5992),
    [anon_sym_FOREACH] = ACTIONS(5992),
    [anon_sym_Foreach] = ACTIONS(5992),
    [anon_sym_while] = ACTIONS(5992),
    [anon_sym_WHILE] = ACTIONS(5992),
    [anon_sym_While] = ACTIONS(5992),
    [anon_sym_repeat] = ACTIONS(5992),
    [anon_sym_REPEAT] = ACTIONS(5992),
    [anon_sym_Repeat] = ACTIONS(5992),
    [anon_sym_exit] = ACTIONS(5992),
    [anon_sym_EXIT] = ACTIONS(5992),
    [anon_sym_Exit] = ACTIONS(5992),
    [anon_sym_continue] = ACTIONS(5992),
    [anon_sym_CONTINUE] = ACTIONS(5992),
    [anon_sym_Continue] = ACTIONS(5992),
    [anon_sym_break] = ACTIONS(5992),
    [anon_sym_BREAK] = ACTIONS(5992),
    [anon_sym_Break] = ACTIONS(5992),
    [anon_sym_with] = ACTIONS(5992),
    [anon_sym_WITH] = ACTIONS(5992),
    [anon_sym_With] = ACTIONS(5992),
    [sym_asserterror_keyword] = ACTIONS(5994),
    [sym_page_keyword] = ACTIONS(5992),
    [anon_sym_codeunit] = ACTIONS(5992),
    [anon_sym_CODEUNIT] = ACTIONS(5992),
    [anon_sym_Codeunit] = ACTIONS(5992),
    [anon_sym_CodeUnit] = ACTIONS(5992),
    [anon_sym_COdeunit] = ACTIONS(5992),
    [anon_sym_codeUnit] = ACTIONS(5992),
    [sym_report_keyword] = ACTIONS(5992),
    [sym_query_keyword] = ACTIONS(5992),
    [anon_sym_xmlport] = ACTIONS(5992),
    [anon_sym_XMLPORT] = ACTIONS(5992),
    [anon_sym_Xmlport] = ACTIONS(5992),
    [anon_sym_XMLport] = ACTIONS(5992),
    [anon_sym_XMLPort] = ACTIONS(5992),
    [anon_sym_XmlPort] = ACTIONS(5992),
    [anon_sym_enum] = ACTIONS(5992),
    [anon_sym_ENUM] = ACTIONS(5992),
    [anon_sym_Enum] = ACTIONS(5992),
    [anon_sym_eNUM] = ACTIONS(5992),
    [anon_sym_eNum] = ACTIONS(5992),
    [anon_sym_ENum] = ACTIONS(5992),
    [sym_quoted_identifier] = ACTIONS(5994),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5994),
    [sym_verbatim_string] = ACTIONS(5994),
    [sym_integer] = ACTIONS(5992),
    [sym_continue_as_identifier] = ACTIONS(5994),
    [sym_preproc_open] = ACTIONS(5994),
    [sym_end_keyword] = ACTIONS(5994),
  },
  [STATE(3208)] = {
    [sym_identifier] = ACTIONS(5988),
    [anon_sym_SEMI] = ACTIONS(5990),
    [anon_sym_DASH] = ACTIONS(5990),
    [aux_sym_boolean_token1] = ACTIONS(5988),
    [aux_sym_boolean_token2] = ACTIONS(5988),
    [sym_decimal] = ACTIONS(5988),
    [anon_sym_LPAREN] = ACTIONS(5990),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5988),
    [anon_sym_LBRACK] = ACTIONS(5990),
    [aux_sym_record_type_token1] = ACTIONS(5988),
    [aux_sym_basic_type_token21] = ACTIONS(5988),
    [aux_sym_basic_type_token22] = ACTIONS(5988),
    [aux_sym_basic_type_token48] = ACTIONS(5988),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5988),
    [anon_sym_POUNDif] = ACTIONS(5990),
    [anon_sym_POUNDIF] = ACTIONS(5990),
    [anon_sym_POUNDIf] = ACTIONS(5990),
    [anon_sym_not] = ACTIONS(5988),
    [anon_sym_NOT] = ACTIONS(5988),
    [anon_sym_Not] = ACTIONS(5988),
    [anon_sym_POUNDelse] = ACTIONS(5990),
    [anon_sym_POUNDELSE] = ACTIONS(5990),
    [anon_sym_POUNDElse] = ACTIONS(5990),
    [anon_sym_POUNDelse2] = ACTIONS(5990),
    [anon_sym_POUNDELSE2] = ACTIONS(5990),
    [anon_sym_POUNDElse2] = ACTIONS(5990),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5988),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5988),
    [anon_sym_PLUS] = ACTIONS(5990),
    [sym_datetime_literal] = ACTIONS(5990),
    [sym_date_literal] = ACTIONS(5988),
    [sym_time_literal] = ACTIONS(5988),
    [sym_biginteger_literal] = ACTIONS(5990),
    [anon_sym_if] = ACTIONS(5988),
    [anon_sym_IF] = ACTIONS(5988),
    [anon_sym_If] = ACTIONS(5988),
    [anon_sym_else] = ACTIONS(5988),
    [anon_sym_ELSE] = ACTIONS(5988),
    [anon_sym_Else] = ACTIONS(5988),
    [anon_sym_case] = ACTIONS(5988),
    [anon_sym_CASE] = ACTIONS(5988),
    [anon_sym_Case] = ACTIONS(5988),
    [anon_sym_for] = ACTIONS(5988),
    [anon_sym_FOR] = ACTIONS(5988),
    [anon_sym_For] = ACTIONS(5988),
    [anon_sym_foreach] = ACTIONS(5988),
    [anon_sym_FOREACH] = ACTIONS(5988),
    [anon_sym_Foreach] = ACTIONS(5988),
    [anon_sym_while] = ACTIONS(5988),
    [anon_sym_WHILE] = ACTIONS(5988),
    [anon_sym_While] = ACTIONS(5988),
    [anon_sym_repeat] = ACTIONS(5988),
    [anon_sym_REPEAT] = ACTIONS(5988),
    [anon_sym_Repeat] = ACTIONS(5988),
    [anon_sym_exit] = ACTIONS(5988),
    [anon_sym_EXIT] = ACTIONS(5988),
    [anon_sym_Exit] = ACTIONS(5988),
    [anon_sym_continue] = ACTIONS(5988),
    [anon_sym_CONTINUE] = ACTIONS(5988),
    [anon_sym_Continue] = ACTIONS(5988),
    [anon_sym_break] = ACTIONS(5988),
    [anon_sym_BREAK] = ACTIONS(5988),
    [anon_sym_Break] = ACTIONS(5988),
    [anon_sym_with] = ACTIONS(5988),
    [anon_sym_WITH] = ACTIONS(5988),
    [anon_sym_With] = ACTIONS(5988),
    [sym_asserterror_keyword] = ACTIONS(5990),
    [sym_page_keyword] = ACTIONS(5988),
    [anon_sym_codeunit] = ACTIONS(5988),
    [anon_sym_CODEUNIT] = ACTIONS(5988),
    [anon_sym_Codeunit] = ACTIONS(5988),
    [anon_sym_CodeUnit] = ACTIONS(5988),
    [anon_sym_COdeunit] = ACTIONS(5988),
    [anon_sym_codeUnit] = ACTIONS(5988),
    [sym_report_keyword] = ACTIONS(5988),
    [sym_query_keyword] = ACTIONS(5988),
    [anon_sym_xmlport] = ACTIONS(5988),
    [anon_sym_XMLPORT] = ACTIONS(5988),
    [anon_sym_Xmlport] = ACTIONS(5988),
    [anon_sym_XMLport] = ACTIONS(5988),
    [anon_sym_XMLPort] = ACTIONS(5988),
    [anon_sym_XmlPort] = ACTIONS(5988),
    [anon_sym_enum] = ACTIONS(5988),
    [anon_sym_ENUM] = ACTIONS(5988),
    [anon_sym_Enum] = ACTIONS(5988),
    [anon_sym_eNUM] = ACTIONS(5988),
    [anon_sym_eNum] = ACTIONS(5988),
    [anon_sym_ENum] = ACTIONS(5988),
    [sym_quoted_identifier] = ACTIONS(5990),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5990),
    [sym_verbatim_string] = ACTIONS(5990),
    [sym_integer] = ACTIONS(5988),
    [sym_continue_as_identifier] = ACTIONS(5990),
    [sym_preproc_open] = ACTIONS(5990),
    [sym_end_keyword] = ACTIONS(5990),
  },
  [STATE(3209)] = {
    [sym_identifier] = ACTIONS(6272),
    [anon_sym_SEMI] = ACTIONS(6274),
    [anon_sym_DASH] = ACTIONS(6274),
    [aux_sym_boolean_token1] = ACTIONS(6272),
    [aux_sym_boolean_token2] = ACTIONS(6272),
    [sym_decimal] = ACTIONS(6272),
    [anon_sym_LPAREN] = ACTIONS(6274),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6272),
    [anon_sym_LBRACK] = ACTIONS(6274),
    [aux_sym_record_type_token1] = ACTIONS(6272),
    [aux_sym_basic_type_token21] = ACTIONS(6272),
    [aux_sym_basic_type_token22] = ACTIONS(6272),
    [aux_sym_basic_type_token48] = ACTIONS(6272),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6272),
    [anon_sym_POUNDif] = ACTIONS(6274),
    [anon_sym_POUNDIF] = ACTIONS(6274),
    [anon_sym_POUNDIf] = ACTIONS(6274),
    [anon_sym_not] = ACTIONS(6272),
    [anon_sym_NOT] = ACTIONS(6272),
    [anon_sym_Not] = ACTIONS(6272),
    [anon_sym_POUNDelse] = ACTIONS(6274),
    [anon_sym_POUNDELSE] = ACTIONS(6274),
    [anon_sym_POUNDElse] = ACTIONS(6274),
    [anon_sym_POUNDelse2] = ACTIONS(6274),
    [anon_sym_POUNDELSE2] = ACTIONS(6274),
    [anon_sym_POUNDElse2] = ACTIONS(6274),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6272),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6272),
    [anon_sym_PLUS] = ACTIONS(6274),
    [sym_datetime_literal] = ACTIONS(6274),
    [sym_date_literal] = ACTIONS(6272),
    [sym_time_literal] = ACTIONS(6272),
    [sym_biginteger_literal] = ACTIONS(6274),
    [anon_sym_if] = ACTIONS(6272),
    [anon_sym_IF] = ACTIONS(6272),
    [anon_sym_If] = ACTIONS(6272),
    [anon_sym_else] = ACTIONS(6272),
    [anon_sym_ELSE] = ACTIONS(6272),
    [anon_sym_Else] = ACTIONS(6272),
    [anon_sym_case] = ACTIONS(6272),
    [anon_sym_CASE] = ACTIONS(6272),
    [anon_sym_Case] = ACTIONS(6272),
    [anon_sym_for] = ACTIONS(6272),
    [anon_sym_FOR] = ACTIONS(6272),
    [anon_sym_For] = ACTIONS(6272),
    [anon_sym_foreach] = ACTIONS(6272),
    [anon_sym_FOREACH] = ACTIONS(6272),
    [anon_sym_Foreach] = ACTIONS(6272),
    [anon_sym_while] = ACTIONS(6272),
    [anon_sym_WHILE] = ACTIONS(6272),
    [anon_sym_While] = ACTIONS(6272),
    [anon_sym_repeat] = ACTIONS(6272),
    [anon_sym_REPEAT] = ACTIONS(6272),
    [anon_sym_Repeat] = ACTIONS(6272),
    [anon_sym_exit] = ACTIONS(6272),
    [anon_sym_EXIT] = ACTIONS(6272),
    [anon_sym_Exit] = ACTIONS(6272),
    [anon_sym_continue] = ACTIONS(6272),
    [anon_sym_CONTINUE] = ACTIONS(6272),
    [anon_sym_Continue] = ACTIONS(6272),
    [anon_sym_break] = ACTIONS(6272),
    [anon_sym_BREAK] = ACTIONS(6272),
    [anon_sym_Break] = ACTIONS(6272),
    [anon_sym_with] = ACTIONS(6272),
    [anon_sym_WITH] = ACTIONS(6272),
    [anon_sym_With] = ACTIONS(6272),
    [sym_asserterror_keyword] = ACTIONS(6274),
    [sym_page_keyword] = ACTIONS(6272),
    [anon_sym_codeunit] = ACTIONS(6272),
    [anon_sym_CODEUNIT] = ACTIONS(6272),
    [anon_sym_Codeunit] = ACTIONS(6272),
    [anon_sym_CodeUnit] = ACTIONS(6272),
    [anon_sym_COdeunit] = ACTIONS(6272),
    [anon_sym_codeUnit] = ACTIONS(6272),
    [sym_report_keyword] = ACTIONS(6272),
    [sym_query_keyword] = ACTIONS(6272),
    [anon_sym_xmlport] = ACTIONS(6272),
    [anon_sym_XMLPORT] = ACTIONS(6272),
    [anon_sym_Xmlport] = ACTIONS(6272),
    [anon_sym_XMLport] = ACTIONS(6272),
    [anon_sym_XMLPort] = ACTIONS(6272),
    [anon_sym_XmlPort] = ACTIONS(6272),
    [anon_sym_enum] = ACTIONS(6272),
    [anon_sym_ENUM] = ACTIONS(6272),
    [anon_sym_Enum] = ACTIONS(6272),
    [anon_sym_eNUM] = ACTIONS(6272),
    [anon_sym_eNum] = ACTIONS(6272),
    [anon_sym_ENum] = ACTIONS(6272),
    [sym_quoted_identifier] = ACTIONS(6274),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6274),
    [sym_verbatim_string] = ACTIONS(6274),
    [sym_integer] = ACTIONS(6272),
    [sym_continue_as_identifier] = ACTIONS(6274),
    [sym_preproc_open] = ACTIONS(6274),
    [sym_end_keyword] = ACTIONS(6274),
  },
  [STATE(3210)] = {
    [sym_identifier] = ACTIONS(6102),
    [anon_sym_SEMI] = ACTIONS(6104),
    [anon_sym_DASH] = ACTIONS(6104),
    [aux_sym_boolean_token1] = ACTIONS(6102),
    [aux_sym_boolean_token2] = ACTIONS(6102),
    [sym_decimal] = ACTIONS(6102),
    [anon_sym_LPAREN] = ACTIONS(6104),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6102),
    [anon_sym_LBRACK] = ACTIONS(6104),
    [aux_sym_record_type_token1] = ACTIONS(6102),
    [aux_sym_basic_type_token21] = ACTIONS(6102),
    [aux_sym_basic_type_token22] = ACTIONS(6102),
    [aux_sym_basic_type_token48] = ACTIONS(6102),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6102),
    [anon_sym_POUNDif] = ACTIONS(6104),
    [anon_sym_POUNDIF] = ACTIONS(6104),
    [anon_sym_POUNDIf] = ACTIONS(6104),
    [anon_sym_not] = ACTIONS(6102),
    [anon_sym_NOT] = ACTIONS(6102),
    [anon_sym_Not] = ACTIONS(6102),
    [anon_sym_POUNDelse] = ACTIONS(6104),
    [anon_sym_POUNDELSE] = ACTIONS(6104),
    [anon_sym_POUNDElse] = ACTIONS(6104),
    [anon_sym_POUNDelse2] = ACTIONS(6104),
    [anon_sym_POUNDELSE2] = ACTIONS(6104),
    [anon_sym_POUNDElse2] = ACTIONS(6104),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6102),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6102),
    [anon_sym_PLUS] = ACTIONS(6104),
    [sym_datetime_literal] = ACTIONS(6104),
    [sym_date_literal] = ACTIONS(6102),
    [sym_time_literal] = ACTIONS(6102),
    [sym_biginteger_literal] = ACTIONS(6104),
    [anon_sym_if] = ACTIONS(6102),
    [anon_sym_IF] = ACTIONS(6102),
    [anon_sym_If] = ACTIONS(6102),
    [anon_sym_else] = ACTIONS(6102),
    [anon_sym_ELSE] = ACTIONS(6102),
    [anon_sym_Else] = ACTIONS(6102),
    [anon_sym_case] = ACTIONS(6102),
    [anon_sym_CASE] = ACTIONS(6102),
    [anon_sym_Case] = ACTIONS(6102),
    [anon_sym_for] = ACTIONS(6102),
    [anon_sym_FOR] = ACTIONS(6102),
    [anon_sym_For] = ACTIONS(6102),
    [anon_sym_foreach] = ACTIONS(6102),
    [anon_sym_FOREACH] = ACTIONS(6102),
    [anon_sym_Foreach] = ACTIONS(6102),
    [anon_sym_while] = ACTIONS(6102),
    [anon_sym_WHILE] = ACTIONS(6102),
    [anon_sym_While] = ACTIONS(6102),
    [anon_sym_repeat] = ACTIONS(6102),
    [anon_sym_REPEAT] = ACTIONS(6102),
    [anon_sym_Repeat] = ACTIONS(6102),
    [anon_sym_exit] = ACTIONS(6102),
    [anon_sym_EXIT] = ACTIONS(6102),
    [anon_sym_Exit] = ACTIONS(6102),
    [anon_sym_continue] = ACTIONS(6102),
    [anon_sym_CONTINUE] = ACTIONS(6102),
    [anon_sym_Continue] = ACTIONS(6102),
    [anon_sym_break] = ACTIONS(6102),
    [anon_sym_BREAK] = ACTIONS(6102),
    [anon_sym_Break] = ACTIONS(6102),
    [anon_sym_with] = ACTIONS(6102),
    [anon_sym_WITH] = ACTIONS(6102),
    [anon_sym_With] = ACTIONS(6102),
    [sym_asserterror_keyword] = ACTIONS(6104),
    [sym_page_keyword] = ACTIONS(6102),
    [anon_sym_codeunit] = ACTIONS(6102),
    [anon_sym_CODEUNIT] = ACTIONS(6102),
    [anon_sym_Codeunit] = ACTIONS(6102),
    [anon_sym_CodeUnit] = ACTIONS(6102),
    [anon_sym_COdeunit] = ACTIONS(6102),
    [anon_sym_codeUnit] = ACTIONS(6102),
    [sym_report_keyword] = ACTIONS(6102),
    [sym_query_keyword] = ACTIONS(6102),
    [anon_sym_xmlport] = ACTIONS(6102),
    [anon_sym_XMLPORT] = ACTIONS(6102),
    [anon_sym_Xmlport] = ACTIONS(6102),
    [anon_sym_XMLport] = ACTIONS(6102),
    [anon_sym_XMLPort] = ACTIONS(6102),
    [anon_sym_XmlPort] = ACTIONS(6102),
    [anon_sym_enum] = ACTIONS(6102),
    [anon_sym_ENUM] = ACTIONS(6102),
    [anon_sym_Enum] = ACTIONS(6102),
    [anon_sym_eNUM] = ACTIONS(6102),
    [anon_sym_eNum] = ACTIONS(6102),
    [anon_sym_ENum] = ACTIONS(6102),
    [sym_quoted_identifier] = ACTIONS(6104),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6104),
    [sym_verbatim_string] = ACTIONS(6104),
    [sym_integer] = ACTIONS(6102),
    [sym_continue_as_identifier] = ACTIONS(6104),
    [sym_preproc_open] = ACTIONS(6104),
    [sym_end_keyword] = ACTIONS(6104),
  },
  [STATE(3211)] = {
    [sym_identifier] = ACTIONS(6300),
    [anon_sym_SEMI] = ACTIONS(6302),
    [anon_sym_DASH] = ACTIONS(6302),
    [aux_sym_boolean_token1] = ACTIONS(6300),
    [aux_sym_boolean_token2] = ACTIONS(6300),
    [sym_decimal] = ACTIONS(6300),
    [anon_sym_LPAREN] = ACTIONS(6302),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6300),
    [anon_sym_LBRACK] = ACTIONS(6302),
    [aux_sym_record_type_token1] = ACTIONS(6300),
    [aux_sym_basic_type_token21] = ACTIONS(6300),
    [aux_sym_basic_type_token22] = ACTIONS(6300),
    [aux_sym_basic_type_token48] = ACTIONS(6300),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6300),
    [anon_sym_POUNDif] = ACTIONS(6302),
    [anon_sym_POUNDIF] = ACTIONS(6302),
    [anon_sym_POUNDIf] = ACTIONS(6302),
    [anon_sym_not] = ACTIONS(6300),
    [anon_sym_NOT] = ACTIONS(6300),
    [anon_sym_Not] = ACTIONS(6300),
    [anon_sym_POUNDelse] = ACTIONS(6302),
    [anon_sym_POUNDELSE] = ACTIONS(6302),
    [anon_sym_POUNDElse] = ACTIONS(6302),
    [anon_sym_POUNDelse2] = ACTIONS(6302),
    [anon_sym_POUNDELSE2] = ACTIONS(6302),
    [anon_sym_POUNDElse2] = ACTIONS(6302),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6300),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6300),
    [anon_sym_PLUS] = ACTIONS(6302),
    [sym_datetime_literal] = ACTIONS(6302),
    [sym_date_literal] = ACTIONS(6300),
    [sym_time_literal] = ACTIONS(6300),
    [sym_biginteger_literal] = ACTIONS(6302),
    [anon_sym_if] = ACTIONS(6300),
    [anon_sym_IF] = ACTIONS(6300),
    [anon_sym_If] = ACTIONS(6300),
    [anon_sym_else] = ACTIONS(6300),
    [anon_sym_ELSE] = ACTIONS(6300),
    [anon_sym_Else] = ACTIONS(6300),
    [anon_sym_case] = ACTIONS(6300),
    [anon_sym_CASE] = ACTIONS(6300),
    [anon_sym_Case] = ACTIONS(6300),
    [anon_sym_for] = ACTIONS(6300),
    [anon_sym_FOR] = ACTIONS(6300),
    [anon_sym_For] = ACTIONS(6300),
    [anon_sym_foreach] = ACTIONS(6300),
    [anon_sym_FOREACH] = ACTIONS(6300),
    [anon_sym_Foreach] = ACTIONS(6300),
    [anon_sym_while] = ACTIONS(6300),
    [anon_sym_WHILE] = ACTIONS(6300),
    [anon_sym_While] = ACTIONS(6300),
    [anon_sym_repeat] = ACTIONS(6300),
    [anon_sym_REPEAT] = ACTIONS(6300),
    [anon_sym_Repeat] = ACTIONS(6300),
    [anon_sym_exit] = ACTIONS(6300),
    [anon_sym_EXIT] = ACTIONS(6300),
    [anon_sym_Exit] = ACTIONS(6300),
    [anon_sym_continue] = ACTIONS(6300),
    [anon_sym_CONTINUE] = ACTIONS(6300),
    [anon_sym_Continue] = ACTIONS(6300),
    [anon_sym_break] = ACTIONS(6300),
    [anon_sym_BREAK] = ACTIONS(6300),
    [anon_sym_Break] = ACTIONS(6300),
    [anon_sym_with] = ACTIONS(6300),
    [anon_sym_WITH] = ACTIONS(6300),
    [anon_sym_With] = ACTIONS(6300),
    [sym_asserterror_keyword] = ACTIONS(6302),
    [sym_page_keyword] = ACTIONS(6300),
    [anon_sym_codeunit] = ACTIONS(6300),
    [anon_sym_CODEUNIT] = ACTIONS(6300),
    [anon_sym_Codeunit] = ACTIONS(6300),
    [anon_sym_CodeUnit] = ACTIONS(6300),
    [anon_sym_COdeunit] = ACTIONS(6300),
    [anon_sym_codeUnit] = ACTIONS(6300),
    [sym_report_keyword] = ACTIONS(6300),
    [sym_query_keyword] = ACTIONS(6300),
    [anon_sym_xmlport] = ACTIONS(6300),
    [anon_sym_XMLPORT] = ACTIONS(6300),
    [anon_sym_Xmlport] = ACTIONS(6300),
    [anon_sym_XMLport] = ACTIONS(6300),
    [anon_sym_XMLPort] = ACTIONS(6300),
    [anon_sym_XmlPort] = ACTIONS(6300),
    [anon_sym_enum] = ACTIONS(6300),
    [anon_sym_ENUM] = ACTIONS(6300),
    [anon_sym_Enum] = ACTIONS(6300),
    [anon_sym_eNUM] = ACTIONS(6300),
    [anon_sym_eNum] = ACTIONS(6300),
    [anon_sym_ENum] = ACTIONS(6300),
    [sym_quoted_identifier] = ACTIONS(6302),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6302),
    [sym_verbatim_string] = ACTIONS(6302),
    [sym_integer] = ACTIONS(6300),
    [sym_continue_as_identifier] = ACTIONS(6302),
    [sym_preproc_open] = ACTIONS(6302),
    [sym_end_keyword] = ACTIONS(6302),
  },
  [STATE(3212)] = {
    [sym_identifier] = ACTIONS(5835),
    [anon_sym_SEMI] = ACTIONS(5837),
    [anon_sym_DASH] = ACTIONS(5837),
    [aux_sym_boolean_token1] = ACTIONS(5835),
    [aux_sym_boolean_token2] = ACTIONS(5835),
    [sym_decimal] = ACTIONS(5835),
    [anon_sym_LPAREN] = ACTIONS(5837),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5835),
    [anon_sym_LBRACK] = ACTIONS(5837),
    [aux_sym_record_type_token1] = ACTIONS(5835),
    [aux_sym_basic_type_token21] = ACTIONS(5835),
    [aux_sym_basic_type_token22] = ACTIONS(5835),
    [aux_sym_basic_type_token48] = ACTIONS(5835),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5835),
    [anon_sym_POUNDif] = ACTIONS(5837),
    [anon_sym_POUNDIF] = ACTIONS(5837),
    [anon_sym_POUNDIf] = ACTIONS(5837),
    [anon_sym_not] = ACTIONS(5835),
    [anon_sym_NOT] = ACTIONS(5835),
    [anon_sym_Not] = ACTIONS(5835),
    [anon_sym_POUNDelse] = ACTIONS(5837),
    [anon_sym_POUNDELSE] = ACTIONS(5837),
    [anon_sym_POUNDElse] = ACTIONS(5837),
    [anon_sym_POUNDelse2] = ACTIONS(5837),
    [anon_sym_POUNDELSE2] = ACTIONS(5837),
    [anon_sym_POUNDElse2] = ACTIONS(5837),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5835),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5835),
    [anon_sym_PLUS] = ACTIONS(5837),
    [sym_datetime_literal] = ACTIONS(5837),
    [sym_date_literal] = ACTIONS(5835),
    [sym_time_literal] = ACTIONS(5835),
    [sym_biginteger_literal] = ACTIONS(5837),
    [anon_sym_if] = ACTIONS(5835),
    [anon_sym_IF] = ACTIONS(5835),
    [anon_sym_If] = ACTIONS(5835),
    [anon_sym_else] = ACTIONS(5835),
    [anon_sym_ELSE] = ACTIONS(5835),
    [anon_sym_Else] = ACTIONS(5835),
    [anon_sym_case] = ACTIONS(5835),
    [anon_sym_CASE] = ACTIONS(5835),
    [anon_sym_Case] = ACTIONS(5835),
    [anon_sym_for] = ACTIONS(5835),
    [anon_sym_FOR] = ACTIONS(5835),
    [anon_sym_For] = ACTIONS(5835),
    [anon_sym_foreach] = ACTIONS(5835),
    [anon_sym_FOREACH] = ACTIONS(5835),
    [anon_sym_Foreach] = ACTIONS(5835),
    [anon_sym_while] = ACTIONS(5835),
    [anon_sym_WHILE] = ACTIONS(5835),
    [anon_sym_While] = ACTIONS(5835),
    [anon_sym_repeat] = ACTIONS(5835),
    [anon_sym_REPEAT] = ACTIONS(5835),
    [anon_sym_Repeat] = ACTIONS(5835),
    [anon_sym_exit] = ACTIONS(5835),
    [anon_sym_EXIT] = ACTIONS(5835),
    [anon_sym_Exit] = ACTIONS(5835),
    [anon_sym_continue] = ACTIONS(5835),
    [anon_sym_CONTINUE] = ACTIONS(5835),
    [anon_sym_Continue] = ACTIONS(5835),
    [anon_sym_break] = ACTIONS(5835),
    [anon_sym_BREAK] = ACTIONS(5835),
    [anon_sym_Break] = ACTIONS(5835),
    [anon_sym_with] = ACTIONS(5835),
    [anon_sym_WITH] = ACTIONS(5835),
    [anon_sym_With] = ACTIONS(5835),
    [sym_asserterror_keyword] = ACTIONS(5837),
    [sym_page_keyword] = ACTIONS(5835),
    [anon_sym_codeunit] = ACTIONS(5835),
    [anon_sym_CODEUNIT] = ACTIONS(5835),
    [anon_sym_Codeunit] = ACTIONS(5835),
    [anon_sym_CodeUnit] = ACTIONS(5835),
    [anon_sym_COdeunit] = ACTIONS(5835),
    [anon_sym_codeUnit] = ACTIONS(5835),
    [sym_report_keyword] = ACTIONS(5835),
    [sym_query_keyword] = ACTIONS(5835),
    [anon_sym_xmlport] = ACTIONS(5835),
    [anon_sym_XMLPORT] = ACTIONS(5835),
    [anon_sym_Xmlport] = ACTIONS(5835),
    [anon_sym_XMLport] = ACTIONS(5835),
    [anon_sym_XMLPort] = ACTIONS(5835),
    [anon_sym_XmlPort] = ACTIONS(5835),
    [anon_sym_enum] = ACTIONS(5835),
    [anon_sym_ENUM] = ACTIONS(5835),
    [anon_sym_Enum] = ACTIONS(5835),
    [anon_sym_eNUM] = ACTIONS(5835),
    [anon_sym_eNum] = ACTIONS(5835),
    [anon_sym_ENum] = ACTIONS(5835),
    [sym_quoted_identifier] = ACTIONS(5837),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5837),
    [sym_verbatim_string] = ACTIONS(5837),
    [sym_integer] = ACTIONS(5835),
    [sym_continue_as_identifier] = ACTIONS(5837),
    [sym_preproc_open] = ACTIONS(5837),
    [sym_end_keyword] = ACTIONS(5837),
  },
  [STATE(3213)] = {
    [sym_identifier] = ACTIONS(5988),
    [anon_sym_SEMI] = ACTIONS(5990),
    [anon_sym_DASH] = ACTIONS(5990),
    [aux_sym_boolean_token1] = ACTIONS(5988),
    [aux_sym_boolean_token2] = ACTIONS(5988),
    [sym_decimal] = ACTIONS(5988),
    [anon_sym_LPAREN] = ACTIONS(5990),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5988),
    [anon_sym_LBRACK] = ACTIONS(5990),
    [aux_sym_record_type_token1] = ACTIONS(5988),
    [aux_sym_basic_type_token21] = ACTIONS(5988),
    [aux_sym_basic_type_token22] = ACTIONS(5988),
    [aux_sym_basic_type_token48] = ACTIONS(5988),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5988),
    [anon_sym_POUNDif] = ACTIONS(5990),
    [anon_sym_POUNDIF] = ACTIONS(5990),
    [anon_sym_POUNDIf] = ACTIONS(5990),
    [anon_sym_not] = ACTIONS(5988),
    [anon_sym_NOT] = ACTIONS(5988),
    [anon_sym_Not] = ACTIONS(5988),
    [anon_sym_POUNDelse] = ACTIONS(5990),
    [anon_sym_POUNDELSE] = ACTIONS(5990),
    [anon_sym_POUNDElse] = ACTIONS(5990),
    [anon_sym_POUNDelse2] = ACTIONS(5990),
    [anon_sym_POUNDELSE2] = ACTIONS(5990),
    [anon_sym_POUNDElse2] = ACTIONS(5990),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5988),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5988),
    [anon_sym_PLUS] = ACTIONS(5990),
    [sym_datetime_literal] = ACTIONS(5990),
    [sym_date_literal] = ACTIONS(5988),
    [sym_time_literal] = ACTIONS(5988),
    [sym_biginteger_literal] = ACTIONS(5990),
    [anon_sym_if] = ACTIONS(5988),
    [anon_sym_IF] = ACTIONS(5988),
    [anon_sym_If] = ACTIONS(5988),
    [anon_sym_else] = ACTIONS(5988),
    [anon_sym_ELSE] = ACTIONS(5988),
    [anon_sym_Else] = ACTIONS(5988),
    [anon_sym_case] = ACTIONS(5988),
    [anon_sym_CASE] = ACTIONS(5988),
    [anon_sym_Case] = ACTIONS(5988),
    [anon_sym_for] = ACTIONS(5988),
    [anon_sym_FOR] = ACTIONS(5988),
    [anon_sym_For] = ACTIONS(5988),
    [anon_sym_foreach] = ACTIONS(5988),
    [anon_sym_FOREACH] = ACTIONS(5988),
    [anon_sym_Foreach] = ACTIONS(5988),
    [anon_sym_while] = ACTIONS(5988),
    [anon_sym_WHILE] = ACTIONS(5988),
    [anon_sym_While] = ACTIONS(5988),
    [anon_sym_repeat] = ACTIONS(5988),
    [anon_sym_REPEAT] = ACTIONS(5988),
    [anon_sym_Repeat] = ACTIONS(5988),
    [anon_sym_exit] = ACTIONS(5988),
    [anon_sym_EXIT] = ACTIONS(5988),
    [anon_sym_Exit] = ACTIONS(5988),
    [anon_sym_continue] = ACTIONS(5988),
    [anon_sym_CONTINUE] = ACTIONS(5988),
    [anon_sym_Continue] = ACTIONS(5988),
    [anon_sym_break] = ACTIONS(5988),
    [anon_sym_BREAK] = ACTIONS(5988),
    [anon_sym_Break] = ACTIONS(5988),
    [anon_sym_with] = ACTIONS(5988),
    [anon_sym_WITH] = ACTIONS(5988),
    [anon_sym_With] = ACTIONS(5988),
    [sym_asserterror_keyword] = ACTIONS(5990),
    [sym_page_keyword] = ACTIONS(5988),
    [anon_sym_codeunit] = ACTIONS(5988),
    [anon_sym_CODEUNIT] = ACTIONS(5988),
    [anon_sym_Codeunit] = ACTIONS(5988),
    [anon_sym_CodeUnit] = ACTIONS(5988),
    [anon_sym_COdeunit] = ACTIONS(5988),
    [anon_sym_codeUnit] = ACTIONS(5988),
    [sym_report_keyword] = ACTIONS(5988),
    [sym_query_keyword] = ACTIONS(5988),
    [anon_sym_xmlport] = ACTIONS(5988),
    [anon_sym_XMLPORT] = ACTIONS(5988),
    [anon_sym_Xmlport] = ACTIONS(5988),
    [anon_sym_XMLport] = ACTIONS(5988),
    [anon_sym_XMLPort] = ACTIONS(5988),
    [anon_sym_XmlPort] = ACTIONS(5988),
    [anon_sym_enum] = ACTIONS(5988),
    [anon_sym_ENUM] = ACTIONS(5988),
    [anon_sym_Enum] = ACTIONS(5988),
    [anon_sym_eNUM] = ACTIONS(5988),
    [anon_sym_eNum] = ACTIONS(5988),
    [anon_sym_ENum] = ACTIONS(5988),
    [sym_quoted_identifier] = ACTIONS(5990),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5990),
    [sym_verbatim_string] = ACTIONS(5990),
    [sym_integer] = ACTIONS(5988),
    [sym_continue_as_identifier] = ACTIONS(5990),
    [sym_preproc_open] = ACTIONS(5990),
    [sym_end_keyword] = ACTIONS(5990),
  },
  [STATE(3214)] = {
    [sym_identifier] = ACTIONS(5617),
    [anon_sym_SEMI] = ACTIONS(5619),
    [anon_sym_DASH] = ACTIONS(5619),
    [aux_sym_boolean_token1] = ACTIONS(5617),
    [aux_sym_boolean_token2] = ACTIONS(5617),
    [sym_decimal] = ACTIONS(5617),
    [anon_sym_LPAREN] = ACTIONS(5619),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5617),
    [anon_sym_LBRACK] = ACTIONS(5619),
    [aux_sym_record_type_token1] = ACTIONS(5617),
    [aux_sym_basic_type_token21] = ACTIONS(5617),
    [aux_sym_basic_type_token22] = ACTIONS(5617),
    [aux_sym_basic_type_token48] = ACTIONS(5617),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5617),
    [anon_sym_POUNDif] = ACTIONS(5619),
    [anon_sym_POUNDIF] = ACTIONS(5619),
    [anon_sym_POUNDIf] = ACTIONS(5619),
    [anon_sym_not] = ACTIONS(5617),
    [anon_sym_NOT] = ACTIONS(5617),
    [anon_sym_Not] = ACTIONS(5617),
    [anon_sym_POUNDelse] = ACTIONS(5619),
    [anon_sym_POUNDELSE] = ACTIONS(5619),
    [anon_sym_POUNDElse] = ACTIONS(5619),
    [anon_sym_POUNDelse2] = ACTIONS(5619),
    [anon_sym_POUNDELSE2] = ACTIONS(5619),
    [anon_sym_POUNDElse2] = ACTIONS(5619),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5617),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5617),
    [anon_sym_PLUS] = ACTIONS(5619),
    [sym_datetime_literal] = ACTIONS(5619),
    [sym_date_literal] = ACTIONS(5617),
    [sym_time_literal] = ACTIONS(5617),
    [sym_biginteger_literal] = ACTIONS(5619),
    [anon_sym_if] = ACTIONS(5617),
    [anon_sym_IF] = ACTIONS(5617),
    [anon_sym_If] = ACTIONS(5617),
    [anon_sym_else] = ACTIONS(5617),
    [anon_sym_ELSE] = ACTIONS(5617),
    [anon_sym_Else] = ACTIONS(5617),
    [anon_sym_case] = ACTIONS(5617),
    [anon_sym_CASE] = ACTIONS(5617),
    [anon_sym_Case] = ACTIONS(5617),
    [anon_sym_for] = ACTIONS(5617),
    [anon_sym_FOR] = ACTIONS(5617),
    [anon_sym_For] = ACTIONS(5617),
    [anon_sym_foreach] = ACTIONS(5617),
    [anon_sym_FOREACH] = ACTIONS(5617),
    [anon_sym_Foreach] = ACTIONS(5617),
    [anon_sym_while] = ACTIONS(5617),
    [anon_sym_WHILE] = ACTIONS(5617),
    [anon_sym_While] = ACTIONS(5617),
    [anon_sym_repeat] = ACTIONS(5617),
    [anon_sym_REPEAT] = ACTIONS(5617),
    [anon_sym_Repeat] = ACTIONS(5617),
    [anon_sym_exit] = ACTIONS(5617),
    [anon_sym_EXIT] = ACTIONS(5617),
    [anon_sym_Exit] = ACTIONS(5617),
    [anon_sym_continue] = ACTIONS(5617),
    [anon_sym_CONTINUE] = ACTIONS(5617),
    [anon_sym_Continue] = ACTIONS(5617),
    [anon_sym_break] = ACTIONS(5617),
    [anon_sym_BREAK] = ACTIONS(5617),
    [anon_sym_Break] = ACTIONS(5617),
    [anon_sym_with] = ACTIONS(5617),
    [anon_sym_WITH] = ACTIONS(5617),
    [anon_sym_With] = ACTIONS(5617),
    [sym_asserterror_keyword] = ACTIONS(5619),
    [sym_page_keyword] = ACTIONS(5617),
    [anon_sym_codeunit] = ACTIONS(5617),
    [anon_sym_CODEUNIT] = ACTIONS(5617),
    [anon_sym_Codeunit] = ACTIONS(5617),
    [anon_sym_CodeUnit] = ACTIONS(5617),
    [anon_sym_COdeunit] = ACTIONS(5617),
    [anon_sym_codeUnit] = ACTIONS(5617),
    [sym_report_keyword] = ACTIONS(5617),
    [sym_query_keyword] = ACTIONS(5617),
    [anon_sym_xmlport] = ACTIONS(5617),
    [anon_sym_XMLPORT] = ACTIONS(5617),
    [anon_sym_Xmlport] = ACTIONS(5617),
    [anon_sym_XMLport] = ACTIONS(5617),
    [anon_sym_XMLPort] = ACTIONS(5617),
    [anon_sym_XmlPort] = ACTIONS(5617),
    [anon_sym_enum] = ACTIONS(5617),
    [anon_sym_ENUM] = ACTIONS(5617),
    [anon_sym_Enum] = ACTIONS(5617),
    [anon_sym_eNUM] = ACTIONS(5617),
    [anon_sym_eNum] = ACTIONS(5617),
    [anon_sym_ENum] = ACTIONS(5617),
    [sym_quoted_identifier] = ACTIONS(5619),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5619),
    [sym_verbatim_string] = ACTIONS(5619),
    [sym_integer] = ACTIONS(5617),
    [sym_continue_as_identifier] = ACTIONS(5619),
    [sym_preproc_open] = ACTIONS(5619),
    [sym_end_keyword] = ACTIONS(5619),
  },
  [STATE(3215)] = {
    [sym_identifier] = ACTIONS(5973),
    [anon_sym_SEMI] = ACTIONS(5975),
    [anon_sym_DASH] = ACTIONS(5975),
    [aux_sym_boolean_token1] = ACTIONS(5973),
    [aux_sym_boolean_token2] = ACTIONS(5973),
    [sym_decimal] = ACTIONS(5973),
    [anon_sym_LPAREN] = ACTIONS(5975),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5973),
    [anon_sym_LBRACK] = ACTIONS(5975),
    [aux_sym_record_type_token1] = ACTIONS(5973),
    [aux_sym_basic_type_token21] = ACTIONS(5973),
    [aux_sym_basic_type_token22] = ACTIONS(5973),
    [aux_sym_basic_type_token48] = ACTIONS(5973),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5973),
    [anon_sym_POUNDif] = ACTIONS(5975),
    [anon_sym_POUNDIF] = ACTIONS(5975),
    [anon_sym_POUNDIf] = ACTIONS(5975),
    [anon_sym_not] = ACTIONS(5973),
    [anon_sym_NOT] = ACTIONS(5973),
    [anon_sym_Not] = ACTIONS(5973),
    [anon_sym_POUNDelse] = ACTIONS(5975),
    [anon_sym_POUNDELSE] = ACTIONS(5975),
    [anon_sym_POUNDElse] = ACTIONS(5975),
    [anon_sym_POUNDelse2] = ACTIONS(5975),
    [anon_sym_POUNDELSE2] = ACTIONS(5975),
    [anon_sym_POUNDElse2] = ACTIONS(5975),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5973),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5973),
    [anon_sym_PLUS] = ACTIONS(5975),
    [sym_datetime_literal] = ACTIONS(5975),
    [sym_date_literal] = ACTIONS(5973),
    [sym_time_literal] = ACTIONS(5973),
    [sym_biginteger_literal] = ACTIONS(5975),
    [anon_sym_if] = ACTIONS(5973),
    [anon_sym_IF] = ACTIONS(5973),
    [anon_sym_If] = ACTIONS(5973),
    [anon_sym_else] = ACTIONS(5973),
    [anon_sym_ELSE] = ACTIONS(5973),
    [anon_sym_Else] = ACTIONS(5973),
    [anon_sym_case] = ACTIONS(5973),
    [anon_sym_CASE] = ACTIONS(5973),
    [anon_sym_Case] = ACTIONS(5973),
    [anon_sym_for] = ACTIONS(5973),
    [anon_sym_FOR] = ACTIONS(5973),
    [anon_sym_For] = ACTIONS(5973),
    [anon_sym_foreach] = ACTIONS(5973),
    [anon_sym_FOREACH] = ACTIONS(5973),
    [anon_sym_Foreach] = ACTIONS(5973),
    [anon_sym_while] = ACTIONS(5973),
    [anon_sym_WHILE] = ACTIONS(5973),
    [anon_sym_While] = ACTIONS(5973),
    [anon_sym_repeat] = ACTIONS(5973),
    [anon_sym_REPEAT] = ACTIONS(5973),
    [anon_sym_Repeat] = ACTIONS(5973),
    [anon_sym_exit] = ACTIONS(5973),
    [anon_sym_EXIT] = ACTIONS(5973),
    [anon_sym_Exit] = ACTIONS(5973),
    [anon_sym_continue] = ACTIONS(5973),
    [anon_sym_CONTINUE] = ACTIONS(5973),
    [anon_sym_Continue] = ACTIONS(5973),
    [anon_sym_break] = ACTIONS(5973),
    [anon_sym_BREAK] = ACTIONS(5973),
    [anon_sym_Break] = ACTIONS(5973),
    [anon_sym_with] = ACTIONS(5973),
    [anon_sym_WITH] = ACTIONS(5973),
    [anon_sym_With] = ACTIONS(5973),
    [sym_asserterror_keyword] = ACTIONS(5975),
    [sym_page_keyword] = ACTIONS(5973),
    [anon_sym_codeunit] = ACTIONS(5973),
    [anon_sym_CODEUNIT] = ACTIONS(5973),
    [anon_sym_Codeunit] = ACTIONS(5973),
    [anon_sym_CodeUnit] = ACTIONS(5973),
    [anon_sym_COdeunit] = ACTIONS(5973),
    [anon_sym_codeUnit] = ACTIONS(5973),
    [sym_report_keyword] = ACTIONS(5973),
    [sym_query_keyword] = ACTIONS(5973),
    [anon_sym_xmlport] = ACTIONS(5973),
    [anon_sym_XMLPORT] = ACTIONS(5973),
    [anon_sym_Xmlport] = ACTIONS(5973),
    [anon_sym_XMLport] = ACTIONS(5973),
    [anon_sym_XMLPort] = ACTIONS(5973),
    [anon_sym_XmlPort] = ACTIONS(5973),
    [anon_sym_enum] = ACTIONS(5973),
    [anon_sym_ENUM] = ACTIONS(5973),
    [anon_sym_Enum] = ACTIONS(5973),
    [anon_sym_eNUM] = ACTIONS(5973),
    [anon_sym_eNum] = ACTIONS(5973),
    [anon_sym_ENum] = ACTIONS(5973),
    [sym_quoted_identifier] = ACTIONS(5975),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5975),
    [sym_verbatim_string] = ACTIONS(5975),
    [sym_integer] = ACTIONS(5973),
    [sym_continue_as_identifier] = ACTIONS(5975),
    [sym_preproc_open] = ACTIONS(5975),
    [sym_end_keyword] = ACTIONS(5975),
  },
  [STATE(3216)] = {
    [sym_identifier] = ACTIONS(5855),
    [anon_sym_SEMI] = ACTIONS(5857),
    [anon_sym_DASH] = ACTIONS(5857),
    [aux_sym_boolean_token1] = ACTIONS(5855),
    [aux_sym_boolean_token2] = ACTIONS(5855),
    [sym_decimal] = ACTIONS(5855),
    [anon_sym_LPAREN] = ACTIONS(5857),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5855),
    [anon_sym_LBRACK] = ACTIONS(5857),
    [aux_sym_record_type_token1] = ACTIONS(5855),
    [aux_sym_basic_type_token21] = ACTIONS(5855),
    [aux_sym_basic_type_token22] = ACTIONS(5855),
    [aux_sym_basic_type_token48] = ACTIONS(5855),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5855),
    [anon_sym_POUNDif] = ACTIONS(5857),
    [anon_sym_POUNDIF] = ACTIONS(5857),
    [anon_sym_POUNDIf] = ACTIONS(5857),
    [anon_sym_not] = ACTIONS(5855),
    [anon_sym_NOT] = ACTIONS(5855),
    [anon_sym_Not] = ACTIONS(5855),
    [anon_sym_POUNDelse] = ACTIONS(5857),
    [anon_sym_POUNDELSE] = ACTIONS(5857),
    [anon_sym_POUNDElse] = ACTIONS(5857),
    [anon_sym_POUNDelse2] = ACTIONS(5857),
    [anon_sym_POUNDELSE2] = ACTIONS(5857),
    [anon_sym_POUNDElse2] = ACTIONS(5857),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5855),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5855),
    [anon_sym_PLUS] = ACTIONS(5857),
    [sym_datetime_literal] = ACTIONS(5857),
    [sym_date_literal] = ACTIONS(5855),
    [sym_time_literal] = ACTIONS(5855),
    [sym_biginteger_literal] = ACTIONS(5857),
    [anon_sym_if] = ACTIONS(5855),
    [anon_sym_IF] = ACTIONS(5855),
    [anon_sym_If] = ACTIONS(5855),
    [anon_sym_else] = ACTIONS(5855),
    [anon_sym_ELSE] = ACTIONS(5855),
    [anon_sym_Else] = ACTIONS(5855),
    [anon_sym_case] = ACTIONS(5855),
    [anon_sym_CASE] = ACTIONS(5855),
    [anon_sym_Case] = ACTIONS(5855),
    [anon_sym_for] = ACTIONS(5855),
    [anon_sym_FOR] = ACTIONS(5855),
    [anon_sym_For] = ACTIONS(5855),
    [anon_sym_foreach] = ACTIONS(5855),
    [anon_sym_FOREACH] = ACTIONS(5855),
    [anon_sym_Foreach] = ACTIONS(5855),
    [anon_sym_while] = ACTIONS(5855),
    [anon_sym_WHILE] = ACTIONS(5855),
    [anon_sym_While] = ACTIONS(5855),
    [anon_sym_repeat] = ACTIONS(5855),
    [anon_sym_REPEAT] = ACTIONS(5855),
    [anon_sym_Repeat] = ACTIONS(5855),
    [anon_sym_exit] = ACTIONS(5855),
    [anon_sym_EXIT] = ACTIONS(5855),
    [anon_sym_Exit] = ACTIONS(5855),
    [anon_sym_continue] = ACTIONS(5855),
    [anon_sym_CONTINUE] = ACTIONS(5855),
    [anon_sym_Continue] = ACTIONS(5855),
    [anon_sym_break] = ACTIONS(5855),
    [anon_sym_BREAK] = ACTIONS(5855),
    [anon_sym_Break] = ACTIONS(5855),
    [anon_sym_with] = ACTIONS(5855),
    [anon_sym_WITH] = ACTIONS(5855),
    [anon_sym_With] = ACTIONS(5855),
    [sym_asserterror_keyword] = ACTIONS(5857),
    [sym_page_keyword] = ACTIONS(5855),
    [anon_sym_codeunit] = ACTIONS(5855),
    [anon_sym_CODEUNIT] = ACTIONS(5855),
    [anon_sym_Codeunit] = ACTIONS(5855),
    [anon_sym_CodeUnit] = ACTIONS(5855),
    [anon_sym_COdeunit] = ACTIONS(5855),
    [anon_sym_codeUnit] = ACTIONS(5855),
    [sym_report_keyword] = ACTIONS(5855),
    [sym_query_keyword] = ACTIONS(5855),
    [anon_sym_xmlport] = ACTIONS(5855),
    [anon_sym_XMLPORT] = ACTIONS(5855),
    [anon_sym_Xmlport] = ACTIONS(5855),
    [anon_sym_XMLport] = ACTIONS(5855),
    [anon_sym_XMLPort] = ACTIONS(5855),
    [anon_sym_XmlPort] = ACTIONS(5855),
    [anon_sym_enum] = ACTIONS(5855),
    [anon_sym_ENUM] = ACTIONS(5855),
    [anon_sym_Enum] = ACTIONS(5855),
    [anon_sym_eNUM] = ACTIONS(5855),
    [anon_sym_eNum] = ACTIONS(5855),
    [anon_sym_ENum] = ACTIONS(5855),
    [sym_quoted_identifier] = ACTIONS(5857),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5857),
    [sym_verbatim_string] = ACTIONS(5857),
    [sym_integer] = ACTIONS(5855),
    [sym_continue_as_identifier] = ACTIONS(5857),
    [sym_preproc_open] = ACTIONS(5857),
    [sym_end_keyword] = ACTIONS(5857),
  },
  [STATE(3217)] = {
    [sym_identifier] = ACTIONS(6058),
    [anon_sym_SEMI] = ACTIONS(6060),
    [anon_sym_DASH] = ACTIONS(6060),
    [aux_sym_boolean_token1] = ACTIONS(6058),
    [aux_sym_boolean_token2] = ACTIONS(6058),
    [sym_decimal] = ACTIONS(6058),
    [anon_sym_LPAREN] = ACTIONS(6060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6058),
    [anon_sym_LBRACK] = ACTIONS(6060),
    [aux_sym_record_type_token1] = ACTIONS(6058),
    [aux_sym_basic_type_token21] = ACTIONS(6058),
    [aux_sym_basic_type_token22] = ACTIONS(6058),
    [aux_sym_basic_type_token48] = ACTIONS(6058),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6058),
    [anon_sym_POUNDif] = ACTIONS(6060),
    [anon_sym_POUNDIF] = ACTIONS(6060),
    [anon_sym_POUNDIf] = ACTIONS(6060),
    [anon_sym_not] = ACTIONS(6058),
    [anon_sym_NOT] = ACTIONS(6058),
    [anon_sym_Not] = ACTIONS(6058),
    [anon_sym_POUNDelse] = ACTIONS(6060),
    [anon_sym_POUNDELSE] = ACTIONS(6060),
    [anon_sym_POUNDElse] = ACTIONS(6060),
    [anon_sym_POUNDelse2] = ACTIONS(6060),
    [anon_sym_POUNDELSE2] = ACTIONS(6060),
    [anon_sym_POUNDElse2] = ACTIONS(6060),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6058),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6058),
    [anon_sym_PLUS] = ACTIONS(6060),
    [sym_datetime_literal] = ACTIONS(6060),
    [sym_date_literal] = ACTIONS(6058),
    [sym_time_literal] = ACTIONS(6058),
    [sym_biginteger_literal] = ACTIONS(6060),
    [anon_sym_if] = ACTIONS(6058),
    [anon_sym_IF] = ACTIONS(6058),
    [anon_sym_If] = ACTIONS(6058),
    [anon_sym_else] = ACTIONS(6058),
    [anon_sym_ELSE] = ACTIONS(6058),
    [anon_sym_Else] = ACTIONS(6058),
    [anon_sym_case] = ACTIONS(6058),
    [anon_sym_CASE] = ACTIONS(6058),
    [anon_sym_Case] = ACTIONS(6058),
    [anon_sym_for] = ACTIONS(6058),
    [anon_sym_FOR] = ACTIONS(6058),
    [anon_sym_For] = ACTIONS(6058),
    [anon_sym_foreach] = ACTIONS(6058),
    [anon_sym_FOREACH] = ACTIONS(6058),
    [anon_sym_Foreach] = ACTIONS(6058),
    [anon_sym_while] = ACTIONS(6058),
    [anon_sym_WHILE] = ACTIONS(6058),
    [anon_sym_While] = ACTIONS(6058),
    [anon_sym_repeat] = ACTIONS(6058),
    [anon_sym_REPEAT] = ACTIONS(6058),
    [anon_sym_Repeat] = ACTIONS(6058),
    [anon_sym_exit] = ACTIONS(6058),
    [anon_sym_EXIT] = ACTIONS(6058),
    [anon_sym_Exit] = ACTIONS(6058),
    [anon_sym_continue] = ACTIONS(6058),
    [anon_sym_CONTINUE] = ACTIONS(6058),
    [anon_sym_Continue] = ACTIONS(6058),
    [anon_sym_break] = ACTIONS(6058),
    [anon_sym_BREAK] = ACTIONS(6058),
    [anon_sym_Break] = ACTIONS(6058),
    [anon_sym_with] = ACTIONS(6058),
    [anon_sym_WITH] = ACTIONS(6058),
    [anon_sym_With] = ACTIONS(6058),
    [sym_asserterror_keyword] = ACTIONS(6060),
    [sym_page_keyword] = ACTIONS(6058),
    [anon_sym_codeunit] = ACTIONS(6058),
    [anon_sym_CODEUNIT] = ACTIONS(6058),
    [anon_sym_Codeunit] = ACTIONS(6058),
    [anon_sym_CodeUnit] = ACTIONS(6058),
    [anon_sym_COdeunit] = ACTIONS(6058),
    [anon_sym_codeUnit] = ACTIONS(6058),
    [sym_report_keyword] = ACTIONS(6058),
    [sym_query_keyword] = ACTIONS(6058),
    [anon_sym_xmlport] = ACTIONS(6058),
    [anon_sym_XMLPORT] = ACTIONS(6058),
    [anon_sym_Xmlport] = ACTIONS(6058),
    [anon_sym_XMLport] = ACTIONS(6058),
    [anon_sym_XMLPort] = ACTIONS(6058),
    [anon_sym_XmlPort] = ACTIONS(6058),
    [anon_sym_enum] = ACTIONS(6058),
    [anon_sym_ENUM] = ACTIONS(6058),
    [anon_sym_Enum] = ACTIONS(6058),
    [anon_sym_eNUM] = ACTIONS(6058),
    [anon_sym_eNum] = ACTIONS(6058),
    [anon_sym_ENum] = ACTIONS(6058),
    [sym_quoted_identifier] = ACTIONS(6060),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6060),
    [sym_verbatim_string] = ACTIONS(6060),
    [sym_integer] = ACTIONS(6058),
    [sym_continue_as_identifier] = ACTIONS(6060),
    [sym_preproc_open] = ACTIONS(6060),
    [sym_end_keyword] = ACTIONS(6060),
  },
  [STATE(3218)] = {
    [sym_identifier] = ACTIONS(6062),
    [anon_sym_SEMI] = ACTIONS(6064),
    [anon_sym_DASH] = ACTIONS(6064),
    [aux_sym_boolean_token1] = ACTIONS(6062),
    [aux_sym_boolean_token2] = ACTIONS(6062),
    [sym_decimal] = ACTIONS(6062),
    [anon_sym_LPAREN] = ACTIONS(6064),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6062),
    [anon_sym_LBRACK] = ACTIONS(6064),
    [aux_sym_record_type_token1] = ACTIONS(6062),
    [aux_sym_basic_type_token21] = ACTIONS(6062),
    [aux_sym_basic_type_token22] = ACTIONS(6062),
    [aux_sym_basic_type_token48] = ACTIONS(6062),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6062),
    [anon_sym_POUNDif] = ACTIONS(6064),
    [anon_sym_POUNDIF] = ACTIONS(6064),
    [anon_sym_POUNDIf] = ACTIONS(6064),
    [anon_sym_not] = ACTIONS(6062),
    [anon_sym_NOT] = ACTIONS(6062),
    [anon_sym_Not] = ACTIONS(6062),
    [anon_sym_POUNDelse] = ACTIONS(6064),
    [anon_sym_POUNDELSE] = ACTIONS(6064),
    [anon_sym_POUNDElse] = ACTIONS(6064),
    [anon_sym_POUNDelse2] = ACTIONS(6064),
    [anon_sym_POUNDELSE2] = ACTIONS(6064),
    [anon_sym_POUNDElse2] = ACTIONS(6064),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6062),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6062),
    [anon_sym_PLUS] = ACTIONS(6064),
    [sym_datetime_literal] = ACTIONS(6064),
    [sym_date_literal] = ACTIONS(6062),
    [sym_time_literal] = ACTIONS(6062),
    [sym_biginteger_literal] = ACTIONS(6064),
    [anon_sym_if] = ACTIONS(6062),
    [anon_sym_IF] = ACTIONS(6062),
    [anon_sym_If] = ACTIONS(6062),
    [anon_sym_else] = ACTIONS(6062),
    [anon_sym_ELSE] = ACTIONS(6062),
    [anon_sym_Else] = ACTIONS(6062),
    [anon_sym_case] = ACTIONS(6062),
    [anon_sym_CASE] = ACTIONS(6062),
    [anon_sym_Case] = ACTIONS(6062),
    [anon_sym_for] = ACTIONS(6062),
    [anon_sym_FOR] = ACTIONS(6062),
    [anon_sym_For] = ACTIONS(6062),
    [anon_sym_foreach] = ACTIONS(6062),
    [anon_sym_FOREACH] = ACTIONS(6062),
    [anon_sym_Foreach] = ACTIONS(6062),
    [anon_sym_while] = ACTIONS(6062),
    [anon_sym_WHILE] = ACTIONS(6062),
    [anon_sym_While] = ACTIONS(6062),
    [anon_sym_repeat] = ACTIONS(6062),
    [anon_sym_REPEAT] = ACTIONS(6062),
    [anon_sym_Repeat] = ACTIONS(6062),
    [anon_sym_exit] = ACTIONS(6062),
    [anon_sym_EXIT] = ACTIONS(6062),
    [anon_sym_Exit] = ACTIONS(6062),
    [anon_sym_continue] = ACTIONS(6062),
    [anon_sym_CONTINUE] = ACTIONS(6062),
    [anon_sym_Continue] = ACTIONS(6062),
    [anon_sym_break] = ACTIONS(6062),
    [anon_sym_BREAK] = ACTIONS(6062),
    [anon_sym_Break] = ACTIONS(6062),
    [anon_sym_with] = ACTIONS(6062),
    [anon_sym_WITH] = ACTIONS(6062),
    [anon_sym_With] = ACTIONS(6062),
    [sym_asserterror_keyword] = ACTIONS(6064),
    [sym_page_keyword] = ACTIONS(6062),
    [anon_sym_codeunit] = ACTIONS(6062),
    [anon_sym_CODEUNIT] = ACTIONS(6062),
    [anon_sym_Codeunit] = ACTIONS(6062),
    [anon_sym_CodeUnit] = ACTIONS(6062),
    [anon_sym_COdeunit] = ACTIONS(6062),
    [anon_sym_codeUnit] = ACTIONS(6062),
    [sym_report_keyword] = ACTIONS(6062),
    [sym_query_keyword] = ACTIONS(6062),
    [anon_sym_xmlport] = ACTIONS(6062),
    [anon_sym_XMLPORT] = ACTIONS(6062),
    [anon_sym_Xmlport] = ACTIONS(6062),
    [anon_sym_XMLport] = ACTIONS(6062),
    [anon_sym_XMLPort] = ACTIONS(6062),
    [anon_sym_XmlPort] = ACTIONS(6062),
    [anon_sym_enum] = ACTIONS(6062),
    [anon_sym_ENUM] = ACTIONS(6062),
    [anon_sym_Enum] = ACTIONS(6062),
    [anon_sym_eNUM] = ACTIONS(6062),
    [anon_sym_eNum] = ACTIONS(6062),
    [anon_sym_ENum] = ACTIONS(6062),
    [sym_quoted_identifier] = ACTIONS(6064),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6064),
    [sym_verbatim_string] = ACTIONS(6064),
    [sym_integer] = ACTIONS(6062),
    [sym_continue_as_identifier] = ACTIONS(6064),
    [sym_preproc_open] = ACTIONS(6064),
    [sym_end_keyword] = ACTIONS(6064),
  },
  [STATE(3219)] = {
    [sym_identifier] = ACTIONS(6058),
    [anon_sym_SEMI] = ACTIONS(6060),
    [anon_sym_DASH] = ACTIONS(6060),
    [aux_sym_boolean_token1] = ACTIONS(6058),
    [aux_sym_boolean_token2] = ACTIONS(6058),
    [sym_decimal] = ACTIONS(6058),
    [anon_sym_LPAREN] = ACTIONS(6060),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6058),
    [anon_sym_LBRACK] = ACTIONS(6060),
    [aux_sym_record_type_token1] = ACTIONS(6058),
    [aux_sym_basic_type_token21] = ACTIONS(6058),
    [aux_sym_basic_type_token22] = ACTIONS(6058),
    [aux_sym_basic_type_token48] = ACTIONS(6058),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6058),
    [anon_sym_POUNDif] = ACTIONS(6060),
    [anon_sym_POUNDIF] = ACTIONS(6060),
    [anon_sym_POUNDIf] = ACTIONS(6060),
    [anon_sym_not] = ACTIONS(6058),
    [anon_sym_NOT] = ACTIONS(6058),
    [anon_sym_Not] = ACTIONS(6058),
    [anon_sym_POUNDelse] = ACTIONS(6060),
    [anon_sym_POUNDELSE] = ACTIONS(6060),
    [anon_sym_POUNDElse] = ACTIONS(6060),
    [anon_sym_POUNDelse2] = ACTIONS(6060),
    [anon_sym_POUNDELSE2] = ACTIONS(6060),
    [anon_sym_POUNDElse2] = ACTIONS(6060),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6058),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6058),
    [anon_sym_PLUS] = ACTIONS(6060),
    [sym_datetime_literal] = ACTIONS(6060),
    [sym_date_literal] = ACTIONS(6058),
    [sym_time_literal] = ACTIONS(6058),
    [sym_biginteger_literal] = ACTIONS(6060),
    [anon_sym_if] = ACTIONS(6058),
    [anon_sym_IF] = ACTIONS(6058),
    [anon_sym_If] = ACTIONS(6058),
    [anon_sym_else] = ACTIONS(6058),
    [anon_sym_ELSE] = ACTIONS(6058),
    [anon_sym_Else] = ACTIONS(6058),
    [anon_sym_case] = ACTIONS(6058),
    [anon_sym_CASE] = ACTIONS(6058),
    [anon_sym_Case] = ACTIONS(6058),
    [anon_sym_for] = ACTIONS(6058),
    [anon_sym_FOR] = ACTIONS(6058),
    [anon_sym_For] = ACTIONS(6058),
    [anon_sym_foreach] = ACTIONS(6058),
    [anon_sym_FOREACH] = ACTIONS(6058),
    [anon_sym_Foreach] = ACTIONS(6058),
    [anon_sym_while] = ACTIONS(6058),
    [anon_sym_WHILE] = ACTIONS(6058),
    [anon_sym_While] = ACTIONS(6058),
    [anon_sym_repeat] = ACTIONS(6058),
    [anon_sym_REPEAT] = ACTIONS(6058),
    [anon_sym_Repeat] = ACTIONS(6058),
    [anon_sym_exit] = ACTIONS(6058),
    [anon_sym_EXIT] = ACTIONS(6058),
    [anon_sym_Exit] = ACTIONS(6058),
    [anon_sym_continue] = ACTIONS(6058),
    [anon_sym_CONTINUE] = ACTIONS(6058),
    [anon_sym_Continue] = ACTIONS(6058),
    [anon_sym_break] = ACTIONS(6058),
    [anon_sym_BREAK] = ACTIONS(6058),
    [anon_sym_Break] = ACTIONS(6058),
    [anon_sym_with] = ACTIONS(6058),
    [anon_sym_WITH] = ACTIONS(6058),
    [anon_sym_With] = ACTIONS(6058),
    [sym_asserterror_keyword] = ACTIONS(6060),
    [sym_page_keyword] = ACTIONS(6058),
    [anon_sym_codeunit] = ACTIONS(6058),
    [anon_sym_CODEUNIT] = ACTIONS(6058),
    [anon_sym_Codeunit] = ACTIONS(6058),
    [anon_sym_CodeUnit] = ACTIONS(6058),
    [anon_sym_COdeunit] = ACTIONS(6058),
    [anon_sym_codeUnit] = ACTIONS(6058),
    [sym_report_keyword] = ACTIONS(6058),
    [sym_query_keyword] = ACTIONS(6058),
    [anon_sym_xmlport] = ACTIONS(6058),
    [anon_sym_XMLPORT] = ACTIONS(6058),
    [anon_sym_Xmlport] = ACTIONS(6058),
    [anon_sym_XMLport] = ACTIONS(6058),
    [anon_sym_XMLPort] = ACTIONS(6058),
    [anon_sym_XmlPort] = ACTIONS(6058),
    [anon_sym_enum] = ACTIONS(6058),
    [anon_sym_ENUM] = ACTIONS(6058),
    [anon_sym_Enum] = ACTIONS(6058),
    [anon_sym_eNUM] = ACTIONS(6058),
    [anon_sym_eNum] = ACTIONS(6058),
    [anon_sym_ENum] = ACTIONS(6058),
    [sym_quoted_identifier] = ACTIONS(6060),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6060),
    [sym_verbatim_string] = ACTIONS(6060),
    [sym_integer] = ACTIONS(6058),
    [sym_continue_as_identifier] = ACTIONS(6060),
    [sym_preproc_open] = ACTIONS(6060),
    [sym_end_keyword] = ACTIONS(6060),
  },
  [STATE(3220)] = {
    [sym_identifier] = ACTIONS(6066),
    [anon_sym_SEMI] = ACTIONS(6068),
    [anon_sym_DASH] = ACTIONS(6068),
    [aux_sym_boolean_token1] = ACTIONS(6066),
    [aux_sym_boolean_token2] = ACTIONS(6066),
    [sym_decimal] = ACTIONS(6066),
    [anon_sym_LPAREN] = ACTIONS(6068),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6066),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [aux_sym_record_type_token1] = ACTIONS(6066),
    [aux_sym_basic_type_token21] = ACTIONS(6066),
    [aux_sym_basic_type_token22] = ACTIONS(6066),
    [aux_sym_basic_type_token48] = ACTIONS(6066),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6066),
    [anon_sym_POUNDif] = ACTIONS(6068),
    [anon_sym_POUNDIF] = ACTIONS(6068),
    [anon_sym_POUNDIf] = ACTIONS(6068),
    [anon_sym_not] = ACTIONS(6066),
    [anon_sym_NOT] = ACTIONS(6066),
    [anon_sym_Not] = ACTIONS(6066),
    [anon_sym_POUNDelse] = ACTIONS(6068),
    [anon_sym_POUNDELSE] = ACTIONS(6068),
    [anon_sym_POUNDElse] = ACTIONS(6068),
    [anon_sym_POUNDelse2] = ACTIONS(6068),
    [anon_sym_POUNDELSE2] = ACTIONS(6068),
    [anon_sym_POUNDElse2] = ACTIONS(6068),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6066),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6066),
    [anon_sym_PLUS] = ACTIONS(6068),
    [sym_datetime_literal] = ACTIONS(6068),
    [sym_date_literal] = ACTIONS(6066),
    [sym_time_literal] = ACTIONS(6066),
    [sym_biginteger_literal] = ACTIONS(6068),
    [anon_sym_if] = ACTIONS(6066),
    [anon_sym_IF] = ACTIONS(6066),
    [anon_sym_If] = ACTIONS(6066),
    [anon_sym_else] = ACTIONS(6066),
    [anon_sym_ELSE] = ACTIONS(6066),
    [anon_sym_Else] = ACTIONS(6066),
    [anon_sym_case] = ACTIONS(6066),
    [anon_sym_CASE] = ACTIONS(6066),
    [anon_sym_Case] = ACTIONS(6066),
    [anon_sym_for] = ACTIONS(6066),
    [anon_sym_FOR] = ACTIONS(6066),
    [anon_sym_For] = ACTIONS(6066),
    [anon_sym_foreach] = ACTIONS(6066),
    [anon_sym_FOREACH] = ACTIONS(6066),
    [anon_sym_Foreach] = ACTIONS(6066),
    [anon_sym_while] = ACTIONS(6066),
    [anon_sym_WHILE] = ACTIONS(6066),
    [anon_sym_While] = ACTIONS(6066),
    [anon_sym_repeat] = ACTIONS(6066),
    [anon_sym_REPEAT] = ACTIONS(6066),
    [anon_sym_Repeat] = ACTIONS(6066),
    [anon_sym_exit] = ACTIONS(6066),
    [anon_sym_EXIT] = ACTIONS(6066),
    [anon_sym_Exit] = ACTIONS(6066),
    [anon_sym_continue] = ACTIONS(6066),
    [anon_sym_CONTINUE] = ACTIONS(6066),
    [anon_sym_Continue] = ACTIONS(6066),
    [anon_sym_break] = ACTIONS(6066),
    [anon_sym_BREAK] = ACTIONS(6066),
    [anon_sym_Break] = ACTIONS(6066),
    [anon_sym_with] = ACTIONS(6066),
    [anon_sym_WITH] = ACTIONS(6066),
    [anon_sym_With] = ACTIONS(6066),
    [sym_asserterror_keyword] = ACTIONS(6068),
    [sym_page_keyword] = ACTIONS(6066),
    [anon_sym_codeunit] = ACTIONS(6066),
    [anon_sym_CODEUNIT] = ACTIONS(6066),
    [anon_sym_Codeunit] = ACTIONS(6066),
    [anon_sym_CodeUnit] = ACTIONS(6066),
    [anon_sym_COdeunit] = ACTIONS(6066),
    [anon_sym_codeUnit] = ACTIONS(6066),
    [sym_report_keyword] = ACTIONS(6066),
    [sym_query_keyword] = ACTIONS(6066),
    [anon_sym_xmlport] = ACTIONS(6066),
    [anon_sym_XMLPORT] = ACTIONS(6066),
    [anon_sym_Xmlport] = ACTIONS(6066),
    [anon_sym_XMLport] = ACTIONS(6066),
    [anon_sym_XMLPort] = ACTIONS(6066),
    [anon_sym_XmlPort] = ACTIONS(6066),
    [anon_sym_enum] = ACTIONS(6066),
    [anon_sym_ENUM] = ACTIONS(6066),
    [anon_sym_Enum] = ACTIONS(6066),
    [anon_sym_eNUM] = ACTIONS(6066),
    [anon_sym_eNum] = ACTIONS(6066),
    [anon_sym_ENum] = ACTIONS(6066),
    [sym_quoted_identifier] = ACTIONS(6068),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6068),
    [sym_verbatim_string] = ACTIONS(6068),
    [sym_integer] = ACTIONS(6066),
    [sym_continue_as_identifier] = ACTIONS(6068),
    [sym_preproc_open] = ACTIONS(6068),
    [sym_end_keyword] = ACTIONS(6068),
  },
  [STATE(3221)] = {
    [sym_identifier] = ACTIONS(6276),
    [anon_sym_SEMI] = ACTIONS(6278),
    [anon_sym_DASH] = ACTIONS(6278),
    [aux_sym_boolean_token1] = ACTIONS(6276),
    [aux_sym_boolean_token2] = ACTIONS(6276),
    [sym_decimal] = ACTIONS(6276),
    [anon_sym_LPAREN] = ACTIONS(6278),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6276),
    [anon_sym_LBRACK] = ACTIONS(6278),
    [aux_sym_record_type_token1] = ACTIONS(6276),
    [aux_sym_basic_type_token21] = ACTIONS(6276),
    [aux_sym_basic_type_token22] = ACTIONS(6276),
    [aux_sym_basic_type_token48] = ACTIONS(6276),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6276),
    [anon_sym_POUNDif] = ACTIONS(6278),
    [anon_sym_POUNDIF] = ACTIONS(6278),
    [anon_sym_POUNDIf] = ACTIONS(6278),
    [anon_sym_not] = ACTIONS(6276),
    [anon_sym_NOT] = ACTIONS(6276),
    [anon_sym_Not] = ACTIONS(6276),
    [anon_sym_POUNDelse] = ACTIONS(6278),
    [anon_sym_POUNDELSE] = ACTIONS(6278),
    [anon_sym_POUNDElse] = ACTIONS(6278),
    [anon_sym_POUNDelse2] = ACTIONS(6278),
    [anon_sym_POUNDELSE2] = ACTIONS(6278),
    [anon_sym_POUNDElse2] = ACTIONS(6278),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6276),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6276),
    [anon_sym_PLUS] = ACTIONS(6278),
    [sym_datetime_literal] = ACTIONS(6278),
    [sym_date_literal] = ACTIONS(6276),
    [sym_time_literal] = ACTIONS(6276),
    [sym_biginteger_literal] = ACTIONS(6278),
    [anon_sym_if] = ACTIONS(6276),
    [anon_sym_IF] = ACTIONS(6276),
    [anon_sym_If] = ACTIONS(6276),
    [anon_sym_else] = ACTIONS(6276),
    [anon_sym_ELSE] = ACTIONS(6276),
    [anon_sym_Else] = ACTIONS(6276),
    [anon_sym_case] = ACTIONS(6276),
    [anon_sym_CASE] = ACTIONS(6276),
    [anon_sym_Case] = ACTIONS(6276),
    [anon_sym_for] = ACTIONS(6276),
    [anon_sym_FOR] = ACTIONS(6276),
    [anon_sym_For] = ACTIONS(6276),
    [anon_sym_foreach] = ACTIONS(6276),
    [anon_sym_FOREACH] = ACTIONS(6276),
    [anon_sym_Foreach] = ACTIONS(6276),
    [anon_sym_while] = ACTIONS(6276),
    [anon_sym_WHILE] = ACTIONS(6276),
    [anon_sym_While] = ACTIONS(6276),
    [anon_sym_repeat] = ACTIONS(6276),
    [anon_sym_REPEAT] = ACTIONS(6276),
    [anon_sym_Repeat] = ACTIONS(6276),
    [anon_sym_exit] = ACTIONS(6276),
    [anon_sym_EXIT] = ACTIONS(6276),
    [anon_sym_Exit] = ACTIONS(6276),
    [anon_sym_continue] = ACTIONS(6276),
    [anon_sym_CONTINUE] = ACTIONS(6276),
    [anon_sym_Continue] = ACTIONS(6276),
    [anon_sym_break] = ACTIONS(6276),
    [anon_sym_BREAK] = ACTIONS(6276),
    [anon_sym_Break] = ACTIONS(6276),
    [anon_sym_with] = ACTIONS(6276),
    [anon_sym_WITH] = ACTIONS(6276),
    [anon_sym_With] = ACTIONS(6276),
    [sym_asserterror_keyword] = ACTIONS(6278),
    [sym_page_keyword] = ACTIONS(6276),
    [anon_sym_codeunit] = ACTIONS(6276),
    [anon_sym_CODEUNIT] = ACTIONS(6276),
    [anon_sym_Codeunit] = ACTIONS(6276),
    [anon_sym_CodeUnit] = ACTIONS(6276),
    [anon_sym_COdeunit] = ACTIONS(6276),
    [anon_sym_codeUnit] = ACTIONS(6276),
    [sym_report_keyword] = ACTIONS(6276),
    [sym_query_keyword] = ACTIONS(6276),
    [anon_sym_xmlport] = ACTIONS(6276),
    [anon_sym_XMLPORT] = ACTIONS(6276),
    [anon_sym_Xmlport] = ACTIONS(6276),
    [anon_sym_XMLport] = ACTIONS(6276),
    [anon_sym_XMLPort] = ACTIONS(6276),
    [anon_sym_XmlPort] = ACTIONS(6276),
    [anon_sym_enum] = ACTIONS(6276),
    [anon_sym_ENUM] = ACTIONS(6276),
    [anon_sym_Enum] = ACTIONS(6276),
    [anon_sym_eNUM] = ACTIONS(6276),
    [anon_sym_eNum] = ACTIONS(6276),
    [anon_sym_ENum] = ACTIONS(6276),
    [sym_quoted_identifier] = ACTIONS(6278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6278),
    [sym_verbatim_string] = ACTIONS(6278),
    [sym_integer] = ACTIONS(6276),
    [sym_continue_as_identifier] = ACTIONS(6278),
    [sym_preproc_open] = ACTIONS(6278),
    [sym_end_keyword] = ACTIONS(6278),
  },
  [STATE(3222)] = {
    [sym_identifier] = ACTIONS(6304),
    [anon_sym_SEMI] = ACTIONS(6306),
    [anon_sym_DASH] = ACTIONS(6306),
    [aux_sym_boolean_token1] = ACTIONS(6304),
    [aux_sym_boolean_token2] = ACTIONS(6304),
    [sym_decimal] = ACTIONS(6304),
    [anon_sym_LPAREN] = ACTIONS(6306),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6304),
    [anon_sym_LBRACK] = ACTIONS(6306),
    [aux_sym_record_type_token1] = ACTIONS(6304),
    [aux_sym_basic_type_token21] = ACTIONS(6304),
    [aux_sym_basic_type_token22] = ACTIONS(6304),
    [aux_sym_basic_type_token48] = ACTIONS(6304),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6304),
    [anon_sym_POUNDif] = ACTIONS(6306),
    [anon_sym_POUNDIF] = ACTIONS(6306),
    [anon_sym_POUNDIf] = ACTIONS(6306),
    [anon_sym_not] = ACTIONS(6304),
    [anon_sym_NOT] = ACTIONS(6304),
    [anon_sym_Not] = ACTIONS(6304),
    [anon_sym_POUNDelse] = ACTIONS(6306),
    [anon_sym_POUNDELSE] = ACTIONS(6306),
    [anon_sym_POUNDElse] = ACTIONS(6306),
    [anon_sym_POUNDelse2] = ACTIONS(6306),
    [anon_sym_POUNDELSE2] = ACTIONS(6306),
    [anon_sym_POUNDElse2] = ACTIONS(6306),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6304),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6304),
    [anon_sym_PLUS] = ACTIONS(6306),
    [sym_datetime_literal] = ACTIONS(6306),
    [sym_date_literal] = ACTIONS(6304),
    [sym_time_literal] = ACTIONS(6304),
    [sym_biginteger_literal] = ACTIONS(6306),
    [anon_sym_if] = ACTIONS(6304),
    [anon_sym_IF] = ACTIONS(6304),
    [anon_sym_If] = ACTIONS(6304),
    [anon_sym_else] = ACTIONS(6304),
    [anon_sym_ELSE] = ACTIONS(6304),
    [anon_sym_Else] = ACTIONS(6304),
    [anon_sym_case] = ACTIONS(6304),
    [anon_sym_CASE] = ACTIONS(6304),
    [anon_sym_Case] = ACTIONS(6304),
    [anon_sym_for] = ACTIONS(6304),
    [anon_sym_FOR] = ACTIONS(6304),
    [anon_sym_For] = ACTIONS(6304),
    [anon_sym_foreach] = ACTIONS(6304),
    [anon_sym_FOREACH] = ACTIONS(6304),
    [anon_sym_Foreach] = ACTIONS(6304),
    [anon_sym_while] = ACTIONS(6304),
    [anon_sym_WHILE] = ACTIONS(6304),
    [anon_sym_While] = ACTIONS(6304),
    [anon_sym_repeat] = ACTIONS(6304),
    [anon_sym_REPEAT] = ACTIONS(6304),
    [anon_sym_Repeat] = ACTIONS(6304),
    [anon_sym_exit] = ACTIONS(6304),
    [anon_sym_EXIT] = ACTIONS(6304),
    [anon_sym_Exit] = ACTIONS(6304),
    [anon_sym_continue] = ACTIONS(6304),
    [anon_sym_CONTINUE] = ACTIONS(6304),
    [anon_sym_Continue] = ACTIONS(6304),
    [anon_sym_break] = ACTIONS(6304),
    [anon_sym_BREAK] = ACTIONS(6304),
    [anon_sym_Break] = ACTIONS(6304),
    [anon_sym_with] = ACTIONS(6304),
    [anon_sym_WITH] = ACTIONS(6304),
    [anon_sym_With] = ACTIONS(6304),
    [sym_asserterror_keyword] = ACTIONS(6306),
    [sym_page_keyword] = ACTIONS(6304),
    [anon_sym_codeunit] = ACTIONS(6304),
    [anon_sym_CODEUNIT] = ACTIONS(6304),
    [anon_sym_Codeunit] = ACTIONS(6304),
    [anon_sym_CodeUnit] = ACTIONS(6304),
    [anon_sym_COdeunit] = ACTIONS(6304),
    [anon_sym_codeUnit] = ACTIONS(6304),
    [sym_report_keyword] = ACTIONS(6304),
    [sym_query_keyword] = ACTIONS(6304),
    [anon_sym_xmlport] = ACTIONS(6304),
    [anon_sym_XMLPORT] = ACTIONS(6304),
    [anon_sym_Xmlport] = ACTIONS(6304),
    [anon_sym_XMLport] = ACTIONS(6304),
    [anon_sym_XMLPort] = ACTIONS(6304),
    [anon_sym_XmlPort] = ACTIONS(6304),
    [anon_sym_enum] = ACTIONS(6304),
    [anon_sym_ENUM] = ACTIONS(6304),
    [anon_sym_Enum] = ACTIONS(6304),
    [anon_sym_eNUM] = ACTIONS(6304),
    [anon_sym_eNum] = ACTIONS(6304),
    [anon_sym_ENum] = ACTIONS(6304),
    [sym_quoted_identifier] = ACTIONS(6306),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6306),
    [sym_verbatim_string] = ACTIONS(6306),
    [sym_integer] = ACTIONS(6304),
    [sym_continue_as_identifier] = ACTIONS(6306),
    [sym_preproc_open] = ACTIONS(6306),
    [sym_end_keyword] = ACTIONS(6306),
  },
  [STATE(3223)] = {
    [sym_identifier] = ACTIONS(6070),
    [anon_sym_SEMI] = ACTIONS(6072),
    [anon_sym_DASH] = ACTIONS(6072),
    [aux_sym_boolean_token1] = ACTIONS(6070),
    [aux_sym_boolean_token2] = ACTIONS(6070),
    [sym_decimal] = ACTIONS(6070),
    [anon_sym_LPAREN] = ACTIONS(6072),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6070),
    [anon_sym_LBRACK] = ACTIONS(6072),
    [aux_sym_record_type_token1] = ACTIONS(6070),
    [aux_sym_basic_type_token21] = ACTIONS(6070),
    [aux_sym_basic_type_token22] = ACTIONS(6070),
    [aux_sym_basic_type_token48] = ACTIONS(6070),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6070),
    [anon_sym_POUNDif] = ACTIONS(6072),
    [anon_sym_POUNDIF] = ACTIONS(6072),
    [anon_sym_POUNDIf] = ACTIONS(6072),
    [anon_sym_not] = ACTIONS(6070),
    [anon_sym_NOT] = ACTIONS(6070),
    [anon_sym_Not] = ACTIONS(6070),
    [anon_sym_POUNDelse] = ACTIONS(6072),
    [anon_sym_POUNDELSE] = ACTIONS(6072),
    [anon_sym_POUNDElse] = ACTIONS(6072),
    [anon_sym_POUNDelse2] = ACTIONS(6072),
    [anon_sym_POUNDELSE2] = ACTIONS(6072),
    [anon_sym_POUNDElse2] = ACTIONS(6072),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6070),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6070),
    [anon_sym_PLUS] = ACTIONS(6072),
    [sym_datetime_literal] = ACTIONS(6072),
    [sym_date_literal] = ACTIONS(6070),
    [sym_time_literal] = ACTIONS(6070),
    [sym_biginteger_literal] = ACTIONS(6072),
    [anon_sym_if] = ACTIONS(6070),
    [anon_sym_IF] = ACTIONS(6070),
    [anon_sym_If] = ACTIONS(6070),
    [anon_sym_else] = ACTIONS(6070),
    [anon_sym_ELSE] = ACTIONS(6070),
    [anon_sym_Else] = ACTIONS(6070),
    [anon_sym_case] = ACTIONS(6070),
    [anon_sym_CASE] = ACTIONS(6070),
    [anon_sym_Case] = ACTIONS(6070),
    [anon_sym_for] = ACTIONS(6070),
    [anon_sym_FOR] = ACTIONS(6070),
    [anon_sym_For] = ACTIONS(6070),
    [anon_sym_foreach] = ACTIONS(6070),
    [anon_sym_FOREACH] = ACTIONS(6070),
    [anon_sym_Foreach] = ACTIONS(6070),
    [anon_sym_while] = ACTIONS(6070),
    [anon_sym_WHILE] = ACTIONS(6070),
    [anon_sym_While] = ACTIONS(6070),
    [anon_sym_repeat] = ACTIONS(6070),
    [anon_sym_REPEAT] = ACTIONS(6070),
    [anon_sym_Repeat] = ACTIONS(6070),
    [anon_sym_exit] = ACTIONS(6070),
    [anon_sym_EXIT] = ACTIONS(6070),
    [anon_sym_Exit] = ACTIONS(6070),
    [anon_sym_continue] = ACTIONS(6070),
    [anon_sym_CONTINUE] = ACTIONS(6070),
    [anon_sym_Continue] = ACTIONS(6070),
    [anon_sym_break] = ACTIONS(6070),
    [anon_sym_BREAK] = ACTIONS(6070),
    [anon_sym_Break] = ACTIONS(6070),
    [anon_sym_with] = ACTIONS(6070),
    [anon_sym_WITH] = ACTIONS(6070),
    [anon_sym_With] = ACTIONS(6070),
    [sym_asserterror_keyword] = ACTIONS(6072),
    [sym_page_keyword] = ACTIONS(6070),
    [anon_sym_codeunit] = ACTIONS(6070),
    [anon_sym_CODEUNIT] = ACTIONS(6070),
    [anon_sym_Codeunit] = ACTIONS(6070),
    [anon_sym_CodeUnit] = ACTIONS(6070),
    [anon_sym_COdeunit] = ACTIONS(6070),
    [anon_sym_codeUnit] = ACTIONS(6070),
    [sym_report_keyword] = ACTIONS(6070),
    [sym_query_keyword] = ACTIONS(6070),
    [anon_sym_xmlport] = ACTIONS(6070),
    [anon_sym_XMLPORT] = ACTIONS(6070),
    [anon_sym_Xmlport] = ACTIONS(6070),
    [anon_sym_XMLport] = ACTIONS(6070),
    [anon_sym_XMLPort] = ACTIONS(6070),
    [anon_sym_XmlPort] = ACTIONS(6070),
    [anon_sym_enum] = ACTIONS(6070),
    [anon_sym_ENUM] = ACTIONS(6070),
    [anon_sym_Enum] = ACTIONS(6070),
    [anon_sym_eNUM] = ACTIONS(6070),
    [anon_sym_eNum] = ACTIONS(6070),
    [anon_sym_ENum] = ACTIONS(6070),
    [sym_quoted_identifier] = ACTIONS(6072),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6072),
    [sym_verbatim_string] = ACTIONS(6072),
    [sym_integer] = ACTIONS(6070),
    [sym_continue_as_identifier] = ACTIONS(6072),
    [sym_preproc_open] = ACTIONS(6072),
    [sym_end_keyword] = ACTIONS(6072),
  },
  [STATE(3224)] = {
    [sym_identifier] = ACTIONS(5984),
    [anon_sym_SEMI] = ACTIONS(5986),
    [anon_sym_DASH] = ACTIONS(5986),
    [aux_sym_boolean_token1] = ACTIONS(5984),
    [aux_sym_boolean_token2] = ACTIONS(5984),
    [sym_decimal] = ACTIONS(5984),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5984),
    [anon_sym_LBRACK] = ACTIONS(5986),
    [aux_sym_record_type_token1] = ACTIONS(5984),
    [aux_sym_basic_type_token21] = ACTIONS(5984),
    [aux_sym_basic_type_token22] = ACTIONS(5984),
    [aux_sym_basic_type_token48] = ACTIONS(5984),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5984),
    [anon_sym_POUNDif] = ACTIONS(5986),
    [anon_sym_POUNDIF] = ACTIONS(5986),
    [anon_sym_POUNDIf] = ACTIONS(5986),
    [anon_sym_not] = ACTIONS(5984),
    [anon_sym_NOT] = ACTIONS(5984),
    [anon_sym_Not] = ACTIONS(5984),
    [anon_sym_POUNDelse] = ACTIONS(5986),
    [anon_sym_POUNDELSE] = ACTIONS(5986),
    [anon_sym_POUNDElse] = ACTIONS(5986),
    [anon_sym_POUNDelse2] = ACTIONS(5986),
    [anon_sym_POUNDELSE2] = ACTIONS(5986),
    [anon_sym_POUNDElse2] = ACTIONS(5986),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5984),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5984),
    [anon_sym_PLUS] = ACTIONS(5986),
    [sym_datetime_literal] = ACTIONS(5986),
    [sym_date_literal] = ACTIONS(5984),
    [sym_time_literal] = ACTIONS(5984),
    [sym_biginteger_literal] = ACTIONS(5986),
    [anon_sym_if] = ACTIONS(5984),
    [anon_sym_IF] = ACTIONS(5984),
    [anon_sym_If] = ACTIONS(5984),
    [anon_sym_else] = ACTIONS(5984),
    [anon_sym_ELSE] = ACTIONS(5984),
    [anon_sym_Else] = ACTIONS(5984),
    [anon_sym_case] = ACTIONS(5984),
    [anon_sym_CASE] = ACTIONS(5984),
    [anon_sym_Case] = ACTIONS(5984),
    [anon_sym_for] = ACTIONS(5984),
    [anon_sym_FOR] = ACTIONS(5984),
    [anon_sym_For] = ACTIONS(5984),
    [anon_sym_foreach] = ACTIONS(5984),
    [anon_sym_FOREACH] = ACTIONS(5984),
    [anon_sym_Foreach] = ACTIONS(5984),
    [anon_sym_while] = ACTIONS(5984),
    [anon_sym_WHILE] = ACTIONS(5984),
    [anon_sym_While] = ACTIONS(5984),
    [anon_sym_repeat] = ACTIONS(5984),
    [anon_sym_REPEAT] = ACTIONS(5984),
    [anon_sym_Repeat] = ACTIONS(5984),
    [anon_sym_exit] = ACTIONS(5984),
    [anon_sym_EXIT] = ACTIONS(5984),
    [anon_sym_Exit] = ACTIONS(5984),
    [anon_sym_continue] = ACTIONS(5984),
    [anon_sym_CONTINUE] = ACTIONS(5984),
    [anon_sym_Continue] = ACTIONS(5984),
    [anon_sym_break] = ACTIONS(5984),
    [anon_sym_BREAK] = ACTIONS(5984),
    [anon_sym_Break] = ACTIONS(5984),
    [anon_sym_with] = ACTIONS(5984),
    [anon_sym_WITH] = ACTIONS(5984),
    [anon_sym_With] = ACTIONS(5984),
    [sym_asserterror_keyword] = ACTIONS(5986),
    [sym_page_keyword] = ACTIONS(5984),
    [anon_sym_codeunit] = ACTIONS(5984),
    [anon_sym_CODEUNIT] = ACTIONS(5984),
    [anon_sym_Codeunit] = ACTIONS(5984),
    [anon_sym_CodeUnit] = ACTIONS(5984),
    [anon_sym_COdeunit] = ACTIONS(5984),
    [anon_sym_codeUnit] = ACTIONS(5984),
    [sym_report_keyword] = ACTIONS(5984),
    [sym_query_keyword] = ACTIONS(5984),
    [anon_sym_xmlport] = ACTIONS(5984),
    [anon_sym_XMLPORT] = ACTIONS(5984),
    [anon_sym_Xmlport] = ACTIONS(5984),
    [anon_sym_XMLport] = ACTIONS(5984),
    [anon_sym_XMLPort] = ACTIONS(5984),
    [anon_sym_XmlPort] = ACTIONS(5984),
    [anon_sym_enum] = ACTIONS(5984),
    [anon_sym_ENUM] = ACTIONS(5984),
    [anon_sym_Enum] = ACTIONS(5984),
    [anon_sym_eNUM] = ACTIONS(5984),
    [anon_sym_eNum] = ACTIONS(5984),
    [anon_sym_ENum] = ACTIONS(5984),
    [sym_quoted_identifier] = ACTIONS(5986),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5986),
    [sym_verbatim_string] = ACTIONS(5986),
    [sym_integer] = ACTIONS(5984),
    [sym_continue_as_identifier] = ACTIONS(5986),
    [sym_preproc_open] = ACTIONS(5986),
    [sym_end_keyword] = ACTIONS(5986),
  },
  [STATE(3225)] = {
    [sym_identifier] = ACTIONS(6066),
    [anon_sym_SEMI] = ACTIONS(6068),
    [anon_sym_DASH] = ACTIONS(6068),
    [aux_sym_boolean_token1] = ACTIONS(6066),
    [aux_sym_boolean_token2] = ACTIONS(6066),
    [sym_decimal] = ACTIONS(6066),
    [anon_sym_LPAREN] = ACTIONS(6068),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6066),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [aux_sym_record_type_token1] = ACTIONS(6066),
    [aux_sym_basic_type_token21] = ACTIONS(6066),
    [aux_sym_basic_type_token22] = ACTIONS(6066),
    [aux_sym_basic_type_token48] = ACTIONS(6066),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6066),
    [anon_sym_POUNDif] = ACTIONS(6068),
    [anon_sym_POUNDIF] = ACTIONS(6068),
    [anon_sym_POUNDIf] = ACTIONS(6068),
    [anon_sym_not] = ACTIONS(6066),
    [anon_sym_NOT] = ACTIONS(6066),
    [anon_sym_Not] = ACTIONS(6066),
    [anon_sym_POUNDelse] = ACTIONS(6068),
    [anon_sym_POUNDELSE] = ACTIONS(6068),
    [anon_sym_POUNDElse] = ACTIONS(6068),
    [anon_sym_POUNDelse2] = ACTIONS(6068),
    [anon_sym_POUNDELSE2] = ACTIONS(6068),
    [anon_sym_POUNDElse2] = ACTIONS(6068),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6066),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6066),
    [anon_sym_PLUS] = ACTIONS(6068),
    [sym_datetime_literal] = ACTIONS(6068),
    [sym_date_literal] = ACTIONS(6066),
    [sym_time_literal] = ACTIONS(6066),
    [sym_biginteger_literal] = ACTIONS(6068),
    [anon_sym_if] = ACTIONS(6066),
    [anon_sym_IF] = ACTIONS(6066),
    [anon_sym_If] = ACTIONS(6066),
    [anon_sym_else] = ACTIONS(6066),
    [anon_sym_ELSE] = ACTIONS(6066),
    [anon_sym_Else] = ACTIONS(6066),
    [anon_sym_case] = ACTIONS(6066),
    [anon_sym_CASE] = ACTIONS(6066),
    [anon_sym_Case] = ACTIONS(6066),
    [anon_sym_for] = ACTIONS(6066),
    [anon_sym_FOR] = ACTIONS(6066),
    [anon_sym_For] = ACTIONS(6066),
    [anon_sym_foreach] = ACTIONS(6066),
    [anon_sym_FOREACH] = ACTIONS(6066),
    [anon_sym_Foreach] = ACTIONS(6066),
    [anon_sym_while] = ACTIONS(6066),
    [anon_sym_WHILE] = ACTIONS(6066),
    [anon_sym_While] = ACTIONS(6066),
    [anon_sym_repeat] = ACTIONS(6066),
    [anon_sym_REPEAT] = ACTIONS(6066),
    [anon_sym_Repeat] = ACTIONS(6066),
    [anon_sym_exit] = ACTIONS(6066),
    [anon_sym_EXIT] = ACTIONS(6066),
    [anon_sym_Exit] = ACTIONS(6066),
    [anon_sym_continue] = ACTIONS(6066),
    [anon_sym_CONTINUE] = ACTIONS(6066),
    [anon_sym_Continue] = ACTIONS(6066),
    [anon_sym_break] = ACTIONS(6066),
    [anon_sym_BREAK] = ACTIONS(6066),
    [anon_sym_Break] = ACTIONS(6066),
    [anon_sym_with] = ACTIONS(6066),
    [anon_sym_WITH] = ACTIONS(6066),
    [anon_sym_With] = ACTIONS(6066),
    [sym_asserterror_keyword] = ACTIONS(6068),
    [sym_page_keyword] = ACTIONS(6066),
    [anon_sym_codeunit] = ACTIONS(6066),
    [anon_sym_CODEUNIT] = ACTIONS(6066),
    [anon_sym_Codeunit] = ACTIONS(6066),
    [anon_sym_CodeUnit] = ACTIONS(6066),
    [anon_sym_COdeunit] = ACTIONS(6066),
    [anon_sym_codeUnit] = ACTIONS(6066),
    [sym_report_keyword] = ACTIONS(6066),
    [sym_query_keyword] = ACTIONS(6066),
    [anon_sym_xmlport] = ACTIONS(6066),
    [anon_sym_XMLPORT] = ACTIONS(6066),
    [anon_sym_Xmlport] = ACTIONS(6066),
    [anon_sym_XMLport] = ACTIONS(6066),
    [anon_sym_XMLPort] = ACTIONS(6066),
    [anon_sym_XmlPort] = ACTIONS(6066),
    [anon_sym_enum] = ACTIONS(6066),
    [anon_sym_ENUM] = ACTIONS(6066),
    [anon_sym_Enum] = ACTIONS(6066),
    [anon_sym_eNUM] = ACTIONS(6066),
    [anon_sym_eNum] = ACTIONS(6066),
    [anon_sym_ENum] = ACTIONS(6066),
    [sym_quoted_identifier] = ACTIONS(6068),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6068),
    [sym_verbatim_string] = ACTIONS(6068),
    [sym_integer] = ACTIONS(6066),
    [sym_continue_as_identifier] = ACTIONS(6068),
    [sym_preproc_open] = ACTIONS(6068),
    [sym_end_keyword] = ACTIONS(6068),
  },
  [STATE(3226)] = {
    [sym_identifier] = ACTIONS(6312),
    [anon_sym_SEMI] = ACTIONS(6314),
    [anon_sym_DASH] = ACTIONS(6314),
    [aux_sym_boolean_token1] = ACTIONS(6312),
    [aux_sym_boolean_token2] = ACTIONS(6312),
    [sym_decimal] = ACTIONS(6312),
    [anon_sym_LPAREN] = ACTIONS(6314),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6312),
    [anon_sym_LBRACK] = ACTIONS(6314),
    [aux_sym_record_type_token1] = ACTIONS(6312),
    [aux_sym_basic_type_token21] = ACTIONS(6312),
    [aux_sym_basic_type_token22] = ACTIONS(6312),
    [aux_sym_basic_type_token48] = ACTIONS(6312),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6312),
    [anon_sym_POUNDif] = ACTIONS(6314),
    [anon_sym_POUNDIF] = ACTIONS(6314),
    [anon_sym_POUNDIf] = ACTIONS(6314),
    [anon_sym_not] = ACTIONS(6312),
    [anon_sym_NOT] = ACTIONS(6312),
    [anon_sym_Not] = ACTIONS(6312),
    [anon_sym_POUNDelse] = ACTIONS(6314),
    [anon_sym_POUNDELSE] = ACTIONS(6314),
    [anon_sym_POUNDElse] = ACTIONS(6314),
    [anon_sym_POUNDelse2] = ACTIONS(6314),
    [anon_sym_POUNDELSE2] = ACTIONS(6314),
    [anon_sym_POUNDElse2] = ACTIONS(6314),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6312),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6312),
    [anon_sym_PLUS] = ACTIONS(6314),
    [sym_datetime_literal] = ACTIONS(6314),
    [sym_date_literal] = ACTIONS(6312),
    [sym_time_literal] = ACTIONS(6312),
    [sym_biginteger_literal] = ACTIONS(6314),
    [anon_sym_if] = ACTIONS(6312),
    [anon_sym_IF] = ACTIONS(6312),
    [anon_sym_If] = ACTIONS(6312),
    [anon_sym_else] = ACTIONS(6312),
    [anon_sym_ELSE] = ACTIONS(6312),
    [anon_sym_Else] = ACTIONS(6312),
    [anon_sym_case] = ACTIONS(6312),
    [anon_sym_CASE] = ACTIONS(6312),
    [anon_sym_Case] = ACTIONS(6312),
    [anon_sym_for] = ACTIONS(6312),
    [anon_sym_FOR] = ACTIONS(6312),
    [anon_sym_For] = ACTIONS(6312),
    [anon_sym_foreach] = ACTIONS(6312),
    [anon_sym_FOREACH] = ACTIONS(6312),
    [anon_sym_Foreach] = ACTIONS(6312),
    [anon_sym_while] = ACTIONS(6312),
    [anon_sym_WHILE] = ACTIONS(6312),
    [anon_sym_While] = ACTIONS(6312),
    [anon_sym_repeat] = ACTIONS(6312),
    [anon_sym_REPEAT] = ACTIONS(6312),
    [anon_sym_Repeat] = ACTIONS(6312),
    [anon_sym_exit] = ACTIONS(6312),
    [anon_sym_EXIT] = ACTIONS(6312),
    [anon_sym_Exit] = ACTIONS(6312),
    [anon_sym_continue] = ACTIONS(6312),
    [anon_sym_CONTINUE] = ACTIONS(6312),
    [anon_sym_Continue] = ACTIONS(6312),
    [anon_sym_break] = ACTIONS(6312),
    [anon_sym_BREAK] = ACTIONS(6312),
    [anon_sym_Break] = ACTIONS(6312),
    [anon_sym_with] = ACTIONS(6312),
    [anon_sym_WITH] = ACTIONS(6312),
    [anon_sym_With] = ACTIONS(6312),
    [sym_asserterror_keyword] = ACTIONS(6314),
    [sym_page_keyword] = ACTIONS(6312),
    [anon_sym_codeunit] = ACTIONS(6312),
    [anon_sym_CODEUNIT] = ACTIONS(6312),
    [anon_sym_Codeunit] = ACTIONS(6312),
    [anon_sym_CodeUnit] = ACTIONS(6312),
    [anon_sym_COdeunit] = ACTIONS(6312),
    [anon_sym_codeUnit] = ACTIONS(6312),
    [sym_report_keyword] = ACTIONS(6312),
    [sym_query_keyword] = ACTIONS(6312),
    [anon_sym_xmlport] = ACTIONS(6312),
    [anon_sym_XMLPORT] = ACTIONS(6312),
    [anon_sym_Xmlport] = ACTIONS(6312),
    [anon_sym_XMLport] = ACTIONS(6312),
    [anon_sym_XMLPort] = ACTIONS(6312),
    [anon_sym_XmlPort] = ACTIONS(6312),
    [anon_sym_enum] = ACTIONS(6312),
    [anon_sym_ENUM] = ACTIONS(6312),
    [anon_sym_Enum] = ACTIONS(6312),
    [anon_sym_eNUM] = ACTIONS(6312),
    [anon_sym_eNum] = ACTIONS(6312),
    [anon_sym_ENum] = ACTIONS(6312),
    [sym_quoted_identifier] = ACTIONS(6314),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6314),
    [sym_verbatim_string] = ACTIONS(6314),
    [sym_integer] = ACTIONS(6312),
    [sym_continue_as_identifier] = ACTIONS(6314),
    [sym_preproc_open] = ACTIONS(6314),
    [sym_end_keyword] = ACTIONS(6314),
  },
  [STATE(3227)] = {
    [sym_identifier] = ACTIONS(6308),
    [anon_sym_SEMI] = ACTIONS(6310),
    [anon_sym_DASH] = ACTIONS(6310),
    [aux_sym_boolean_token1] = ACTIONS(6308),
    [aux_sym_boolean_token2] = ACTIONS(6308),
    [sym_decimal] = ACTIONS(6308),
    [anon_sym_LPAREN] = ACTIONS(6310),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6308),
    [anon_sym_LBRACK] = ACTIONS(6310),
    [aux_sym_record_type_token1] = ACTIONS(6308),
    [aux_sym_basic_type_token21] = ACTIONS(6308),
    [aux_sym_basic_type_token22] = ACTIONS(6308),
    [aux_sym_basic_type_token48] = ACTIONS(6308),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6308),
    [anon_sym_POUNDif] = ACTIONS(6310),
    [anon_sym_POUNDIF] = ACTIONS(6310),
    [anon_sym_POUNDIf] = ACTIONS(6310),
    [anon_sym_not] = ACTIONS(6308),
    [anon_sym_NOT] = ACTIONS(6308),
    [anon_sym_Not] = ACTIONS(6308),
    [anon_sym_POUNDelse] = ACTIONS(6310),
    [anon_sym_POUNDELSE] = ACTIONS(6310),
    [anon_sym_POUNDElse] = ACTIONS(6310),
    [anon_sym_POUNDelse2] = ACTIONS(6310),
    [anon_sym_POUNDELSE2] = ACTIONS(6310),
    [anon_sym_POUNDElse2] = ACTIONS(6310),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6308),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6308),
    [anon_sym_PLUS] = ACTIONS(6310),
    [sym_datetime_literal] = ACTIONS(6310),
    [sym_date_literal] = ACTIONS(6308),
    [sym_time_literal] = ACTIONS(6308),
    [sym_biginteger_literal] = ACTIONS(6310),
    [anon_sym_if] = ACTIONS(6308),
    [anon_sym_IF] = ACTIONS(6308),
    [anon_sym_If] = ACTIONS(6308),
    [anon_sym_else] = ACTIONS(6308),
    [anon_sym_ELSE] = ACTIONS(6308),
    [anon_sym_Else] = ACTIONS(6308),
    [anon_sym_case] = ACTIONS(6308),
    [anon_sym_CASE] = ACTIONS(6308),
    [anon_sym_Case] = ACTIONS(6308),
    [anon_sym_for] = ACTIONS(6308),
    [anon_sym_FOR] = ACTIONS(6308),
    [anon_sym_For] = ACTIONS(6308),
    [anon_sym_foreach] = ACTIONS(6308),
    [anon_sym_FOREACH] = ACTIONS(6308),
    [anon_sym_Foreach] = ACTIONS(6308),
    [anon_sym_while] = ACTIONS(6308),
    [anon_sym_WHILE] = ACTIONS(6308),
    [anon_sym_While] = ACTIONS(6308),
    [anon_sym_repeat] = ACTIONS(6308),
    [anon_sym_REPEAT] = ACTIONS(6308),
    [anon_sym_Repeat] = ACTIONS(6308),
    [anon_sym_exit] = ACTIONS(6308),
    [anon_sym_EXIT] = ACTIONS(6308),
    [anon_sym_Exit] = ACTIONS(6308),
    [anon_sym_continue] = ACTIONS(6308),
    [anon_sym_CONTINUE] = ACTIONS(6308),
    [anon_sym_Continue] = ACTIONS(6308),
    [anon_sym_break] = ACTIONS(6308),
    [anon_sym_BREAK] = ACTIONS(6308),
    [anon_sym_Break] = ACTIONS(6308),
    [anon_sym_with] = ACTIONS(6308),
    [anon_sym_WITH] = ACTIONS(6308),
    [anon_sym_With] = ACTIONS(6308),
    [sym_asserterror_keyword] = ACTIONS(6310),
    [sym_page_keyword] = ACTIONS(6308),
    [anon_sym_codeunit] = ACTIONS(6308),
    [anon_sym_CODEUNIT] = ACTIONS(6308),
    [anon_sym_Codeunit] = ACTIONS(6308),
    [anon_sym_CodeUnit] = ACTIONS(6308),
    [anon_sym_COdeunit] = ACTIONS(6308),
    [anon_sym_codeUnit] = ACTIONS(6308),
    [sym_report_keyword] = ACTIONS(6308),
    [sym_query_keyword] = ACTIONS(6308),
    [anon_sym_xmlport] = ACTIONS(6308),
    [anon_sym_XMLPORT] = ACTIONS(6308),
    [anon_sym_Xmlport] = ACTIONS(6308),
    [anon_sym_XMLport] = ACTIONS(6308),
    [anon_sym_XMLPort] = ACTIONS(6308),
    [anon_sym_XmlPort] = ACTIONS(6308),
    [anon_sym_enum] = ACTIONS(6308),
    [anon_sym_ENUM] = ACTIONS(6308),
    [anon_sym_Enum] = ACTIONS(6308),
    [anon_sym_eNUM] = ACTIONS(6308),
    [anon_sym_eNum] = ACTIONS(6308),
    [anon_sym_ENum] = ACTIONS(6308),
    [sym_quoted_identifier] = ACTIONS(6310),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6310),
    [sym_verbatim_string] = ACTIONS(6310),
    [sym_integer] = ACTIONS(6308),
    [sym_continue_as_identifier] = ACTIONS(6310),
    [sym_preproc_open] = ACTIONS(6310),
    [sym_end_keyword] = ACTIONS(6310),
  },
  [STATE(3228)] = {
    [sym_identifier] = ACTIONS(6316),
    [anon_sym_SEMI] = ACTIONS(6318),
    [anon_sym_DASH] = ACTIONS(6318),
    [aux_sym_boolean_token1] = ACTIONS(6316),
    [aux_sym_boolean_token2] = ACTIONS(6316),
    [sym_decimal] = ACTIONS(6316),
    [anon_sym_LPAREN] = ACTIONS(6318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6316),
    [anon_sym_LBRACK] = ACTIONS(6318),
    [aux_sym_record_type_token1] = ACTIONS(6316),
    [aux_sym_basic_type_token21] = ACTIONS(6316),
    [aux_sym_basic_type_token22] = ACTIONS(6316),
    [aux_sym_basic_type_token48] = ACTIONS(6316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6316),
    [anon_sym_POUNDif] = ACTIONS(6318),
    [anon_sym_POUNDIF] = ACTIONS(6318),
    [anon_sym_POUNDIf] = ACTIONS(6318),
    [anon_sym_not] = ACTIONS(6316),
    [anon_sym_NOT] = ACTIONS(6316),
    [anon_sym_Not] = ACTIONS(6316),
    [anon_sym_POUNDelse] = ACTIONS(6318),
    [anon_sym_POUNDELSE] = ACTIONS(6318),
    [anon_sym_POUNDElse] = ACTIONS(6318),
    [anon_sym_POUNDelse2] = ACTIONS(6318),
    [anon_sym_POUNDELSE2] = ACTIONS(6318),
    [anon_sym_POUNDElse2] = ACTIONS(6318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6316),
    [anon_sym_PLUS] = ACTIONS(6318),
    [sym_datetime_literal] = ACTIONS(6318),
    [sym_date_literal] = ACTIONS(6316),
    [sym_time_literal] = ACTIONS(6316),
    [sym_biginteger_literal] = ACTIONS(6318),
    [anon_sym_if] = ACTIONS(6316),
    [anon_sym_IF] = ACTIONS(6316),
    [anon_sym_If] = ACTIONS(6316),
    [anon_sym_else] = ACTIONS(6316),
    [anon_sym_ELSE] = ACTIONS(6316),
    [anon_sym_Else] = ACTIONS(6316),
    [anon_sym_case] = ACTIONS(6316),
    [anon_sym_CASE] = ACTIONS(6316),
    [anon_sym_Case] = ACTIONS(6316),
    [anon_sym_for] = ACTIONS(6316),
    [anon_sym_FOR] = ACTIONS(6316),
    [anon_sym_For] = ACTIONS(6316),
    [anon_sym_foreach] = ACTIONS(6316),
    [anon_sym_FOREACH] = ACTIONS(6316),
    [anon_sym_Foreach] = ACTIONS(6316),
    [anon_sym_while] = ACTIONS(6316),
    [anon_sym_WHILE] = ACTIONS(6316),
    [anon_sym_While] = ACTIONS(6316),
    [anon_sym_repeat] = ACTIONS(6316),
    [anon_sym_REPEAT] = ACTIONS(6316),
    [anon_sym_Repeat] = ACTIONS(6316),
    [anon_sym_exit] = ACTIONS(6316),
    [anon_sym_EXIT] = ACTIONS(6316),
    [anon_sym_Exit] = ACTIONS(6316),
    [anon_sym_continue] = ACTIONS(6316),
    [anon_sym_CONTINUE] = ACTIONS(6316),
    [anon_sym_Continue] = ACTIONS(6316),
    [anon_sym_break] = ACTIONS(6316),
    [anon_sym_BREAK] = ACTIONS(6316),
    [anon_sym_Break] = ACTIONS(6316),
    [anon_sym_with] = ACTIONS(6316),
    [anon_sym_WITH] = ACTIONS(6316),
    [anon_sym_With] = ACTIONS(6316),
    [sym_asserterror_keyword] = ACTIONS(6318),
    [sym_page_keyword] = ACTIONS(6316),
    [anon_sym_codeunit] = ACTIONS(6316),
    [anon_sym_CODEUNIT] = ACTIONS(6316),
    [anon_sym_Codeunit] = ACTIONS(6316),
    [anon_sym_CodeUnit] = ACTIONS(6316),
    [anon_sym_COdeunit] = ACTIONS(6316),
    [anon_sym_codeUnit] = ACTIONS(6316),
    [sym_report_keyword] = ACTIONS(6316),
    [sym_query_keyword] = ACTIONS(6316),
    [anon_sym_xmlport] = ACTIONS(6316),
    [anon_sym_XMLPORT] = ACTIONS(6316),
    [anon_sym_Xmlport] = ACTIONS(6316),
    [anon_sym_XMLport] = ACTIONS(6316),
    [anon_sym_XMLPort] = ACTIONS(6316),
    [anon_sym_XmlPort] = ACTIONS(6316),
    [anon_sym_enum] = ACTIONS(6316),
    [anon_sym_ENUM] = ACTIONS(6316),
    [anon_sym_Enum] = ACTIONS(6316),
    [anon_sym_eNUM] = ACTIONS(6316),
    [anon_sym_eNum] = ACTIONS(6316),
    [anon_sym_ENum] = ACTIONS(6316),
    [sym_quoted_identifier] = ACTIONS(6318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6318),
    [sym_verbatim_string] = ACTIONS(6318),
    [sym_integer] = ACTIONS(6316),
    [sym_continue_as_identifier] = ACTIONS(6318),
    [sym_preproc_open] = ACTIONS(6318),
    [sym_end_keyword] = ACTIONS(6318),
  },
  [STATE(3229)] = {
    [sym_identifier] = ACTIONS(5996),
    [anon_sym_SEMI] = ACTIONS(5998),
    [anon_sym_DASH] = ACTIONS(5998),
    [aux_sym_boolean_token1] = ACTIONS(5996),
    [aux_sym_boolean_token2] = ACTIONS(5996),
    [sym_decimal] = ACTIONS(5996),
    [anon_sym_LPAREN] = ACTIONS(5998),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5996),
    [anon_sym_LBRACK] = ACTIONS(5998),
    [aux_sym_record_type_token1] = ACTIONS(5996),
    [aux_sym_basic_type_token21] = ACTIONS(5996),
    [aux_sym_basic_type_token22] = ACTIONS(5996),
    [aux_sym_basic_type_token48] = ACTIONS(5996),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5996),
    [anon_sym_POUNDif] = ACTIONS(5998),
    [anon_sym_POUNDIF] = ACTIONS(5998),
    [anon_sym_POUNDIf] = ACTIONS(5998),
    [anon_sym_not] = ACTIONS(5996),
    [anon_sym_NOT] = ACTIONS(5996),
    [anon_sym_Not] = ACTIONS(5996),
    [anon_sym_POUNDelse] = ACTIONS(5998),
    [anon_sym_POUNDELSE] = ACTIONS(5998),
    [anon_sym_POUNDElse] = ACTIONS(5998),
    [anon_sym_POUNDelse2] = ACTIONS(5998),
    [anon_sym_POUNDELSE2] = ACTIONS(5998),
    [anon_sym_POUNDElse2] = ACTIONS(5998),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5996),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5996),
    [anon_sym_PLUS] = ACTIONS(5998),
    [sym_datetime_literal] = ACTIONS(5998),
    [sym_date_literal] = ACTIONS(5996),
    [sym_time_literal] = ACTIONS(5996),
    [sym_biginteger_literal] = ACTIONS(5998),
    [anon_sym_if] = ACTIONS(5996),
    [anon_sym_IF] = ACTIONS(5996),
    [anon_sym_If] = ACTIONS(5996),
    [anon_sym_else] = ACTIONS(5996),
    [anon_sym_ELSE] = ACTIONS(5996),
    [anon_sym_Else] = ACTIONS(5996),
    [anon_sym_case] = ACTIONS(5996),
    [anon_sym_CASE] = ACTIONS(5996),
    [anon_sym_Case] = ACTIONS(5996),
    [anon_sym_for] = ACTIONS(5996),
    [anon_sym_FOR] = ACTIONS(5996),
    [anon_sym_For] = ACTIONS(5996),
    [anon_sym_foreach] = ACTIONS(5996),
    [anon_sym_FOREACH] = ACTIONS(5996),
    [anon_sym_Foreach] = ACTIONS(5996),
    [anon_sym_while] = ACTIONS(5996),
    [anon_sym_WHILE] = ACTIONS(5996),
    [anon_sym_While] = ACTIONS(5996),
    [anon_sym_repeat] = ACTIONS(5996),
    [anon_sym_REPEAT] = ACTIONS(5996),
    [anon_sym_Repeat] = ACTIONS(5996),
    [anon_sym_exit] = ACTIONS(5996),
    [anon_sym_EXIT] = ACTIONS(5996),
    [anon_sym_Exit] = ACTIONS(5996),
    [anon_sym_continue] = ACTIONS(5996),
    [anon_sym_CONTINUE] = ACTIONS(5996),
    [anon_sym_Continue] = ACTIONS(5996),
    [anon_sym_break] = ACTIONS(5996),
    [anon_sym_BREAK] = ACTIONS(5996),
    [anon_sym_Break] = ACTIONS(5996),
    [anon_sym_with] = ACTIONS(5996),
    [anon_sym_WITH] = ACTIONS(5996),
    [anon_sym_With] = ACTIONS(5996),
    [sym_asserterror_keyword] = ACTIONS(5998),
    [sym_page_keyword] = ACTIONS(5996),
    [anon_sym_codeunit] = ACTIONS(5996),
    [anon_sym_CODEUNIT] = ACTIONS(5996),
    [anon_sym_Codeunit] = ACTIONS(5996),
    [anon_sym_CodeUnit] = ACTIONS(5996),
    [anon_sym_COdeunit] = ACTIONS(5996),
    [anon_sym_codeUnit] = ACTIONS(5996),
    [sym_report_keyword] = ACTIONS(5996),
    [sym_query_keyword] = ACTIONS(5996),
    [anon_sym_xmlport] = ACTIONS(5996),
    [anon_sym_XMLPORT] = ACTIONS(5996),
    [anon_sym_Xmlport] = ACTIONS(5996),
    [anon_sym_XMLport] = ACTIONS(5996),
    [anon_sym_XMLPort] = ACTIONS(5996),
    [anon_sym_XmlPort] = ACTIONS(5996),
    [anon_sym_enum] = ACTIONS(5996),
    [anon_sym_ENUM] = ACTIONS(5996),
    [anon_sym_Enum] = ACTIONS(5996),
    [anon_sym_eNUM] = ACTIONS(5996),
    [anon_sym_eNum] = ACTIONS(5996),
    [anon_sym_ENum] = ACTIONS(5996),
    [sym_quoted_identifier] = ACTIONS(5998),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5998),
    [sym_verbatim_string] = ACTIONS(5998),
    [sym_integer] = ACTIONS(5996),
    [sym_continue_as_identifier] = ACTIONS(5998),
    [sym_preproc_open] = ACTIONS(5998),
    [sym_end_keyword] = ACTIONS(5998),
  },
  [STATE(3230)] = {
    [sym_identifier] = ACTIONS(6359),
    [anon_sym_SEMI] = ACTIONS(6361),
    [anon_sym_DASH] = ACTIONS(6361),
    [aux_sym_boolean_token1] = ACTIONS(6359),
    [aux_sym_boolean_token2] = ACTIONS(6359),
    [sym_decimal] = ACTIONS(6359),
    [anon_sym_LPAREN] = ACTIONS(6361),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6359),
    [anon_sym_LBRACK] = ACTIONS(6361),
    [aux_sym_record_type_token1] = ACTIONS(6359),
    [aux_sym_basic_type_token21] = ACTIONS(6359),
    [aux_sym_basic_type_token22] = ACTIONS(6359),
    [aux_sym_basic_type_token48] = ACTIONS(6359),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6359),
    [anon_sym_POUNDif] = ACTIONS(6361),
    [anon_sym_POUNDIF] = ACTIONS(6361),
    [anon_sym_POUNDIf] = ACTIONS(6361),
    [anon_sym_not] = ACTIONS(6359),
    [anon_sym_NOT] = ACTIONS(6359),
    [anon_sym_Not] = ACTIONS(6359),
    [anon_sym_POUNDelse] = ACTIONS(6361),
    [anon_sym_POUNDELSE] = ACTIONS(6361),
    [anon_sym_POUNDElse] = ACTIONS(6361),
    [anon_sym_POUNDelse2] = ACTIONS(6361),
    [anon_sym_POUNDELSE2] = ACTIONS(6361),
    [anon_sym_POUNDElse2] = ACTIONS(6361),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6359),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6359),
    [anon_sym_PLUS] = ACTIONS(6361),
    [sym_datetime_literal] = ACTIONS(6361),
    [sym_date_literal] = ACTIONS(6359),
    [sym_time_literal] = ACTIONS(6359),
    [sym_biginteger_literal] = ACTIONS(6361),
    [anon_sym_if] = ACTIONS(6359),
    [anon_sym_IF] = ACTIONS(6359),
    [anon_sym_If] = ACTIONS(6359),
    [anon_sym_else] = ACTIONS(6359),
    [anon_sym_ELSE] = ACTIONS(6359),
    [anon_sym_Else] = ACTIONS(6359),
    [anon_sym_case] = ACTIONS(6359),
    [anon_sym_CASE] = ACTIONS(6359),
    [anon_sym_Case] = ACTIONS(6359),
    [anon_sym_for] = ACTIONS(6359),
    [anon_sym_FOR] = ACTIONS(6359),
    [anon_sym_For] = ACTIONS(6359),
    [anon_sym_foreach] = ACTIONS(6359),
    [anon_sym_FOREACH] = ACTIONS(6359),
    [anon_sym_Foreach] = ACTIONS(6359),
    [anon_sym_while] = ACTIONS(6359),
    [anon_sym_WHILE] = ACTIONS(6359),
    [anon_sym_While] = ACTIONS(6359),
    [anon_sym_repeat] = ACTIONS(6359),
    [anon_sym_REPEAT] = ACTIONS(6359),
    [anon_sym_Repeat] = ACTIONS(6359),
    [anon_sym_exit] = ACTIONS(6359),
    [anon_sym_EXIT] = ACTIONS(6359),
    [anon_sym_Exit] = ACTIONS(6359),
    [anon_sym_continue] = ACTIONS(6359),
    [anon_sym_CONTINUE] = ACTIONS(6359),
    [anon_sym_Continue] = ACTIONS(6359),
    [anon_sym_break] = ACTIONS(6359),
    [anon_sym_BREAK] = ACTIONS(6359),
    [anon_sym_Break] = ACTIONS(6359),
    [anon_sym_with] = ACTIONS(6359),
    [anon_sym_WITH] = ACTIONS(6359),
    [anon_sym_With] = ACTIONS(6359),
    [sym_asserterror_keyword] = ACTIONS(6361),
    [sym_page_keyword] = ACTIONS(6359),
    [anon_sym_codeunit] = ACTIONS(6359),
    [anon_sym_CODEUNIT] = ACTIONS(6359),
    [anon_sym_Codeunit] = ACTIONS(6359),
    [anon_sym_CodeUnit] = ACTIONS(6359),
    [anon_sym_COdeunit] = ACTIONS(6359),
    [anon_sym_codeUnit] = ACTIONS(6359),
    [sym_report_keyword] = ACTIONS(6359),
    [sym_query_keyword] = ACTIONS(6359),
    [anon_sym_xmlport] = ACTIONS(6359),
    [anon_sym_XMLPORT] = ACTIONS(6359),
    [anon_sym_Xmlport] = ACTIONS(6359),
    [anon_sym_XMLport] = ACTIONS(6359),
    [anon_sym_XMLPort] = ACTIONS(6359),
    [anon_sym_XmlPort] = ACTIONS(6359),
    [anon_sym_enum] = ACTIONS(6359),
    [anon_sym_ENUM] = ACTIONS(6359),
    [anon_sym_Enum] = ACTIONS(6359),
    [anon_sym_eNUM] = ACTIONS(6359),
    [anon_sym_eNum] = ACTIONS(6359),
    [anon_sym_ENum] = ACTIONS(6359),
    [sym_quoted_identifier] = ACTIONS(6361),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6361),
    [sym_verbatim_string] = ACTIONS(6361),
    [sym_integer] = ACTIONS(6359),
    [sym_continue_as_identifier] = ACTIONS(6361),
    [sym_preproc_open] = ACTIONS(6361),
    [sym_end_keyword] = ACTIONS(6361),
  },
  [STATE(3231)] = {
    [sym_identifier] = ACTIONS(5621),
    [anon_sym_SEMI] = ACTIONS(5623),
    [anon_sym_DASH] = ACTIONS(5623),
    [aux_sym_boolean_token1] = ACTIONS(5621),
    [aux_sym_boolean_token2] = ACTIONS(5621),
    [sym_decimal] = ACTIONS(5621),
    [anon_sym_LPAREN] = ACTIONS(5623),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5621),
    [anon_sym_LBRACK] = ACTIONS(5623),
    [aux_sym_record_type_token1] = ACTIONS(5621),
    [aux_sym_basic_type_token21] = ACTIONS(5621),
    [aux_sym_basic_type_token22] = ACTIONS(5621),
    [aux_sym_basic_type_token48] = ACTIONS(5621),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5621),
    [anon_sym_POUNDif] = ACTIONS(5623),
    [anon_sym_POUNDIF] = ACTIONS(5623),
    [anon_sym_POUNDIf] = ACTIONS(5623),
    [anon_sym_not] = ACTIONS(5621),
    [anon_sym_NOT] = ACTIONS(5621),
    [anon_sym_Not] = ACTIONS(5621),
    [anon_sym_POUNDelse] = ACTIONS(5623),
    [anon_sym_POUNDELSE] = ACTIONS(5623),
    [anon_sym_POUNDElse] = ACTIONS(5623),
    [anon_sym_POUNDelse2] = ACTIONS(5623),
    [anon_sym_POUNDELSE2] = ACTIONS(5623),
    [anon_sym_POUNDElse2] = ACTIONS(5623),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5621),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5621),
    [anon_sym_PLUS] = ACTIONS(5623),
    [sym_datetime_literal] = ACTIONS(5623),
    [sym_date_literal] = ACTIONS(5621),
    [sym_time_literal] = ACTIONS(5621),
    [sym_biginteger_literal] = ACTIONS(5623),
    [anon_sym_if] = ACTIONS(5621),
    [anon_sym_IF] = ACTIONS(5621),
    [anon_sym_If] = ACTIONS(5621),
    [anon_sym_else] = ACTIONS(5621),
    [anon_sym_ELSE] = ACTIONS(5621),
    [anon_sym_Else] = ACTIONS(5621),
    [anon_sym_case] = ACTIONS(5621),
    [anon_sym_CASE] = ACTIONS(5621),
    [anon_sym_Case] = ACTIONS(5621),
    [anon_sym_for] = ACTIONS(5621),
    [anon_sym_FOR] = ACTIONS(5621),
    [anon_sym_For] = ACTIONS(5621),
    [anon_sym_foreach] = ACTIONS(5621),
    [anon_sym_FOREACH] = ACTIONS(5621),
    [anon_sym_Foreach] = ACTIONS(5621),
    [anon_sym_while] = ACTIONS(5621),
    [anon_sym_WHILE] = ACTIONS(5621),
    [anon_sym_While] = ACTIONS(5621),
    [anon_sym_repeat] = ACTIONS(5621),
    [anon_sym_REPEAT] = ACTIONS(5621),
    [anon_sym_Repeat] = ACTIONS(5621),
    [anon_sym_exit] = ACTIONS(5621),
    [anon_sym_EXIT] = ACTIONS(5621),
    [anon_sym_Exit] = ACTIONS(5621),
    [anon_sym_continue] = ACTIONS(5621),
    [anon_sym_CONTINUE] = ACTIONS(5621),
    [anon_sym_Continue] = ACTIONS(5621),
    [anon_sym_break] = ACTIONS(5621),
    [anon_sym_BREAK] = ACTIONS(5621),
    [anon_sym_Break] = ACTIONS(5621),
    [anon_sym_with] = ACTIONS(5621),
    [anon_sym_WITH] = ACTIONS(5621),
    [anon_sym_With] = ACTIONS(5621),
    [sym_asserterror_keyword] = ACTIONS(5623),
    [sym_page_keyword] = ACTIONS(5621),
    [anon_sym_codeunit] = ACTIONS(5621),
    [anon_sym_CODEUNIT] = ACTIONS(5621),
    [anon_sym_Codeunit] = ACTIONS(5621),
    [anon_sym_CodeUnit] = ACTIONS(5621),
    [anon_sym_COdeunit] = ACTIONS(5621),
    [anon_sym_codeUnit] = ACTIONS(5621),
    [sym_report_keyword] = ACTIONS(5621),
    [sym_query_keyword] = ACTIONS(5621),
    [anon_sym_xmlport] = ACTIONS(5621),
    [anon_sym_XMLPORT] = ACTIONS(5621),
    [anon_sym_Xmlport] = ACTIONS(5621),
    [anon_sym_XMLport] = ACTIONS(5621),
    [anon_sym_XMLPort] = ACTIONS(5621),
    [anon_sym_XmlPort] = ACTIONS(5621),
    [anon_sym_enum] = ACTIONS(5621),
    [anon_sym_ENUM] = ACTIONS(5621),
    [anon_sym_Enum] = ACTIONS(5621),
    [anon_sym_eNUM] = ACTIONS(5621),
    [anon_sym_eNum] = ACTIONS(5621),
    [anon_sym_ENum] = ACTIONS(5621),
    [sym_quoted_identifier] = ACTIONS(5623),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5623),
    [sym_verbatim_string] = ACTIONS(5623),
    [sym_integer] = ACTIONS(5621),
    [sym_continue_as_identifier] = ACTIONS(5623),
    [sym_preproc_open] = ACTIONS(5623),
    [sym_end_keyword] = ACTIONS(5623),
  },
  [STATE(3232)] = {
    [sym_identifier] = ACTIONS(5625),
    [anon_sym_SEMI] = ACTIONS(5627),
    [anon_sym_DASH] = ACTIONS(5627),
    [aux_sym_boolean_token1] = ACTIONS(5625),
    [aux_sym_boolean_token2] = ACTIONS(5625),
    [sym_decimal] = ACTIONS(5625),
    [anon_sym_LPAREN] = ACTIONS(5627),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5625),
    [anon_sym_LBRACK] = ACTIONS(5627),
    [aux_sym_record_type_token1] = ACTIONS(5625),
    [aux_sym_basic_type_token21] = ACTIONS(5625),
    [aux_sym_basic_type_token22] = ACTIONS(5625),
    [aux_sym_basic_type_token48] = ACTIONS(5625),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5625),
    [anon_sym_POUNDif] = ACTIONS(5627),
    [anon_sym_POUNDIF] = ACTIONS(5627),
    [anon_sym_POUNDIf] = ACTIONS(5627),
    [anon_sym_not] = ACTIONS(5625),
    [anon_sym_NOT] = ACTIONS(5625),
    [anon_sym_Not] = ACTIONS(5625),
    [anon_sym_POUNDelse] = ACTIONS(5627),
    [anon_sym_POUNDELSE] = ACTIONS(5627),
    [anon_sym_POUNDElse] = ACTIONS(5627),
    [anon_sym_POUNDelse2] = ACTIONS(5627),
    [anon_sym_POUNDELSE2] = ACTIONS(5627),
    [anon_sym_POUNDElse2] = ACTIONS(5627),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5625),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5625),
    [anon_sym_PLUS] = ACTIONS(5627),
    [sym_datetime_literal] = ACTIONS(5627),
    [sym_date_literal] = ACTIONS(5625),
    [sym_time_literal] = ACTIONS(5625),
    [sym_biginteger_literal] = ACTIONS(5627),
    [anon_sym_if] = ACTIONS(5625),
    [anon_sym_IF] = ACTIONS(5625),
    [anon_sym_If] = ACTIONS(5625),
    [anon_sym_else] = ACTIONS(5625),
    [anon_sym_ELSE] = ACTIONS(5625),
    [anon_sym_Else] = ACTIONS(5625),
    [anon_sym_case] = ACTIONS(5625),
    [anon_sym_CASE] = ACTIONS(5625),
    [anon_sym_Case] = ACTIONS(5625),
    [anon_sym_for] = ACTIONS(5625),
    [anon_sym_FOR] = ACTIONS(5625),
    [anon_sym_For] = ACTIONS(5625),
    [anon_sym_foreach] = ACTIONS(5625),
    [anon_sym_FOREACH] = ACTIONS(5625),
    [anon_sym_Foreach] = ACTIONS(5625),
    [anon_sym_while] = ACTIONS(5625),
    [anon_sym_WHILE] = ACTIONS(5625),
    [anon_sym_While] = ACTIONS(5625),
    [anon_sym_repeat] = ACTIONS(5625),
    [anon_sym_REPEAT] = ACTIONS(5625),
    [anon_sym_Repeat] = ACTIONS(5625),
    [anon_sym_exit] = ACTIONS(5625),
    [anon_sym_EXIT] = ACTIONS(5625),
    [anon_sym_Exit] = ACTIONS(5625),
    [anon_sym_continue] = ACTIONS(5625),
    [anon_sym_CONTINUE] = ACTIONS(5625),
    [anon_sym_Continue] = ACTIONS(5625),
    [anon_sym_break] = ACTIONS(5625),
    [anon_sym_BREAK] = ACTIONS(5625),
    [anon_sym_Break] = ACTIONS(5625),
    [anon_sym_with] = ACTIONS(5625),
    [anon_sym_WITH] = ACTIONS(5625),
    [anon_sym_With] = ACTIONS(5625),
    [sym_asserterror_keyword] = ACTIONS(5627),
    [sym_page_keyword] = ACTIONS(5625),
    [anon_sym_codeunit] = ACTIONS(5625),
    [anon_sym_CODEUNIT] = ACTIONS(5625),
    [anon_sym_Codeunit] = ACTIONS(5625),
    [anon_sym_CodeUnit] = ACTIONS(5625),
    [anon_sym_COdeunit] = ACTIONS(5625),
    [anon_sym_codeUnit] = ACTIONS(5625),
    [sym_report_keyword] = ACTIONS(5625),
    [sym_query_keyword] = ACTIONS(5625),
    [anon_sym_xmlport] = ACTIONS(5625),
    [anon_sym_XMLPORT] = ACTIONS(5625),
    [anon_sym_Xmlport] = ACTIONS(5625),
    [anon_sym_XMLport] = ACTIONS(5625),
    [anon_sym_XMLPort] = ACTIONS(5625),
    [anon_sym_XmlPort] = ACTIONS(5625),
    [anon_sym_enum] = ACTIONS(5625),
    [anon_sym_ENUM] = ACTIONS(5625),
    [anon_sym_Enum] = ACTIONS(5625),
    [anon_sym_eNUM] = ACTIONS(5625),
    [anon_sym_eNum] = ACTIONS(5625),
    [anon_sym_ENum] = ACTIONS(5625),
    [sym_quoted_identifier] = ACTIONS(5627),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5627),
    [sym_verbatim_string] = ACTIONS(5627),
    [sym_integer] = ACTIONS(5625),
    [sym_continue_as_identifier] = ACTIONS(5627),
    [sym_preproc_open] = ACTIONS(5627),
    [sym_end_keyword] = ACTIONS(5627),
  },
  [STATE(3233)] = {
    [sym_identifier] = ACTIONS(5629),
    [anon_sym_SEMI] = ACTIONS(5631),
    [anon_sym_DASH] = ACTIONS(5631),
    [aux_sym_boolean_token1] = ACTIONS(5629),
    [aux_sym_boolean_token2] = ACTIONS(5629),
    [sym_decimal] = ACTIONS(5629),
    [anon_sym_LPAREN] = ACTIONS(5631),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5629),
    [anon_sym_LBRACK] = ACTIONS(5631),
    [aux_sym_record_type_token1] = ACTIONS(5629),
    [aux_sym_basic_type_token21] = ACTIONS(5629),
    [aux_sym_basic_type_token22] = ACTIONS(5629),
    [aux_sym_basic_type_token48] = ACTIONS(5629),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5629),
    [anon_sym_POUNDif] = ACTIONS(5631),
    [anon_sym_POUNDIF] = ACTIONS(5631),
    [anon_sym_POUNDIf] = ACTIONS(5631),
    [anon_sym_not] = ACTIONS(5629),
    [anon_sym_NOT] = ACTIONS(5629),
    [anon_sym_Not] = ACTIONS(5629),
    [anon_sym_POUNDelse] = ACTIONS(5631),
    [anon_sym_POUNDELSE] = ACTIONS(5631),
    [anon_sym_POUNDElse] = ACTIONS(5631),
    [anon_sym_POUNDelse2] = ACTIONS(5631),
    [anon_sym_POUNDELSE2] = ACTIONS(5631),
    [anon_sym_POUNDElse2] = ACTIONS(5631),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5629),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5629),
    [anon_sym_PLUS] = ACTIONS(5631),
    [sym_datetime_literal] = ACTIONS(5631),
    [sym_date_literal] = ACTIONS(5629),
    [sym_time_literal] = ACTIONS(5629),
    [sym_biginteger_literal] = ACTIONS(5631),
    [anon_sym_if] = ACTIONS(5629),
    [anon_sym_IF] = ACTIONS(5629),
    [anon_sym_If] = ACTIONS(5629),
    [anon_sym_else] = ACTIONS(5629),
    [anon_sym_ELSE] = ACTIONS(5629),
    [anon_sym_Else] = ACTIONS(5629),
    [anon_sym_case] = ACTIONS(5629),
    [anon_sym_CASE] = ACTIONS(5629),
    [anon_sym_Case] = ACTIONS(5629),
    [anon_sym_for] = ACTIONS(5629),
    [anon_sym_FOR] = ACTIONS(5629),
    [anon_sym_For] = ACTIONS(5629),
    [anon_sym_foreach] = ACTIONS(5629),
    [anon_sym_FOREACH] = ACTIONS(5629),
    [anon_sym_Foreach] = ACTIONS(5629),
    [anon_sym_while] = ACTIONS(5629),
    [anon_sym_WHILE] = ACTIONS(5629),
    [anon_sym_While] = ACTIONS(5629),
    [anon_sym_repeat] = ACTIONS(5629),
    [anon_sym_REPEAT] = ACTIONS(5629),
    [anon_sym_Repeat] = ACTIONS(5629),
    [anon_sym_exit] = ACTIONS(5629),
    [anon_sym_EXIT] = ACTIONS(5629),
    [anon_sym_Exit] = ACTIONS(5629),
    [anon_sym_continue] = ACTIONS(5629),
    [anon_sym_CONTINUE] = ACTIONS(5629),
    [anon_sym_Continue] = ACTIONS(5629),
    [anon_sym_break] = ACTIONS(5629),
    [anon_sym_BREAK] = ACTIONS(5629),
    [anon_sym_Break] = ACTIONS(5629),
    [anon_sym_with] = ACTIONS(5629),
    [anon_sym_WITH] = ACTIONS(5629),
    [anon_sym_With] = ACTIONS(5629),
    [sym_asserterror_keyword] = ACTIONS(5631),
    [sym_page_keyword] = ACTIONS(5629),
    [anon_sym_codeunit] = ACTIONS(5629),
    [anon_sym_CODEUNIT] = ACTIONS(5629),
    [anon_sym_Codeunit] = ACTIONS(5629),
    [anon_sym_CodeUnit] = ACTIONS(5629),
    [anon_sym_COdeunit] = ACTIONS(5629),
    [anon_sym_codeUnit] = ACTIONS(5629),
    [sym_report_keyword] = ACTIONS(5629),
    [sym_query_keyword] = ACTIONS(5629),
    [anon_sym_xmlport] = ACTIONS(5629),
    [anon_sym_XMLPORT] = ACTIONS(5629),
    [anon_sym_Xmlport] = ACTIONS(5629),
    [anon_sym_XMLport] = ACTIONS(5629),
    [anon_sym_XMLPort] = ACTIONS(5629),
    [anon_sym_XmlPort] = ACTIONS(5629),
    [anon_sym_enum] = ACTIONS(5629),
    [anon_sym_ENUM] = ACTIONS(5629),
    [anon_sym_Enum] = ACTIONS(5629),
    [anon_sym_eNUM] = ACTIONS(5629),
    [anon_sym_eNum] = ACTIONS(5629),
    [anon_sym_ENum] = ACTIONS(5629),
    [sym_quoted_identifier] = ACTIONS(5631),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5631),
    [sym_verbatim_string] = ACTIONS(5631),
    [sym_integer] = ACTIONS(5629),
    [sym_continue_as_identifier] = ACTIONS(5631),
    [sym_preproc_open] = ACTIONS(5631),
    [sym_end_keyword] = ACTIONS(5631),
  },
  [STATE(3234)] = {
    [sym_identifier] = ACTIONS(5633),
    [anon_sym_SEMI] = ACTIONS(5635),
    [anon_sym_DASH] = ACTIONS(5635),
    [aux_sym_boolean_token1] = ACTIONS(5633),
    [aux_sym_boolean_token2] = ACTIONS(5633),
    [sym_decimal] = ACTIONS(5633),
    [anon_sym_LPAREN] = ACTIONS(5635),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5633),
    [anon_sym_LBRACK] = ACTIONS(5635),
    [aux_sym_record_type_token1] = ACTIONS(5633),
    [aux_sym_basic_type_token21] = ACTIONS(5633),
    [aux_sym_basic_type_token22] = ACTIONS(5633),
    [aux_sym_basic_type_token48] = ACTIONS(5633),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5633),
    [anon_sym_POUNDif] = ACTIONS(5635),
    [anon_sym_POUNDIF] = ACTIONS(5635),
    [anon_sym_POUNDIf] = ACTIONS(5635),
    [anon_sym_not] = ACTIONS(5633),
    [anon_sym_NOT] = ACTIONS(5633),
    [anon_sym_Not] = ACTIONS(5633),
    [anon_sym_POUNDelse] = ACTIONS(5635),
    [anon_sym_POUNDELSE] = ACTIONS(5635),
    [anon_sym_POUNDElse] = ACTIONS(5635),
    [anon_sym_POUNDelse2] = ACTIONS(5635),
    [anon_sym_POUNDELSE2] = ACTIONS(5635),
    [anon_sym_POUNDElse2] = ACTIONS(5635),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5633),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5633),
    [anon_sym_PLUS] = ACTIONS(5635),
    [sym_datetime_literal] = ACTIONS(5635),
    [sym_date_literal] = ACTIONS(5633),
    [sym_time_literal] = ACTIONS(5633),
    [sym_biginteger_literal] = ACTIONS(5635),
    [anon_sym_if] = ACTIONS(5633),
    [anon_sym_IF] = ACTIONS(5633),
    [anon_sym_If] = ACTIONS(5633),
    [anon_sym_else] = ACTIONS(5633),
    [anon_sym_ELSE] = ACTIONS(5633),
    [anon_sym_Else] = ACTIONS(5633),
    [anon_sym_case] = ACTIONS(5633),
    [anon_sym_CASE] = ACTIONS(5633),
    [anon_sym_Case] = ACTIONS(5633),
    [anon_sym_for] = ACTIONS(5633),
    [anon_sym_FOR] = ACTIONS(5633),
    [anon_sym_For] = ACTIONS(5633),
    [anon_sym_foreach] = ACTIONS(5633),
    [anon_sym_FOREACH] = ACTIONS(5633),
    [anon_sym_Foreach] = ACTIONS(5633),
    [anon_sym_while] = ACTIONS(5633),
    [anon_sym_WHILE] = ACTIONS(5633),
    [anon_sym_While] = ACTIONS(5633),
    [anon_sym_repeat] = ACTIONS(5633),
    [anon_sym_REPEAT] = ACTIONS(5633),
    [anon_sym_Repeat] = ACTIONS(5633),
    [anon_sym_exit] = ACTIONS(5633),
    [anon_sym_EXIT] = ACTIONS(5633),
    [anon_sym_Exit] = ACTIONS(5633),
    [anon_sym_continue] = ACTIONS(5633),
    [anon_sym_CONTINUE] = ACTIONS(5633),
    [anon_sym_Continue] = ACTIONS(5633),
    [anon_sym_break] = ACTIONS(5633),
    [anon_sym_BREAK] = ACTIONS(5633),
    [anon_sym_Break] = ACTIONS(5633),
    [anon_sym_with] = ACTIONS(5633),
    [anon_sym_WITH] = ACTIONS(5633),
    [anon_sym_With] = ACTIONS(5633),
    [sym_asserterror_keyword] = ACTIONS(5635),
    [sym_page_keyword] = ACTIONS(5633),
    [anon_sym_codeunit] = ACTIONS(5633),
    [anon_sym_CODEUNIT] = ACTIONS(5633),
    [anon_sym_Codeunit] = ACTIONS(5633),
    [anon_sym_CodeUnit] = ACTIONS(5633),
    [anon_sym_COdeunit] = ACTIONS(5633),
    [anon_sym_codeUnit] = ACTIONS(5633),
    [sym_report_keyword] = ACTIONS(5633),
    [sym_query_keyword] = ACTIONS(5633),
    [anon_sym_xmlport] = ACTIONS(5633),
    [anon_sym_XMLPORT] = ACTIONS(5633),
    [anon_sym_Xmlport] = ACTIONS(5633),
    [anon_sym_XMLport] = ACTIONS(5633),
    [anon_sym_XMLPort] = ACTIONS(5633),
    [anon_sym_XmlPort] = ACTIONS(5633),
    [anon_sym_enum] = ACTIONS(5633),
    [anon_sym_ENUM] = ACTIONS(5633),
    [anon_sym_Enum] = ACTIONS(5633),
    [anon_sym_eNUM] = ACTIONS(5633),
    [anon_sym_eNum] = ACTIONS(5633),
    [anon_sym_ENum] = ACTIONS(5633),
    [sym_quoted_identifier] = ACTIONS(5635),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5635),
    [sym_verbatim_string] = ACTIONS(5635),
    [sym_integer] = ACTIONS(5633),
    [sym_continue_as_identifier] = ACTIONS(5635),
    [sym_preproc_open] = ACTIONS(5635),
    [sym_end_keyword] = ACTIONS(5635),
  },
  [STATE(3235)] = {
    [sym_identifier] = ACTIONS(5637),
    [anon_sym_SEMI] = ACTIONS(5639),
    [anon_sym_DASH] = ACTIONS(5639),
    [aux_sym_boolean_token1] = ACTIONS(5637),
    [aux_sym_boolean_token2] = ACTIONS(5637),
    [sym_decimal] = ACTIONS(5637),
    [anon_sym_LPAREN] = ACTIONS(5639),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5637),
    [anon_sym_LBRACK] = ACTIONS(5639),
    [aux_sym_record_type_token1] = ACTIONS(5637),
    [aux_sym_basic_type_token21] = ACTIONS(5637),
    [aux_sym_basic_type_token22] = ACTIONS(5637),
    [aux_sym_basic_type_token48] = ACTIONS(5637),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5637),
    [anon_sym_POUNDif] = ACTIONS(5639),
    [anon_sym_POUNDIF] = ACTIONS(5639),
    [anon_sym_POUNDIf] = ACTIONS(5639),
    [anon_sym_not] = ACTIONS(5637),
    [anon_sym_NOT] = ACTIONS(5637),
    [anon_sym_Not] = ACTIONS(5637),
    [anon_sym_POUNDelse] = ACTIONS(5639),
    [anon_sym_POUNDELSE] = ACTIONS(5639),
    [anon_sym_POUNDElse] = ACTIONS(5639),
    [anon_sym_POUNDelse2] = ACTIONS(5639),
    [anon_sym_POUNDELSE2] = ACTIONS(5639),
    [anon_sym_POUNDElse2] = ACTIONS(5639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5637),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5637),
    [anon_sym_PLUS] = ACTIONS(5639),
    [sym_datetime_literal] = ACTIONS(5639),
    [sym_date_literal] = ACTIONS(5637),
    [sym_time_literal] = ACTIONS(5637),
    [sym_biginteger_literal] = ACTIONS(5639),
    [anon_sym_if] = ACTIONS(5637),
    [anon_sym_IF] = ACTIONS(5637),
    [anon_sym_If] = ACTIONS(5637),
    [anon_sym_else] = ACTIONS(5637),
    [anon_sym_ELSE] = ACTIONS(5637),
    [anon_sym_Else] = ACTIONS(5637),
    [anon_sym_case] = ACTIONS(5637),
    [anon_sym_CASE] = ACTIONS(5637),
    [anon_sym_Case] = ACTIONS(5637),
    [anon_sym_for] = ACTIONS(5637),
    [anon_sym_FOR] = ACTIONS(5637),
    [anon_sym_For] = ACTIONS(5637),
    [anon_sym_foreach] = ACTIONS(5637),
    [anon_sym_FOREACH] = ACTIONS(5637),
    [anon_sym_Foreach] = ACTIONS(5637),
    [anon_sym_while] = ACTIONS(5637),
    [anon_sym_WHILE] = ACTIONS(5637),
    [anon_sym_While] = ACTIONS(5637),
    [anon_sym_repeat] = ACTIONS(5637),
    [anon_sym_REPEAT] = ACTIONS(5637),
    [anon_sym_Repeat] = ACTIONS(5637),
    [anon_sym_exit] = ACTIONS(5637),
    [anon_sym_EXIT] = ACTIONS(5637),
    [anon_sym_Exit] = ACTIONS(5637),
    [anon_sym_continue] = ACTIONS(5637),
    [anon_sym_CONTINUE] = ACTIONS(5637),
    [anon_sym_Continue] = ACTIONS(5637),
    [anon_sym_break] = ACTIONS(5637),
    [anon_sym_BREAK] = ACTIONS(5637),
    [anon_sym_Break] = ACTIONS(5637),
    [anon_sym_with] = ACTIONS(5637),
    [anon_sym_WITH] = ACTIONS(5637),
    [anon_sym_With] = ACTIONS(5637),
    [sym_asserterror_keyword] = ACTIONS(5639),
    [sym_page_keyword] = ACTIONS(5637),
    [anon_sym_codeunit] = ACTIONS(5637),
    [anon_sym_CODEUNIT] = ACTIONS(5637),
    [anon_sym_Codeunit] = ACTIONS(5637),
    [anon_sym_CodeUnit] = ACTIONS(5637),
    [anon_sym_COdeunit] = ACTIONS(5637),
    [anon_sym_codeUnit] = ACTIONS(5637),
    [sym_report_keyword] = ACTIONS(5637),
    [sym_query_keyword] = ACTIONS(5637),
    [anon_sym_xmlport] = ACTIONS(5637),
    [anon_sym_XMLPORT] = ACTIONS(5637),
    [anon_sym_Xmlport] = ACTIONS(5637),
    [anon_sym_XMLport] = ACTIONS(5637),
    [anon_sym_XMLPort] = ACTIONS(5637),
    [anon_sym_XmlPort] = ACTIONS(5637),
    [anon_sym_enum] = ACTIONS(5637),
    [anon_sym_ENUM] = ACTIONS(5637),
    [anon_sym_Enum] = ACTIONS(5637),
    [anon_sym_eNUM] = ACTIONS(5637),
    [anon_sym_eNum] = ACTIONS(5637),
    [anon_sym_ENum] = ACTIONS(5637),
    [sym_quoted_identifier] = ACTIONS(5639),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5639),
    [sym_verbatim_string] = ACTIONS(5639),
    [sym_integer] = ACTIONS(5637),
    [sym_continue_as_identifier] = ACTIONS(5639),
    [sym_preproc_open] = ACTIONS(5639),
    [sym_end_keyword] = ACTIONS(5639),
  },
  [STATE(3236)] = {
    [sym_identifier] = ACTIONS(5641),
    [anon_sym_SEMI] = ACTIONS(5643),
    [anon_sym_DASH] = ACTIONS(5643),
    [aux_sym_boolean_token1] = ACTIONS(5641),
    [aux_sym_boolean_token2] = ACTIONS(5641),
    [sym_decimal] = ACTIONS(5641),
    [anon_sym_LPAREN] = ACTIONS(5643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5641),
    [anon_sym_LBRACK] = ACTIONS(5643),
    [aux_sym_record_type_token1] = ACTIONS(5641),
    [aux_sym_basic_type_token21] = ACTIONS(5641),
    [aux_sym_basic_type_token22] = ACTIONS(5641),
    [aux_sym_basic_type_token48] = ACTIONS(5641),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5641),
    [anon_sym_POUNDif] = ACTIONS(5643),
    [anon_sym_POUNDIF] = ACTIONS(5643),
    [anon_sym_POUNDIf] = ACTIONS(5643),
    [anon_sym_not] = ACTIONS(5641),
    [anon_sym_NOT] = ACTIONS(5641),
    [anon_sym_Not] = ACTIONS(5641),
    [anon_sym_POUNDelse] = ACTIONS(5643),
    [anon_sym_POUNDELSE] = ACTIONS(5643),
    [anon_sym_POUNDElse] = ACTIONS(5643),
    [anon_sym_POUNDelse2] = ACTIONS(5643),
    [anon_sym_POUNDELSE2] = ACTIONS(5643),
    [anon_sym_POUNDElse2] = ACTIONS(5643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5641),
    [anon_sym_PLUS] = ACTIONS(5643),
    [sym_datetime_literal] = ACTIONS(5643),
    [sym_date_literal] = ACTIONS(5641),
    [sym_time_literal] = ACTIONS(5641),
    [sym_biginteger_literal] = ACTIONS(5643),
    [anon_sym_if] = ACTIONS(5641),
    [anon_sym_IF] = ACTIONS(5641),
    [anon_sym_If] = ACTIONS(5641),
    [anon_sym_else] = ACTIONS(5641),
    [anon_sym_ELSE] = ACTIONS(5641),
    [anon_sym_Else] = ACTIONS(5641),
    [anon_sym_case] = ACTIONS(5641),
    [anon_sym_CASE] = ACTIONS(5641),
    [anon_sym_Case] = ACTIONS(5641),
    [anon_sym_for] = ACTIONS(5641),
    [anon_sym_FOR] = ACTIONS(5641),
    [anon_sym_For] = ACTIONS(5641),
    [anon_sym_foreach] = ACTIONS(5641),
    [anon_sym_FOREACH] = ACTIONS(5641),
    [anon_sym_Foreach] = ACTIONS(5641),
    [anon_sym_while] = ACTIONS(5641),
    [anon_sym_WHILE] = ACTIONS(5641),
    [anon_sym_While] = ACTIONS(5641),
    [anon_sym_repeat] = ACTIONS(5641),
    [anon_sym_REPEAT] = ACTIONS(5641),
    [anon_sym_Repeat] = ACTIONS(5641),
    [anon_sym_exit] = ACTIONS(5641),
    [anon_sym_EXIT] = ACTIONS(5641),
    [anon_sym_Exit] = ACTIONS(5641),
    [anon_sym_continue] = ACTIONS(5641),
    [anon_sym_CONTINUE] = ACTIONS(5641),
    [anon_sym_Continue] = ACTIONS(5641),
    [anon_sym_break] = ACTIONS(5641),
    [anon_sym_BREAK] = ACTIONS(5641),
    [anon_sym_Break] = ACTIONS(5641),
    [anon_sym_with] = ACTIONS(5641),
    [anon_sym_WITH] = ACTIONS(5641),
    [anon_sym_With] = ACTIONS(5641),
    [sym_asserterror_keyword] = ACTIONS(5643),
    [sym_page_keyword] = ACTIONS(5641),
    [anon_sym_codeunit] = ACTIONS(5641),
    [anon_sym_CODEUNIT] = ACTIONS(5641),
    [anon_sym_Codeunit] = ACTIONS(5641),
    [anon_sym_CodeUnit] = ACTIONS(5641),
    [anon_sym_COdeunit] = ACTIONS(5641),
    [anon_sym_codeUnit] = ACTIONS(5641),
    [sym_report_keyword] = ACTIONS(5641),
    [sym_query_keyword] = ACTIONS(5641),
    [anon_sym_xmlport] = ACTIONS(5641),
    [anon_sym_XMLPORT] = ACTIONS(5641),
    [anon_sym_Xmlport] = ACTIONS(5641),
    [anon_sym_XMLport] = ACTIONS(5641),
    [anon_sym_XMLPort] = ACTIONS(5641),
    [anon_sym_XmlPort] = ACTIONS(5641),
    [anon_sym_enum] = ACTIONS(5641),
    [anon_sym_ENUM] = ACTIONS(5641),
    [anon_sym_Enum] = ACTIONS(5641),
    [anon_sym_eNUM] = ACTIONS(5641),
    [anon_sym_eNum] = ACTIONS(5641),
    [anon_sym_ENum] = ACTIONS(5641),
    [sym_quoted_identifier] = ACTIONS(5643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5643),
    [sym_verbatim_string] = ACTIONS(5643),
    [sym_integer] = ACTIONS(5641),
    [sym_continue_as_identifier] = ACTIONS(5643),
    [sym_preproc_open] = ACTIONS(5643),
    [sym_end_keyword] = ACTIONS(5643),
  },
  [STATE(3237)] = {
    [sym_identifier] = ACTIONS(5645),
    [anon_sym_SEMI] = ACTIONS(5647),
    [anon_sym_DASH] = ACTIONS(5647),
    [aux_sym_boolean_token1] = ACTIONS(5645),
    [aux_sym_boolean_token2] = ACTIONS(5645),
    [sym_decimal] = ACTIONS(5645),
    [anon_sym_LPAREN] = ACTIONS(5647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5645),
    [anon_sym_LBRACK] = ACTIONS(5647),
    [aux_sym_record_type_token1] = ACTIONS(5645),
    [aux_sym_basic_type_token21] = ACTIONS(5645),
    [aux_sym_basic_type_token22] = ACTIONS(5645),
    [aux_sym_basic_type_token48] = ACTIONS(5645),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5645),
    [anon_sym_POUNDif] = ACTIONS(5647),
    [anon_sym_POUNDIF] = ACTIONS(5647),
    [anon_sym_POUNDIf] = ACTIONS(5647),
    [anon_sym_not] = ACTIONS(5645),
    [anon_sym_NOT] = ACTIONS(5645),
    [anon_sym_Not] = ACTIONS(5645),
    [anon_sym_POUNDelse] = ACTIONS(5647),
    [anon_sym_POUNDELSE] = ACTIONS(5647),
    [anon_sym_POUNDElse] = ACTIONS(5647),
    [anon_sym_POUNDelse2] = ACTIONS(5647),
    [anon_sym_POUNDELSE2] = ACTIONS(5647),
    [anon_sym_POUNDElse2] = ACTIONS(5647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5645),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5645),
    [anon_sym_PLUS] = ACTIONS(5647),
    [sym_datetime_literal] = ACTIONS(5647),
    [sym_date_literal] = ACTIONS(5645),
    [sym_time_literal] = ACTIONS(5645),
    [sym_biginteger_literal] = ACTIONS(5647),
    [anon_sym_if] = ACTIONS(5645),
    [anon_sym_IF] = ACTIONS(5645),
    [anon_sym_If] = ACTIONS(5645),
    [anon_sym_else] = ACTIONS(5645),
    [anon_sym_ELSE] = ACTIONS(5645),
    [anon_sym_Else] = ACTIONS(5645),
    [anon_sym_case] = ACTIONS(5645),
    [anon_sym_CASE] = ACTIONS(5645),
    [anon_sym_Case] = ACTIONS(5645),
    [anon_sym_for] = ACTIONS(5645),
    [anon_sym_FOR] = ACTIONS(5645),
    [anon_sym_For] = ACTIONS(5645),
    [anon_sym_foreach] = ACTIONS(5645),
    [anon_sym_FOREACH] = ACTIONS(5645),
    [anon_sym_Foreach] = ACTIONS(5645),
    [anon_sym_while] = ACTIONS(5645),
    [anon_sym_WHILE] = ACTIONS(5645),
    [anon_sym_While] = ACTIONS(5645),
    [anon_sym_repeat] = ACTIONS(5645),
    [anon_sym_REPEAT] = ACTIONS(5645),
    [anon_sym_Repeat] = ACTIONS(5645),
    [anon_sym_exit] = ACTIONS(5645),
    [anon_sym_EXIT] = ACTIONS(5645),
    [anon_sym_Exit] = ACTIONS(5645),
    [anon_sym_continue] = ACTIONS(5645),
    [anon_sym_CONTINUE] = ACTIONS(5645),
    [anon_sym_Continue] = ACTIONS(5645),
    [anon_sym_break] = ACTIONS(5645),
    [anon_sym_BREAK] = ACTIONS(5645),
    [anon_sym_Break] = ACTIONS(5645),
    [anon_sym_with] = ACTIONS(5645),
    [anon_sym_WITH] = ACTIONS(5645),
    [anon_sym_With] = ACTIONS(5645),
    [sym_asserterror_keyword] = ACTIONS(5647),
    [sym_page_keyword] = ACTIONS(5645),
    [anon_sym_codeunit] = ACTIONS(5645),
    [anon_sym_CODEUNIT] = ACTIONS(5645),
    [anon_sym_Codeunit] = ACTIONS(5645),
    [anon_sym_CodeUnit] = ACTIONS(5645),
    [anon_sym_COdeunit] = ACTIONS(5645),
    [anon_sym_codeUnit] = ACTIONS(5645),
    [sym_report_keyword] = ACTIONS(5645),
    [sym_query_keyword] = ACTIONS(5645),
    [anon_sym_xmlport] = ACTIONS(5645),
    [anon_sym_XMLPORT] = ACTIONS(5645),
    [anon_sym_Xmlport] = ACTIONS(5645),
    [anon_sym_XMLport] = ACTIONS(5645),
    [anon_sym_XMLPort] = ACTIONS(5645),
    [anon_sym_XmlPort] = ACTIONS(5645),
    [anon_sym_enum] = ACTIONS(5645),
    [anon_sym_ENUM] = ACTIONS(5645),
    [anon_sym_Enum] = ACTIONS(5645),
    [anon_sym_eNUM] = ACTIONS(5645),
    [anon_sym_eNum] = ACTIONS(5645),
    [anon_sym_ENum] = ACTIONS(5645),
    [sym_quoted_identifier] = ACTIONS(5647),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5647),
    [sym_verbatim_string] = ACTIONS(5647),
    [sym_integer] = ACTIONS(5645),
    [sym_continue_as_identifier] = ACTIONS(5647),
    [sym_preproc_open] = ACTIONS(5647),
    [sym_end_keyword] = ACTIONS(5647),
  },
  [STATE(3238)] = {
    [sym_identifier] = ACTIONS(5649),
    [anon_sym_SEMI] = ACTIONS(5651),
    [anon_sym_DASH] = ACTIONS(5651),
    [aux_sym_boolean_token1] = ACTIONS(5649),
    [aux_sym_boolean_token2] = ACTIONS(5649),
    [sym_decimal] = ACTIONS(5649),
    [anon_sym_LPAREN] = ACTIONS(5651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5649),
    [anon_sym_LBRACK] = ACTIONS(5651),
    [aux_sym_record_type_token1] = ACTIONS(5649),
    [aux_sym_basic_type_token21] = ACTIONS(5649),
    [aux_sym_basic_type_token22] = ACTIONS(5649),
    [aux_sym_basic_type_token48] = ACTIONS(5649),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5649),
    [anon_sym_POUNDif] = ACTIONS(5651),
    [anon_sym_POUNDIF] = ACTIONS(5651),
    [anon_sym_POUNDIf] = ACTIONS(5651),
    [anon_sym_not] = ACTIONS(5649),
    [anon_sym_NOT] = ACTIONS(5649),
    [anon_sym_Not] = ACTIONS(5649),
    [anon_sym_POUNDelse] = ACTIONS(5651),
    [anon_sym_POUNDELSE] = ACTIONS(5651),
    [anon_sym_POUNDElse] = ACTIONS(5651),
    [anon_sym_POUNDelse2] = ACTIONS(5651),
    [anon_sym_POUNDELSE2] = ACTIONS(5651),
    [anon_sym_POUNDElse2] = ACTIONS(5651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5649),
    [anon_sym_PLUS] = ACTIONS(5651),
    [sym_datetime_literal] = ACTIONS(5651),
    [sym_date_literal] = ACTIONS(5649),
    [sym_time_literal] = ACTIONS(5649),
    [sym_biginteger_literal] = ACTIONS(5651),
    [anon_sym_if] = ACTIONS(5649),
    [anon_sym_IF] = ACTIONS(5649),
    [anon_sym_If] = ACTIONS(5649),
    [anon_sym_else] = ACTIONS(5649),
    [anon_sym_ELSE] = ACTIONS(5649),
    [anon_sym_Else] = ACTIONS(5649),
    [anon_sym_case] = ACTIONS(5649),
    [anon_sym_CASE] = ACTIONS(5649),
    [anon_sym_Case] = ACTIONS(5649),
    [anon_sym_for] = ACTIONS(5649),
    [anon_sym_FOR] = ACTIONS(5649),
    [anon_sym_For] = ACTIONS(5649),
    [anon_sym_foreach] = ACTIONS(5649),
    [anon_sym_FOREACH] = ACTIONS(5649),
    [anon_sym_Foreach] = ACTIONS(5649),
    [anon_sym_while] = ACTIONS(5649),
    [anon_sym_WHILE] = ACTIONS(5649),
    [anon_sym_While] = ACTIONS(5649),
    [anon_sym_repeat] = ACTIONS(5649),
    [anon_sym_REPEAT] = ACTIONS(5649),
    [anon_sym_Repeat] = ACTIONS(5649),
    [anon_sym_exit] = ACTIONS(5649),
    [anon_sym_EXIT] = ACTIONS(5649),
    [anon_sym_Exit] = ACTIONS(5649),
    [anon_sym_continue] = ACTIONS(5649),
    [anon_sym_CONTINUE] = ACTIONS(5649),
    [anon_sym_Continue] = ACTIONS(5649),
    [anon_sym_break] = ACTIONS(5649),
    [anon_sym_BREAK] = ACTIONS(5649),
    [anon_sym_Break] = ACTIONS(5649),
    [anon_sym_with] = ACTIONS(5649),
    [anon_sym_WITH] = ACTIONS(5649),
    [anon_sym_With] = ACTIONS(5649),
    [sym_asserterror_keyword] = ACTIONS(5651),
    [sym_page_keyword] = ACTIONS(5649),
    [anon_sym_codeunit] = ACTIONS(5649),
    [anon_sym_CODEUNIT] = ACTIONS(5649),
    [anon_sym_Codeunit] = ACTIONS(5649),
    [anon_sym_CodeUnit] = ACTIONS(5649),
    [anon_sym_COdeunit] = ACTIONS(5649),
    [anon_sym_codeUnit] = ACTIONS(5649),
    [sym_report_keyword] = ACTIONS(5649),
    [sym_query_keyword] = ACTIONS(5649),
    [anon_sym_xmlport] = ACTIONS(5649),
    [anon_sym_XMLPORT] = ACTIONS(5649),
    [anon_sym_Xmlport] = ACTIONS(5649),
    [anon_sym_XMLport] = ACTIONS(5649),
    [anon_sym_XMLPort] = ACTIONS(5649),
    [anon_sym_XmlPort] = ACTIONS(5649),
    [anon_sym_enum] = ACTIONS(5649),
    [anon_sym_ENUM] = ACTIONS(5649),
    [anon_sym_Enum] = ACTIONS(5649),
    [anon_sym_eNUM] = ACTIONS(5649),
    [anon_sym_eNum] = ACTIONS(5649),
    [anon_sym_ENum] = ACTIONS(5649),
    [sym_quoted_identifier] = ACTIONS(5651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5651),
    [sym_verbatim_string] = ACTIONS(5651),
    [sym_integer] = ACTIONS(5649),
    [sym_continue_as_identifier] = ACTIONS(5651),
    [sym_preproc_open] = ACTIONS(5651),
    [sym_end_keyword] = ACTIONS(5651),
  },
  [STATE(3239)] = {
    [sym_identifier] = ACTIONS(6320),
    [anon_sym_SEMI] = ACTIONS(6322),
    [anon_sym_DASH] = ACTIONS(6322),
    [aux_sym_boolean_token1] = ACTIONS(6320),
    [aux_sym_boolean_token2] = ACTIONS(6320),
    [sym_decimal] = ACTIONS(6320),
    [anon_sym_LPAREN] = ACTIONS(6322),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6320),
    [anon_sym_LBRACK] = ACTIONS(6322),
    [aux_sym_record_type_token1] = ACTIONS(6320),
    [aux_sym_basic_type_token21] = ACTIONS(6320),
    [aux_sym_basic_type_token22] = ACTIONS(6320),
    [aux_sym_basic_type_token48] = ACTIONS(6320),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6320),
    [anon_sym_POUNDif] = ACTIONS(6322),
    [anon_sym_POUNDIF] = ACTIONS(6322),
    [anon_sym_POUNDIf] = ACTIONS(6322),
    [anon_sym_not] = ACTIONS(6320),
    [anon_sym_NOT] = ACTIONS(6320),
    [anon_sym_Not] = ACTIONS(6320),
    [anon_sym_POUNDelse] = ACTIONS(6322),
    [anon_sym_POUNDELSE] = ACTIONS(6322),
    [anon_sym_POUNDElse] = ACTIONS(6322),
    [anon_sym_POUNDelse2] = ACTIONS(6322),
    [anon_sym_POUNDELSE2] = ACTIONS(6322),
    [anon_sym_POUNDElse2] = ACTIONS(6322),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6320),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6320),
    [anon_sym_PLUS] = ACTIONS(6322),
    [sym_datetime_literal] = ACTIONS(6322),
    [sym_date_literal] = ACTIONS(6320),
    [sym_time_literal] = ACTIONS(6320),
    [sym_biginteger_literal] = ACTIONS(6322),
    [anon_sym_if] = ACTIONS(6320),
    [anon_sym_IF] = ACTIONS(6320),
    [anon_sym_If] = ACTIONS(6320),
    [anon_sym_else] = ACTIONS(6320),
    [anon_sym_ELSE] = ACTIONS(6320),
    [anon_sym_Else] = ACTIONS(6320),
    [anon_sym_case] = ACTIONS(6320),
    [anon_sym_CASE] = ACTIONS(6320),
    [anon_sym_Case] = ACTIONS(6320),
    [anon_sym_for] = ACTIONS(6320),
    [anon_sym_FOR] = ACTIONS(6320),
    [anon_sym_For] = ACTIONS(6320),
    [anon_sym_foreach] = ACTIONS(6320),
    [anon_sym_FOREACH] = ACTIONS(6320),
    [anon_sym_Foreach] = ACTIONS(6320),
    [anon_sym_while] = ACTIONS(6320),
    [anon_sym_WHILE] = ACTIONS(6320),
    [anon_sym_While] = ACTIONS(6320),
    [anon_sym_repeat] = ACTIONS(6320),
    [anon_sym_REPEAT] = ACTIONS(6320),
    [anon_sym_Repeat] = ACTIONS(6320),
    [anon_sym_exit] = ACTIONS(6320),
    [anon_sym_EXIT] = ACTIONS(6320),
    [anon_sym_Exit] = ACTIONS(6320),
    [anon_sym_continue] = ACTIONS(6320),
    [anon_sym_CONTINUE] = ACTIONS(6320),
    [anon_sym_Continue] = ACTIONS(6320),
    [anon_sym_break] = ACTIONS(6320),
    [anon_sym_BREAK] = ACTIONS(6320),
    [anon_sym_Break] = ACTIONS(6320),
    [anon_sym_with] = ACTIONS(6320),
    [anon_sym_WITH] = ACTIONS(6320),
    [anon_sym_With] = ACTIONS(6320),
    [sym_asserterror_keyword] = ACTIONS(6322),
    [sym_page_keyword] = ACTIONS(6320),
    [anon_sym_codeunit] = ACTIONS(6320),
    [anon_sym_CODEUNIT] = ACTIONS(6320),
    [anon_sym_Codeunit] = ACTIONS(6320),
    [anon_sym_CodeUnit] = ACTIONS(6320),
    [anon_sym_COdeunit] = ACTIONS(6320),
    [anon_sym_codeUnit] = ACTIONS(6320),
    [sym_report_keyword] = ACTIONS(6320),
    [sym_query_keyword] = ACTIONS(6320),
    [anon_sym_xmlport] = ACTIONS(6320),
    [anon_sym_XMLPORT] = ACTIONS(6320),
    [anon_sym_Xmlport] = ACTIONS(6320),
    [anon_sym_XMLport] = ACTIONS(6320),
    [anon_sym_XMLPort] = ACTIONS(6320),
    [anon_sym_XmlPort] = ACTIONS(6320),
    [anon_sym_enum] = ACTIONS(6320),
    [anon_sym_ENUM] = ACTIONS(6320),
    [anon_sym_Enum] = ACTIONS(6320),
    [anon_sym_eNUM] = ACTIONS(6320),
    [anon_sym_eNum] = ACTIONS(6320),
    [anon_sym_ENum] = ACTIONS(6320),
    [sym_quoted_identifier] = ACTIONS(6322),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6322),
    [sym_verbatim_string] = ACTIONS(6322),
    [sym_integer] = ACTIONS(6320),
    [sym_continue_as_identifier] = ACTIONS(6322),
    [sym_preproc_open] = ACTIONS(6322),
    [sym_end_keyword] = ACTIONS(6322),
  },
  [STATE(3240)] = {
    [sym_identifier] = ACTIONS(6316),
    [anon_sym_SEMI] = ACTIONS(6318),
    [anon_sym_DASH] = ACTIONS(6318),
    [aux_sym_boolean_token1] = ACTIONS(6316),
    [aux_sym_boolean_token2] = ACTIONS(6316),
    [sym_decimal] = ACTIONS(6316),
    [anon_sym_LPAREN] = ACTIONS(6318),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6316),
    [anon_sym_LBRACK] = ACTIONS(6318),
    [aux_sym_record_type_token1] = ACTIONS(6316),
    [aux_sym_basic_type_token21] = ACTIONS(6316),
    [aux_sym_basic_type_token22] = ACTIONS(6316),
    [aux_sym_basic_type_token48] = ACTIONS(6316),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6316),
    [anon_sym_POUNDif] = ACTIONS(6318),
    [anon_sym_POUNDIF] = ACTIONS(6318),
    [anon_sym_POUNDIf] = ACTIONS(6318),
    [anon_sym_not] = ACTIONS(6316),
    [anon_sym_NOT] = ACTIONS(6316),
    [anon_sym_Not] = ACTIONS(6316),
    [anon_sym_POUNDelse] = ACTIONS(6318),
    [anon_sym_POUNDELSE] = ACTIONS(6318),
    [anon_sym_POUNDElse] = ACTIONS(6318),
    [anon_sym_POUNDelse2] = ACTIONS(6318),
    [anon_sym_POUNDELSE2] = ACTIONS(6318),
    [anon_sym_POUNDElse2] = ACTIONS(6318),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6316),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6316),
    [anon_sym_PLUS] = ACTIONS(6318),
    [sym_datetime_literal] = ACTIONS(6318),
    [sym_date_literal] = ACTIONS(6316),
    [sym_time_literal] = ACTIONS(6316),
    [sym_biginteger_literal] = ACTIONS(6318),
    [anon_sym_if] = ACTIONS(6316),
    [anon_sym_IF] = ACTIONS(6316),
    [anon_sym_If] = ACTIONS(6316),
    [anon_sym_else] = ACTIONS(6316),
    [anon_sym_ELSE] = ACTIONS(6316),
    [anon_sym_Else] = ACTIONS(6316),
    [anon_sym_case] = ACTIONS(6316),
    [anon_sym_CASE] = ACTIONS(6316),
    [anon_sym_Case] = ACTIONS(6316),
    [anon_sym_for] = ACTIONS(6316),
    [anon_sym_FOR] = ACTIONS(6316),
    [anon_sym_For] = ACTIONS(6316),
    [anon_sym_foreach] = ACTIONS(6316),
    [anon_sym_FOREACH] = ACTIONS(6316),
    [anon_sym_Foreach] = ACTIONS(6316),
    [anon_sym_while] = ACTIONS(6316),
    [anon_sym_WHILE] = ACTIONS(6316),
    [anon_sym_While] = ACTIONS(6316),
    [anon_sym_repeat] = ACTIONS(6316),
    [anon_sym_REPEAT] = ACTIONS(6316),
    [anon_sym_Repeat] = ACTIONS(6316),
    [anon_sym_exit] = ACTIONS(6316),
    [anon_sym_EXIT] = ACTIONS(6316),
    [anon_sym_Exit] = ACTIONS(6316),
    [anon_sym_continue] = ACTIONS(6316),
    [anon_sym_CONTINUE] = ACTIONS(6316),
    [anon_sym_Continue] = ACTIONS(6316),
    [anon_sym_break] = ACTIONS(6316),
    [anon_sym_BREAK] = ACTIONS(6316),
    [anon_sym_Break] = ACTIONS(6316),
    [anon_sym_with] = ACTIONS(6316),
    [anon_sym_WITH] = ACTIONS(6316),
    [anon_sym_With] = ACTIONS(6316),
    [sym_asserterror_keyword] = ACTIONS(6318),
    [sym_page_keyword] = ACTIONS(6316),
    [anon_sym_codeunit] = ACTIONS(6316),
    [anon_sym_CODEUNIT] = ACTIONS(6316),
    [anon_sym_Codeunit] = ACTIONS(6316),
    [anon_sym_CodeUnit] = ACTIONS(6316),
    [anon_sym_COdeunit] = ACTIONS(6316),
    [anon_sym_codeUnit] = ACTIONS(6316),
    [sym_report_keyword] = ACTIONS(6316),
    [sym_query_keyword] = ACTIONS(6316),
    [anon_sym_xmlport] = ACTIONS(6316),
    [anon_sym_XMLPORT] = ACTIONS(6316),
    [anon_sym_Xmlport] = ACTIONS(6316),
    [anon_sym_XMLport] = ACTIONS(6316),
    [anon_sym_XMLPort] = ACTIONS(6316),
    [anon_sym_XmlPort] = ACTIONS(6316),
    [anon_sym_enum] = ACTIONS(6316),
    [anon_sym_ENUM] = ACTIONS(6316),
    [anon_sym_Enum] = ACTIONS(6316),
    [anon_sym_eNUM] = ACTIONS(6316),
    [anon_sym_eNum] = ACTIONS(6316),
    [anon_sym_ENum] = ACTIONS(6316),
    [sym_quoted_identifier] = ACTIONS(6318),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6318),
    [sym_verbatim_string] = ACTIONS(6318),
    [sym_integer] = ACTIONS(6316),
    [sym_continue_as_identifier] = ACTIONS(6318),
    [sym_preproc_open] = ACTIONS(6318),
    [sym_end_keyword] = ACTIONS(6318),
  },
  [STATE(3241)] = {
    [sym_boolean] = STATE(7226),
    [sym_option_member_list] = STATE(7208),
    [sym_option_member] = STATE(8485),
    [sym_keyword_identifier] = STATE(7226),
    [sym_codeunit_keyword] = STATE(6858),
    [sym_xmlport_keyword] = STATE(6858),
    [sym_enum_keyword] = STATE(6858),
    [sym_keyword_as_identifier] = STATE(7226),
    [aux_sym_option_member_list_repeat2] = STATE(3415),
    [sym_identifier] = ACTIONS(3993),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_DOT] = ACTIONS(584),
    [anon_sym_EQ] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(7329),
    [anon_sym_DASH] = ACTIONS(6032),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [aux_sym_where_condition_token1] = ACTIONS(7225),
    [anon_sym_DOT_DOT] = ACTIONS(582),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(6034),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7225),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7225),
    [aux_sym_separator_action_token1] = ACTIONS(7225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7225),
    [aux_sym_type_declaration_token1] = ACTIONS(7225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(582),
    [aux_sym__expression_token1] = ACTIONS(582),
    [aux_sym__expression_token2] = ACTIONS(582),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1382),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_div] = ACTIONS(584),
    [anon_sym_DIV] = ACTIONS(584),
    [anon_sym_Div] = ACTIONS(584),
    [anon_sym_mod] = ACTIONS(584),
    [anon_sym_MOD] = ACTIONS(584),
    [anon_sym_Mod] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_GT] = ACTIONS(582),
    [anon_sym_and] = ACTIONS(584),
    [anon_sym_AND] = ACTIONS(584),
    [anon_sym_And] = ACTIONS(584),
    [anon_sym_or] = ACTIONS(584),
    [anon_sym_OR] = ACTIONS(584),
    [anon_sym_Or] = ACTIONS(584),
    [anon_sym_xor] = ACTIONS(584),
    [anon_sym_XOR] = ACTIONS(584),
    [anon_sym_Xor] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(584),
    [anon_sym_ELSE] = ACTIONS(584),
    [anon_sym_Else] = ACTIONS(584),
    [anon_sym_in] = ACTIONS(584),
    [anon_sym_IN] = ACTIONS(584),
    [anon_sym_In] = ACTIONS(584),
    [sym_table_keyword] = ACTIONS(7225),
    [sym_page_keyword] = ACTIONS(1382),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1382),
    [sym_query_keyword] = ACTIONS(1382),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(7225),
    [sym_dataset_keyword] = ACTIONS(7225),
    [sym_quoted_identifier] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6036),
    [sym_integer] = ACTIONS(6036),
  },
  [STATE(3242)] = {
    [sym_identifier] = ACTIONS(5653),
    [anon_sym_SEMI] = ACTIONS(5655),
    [anon_sym_DASH] = ACTIONS(5655),
    [aux_sym_boolean_token1] = ACTIONS(5653),
    [aux_sym_boolean_token2] = ACTIONS(5653),
    [sym_decimal] = ACTIONS(5653),
    [anon_sym_LPAREN] = ACTIONS(5655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5653),
    [anon_sym_LBRACK] = ACTIONS(5655),
    [aux_sym_record_type_token1] = ACTIONS(5653),
    [aux_sym_basic_type_token21] = ACTIONS(5653),
    [aux_sym_basic_type_token22] = ACTIONS(5653),
    [aux_sym_basic_type_token48] = ACTIONS(5653),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5653),
    [anon_sym_POUNDif] = ACTIONS(5655),
    [anon_sym_POUNDIF] = ACTIONS(5655),
    [anon_sym_POUNDIf] = ACTIONS(5655),
    [anon_sym_not] = ACTIONS(5653),
    [anon_sym_NOT] = ACTIONS(5653),
    [anon_sym_Not] = ACTIONS(5653),
    [anon_sym_POUNDelse] = ACTIONS(5655),
    [anon_sym_POUNDELSE] = ACTIONS(5655),
    [anon_sym_POUNDElse] = ACTIONS(5655),
    [anon_sym_POUNDelse2] = ACTIONS(5655),
    [anon_sym_POUNDELSE2] = ACTIONS(5655),
    [anon_sym_POUNDElse2] = ACTIONS(5655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5653),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5653),
    [anon_sym_PLUS] = ACTIONS(5655),
    [sym_datetime_literal] = ACTIONS(5655),
    [sym_date_literal] = ACTIONS(5653),
    [sym_time_literal] = ACTIONS(5653),
    [sym_biginteger_literal] = ACTIONS(5655),
    [anon_sym_if] = ACTIONS(5653),
    [anon_sym_IF] = ACTIONS(5653),
    [anon_sym_If] = ACTIONS(5653),
    [anon_sym_else] = ACTIONS(5653),
    [anon_sym_ELSE] = ACTIONS(5653),
    [anon_sym_Else] = ACTIONS(5653),
    [anon_sym_case] = ACTIONS(5653),
    [anon_sym_CASE] = ACTIONS(5653),
    [anon_sym_Case] = ACTIONS(5653),
    [anon_sym_for] = ACTIONS(5653),
    [anon_sym_FOR] = ACTIONS(5653),
    [anon_sym_For] = ACTIONS(5653),
    [anon_sym_foreach] = ACTIONS(5653),
    [anon_sym_FOREACH] = ACTIONS(5653),
    [anon_sym_Foreach] = ACTIONS(5653),
    [anon_sym_while] = ACTIONS(5653),
    [anon_sym_WHILE] = ACTIONS(5653),
    [anon_sym_While] = ACTIONS(5653),
    [anon_sym_repeat] = ACTIONS(5653),
    [anon_sym_REPEAT] = ACTIONS(5653),
    [anon_sym_Repeat] = ACTIONS(5653),
    [anon_sym_exit] = ACTIONS(5653),
    [anon_sym_EXIT] = ACTIONS(5653),
    [anon_sym_Exit] = ACTIONS(5653),
    [anon_sym_continue] = ACTIONS(5653),
    [anon_sym_CONTINUE] = ACTIONS(5653),
    [anon_sym_Continue] = ACTIONS(5653),
    [anon_sym_break] = ACTIONS(5653),
    [anon_sym_BREAK] = ACTIONS(5653),
    [anon_sym_Break] = ACTIONS(5653),
    [anon_sym_with] = ACTIONS(5653),
    [anon_sym_WITH] = ACTIONS(5653),
    [anon_sym_With] = ACTIONS(5653),
    [sym_asserterror_keyword] = ACTIONS(5655),
    [sym_page_keyword] = ACTIONS(5653),
    [anon_sym_codeunit] = ACTIONS(5653),
    [anon_sym_CODEUNIT] = ACTIONS(5653),
    [anon_sym_Codeunit] = ACTIONS(5653),
    [anon_sym_CodeUnit] = ACTIONS(5653),
    [anon_sym_COdeunit] = ACTIONS(5653),
    [anon_sym_codeUnit] = ACTIONS(5653),
    [sym_report_keyword] = ACTIONS(5653),
    [sym_query_keyword] = ACTIONS(5653),
    [anon_sym_xmlport] = ACTIONS(5653),
    [anon_sym_XMLPORT] = ACTIONS(5653),
    [anon_sym_Xmlport] = ACTIONS(5653),
    [anon_sym_XMLport] = ACTIONS(5653),
    [anon_sym_XMLPort] = ACTIONS(5653),
    [anon_sym_XmlPort] = ACTIONS(5653),
    [anon_sym_enum] = ACTIONS(5653),
    [anon_sym_ENUM] = ACTIONS(5653),
    [anon_sym_Enum] = ACTIONS(5653),
    [anon_sym_eNUM] = ACTIONS(5653),
    [anon_sym_eNum] = ACTIONS(5653),
    [anon_sym_ENum] = ACTIONS(5653),
    [sym_quoted_identifier] = ACTIONS(5655),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5655),
    [sym_verbatim_string] = ACTIONS(5655),
    [sym_integer] = ACTIONS(5653),
    [sym_continue_as_identifier] = ACTIONS(5655),
    [sym_preproc_open] = ACTIONS(5655),
    [sym_end_keyword] = ACTIONS(5655),
  },
  [STATE(3243)] = {
    [sym_identifier] = ACTIONS(5657),
    [anon_sym_SEMI] = ACTIONS(5659),
    [anon_sym_DASH] = ACTIONS(5659),
    [aux_sym_boolean_token1] = ACTIONS(5657),
    [aux_sym_boolean_token2] = ACTIONS(5657),
    [sym_decimal] = ACTIONS(5657),
    [anon_sym_LPAREN] = ACTIONS(5659),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5657),
    [anon_sym_LBRACK] = ACTIONS(5659),
    [aux_sym_record_type_token1] = ACTIONS(5657),
    [aux_sym_basic_type_token21] = ACTIONS(5657),
    [aux_sym_basic_type_token22] = ACTIONS(5657),
    [aux_sym_basic_type_token48] = ACTIONS(5657),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5657),
    [anon_sym_POUNDif] = ACTIONS(5659),
    [anon_sym_POUNDIF] = ACTIONS(5659),
    [anon_sym_POUNDIf] = ACTIONS(5659),
    [anon_sym_not] = ACTIONS(5657),
    [anon_sym_NOT] = ACTIONS(5657),
    [anon_sym_Not] = ACTIONS(5657),
    [anon_sym_POUNDelse] = ACTIONS(5659),
    [anon_sym_POUNDELSE] = ACTIONS(5659),
    [anon_sym_POUNDElse] = ACTIONS(5659),
    [anon_sym_POUNDelse2] = ACTIONS(5659),
    [anon_sym_POUNDELSE2] = ACTIONS(5659),
    [anon_sym_POUNDElse2] = ACTIONS(5659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5657),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5657),
    [anon_sym_PLUS] = ACTIONS(5659),
    [sym_datetime_literal] = ACTIONS(5659),
    [sym_date_literal] = ACTIONS(5657),
    [sym_time_literal] = ACTIONS(5657),
    [sym_biginteger_literal] = ACTIONS(5659),
    [anon_sym_if] = ACTIONS(5657),
    [anon_sym_IF] = ACTIONS(5657),
    [anon_sym_If] = ACTIONS(5657),
    [anon_sym_else] = ACTIONS(5657),
    [anon_sym_ELSE] = ACTIONS(5657),
    [anon_sym_Else] = ACTIONS(5657),
    [anon_sym_case] = ACTIONS(5657),
    [anon_sym_CASE] = ACTIONS(5657),
    [anon_sym_Case] = ACTIONS(5657),
    [anon_sym_for] = ACTIONS(5657),
    [anon_sym_FOR] = ACTIONS(5657),
    [anon_sym_For] = ACTIONS(5657),
    [anon_sym_foreach] = ACTIONS(5657),
    [anon_sym_FOREACH] = ACTIONS(5657),
    [anon_sym_Foreach] = ACTIONS(5657),
    [anon_sym_while] = ACTIONS(5657),
    [anon_sym_WHILE] = ACTIONS(5657),
    [anon_sym_While] = ACTIONS(5657),
    [anon_sym_repeat] = ACTIONS(5657),
    [anon_sym_REPEAT] = ACTIONS(5657),
    [anon_sym_Repeat] = ACTIONS(5657),
    [anon_sym_exit] = ACTIONS(5657),
    [anon_sym_EXIT] = ACTIONS(5657),
    [anon_sym_Exit] = ACTIONS(5657),
    [anon_sym_continue] = ACTIONS(5657),
    [anon_sym_CONTINUE] = ACTIONS(5657),
    [anon_sym_Continue] = ACTIONS(5657),
    [anon_sym_break] = ACTIONS(5657),
    [anon_sym_BREAK] = ACTIONS(5657),
    [anon_sym_Break] = ACTIONS(5657),
    [anon_sym_with] = ACTIONS(5657),
    [anon_sym_WITH] = ACTIONS(5657),
    [anon_sym_With] = ACTIONS(5657),
    [sym_asserterror_keyword] = ACTIONS(5659),
    [sym_page_keyword] = ACTIONS(5657),
    [anon_sym_codeunit] = ACTIONS(5657),
    [anon_sym_CODEUNIT] = ACTIONS(5657),
    [anon_sym_Codeunit] = ACTIONS(5657),
    [anon_sym_CodeUnit] = ACTIONS(5657),
    [anon_sym_COdeunit] = ACTIONS(5657),
    [anon_sym_codeUnit] = ACTIONS(5657),
    [sym_report_keyword] = ACTIONS(5657),
    [sym_query_keyword] = ACTIONS(5657),
    [anon_sym_xmlport] = ACTIONS(5657),
    [anon_sym_XMLPORT] = ACTIONS(5657),
    [anon_sym_Xmlport] = ACTIONS(5657),
    [anon_sym_XMLport] = ACTIONS(5657),
    [anon_sym_XMLPort] = ACTIONS(5657),
    [anon_sym_XmlPort] = ACTIONS(5657),
    [anon_sym_enum] = ACTIONS(5657),
    [anon_sym_ENUM] = ACTIONS(5657),
    [anon_sym_Enum] = ACTIONS(5657),
    [anon_sym_eNUM] = ACTIONS(5657),
    [anon_sym_eNum] = ACTIONS(5657),
    [anon_sym_ENum] = ACTIONS(5657),
    [sym_quoted_identifier] = ACTIONS(5659),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5659),
    [sym_verbatim_string] = ACTIONS(5659),
    [sym_integer] = ACTIONS(5657),
    [sym_continue_as_identifier] = ACTIONS(5659),
    [sym_preproc_open] = ACTIONS(5659),
    [sym_end_keyword] = ACTIONS(5659),
  },
  [STATE(3244)] = {
    [sym_identifier] = ACTIONS(6308),
    [anon_sym_SEMI] = ACTIONS(6310),
    [anon_sym_DASH] = ACTIONS(6310),
    [aux_sym_boolean_token1] = ACTIONS(6308),
    [aux_sym_boolean_token2] = ACTIONS(6308),
    [sym_decimal] = ACTIONS(6308),
    [anon_sym_LPAREN] = ACTIONS(6310),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6308),
    [anon_sym_LBRACK] = ACTIONS(6310),
    [aux_sym_record_type_token1] = ACTIONS(6308),
    [aux_sym_basic_type_token21] = ACTIONS(6308),
    [aux_sym_basic_type_token22] = ACTIONS(6308),
    [aux_sym_basic_type_token48] = ACTIONS(6308),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6308),
    [anon_sym_POUNDif] = ACTIONS(6310),
    [anon_sym_POUNDIF] = ACTIONS(6310),
    [anon_sym_POUNDIf] = ACTIONS(6310),
    [anon_sym_not] = ACTIONS(6308),
    [anon_sym_NOT] = ACTIONS(6308),
    [anon_sym_Not] = ACTIONS(6308),
    [anon_sym_POUNDelse] = ACTIONS(6310),
    [anon_sym_POUNDELSE] = ACTIONS(6310),
    [anon_sym_POUNDElse] = ACTIONS(6310),
    [anon_sym_POUNDelse2] = ACTIONS(6310),
    [anon_sym_POUNDELSE2] = ACTIONS(6310),
    [anon_sym_POUNDElse2] = ACTIONS(6310),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6308),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6308),
    [anon_sym_PLUS] = ACTIONS(6310),
    [sym_datetime_literal] = ACTIONS(6310),
    [sym_date_literal] = ACTIONS(6308),
    [sym_time_literal] = ACTIONS(6308),
    [sym_biginteger_literal] = ACTIONS(6310),
    [anon_sym_if] = ACTIONS(6308),
    [anon_sym_IF] = ACTIONS(6308),
    [anon_sym_If] = ACTIONS(6308),
    [anon_sym_else] = ACTIONS(6308),
    [anon_sym_ELSE] = ACTIONS(6308),
    [anon_sym_Else] = ACTIONS(6308),
    [anon_sym_case] = ACTIONS(6308),
    [anon_sym_CASE] = ACTIONS(6308),
    [anon_sym_Case] = ACTIONS(6308),
    [anon_sym_for] = ACTIONS(6308),
    [anon_sym_FOR] = ACTIONS(6308),
    [anon_sym_For] = ACTIONS(6308),
    [anon_sym_foreach] = ACTIONS(6308),
    [anon_sym_FOREACH] = ACTIONS(6308),
    [anon_sym_Foreach] = ACTIONS(6308),
    [anon_sym_while] = ACTIONS(6308),
    [anon_sym_WHILE] = ACTIONS(6308),
    [anon_sym_While] = ACTIONS(6308),
    [anon_sym_repeat] = ACTIONS(6308),
    [anon_sym_REPEAT] = ACTIONS(6308),
    [anon_sym_Repeat] = ACTIONS(6308),
    [anon_sym_exit] = ACTIONS(6308),
    [anon_sym_EXIT] = ACTIONS(6308),
    [anon_sym_Exit] = ACTIONS(6308),
    [anon_sym_continue] = ACTIONS(6308),
    [anon_sym_CONTINUE] = ACTIONS(6308),
    [anon_sym_Continue] = ACTIONS(6308),
    [anon_sym_break] = ACTIONS(6308),
    [anon_sym_BREAK] = ACTIONS(6308),
    [anon_sym_Break] = ACTIONS(6308),
    [anon_sym_with] = ACTIONS(6308),
    [anon_sym_WITH] = ACTIONS(6308),
    [anon_sym_With] = ACTIONS(6308),
    [sym_asserterror_keyword] = ACTIONS(6310),
    [sym_page_keyword] = ACTIONS(6308),
    [anon_sym_codeunit] = ACTIONS(6308),
    [anon_sym_CODEUNIT] = ACTIONS(6308),
    [anon_sym_Codeunit] = ACTIONS(6308),
    [anon_sym_CodeUnit] = ACTIONS(6308),
    [anon_sym_COdeunit] = ACTIONS(6308),
    [anon_sym_codeUnit] = ACTIONS(6308),
    [sym_report_keyword] = ACTIONS(6308),
    [sym_query_keyword] = ACTIONS(6308),
    [anon_sym_xmlport] = ACTIONS(6308),
    [anon_sym_XMLPORT] = ACTIONS(6308),
    [anon_sym_Xmlport] = ACTIONS(6308),
    [anon_sym_XMLport] = ACTIONS(6308),
    [anon_sym_XMLPort] = ACTIONS(6308),
    [anon_sym_XmlPort] = ACTIONS(6308),
    [anon_sym_enum] = ACTIONS(6308),
    [anon_sym_ENUM] = ACTIONS(6308),
    [anon_sym_Enum] = ACTIONS(6308),
    [anon_sym_eNUM] = ACTIONS(6308),
    [anon_sym_eNum] = ACTIONS(6308),
    [anon_sym_ENum] = ACTIONS(6308),
    [sym_quoted_identifier] = ACTIONS(6310),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6310),
    [sym_verbatim_string] = ACTIONS(6310),
    [sym_integer] = ACTIONS(6308),
    [sym_continue_as_identifier] = ACTIONS(6310),
    [sym_preproc_open] = ACTIONS(6310),
    [sym_end_keyword] = ACTIONS(6310),
  },
  [STATE(3245)] = {
    [sym_identifier] = ACTIONS(6324),
    [anon_sym_SEMI] = ACTIONS(6326),
    [anon_sym_DASH] = ACTIONS(6326),
    [aux_sym_boolean_token1] = ACTIONS(6324),
    [aux_sym_boolean_token2] = ACTIONS(6324),
    [sym_decimal] = ACTIONS(6324),
    [anon_sym_LPAREN] = ACTIONS(6326),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6324),
    [anon_sym_LBRACK] = ACTIONS(6326),
    [aux_sym_record_type_token1] = ACTIONS(6324),
    [aux_sym_basic_type_token21] = ACTIONS(6324),
    [aux_sym_basic_type_token22] = ACTIONS(6324),
    [aux_sym_basic_type_token48] = ACTIONS(6324),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6324),
    [anon_sym_POUNDif] = ACTIONS(6326),
    [anon_sym_POUNDIF] = ACTIONS(6326),
    [anon_sym_POUNDIf] = ACTIONS(6326),
    [anon_sym_not] = ACTIONS(6324),
    [anon_sym_NOT] = ACTIONS(6324),
    [anon_sym_Not] = ACTIONS(6324),
    [anon_sym_POUNDelse] = ACTIONS(6326),
    [anon_sym_POUNDELSE] = ACTIONS(6326),
    [anon_sym_POUNDElse] = ACTIONS(6326),
    [anon_sym_POUNDelse2] = ACTIONS(6326),
    [anon_sym_POUNDELSE2] = ACTIONS(6326),
    [anon_sym_POUNDElse2] = ACTIONS(6326),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6324),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6324),
    [anon_sym_PLUS] = ACTIONS(6326),
    [sym_datetime_literal] = ACTIONS(6326),
    [sym_date_literal] = ACTIONS(6324),
    [sym_time_literal] = ACTIONS(6324),
    [sym_biginteger_literal] = ACTIONS(6326),
    [anon_sym_if] = ACTIONS(6324),
    [anon_sym_IF] = ACTIONS(6324),
    [anon_sym_If] = ACTIONS(6324),
    [anon_sym_else] = ACTIONS(6324),
    [anon_sym_ELSE] = ACTIONS(6324),
    [anon_sym_Else] = ACTIONS(6324),
    [anon_sym_case] = ACTIONS(6324),
    [anon_sym_CASE] = ACTIONS(6324),
    [anon_sym_Case] = ACTIONS(6324),
    [anon_sym_for] = ACTIONS(6324),
    [anon_sym_FOR] = ACTIONS(6324),
    [anon_sym_For] = ACTIONS(6324),
    [anon_sym_foreach] = ACTIONS(6324),
    [anon_sym_FOREACH] = ACTIONS(6324),
    [anon_sym_Foreach] = ACTIONS(6324),
    [anon_sym_while] = ACTIONS(6324),
    [anon_sym_WHILE] = ACTIONS(6324),
    [anon_sym_While] = ACTIONS(6324),
    [anon_sym_repeat] = ACTIONS(6324),
    [anon_sym_REPEAT] = ACTIONS(6324),
    [anon_sym_Repeat] = ACTIONS(6324),
    [anon_sym_exit] = ACTIONS(6324),
    [anon_sym_EXIT] = ACTIONS(6324),
    [anon_sym_Exit] = ACTIONS(6324),
    [anon_sym_continue] = ACTIONS(6324),
    [anon_sym_CONTINUE] = ACTIONS(6324),
    [anon_sym_Continue] = ACTIONS(6324),
    [anon_sym_break] = ACTIONS(6324),
    [anon_sym_BREAK] = ACTIONS(6324),
    [anon_sym_Break] = ACTIONS(6324),
    [anon_sym_with] = ACTIONS(6324),
    [anon_sym_WITH] = ACTIONS(6324),
    [anon_sym_With] = ACTIONS(6324),
    [sym_asserterror_keyword] = ACTIONS(6326),
    [sym_page_keyword] = ACTIONS(6324),
    [anon_sym_codeunit] = ACTIONS(6324),
    [anon_sym_CODEUNIT] = ACTIONS(6324),
    [anon_sym_Codeunit] = ACTIONS(6324),
    [anon_sym_CodeUnit] = ACTIONS(6324),
    [anon_sym_COdeunit] = ACTIONS(6324),
    [anon_sym_codeUnit] = ACTIONS(6324),
    [sym_report_keyword] = ACTIONS(6324),
    [sym_query_keyword] = ACTIONS(6324),
    [anon_sym_xmlport] = ACTIONS(6324),
    [anon_sym_XMLPORT] = ACTIONS(6324),
    [anon_sym_Xmlport] = ACTIONS(6324),
    [anon_sym_XMLport] = ACTIONS(6324),
    [anon_sym_XMLPort] = ACTIONS(6324),
    [anon_sym_XmlPort] = ACTIONS(6324),
    [anon_sym_enum] = ACTIONS(6324),
    [anon_sym_ENUM] = ACTIONS(6324),
    [anon_sym_Enum] = ACTIONS(6324),
    [anon_sym_eNUM] = ACTIONS(6324),
    [anon_sym_eNum] = ACTIONS(6324),
    [anon_sym_ENum] = ACTIONS(6324),
    [sym_quoted_identifier] = ACTIONS(6326),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6326),
    [sym_verbatim_string] = ACTIONS(6326),
    [sym_integer] = ACTIONS(6324),
    [sym_continue_as_identifier] = ACTIONS(6326),
    [sym_preproc_open] = ACTIONS(6326),
    [sym_end_keyword] = ACTIONS(6326),
  },
  [STATE(3246)] = {
    [sym_identifier] = ACTIONS(6328),
    [anon_sym_SEMI] = ACTIONS(6330),
    [anon_sym_DASH] = ACTIONS(6330),
    [aux_sym_boolean_token1] = ACTIONS(6328),
    [aux_sym_boolean_token2] = ACTIONS(6328),
    [sym_decimal] = ACTIONS(6328),
    [anon_sym_LPAREN] = ACTIONS(6330),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6328),
    [anon_sym_LBRACK] = ACTIONS(6330),
    [aux_sym_record_type_token1] = ACTIONS(6328),
    [aux_sym_basic_type_token21] = ACTIONS(6328),
    [aux_sym_basic_type_token22] = ACTIONS(6328),
    [aux_sym_basic_type_token48] = ACTIONS(6328),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6328),
    [anon_sym_POUNDif] = ACTIONS(6330),
    [anon_sym_POUNDIF] = ACTIONS(6330),
    [anon_sym_POUNDIf] = ACTIONS(6330),
    [anon_sym_not] = ACTIONS(6328),
    [anon_sym_NOT] = ACTIONS(6328),
    [anon_sym_Not] = ACTIONS(6328),
    [anon_sym_POUNDelse] = ACTIONS(6330),
    [anon_sym_POUNDELSE] = ACTIONS(6330),
    [anon_sym_POUNDElse] = ACTIONS(6330),
    [anon_sym_POUNDelse2] = ACTIONS(6330),
    [anon_sym_POUNDELSE2] = ACTIONS(6330),
    [anon_sym_POUNDElse2] = ACTIONS(6330),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6328),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6328),
    [anon_sym_PLUS] = ACTIONS(6330),
    [sym_datetime_literal] = ACTIONS(6330),
    [sym_date_literal] = ACTIONS(6328),
    [sym_time_literal] = ACTIONS(6328),
    [sym_biginteger_literal] = ACTIONS(6330),
    [anon_sym_if] = ACTIONS(6328),
    [anon_sym_IF] = ACTIONS(6328),
    [anon_sym_If] = ACTIONS(6328),
    [anon_sym_else] = ACTIONS(6328),
    [anon_sym_ELSE] = ACTIONS(6328),
    [anon_sym_Else] = ACTIONS(6328),
    [anon_sym_case] = ACTIONS(6328),
    [anon_sym_CASE] = ACTIONS(6328),
    [anon_sym_Case] = ACTIONS(6328),
    [anon_sym_for] = ACTIONS(6328),
    [anon_sym_FOR] = ACTIONS(6328),
    [anon_sym_For] = ACTIONS(6328),
    [anon_sym_foreach] = ACTIONS(6328),
    [anon_sym_FOREACH] = ACTIONS(6328),
    [anon_sym_Foreach] = ACTIONS(6328),
    [anon_sym_while] = ACTIONS(6328),
    [anon_sym_WHILE] = ACTIONS(6328),
    [anon_sym_While] = ACTIONS(6328),
    [anon_sym_repeat] = ACTIONS(6328),
    [anon_sym_REPEAT] = ACTIONS(6328),
    [anon_sym_Repeat] = ACTIONS(6328),
    [anon_sym_exit] = ACTIONS(6328),
    [anon_sym_EXIT] = ACTIONS(6328),
    [anon_sym_Exit] = ACTIONS(6328),
    [anon_sym_continue] = ACTIONS(6328),
    [anon_sym_CONTINUE] = ACTIONS(6328),
    [anon_sym_Continue] = ACTIONS(6328),
    [anon_sym_break] = ACTIONS(6328),
    [anon_sym_BREAK] = ACTIONS(6328),
    [anon_sym_Break] = ACTIONS(6328),
    [anon_sym_with] = ACTIONS(6328),
    [anon_sym_WITH] = ACTIONS(6328),
    [anon_sym_With] = ACTIONS(6328),
    [sym_asserterror_keyword] = ACTIONS(6330),
    [sym_page_keyword] = ACTIONS(6328),
    [anon_sym_codeunit] = ACTIONS(6328),
    [anon_sym_CODEUNIT] = ACTIONS(6328),
    [anon_sym_Codeunit] = ACTIONS(6328),
    [anon_sym_CodeUnit] = ACTIONS(6328),
    [anon_sym_COdeunit] = ACTIONS(6328),
    [anon_sym_codeUnit] = ACTIONS(6328),
    [sym_report_keyword] = ACTIONS(6328),
    [sym_query_keyword] = ACTIONS(6328),
    [anon_sym_xmlport] = ACTIONS(6328),
    [anon_sym_XMLPORT] = ACTIONS(6328),
    [anon_sym_Xmlport] = ACTIONS(6328),
    [anon_sym_XMLport] = ACTIONS(6328),
    [anon_sym_XMLPort] = ACTIONS(6328),
    [anon_sym_XmlPort] = ACTIONS(6328),
    [anon_sym_enum] = ACTIONS(6328),
    [anon_sym_ENUM] = ACTIONS(6328),
    [anon_sym_Enum] = ACTIONS(6328),
    [anon_sym_eNUM] = ACTIONS(6328),
    [anon_sym_eNum] = ACTIONS(6328),
    [anon_sym_ENum] = ACTIONS(6328),
    [sym_quoted_identifier] = ACTIONS(6330),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6330),
    [sym_verbatim_string] = ACTIONS(6330),
    [sym_integer] = ACTIONS(6328),
    [sym_continue_as_identifier] = ACTIONS(6330),
    [sym_preproc_open] = ACTIONS(6330),
    [sym_end_keyword] = ACTIONS(6330),
  },
  [STATE(3247)] = {
    [sym_identifier] = ACTIONS(6332),
    [anon_sym_SEMI] = ACTIONS(6334),
    [anon_sym_DASH] = ACTIONS(6334),
    [aux_sym_boolean_token1] = ACTIONS(6332),
    [aux_sym_boolean_token2] = ACTIONS(6332),
    [sym_decimal] = ACTIONS(6332),
    [anon_sym_LPAREN] = ACTIONS(6334),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6332),
    [anon_sym_LBRACK] = ACTIONS(6334),
    [aux_sym_record_type_token1] = ACTIONS(6332),
    [aux_sym_basic_type_token21] = ACTIONS(6332),
    [aux_sym_basic_type_token22] = ACTIONS(6332),
    [aux_sym_basic_type_token48] = ACTIONS(6332),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6332),
    [anon_sym_POUNDif] = ACTIONS(6334),
    [anon_sym_POUNDIF] = ACTIONS(6334),
    [anon_sym_POUNDIf] = ACTIONS(6334),
    [anon_sym_not] = ACTIONS(6332),
    [anon_sym_NOT] = ACTIONS(6332),
    [anon_sym_Not] = ACTIONS(6332),
    [anon_sym_POUNDelse] = ACTIONS(6334),
    [anon_sym_POUNDELSE] = ACTIONS(6334),
    [anon_sym_POUNDElse] = ACTIONS(6334),
    [anon_sym_POUNDelse2] = ACTIONS(6334),
    [anon_sym_POUNDELSE2] = ACTIONS(6334),
    [anon_sym_POUNDElse2] = ACTIONS(6334),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6332),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6332),
    [anon_sym_PLUS] = ACTIONS(6334),
    [sym_datetime_literal] = ACTIONS(6334),
    [sym_date_literal] = ACTIONS(6332),
    [sym_time_literal] = ACTIONS(6332),
    [sym_biginteger_literal] = ACTIONS(6334),
    [anon_sym_if] = ACTIONS(6332),
    [anon_sym_IF] = ACTIONS(6332),
    [anon_sym_If] = ACTIONS(6332),
    [anon_sym_else] = ACTIONS(6332),
    [anon_sym_ELSE] = ACTIONS(6332),
    [anon_sym_Else] = ACTIONS(6332),
    [anon_sym_case] = ACTIONS(6332),
    [anon_sym_CASE] = ACTIONS(6332),
    [anon_sym_Case] = ACTIONS(6332),
    [anon_sym_for] = ACTIONS(6332),
    [anon_sym_FOR] = ACTIONS(6332),
    [anon_sym_For] = ACTIONS(6332),
    [anon_sym_foreach] = ACTIONS(6332),
    [anon_sym_FOREACH] = ACTIONS(6332),
    [anon_sym_Foreach] = ACTIONS(6332),
    [anon_sym_while] = ACTIONS(6332),
    [anon_sym_WHILE] = ACTIONS(6332),
    [anon_sym_While] = ACTIONS(6332),
    [anon_sym_repeat] = ACTIONS(6332),
    [anon_sym_REPEAT] = ACTIONS(6332),
    [anon_sym_Repeat] = ACTIONS(6332),
    [anon_sym_exit] = ACTIONS(6332),
    [anon_sym_EXIT] = ACTIONS(6332),
    [anon_sym_Exit] = ACTIONS(6332),
    [anon_sym_continue] = ACTIONS(6332),
    [anon_sym_CONTINUE] = ACTIONS(6332),
    [anon_sym_Continue] = ACTIONS(6332),
    [anon_sym_break] = ACTIONS(6332),
    [anon_sym_BREAK] = ACTIONS(6332),
    [anon_sym_Break] = ACTIONS(6332),
    [anon_sym_with] = ACTIONS(6332),
    [anon_sym_WITH] = ACTIONS(6332),
    [anon_sym_With] = ACTIONS(6332),
    [sym_asserterror_keyword] = ACTIONS(6334),
    [sym_page_keyword] = ACTIONS(6332),
    [anon_sym_codeunit] = ACTIONS(6332),
    [anon_sym_CODEUNIT] = ACTIONS(6332),
    [anon_sym_Codeunit] = ACTIONS(6332),
    [anon_sym_CodeUnit] = ACTIONS(6332),
    [anon_sym_COdeunit] = ACTIONS(6332),
    [anon_sym_codeUnit] = ACTIONS(6332),
    [sym_report_keyword] = ACTIONS(6332),
    [sym_query_keyword] = ACTIONS(6332),
    [anon_sym_xmlport] = ACTIONS(6332),
    [anon_sym_XMLPORT] = ACTIONS(6332),
    [anon_sym_Xmlport] = ACTIONS(6332),
    [anon_sym_XMLport] = ACTIONS(6332),
    [anon_sym_XMLPort] = ACTIONS(6332),
    [anon_sym_XmlPort] = ACTIONS(6332),
    [anon_sym_enum] = ACTIONS(6332),
    [anon_sym_ENUM] = ACTIONS(6332),
    [anon_sym_Enum] = ACTIONS(6332),
    [anon_sym_eNUM] = ACTIONS(6332),
    [anon_sym_eNum] = ACTIONS(6332),
    [anon_sym_ENum] = ACTIONS(6332),
    [sym_quoted_identifier] = ACTIONS(6334),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6334),
    [sym_verbatim_string] = ACTIONS(6334),
    [sym_integer] = ACTIONS(6332),
    [sym_continue_as_identifier] = ACTIONS(6334),
    [sym_preproc_open] = ACTIONS(6334),
    [sym_end_keyword] = ACTIONS(6334),
  },
  [STATE(3248)] = {
    [sym_identifier] = ACTIONS(6336),
    [anon_sym_SEMI] = ACTIONS(6338),
    [anon_sym_DASH] = ACTIONS(6338),
    [aux_sym_boolean_token1] = ACTIONS(6336),
    [aux_sym_boolean_token2] = ACTIONS(6336),
    [sym_decimal] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6338),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6336),
    [anon_sym_LBRACK] = ACTIONS(6338),
    [aux_sym_record_type_token1] = ACTIONS(6336),
    [aux_sym_basic_type_token21] = ACTIONS(6336),
    [aux_sym_basic_type_token22] = ACTIONS(6336),
    [aux_sym_basic_type_token48] = ACTIONS(6336),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6336),
    [anon_sym_POUNDif] = ACTIONS(6338),
    [anon_sym_POUNDIF] = ACTIONS(6338),
    [anon_sym_POUNDIf] = ACTIONS(6338),
    [anon_sym_not] = ACTIONS(6336),
    [anon_sym_NOT] = ACTIONS(6336),
    [anon_sym_Not] = ACTIONS(6336),
    [anon_sym_POUNDelse] = ACTIONS(6338),
    [anon_sym_POUNDELSE] = ACTIONS(6338),
    [anon_sym_POUNDElse] = ACTIONS(6338),
    [anon_sym_POUNDelse2] = ACTIONS(6338),
    [anon_sym_POUNDELSE2] = ACTIONS(6338),
    [anon_sym_POUNDElse2] = ACTIONS(6338),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6336),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6336),
    [anon_sym_PLUS] = ACTIONS(6338),
    [sym_datetime_literal] = ACTIONS(6338),
    [sym_date_literal] = ACTIONS(6336),
    [sym_time_literal] = ACTIONS(6336),
    [sym_biginteger_literal] = ACTIONS(6338),
    [anon_sym_if] = ACTIONS(6336),
    [anon_sym_IF] = ACTIONS(6336),
    [anon_sym_If] = ACTIONS(6336),
    [anon_sym_else] = ACTIONS(6336),
    [anon_sym_ELSE] = ACTIONS(6336),
    [anon_sym_Else] = ACTIONS(6336),
    [anon_sym_case] = ACTIONS(6336),
    [anon_sym_CASE] = ACTIONS(6336),
    [anon_sym_Case] = ACTIONS(6336),
    [anon_sym_for] = ACTIONS(6336),
    [anon_sym_FOR] = ACTIONS(6336),
    [anon_sym_For] = ACTIONS(6336),
    [anon_sym_foreach] = ACTIONS(6336),
    [anon_sym_FOREACH] = ACTIONS(6336),
    [anon_sym_Foreach] = ACTIONS(6336),
    [anon_sym_while] = ACTIONS(6336),
    [anon_sym_WHILE] = ACTIONS(6336),
    [anon_sym_While] = ACTIONS(6336),
    [anon_sym_repeat] = ACTIONS(6336),
    [anon_sym_REPEAT] = ACTIONS(6336),
    [anon_sym_Repeat] = ACTIONS(6336),
    [anon_sym_exit] = ACTIONS(6336),
    [anon_sym_EXIT] = ACTIONS(6336),
    [anon_sym_Exit] = ACTIONS(6336),
    [anon_sym_continue] = ACTIONS(6336),
    [anon_sym_CONTINUE] = ACTIONS(6336),
    [anon_sym_Continue] = ACTIONS(6336),
    [anon_sym_break] = ACTIONS(6336),
    [anon_sym_BREAK] = ACTIONS(6336),
    [anon_sym_Break] = ACTIONS(6336),
    [anon_sym_with] = ACTIONS(6336),
    [anon_sym_WITH] = ACTIONS(6336),
    [anon_sym_With] = ACTIONS(6336),
    [sym_asserterror_keyword] = ACTIONS(6338),
    [sym_page_keyword] = ACTIONS(6336),
    [anon_sym_codeunit] = ACTIONS(6336),
    [anon_sym_CODEUNIT] = ACTIONS(6336),
    [anon_sym_Codeunit] = ACTIONS(6336),
    [anon_sym_CodeUnit] = ACTIONS(6336),
    [anon_sym_COdeunit] = ACTIONS(6336),
    [anon_sym_codeUnit] = ACTIONS(6336),
    [sym_report_keyword] = ACTIONS(6336),
    [sym_query_keyword] = ACTIONS(6336),
    [anon_sym_xmlport] = ACTIONS(6336),
    [anon_sym_XMLPORT] = ACTIONS(6336),
    [anon_sym_Xmlport] = ACTIONS(6336),
    [anon_sym_XMLport] = ACTIONS(6336),
    [anon_sym_XMLPort] = ACTIONS(6336),
    [anon_sym_XmlPort] = ACTIONS(6336),
    [anon_sym_enum] = ACTIONS(6336),
    [anon_sym_ENUM] = ACTIONS(6336),
    [anon_sym_Enum] = ACTIONS(6336),
    [anon_sym_eNUM] = ACTIONS(6336),
    [anon_sym_eNum] = ACTIONS(6336),
    [anon_sym_ENum] = ACTIONS(6336),
    [sym_quoted_identifier] = ACTIONS(6338),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6338),
    [sym_verbatim_string] = ACTIONS(6338),
    [sym_integer] = ACTIONS(6336),
    [sym_continue_as_identifier] = ACTIONS(6338),
    [sym_preproc_open] = ACTIONS(6338),
    [sym_end_keyword] = ACTIONS(6338),
  },
  [STATE(3249)] = {
    [sym_identifier] = ACTIONS(6336),
    [anon_sym_SEMI] = ACTIONS(6338),
    [anon_sym_DASH] = ACTIONS(6338),
    [aux_sym_boolean_token1] = ACTIONS(6336),
    [aux_sym_boolean_token2] = ACTIONS(6336),
    [sym_decimal] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6338),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6336),
    [anon_sym_LBRACK] = ACTIONS(6338),
    [aux_sym_record_type_token1] = ACTIONS(6336),
    [aux_sym_basic_type_token21] = ACTIONS(6336),
    [aux_sym_basic_type_token22] = ACTIONS(6336),
    [aux_sym_basic_type_token48] = ACTIONS(6336),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6336),
    [anon_sym_POUNDif] = ACTIONS(6338),
    [anon_sym_POUNDIF] = ACTIONS(6338),
    [anon_sym_POUNDIf] = ACTIONS(6338),
    [anon_sym_not] = ACTIONS(6336),
    [anon_sym_NOT] = ACTIONS(6336),
    [anon_sym_Not] = ACTIONS(6336),
    [anon_sym_POUNDelse] = ACTIONS(6338),
    [anon_sym_POUNDELSE] = ACTIONS(6338),
    [anon_sym_POUNDElse] = ACTIONS(6338),
    [anon_sym_POUNDelse2] = ACTIONS(6338),
    [anon_sym_POUNDELSE2] = ACTIONS(6338),
    [anon_sym_POUNDElse2] = ACTIONS(6338),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6336),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6336),
    [anon_sym_PLUS] = ACTIONS(6338),
    [sym_datetime_literal] = ACTIONS(6338),
    [sym_date_literal] = ACTIONS(6336),
    [sym_time_literal] = ACTIONS(6336),
    [sym_biginteger_literal] = ACTIONS(6338),
    [anon_sym_if] = ACTIONS(6336),
    [anon_sym_IF] = ACTIONS(6336),
    [anon_sym_If] = ACTIONS(6336),
    [anon_sym_else] = ACTIONS(6336),
    [anon_sym_ELSE] = ACTIONS(6336),
    [anon_sym_Else] = ACTIONS(6336),
    [anon_sym_case] = ACTIONS(6336),
    [anon_sym_CASE] = ACTIONS(6336),
    [anon_sym_Case] = ACTIONS(6336),
    [anon_sym_for] = ACTIONS(6336),
    [anon_sym_FOR] = ACTIONS(6336),
    [anon_sym_For] = ACTIONS(6336),
    [anon_sym_foreach] = ACTIONS(6336),
    [anon_sym_FOREACH] = ACTIONS(6336),
    [anon_sym_Foreach] = ACTIONS(6336),
    [anon_sym_while] = ACTIONS(6336),
    [anon_sym_WHILE] = ACTIONS(6336),
    [anon_sym_While] = ACTIONS(6336),
    [anon_sym_repeat] = ACTIONS(6336),
    [anon_sym_REPEAT] = ACTIONS(6336),
    [anon_sym_Repeat] = ACTIONS(6336),
    [anon_sym_exit] = ACTIONS(6336),
    [anon_sym_EXIT] = ACTIONS(6336),
    [anon_sym_Exit] = ACTIONS(6336),
    [anon_sym_continue] = ACTIONS(6336),
    [anon_sym_CONTINUE] = ACTIONS(6336),
    [anon_sym_Continue] = ACTIONS(6336),
    [anon_sym_break] = ACTIONS(6336),
    [anon_sym_BREAK] = ACTIONS(6336),
    [anon_sym_Break] = ACTIONS(6336),
    [anon_sym_with] = ACTIONS(6336),
    [anon_sym_WITH] = ACTIONS(6336),
    [anon_sym_With] = ACTIONS(6336),
    [sym_asserterror_keyword] = ACTIONS(6338),
    [sym_page_keyword] = ACTIONS(6336),
    [anon_sym_codeunit] = ACTIONS(6336),
    [anon_sym_CODEUNIT] = ACTIONS(6336),
    [anon_sym_Codeunit] = ACTIONS(6336),
    [anon_sym_CodeUnit] = ACTIONS(6336),
    [anon_sym_COdeunit] = ACTIONS(6336),
    [anon_sym_codeUnit] = ACTIONS(6336),
    [sym_report_keyword] = ACTIONS(6336),
    [sym_query_keyword] = ACTIONS(6336),
    [anon_sym_xmlport] = ACTIONS(6336),
    [anon_sym_XMLPORT] = ACTIONS(6336),
    [anon_sym_Xmlport] = ACTIONS(6336),
    [anon_sym_XMLport] = ACTIONS(6336),
    [anon_sym_XMLPort] = ACTIONS(6336),
    [anon_sym_XmlPort] = ACTIONS(6336),
    [anon_sym_enum] = ACTIONS(6336),
    [anon_sym_ENUM] = ACTIONS(6336),
    [anon_sym_Enum] = ACTIONS(6336),
    [anon_sym_eNUM] = ACTIONS(6336),
    [anon_sym_eNum] = ACTIONS(6336),
    [anon_sym_ENum] = ACTIONS(6336),
    [sym_quoted_identifier] = ACTIONS(6338),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6338),
    [sym_verbatim_string] = ACTIONS(6338),
    [sym_integer] = ACTIONS(6336),
    [sym_continue_as_identifier] = ACTIONS(6338),
    [sym_preproc_open] = ACTIONS(6338),
    [sym_end_keyword] = ACTIONS(6338),
  },
  [STATE(3250)] = {
    [sym_identifier] = ACTIONS(6106),
    [anon_sym_SEMI] = ACTIONS(6108),
    [anon_sym_DASH] = ACTIONS(6108),
    [aux_sym_boolean_token1] = ACTIONS(6106),
    [aux_sym_boolean_token2] = ACTIONS(6106),
    [sym_decimal] = ACTIONS(6106),
    [anon_sym_LPAREN] = ACTIONS(6108),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6106),
    [anon_sym_LBRACK] = ACTIONS(6108),
    [aux_sym_record_type_token1] = ACTIONS(6106),
    [aux_sym_basic_type_token21] = ACTIONS(6106),
    [aux_sym_basic_type_token22] = ACTIONS(6106),
    [aux_sym_basic_type_token48] = ACTIONS(6106),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6106),
    [anon_sym_POUNDif] = ACTIONS(6108),
    [anon_sym_POUNDIF] = ACTIONS(6108),
    [anon_sym_POUNDIf] = ACTIONS(6108),
    [anon_sym_not] = ACTIONS(6106),
    [anon_sym_NOT] = ACTIONS(6106),
    [anon_sym_Not] = ACTIONS(6106),
    [anon_sym_POUNDelse] = ACTIONS(6108),
    [anon_sym_POUNDELSE] = ACTIONS(6108),
    [anon_sym_POUNDElse] = ACTIONS(6108),
    [anon_sym_POUNDelse2] = ACTIONS(6108),
    [anon_sym_POUNDELSE2] = ACTIONS(6108),
    [anon_sym_POUNDElse2] = ACTIONS(6108),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6106),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6106),
    [anon_sym_PLUS] = ACTIONS(6108),
    [sym_datetime_literal] = ACTIONS(6108),
    [sym_date_literal] = ACTIONS(6106),
    [sym_time_literal] = ACTIONS(6106),
    [sym_biginteger_literal] = ACTIONS(6108),
    [anon_sym_if] = ACTIONS(6106),
    [anon_sym_IF] = ACTIONS(6106),
    [anon_sym_If] = ACTIONS(6106),
    [anon_sym_else] = ACTIONS(6106),
    [anon_sym_ELSE] = ACTIONS(6106),
    [anon_sym_Else] = ACTIONS(6106),
    [anon_sym_case] = ACTIONS(6106),
    [anon_sym_CASE] = ACTIONS(6106),
    [anon_sym_Case] = ACTIONS(6106),
    [anon_sym_for] = ACTIONS(6106),
    [anon_sym_FOR] = ACTIONS(6106),
    [anon_sym_For] = ACTIONS(6106),
    [anon_sym_foreach] = ACTIONS(6106),
    [anon_sym_FOREACH] = ACTIONS(6106),
    [anon_sym_Foreach] = ACTIONS(6106),
    [anon_sym_while] = ACTIONS(6106),
    [anon_sym_WHILE] = ACTIONS(6106),
    [anon_sym_While] = ACTIONS(6106),
    [anon_sym_repeat] = ACTIONS(6106),
    [anon_sym_REPEAT] = ACTIONS(6106),
    [anon_sym_Repeat] = ACTIONS(6106),
    [anon_sym_exit] = ACTIONS(6106),
    [anon_sym_EXIT] = ACTIONS(6106),
    [anon_sym_Exit] = ACTIONS(6106),
    [anon_sym_continue] = ACTIONS(6106),
    [anon_sym_CONTINUE] = ACTIONS(6106),
    [anon_sym_Continue] = ACTIONS(6106),
    [anon_sym_break] = ACTIONS(6106),
    [anon_sym_BREAK] = ACTIONS(6106),
    [anon_sym_Break] = ACTIONS(6106),
    [anon_sym_with] = ACTIONS(6106),
    [anon_sym_WITH] = ACTIONS(6106),
    [anon_sym_With] = ACTIONS(6106),
    [sym_asserterror_keyword] = ACTIONS(6108),
    [sym_page_keyword] = ACTIONS(6106),
    [anon_sym_codeunit] = ACTIONS(6106),
    [anon_sym_CODEUNIT] = ACTIONS(6106),
    [anon_sym_Codeunit] = ACTIONS(6106),
    [anon_sym_CodeUnit] = ACTIONS(6106),
    [anon_sym_COdeunit] = ACTIONS(6106),
    [anon_sym_codeUnit] = ACTIONS(6106),
    [sym_report_keyword] = ACTIONS(6106),
    [sym_query_keyword] = ACTIONS(6106),
    [anon_sym_xmlport] = ACTIONS(6106),
    [anon_sym_XMLPORT] = ACTIONS(6106),
    [anon_sym_Xmlport] = ACTIONS(6106),
    [anon_sym_XMLport] = ACTIONS(6106),
    [anon_sym_XMLPort] = ACTIONS(6106),
    [anon_sym_XmlPort] = ACTIONS(6106),
    [anon_sym_enum] = ACTIONS(6106),
    [anon_sym_ENUM] = ACTIONS(6106),
    [anon_sym_Enum] = ACTIONS(6106),
    [anon_sym_eNUM] = ACTIONS(6106),
    [anon_sym_eNum] = ACTIONS(6106),
    [anon_sym_ENum] = ACTIONS(6106),
    [sym_quoted_identifier] = ACTIONS(6108),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6108),
    [sym_verbatim_string] = ACTIONS(6108),
    [sym_integer] = ACTIONS(6106),
    [sym_continue_as_identifier] = ACTIONS(6108),
    [sym_preproc_open] = ACTIONS(6108),
    [sym_end_keyword] = ACTIONS(6108),
  },
  [STATE(3251)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_DASH] = ACTIONS(5277),
    [aux_sym_boolean_token1] = ACTIONS(5279),
    [aux_sym_boolean_token2] = ACTIONS(5279),
    [sym_decimal] = ACTIONS(5279),
    [anon_sym_LPAREN] = ACTIONS(5277),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_record_type_token1] = ACTIONS(5279),
    [aux_sym_basic_type_token21] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token48] = ACTIONS(5279),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_not] = ACTIONS(5279),
    [anon_sym_NOT] = ACTIONS(5279),
    [anon_sym_Not] = ACTIONS(5279),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5279),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5279),
    [anon_sym_PLUS] = ACTIONS(5277),
    [sym_datetime_literal] = ACTIONS(5277),
    [sym_date_literal] = ACTIONS(5279),
    [sym_time_literal] = ACTIONS(5279),
    [sym_biginteger_literal] = ACTIONS(5277),
    [anon_sym_if] = ACTIONS(5279),
    [anon_sym_IF] = ACTIONS(5279),
    [anon_sym_If] = ACTIONS(5279),
    [anon_sym_else] = ACTIONS(5279),
    [anon_sym_ELSE] = ACTIONS(5279),
    [anon_sym_Else] = ACTIONS(5279),
    [anon_sym_case] = ACTIONS(5279),
    [anon_sym_CASE] = ACTIONS(5279),
    [anon_sym_Case] = ACTIONS(5279),
    [anon_sym_for] = ACTIONS(5279),
    [anon_sym_FOR] = ACTIONS(5279),
    [anon_sym_For] = ACTIONS(5279),
    [anon_sym_foreach] = ACTIONS(5279),
    [anon_sym_FOREACH] = ACTIONS(5279),
    [anon_sym_Foreach] = ACTIONS(5279),
    [anon_sym_while] = ACTIONS(5279),
    [anon_sym_WHILE] = ACTIONS(5279),
    [anon_sym_While] = ACTIONS(5279),
    [anon_sym_repeat] = ACTIONS(5279),
    [anon_sym_REPEAT] = ACTIONS(5279),
    [anon_sym_Repeat] = ACTIONS(5279),
    [anon_sym_exit] = ACTIONS(5279),
    [anon_sym_EXIT] = ACTIONS(5279),
    [anon_sym_Exit] = ACTIONS(5279),
    [anon_sym_continue] = ACTIONS(5279),
    [anon_sym_CONTINUE] = ACTIONS(5279),
    [anon_sym_Continue] = ACTIONS(5279),
    [anon_sym_break] = ACTIONS(5279),
    [anon_sym_BREAK] = ACTIONS(5279),
    [anon_sym_Break] = ACTIONS(5279),
    [anon_sym_with] = ACTIONS(5279),
    [anon_sym_WITH] = ACTIONS(5279),
    [anon_sym_With] = ACTIONS(5279),
    [sym_asserterror_keyword] = ACTIONS(5277),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [anon_sym_enum] = ACTIONS(5279),
    [anon_sym_ENUM] = ACTIONS(5279),
    [anon_sym_Enum] = ACTIONS(5279),
    [anon_sym_eNUM] = ACTIONS(5279),
    [anon_sym_eNum] = ACTIONS(5279),
    [anon_sym_ENum] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5277),
    [sym_verbatim_string] = ACTIONS(5277),
    [sym_integer] = ACTIONS(5279),
    [sym_continue_as_identifier] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_end_keyword] = ACTIONS(5277),
  },
  [STATE(3252)] = {
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_RBRACE] = ACTIONS(5405),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [aux_sym_where_condition_token1] = ACTIONS(5410),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5405),
    [anon_sym_STAR] = ACTIONS(3681),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5405),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5405),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_basic_type_token6] = ACTIONS(5410),
    [aux_sym_basic_type_token22] = ACTIONS(5410),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5405),
    [aux_sym_addafter_modification_token1] = ACTIONS(5405),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5405),
    [aux_sym_modify_modification_token1] = ACTIONS(5405),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5405),
    [aux_sym_movelast_modification_token1] = ACTIONS(5405),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5405),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5405),
    [aux_sym_separator_action_token1] = ACTIONS(5405),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5405),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5405),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5405),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5405),
    [sym_trigger_keyword] = ACTIONS(5405),
    [sym_var_keyword] = ACTIONS(5405),
    [sym_local_keyword] = ACTIONS(5405),
    [sym_internal_keyword] = ACTIONS(5405),
    [sym_protected_keyword] = ACTIONS(5405),
    [sym_event_keyword] = ACTIONS(5405),
    [sym_fields_keyword] = ACTIONS(5405),
    [sym_keys_keyword] = ACTIONS(5405),
    [sym_fieldgroups_keyword] = ACTIONS(5405),
    [sym_actions_keyword] = ACTIONS(5405),
    [sym_layout_keyword] = ACTIONS(5405),
    [sym_area_keyword] = ACTIONS(5405),
    [sym_group_keyword] = ACTIONS(5405),
    [sym_repeater_keyword] = ACTIONS(5405),
    [sym_cuegroup_keyword] = ACTIONS(5405),
    [sym_fixed_keyword] = ACTIONS(5405),
    [sym_grid_keyword] = ACTIONS(5405),
    [sym_part_keyword] = ACTIONS(5405),
    [sym_systempart_keyword] = ACTIONS(5405),
    [sym_usercontrol_keyword] = ACTIONS(5405),
    [sym_dataset_keyword] = ACTIONS(5405),
    [sym_elements_keyword] = ACTIONS(5405),
    [sym_dataitem_keyword] = ACTIONS(5405),
    [sym_column_keyword] = ACTIONS(5405),
    [sym_filter_keyword] = ACTIONS(5405),
    [sym_labels_keyword] = ACTIONS(5405),
    [sym_rendering_keyword] = ACTIONS(5405),
    [sym_requestpage_keyword] = ACTIONS(5405),
    [sym_schema_keyword] = ACTIONS(5405),
    [sym_views_keyword] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
  },
  [STATE(3253)] = {
    [sym_identifier] = ACTIONS(6284),
    [anon_sym_SEMI] = ACTIONS(6286),
    [anon_sym_DASH] = ACTIONS(6286),
    [aux_sym_boolean_token1] = ACTIONS(6284),
    [aux_sym_boolean_token2] = ACTIONS(6284),
    [sym_decimal] = ACTIONS(6284),
    [anon_sym_LPAREN] = ACTIONS(6286),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6284),
    [anon_sym_LBRACK] = ACTIONS(6286),
    [aux_sym_record_type_token1] = ACTIONS(6284),
    [aux_sym_basic_type_token21] = ACTIONS(6284),
    [aux_sym_basic_type_token22] = ACTIONS(6284),
    [aux_sym_basic_type_token48] = ACTIONS(6284),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6284),
    [anon_sym_POUNDif] = ACTIONS(6286),
    [anon_sym_POUNDIF] = ACTIONS(6286),
    [anon_sym_POUNDIf] = ACTIONS(6286),
    [anon_sym_not] = ACTIONS(6284),
    [anon_sym_NOT] = ACTIONS(6284),
    [anon_sym_Not] = ACTIONS(6284),
    [anon_sym_POUNDelse] = ACTIONS(6286),
    [anon_sym_POUNDELSE] = ACTIONS(6286),
    [anon_sym_POUNDElse] = ACTIONS(6286),
    [anon_sym_POUNDelse2] = ACTIONS(6286),
    [anon_sym_POUNDELSE2] = ACTIONS(6286),
    [anon_sym_POUNDElse2] = ACTIONS(6286),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6284),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6284),
    [anon_sym_PLUS] = ACTIONS(6286),
    [sym_datetime_literal] = ACTIONS(6286),
    [sym_date_literal] = ACTIONS(6284),
    [sym_time_literal] = ACTIONS(6284),
    [sym_biginteger_literal] = ACTIONS(6286),
    [anon_sym_if] = ACTIONS(6284),
    [anon_sym_IF] = ACTIONS(6284),
    [anon_sym_If] = ACTIONS(6284),
    [anon_sym_else] = ACTIONS(6284),
    [anon_sym_ELSE] = ACTIONS(6284),
    [anon_sym_Else] = ACTIONS(6284),
    [anon_sym_case] = ACTIONS(6284),
    [anon_sym_CASE] = ACTIONS(6284),
    [anon_sym_Case] = ACTIONS(6284),
    [anon_sym_for] = ACTIONS(6284),
    [anon_sym_FOR] = ACTIONS(6284),
    [anon_sym_For] = ACTIONS(6284),
    [anon_sym_foreach] = ACTIONS(6284),
    [anon_sym_FOREACH] = ACTIONS(6284),
    [anon_sym_Foreach] = ACTIONS(6284),
    [anon_sym_while] = ACTIONS(6284),
    [anon_sym_WHILE] = ACTIONS(6284),
    [anon_sym_While] = ACTIONS(6284),
    [anon_sym_repeat] = ACTIONS(6284),
    [anon_sym_REPEAT] = ACTIONS(6284),
    [anon_sym_Repeat] = ACTIONS(6284),
    [anon_sym_exit] = ACTIONS(6284),
    [anon_sym_EXIT] = ACTIONS(6284),
    [anon_sym_Exit] = ACTIONS(6284),
    [anon_sym_continue] = ACTIONS(6284),
    [anon_sym_CONTINUE] = ACTIONS(6284),
    [anon_sym_Continue] = ACTIONS(6284),
    [anon_sym_break] = ACTIONS(6284),
    [anon_sym_BREAK] = ACTIONS(6284),
    [anon_sym_Break] = ACTIONS(6284),
    [anon_sym_with] = ACTIONS(6284),
    [anon_sym_WITH] = ACTIONS(6284),
    [anon_sym_With] = ACTIONS(6284),
    [sym_asserterror_keyword] = ACTIONS(6286),
    [sym_page_keyword] = ACTIONS(6284),
    [anon_sym_codeunit] = ACTIONS(6284),
    [anon_sym_CODEUNIT] = ACTIONS(6284),
    [anon_sym_Codeunit] = ACTIONS(6284),
    [anon_sym_CodeUnit] = ACTIONS(6284),
    [anon_sym_COdeunit] = ACTIONS(6284),
    [anon_sym_codeUnit] = ACTIONS(6284),
    [sym_report_keyword] = ACTIONS(6284),
    [sym_query_keyword] = ACTIONS(6284),
    [anon_sym_xmlport] = ACTIONS(6284),
    [anon_sym_XMLPORT] = ACTIONS(6284),
    [anon_sym_Xmlport] = ACTIONS(6284),
    [anon_sym_XMLport] = ACTIONS(6284),
    [anon_sym_XMLPort] = ACTIONS(6284),
    [anon_sym_XmlPort] = ACTIONS(6284),
    [anon_sym_enum] = ACTIONS(6284),
    [anon_sym_ENUM] = ACTIONS(6284),
    [anon_sym_Enum] = ACTIONS(6284),
    [anon_sym_eNUM] = ACTIONS(6284),
    [anon_sym_eNum] = ACTIONS(6284),
    [anon_sym_ENum] = ACTIONS(6284),
    [sym_quoted_identifier] = ACTIONS(6286),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6286),
    [sym_verbatim_string] = ACTIONS(6286),
    [sym_integer] = ACTIONS(6284),
    [sym_continue_as_identifier] = ACTIONS(6286),
    [sym_preproc_open] = ACTIONS(6286),
    [sym_end_keyword] = ACTIONS(6286),
  },
  [STATE(3254)] = {
    [sym_where_clause] = STATE(6608),
    [sym_argument_list] = STATE(7165),
    [sym_identifier] = ACTIONS(5392),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(7331),
    [aux_sym_where_condition_token1] = ACTIONS(5392),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5392),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [aux_sym_basic_type_token22] = ACTIONS(5392),
    [aux_sym_basic_type_token53] = ACTIONS(5392),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5392),
    [aux_sym_modify_modification_token1] = ACTIONS(5392),
    [aux_sym_separator_action_token1] = ACTIONS(5392),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5392),
    [aux_sym_type_declaration_token1] = ACTIONS(5392),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5386),
    [anon_sym_POUNDIF] = ACTIONS(5386),
    [anon_sym_POUNDIf] = ACTIONS(5386),
    [anon_sym_POUNDelif] = ACTIONS(5386),
    [anon_sym_POUNDELIF] = ACTIONS(5386),
    [anon_sym_POUNDElif] = ACTIONS(5386),
    [anon_sym_POUNDelse] = ACTIONS(5386),
    [anon_sym_POUNDELSE] = ACTIONS(5386),
    [anon_sym_POUNDElse] = ACTIONS(5386),
    [anon_sym_POUNDelse2] = ACTIONS(5386),
    [anon_sym_POUNDELSE2] = ACTIONS(5386),
    [anon_sym_POUNDElse2] = ACTIONS(5386),
    [anon_sym_POUNDendif] = ACTIONS(5386),
    [anon_sym_POUNDENDIF] = ACTIONS(5386),
    [anon_sym_POUNDEndif] = ACTIONS(5386),
    [anon_sym_POUNDendif2] = ACTIONS(5386),
    [anon_sym_POUNDENDIF2] = ACTIONS(5386),
    [anon_sym_POUNDEndif2] = ACTIONS(5386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_table_keyword] = ACTIONS(5392),
    [sym_procedure_keyword] = ACTIONS(5392),
    [sym_trigger_keyword] = ACTIONS(5392),
    [sym_var_keyword] = ACTIONS(5392),
    [sym_local_keyword] = ACTIONS(5392),
    [sym_internal_keyword] = ACTIONS(5392),
    [sym_protected_keyword] = ACTIONS(5392),
    [sym_event_keyword] = ACTIONS(5392),
    [sym_fields_keyword] = ACTIONS(5392),
    [sym_keys_keyword] = ACTIONS(5392),
    [sym_key_keyword] = ACTIONS(5392),
    [sym_fieldgroups_keyword] = ACTIONS(5392),
    [sym_actions_keyword] = ACTIONS(5392),
    [sym_layout_keyword] = ACTIONS(5392),
    [sym_dataset_keyword] = ACTIONS(5392),
    [sym_elements_keyword] = ACTIONS(5392),
    [sym_labels_keyword] = ACTIONS(5392),
    [sym_rendering_keyword] = ACTIONS(5392),
    [sym_requestpage_keyword] = ACTIONS(5392),
    [sym_schema_keyword] = ACTIONS(5392),
    [sym_views_keyword] = ACTIONS(5392),
    [sym_quoted_identifier] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5386),
    [sym_preproc_open] = ACTIONS(5386),
    [sym_preproc_close] = ACTIONS(5386),
    [sym_var_attribute_open] = ACTIONS(5386),
  },
  [STATE(3255)] = {
    [sym_identifier] = ACTIONS(5661),
    [anon_sym_SEMI] = ACTIONS(5663),
    [anon_sym_DASH] = ACTIONS(5663),
    [aux_sym_boolean_token1] = ACTIONS(5661),
    [aux_sym_boolean_token2] = ACTIONS(5661),
    [sym_decimal] = ACTIONS(5661),
    [anon_sym_LPAREN] = ACTIONS(5663),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5663),
    [aux_sym_record_type_token1] = ACTIONS(5661),
    [aux_sym_basic_type_token21] = ACTIONS(5661),
    [aux_sym_basic_type_token22] = ACTIONS(5661),
    [aux_sym_basic_type_token48] = ACTIONS(5661),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5661),
    [anon_sym_POUNDif] = ACTIONS(5663),
    [anon_sym_POUNDIF] = ACTIONS(5663),
    [anon_sym_POUNDIf] = ACTIONS(5663),
    [anon_sym_not] = ACTIONS(5661),
    [anon_sym_NOT] = ACTIONS(5661),
    [anon_sym_Not] = ACTIONS(5661),
    [anon_sym_POUNDelse] = ACTIONS(5663),
    [anon_sym_POUNDELSE] = ACTIONS(5663),
    [anon_sym_POUNDElse] = ACTIONS(5663),
    [anon_sym_POUNDelse2] = ACTIONS(5663),
    [anon_sym_POUNDELSE2] = ACTIONS(5663),
    [anon_sym_POUNDElse2] = ACTIONS(5663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5661),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5661),
    [anon_sym_PLUS] = ACTIONS(5663),
    [sym_datetime_literal] = ACTIONS(5663),
    [sym_date_literal] = ACTIONS(5661),
    [sym_time_literal] = ACTIONS(5661),
    [sym_biginteger_literal] = ACTIONS(5663),
    [anon_sym_if] = ACTIONS(5661),
    [anon_sym_IF] = ACTIONS(5661),
    [anon_sym_If] = ACTIONS(5661),
    [anon_sym_else] = ACTIONS(5661),
    [anon_sym_ELSE] = ACTIONS(5661),
    [anon_sym_Else] = ACTIONS(5661),
    [anon_sym_case] = ACTIONS(5661),
    [anon_sym_CASE] = ACTIONS(5661),
    [anon_sym_Case] = ACTIONS(5661),
    [anon_sym_for] = ACTIONS(5661),
    [anon_sym_FOR] = ACTIONS(5661),
    [anon_sym_For] = ACTIONS(5661),
    [anon_sym_foreach] = ACTIONS(5661),
    [anon_sym_FOREACH] = ACTIONS(5661),
    [anon_sym_Foreach] = ACTIONS(5661),
    [anon_sym_while] = ACTIONS(5661),
    [anon_sym_WHILE] = ACTIONS(5661),
    [anon_sym_While] = ACTIONS(5661),
    [anon_sym_repeat] = ACTIONS(5661),
    [anon_sym_REPEAT] = ACTIONS(5661),
    [anon_sym_Repeat] = ACTIONS(5661),
    [anon_sym_exit] = ACTIONS(5661),
    [anon_sym_EXIT] = ACTIONS(5661),
    [anon_sym_Exit] = ACTIONS(5661),
    [anon_sym_continue] = ACTIONS(5661),
    [anon_sym_CONTINUE] = ACTIONS(5661),
    [anon_sym_Continue] = ACTIONS(5661),
    [anon_sym_break] = ACTIONS(5661),
    [anon_sym_BREAK] = ACTIONS(5661),
    [anon_sym_Break] = ACTIONS(5661),
    [anon_sym_with] = ACTIONS(5661),
    [anon_sym_WITH] = ACTIONS(5661),
    [anon_sym_With] = ACTIONS(5661),
    [sym_asserterror_keyword] = ACTIONS(5663),
    [sym_page_keyword] = ACTIONS(5661),
    [anon_sym_codeunit] = ACTIONS(5661),
    [anon_sym_CODEUNIT] = ACTIONS(5661),
    [anon_sym_Codeunit] = ACTIONS(5661),
    [anon_sym_CodeUnit] = ACTIONS(5661),
    [anon_sym_COdeunit] = ACTIONS(5661),
    [anon_sym_codeUnit] = ACTIONS(5661),
    [sym_report_keyword] = ACTIONS(5661),
    [sym_query_keyword] = ACTIONS(5661),
    [anon_sym_xmlport] = ACTIONS(5661),
    [anon_sym_XMLPORT] = ACTIONS(5661),
    [anon_sym_Xmlport] = ACTIONS(5661),
    [anon_sym_XMLport] = ACTIONS(5661),
    [anon_sym_XMLPort] = ACTIONS(5661),
    [anon_sym_XmlPort] = ACTIONS(5661),
    [anon_sym_enum] = ACTIONS(5661),
    [anon_sym_ENUM] = ACTIONS(5661),
    [anon_sym_Enum] = ACTIONS(5661),
    [anon_sym_eNUM] = ACTIONS(5661),
    [anon_sym_eNum] = ACTIONS(5661),
    [anon_sym_ENum] = ACTIONS(5661),
    [sym_quoted_identifier] = ACTIONS(5663),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5663),
    [sym_verbatim_string] = ACTIONS(5663),
    [sym_integer] = ACTIONS(5661),
    [sym_continue_as_identifier] = ACTIONS(5663),
    [sym_preproc_open] = ACTIONS(5663),
    [sym_end_keyword] = ACTIONS(5663),
  },
  [STATE(3256)] = {
    [sym_identifier] = ACTIONS(5665),
    [anon_sym_SEMI] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5667),
    [aux_sym_boolean_token1] = ACTIONS(5665),
    [aux_sym_boolean_token2] = ACTIONS(5665),
    [sym_decimal] = ACTIONS(5665),
    [anon_sym_LPAREN] = ACTIONS(5667),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5665),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [aux_sym_record_type_token1] = ACTIONS(5665),
    [aux_sym_basic_type_token21] = ACTIONS(5665),
    [aux_sym_basic_type_token22] = ACTIONS(5665),
    [aux_sym_basic_type_token48] = ACTIONS(5665),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5665),
    [anon_sym_POUNDif] = ACTIONS(5667),
    [anon_sym_POUNDIF] = ACTIONS(5667),
    [anon_sym_POUNDIf] = ACTIONS(5667),
    [anon_sym_not] = ACTIONS(5665),
    [anon_sym_NOT] = ACTIONS(5665),
    [anon_sym_Not] = ACTIONS(5665),
    [anon_sym_POUNDelse] = ACTIONS(5667),
    [anon_sym_POUNDELSE] = ACTIONS(5667),
    [anon_sym_POUNDElse] = ACTIONS(5667),
    [anon_sym_POUNDelse2] = ACTIONS(5667),
    [anon_sym_POUNDELSE2] = ACTIONS(5667),
    [anon_sym_POUNDElse2] = ACTIONS(5667),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5665),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5665),
    [anon_sym_PLUS] = ACTIONS(5667),
    [sym_datetime_literal] = ACTIONS(5667),
    [sym_date_literal] = ACTIONS(5665),
    [sym_time_literal] = ACTIONS(5665),
    [sym_biginteger_literal] = ACTIONS(5667),
    [anon_sym_if] = ACTIONS(5665),
    [anon_sym_IF] = ACTIONS(5665),
    [anon_sym_If] = ACTIONS(5665),
    [anon_sym_else] = ACTIONS(5665),
    [anon_sym_ELSE] = ACTIONS(5665),
    [anon_sym_Else] = ACTIONS(5665),
    [anon_sym_case] = ACTIONS(5665),
    [anon_sym_CASE] = ACTIONS(5665),
    [anon_sym_Case] = ACTIONS(5665),
    [anon_sym_for] = ACTIONS(5665),
    [anon_sym_FOR] = ACTIONS(5665),
    [anon_sym_For] = ACTIONS(5665),
    [anon_sym_foreach] = ACTIONS(5665),
    [anon_sym_FOREACH] = ACTIONS(5665),
    [anon_sym_Foreach] = ACTIONS(5665),
    [anon_sym_while] = ACTIONS(5665),
    [anon_sym_WHILE] = ACTIONS(5665),
    [anon_sym_While] = ACTIONS(5665),
    [anon_sym_repeat] = ACTIONS(5665),
    [anon_sym_REPEAT] = ACTIONS(5665),
    [anon_sym_Repeat] = ACTIONS(5665),
    [anon_sym_exit] = ACTIONS(5665),
    [anon_sym_EXIT] = ACTIONS(5665),
    [anon_sym_Exit] = ACTIONS(5665),
    [anon_sym_continue] = ACTIONS(5665),
    [anon_sym_CONTINUE] = ACTIONS(5665),
    [anon_sym_Continue] = ACTIONS(5665),
    [anon_sym_break] = ACTIONS(5665),
    [anon_sym_BREAK] = ACTIONS(5665),
    [anon_sym_Break] = ACTIONS(5665),
    [anon_sym_with] = ACTIONS(5665),
    [anon_sym_WITH] = ACTIONS(5665),
    [anon_sym_With] = ACTIONS(5665),
    [sym_asserterror_keyword] = ACTIONS(5667),
    [sym_page_keyword] = ACTIONS(5665),
    [anon_sym_codeunit] = ACTIONS(5665),
    [anon_sym_CODEUNIT] = ACTIONS(5665),
    [anon_sym_Codeunit] = ACTIONS(5665),
    [anon_sym_CodeUnit] = ACTIONS(5665),
    [anon_sym_COdeunit] = ACTIONS(5665),
    [anon_sym_codeUnit] = ACTIONS(5665),
    [sym_report_keyword] = ACTIONS(5665),
    [sym_query_keyword] = ACTIONS(5665),
    [anon_sym_xmlport] = ACTIONS(5665),
    [anon_sym_XMLPORT] = ACTIONS(5665),
    [anon_sym_Xmlport] = ACTIONS(5665),
    [anon_sym_XMLport] = ACTIONS(5665),
    [anon_sym_XMLPort] = ACTIONS(5665),
    [anon_sym_XmlPort] = ACTIONS(5665),
    [anon_sym_enum] = ACTIONS(5665),
    [anon_sym_ENUM] = ACTIONS(5665),
    [anon_sym_Enum] = ACTIONS(5665),
    [anon_sym_eNUM] = ACTIONS(5665),
    [anon_sym_eNum] = ACTIONS(5665),
    [anon_sym_ENum] = ACTIONS(5665),
    [sym_quoted_identifier] = ACTIONS(5667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5667),
    [sym_verbatim_string] = ACTIONS(5667),
    [sym_integer] = ACTIONS(5665),
    [sym_continue_as_identifier] = ACTIONS(5667),
    [sym_preproc_open] = ACTIONS(5667),
    [sym_end_keyword] = ACTIONS(5667),
  },
  [STATE(3257)] = {
    [sym_identifier] = ACTIONS(5669),
    [anon_sym_SEMI] = ACTIONS(5671),
    [anon_sym_DASH] = ACTIONS(5671),
    [aux_sym_boolean_token1] = ACTIONS(5669),
    [aux_sym_boolean_token2] = ACTIONS(5669),
    [sym_decimal] = ACTIONS(5669),
    [anon_sym_LPAREN] = ACTIONS(5671),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5669),
    [anon_sym_LBRACK] = ACTIONS(5671),
    [aux_sym_record_type_token1] = ACTIONS(5669),
    [aux_sym_basic_type_token21] = ACTIONS(5669),
    [aux_sym_basic_type_token22] = ACTIONS(5669),
    [aux_sym_basic_type_token48] = ACTIONS(5669),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5669),
    [anon_sym_POUNDif] = ACTIONS(5671),
    [anon_sym_POUNDIF] = ACTIONS(5671),
    [anon_sym_POUNDIf] = ACTIONS(5671),
    [anon_sym_not] = ACTIONS(5669),
    [anon_sym_NOT] = ACTIONS(5669),
    [anon_sym_Not] = ACTIONS(5669),
    [anon_sym_POUNDelse] = ACTIONS(5671),
    [anon_sym_POUNDELSE] = ACTIONS(5671),
    [anon_sym_POUNDElse] = ACTIONS(5671),
    [anon_sym_POUNDelse2] = ACTIONS(5671),
    [anon_sym_POUNDELSE2] = ACTIONS(5671),
    [anon_sym_POUNDElse2] = ACTIONS(5671),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5669),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5669),
    [anon_sym_PLUS] = ACTIONS(5671),
    [sym_datetime_literal] = ACTIONS(5671),
    [sym_date_literal] = ACTIONS(5669),
    [sym_time_literal] = ACTIONS(5669),
    [sym_biginteger_literal] = ACTIONS(5671),
    [anon_sym_if] = ACTIONS(5669),
    [anon_sym_IF] = ACTIONS(5669),
    [anon_sym_If] = ACTIONS(5669),
    [anon_sym_else] = ACTIONS(5669),
    [anon_sym_ELSE] = ACTIONS(5669),
    [anon_sym_Else] = ACTIONS(5669),
    [anon_sym_case] = ACTIONS(5669),
    [anon_sym_CASE] = ACTIONS(5669),
    [anon_sym_Case] = ACTIONS(5669),
    [anon_sym_for] = ACTIONS(5669),
    [anon_sym_FOR] = ACTIONS(5669),
    [anon_sym_For] = ACTIONS(5669),
    [anon_sym_foreach] = ACTIONS(5669),
    [anon_sym_FOREACH] = ACTIONS(5669),
    [anon_sym_Foreach] = ACTIONS(5669),
    [anon_sym_while] = ACTIONS(5669),
    [anon_sym_WHILE] = ACTIONS(5669),
    [anon_sym_While] = ACTIONS(5669),
    [anon_sym_repeat] = ACTIONS(5669),
    [anon_sym_REPEAT] = ACTIONS(5669),
    [anon_sym_Repeat] = ACTIONS(5669),
    [anon_sym_exit] = ACTIONS(5669),
    [anon_sym_EXIT] = ACTIONS(5669),
    [anon_sym_Exit] = ACTIONS(5669),
    [anon_sym_continue] = ACTIONS(5669),
    [anon_sym_CONTINUE] = ACTIONS(5669),
    [anon_sym_Continue] = ACTIONS(5669),
    [anon_sym_break] = ACTIONS(5669),
    [anon_sym_BREAK] = ACTIONS(5669),
    [anon_sym_Break] = ACTIONS(5669),
    [anon_sym_with] = ACTIONS(5669),
    [anon_sym_WITH] = ACTIONS(5669),
    [anon_sym_With] = ACTIONS(5669),
    [sym_asserterror_keyword] = ACTIONS(5671),
    [sym_page_keyword] = ACTIONS(5669),
    [anon_sym_codeunit] = ACTIONS(5669),
    [anon_sym_CODEUNIT] = ACTIONS(5669),
    [anon_sym_Codeunit] = ACTIONS(5669),
    [anon_sym_CodeUnit] = ACTIONS(5669),
    [anon_sym_COdeunit] = ACTIONS(5669),
    [anon_sym_codeUnit] = ACTIONS(5669),
    [sym_report_keyword] = ACTIONS(5669),
    [sym_query_keyword] = ACTIONS(5669),
    [anon_sym_xmlport] = ACTIONS(5669),
    [anon_sym_XMLPORT] = ACTIONS(5669),
    [anon_sym_Xmlport] = ACTIONS(5669),
    [anon_sym_XMLport] = ACTIONS(5669),
    [anon_sym_XMLPort] = ACTIONS(5669),
    [anon_sym_XmlPort] = ACTIONS(5669),
    [anon_sym_enum] = ACTIONS(5669),
    [anon_sym_ENUM] = ACTIONS(5669),
    [anon_sym_Enum] = ACTIONS(5669),
    [anon_sym_eNUM] = ACTIONS(5669),
    [anon_sym_eNum] = ACTIONS(5669),
    [anon_sym_ENum] = ACTIONS(5669),
    [sym_quoted_identifier] = ACTIONS(5671),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5671),
    [sym_verbatim_string] = ACTIONS(5671),
    [sym_integer] = ACTIONS(5669),
    [sym_continue_as_identifier] = ACTIONS(5671),
    [sym_preproc_open] = ACTIONS(5671),
    [sym_end_keyword] = ACTIONS(5671),
  },
  [STATE(3258)] = {
    [sym_identifier] = ACTIONS(5673),
    [anon_sym_SEMI] = ACTIONS(5675),
    [anon_sym_DASH] = ACTIONS(5675),
    [aux_sym_boolean_token1] = ACTIONS(5673),
    [aux_sym_boolean_token2] = ACTIONS(5673),
    [sym_decimal] = ACTIONS(5673),
    [anon_sym_LPAREN] = ACTIONS(5675),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5673),
    [anon_sym_LBRACK] = ACTIONS(5675),
    [aux_sym_record_type_token1] = ACTIONS(5673),
    [aux_sym_basic_type_token21] = ACTIONS(5673),
    [aux_sym_basic_type_token22] = ACTIONS(5673),
    [aux_sym_basic_type_token48] = ACTIONS(5673),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5673),
    [anon_sym_POUNDif] = ACTIONS(5675),
    [anon_sym_POUNDIF] = ACTIONS(5675),
    [anon_sym_POUNDIf] = ACTIONS(5675),
    [anon_sym_not] = ACTIONS(5673),
    [anon_sym_NOT] = ACTIONS(5673),
    [anon_sym_Not] = ACTIONS(5673),
    [anon_sym_POUNDelse] = ACTIONS(5675),
    [anon_sym_POUNDELSE] = ACTIONS(5675),
    [anon_sym_POUNDElse] = ACTIONS(5675),
    [anon_sym_POUNDelse2] = ACTIONS(5675),
    [anon_sym_POUNDELSE2] = ACTIONS(5675),
    [anon_sym_POUNDElse2] = ACTIONS(5675),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5673),
    [anon_sym_PLUS] = ACTIONS(5675),
    [sym_datetime_literal] = ACTIONS(5675),
    [sym_date_literal] = ACTIONS(5673),
    [sym_time_literal] = ACTIONS(5673),
    [sym_biginteger_literal] = ACTIONS(5675),
    [anon_sym_if] = ACTIONS(5673),
    [anon_sym_IF] = ACTIONS(5673),
    [anon_sym_If] = ACTIONS(5673),
    [anon_sym_else] = ACTIONS(5673),
    [anon_sym_ELSE] = ACTIONS(5673),
    [anon_sym_Else] = ACTIONS(5673),
    [anon_sym_case] = ACTIONS(5673),
    [anon_sym_CASE] = ACTIONS(5673),
    [anon_sym_Case] = ACTIONS(5673),
    [anon_sym_for] = ACTIONS(5673),
    [anon_sym_FOR] = ACTIONS(5673),
    [anon_sym_For] = ACTIONS(5673),
    [anon_sym_foreach] = ACTIONS(5673),
    [anon_sym_FOREACH] = ACTIONS(5673),
    [anon_sym_Foreach] = ACTIONS(5673),
    [anon_sym_while] = ACTIONS(5673),
    [anon_sym_WHILE] = ACTIONS(5673),
    [anon_sym_While] = ACTIONS(5673),
    [anon_sym_repeat] = ACTIONS(5673),
    [anon_sym_REPEAT] = ACTIONS(5673),
    [anon_sym_Repeat] = ACTIONS(5673),
    [anon_sym_exit] = ACTIONS(5673),
    [anon_sym_EXIT] = ACTIONS(5673),
    [anon_sym_Exit] = ACTIONS(5673),
    [anon_sym_continue] = ACTIONS(5673),
    [anon_sym_CONTINUE] = ACTIONS(5673),
    [anon_sym_Continue] = ACTIONS(5673),
    [anon_sym_break] = ACTIONS(5673),
    [anon_sym_BREAK] = ACTIONS(5673),
    [anon_sym_Break] = ACTIONS(5673),
    [anon_sym_with] = ACTIONS(5673),
    [anon_sym_WITH] = ACTIONS(5673),
    [anon_sym_With] = ACTIONS(5673),
    [sym_asserterror_keyword] = ACTIONS(5675),
    [sym_page_keyword] = ACTIONS(5673),
    [anon_sym_codeunit] = ACTIONS(5673),
    [anon_sym_CODEUNIT] = ACTIONS(5673),
    [anon_sym_Codeunit] = ACTIONS(5673),
    [anon_sym_CodeUnit] = ACTIONS(5673),
    [anon_sym_COdeunit] = ACTIONS(5673),
    [anon_sym_codeUnit] = ACTIONS(5673),
    [sym_report_keyword] = ACTIONS(5673),
    [sym_query_keyword] = ACTIONS(5673),
    [anon_sym_xmlport] = ACTIONS(5673),
    [anon_sym_XMLPORT] = ACTIONS(5673),
    [anon_sym_Xmlport] = ACTIONS(5673),
    [anon_sym_XMLport] = ACTIONS(5673),
    [anon_sym_XMLPort] = ACTIONS(5673),
    [anon_sym_XmlPort] = ACTIONS(5673),
    [anon_sym_enum] = ACTIONS(5673),
    [anon_sym_ENUM] = ACTIONS(5673),
    [anon_sym_Enum] = ACTIONS(5673),
    [anon_sym_eNUM] = ACTIONS(5673),
    [anon_sym_eNum] = ACTIONS(5673),
    [anon_sym_ENum] = ACTIONS(5673),
    [sym_quoted_identifier] = ACTIONS(5675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5675),
    [sym_verbatim_string] = ACTIONS(5675),
    [sym_integer] = ACTIONS(5673),
    [sym_continue_as_identifier] = ACTIONS(5675),
    [sym_preproc_open] = ACTIONS(5675),
    [sym_end_keyword] = ACTIONS(5675),
  },
  [STATE(3259)] = {
    [sym_identifier] = ACTIONS(6232),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6234),
    [aux_sym_boolean_token1] = ACTIONS(6232),
    [aux_sym_boolean_token2] = ACTIONS(6232),
    [sym_decimal] = ACTIONS(6232),
    [anon_sym_LPAREN] = ACTIONS(6234),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6232),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [aux_sym_record_type_token1] = ACTIONS(6232),
    [aux_sym_basic_type_token21] = ACTIONS(6232),
    [aux_sym_basic_type_token22] = ACTIONS(6232),
    [aux_sym_basic_type_token48] = ACTIONS(6232),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6232),
    [anon_sym_POUNDif] = ACTIONS(6234),
    [anon_sym_POUNDIF] = ACTIONS(6234),
    [anon_sym_POUNDIf] = ACTIONS(6234),
    [anon_sym_not] = ACTIONS(6232),
    [anon_sym_NOT] = ACTIONS(6232),
    [anon_sym_Not] = ACTIONS(6232),
    [anon_sym_POUNDelse] = ACTIONS(6234),
    [anon_sym_POUNDELSE] = ACTIONS(6234),
    [anon_sym_POUNDElse] = ACTIONS(6234),
    [anon_sym_POUNDelse2] = ACTIONS(6234),
    [anon_sym_POUNDELSE2] = ACTIONS(6234),
    [anon_sym_POUNDElse2] = ACTIONS(6234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6232),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6232),
    [anon_sym_PLUS] = ACTIONS(6234),
    [sym_datetime_literal] = ACTIONS(6234),
    [sym_date_literal] = ACTIONS(6232),
    [sym_time_literal] = ACTIONS(6232),
    [sym_biginteger_literal] = ACTIONS(6234),
    [anon_sym_if] = ACTIONS(6232),
    [anon_sym_IF] = ACTIONS(6232),
    [anon_sym_If] = ACTIONS(6232),
    [anon_sym_else] = ACTIONS(6232),
    [anon_sym_ELSE] = ACTIONS(6232),
    [anon_sym_Else] = ACTIONS(6232),
    [anon_sym_case] = ACTIONS(6232),
    [anon_sym_CASE] = ACTIONS(6232),
    [anon_sym_Case] = ACTIONS(6232),
    [anon_sym_for] = ACTIONS(6232),
    [anon_sym_FOR] = ACTIONS(6232),
    [anon_sym_For] = ACTIONS(6232),
    [anon_sym_foreach] = ACTIONS(6232),
    [anon_sym_FOREACH] = ACTIONS(6232),
    [anon_sym_Foreach] = ACTIONS(6232),
    [anon_sym_while] = ACTIONS(6232),
    [anon_sym_WHILE] = ACTIONS(6232),
    [anon_sym_While] = ACTIONS(6232),
    [anon_sym_repeat] = ACTIONS(6232),
    [anon_sym_REPEAT] = ACTIONS(6232),
    [anon_sym_Repeat] = ACTIONS(6232),
    [anon_sym_exit] = ACTIONS(6232),
    [anon_sym_EXIT] = ACTIONS(6232),
    [anon_sym_Exit] = ACTIONS(6232),
    [anon_sym_continue] = ACTIONS(6232),
    [anon_sym_CONTINUE] = ACTIONS(6232),
    [anon_sym_Continue] = ACTIONS(6232),
    [anon_sym_break] = ACTIONS(6232),
    [anon_sym_BREAK] = ACTIONS(6232),
    [anon_sym_Break] = ACTIONS(6232),
    [anon_sym_with] = ACTIONS(6232),
    [anon_sym_WITH] = ACTIONS(6232),
    [anon_sym_With] = ACTIONS(6232),
    [sym_asserterror_keyword] = ACTIONS(6234),
    [sym_page_keyword] = ACTIONS(6232),
    [anon_sym_codeunit] = ACTIONS(6232),
    [anon_sym_CODEUNIT] = ACTIONS(6232),
    [anon_sym_Codeunit] = ACTIONS(6232),
    [anon_sym_CodeUnit] = ACTIONS(6232),
    [anon_sym_COdeunit] = ACTIONS(6232),
    [anon_sym_codeUnit] = ACTIONS(6232),
    [sym_report_keyword] = ACTIONS(6232),
    [sym_query_keyword] = ACTIONS(6232),
    [anon_sym_xmlport] = ACTIONS(6232),
    [anon_sym_XMLPORT] = ACTIONS(6232),
    [anon_sym_Xmlport] = ACTIONS(6232),
    [anon_sym_XMLport] = ACTIONS(6232),
    [anon_sym_XMLPort] = ACTIONS(6232),
    [anon_sym_XmlPort] = ACTIONS(6232),
    [anon_sym_enum] = ACTIONS(6232),
    [anon_sym_ENUM] = ACTIONS(6232),
    [anon_sym_Enum] = ACTIONS(6232),
    [anon_sym_eNUM] = ACTIONS(6232),
    [anon_sym_eNum] = ACTIONS(6232),
    [anon_sym_ENum] = ACTIONS(6232),
    [sym_quoted_identifier] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6234),
    [sym_verbatim_string] = ACTIONS(6234),
    [sym_integer] = ACTIONS(6232),
    [sym_continue_as_identifier] = ACTIONS(6234),
    [sym_preproc_open] = ACTIONS(6234),
    [sym_end_keyword] = ACTIONS(6234),
  },
  [STATE(3260)] = {
    [sym_identifier] = ACTIONS(6340),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_DASH] = ACTIONS(6342),
    [aux_sym_boolean_token1] = ACTIONS(6340),
    [aux_sym_boolean_token2] = ACTIONS(6340),
    [sym_decimal] = ACTIONS(6340),
    [anon_sym_LPAREN] = ACTIONS(6342),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6340),
    [anon_sym_LBRACK] = ACTIONS(6342),
    [aux_sym_record_type_token1] = ACTIONS(6340),
    [aux_sym_basic_type_token21] = ACTIONS(6340),
    [aux_sym_basic_type_token22] = ACTIONS(6340),
    [aux_sym_basic_type_token48] = ACTIONS(6340),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6340),
    [anon_sym_POUNDif] = ACTIONS(6342),
    [anon_sym_POUNDIF] = ACTIONS(6342),
    [anon_sym_POUNDIf] = ACTIONS(6342),
    [anon_sym_not] = ACTIONS(6340),
    [anon_sym_NOT] = ACTIONS(6340),
    [anon_sym_Not] = ACTIONS(6340),
    [anon_sym_POUNDelse] = ACTIONS(6342),
    [anon_sym_POUNDELSE] = ACTIONS(6342),
    [anon_sym_POUNDElse] = ACTIONS(6342),
    [anon_sym_POUNDelse2] = ACTIONS(6342),
    [anon_sym_POUNDELSE2] = ACTIONS(6342),
    [anon_sym_POUNDElse2] = ACTIONS(6342),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6340),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6340),
    [anon_sym_PLUS] = ACTIONS(6342),
    [sym_datetime_literal] = ACTIONS(6342),
    [sym_date_literal] = ACTIONS(6340),
    [sym_time_literal] = ACTIONS(6340),
    [sym_biginteger_literal] = ACTIONS(6342),
    [anon_sym_if] = ACTIONS(6340),
    [anon_sym_IF] = ACTIONS(6340),
    [anon_sym_If] = ACTIONS(6340),
    [anon_sym_else] = ACTIONS(6340),
    [anon_sym_ELSE] = ACTIONS(6340),
    [anon_sym_Else] = ACTIONS(6340),
    [anon_sym_case] = ACTIONS(6340),
    [anon_sym_CASE] = ACTIONS(6340),
    [anon_sym_Case] = ACTIONS(6340),
    [anon_sym_for] = ACTIONS(6340),
    [anon_sym_FOR] = ACTIONS(6340),
    [anon_sym_For] = ACTIONS(6340),
    [anon_sym_foreach] = ACTIONS(6340),
    [anon_sym_FOREACH] = ACTIONS(6340),
    [anon_sym_Foreach] = ACTIONS(6340),
    [anon_sym_while] = ACTIONS(6340),
    [anon_sym_WHILE] = ACTIONS(6340),
    [anon_sym_While] = ACTIONS(6340),
    [anon_sym_repeat] = ACTIONS(6340),
    [anon_sym_REPEAT] = ACTIONS(6340),
    [anon_sym_Repeat] = ACTIONS(6340),
    [anon_sym_exit] = ACTIONS(6340),
    [anon_sym_EXIT] = ACTIONS(6340),
    [anon_sym_Exit] = ACTIONS(6340),
    [anon_sym_continue] = ACTIONS(6340),
    [anon_sym_CONTINUE] = ACTIONS(6340),
    [anon_sym_Continue] = ACTIONS(6340),
    [anon_sym_break] = ACTIONS(6340),
    [anon_sym_BREAK] = ACTIONS(6340),
    [anon_sym_Break] = ACTIONS(6340),
    [anon_sym_with] = ACTIONS(6340),
    [anon_sym_WITH] = ACTIONS(6340),
    [anon_sym_With] = ACTIONS(6340),
    [sym_asserterror_keyword] = ACTIONS(6342),
    [sym_page_keyword] = ACTIONS(6340),
    [anon_sym_codeunit] = ACTIONS(6340),
    [anon_sym_CODEUNIT] = ACTIONS(6340),
    [anon_sym_Codeunit] = ACTIONS(6340),
    [anon_sym_CodeUnit] = ACTIONS(6340),
    [anon_sym_COdeunit] = ACTIONS(6340),
    [anon_sym_codeUnit] = ACTIONS(6340),
    [sym_report_keyword] = ACTIONS(6340),
    [sym_query_keyword] = ACTIONS(6340),
    [anon_sym_xmlport] = ACTIONS(6340),
    [anon_sym_XMLPORT] = ACTIONS(6340),
    [anon_sym_Xmlport] = ACTIONS(6340),
    [anon_sym_XMLport] = ACTIONS(6340),
    [anon_sym_XMLPort] = ACTIONS(6340),
    [anon_sym_XmlPort] = ACTIONS(6340),
    [anon_sym_enum] = ACTIONS(6340),
    [anon_sym_ENUM] = ACTIONS(6340),
    [anon_sym_Enum] = ACTIONS(6340),
    [anon_sym_eNUM] = ACTIONS(6340),
    [anon_sym_eNum] = ACTIONS(6340),
    [anon_sym_ENum] = ACTIONS(6340),
    [sym_quoted_identifier] = ACTIONS(6342),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6342),
    [sym_verbatim_string] = ACTIONS(6342),
    [sym_integer] = ACTIONS(6340),
    [sym_continue_as_identifier] = ACTIONS(6342),
    [sym_preproc_open] = ACTIONS(6342),
    [sym_end_keyword] = ACTIONS(6342),
  },
  [STATE(3261)] = {
    [sym_identifier] = ACTIONS(6288),
    [anon_sym_SEMI] = ACTIONS(6290),
    [anon_sym_DASH] = ACTIONS(6290),
    [aux_sym_boolean_token1] = ACTIONS(6288),
    [aux_sym_boolean_token2] = ACTIONS(6288),
    [sym_decimal] = ACTIONS(6288),
    [anon_sym_LPAREN] = ACTIONS(6290),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6288),
    [anon_sym_LBRACK] = ACTIONS(6290),
    [aux_sym_record_type_token1] = ACTIONS(6288),
    [aux_sym_basic_type_token21] = ACTIONS(6288),
    [aux_sym_basic_type_token22] = ACTIONS(6288),
    [aux_sym_basic_type_token48] = ACTIONS(6288),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6288),
    [anon_sym_POUNDif] = ACTIONS(6290),
    [anon_sym_POUNDIF] = ACTIONS(6290),
    [anon_sym_POUNDIf] = ACTIONS(6290),
    [anon_sym_not] = ACTIONS(6288),
    [anon_sym_NOT] = ACTIONS(6288),
    [anon_sym_Not] = ACTIONS(6288),
    [anon_sym_POUNDelse] = ACTIONS(6290),
    [anon_sym_POUNDELSE] = ACTIONS(6290),
    [anon_sym_POUNDElse] = ACTIONS(6290),
    [anon_sym_POUNDelse2] = ACTIONS(6290),
    [anon_sym_POUNDELSE2] = ACTIONS(6290),
    [anon_sym_POUNDElse2] = ACTIONS(6290),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6288),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6288),
    [anon_sym_PLUS] = ACTIONS(6290),
    [sym_datetime_literal] = ACTIONS(6290),
    [sym_date_literal] = ACTIONS(6288),
    [sym_time_literal] = ACTIONS(6288),
    [sym_biginteger_literal] = ACTIONS(6290),
    [anon_sym_if] = ACTIONS(6288),
    [anon_sym_IF] = ACTIONS(6288),
    [anon_sym_If] = ACTIONS(6288),
    [anon_sym_else] = ACTIONS(6288),
    [anon_sym_ELSE] = ACTIONS(6288),
    [anon_sym_Else] = ACTIONS(6288),
    [anon_sym_case] = ACTIONS(6288),
    [anon_sym_CASE] = ACTIONS(6288),
    [anon_sym_Case] = ACTIONS(6288),
    [anon_sym_for] = ACTIONS(6288),
    [anon_sym_FOR] = ACTIONS(6288),
    [anon_sym_For] = ACTIONS(6288),
    [anon_sym_foreach] = ACTIONS(6288),
    [anon_sym_FOREACH] = ACTIONS(6288),
    [anon_sym_Foreach] = ACTIONS(6288),
    [anon_sym_while] = ACTIONS(6288),
    [anon_sym_WHILE] = ACTIONS(6288),
    [anon_sym_While] = ACTIONS(6288),
    [anon_sym_repeat] = ACTIONS(6288),
    [anon_sym_REPEAT] = ACTIONS(6288),
    [anon_sym_Repeat] = ACTIONS(6288),
    [anon_sym_exit] = ACTIONS(6288),
    [anon_sym_EXIT] = ACTIONS(6288),
    [anon_sym_Exit] = ACTIONS(6288),
    [anon_sym_continue] = ACTIONS(6288),
    [anon_sym_CONTINUE] = ACTIONS(6288),
    [anon_sym_Continue] = ACTIONS(6288),
    [anon_sym_break] = ACTIONS(6288),
    [anon_sym_BREAK] = ACTIONS(6288),
    [anon_sym_Break] = ACTIONS(6288),
    [anon_sym_with] = ACTIONS(6288),
    [anon_sym_WITH] = ACTIONS(6288),
    [anon_sym_With] = ACTIONS(6288),
    [sym_asserterror_keyword] = ACTIONS(6290),
    [sym_page_keyword] = ACTIONS(6288),
    [anon_sym_codeunit] = ACTIONS(6288),
    [anon_sym_CODEUNIT] = ACTIONS(6288),
    [anon_sym_Codeunit] = ACTIONS(6288),
    [anon_sym_CodeUnit] = ACTIONS(6288),
    [anon_sym_COdeunit] = ACTIONS(6288),
    [anon_sym_codeUnit] = ACTIONS(6288),
    [sym_report_keyword] = ACTIONS(6288),
    [sym_query_keyword] = ACTIONS(6288),
    [anon_sym_xmlport] = ACTIONS(6288),
    [anon_sym_XMLPORT] = ACTIONS(6288),
    [anon_sym_Xmlport] = ACTIONS(6288),
    [anon_sym_XMLport] = ACTIONS(6288),
    [anon_sym_XMLPort] = ACTIONS(6288),
    [anon_sym_XmlPort] = ACTIONS(6288),
    [anon_sym_enum] = ACTIONS(6288),
    [anon_sym_ENUM] = ACTIONS(6288),
    [anon_sym_Enum] = ACTIONS(6288),
    [anon_sym_eNUM] = ACTIONS(6288),
    [anon_sym_eNum] = ACTIONS(6288),
    [anon_sym_ENum] = ACTIONS(6288),
    [sym_quoted_identifier] = ACTIONS(6290),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6290),
    [sym_verbatim_string] = ACTIONS(6290),
    [sym_integer] = ACTIONS(6288),
    [sym_continue_as_identifier] = ACTIONS(6290),
    [sym_preproc_open] = ACTIONS(6290),
    [sym_end_keyword] = ACTIONS(6290),
  },
  [STATE(3262)] = {
    [sym_identifier] = ACTIONS(6344),
    [anon_sym_SEMI] = ACTIONS(6346),
    [anon_sym_DASH] = ACTIONS(6346),
    [aux_sym_boolean_token1] = ACTIONS(6344),
    [aux_sym_boolean_token2] = ACTIONS(6344),
    [sym_decimal] = ACTIONS(6344),
    [anon_sym_LPAREN] = ACTIONS(6346),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6344),
    [anon_sym_LBRACK] = ACTIONS(6346),
    [aux_sym_record_type_token1] = ACTIONS(6344),
    [aux_sym_basic_type_token21] = ACTIONS(6344),
    [aux_sym_basic_type_token22] = ACTIONS(6344),
    [aux_sym_basic_type_token48] = ACTIONS(6344),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6344),
    [anon_sym_POUNDif] = ACTIONS(6346),
    [anon_sym_POUNDIF] = ACTIONS(6346),
    [anon_sym_POUNDIf] = ACTIONS(6346),
    [anon_sym_not] = ACTIONS(6344),
    [anon_sym_NOT] = ACTIONS(6344),
    [anon_sym_Not] = ACTIONS(6344),
    [anon_sym_POUNDelse] = ACTIONS(6346),
    [anon_sym_POUNDELSE] = ACTIONS(6346),
    [anon_sym_POUNDElse] = ACTIONS(6346),
    [anon_sym_POUNDelse2] = ACTIONS(6346),
    [anon_sym_POUNDELSE2] = ACTIONS(6346),
    [anon_sym_POUNDElse2] = ACTIONS(6346),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6344),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6344),
    [anon_sym_PLUS] = ACTIONS(6346),
    [sym_datetime_literal] = ACTIONS(6346),
    [sym_date_literal] = ACTIONS(6344),
    [sym_time_literal] = ACTIONS(6344),
    [sym_biginteger_literal] = ACTIONS(6346),
    [anon_sym_if] = ACTIONS(6344),
    [anon_sym_IF] = ACTIONS(6344),
    [anon_sym_If] = ACTIONS(6344),
    [anon_sym_else] = ACTIONS(6344),
    [anon_sym_ELSE] = ACTIONS(6344),
    [anon_sym_Else] = ACTIONS(6344),
    [anon_sym_case] = ACTIONS(6344),
    [anon_sym_CASE] = ACTIONS(6344),
    [anon_sym_Case] = ACTIONS(6344),
    [anon_sym_for] = ACTIONS(6344),
    [anon_sym_FOR] = ACTIONS(6344),
    [anon_sym_For] = ACTIONS(6344),
    [anon_sym_foreach] = ACTIONS(6344),
    [anon_sym_FOREACH] = ACTIONS(6344),
    [anon_sym_Foreach] = ACTIONS(6344),
    [anon_sym_while] = ACTIONS(6344),
    [anon_sym_WHILE] = ACTIONS(6344),
    [anon_sym_While] = ACTIONS(6344),
    [anon_sym_repeat] = ACTIONS(6344),
    [anon_sym_REPEAT] = ACTIONS(6344),
    [anon_sym_Repeat] = ACTIONS(6344),
    [anon_sym_exit] = ACTIONS(6344),
    [anon_sym_EXIT] = ACTIONS(6344),
    [anon_sym_Exit] = ACTIONS(6344),
    [anon_sym_continue] = ACTIONS(6344),
    [anon_sym_CONTINUE] = ACTIONS(6344),
    [anon_sym_Continue] = ACTIONS(6344),
    [anon_sym_break] = ACTIONS(6344),
    [anon_sym_BREAK] = ACTIONS(6344),
    [anon_sym_Break] = ACTIONS(6344),
    [anon_sym_with] = ACTIONS(6344),
    [anon_sym_WITH] = ACTIONS(6344),
    [anon_sym_With] = ACTIONS(6344),
    [sym_asserterror_keyword] = ACTIONS(6346),
    [sym_page_keyword] = ACTIONS(6344),
    [anon_sym_codeunit] = ACTIONS(6344),
    [anon_sym_CODEUNIT] = ACTIONS(6344),
    [anon_sym_Codeunit] = ACTIONS(6344),
    [anon_sym_CodeUnit] = ACTIONS(6344),
    [anon_sym_COdeunit] = ACTIONS(6344),
    [anon_sym_codeUnit] = ACTIONS(6344),
    [sym_report_keyword] = ACTIONS(6344),
    [sym_query_keyword] = ACTIONS(6344),
    [anon_sym_xmlport] = ACTIONS(6344),
    [anon_sym_XMLPORT] = ACTIONS(6344),
    [anon_sym_Xmlport] = ACTIONS(6344),
    [anon_sym_XMLport] = ACTIONS(6344),
    [anon_sym_XMLPort] = ACTIONS(6344),
    [anon_sym_XmlPort] = ACTIONS(6344),
    [anon_sym_enum] = ACTIONS(6344),
    [anon_sym_ENUM] = ACTIONS(6344),
    [anon_sym_Enum] = ACTIONS(6344),
    [anon_sym_eNUM] = ACTIONS(6344),
    [anon_sym_eNum] = ACTIONS(6344),
    [anon_sym_ENum] = ACTIONS(6344),
    [sym_quoted_identifier] = ACTIONS(6346),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6346),
    [sym_verbatim_string] = ACTIONS(6346),
    [sym_integer] = ACTIONS(6344),
    [sym_continue_as_identifier] = ACTIONS(6346),
    [sym_preproc_open] = ACTIONS(6346),
    [sym_end_keyword] = ACTIONS(6346),
  },
  [STATE(3263)] = {
    [sym_identifier] = ACTIONS(6348),
    [anon_sym_SEMI] = ACTIONS(6350),
    [anon_sym_DASH] = ACTIONS(6350),
    [aux_sym_boolean_token1] = ACTIONS(6348),
    [aux_sym_boolean_token2] = ACTIONS(6348),
    [sym_decimal] = ACTIONS(6348),
    [anon_sym_LPAREN] = ACTIONS(6350),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6348),
    [anon_sym_LBRACK] = ACTIONS(6350),
    [aux_sym_record_type_token1] = ACTIONS(6348),
    [aux_sym_basic_type_token21] = ACTIONS(6348),
    [aux_sym_basic_type_token22] = ACTIONS(6348),
    [aux_sym_basic_type_token48] = ACTIONS(6348),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6348),
    [anon_sym_POUNDif] = ACTIONS(6350),
    [anon_sym_POUNDIF] = ACTIONS(6350),
    [anon_sym_POUNDIf] = ACTIONS(6350),
    [anon_sym_not] = ACTIONS(6348),
    [anon_sym_NOT] = ACTIONS(6348),
    [anon_sym_Not] = ACTIONS(6348),
    [anon_sym_POUNDelse] = ACTIONS(6350),
    [anon_sym_POUNDELSE] = ACTIONS(6350),
    [anon_sym_POUNDElse] = ACTIONS(6350),
    [anon_sym_POUNDelse2] = ACTIONS(6350),
    [anon_sym_POUNDELSE2] = ACTIONS(6350),
    [anon_sym_POUNDElse2] = ACTIONS(6350),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6348),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6348),
    [anon_sym_PLUS] = ACTIONS(6350),
    [sym_datetime_literal] = ACTIONS(6350),
    [sym_date_literal] = ACTIONS(6348),
    [sym_time_literal] = ACTIONS(6348),
    [sym_biginteger_literal] = ACTIONS(6350),
    [anon_sym_if] = ACTIONS(6348),
    [anon_sym_IF] = ACTIONS(6348),
    [anon_sym_If] = ACTIONS(6348),
    [anon_sym_else] = ACTIONS(6348),
    [anon_sym_ELSE] = ACTIONS(6348),
    [anon_sym_Else] = ACTIONS(6348),
    [anon_sym_case] = ACTIONS(6348),
    [anon_sym_CASE] = ACTIONS(6348),
    [anon_sym_Case] = ACTIONS(6348),
    [anon_sym_for] = ACTIONS(6348),
    [anon_sym_FOR] = ACTIONS(6348),
    [anon_sym_For] = ACTIONS(6348),
    [anon_sym_foreach] = ACTIONS(6348),
    [anon_sym_FOREACH] = ACTIONS(6348),
    [anon_sym_Foreach] = ACTIONS(6348),
    [anon_sym_while] = ACTIONS(6348),
    [anon_sym_WHILE] = ACTIONS(6348),
    [anon_sym_While] = ACTIONS(6348),
    [anon_sym_repeat] = ACTIONS(6348),
    [anon_sym_REPEAT] = ACTIONS(6348),
    [anon_sym_Repeat] = ACTIONS(6348),
    [anon_sym_exit] = ACTIONS(6348),
    [anon_sym_EXIT] = ACTIONS(6348),
    [anon_sym_Exit] = ACTIONS(6348),
    [anon_sym_continue] = ACTIONS(6348),
    [anon_sym_CONTINUE] = ACTIONS(6348),
    [anon_sym_Continue] = ACTIONS(6348),
    [anon_sym_break] = ACTIONS(6348),
    [anon_sym_BREAK] = ACTIONS(6348),
    [anon_sym_Break] = ACTIONS(6348),
    [anon_sym_with] = ACTIONS(6348),
    [anon_sym_WITH] = ACTIONS(6348),
    [anon_sym_With] = ACTIONS(6348),
    [sym_asserterror_keyword] = ACTIONS(6350),
    [sym_page_keyword] = ACTIONS(6348),
    [anon_sym_codeunit] = ACTIONS(6348),
    [anon_sym_CODEUNIT] = ACTIONS(6348),
    [anon_sym_Codeunit] = ACTIONS(6348),
    [anon_sym_CodeUnit] = ACTIONS(6348),
    [anon_sym_COdeunit] = ACTIONS(6348),
    [anon_sym_codeUnit] = ACTIONS(6348),
    [sym_report_keyword] = ACTIONS(6348),
    [sym_query_keyword] = ACTIONS(6348),
    [anon_sym_xmlport] = ACTIONS(6348),
    [anon_sym_XMLPORT] = ACTIONS(6348),
    [anon_sym_Xmlport] = ACTIONS(6348),
    [anon_sym_XMLport] = ACTIONS(6348),
    [anon_sym_XMLPort] = ACTIONS(6348),
    [anon_sym_XmlPort] = ACTIONS(6348),
    [anon_sym_enum] = ACTIONS(6348),
    [anon_sym_ENUM] = ACTIONS(6348),
    [anon_sym_Enum] = ACTIONS(6348),
    [anon_sym_eNUM] = ACTIONS(6348),
    [anon_sym_eNum] = ACTIONS(6348),
    [anon_sym_ENum] = ACTIONS(6348),
    [sym_quoted_identifier] = ACTIONS(6350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6350),
    [sym_verbatim_string] = ACTIONS(6350),
    [sym_integer] = ACTIONS(6348),
    [sym_continue_as_identifier] = ACTIONS(6350),
    [sym_preproc_open] = ACTIONS(6350),
    [sym_end_keyword] = ACTIONS(6350),
  },
  [STATE(3264)] = {
    [sym_identifier] = ACTIONS(5899),
    [anon_sym_SEMI] = ACTIONS(5901),
    [anon_sym_DASH] = ACTIONS(5901),
    [aux_sym_boolean_token1] = ACTIONS(5899),
    [aux_sym_boolean_token2] = ACTIONS(5899),
    [sym_decimal] = ACTIONS(5899),
    [anon_sym_LPAREN] = ACTIONS(5901),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5899),
    [anon_sym_LBRACK] = ACTIONS(5901),
    [aux_sym_record_type_token1] = ACTIONS(5899),
    [aux_sym_basic_type_token21] = ACTIONS(5899),
    [aux_sym_basic_type_token22] = ACTIONS(5899),
    [aux_sym_basic_type_token48] = ACTIONS(5899),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5899),
    [anon_sym_POUNDif] = ACTIONS(5901),
    [anon_sym_POUNDIF] = ACTIONS(5901),
    [anon_sym_POUNDIf] = ACTIONS(5901),
    [anon_sym_not] = ACTIONS(5899),
    [anon_sym_NOT] = ACTIONS(5899),
    [anon_sym_Not] = ACTIONS(5899),
    [anon_sym_POUNDelse] = ACTIONS(5901),
    [anon_sym_POUNDELSE] = ACTIONS(5901),
    [anon_sym_POUNDElse] = ACTIONS(5901),
    [anon_sym_POUNDelse2] = ACTIONS(5901),
    [anon_sym_POUNDELSE2] = ACTIONS(5901),
    [anon_sym_POUNDElse2] = ACTIONS(5901),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5899),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5899),
    [anon_sym_PLUS] = ACTIONS(5901),
    [sym_datetime_literal] = ACTIONS(5901),
    [sym_date_literal] = ACTIONS(5899),
    [sym_time_literal] = ACTIONS(5899),
    [sym_biginteger_literal] = ACTIONS(5901),
    [anon_sym_if] = ACTIONS(5899),
    [anon_sym_IF] = ACTIONS(5899),
    [anon_sym_If] = ACTIONS(5899),
    [anon_sym_else] = ACTIONS(5899),
    [anon_sym_ELSE] = ACTIONS(5899),
    [anon_sym_Else] = ACTIONS(5899),
    [anon_sym_case] = ACTIONS(5899),
    [anon_sym_CASE] = ACTIONS(5899),
    [anon_sym_Case] = ACTIONS(5899),
    [anon_sym_for] = ACTIONS(5899),
    [anon_sym_FOR] = ACTIONS(5899),
    [anon_sym_For] = ACTIONS(5899),
    [anon_sym_foreach] = ACTIONS(5899),
    [anon_sym_FOREACH] = ACTIONS(5899),
    [anon_sym_Foreach] = ACTIONS(5899),
    [anon_sym_while] = ACTIONS(5899),
    [anon_sym_WHILE] = ACTIONS(5899),
    [anon_sym_While] = ACTIONS(5899),
    [anon_sym_repeat] = ACTIONS(5899),
    [anon_sym_REPEAT] = ACTIONS(5899),
    [anon_sym_Repeat] = ACTIONS(5899),
    [anon_sym_exit] = ACTIONS(5899),
    [anon_sym_EXIT] = ACTIONS(5899),
    [anon_sym_Exit] = ACTIONS(5899),
    [anon_sym_continue] = ACTIONS(5899),
    [anon_sym_CONTINUE] = ACTIONS(5899),
    [anon_sym_Continue] = ACTIONS(5899),
    [anon_sym_break] = ACTIONS(5899),
    [anon_sym_BREAK] = ACTIONS(5899),
    [anon_sym_Break] = ACTIONS(5899),
    [anon_sym_with] = ACTIONS(5899),
    [anon_sym_WITH] = ACTIONS(5899),
    [anon_sym_With] = ACTIONS(5899),
    [sym_asserterror_keyword] = ACTIONS(5901),
    [sym_page_keyword] = ACTIONS(5899),
    [anon_sym_codeunit] = ACTIONS(5899),
    [anon_sym_CODEUNIT] = ACTIONS(5899),
    [anon_sym_Codeunit] = ACTIONS(5899),
    [anon_sym_CodeUnit] = ACTIONS(5899),
    [anon_sym_COdeunit] = ACTIONS(5899),
    [anon_sym_codeUnit] = ACTIONS(5899),
    [sym_report_keyword] = ACTIONS(5899),
    [sym_query_keyword] = ACTIONS(5899),
    [anon_sym_xmlport] = ACTIONS(5899),
    [anon_sym_XMLPORT] = ACTIONS(5899),
    [anon_sym_Xmlport] = ACTIONS(5899),
    [anon_sym_XMLport] = ACTIONS(5899),
    [anon_sym_XMLPort] = ACTIONS(5899),
    [anon_sym_XmlPort] = ACTIONS(5899),
    [anon_sym_enum] = ACTIONS(5899),
    [anon_sym_ENUM] = ACTIONS(5899),
    [anon_sym_Enum] = ACTIONS(5899),
    [anon_sym_eNUM] = ACTIONS(5899),
    [anon_sym_eNum] = ACTIONS(5899),
    [anon_sym_ENum] = ACTIONS(5899),
    [sym_quoted_identifier] = ACTIONS(5901),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5901),
    [sym_verbatim_string] = ACTIONS(5901),
    [sym_integer] = ACTIONS(5899),
    [sym_continue_as_identifier] = ACTIONS(5901),
    [sym_preproc_open] = ACTIONS(5901),
    [sym_end_keyword] = ACTIONS(5901),
  },
  [STATE(3265)] = {
    [sym_identifier] = ACTIONS(6352),
    [anon_sym_SEMI] = ACTIONS(6354),
    [anon_sym_DASH] = ACTIONS(6354),
    [aux_sym_boolean_token1] = ACTIONS(6352),
    [aux_sym_boolean_token2] = ACTIONS(6352),
    [sym_decimal] = ACTIONS(6352),
    [anon_sym_LPAREN] = ACTIONS(6354),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6352),
    [anon_sym_LBRACK] = ACTIONS(6354),
    [aux_sym_record_type_token1] = ACTIONS(6352),
    [aux_sym_basic_type_token21] = ACTIONS(6352),
    [aux_sym_basic_type_token22] = ACTIONS(6352),
    [aux_sym_basic_type_token48] = ACTIONS(6352),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6352),
    [anon_sym_POUNDif] = ACTIONS(6354),
    [anon_sym_POUNDIF] = ACTIONS(6354),
    [anon_sym_POUNDIf] = ACTIONS(6354),
    [anon_sym_not] = ACTIONS(6352),
    [anon_sym_NOT] = ACTIONS(6352),
    [anon_sym_Not] = ACTIONS(6352),
    [anon_sym_POUNDelse] = ACTIONS(6354),
    [anon_sym_POUNDELSE] = ACTIONS(6354),
    [anon_sym_POUNDElse] = ACTIONS(6354),
    [anon_sym_POUNDelse2] = ACTIONS(6354),
    [anon_sym_POUNDELSE2] = ACTIONS(6354),
    [anon_sym_POUNDElse2] = ACTIONS(6354),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6352),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(6354),
    [sym_datetime_literal] = ACTIONS(6354),
    [sym_date_literal] = ACTIONS(6352),
    [sym_time_literal] = ACTIONS(6352),
    [sym_biginteger_literal] = ACTIONS(6354),
    [anon_sym_if] = ACTIONS(6352),
    [anon_sym_IF] = ACTIONS(6352),
    [anon_sym_If] = ACTIONS(6352),
    [anon_sym_else] = ACTIONS(6352),
    [anon_sym_ELSE] = ACTIONS(6352),
    [anon_sym_Else] = ACTIONS(6352),
    [anon_sym_case] = ACTIONS(6352),
    [anon_sym_CASE] = ACTIONS(6352),
    [anon_sym_Case] = ACTIONS(6352),
    [anon_sym_for] = ACTIONS(6352),
    [anon_sym_FOR] = ACTIONS(6352),
    [anon_sym_For] = ACTIONS(6352),
    [anon_sym_foreach] = ACTIONS(6352),
    [anon_sym_FOREACH] = ACTIONS(6352),
    [anon_sym_Foreach] = ACTIONS(6352),
    [anon_sym_while] = ACTIONS(6352),
    [anon_sym_WHILE] = ACTIONS(6352),
    [anon_sym_While] = ACTIONS(6352),
    [anon_sym_repeat] = ACTIONS(6352),
    [anon_sym_REPEAT] = ACTIONS(6352),
    [anon_sym_Repeat] = ACTIONS(6352),
    [anon_sym_exit] = ACTIONS(6352),
    [anon_sym_EXIT] = ACTIONS(6352),
    [anon_sym_Exit] = ACTIONS(6352),
    [anon_sym_continue] = ACTIONS(6352),
    [anon_sym_CONTINUE] = ACTIONS(6352),
    [anon_sym_Continue] = ACTIONS(6352),
    [anon_sym_break] = ACTIONS(6352),
    [anon_sym_BREAK] = ACTIONS(6352),
    [anon_sym_Break] = ACTIONS(6352),
    [anon_sym_with] = ACTIONS(6352),
    [anon_sym_WITH] = ACTIONS(6352),
    [anon_sym_With] = ACTIONS(6352),
    [sym_asserterror_keyword] = ACTIONS(6354),
    [sym_page_keyword] = ACTIONS(6352),
    [anon_sym_codeunit] = ACTIONS(6352),
    [anon_sym_CODEUNIT] = ACTIONS(6352),
    [anon_sym_Codeunit] = ACTIONS(6352),
    [anon_sym_CodeUnit] = ACTIONS(6352),
    [anon_sym_COdeunit] = ACTIONS(6352),
    [anon_sym_codeUnit] = ACTIONS(6352),
    [sym_report_keyword] = ACTIONS(6352),
    [sym_query_keyword] = ACTIONS(6352),
    [anon_sym_xmlport] = ACTIONS(6352),
    [anon_sym_XMLPORT] = ACTIONS(6352),
    [anon_sym_Xmlport] = ACTIONS(6352),
    [anon_sym_XMLport] = ACTIONS(6352),
    [anon_sym_XMLPort] = ACTIONS(6352),
    [anon_sym_XmlPort] = ACTIONS(6352),
    [anon_sym_enum] = ACTIONS(6352),
    [anon_sym_ENUM] = ACTIONS(6352),
    [anon_sym_Enum] = ACTIONS(6352),
    [anon_sym_eNUM] = ACTIONS(6352),
    [anon_sym_eNum] = ACTIONS(6352),
    [anon_sym_ENum] = ACTIONS(6352),
    [sym_quoted_identifier] = ACTIONS(6354),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6354),
    [sym_verbatim_string] = ACTIONS(6354),
    [sym_integer] = ACTIONS(6352),
    [sym_continue_as_identifier] = ACTIONS(6354),
    [sym_preproc_open] = ACTIONS(6354),
    [sym_end_keyword] = ACTIONS(6354),
  },
  [STATE(3266)] = {
    [sym_identifier] = ACTIONS(6042),
    [anon_sym_SEMI] = ACTIONS(6044),
    [anon_sym_DASH] = ACTIONS(6044),
    [aux_sym_boolean_token1] = ACTIONS(6042),
    [aux_sym_boolean_token2] = ACTIONS(6042),
    [sym_decimal] = ACTIONS(6042),
    [anon_sym_LPAREN] = ACTIONS(6044),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6042),
    [anon_sym_LBRACK] = ACTIONS(6044),
    [aux_sym_record_type_token1] = ACTIONS(6042),
    [aux_sym_basic_type_token21] = ACTIONS(6042),
    [aux_sym_basic_type_token22] = ACTIONS(6042),
    [aux_sym_basic_type_token48] = ACTIONS(6042),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6042),
    [anon_sym_POUNDif] = ACTIONS(6044),
    [anon_sym_POUNDIF] = ACTIONS(6044),
    [anon_sym_POUNDIf] = ACTIONS(6044),
    [anon_sym_not] = ACTIONS(6042),
    [anon_sym_NOT] = ACTIONS(6042),
    [anon_sym_Not] = ACTIONS(6042),
    [anon_sym_POUNDelse] = ACTIONS(6044),
    [anon_sym_POUNDELSE] = ACTIONS(6044),
    [anon_sym_POUNDElse] = ACTIONS(6044),
    [anon_sym_POUNDelse2] = ACTIONS(6044),
    [anon_sym_POUNDELSE2] = ACTIONS(6044),
    [anon_sym_POUNDElse2] = ACTIONS(6044),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6042),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6042),
    [anon_sym_PLUS] = ACTIONS(6044),
    [sym_datetime_literal] = ACTIONS(6044),
    [sym_date_literal] = ACTIONS(6042),
    [sym_time_literal] = ACTIONS(6042),
    [sym_biginteger_literal] = ACTIONS(6044),
    [anon_sym_if] = ACTIONS(6042),
    [anon_sym_IF] = ACTIONS(6042),
    [anon_sym_If] = ACTIONS(6042),
    [anon_sym_else] = ACTIONS(6042),
    [anon_sym_ELSE] = ACTIONS(6042),
    [anon_sym_Else] = ACTIONS(6042),
    [anon_sym_case] = ACTIONS(6042),
    [anon_sym_CASE] = ACTIONS(6042),
    [anon_sym_Case] = ACTIONS(6042),
    [anon_sym_for] = ACTIONS(6042),
    [anon_sym_FOR] = ACTIONS(6042),
    [anon_sym_For] = ACTIONS(6042),
    [anon_sym_foreach] = ACTIONS(6042),
    [anon_sym_FOREACH] = ACTIONS(6042),
    [anon_sym_Foreach] = ACTIONS(6042),
    [anon_sym_while] = ACTIONS(6042),
    [anon_sym_WHILE] = ACTIONS(6042),
    [anon_sym_While] = ACTIONS(6042),
    [anon_sym_repeat] = ACTIONS(6042),
    [anon_sym_REPEAT] = ACTIONS(6042),
    [anon_sym_Repeat] = ACTIONS(6042),
    [anon_sym_exit] = ACTIONS(6042),
    [anon_sym_EXIT] = ACTIONS(6042),
    [anon_sym_Exit] = ACTIONS(6042),
    [anon_sym_continue] = ACTIONS(6042),
    [anon_sym_CONTINUE] = ACTIONS(6042),
    [anon_sym_Continue] = ACTIONS(6042),
    [anon_sym_break] = ACTIONS(6042),
    [anon_sym_BREAK] = ACTIONS(6042),
    [anon_sym_Break] = ACTIONS(6042),
    [anon_sym_with] = ACTIONS(6042),
    [anon_sym_WITH] = ACTIONS(6042),
    [anon_sym_With] = ACTIONS(6042),
    [sym_asserterror_keyword] = ACTIONS(6044),
    [sym_page_keyword] = ACTIONS(6042),
    [anon_sym_codeunit] = ACTIONS(6042),
    [anon_sym_CODEUNIT] = ACTIONS(6042),
    [anon_sym_Codeunit] = ACTIONS(6042),
    [anon_sym_CodeUnit] = ACTIONS(6042),
    [anon_sym_COdeunit] = ACTIONS(6042),
    [anon_sym_codeUnit] = ACTIONS(6042),
    [sym_report_keyword] = ACTIONS(6042),
    [sym_query_keyword] = ACTIONS(6042),
    [anon_sym_xmlport] = ACTIONS(6042),
    [anon_sym_XMLPORT] = ACTIONS(6042),
    [anon_sym_Xmlport] = ACTIONS(6042),
    [anon_sym_XMLport] = ACTIONS(6042),
    [anon_sym_XMLPort] = ACTIONS(6042),
    [anon_sym_XmlPort] = ACTIONS(6042),
    [anon_sym_enum] = ACTIONS(6042),
    [anon_sym_ENUM] = ACTIONS(6042),
    [anon_sym_Enum] = ACTIONS(6042),
    [anon_sym_eNUM] = ACTIONS(6042),
    [anon_sym_eNum] = ACTIONS(6042),
    [anon_sym_ENum] = ACTIONS(6042),
    [sym_quoted_identifier] = ACTIONS(6044),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6044),
    [sym_verbatim_string] = ACTIONS(6044),
    [sym_integer] = ACTIONS(6042),
    [sym_continue_as_identifier] = ACTIONS(6044),
    [sym_preproc_open] = ACTIONS(6044),
    [sym_end_keyword] = ACTIONS(6044),
  },
  [STATE(3267)] = {
    [sym_identifier] = ACTIONS(6042),
    [anon_sym_SEMI] = ACTIONS(6044),
    [anon_sym_DASH] = ACTIONS(6044),
    [aux_sym_boolean_token1] = ACTIONS(6042),
    [aux_sym_boolean_token2] = ACTIONS(6042),
    [sym_decimal] = ACTIONS(6042),
    [anon_sym_LPAREN] = ACTIONS(6044),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6042),
    [anon_sym_LBRACK] = ACTIONS(6044),
    [aux_sym_record_type_token1] = ACTIONS(6042),
    [aux_sym_basic_type_token21] = ACTIONS(6042),
    [aux_sym_basic_type_token22] = ACTIONS(6042),
    [aux_sym_basic_type_token48] = ACTIONS(6042),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6042),
    [anon_sym_POUNDif] = ACTIONS(6044),
    [anon_sym_POUNDIF] = ACTIONS(6044),
    [anon_sym_POUNDIf] = ACTIONS(6044),
    [anon_sym_not] = ACTIONS(6042),
    [anon_sym_NOT] = ACTIONS(6042),
    [anon_sym_Not] = ACTIONS(6042),
    [anon_sym_POUNDelse] = ACTIONS(6044),
    [anon_sym_POUNDELSE] = ACTIONS(6044),
    [anon_sym_POUNDElse] = ACTIONS(6044),
    [anon_sym_POUNDelse2] = ACTIONS(6044),
    [anon_sym_POUNDELSE2] = ACTIONS(6044),
    [anon_sym_POUNDElse2] = ACTIONS(6044),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6042),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6042),
    [anon_sym_PLUS] = ACTIONS(6044),
    [sym_datetime_literal] = ACTIONS(6044),
    [sym_date_literal] = ACTIONS(6042),
    [sym_time_literal] = ACTIONS(6042),
    [sym_biginteger_literal] = ACTIONS(6044),
    [anon_sym_if] = ACTIONS(6042),
    [anon_sym_IF] = ACTIONS(6042),
    [anon_sym_If] = ACTIONS(6042),
    [anon_sym_else] = ACTIONS(6042),
    [anon_sym_ELSE] = ACTIONS(6042),
    [anon_sym_Else] = ACTIONS(6042),
    [anon_sym_case] = ACTIONS(6042),
    [anon_sym_CASE] = ACTIONS(6042),
    [anon_sym_Case] = ACTIONS(6042),
    [anon_sym_for] = ACTIONS(6042),
    [anon_sym_FOR] = ACTIONS(6042),
    [anon_sym_For] = ACTIONS(6042),
    [anon_sym_foreach] = ACTIONS(6042),
    [anon_sym_FOREACH] = ACTIONS(6042),
    [anon_sym_Foreach] = ACTIONS(6042),
    [anon_sym_while] = ACTIONS(6042),
    [anon_sym_WHILE] = ACTIONS(6042),
    [anon_sym_While] = ACTIONS(6042),
    [anon_sym_repeat] = ACTIONS(6042),
    [anon_sym_REPEAT] = ACTIONS(6042),
    [anon_sym_Repeat] = ACTIONS(6042),
    [anon_sym_exit] = ACTIONS(6042),
    [anon_sym_EXIT] = ACTIONS(6042),
    [anon_sym_Exit] = ACTIONS(6042),
    [anon_sym_continue] = ACTIONS(6042),
    [anon_sym_CONTINUE] = ACTIONS(6042),
    [anon_sym_Continue] = ACTIONS(6042),
    [anon_sym_break] = ACTIONS(6042),
    [anon_sym_BREAK] = ACTIONS(6042),
    [anon_sym_Break] = ACTIONS(6042),
    [anon_sym_with] = ACTIONS(6042),
    [anon_sym_WITH] = ACTIONS(6042),
    [anon_sym_With] = ACTIONS(6042),
    [sym_asserterror_keyword] = ACTIONS(6044),
    [sym_page_keyword] = ACTIONS(6042),
    [anon_sym_codeunit] = ACTIONS(6042),
    [anon_sym_CODEUNIT] = ACTIONS(6042),
    [anon_sym_Codeunit] = ACTIONS(6042),
    [anon_sym_CodeUnit] = ACTIONS(6042),
    [anon_sym_COdeunit] = ACTIONS(6042),
    [anon_sym_codeUnit] = ACTIONS(6042),
    [sym_report_keyword] = ACTIONS(6042),
    [sym_query_keyword] = ACTIONS(6042),
    [anon_sym_xmlport] = ACTIONS(6042),
    [anon_sym_XMLPORT] = ACTIONS(6042),
    [anon_sym_Xmlport] = ACTIONS(6042),
    [anon_sym_XMLport] = ACTIONS(6042),
    [anon_sym_XMLPort] = ACTIONS(6042),
    [anon_sym_XmlPort] = ACTIONS(6042),
    [anon_sym_enum] = ACTIONS(6042),
    [anon_sym_ENUM] = ACTIONS(6042),
    [anon_sym_Enum] = ACTIONS(6042),
    [anon_sym_eNUM] = ACTIONS(6042),
    [anon_sym_eNum] = ACTIONS(6042),
    [anon_sym_ENum] = ACTIONS(6042),
    [sym_quoted_identifier] = ACTIONS(6044),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6044),
    [sym_verbatim_string] = ACTIONS(6044),
    [sym_integer] = ACTIONS(6042),
    [sym_continue_as_identifier] = ACTIONS(6044),
    [sym_preproc_open] = ACTIONS(6044),
    [sym_end_keyword] = ACTIONS(6044),
  },
  [STATE(3268)] = {
    [sym_identifier] = ACTIONS(6074),
    [anon_sym_SEMI] = ACTIONS(6076),
    [anon_sym_DASH] = ACTIONS(6076),
    [aux_sym_boolean_token1] = ACTIONS(6074),
    [aux_sym_boolean_token2] = ACTIONS(6074),
    [sym_decimal] = ACTIONS(6074),
    [anon_sym_LPAREN] = ACTIONS(6076),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6074),
    [anon_sym_LBRACK] = ACTIONS(6076),
    [aux_sym_record_type_token1] = ACTIONS(6074),
    [aux_sym_basic_type_token21] = ACTIONS(6074),
    [aux_sym_basic_type_token22] = ACTIONS(6074),
    [aux_sym_basic_type_token48] = ACTIONS(6074),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6074),
    [anon_sym_POUNDif] = ACTIONS(6076),
    [anon_sym_POUNDIF] = ACTIONS(6076),
    [anon_sym_POUNDIf] = ACTIONS(6076),
    [anon_sym_not] = ACTIONS(6074),
    [anon_sym_NOT] = ACTIONS(6074),
    [anon_sym_Not] = ACTIONS(6074),
    [anon_sym_POUNDelse] = ACTIONS(6076),
    [anon_sym_POUNDELSE] = ACTIONS(6076),
    [anon_sym_POUNDElse] = ACTIONS(6076),
    [anon_sym_POUNDelse2] = ACTIONS(6076),
    [anon_sym_POUNDELSE2] = ACTIONS(6076),
    [anon_sym_POUNDElse2] = ACTIONS(6076),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6074),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6074),
    [anon_sym_PLUS] = ACTIONS(6076),
    [sym_datetime_literal] = ACTIONS(6076),
    [sym_date_literal] = ACTIONS(6074),
    [sym_time_literal] = ACTIONS(6074),
    [sym_biginteger_literal] = ACTIONS(6076),
    [anon_sym_if] = ACTIONS(6074),
    [anon_sym_IF] = ACTIONS(6074),
    [anon_sym_If] = ACTIONS(6074),
    [anon_sym_else] = ACTIONS(6074),
    [anon_sym_ELSE] = ACTIONS(6074),
    [anon_sym_Else] = ACTIONS(6074),
    [anon_sym_case] = ACTIONS(6074),
    [anon_sym_CASE] = ACTIONS(6074),
    [anon_sym_Case] = ACTIONS(6074),
    [anon_sym_for] = ACTIONS(6074),
    [anon_sym_FOR] = ACTIONS(6074),
    [anon_sym_For] = ACTIONS(6074),
    [anon_sym_foreach] = ACTIONS(6074),
    [anon_sym_FOREACH] = ACTIONS(6074),
    [anon_sym_Foreach] = ACTIONS(6074),
    [anon_sym_while] = ACTIONS(6074),
    [anon_sym_WHILE] = ACTIONS(6074),
    [anon_sym_While] = ACTIONS(6074),
    [anon_sym_repeat] = ACTIONS(6074),
    [anon_sym_REPEAT] = ACTIONS(6074),
    [anon_sym_Repeat] = ACTIONS(6074),
    [anon_sym_exit] = ACTIONS(6074),
    [anon_sym_EXIT] = ACTIONS(6074),
    [anon_sym_Exit] = ACTIONS(6074),
    [anon_sym_continue] = ACTIONS(6074),
    [anon_sym_CONTINUE] = ACTIONS(6074),
    [anon_sym_Continue] = ACTIONS(6074),
    [anon_sym_break] = ACTIONS(6074),
    [anon_sym_BREAK] = ACTIONS(6074),
    [anon_sym_Break] = ACTIONS(6074),
    [anon_sym_with] = ACTIONS(6074),
    [anon_sym_WITH] = ACTIONS(6074),
    [anon_sym_With] = ACTIONS(6074),
    [sym_asserterror_keyword] = ACTIONS(6076),
    [sym_page_keyword] = ACTIONS(6074),
    [anon_sym_codeunit] = ACTIONS(6074),
    [anon_sym_CODEUNIT] = ACTIONS(6074),
    [anon_sym_Codeunit] = ACTIONS(6074),
    [anon_sym_CodeUnit] = ACTIONS(6074),
    [anon_sym_COdeunit] = ACTIONS(6074),
    [anon_sym_codeUnit] = ACTIONS(6074),
    [sym_report_keyword] = ACTIONS(6074),
    [sym_query_keyword] = ACTIONS(6074),
    [anon_sym_xmlport] = ACTIONS(6074),
    [anon_sym_XMLPORT] = ACTIONS(6074),
    [anon_sym_Xmlport] = ACTIONS(6074),
    [anon_sym_XMLport] = ACTIONS(6074),
    [anon_sym_XMLPort] = ACTIONS(6074),
    [anon_sym_XmlPort] = ACTIONS(6074),
    [anon_sym_enum] = ACTIONS(6074),
    [anon_sym_ENUM] = ACTIONS(6074),
    [anon_sym_Enum] = ACTIONS(6074),
    [anon_sym_eNUM] = ACTIONS(6074),
    [anon_sym_eNum] = ACTIONS(6074),
    [anon_sym_ENum] = ACTIONS(6074),
    [sym_quoted_identifier] = ACTIONS(6076),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6076),
    [sym_verbatim_string] = ACTIONS(6076),
    [sym_integer] = ACTIONS(6074),
    [sym_continue_as_identifier] = ACTIONS(6076),
    [sym_preproc_open] = ACTIONS(6076),
    [sym_end_keyword] = ACTIONS(6076),
  },
  [STATE(3269)] = {
    [sym_identifier] = ACTIONS(5677),
    [anon_sym_SEMI] = ACTIONS(5679),
    [anon_sym_DASH] = ACTIONS(5679),
    [aux_sym_boolean_token1] = ACTIONS(5677),
    [aux_sym_boolean_token2] = ACTIONS(5677),
    [sym_decimal] = ACTIONS(5677),
    [anon_sym_LPAREN] = ACTIONS(5679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5677),
    [anon_sym_LBRACK] = ACTIONS(5679),
    [aux_sym_record_type_token1] = ACTIONS(5677),
    [aux_sym_basic_type_token21] = ACTIONS(5677),
    [aux_sym_basic_type_token22] = ACTIONS(5677),
    [aux_sym_basic_type_token48] = ACTIONS(5677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5677),
    [anon_sym_POUNDif] = ACTIONS(5679),
    [anon_sym_POUNDIF] = ACTIONS(5679),
    [anon_sym_POUNDIf] = ACTIONS(5679),
    [anon_sym_not] = ACTIONS(5677),
    [anon_sym_NOT] = ACTIONS(5677),
    [anon_sym_Not] = ACTIONS(5677),
    [anon_sym_POUNDelse] = ACTIONS(5679),
    [anon_sym_POUNDELSE] = ACTIONS(5679),
    [anon_sym_POUNDElse] = ACTIONS(5679),
    [anon_sym_POUNDelse2] = ACTIONS(5679),
    [anon_sym_POUNDELSE2] = ACTIONS(5679),
    [anon_sym_POUNDElse2] = ACTIONS(5679),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5677),
    [anon_sym_PLUS] = ACTIONS(5679),
    [sym_datetime_literal] = ACTIONS(5679),
    [sym_date_literal] = ACTIONS(5677),
    [sym_time_literal] = ACTIONS(5677),
    [sym_biginteger_literal] = ACTIONS(5679),
    [anon_sym_if] = ACTIONS(5677),
    [anon_sym_IF] = ACTIONS(5677),
    [anon_sym_If] = ACTIONS(5677),
    [anon_sym_else] = ACTIONS(5677),
    [anon_sym_ELSE] = ACTIONS(5677),
    [anon_sym_Else] = ACTIONS(5677),
    [anon_sym_case] = ACTIONS(5677),
    [anon_sym_CASE] = ACTIONS(5677),
    [anon_sym_Case] = ACTIONS(5677),
    [anon_sym_for] = ACTIONS(5677),
    [anon_sym_FOR] = ACTIONS(5677),
    [anon_sym_For] = ACTIONS(5677),
    [anon_sym_foreach] = ACTIONS(5677),
    [anon_sym_FOREACH] = ACTIONS(5677),
    [anon_sym_Foreach] = ACTIONS(5677),
    [anon_sym_while] = ACTIONS(5677),
    [anon_sym_WHILE] = ACTIONS(5677),
    [anon_sym_While] = ACTIONS(5677),
    [anon_sym_repeat] = ACTIONS(5677),
    [anon_sym_REPEAT] = ACTIONS(5677),
    [anon_sym_Repeat] = ACTIONS(5677),
    [anon_sym_exit] = ACTIONS(5677),
    [anon_sym_EXIT] = ACTIONS(5677),
    [anon_sym_Exit] = ACTIONS(5677),
    [anon_sym_continue] = ACTIONS(5677),
    [anon_sym_CONTINUE] = ACTIONS(5677),
    [anon_sym_Continue] = ACTIONS(5677),
    [anon_sym_break] = ACTIONS(5677),
    [anon_sym_BREAK] = ACTIONS(5677),
    [anon_sym_Break] = ACTIONS(5677),
    [anon_sym_with] = ACTIONS(5677),
    [anon_sym_WITH] = ACTIONS(5677),
    [anon_sym_With] = ACTIONS(5677),
    [sym_asserterror_keyword] = ACTIONS(5679),
    [sym_page_keyword] = ACTIONS(5677),
    [anon_sym_codeunit] = ACTIONS(5677),
    [anon_sym_CODEUNIT] = ACTIONS(5677),
    [anon_sym_Codeunit] = ACTIONS(5677),
    [anon_sym_CodeUnit] = ACTIONS(5677),
    [anon_sym_COdeunit] = ACTIONS(5677),
    [anon_sym_codeUnit] = ACTIONS(5677),
    [sym_report_keyword] = ACTIONS(5677),
    [sym_query_keyword] = ACTIONS(5677),
    [anon_sym_xmlport] = ACTIONS(5677),
    [anon_sym_XMLPORT] = ACTIONS(5677),
    [anon_sym_Xmlport] = ACTIONS(5677),
    [anon_sym_XMLport] = ACTIONS(5677),
    [anon_sym_XMLPort] = ACTIONS(5677),
    [anon_sym_XmlPort] = ACTIONS(5677),
    [anon_sym_enum] = ACTIONS(5677),
    [anon_sym_ENUM] = ACTIONS(5677),
    [anon_sym_Enum] = ACTIONS(5677),
    [anon_sym_eNUM] = ACTIONS(5677),
    [anon_sym_eNum] = ACTIONS(5677),
    [anon_sym_ENum] = ACTIONS(5677),
    [sym_quoted_identifier] = ACTIONS(5679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5679),
    [sym_verbatim_string] = ACTIONS(5679),
    [sym_integer] = ACTIONS(5677),
    [sym_continue_as_identifier] = ACTIONS(5679),
    [sym_preproc_open] = ACTIONS(5679),
    [sym_end_keyword] = ACTIONS(5679),
  },
  [STATE(3270)] = {
    [sym_identifier] = ACTIONS(6236),
    [anon_sym_SEMI] = ACTIONS(6238),
    [anon_sym_DASH] = ACTIONS(6238),
    [aux_sym_boolean_token1] = ACTIONS(6236),
    [aux_sym_boolean_token2] = ACTIONS(6236),
    [sym_decimal] = ACTIONS(6236),
    [anon_sym_LPAREN] = ACTIONS(6238),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6236),
    [anon_sym_LBRACK] = ACTIONS(6238),
    [aux_sym_record_type_token1] = ACTIONS(6236),
    [aux_sym_basic_type_token21] = ACTIONS(6236),
    [aux_sym_basic_type_token22] = ACTIONS(6236),
    [aux_sym_basic_type_token48] = ACTIONS(6236),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6236),
    [anon_sym_POUNDif] = ACTIONS(6238),
    [anon_sym_POUNDIF] = ACTIONS(6238),
    [anon_sym_POUNDIf] = ACTIONS(6238),
    [anon_sym_not] = ACTIONS(6236),
    [anon_sym_NOT] = ACTIONS(6236),
    [anon_sym_Not] = ACTIONS(6236),
    [anon_sym_POUNDelse] = ACTIONS(6238),
    [anon_sym_POUNDELSE] = ACTIONS(6238),
    [anon_sym_POUNDElse] = ACTIONS(6238),
    [anon_sym_POUNDelse2] = ACTIONS(6238),
    [anon_sym_POUNDELSE2] = ACTIONS(6238),
    [anon_sym_POUNDElse2] = ACTIONS(6238),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6236),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6236),
    [anon_sym_PLUS] = ACTIONS(6238),
    [sym_datetime_literal] = ACTIONS(6238),
    [sym_date_literal] = ACTIONS(6236),
    [sym_time_literal] = ACTIONS(6236),
    [sym_biginteger_literal] = ACTIONS(6238),
    [anon_sym_if] = ACTIONS(6236),
    [anon_sym_IF] = ACTIONS(6236),
    [anon_sym_If] = ACTIONS(6236),
    [anon_sym_else] = ACTIONS(6236),
    [anon_sym_ELSE] = ACTIONS(6236),
    [anon_sym_Else] = ACTIONS(6236),
    [anon_sym_case] = ACTIONS(6236),
    [anon_sym_CASE] = ACTIONS(6236),
    [anon_sym_Case] = ACTIONS(6236),
    [anon_sym_for] = ACTIONS(6236),
    [anon_sym_FOR] = ACTIONS(6236),
    [anon_sym_For] = ACTIONS(6236),
    [anon_sym_foreach] = ACTIONS(6236),
    [anon_sym_FOREACH] = ACTIONS(6236),
    [anon_sym_Foreach] = ACTIONS(6236),
    [anon_sym_while] = ACTIONS(6236),
    [anon_sym_WHILE] = ACTIONS(6236),
    [anon_sym_While] = ACTIONS(6236),
    [anon_sym_repeat] = ACTIONS(6236),
    [anon_sym_REPEAT] = ACTIONS(6236),
    [anon_sym_Repeat] = ACTIONS(6236),
    [anon_sym_exit] = ACTIONS(6236),
    [anon_sym_EXIT] = ACTIONS(6236),
    [anon_sym_Exit] = ACTIONS(6236),
    [anon_sym_continue] = ACTIONS(6236),
    [anon_sym_CONTINUE] = ACTIONS(6236),
    [anon_sym_Continue] = ACTIONS(6236),
    [anon_sym_break] = ACTIONS(6236),
    [anon_sym_BREAK] = ACTIONS(6236),
    [anon_sym_Break] = ACTIONS(6236),
    [anon_sym_with] = ACTIONS(6236),
    [anon_sym_WITH] = ACTIONS(6236),
    [anon_sym_With] = ACTIONS(6236),
    [sym_asserterror_keyword] = ACTIONS(6238),
    [sym_page_keyword] = ACTIONS(6236),
    [anon_sym_codeunit] = ACTIONS(6236),
    [anon_sym_CODEUNIT] = ACTIONS(6236),
    [anon_sym_Codeunit] = ACTIONS(6236),
    [anon_sym_CodeUnit] = ACTIONS(6236),
    [anon_sym_COdeunit] = ACTIONS(6236),
    [anon_sym_codeUnit] = ACTIONS(6236),
    [sym_report_keyword] = ACTIONS(6236),
    [sym_query_keyword] = ACTIONS(6236),
    [anon_sym_xmlport] = ACTIONS(6236),
    [anon_sym_XMLPORT] = ACTIONS(6236),
    [anon_sym_Xmlport] = ACTIONS(6236),
    [anon_sym_XMLport] = ACTIONS(6236),
    [anon_sym_XMLPort] = ACTIONS(6236),
    [anon_sym_XmlPort] = ACTIONS(6236),
    [anon_sym_enum] = ACTIONS(6236),
    [anon_sym_ENUM] = ACTIONS(6236),
    [anon_sym_Enum] = ACTIONS(6236),
    [anon_sym_eNUM] = ACTIONS(6236),
    [anon_sym_eNum] = ACTIONS(6236),
    [anon_sym_ENum] = ACTIONS(6236),
    [sym_quoted_identifier] = ACTIONS(6238),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6238),
    [sym_verbatim_string] = ACTIONS(6238),
    [sym_integer] = ACTIONS(6236),
    [sym_continue_as_identifier] = ACTIONS(6238),
    [sym_preproc_open] = ACTIONS(6238),
    [sym_end_keyword] = ACTIONS(6238),
  },
  [STATE(3271)] = {
    [sym_identifier] = ACTIONS(5497),
    [anon_sym_SEMI] = ACTIONS(7333),
    [anon_sym_DASH] = ACTIONS(5501),
    [aux_sym_boolean_token1] = ACTIONS(5497),
    [aux_sym_boolean_token2] = ACTIONS(5497),
    [sym_decimal] = ACTIONS(5497),
    [anon_sym_LPAREN] = ACTIONS(5501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5497),
    [anon_sym_LBRACK] = ACTIONS(5501),
    [aux_sym_record_type_token1] = ACTIONS(5497),
    [aux_sym_basic_type_token21] = ACTIONS(5497),
    [aux_sym_basic_type_token22] = ACTIONS(5497),
    [aux_sym_basic_type_token48] = ACTIONS(5497),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5497),
    [anon_sym_POUNDif] = ACTIONS(5501),
    [anon_sym_POUNDIF] = ACTIONS(5501),
    [anon_sym_POUNDIf] = ACTIONS(5501),
    [anon_sym_not] = ACTIONS(5497),
    [anon_sym_NOT] = ACTIONS(5497),
    [anon_sym_Not] = ACTIONS(5497),
    [anon_sym_POUNDelse] = ACTIONS(5501),
    [anon_sym_POUNDELSE] = ACTIONS(5501),
    [anon_sym_POUNDElse] = ACTIONS(5501),
    [anon_sym_POUNDelse2] = ACTIONS(5501),
    [anon_sym_POUNDELSE2] = ACTIONS(5501),
    [anon_sym_POUNDElse2] = ACTIONS(5501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5497),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5497),
    [anon_sym_PLUS] = ACTIONS(5501),
    [sym_datetime_literal] = ACTIONS(5501),
    [sym_date_literal] = ACTIONS(5497),
    [sym_time_literal] = ACTIONS(5497),
    [sym_biginteger_literal] = ACTIONS(5501),
    [anon_sym_if] = ACTIONS(5497),
    [anon_sym_IF] = ACTIONS(5497),
    [anon_sym_If] = ACTIONS(5497),
    [anon_sym_else] = ACTIONS(5497),
    [anon_sym_ELSE] = ACTIONS(5497),
    [anon_sym_Else] = ACTIONS(5497),
    [anon_sym_case] = ACTIONS(5497),
    [anon_sym_CASE] = ACTIONS(5497),
    [anon_sym_Case] = ACTIONS(5497),
    [anon_sym_for] = ACTIONS(5497),
    [anon_sym_FOR] = ACTIONS(5497),
    [anon_sym_For] = ACTIONS(5497),
    [anon_sym_foreach] = ACTIONS(5497),
    [anon_sym_FOREACH] = ACTIONS(5497),
    [anon_sym_Foreach] = ACTIONS(5497),
    [anon_sym_while] = ACTIONS(5497),
    [anon_sym_WHILE] = ACTIONS(5497),
    [anon_sym_While] = ACTIONS(5497),
    [anon_sym_repeat] = ACTIONS(5497),
    [anon_sym_REPEAT] = ACTIONS(5497),
    [anon_sym_Repeat] = ACTIONS(5497),
    [anon_sym_exit] = ACTIONS(5497),
    [anon_sym_EXIT] = ACTIONS(5497),
    [anon_sym_Exit] = ACTIONS(5497),
    [anon_sym_continue] = ACTIONS(5497),
    [anon_sym_CONTINUE] = ACTIONS(5497),
    [anon_sym_Continue] = ACTIONS(5497),
    [anon_sym_break] = ACTIONS(5497),
    [anon_sym_BREAK] = ACTIONS(5497),
    [anon_sym_Break] = ACTIONS(5497),
    [anon_sym_with] = ACTIONS(5497),
    [anon_sym_WITH] = ACTIONS(5497),
    [anon_sym_With] = ACTIONS(5497),
    [sym_asserterror_keyword] = ACTIONS(5501),
    [sym_page_keyword] = ACTIONS(5497),
    [anon_sym_codeunit] = ACTIONS(5497),
    [anon_sym_CODEUNIT] = ACTIONS(5497),
    [anon_sym_Codeunit] = ACTIONS(5497),
    [anon_sym_CodeUnit] = ACTIONS(5497),
    [anon_sym_COdeunit] = ACTIONS(5497),
    [anon_sym_codeUnit] = ACTIONS(5497),
    [sym_report_keyword] = ACTIONS(5497),
    [sym_query_keyword] = ACTIONS(5497),
    [anon_sym_xmlport] = ACTIONS(5497),
    [anon_sym_XMLPORT] = ACTIONS(5497),
    [anon_sym_Xmlport] = ACTIONS(5497),
    [anon_sym_XMLport] = ACTIONS(5497),
    [anon_sym_XMLPort] = ACTIONS(5497),
    [anon_sym_XmlPort] = ACTIONS(5497),
    [anon_sym_enum] = ACTIONS(5497),
    [anon_sym_ENUM] = ACTIONS(5497),
    [anon_sym_Enum] = ACTIONS(5497),
    [anon_sym_eNUM] = ACTIONS(5497),
    [anon_sym_eNum] = ACTIONS(5497),
    [anon_sym_ENum] = ACTIONS(5497),
    [sym_quoted_identifier] = ACTIONS(5501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5501),
    [sym_verbatim_string] = ACTIONS(5501),
    [sym_integer] = ACTIONS(5497),
    [sym_continue_as_identifier] = ACTIONS(5501),
    [sym_preproc_open] = ACTIONS(5501),
    [sym_end_keyword] = ACTIONS(5501),
  },
  [STATE(3272)] = {
    [sym_identifier] = ACTIONS(5681),
    [anon_sym_SEMI] = ACTIONS(5683),
    [anon_sym_DASH] = ACTIONS(5683),
    [aux_sym_boolean_token1] = ACTIONS(5681),
    [aux_sym_boolean_token2] = ACTIONS(5681),
    [sym_decimal] = ACTIONS(5681),
    [anon_sym_LPAREN] = ACTIONS(5683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5681),
    [anon_sym_LBRACK] = ACTIONS(5683),
    [aux_sym_record_type_token1] = ACTIONS(5681),
    [aux_sym_basic_type_token21] = ACTIONS(5681),
    [aux_sym_basic_type_token22] = ACTIONS(5681),
    [aux_sym_basic_type_token48] = ACTIONS(5681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5681),
    [anon_sym_POUNDif] = ACTIONS(5683),
    [anon_sym_POUNDIF] = ACTIONS(5683),
    [anon_sym_POUNDIf] = ACTIONS(5683),
    [anon_sym_not] = ACTIONS(5681),
    [anon_sym_NOT] = ACTIONS(5681),
    [anon_sym_Not] = ACTIONS(5681),
    [anon_sym_POUNDelse] = ACTIONS(5683),
    [anon_sym_POUNDELSE] = ACTIONS(5683),
    [anon_sym_POUNDElse] = ACTIONS(5683),
    [anon_sym_POUNDelse2] = ACTIONS(5683),
    [anon_sym_POUNDELSE2] = ACTIONS(5683),
    [anon_sym_POUNDElse2] = ACTIONS(5683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5681),
    [anon_sym_PLUS] = ACTIONS(5683),
    [sym_datetime_literal] = ACTIONS(5683),
    [sym_date_literal] = ACTIONS(5681),
    [sym_time_literal] = ACTIONS(5681),
    [sym_biginteger_literal] = ACTIONS(5683),
    [anon_sym_if] = ACTIONS(5681),
    [anon_sym_IF] = ACTIONS(5681),
    [anon_sym_If] = ACTIONS(5681),
    [anon_sym_else] = ACTIONS(5681),
    [anon_sym_ELSE] = ACTIONS(5681),
    [anon_sym_Else] = ACTIONS(5681),
    [anon_sym_case] = ACTIONS(5681),
    [anon_sym_CASE] = ACTIONS(5681),
    [anon_sym_Case] = ACTIONS(5681),
    [anon_sym_for] = ACTIONS(5681),
    [anon_sym_FOR] = ACTIONS(5681),
    [anon_sym_For] = ACTIONS(5681),
    [anon_sym_foreach] = ACTIONS(5681),
    [anon_sym_FOREACH] = ACTIONS(5681),
    [anon_sym_Foreach] = ACTIONS(5681),
    [anon_sym_while] = ACTIONS(5681),
    [anon_sym_WHILE] = ACTIONS(5681),
    [anon_sym_While] = ACTIONS(5681),
    [anon_sym_repeat] = ACTIONS(5681),
    [anon_sym_REPEAT] = ACTIONS(5681),
    [anon_sym_Repeat] = ACTIONS(5681),
    [anon_sym_exit] = ACTIONS(5681),
    [anon_sym_EXIT] = ACTIONS(5681),
    [anon_sym_Exit] = ACTIONS(5681),
    [anon_sym_continue] = ACTIONS(5681),
    [anon_sym_CONTINUE] = ACTIONS(5681),
    [anon_sym_Continue] = ACTIONS(5681),
    [anon_sym_break] = ACTIONS(5681),
    [anon_sym_BREAK] = ACTIONS(5681),
    [anon_sym_Break] = ACTIONS(5681),
    [anon_sym_with] = ACTIONS(5681),
    [anon_sym_WITH] = ACTIONS(5681),
    [anon_sym_With] = ACTIONS(5681),
    [sym_asserterror_keyword] = ACTIONS(5683),
    [sym_page_keyword] = ACTIONS(5681),
    [anon_sym_codeunit] = ACTIONS(5681),
    [anon_sym_CODEUNIT] = ACTIONS(5681),
    [anon_sym_Codeunit] = ACTIONS(5681),
    [anon_sym_CodeUnit] = ACTIONS(5681),
    [anon_sym_COdeunit] = ACTIONS(5681),
    [anon_sym_codeUnit] = ACTIONS(5681),
    [sym_report_keyword] = ACTIONS(5681),
    [sym_query_keyword] = ACTIONS(5681),
    [anon_sym_xmlport] = ACTIONS(5681),
    [anon_sym_XMLPORT] = ACTIONS(5681),
    [anon_sym_Xmlport] = ACTIONS(5681),
    [anon_sym_XMLport] = ACTIONS(5681),
    [anon_sym_XMLPort] = ACTIONS(5681),
    [anon_sym_XmlPort] = ACTIONS(5681),
    [anon_sym_enum] = ACTIONS(5681),
    [anon_sym_ENUM] = ACTIONS(5681),
    [anon_sym_Enum] = ACTIONS(5681),
    [anon_sym_eNUM] = ACTIONS(5681),
    [anon_sym_eNum] = ACTIONS(5681),
    [anon_sym_ENum] = ACTIONS(5681),
    [sym_quoted_identifier] = ACTIONS(5683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5683),
    [sym_verbatim_string] = ACTIONS(5683),
    [sym_integer] = ACTIONS(5681),
    [sym_continue_as_identifier] = ACTIONS(5683),
    [sym_preproc_open] = ACTIONS(5683),
    [sym_end_keyword] = ACTIONS(5683),
  },
  [STATE(3273)] = {
    [sym_identifier] = ACTIONS(5685),
    [anon_sym_SEMI] = ACTIONS(5687),
    [anon_sym_DASH] = ACTIONS(5687),
    [aux_sym_boolean_token1] = ACTIONS(5685),
    [aux_sym_boolean_token2] = ACTIONS(5685),
    [sym_decimal] = ACTIONS(5685),
    [anon_sym_LPAREN] = ACTIONS(5687),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5685),
    [anon_sym_LBRACK] = ACTIONS(5687),
    [aux_sym_record_type_token1] = ACTIONS(5685),
    [aux_sym_basic_type_token21] = ACTIONS(5685),
    [aux_sym_basic_type_token22] = ACTIONS(5685),
    [aux_sym_basic_type_token48] = ACTIONS(5685),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5685),
    [anon_sym_POUNDif] = ACTIONS(5687),
    [anon_sym_POUNDIF] = ACTIONS(5687),
    [anon_sym_POUNDIf] = ACTIONS(5687),
    [anon_sym_not] = ACTIONS(5685),
    [anon_sym_NOT] = ACTIONS(5685),
    [anon_sym_Not] = ACTIONS(5685),
    [anon_sym_POUNDelse] = ACTIONS(5687),
    [anon_sym_POUNDELSE] = ACTIONS(5687),
    [anon_sym_POUNDElse] = ACTIONS(5687),
    [anon_sym_POUNDelse2] = ACTIONS(5687),
    [anon_sym_POUNDELSE2] = ACTIONS(5687),
    [anon_sym_POUNDElse2] = ACTIONS(5687),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5685),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5685),
    [anon_sym_PLUS] = ACTIONS(5687),
    [sym_datetime_literal] = ACTIONS(5687),
    [sym_date_literal] = ACTIONS(5685),
    [sym_time_literal] = ACTIONS(5685),
    [sym_biginteger_literal] = ACTIONS(5687),
    [anon_sym_if] = ACTIONS(5685),
    [anon_sym_IF] = ACTIONS(5685),
    [anon_sym_If] = ACTIONS(5685),
    [anon_sym_else] = ACTIONS(5685),
    [anon_sym_ELSE] = ACTIONS(5685),
    [anon_sym_Else] = ACTIONS(5685),
    [anon_sym_case] = ACTIONS(5685),
    [anon_sym_CASE] = ACTIONS(5685),
    [anon_sym_Case] = ACTIONS(5685),
    [anon_sym_for] = ACTIONS(5685),
    [anon_sym_FOR] = ACTIONS(5685),
    [anon_sym_For] = ACTIONS(5685),
    [anon_sym_foreach] = ACTIONS(5685),
    [anon_sym_FOREACH] = ACTIONS(5685),
    [anon_sym_Foreach] = ACTIONS(5685),
    [anon_sym_while] = ACTIONS(5685),
    [anon_sym_WHILE] = ACTIONS(5685),
    [anon_sym_While] = ACTIONS(5685),
    [anon_sym_repeat] = ACTIONS(5685),
    [anon_sym_REPEAT] = ACTIONS(5685),
    [anon_sym_Repeat] = ACTIONS(5685),
    [anon_sym_exit] = ACTIONS(5685),
    [anon_sym_EXIT] = ACTIONS(5685),
    [anon_sym_Exit] = ACTIONS(5685),
    [anon_sym_continue] = ACTIONS(5685),
    [anon_sym_CONTINUE] = ACTIONS(5685),
    [anon_sym_Continue] = ACTIONS(5685),
    [anon_sym_break] = ACTIONS(5685),
    [anon_sym_BREAK] = ACTIONS(5685),
    [anon_sym_Break] = ACTIONS(5685),
    [anon_sym_with] = ACTIONS(5685),
    [anon_sym_WITH] = ACTIONS(5685),
    [anon_sym_With] = ACTIONS(5685),
    [sym_asserterror_keyword] = ACTIONS(5687),
    [sym_page_keyword] = ACTIONS(5685),
    [anon_sym_codeunit] = ACTIONS(5685),
    [anon_sym_CODEUNIT] = ACTIONS(5685),
    [anon_sym_Codeunit] = ACTIONS(5685),
    [anon_sym_CodeUnit] = ACTIONS(5685),
    [anon_sym_COdeunit] = ACTIONS(5685),
    [anon_sym_codeUnit] = ACTIONS(5685),
    [sym_report_keyword] = ACTIONS(5685),
    [sym_query_keyword] = ACTIONS(5685),
    [anon_sym_xmlport] = ACTIONS(5685),
    [anon_sym_XMLPORT] = ACTIONS(5685),
    [anon_sym_Xmlport] = ACTIONS(5685),
    [anon_sym_XMLport] = ACTIONS(5685),
    [anon_sym_XMLPort] = ACTIONS(5685),
    [anon_sym_XmlPort] = ACTIONS(5685),
    [anon_sym_enum] = ACTIONS(5685),
    [anon_sym_ENUM] = ACTIONS(5685),
    [anon_sym_Enum] = ACTIONS(5685),
    [anon_sym_eNUM] = ACTIONS(5685),
    [anon_sym_eNum] = ACTIONS(5685),
    [anon_sym_ENum] = ACTIONS(5685),
    [sym_quoted_identifier] = ACTIONS(5687),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5687),
    [sym_verbatim_string] = ACTIONS(5687),
    [sym_integer] = ACTIONS(5685),
    [sym_continue_as_identifier] = ACTIONS(5687),
    [sym_preproc_open] = ACTIONS(5687),
    [sym_end_keyword] = ACTIONS(5687),
  },
  [STATE(3274)] = {
    [sym_identifier] = ACTIONS(5927),
    [anon_sym_SEMI] = ACTIONS(5929),
    [anon_sym_DASH] = ACTIONS(5929),
    [aux_sym_boolean_token1] = ACTIONS(5927),
    [aux_sym_boolean_token2] = ACTIONS(5927),
    [sym_decimal] = ACTIONS(5927),
    [anon_sym_LPAREN] = ACTIONS(5929),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5927),
    [anon_sym_LBRACK] = ACTIONS(5929),
    [aux_sym_record_type_token1] = ACTIONS(5927),
    [aux_sym_basic_type_token21] = ACTIONS(5927),
    [aux_sym_basic_type_token22] = ACTIONS(5927),
    [aux_sym_basic_type_token48] = ACTIONS(5927),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5927),
    [anon_sym_POUNDif] = ACTIONS(5929),
    [anon_sym_POUNDIF] = ACTIONS(5929),
    [anon_sym_POUNDIf] = ACTIONS(5929),
    [anon_sym_not] = ACTIONS(5927),
    [anon_sym_NOT] = ACTIONS(5927),
    [anon_sym_Not] = ACTIONS(5927),
    [anon_sym_POUNDelse] = ACTIONS(5929),
    [anon_sym_POUNDELSE] = ACTIONS(5929),
    [anon_sym_POUNDElse] = ACTIONS(5929),
    [anon_sym_POUNDelse2] = ACTIONS(5929),
    [anon_sym_POUNDELSE2] = ACTIONS(5929),
    [anon_sym_POUNDElse2] = ACTIONS(5929),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5927),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5927),
    [anon_sym_PLUS] = ACTIONS(5929),
    [sym_datetime_literal] = ACTIONS(5929),
    [sym_date_literal] = ACTIONS(5927),
    [sym_time_literal] = ACTIONS(5927),
    [sym_biginteger_literal] = ACTIONS(5929),
    [anon_sym_if] = ACTIONS(5927),
    [anon_sym_IF] = ACTIONS(5927),
    [anon_sym_If] = ACTIONS(5927),
    [anon_sym_else] = ACTIONS(5927),
    [anon_sym_ELSE] = ACTIONS(5927),
    [anon_sym_Else] = ACTIONS(5927),
    [anon_sym_case] = ACTIONS(5927),
    [anon_sym_CASE] = ACTIONS(5927),
    [anon_sym_Case] = ACTIONS(5927),
    [anon_sym_for] = ACTIONS(5927),
    [anon_sym_FOR] = ACTIONS(5927),
    [anon_sym_For] = ACTIONS(5927),
    [anon_sym_foreach] = ACTIONS(5927),
    [anon_sym_FOREACH] = ACTIONS(5927),
    [anon_sym_Foreach] = ACTIONS(5927),
    [anon_sym_while] = ACTIONS(5927),
    [anon_sym_WHILE] = ACTIONS(5927),
    [anon_sym_While] = ACTIONS(5927),
    [anon_sym_repeat] = ACTIONS(5927),
    [anon_sym_REPEAT] = ACTIONS(5927),
    [anon_sym_Repeat] = ACTIONS(5927),
    [anon_sym_exit] = ACTIONS(5927),
    [anon_sym_EXIT] = ACTIONS(5927),
    [anon_sym_Exit] = ACTIONS(5927),
    [anon_sym_continue] = ACTIONS(5927),
    [anon_sym_CONTINUE] = ACTIONS(5927),
    [anon_sym_Continue] = ACTIONS(5927),
    [anon_sym_break] = ACTIONS(5927),
    [anon_sym_BREAK] = ACTIONS(5927),
    [anon_sym_Break] = ACTIONS(5927),
    [anon_sym_with] = ACTIONS(5927),
    [anon_sym_WITH] = ACTIONS(5927),
    [anon_sym_With] = ACTIONS(5927),
    [sym_asserterror_keyword] = ACTIONS(5929),
    [sym_page_keyword] = ACTIONS(5927),
    [anon_sym_codeunit] = ACTIONS(5927),
    [anon_sym_CODEUNIT] = ACTIONS(5927),
    [anon_sym_Codeunit] = ACTIONS(5927),
    [anon_sym_CodeUnit] = ACTIONS(5927),
    [anon_sym_COdeunit] = ACTIONS(5927),
    [anon_sym_codeUnit] = ACTIONS(5927),
    [sym_report_keyword] = ACTIONS(5927),
    [sym_query_keyword] = ACTIONS(5927),
    [anon_sym_xmlport] = ACTIONS(5927),
    [anon_sym_XMLPORT] = ACTIONS(5927),
    [anon_sym_Xmlport] = ACTIONS(5927),
    [anon_sym_XMLport] = ACTIONS(5927),
    [anon_sym_XMLPort] = ACTIONS(5927),
    [anon_sym_XmlPort] = ACTIONS(5927),
    [anon_sym_enum] = ACTIONS(5927),
    [anon_sym_ENUM] = ACTIONS(5927),
    [anon_sym_Enum] = ACTIONS(5927),
    [anon_sym_eNUM] = ACTIONS(5927),
    [anon_sym_eNum] = ACTIONS(5927),
    [anon_sym_ENum] = ACTIONS(5927),
    [sym_quoted_identifier] = ACTIONS(5929),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5929),
    [sym_verbatim_string] = ACTIONS(5929),
    [sym_integer] = ACTIONS(5927),
    [sym_continue_as_identifier] = ACTIONS(5929),
    [sym_preproc_open] = ACTIONS(5929),
    [sym_end_keyword] = ACTIONS(5929),
  },
  [STATE(3275)] = {
    [sym_identifier] = ACTIONS(5689),
    [anon_sym_SEMI] = ACTIONS(5691),
    [anon_sym_DASH] = ACTIONS(5691),
    [aux_sym_boolean_token1] = ACTIONS(5689),
    [aux_sym_boolean_token2] = ACTIONS(5689),
    [sym_decimal] = ACTIONS(5689),
    [anon_sym_LPAREN] = ACTIONS(5691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5689),
    [anon_sym_LBRACK] = ACTIONS(5691),
    [aux_sym_record_type_token1] = ACTIONS(5689),
    [aux_sym_basic_type_token21] = ACTIONS(5689),
    [aux_sym_basic_type_token22] = ACTIONS(5689),
    [aux_sym_basic_type_token48] = ACTIONS(5689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5689),
    [anon_sym_POUNDif] = ACTIONS(5691),
    [anon_sym_POUNDIF] = ACTIONS(5691),
    [anon_sym_POUNDIf] = ACTIONS(5691),
    [anon_sym_not] = ACTIONS(5689),
    [anon_sym_NOT] = ACTIONS(5689),
    [anon_sym_Not] = ACTIONS(5689),
    [anon_sym_POUNDelse] = ACTIONS(5691),
    [anon_sym_POUNDELSE] = ACTIONS(5691),
    [anon_sym_POUNDElse] = ACTIONS(5691),
    [anon_sym_POUNDelse2] = ACTIONS(5691),
    [anon_sym_POUNDELSE2] = ACTIONS(5691),
    [anon_sym_POUNDElse2] = ACTIONS(5691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5689),
    [anon_sym_PLUS] = ACTIONS(5691),
    [sym_datetime_literal] = ACTIONS(5691),
    [sym_date_literal] = ACTIONS(5689),
    [sym_time_literal] = ACTIONS(5689),
    [sym_biginteger_literal] = ACTIONS(5691),
    [anon_sym_if] = ACTIONS(5689),
    [anon_sym_IF] = ACTIONS(5689),
    [anon_sym_If] = ACTIONS(5689),
    [anon_sym_else] = ACTIONS(5689),
    [anon_sym_ELSE] = ACTIONS(5689),
    [anon_sym_Else] = ACTIONS(5689),
    [anon_sym_case] = ACTIONS(5689),
    [anon_sym_CASE] = ACTIONS(5689),
    [anon_sym_Case] = ACTIONS(5689),
    [anon_sym_for] = ACTIONS(5689),
    [anon_sym_FOR] = ACTIONS(5689),
    [anon_sym_For] = ACTIONS(5689),
    [anon_sym_foreach] = ACTIONS(5689),
    [anon_sym_FOREACH] = ACTIONS(5689),
    [anon_sym_Foreach] = ACTIONS(5689),
    [anon_sym_while] = ACTIONS(5689),
    [anon_sym_WHILE] = ACTIONS(5689),
    [anon_sym_While] = ACTIONS(5689),
    [anon_sym_repeat] = ACTIONS(5689),
    [anon_sym_REPEAT] = ACTIONS(5689),
    [anon_sym_Repeat] = ACTIONS(5689),
    [anon_sym_exit] = ACTIONS(5689),
    [anon_sym_EXIT] = ACTIONS(5689),
    [anon_sym_Exit] = ACTIONS(5689),
    [anon_sym_continue] = ACTIONS(5689),
    [anon_sym_CONTINUE] = ACTIONS(5689),
    [anon_sym_Continue] = ACTIONS(5689),
    [anon_sym_break] = ACTIONS(5689),
    [anon_sym_BREAK] = ACTIONS(5689),
    [anon_sym_Break] = ACTIONS(5689),
    [anon_sym_with] = ACTIONS(5689),
    [anon_sym_WITH] = ACTIONS(5689),
    [anon_sym_With] = ACTIONS(5689),
    [sym_asserterror_keyword] = ACTIONS(5691),
    [sym_page_keyword] = ACTIONS(5689),
    [anon_sym_codeunit] = ACTIONS(5689),
    [anon_sym_CODEUNIT] = ACTIONS(5689),
    [anon_sym_Codeunit] = ACTIONS(5689),
    [anon_sym_CodeUnit] = ACTIONS(5689),
    [anon_sym_COdeunit] = ACTIONS(5689),
    [anon_sym_codeUnit] = ACTIONS(5689),
    [sym_report_keyword] = ACTIONS(5689),
    [sym_query_keyword] = ACTIONS(5689),
    [anon_sym_xmlport] = ACTIONS(5689),
    [anon_sym_XMLPORT] = ACTIONS(5689),
    [anon_sym_Xmlport] = ACTIONS(5689),
    [anon_sym_XMLport] = ACTIONS(5689),
    [anon_sym_XMLPort] = ACTIONS(5689),
    [anon_sym_XmlPort] = ACTIONS(5689),
    [anon_sym_enum] = ACTIONS(5689),
    [anon_sym_ENUM] = ACTIONS(5689),
    [anon_sym_Enum] = ACTIONS(5689),
    [anon_sym_eNUM] = ACTIONS(5689),
    [anon_sym_eNum] = ACTIONS(5689),
    [anon_sym_ENum] = ACTIONS(5689),
    [sym_quoted_identifier] = ACTIONS(5691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5691),
    [sym_verbatim_string] = ACTIONS(5691),
    [sym_integer] = ACTIONS(5689),
    [sym_continue_as_identifier] = ACTIONS(5691),
    [sym_preproc_open] = ACTIONS(5691),
    [sym_end_keyword] = ACTIONS(5691),
  },
  [STATE(3276)] = {
    [sym_identifier] = ACTIONS(6078),
    [anon_sym_SEMI] = ACTIONS(6080),
    [anon_sym_DASH] = ACTIONS(6080),
    [aux_sym_boolean_token1] = ACTIONS(6078),
    [aux_sym_boolean_token2] = ACTIONS(6078),
    [sym_decimal] = ACTIONS(6078),
    [anon_sym_LPAREN] = ACTIONS(6080),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6078),
    [anon_sym_LBRACK] = ACTIONS(6080),
    [aux_sym_record_type_token1] = ACTIONS(6078),
    [aux_sym_basic_type_token21] = ACTIONS(6078),
    [aux_sym_basic_type_token22] = ACTIONS(6078),
    [aux_sym_basic_type_token48] = ACTIONS(6078),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6078),
    [anon_sym_POUNDif] = ACTIONS(6080),
    [anon_sym_POUNDIF] = ACTIONS(6080),
    [anon_sym_POUNDIf] = ACTIONS(6080),
    [anon_sym_not] = ACTIONS(6078),
    [anon_sym_NOT] = ACTIONS(6078),
    [anon_sym_Not] = ACTIONS(6078),
    [anon_sym_POUNDelse] = ACTIONS(6080),
    [anon_sym_POUNDELSE] = ACTIONS(6080),
    [anon_sym_POUNDElse] = ACTIONS(6080),
    [anon_sym_POUNDelse2] = ACTIONS(6080),
    [anon_sym_POUNDELSE2] = ACTIONS(6080),
    [anon_sym_POUNDElse2] = ACTIONS(6080),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6078),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6078),
    [anon_sym_PLUS] = ACTIONS(6080),
    [sym_datetime_literal] = ACTIONS(6080),
    [sym_date_literal] = ACTIONS(6078),
    [sym_time_literal] = ACTIONS(6078),
    [sym_biginteger_literal] = ACTIONS(6080),
    [anon_sym_if] = ACTIONS(6078),
    [anon_sym_IF] = ACTIONS(6078),
    [anon_sym_If] = ACTIONS(6078),
    [anon_sym_else] = ACTIONS(6078),
    [anon_sym_ELSE] = ACTIONS(6078),
    [anon_sym_Else] = ACTIONS(6078),
    [anon_sym_case] = ACTIONS(6078),
    [anon_sym_CASE] = ACTIONS(6078),
    [anon_sym_Case] = ACTIONS(6078),
    [anon_sym_for] = ACTIONS(6078),
    [anon_sym_FOR] = ACTIONS(6078),
    [anon_sym_For] = ACTIONS(6078),
    [anon_sym_foreach] = ACTIONS(6078),
    [anon_sym_FOREACH] = ACTIONS(6078),
    [anon_sym_Foreach] = ACTIONS(6078),
    [anon_sym_while] = ACTIONS(6078),
    [anon_sym_WHILE] = ACTIONS(6078),
    [anon_sym_While] = ACTIONS(6078),
    [anon_sym_repeat] = ACTIONS(6078),
    [anon_sym_REPEAT] = ACTIONS(6078),
    [anon_sym_Repeat] = ACTIONS(6078),
    [anon_sym_exit] = ACTIONS(6078),
    [anon_sym_EXIT] = ACTIONS(6078),
    [anon_sym_Exit] = ACTIONS(6078),
    [anon_sym_continue] = ACTIONS(6078),
    [anon_sym_CONTINUE] = ACTIONS(6078),
    [anon_sym_Continue] = ACTIONS(6078),
    [anon_sym_break] = ACTIONS(6078),
    [anon_sym_BREAK] = ACTIONS(6078),
    [anon_sym_Break] = ACTIONS(6078),
    [anon_sym_with] = ACTIONS(6078),
    [anon_sym_WITH] = ACTIONS(6078),
    [anon_sym_With] = ACTIONS(6078),
    [sym_asserterror_keyword] = ACTIONS(6080),
    [sym_page_keyword] = ACTIONS(6078),
    [anon_sym_codeunit] = ACTIONS(6078),
    [anon_sym_CODEUNIT] = ACTIONS(6078),
    [anon_sym_Codeunit] = ACTIONS(6078),
    [anon_sym_CodeUnit] = ACTIONS(6078),
    [anon_sym_COdeunit] = ACTIONS(6078),
    [anon_sym_codeUnit] = ACTIONS(6078),
    [sym_report_keyword] = ACTIONS(6078),
    [sym_query_keyword] = ACTIONS(6078),
    [anon_sym_xmlport] = ACTIONS(6078),
    [anon_sym_XMLPORT] = ACTIONS(6078),
    [anon_sym_Xmlport] = ACTIONS(6078),
    [anon_sym_XMLport] = ACTIONS(6078),
    [anon_sym_XMLPort] = ACTIONS(6078),
    [anon_sym_XmlPort] = ACTIONS(6078),
    [anon_sym_enum] = ACTIONS(6078),
    [anon_sym_ENUM] = ACTIONS(6078),
    [anon_sym_Enum] = ACTIONS(6078),
    [anon_sym_eNUM] = ACTIONS(6078),
    [anon_sym_eNum] = ACTIONS(6078),
    [anon_sym_ENum] = ACTIONS(6078),
    [sym_quoted_identifier] = ACTIONS(6080),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6080),
    [sym_verbatim_string] = ACTIONS(6080),
    [sym_integer] = ACTIONS(6078),
    [sym_continue_as_identifier] = ACTIONS(6080),
    [sym_preproc_open] = ACTIONS(6080),
    [sym_end_keyword] = ACTIONS(6080),
  },
  [STATE(3277)] = {
    [sym_identifier] = ACTIONS(5497),
    [anon_sym_SEMI] = ACTIONS(7335),
    [anon_sym_DASH] = ACTIONS(5501),
    [aux_sym_boolean_token1] = ACTIONS(5497),
    [aux_sym_boolean_token2] = ACTIONS(5497),
    [sym_decimal] = ACTIONS(5497),
    [anon_sym_LPAREN] = ACTIONS(5501),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5497),
    [anon_sym_LBRACK] = ACTIONS(5501),
    [aux_sym_record_type_token1] = ACTIONS(5497),
    [aux_sym_basic_type_token21] = ACTIONS(5497),
    [aux_sym_basic_type_token22] = ACTIONS(5497),
    [aux_sym_basic_type_token48] = ACTIONS(5497),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5497),
    [anon_sym_POUNDif] = ACTIONS(5501),
    [anon_sym_POUNDIF] = ACTIONS(5501),
    [anon_sym_POUNDIf] = ACTIONS(5501),
    [anon_sym_not] = ACTIONS(5497),
    [anon_sym_NOT] = ACTIONS(5497),
    [anon_sym_Not] = ACTIONS(5497),
    [anon_sym_POUNDelse] = ACTIONS(5501),
    [anon_sym_POUNDELSE] = ACTIONS(5501),
    [anon_sym_POUNDElse] = ACTIONS(5501),
    [anon_sym_POUNDelse2] = ACTIONS(5501),
    [anon_sym_POUNDELSE2] = ACTIONS(5501),
    [anon_sym_POUNDElse2] = ACTIONS(5501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5497),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5497),
    [anon_sym_PLUS] = ACTIONS(5501),
    [sym_datetime_literal] = ACTIONS(5501),
    [sym_date_literal] = ACTIONS(5497),
    [sym_time_literal] = ACTIONS(5497),
    [sym_biginteger_literal] = ACTIONS(5501),
    [anon_sym_if] = ACTIONS(5497),
    [anon_sym_IF] = ACTIONS(5497),
    [anon_sym_If] = ACTIONS(5497),
    [anon_sym_else] = ACTIONS(5497),
    [anon_sym_ELSE] = ACTIONS(5497),
    [anon_sym_Else] = ACTIONS(5497),
    [anon_sym_case] = ACTIONS(5497),
    [anon_sym_CASE] = ACTIONS(5497),
    [anon_sym_Case] = ACTIONS(5497),
    [anon_sym_for] = ACTIONS(5497),
    [anon_sym_FOR] = ACTIONS(5497),
    [anon_sym_For] = ACTIONS(5497),
    [anon_sym_foreach] = ACTIONS(5497),
    [anon_sym_FOREACH] = ACTIONS(5497),
    [anon_sym_Foreach] = ACTIONS(5497),
    [anon_sym_while] = ACTIONS(5497),
    [anon_sym_WHILE] = ACTIONS(5497),
    [anon_sym_While] = ACTIONS(5497),
    [anon_sym_repeat] = ACTIONS(5497),
    [anon_sym_REPEAT] = ACTIONS(5497),
    [anon_sym_Repeat] = ACTIONS(5497),
    [anon_sym_exit] = ACTIONS(5497),
    [anon_sym_EXIT] = ACTIONS(5497),
    [anon_sym_Exit] = ACTIONS(5497),
    [anon_sym_continue] = ACTIONS(5497),
    [anon_sym_CONTINUE] = ACTIONS(5497),
    [anon_sym_Continue] = ACTIONS(5497),
    [anon_sym_break] = ACTIONS(5497),
    [anon_sym_BREAK] = ACTIONS(5497),
    [anon_sym_Break] = ACTIONS(5497),
    [anon_sym_with] = ACTIONS(5497),
    [anon_sym_WITH] = ACTIONS(5497),
    [anon_sym_With] = ACTIONS(5497),
    [sym_asserterror_keyword] = ACTIONS(5501),
    [sym_page_keyword] = ACTIONS(5497),
    [anon_sym_codeunit] = ACTIONS(5497),
    [anon_sym_CODEUNIT] = ACTIONS(5497),
    [anon_sym_Codeunit] = ACTIONS(5497),
    [anon_sym_CodeUnit] = ACTIONS(5497),
    [anon_sym_COdeunit] = ACTIONS(5497),
    [anon_sym_codeUnit] = ACTIONS(5497),
    [sym_report_keyword] = ACTIONS(5497),
    [sym_query_keyword] = ACTIONS(5497),
    [anon_sym_xmlport] = ACTIONS(5497),
    [anon_sym_XMLPORT] = ACTIONS(5497),
    [anon_sym_Xmlport] = ACTIONS(5497),
    [anon_sym_XMLport] = ACTIONS(5497),
    [anon_sym_XMLPort] = ACTIONS(5497),
    [anon_sym_XmlPort] = ACTIONS(5497),
    [anon_sym_enum] = ACTIONS(5497),
    [anon_sym_ENUM] = ACTIONS(5497),
    [anon_sym_Enum] = ACTIONS(5497),
    [anon_sym_eNUM] = ACTIONS(5497),
    [anon_sym_eNum] = ACTIONS(5497),
    [anon_sym_ENum] = ACTIONS(5497),
    [sym_quoted_identifier] = ACTIONS(5501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5501),
    [sym_verbatim_string] = ACTIONS(5501),
    [sym_integer] = ACTIONS(5497),
    [sym_continue_as_identifier] = ACTIONS(5501),
    [sym_preproc_open] = ACTIONS(5501),
    [sym_end_keyword] = ACTIONS(5501),
  },
  [STATE(3278)] = {
    [sym_identifier] = ACTIONS(6010),
    [anon_sym_SEMI] = ACTIONS(6012),
    [anon_sym_DASH] = ACTIONS(6012),
    [aux_sym_boolean_token1] = ACTIONS(6010),
    [aux_sym_boolean_token2] = ACTIONS(6010),
    [sym_decimal] = ACTIONS(6010),
    [anon_sym_LPAREN] = ACTIONS(6012),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6010),
    [anon_sym_LBRACK] = ACTIONS(6012),
    [aux_sym_record_type_token1] = ACTIONS(6010),
    [aux_sym_basic_type_token21] = ACTIONS(6010),
    [aux_sym_basic_type_token22] = ACTIONS(6010),
    [aux_sym_basic_type_token48] = ACTIONS(6010),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6010),
    [anon_sym_POUNDif] = ACTIONS(6012),
    [anon_sym_POUNDIF] = ACTIONS(6012),
    [anon_sym_POUNDIf] = ACTIONS(6012),
    [anon_sym_not] = ACTIONS(6010),
    [anon_sym_NOT] = ACTIONS(6010),
    [anon_sym_Not] = ACTIONS(6010),
    [anon_sym_POUNDelse] = ACTIONS(6012),
    [anon_sym_POUNDELSE] = ACTIONS(6012),
    [anon_sym_POUNDElse] = ACTIONS(6012),
    [anon_sym_POUNDelse2] = ACTIONS(6012),
    [anon_sym_POUNDELSE2] = ACTIONS(6012),
    [anon_sym_POUNDElse2] = ACTIONS(6012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6010),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6010),
    [anon_sym_PLUS] = ACTIONS(6012),
    [sym_datetime_literal] = ACTIONS(6012),
    [sym_date_literal] = ACTIONS(6010),
    [sym_time_literal] = ACTIONS(6010),
    [sym_biginteger_literal] = ACTIONS(6012),
    [anon_sym_if] = ACTIONS(6010),
    [anon_sym_IF] = ACTIONS(6010),
    [anon_sym_If] = ACTIONS(6010),
    [anon_sym_else] = ACTIONS(6010),
    [anon_sym_ELSE] = ACTIONS(6010),
    [anon_sym_Else] = ACTIONS(6010),
    [anon_sym_case] = ACTIONS(6010),
    [anon_sym_CASE] = ACTIONS(6010),
    [anon_sym_Case] = ACTIONS(6010),
    [anon_sym_for] = ACTIONS(6010),
    [anon_sym_FOR] = ACTIONS(6010),
    [anon_sym_For] = ACTIONS(6010),
    [anon_sym_foreach] = ACTIONS(6010),
    [anon_sym_FOREACH] = ACTIONS(6010),
    [anon_sym_Foreach] = ACTIONS(6010),
    [anon_sym_while] = ACTIONS(6010),
    [anon_sym_WHILE] = ACTIONS(6010),
    [anon_sym_While] = ACTIONS(6010),
    [anon_sym_repeat] = ACTIONS(6010),
    [anon_sym_REPEAT] = ACTIONS(6010),
    [anon_sym_Repeat] = ACTIONS(6010),
    [anon_sym_exit] = ACTIONS(6010),
    [anon_sym_EXIT] = ACTIONS(6010),
    [anon_sym_Exit] = ACTIONS(6010),
    [anon_sym_continue] = ACTIONS(6010),
    [anon_sym_CONTINUE] = ACTIONS(6010),
    [anon_sym_Continue] = ACTIONS(6010),
    [anon_sym_break] = ACTIONS(6010),
    [anon_sym_BREAK] = ACTIONS(6010),
    [anon_sym_Break] = ACTIONS(6010),
    [anon_sym_with] = ACTIONS(6010),
    [anon_sym_WITH] = ACTIONS(6010),
    [anon_sym_With] = ACTIONS(6010),
    [sym_asserterror_keyword] = ACTIONS(6012),
    [sym_page_keyword] = ACTIONS(6010),
    [anon_sym_codeunit] = ACTIONS(6010),
    [anon_sym_CODEUNIT] = ACTIONS(6010),
    [anon_sym_Codeunit] = ACTIONS(6010),
    [anon_sym_CodeUnit] = ACTIONS(6010),
    [anon_sym_COdeunit] = ACTIONS(6010),
    [anon_sym_codeUnit] = ACTIONS(6010),
    [sym_report_keyword] = ACTIONS(6010),
    [sym_query_keyword] = ACTIONS(6010),
    [anon_sym_xmlport] = ACTIONS(6010),
    [anon_sym_XMLPORT] = ACTIONS(6010),
    [anon_sym_Xmlport] = ACTIONS(6010),
    [anon_sym_XMLport] = ACTIONS(6010),
    [anon_sym_XMLPort] = ACTIONS(6010),
    [anon_sym_XmlPort] = ACTIONS(6010),
    [anon_sym_enum] = ACTIONS(6010),
    [anon_sym_ENUM] = ACTIONS(6010),
    [anon_sym_Enum] = ACTIONS(6010),
    [anon_sym_eNUM] = ACTIONS(6010),
    [anon_sym_eNum] = ACTIONS(6010),
    [anon_sym_ENum] = ACTIONS(6010),
    [sym_quoted_identifier] = ACTIONS(6012),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6012),
    [sym_verbatim_string] = ACTIONS(6012),
    [sym_integer] = ACTIONS(6010),
    [sym_continue_as_identifier] = ACTIONS(6012),
    [sym_preproc_open] = ACTIONS(6012),
    [sym_end_keyword] = ACTIONS(6012),
  },
  [STATE(3279)] = {
    [sym_identifier] = ACTIONS(6232),
    [anon_sym_SEMI] = ACTIONS(6234),
    [anon_sym_DASH] = ACTIONS(6234),
    [aux_sym_boolean_token1] = ACTIONS(6232),
    [aux_sym_boolean_token2] = ACTIONS(6232),
    [sym_decimal] = ACTIONS(6232),
    [anon_sym_LPAREN] = ACTIONS(6234),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6232),
    [anon_sym_LBRACK] = ACTIONS(6234),
    [aux_sym_record_type_token1] = ACTIONS(6232),
    [aux_sym_basic_type_token21] = ACTIONS(6232),
    [aux_sym_basic_type_token22] = ACTIONS(6232),
    [aux_sym_basic_type_token48] = ACTIONS(6232),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6232),
    [anon_sym_POUNDif] = ACTIONS(6234),
    [anon_sym_POUNDIF] = ACTIONS(6234),
    [anon_sym_POUNDIf] = ACTIONS(6234),
    [anon_sym_not] = ACTIONS(6232),
    [anon_sym_NOT] = ACTIONS(6232),
    [anon_sym_Not] = ACTIONS(6232),
    [anon_sym_POUNDelse] = ACTIONS(6234),
    [anon_sym_POUNDELSE] = ACTIONS(6234),
    [anon_sym_POUNDElse] = ACTIONS(6234),
    [anon_sym_POUNDelse2] = ACTIONS(6234),
    [anon_sym_POUNDELSE2] = ACTIONS(6234),
    [anon_sym_POUNDElse2] = ACTIONS(6234),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6232),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6232),
    [anon_sym_PLUS] = ACTIONS(6234),
    [sym_datetime_literal] = ACTIONS(6234),
    [sym_date_literal] = ACTIONS(6232),
    [sym_time_literal] = ACTIONS(6232),
    [sym_biginteger_literal] = ACTIONS(6234),
    [anon_sym_if] = ACTIONS(6232),
    [anon_sym_IF] = ACTIONS(6232),
    [anon_sym_If] = ACTIONS(6232),
    [anon_sym_else] = ACTIONS(6232),
    [anon_sym_ELSE] = ACTIONS(6232),
    [anon_sym_Else] = ACTIONS(6232),
    [anon_sym_case] = ACTIONS(6232),
    [anon_sym_CASE] = ACTIONS(6232),
    [anon_sym_Case] = ACTIONS(6232),
    [anon_sym_for] = ACTIONS(6232),
    [anon_sym_FOR] = ACTIONS(6232),
    [anon_sym_For] = ACTIONS(6232),
    [anon_sym_foreach] = ACTIONS(6232),
    [anon_sym_FOREACH] = ACTIONS(6232),
    [anon_sym_Foreach] = ACTIONS(6232),
    [anon_sym_while] = ACTIONS(6232),
    [anon_sym_WHILE] = ACTIONS(6232),
    [anon_sym_While] = ACTIONS(6232),
    [anon_sym_repeat] = ACTIONS(6232),
    [anon_sym_REPEAT] = ACTIONS(6232),
    [anon_sym_Repeat] = ACTIONS(6232),
    [anon_sym_exit] = ACTIONS(6232),
    [anon_sym_EXIT] = ACTIONS(6232),
    [anon_sym_Exit] = ACTIONS(6232),
    [anon_sym_continue] = ACTIONS(6232),
    [anon_sym_CONTINUE] = ACTIONS(6232),
    [anon_sym_Continue] = ACTIONS(6232),
    [anon_sym_break] = ACTIONS(6232),
    [anon_sym_BREAK] = ACTIONS(6232),
    [anon_sym_Break] = ACTIONS(6232),
    [anon_sym_with] = ACTIONS(6232),
    [anon_sym_WITH] = ACTIONS(6232),
    [anon_sym_With] = ACTIONS(6232),
    [sym_asserterror_keyword] = ACTIONS(6234),
    [sym_page_keyword] = ACTIONS(6232),
    [anon_sym_codeunit] = ACTIONS(6232),
    [anon_sym_CODEUNIT] = ACTIONS(6232),
    [anon_sym_Codeunit] = ACTIONS(6232),
    [anon_sym_CodeUnit] = ACTIONS(6232),
    [anon_sym_COdeunit] = ACTIONS(6232),
    [anon_sym_codeUnit] = ACTIONS(6232),
    [sym_report_keyword] = ACTIONS(6232),
    [sym_query_keyword] = ACTIONS(6232),
    [anon_sym_xmlport] = ACTIONS(6232),
    [anon_sym_XMLPORT] = ACTIONS(6232),
    [anon_sym_Xmlport] = ACTIONS(6232),
    [anon_sym_XMLport] = ACTIONS(6232),
    [anon_sym_XMLPort] = ACTIONS(6232),
    [anon_sym_XmlPort] = ACTIONS(6232),
    [anon_sym_enum] = ACTIONS(6232),
    [anon_sym_ENUM] = ACTIONS(6232),
    [anon_sym_Enum] = ACTIONS(6232),
    [anon_sym_eNUM] = ACTIONS(6232),
    [anon_sym_eNum] = ACTIONS(6232),
    [anon_sym_ENum] = ACTIONS(6232),
    [sym_quoted_identifier] = ACTIONS(6234),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6234),
    [sym_verbatim_string] = ACTIONS(6234),
    [sym_integer] = ACTIONS(6232),
    [sym_continue_as_identifier] = ACTIONS(6234),
    [sym_preproc_open] = ACTIONS(6234),
    [sym_end_keyword] = ACTIONS(6234),
  },
  [STATE(3280)] = {
    [sym_identifier] = ACTIONS(6114),
    [anon_sym_SEMI] = ACTIONS(6116),
    [anon_sym_DASH] = ACTIONS(6116),
    [aux_sym_boolean_token1] = ACTIONS(6114),
    [aux_sym_boolean_token2] = ACTIONS(6114),
    [sym_decimal] = ACTIONS(6114),
    [anon_sym_LPAREN] = ACTIONS(6116),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6114),
    [anon_sym_LBRACK] = ACTIONS(6116),
    [aux_sym_record_type_token1] = ACTIONS(6114),
    [aux_sym_basic_type_token21] = ACTIONS(6114),
    [aux_sym_basic_type_token22] = ACTIONS(6114),
    [aux_sym_basic_type_token48] = ACTIONS(6114),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6114),
    [anon_sym_POUNDif] = ACTIONS(6116),
    [anon_sym_POUNDIF] = ACTIONS(6116),
    [anon_sym_POUNDIf] = ACTIONS(6116),
    [anon_sym_not] = ACTIONS(6114),
    [anon_sym_NOT] = ACTIONS(6114),
    [anon_sym_Not] = ACTIONS(6114),
    [anon_sym_POUNDelse] = ACTIONS(6116),
    [anon_sym_POUNDELSE] = ACTIONS(6116),
    [anon_sym_POUNDElse] = ACTIONS(6116),
    [anon_sym_POUNDelse2] = ACTIONS(6116),
    [anon_sym_POUNDELSE2] = ACTIONS(6116),
    [anon_sym_POUNDElse2] = ACTIONS(6116),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6114),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6114),
    [anon_sym_PLUS] = ACTIONS(6116),
    [sym_datetime_literal] = ACTIONS(6116),
    [sym_date_literal] = ACTIONS(6114),
    [sym_time_literal] = ACTIONS(6114),
    [sym_biginteger_literal] = ACTIONS(6116),
    [anon_sym_if] = ACTIONS(6114),
    [anon_sym_IF] = ACTIONS(6114),
    [anon_sym_If] = ACTIONS(6114),
    [anon_sym_else] = ACTIONS(6114),
    [anon_sym_ELSE] = ACTIONS(6114),
    [anon_sym_Else] = ACTIONS(6114),
    [anon_sym_case] = ACTIONS(6114),
    [anon_sym_CASE] = ACTIONS(6114),
    [anon_sym_Case] = ACTIONS(6114),
    [anon_sym_for] = ACTIONS(6114),
    [anon_sym_FOR] = ACTIONS(6114),
    [anon_sym_For] = ACTIONS(6114),
    [anon_sym_foreach] = ACTIONS(6114),
    [anon_sym_FOREACH] = ACTIONS(6114),
    [anon_sym_Foreach] = ACTIONS(6114),
    [anon_sym_while] = ACTIONS(6114),
    [anon_sym_WHILE] = ACTIONS(6114),
    [anon_sym_While] = ACTIONS(6114),
    [anon_sym_repeat] = ACTIONS(6114),
    [anon_sym_REPEAT] = ACTIONS(6114),
    [anon_sym_Repeat] = ACTIONS(6114),
    [anon_sym_exit] = ACTIONS(6114),
    [anon_sym_EXIT] = ACTIONS(6114),
    [anon_sym_Exit] = ACTIONS(6114),
    [anon_sym_continue] = ACTIONS(6114),
    [anon_sym_CONTINUE] = ACTIONS(6114),
    [anon_sym_Continue] = ACTIONS(6114),
    [anon_sym_break] = ACTIONS(6114),
    [anon_sym_BREAK] = ACTIONS(6114),
    [anon_sym_Break] = ACTIONS(6114),
    [anon_sym_with] = ACTIONS(6114),
    [anon_sym_WITH] = ACTIONS(6114),
    [anon_sym_With] = ACTIONS(6114),
    [sym_asserterror_keyword] = ACTIONS(6116),
    [sym_page_keyword] = ACTIONS(6114),
    [anon_sym_codeunit] = ACTIONS(6114),
    [anon_sym_CODEUNIT] = ACTIONS(6114),
    [anon_sym_Codeunit] = ACTIONS(6114),
    [anon_sym_CodeUnit] = ACTIONS(6114),
    [anon_sym_COdeunit] = ACTIONS(6114),
    [anon_sym_codeUnit] = ACTIONS(6114),
    [sym_report_keyword] = ACTIONS(6114),
    [sym_query_keyword] = ACTIONS(6114),
    [anon_sym_xmlport] = ACTIONS(6114),
    [anon_sym_XMLPORT] = ACTIONS(6114),
    [anon_sym_Xmlport] = ACTIONS(6114),
    [anon_sym_XMLport] = ACTIONS(6114),
    [anon_sym_XMLPort] = ACTIONS(6114),
    [anon_sym_XmlPort] = ACTIONS(6114),
    [anon_sym_enum] = ACTIONS(6114),
    [anon_sym_ENUM] = ACTIONS(6114),
    [anon_sym_Enum] = ACTIONS(6114),
    [anon_sym_eNUM] = ACTIONS(6114),
    [anon_sym_eNum] = ACTIONS(6114),
    [anon_sym_ENum] = ACTIONS(6114),
    [sym_quoted_identifier] = ACTIONS(6116),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6116),
    [sym_verbatim_string] = ACTIONS(6116),
    [sym_integer] = ACTIONS(6114),
    [sym_continue_as_identifier] = ACTIONS(6116),
    [sym_preproc_open] = ACTIONS(6116),
    [sym_end_keyword] = ACTIONS(6116),
  },
  [STATE(3281)] = {
    [sym_identifier] = ACTIONS(6086),
    [anon_sym_SEMI] = ACTIONS(6088),
    [anon_sym_DASH] = ACTIONS(6088),
    [aux_sym_boolean_token1] = ACTIONS(6086),
    [aux_sym_boolean_token2] = ACTIONS(6086),
    [sym_decimal] = ACTIONS(6086),
    [anon_sym_LPAREN] = ACTIONS(6088),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6086),
    [anon_sym_LBRACK] = ACTIONS(6088),
    [aux_sym_record_type_token1] = ACTIONS(6086),
    [aux_sym_basic_type_token21] = ACTIONS(6086),
    [aux_sym_basic_type_token22] = ACTIONS(6086),
    [aux_sym_basic_type_token48] = ACTIONS(6086),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6086),
    [anon_sym_POUNDif] = ACTIONS(6088),
    [anon_sym_POUNDIF] = ACTIONS(6088),
    [anon_sym_POUNDIf] = ACTIONS(6088),
    [anon_sym_not] = ACTIONS(6086),
    [anon_sym_NOT] = ACTIONS(6086),
    [anon_sym_Not] = ACTIONS(6086),
    [anon_sym_POUNDelse] = ACTIONS(6088),
    [anon_sym_POUNDELSE] = ACTIONS(6088),
    [anon_sym_POUNDElse] = ACTIONS(6088),
    [anon_sym_POUNDelse2] = ACTIONS(6088),
    [anon_sym_POUNDELSE2] = ACTIONS(6088),
    [anon_sym_POUNDElse2] = ACTIONS(6088),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6086),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6086),
    [anon_sym_PLUS] = ACTIONS(6088),
    [sym_datetime_literal] = ACTIONS(6088),
    [sym_date_literal] = ACTIONS(6086),
    [sym_time_literal] = ACTIONS(6086),
    [sym_biginteger_literal] = ACTIONS(6088),
    [anon_sym_if] = ACTIONS(6086),
    [anon_sym_IF] = ACTIONS(6086),
    [anon_sym_If] = ACTIONS(6086),
    [anon_sym_else] = ACTIONS(6086),
    [anon_sym_ELSE] = ACTIONS(6086),
    [anon_sym_Else] = ACTIONS(6086),
    [anon_sym_case] = ACTIONS(6086),
    [anon_sym_CASE] = ACTIONS(6086),
    [anon_sym_Case] = ACTIONS(6086),
    [anon_sym_for] = ACTIONS(6086),
    [anon_sym_FOR] = ACTIONS(6086),
    [anon_sym_For] = ACTIONS(6086),
    [anon_sym_foreach] = ACTIONS(6086),
    [anon_sym_FOREACH] = ACTIONS(6086),
    [anon_sym_Foreach] = ACTIONS(6086),
    [anon_sym_while] = ACTIONS(6086),
    [anon_sym_WHILE] = ACTIONS(6086),
    [anon_sym_While] = ACTIONS(6086),
    [anon_sym_repeat] = ACTIONS(6086),
    [anon_sym_REPEAT] = ACTIONS(6086),
    [anon_sym_Repeat] = ACTIONS(6086),
    [anon_sym_exit] = ACTIONS(6086),
    [anon_sym_EXIT] = ACTIONS(6086),
    [anon_sym_Exit] = ACTIONS(6086),
    [anon_sym_continue] = ACTIONS(6086),
    [anon_sym_CONTINUE] = ACTIONS(6086),
    [anon_sym_Continue] = ACTIONS(6086),
    [anon_sym_break] = ACTIONS(6086),
    [anon_sym_BREAK] = ACTIONS(6086),
    [anon_sym_Break] = ACTIONS(6086),
    [anon_sym_with] = ACTIONS(6086),
    [anon_sym_WITH] = ACTIONS(6086),
    [anon_sym_With] = ACTIONS(6086),
    [sym_asserterror_keyword] = ACTIONS(6088),
    [sym_page_keyword] = ACTIONS(6086),
    [anon_sym_codeunit] = ACTIONS(6086),
    [anon_sym_CODEUNIT] = ACTIONS(6086),
    [anon_sym_Codeunit] = ACTIONS(6086),
    [anon_sym_CodeUnit] = ACTIONS(6086),
    [anon_sym_COdeunit] = ACTIONS(6086),
    [anon_sym_codeUnit] = ACTIONS(6086),
    [sym_report_keyword] = ACTIONS(6086),
    [sym_query_keyword] = ACTIONS(6086),
    [anon_sym_xmlport] = ACTIONS(6086),
    [anon_sym_XMLPORT] = ACTIONS(6086),
    [anon_sym_Xmlport] = ACTIONS(6086),
    [anon_sym_XMLport] = ACTIONS(6086),
    [anon_sym_XMLPort] = ACTIONS(6086),
    [anon_sym_XmlPort] = ACTIONS(6086),
    [anon_sym_enum] = ACTIONS(6086),
    [anon_sym_ENUM] = ACTIONS(6086),
    [anon_sym_Enum] = ACTIONS(6086),
    [anon_sym_eNUM] = ACTIONS(6086),
    [anon_sym_eNum] = ACTIONS(6086),
    [anon_sym_ENum] = ACTIONS(6086),
    [sym_quoted_identifier] = ACTIONS(6088),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6088),
    [sym_verbatim_string] = ACTIONS(6088),
    [sym_integer] = ACTIONS(6086),
    [sym_continue_as_identifier] = ACTIONS(6088),
    [sym_preproc_open] = ACTIONS(6088),
    [sym_end_keyword] = ACTIONS(6088),
  },
  [STATE(3282)] = {
    [sym_identifier] = ACTIONS(6292),
    [anon_sym_SEMI] = ACTIONS(7337),
    [anon_sym_DASH] = ACTIONS(6296),
    [aux_sym_boolean_token1] = ACTIONS(6292),
    [aux_sym_boolean_token2] = ACTIONS(6292),
    [sym_decimal] = ACTIONS(6292),
    [anon_sym_LPAREN] = ACTIONS(6296),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6292),
    [anon_sym_LBRACK] = ACTIONS(6296),
    [aux_sym_record_type_token1] = ACTIONS(6292),
    [aux_sym_basic_type_token21] = ACTIONS(6292),
    [aux_sym_basic_type_token22] = ACTIONS(6292),
    [aux_sym_basic_type_token48] = ACTIONS(6292),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6292),
    [anon_sym_POUNDif] = ACTIONS(6296),
    [anon_sym_POUNDIF] = ACTIONS(6296),
    [anon_sym_POUNDIf] = ACTIONS(6296),
    [anon_sym_not] = ACTIONS(6292),
    [anon_sym_NOT] = ACTIONS(6292),
    [anon_sym_Not] = ACTIONS(6292),
    [anon_sym_POUNDelse] = ACTIONS(6296),
    [anon_sym_POUNDELSE] = ACTIONS(6296),
    [anon_sym_POUNDElse] = ACTIONS(6296),
    [anon_sym_POUNDelse2] = ACTIONS(6296),
    [anon_sym_POUNDELSE2] = ACTIONS(6296),
    [anon_sym_POUNDElse2] = ACTIONS(6296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6292),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6292),
    [anon_sym_PLUS] = ACTIONS(6296),
    [sym_datetime_literal] = ACTIONS(6296),
    [sym_date_literal] = ACTIONS(6292),
    [sym_time_literal] = ACTIONS(6292),
    [sym_biginteger_literal] = ACTIONS(6296),
    [anon_sym_if] = ACTIONS(6292),
    [anon_sym_IF] = ACTIONS(6292),
    [anon_sym_If] = ACTIONS(6292),
    [anon_sym_else] = ACTIONS(6292),
    [anon_sym_ELSE] = ACTIONS(6292),
    [anon_sym_Else] = ACTIONS(6292),
    [anon_sym_case] = ACTIONS(6292),
    [anon_sym_CASE] = ACTIONS(6292),
    [anon_sym_Case] = ACTIONS(6292),
    [anon_sym_for] = ACTIONS(6292),
    [anon_sym_FOR] = ACTIONS(6292),
    [anon_sym_For] = ACTIONS(6292),
    [anon_sym_foreach] = ACTIONS(6292),
    [anon_sym_FOREACH] = ACTIONS(6292),
    [anon_sym_Foreach] = ACTIONS(6292),
    [anon_sym_while] = ACTIONS(6292),
    [anon_sym_WHILE] = ACTIONS(6292),
    [anon_sym_While] = ACTIONS(6292),
    [anon_sym_repeat] = ACTIONS(6292),
    [anon_sym_REPEAT] = ACTIONS(6292),
    [anon_sym_Repeat] = ACTIONS(6292),
    [anon_sym_exit] = ACTIONS(6292),
    [anon_sym_EXIT] = ACTIONS(6292),
    [anon_sym_Exit] = ACTIONS(6292),
    [anon_sym_continue] = ACTIONS(6292),
    [anon_sym_CONTINUE] = ACTIONS(6292),
    [anon_sym_Continue] = ACTIONS(6292),
    [anon_sym_break] = ACTIONS(6292),
    [anon_sym_BREAK] = ACTIONS(6292),
    [anon_sym_Break] = ACTIONS(6292),
    [anon_sym_with] = ACTIONS(6292),
    [anon_sym_WITH] = ACTIONS(6292),
    [anon_sym_With] = ACTIONS(6292),
    [sym_asserterror_keyword] = ACTIONS(6296),
    [sym_page_keyword] = ACTIONS(6292),
    [anon_sym_codeunit] = ACTIONS(6292),
    [anon_sym_CODEUNIT] = ACTIONS(6292),
    [anon_sym_Codeunit] = ACTIONS(6292),
    [anon_sym_CodeUnit] = ACTIONS(6292),
    [anon_sym_COdeunit] = ACTIONS(6292),
    [anon_sym_codeUnit] = ACTIONS(6292),
    [sym_report_keyword] = ACTIONS(6292),
    [sym_query_keyword] = ACTIONS(6292),
    [anon_sym_xmlport] = ACTIONS(6292),
    [anon_sym_XMLPORT] = ACTIONS(6292),
    [anon_sym_Xmlport] = ACTIONS(6292),
    [anon_sym_XMLport] = ACTIONS(6292),
    [anon_sym_XMLPort] = ACTIONS(6292),
    [anon_sym_XmlPort] = ACTIONS(6292),
    [anon_sym_enum] = ACTIONS(6292),
    [anon_sym_ENUM] = ACTIONS(6292),
    [anon_sym_Enum] = ACTIONS(6292),
    [anon_sym_eNUM] = ACTIONS(6292),
    [anon_sym_eNum] = ACTIONS(6292),
    [anon_sym_ENum] = ACTIONS(6292),
    [sym_quoted_identifier] = ACTIONS(6296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6296),
    [sym_verbatim_string] = ACTIONS(6296),
    [sym_integer] = ACTIONS(6292),
    [sym_continue_as_identifier] = ACTIONS(6296),
    [sym_preproc_open] = ACTIONS(6296),
    [sym_end_keyword] = ACTIONS(6296),
  },
  [STATE(3283)] = {
    [sym_identifier] = ACTIONS(6292),
    [anon_sym_SEMI] = ACTIONS(7339),
    [anon_sym_DASH] = ACTIONS(6296),
    [aux_sym_boolean_token1] = ACTIONS(6292),
    [aux_sym_boolean_token2] = ACTIONS(6292),
    [sym_decimal] = ACTIONS(6292),
    [anon_sym_LPAREN] = ACTIONS(6296),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6292),
    [anon_sym_LBRACK] = ACTIONS(6296),
    [aux_sym_record_type_token1] = ACTIONS(6292),
    [aux_sym_basic_type_token21] = ACTIONS(6292),
    [aux_sym_basic_type_token22] = ACTIONS(6292),
    [aux_sym_basic_type_token48] = ACTIONS(6292),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6292),
    [anon_sym_POUNDif] = ACTIONS(6296),
    [anon_sym_POUNDIF] = ACTIONS(6296),
    [anon_sym_POUNDIf] = ACTIONS(6296),
    [anon_sym_not] = ACTIONS(6292),
    [anon_sym_NOT] = ACTIONS(6292),
    [anon_sym_Not] = ACTIONS(6292),
    [anon_sym_POUNDelse] = ACTIONS(6296),
    [anon_sym_POUNDELSE] = ACTIONS(6296),
    [anon_sym_POUNDElse] = ACTIONS(6296),
    [anon_sym_POUNDelse2] = ACTIONS(6296),
    [anon_sym_POUNDELSE2] = ACTIONS(6296),
    [anon_sym_POUNDElse2] = ACTIONS(6296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6292),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6292),
    [anon_sym_PLUS] = ACTIONS(6296),
    [sym_datetime_literal] = ACTIONS(6296),
    [sym_date_literal] = ACTIONS(6292),
    [sym_time_literal] = ACTIONS(6292),
    [sym_biginteger_literal] = ACTIONS(6296),
    [anon_sym_if] = ACTIONS(6292),
    [anon_sym_IF] = ACTIONS(6292),
    [anon_sym_If] = ACTIONS(6292),
    [anon_sym_else] = ACTIONS(6292),
    [anon_sym_ELSE] = ACTIONS(6292),
    [anon_sym_Else] = ACTIONS(6292),
    [anon_sym_case] = ACTIONS(6292),
    [anon_sym_CASE] = ACTIONS(6292),
    [anon_sym_Case] = ACTIONS(6292),
    [anon_sym_for] = ACTIONS(6292),
    [anon_sym_FOR] = ACTIONS(6292),
    [anon_sym_For] = ACTIONS(6292),
    [anon_sym_foreach] = ACTIONS(6292),
    [anon_sym_FOREACH] = ACTIONS(6292),
    [anon_sym_Foreach] = ACTIONS(6292),
    [anon_sym_while] = ACTIONS(6292),
    [anon_sym_WHILE] = ACTIONS(6292),
    [anon_sym_While] = ACTIONS(6292),
    [anon_sym_repeat] = ACTIONS(6292),
    [anon_sym_REPEAT] = ACTIONS(6292),
    [anon_sym_Repeat] = ACTIONS(6292),
    [anon_sym_exit] = ACTIONS(6292),
    [anon_sym_EXIT] = ACTIONS(6292),
    [anon_sym_Exit] = ACTIONS(6292),
    [anon_sym_continue] = ACTIONS(6292),
    [anon_sym_CONTINUE] = ACTIONS(6292),
    [anon_sym_Continue] = ACTIONS(6292),
    [anon_sym_break] = ACTIONS(6292),
    [anon_sym_BREAK] = ACTIONS(6292),
    [anon_sym_Break] = ACTIONS(6292),
    [anon_sym_with] = ACTIONS(6292),
    [anon_sym_WITH] = ACTIONS(6292),
    [anon_sym_With] = ACTIONS(6292),
    [sym_asserterror_keyword] = ACTIONS(6296),
    [sym_page_keyword] = ACTIONS(6292),
    [anon_sym_codeunit] = ACTIONS(6292),
    [anon_sym_CODEUNIT] = ACTIONS(6292),
    [anon_sym_Codeunit] = ACTIONS(6292),
    [anon_sym_CodeUnit] = ACTIONS(6292),
    [anon_sym_COdeunit] = ACTIONS(6292),
    [anon_sym_codeUnit] = ACTIONS(6292),
    [sym_report_keyword] = ACTIONS(6292),
    [sym_query_keyword] = ACTIONS(6292),
    [anon_sym_xmlport] = ACTIONS(6292),
    [anon_sym_XMLPORT] = ACTIONS(6292),
    [anon_sym_Xmlport] = ACTIONS(6292),
    [anon_sym_XMLport] = ACTIONS(6292),
    [anon_sym_XMLPort] = ACTIONS(6292),
    [anon_sym_XmlPort] = ACTIONS(6292),
    [anon_sym_enum] = ACTIONS(6292),
    [anon_sym_ENUM] = ACTIONS(6292),
    [anon_sym_Enum] = ACTIONS(6292),
    [anon_sym_eNUM] = ACTIONS(6292),
    [anon_sym_eNum] = ACTIONS(6292),
    [anon_sym_ENum] = ACTIONS(6292),
    [sym_quoted_identifier] = ACTIONS(6296),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6296),
    [sym_verbatim_string] = ACTIONS(6296),
    [sym_integer] = ACTIONS(6292),
    [sym_continue_as_identifier] = ACTIONS(6296),
    [sym_preproc_open] = ACTIONS(6296),
    [sym_end_keyword] = ACTIONS(6296),
  },
  [STATE(3284)] = {
    [sym_identifier] = ACTIONS(5697),
    [anon_sym_SEMI] = ACTIONS(5699),
    [anon_sym_DASH] = ACTIONS(5699),
    [aux_sym_boolean_token1] = ACTIONS(5697),
    [aux_sym_boolean_token2] = ACTIONS(5697),
    [sym_decimal] = ACTIONS(5697),
    [anon_sym_LPAREN] = ACTIONS(5699),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5697),
    [anon_sym_LBRACK] = ACTIONS(5699),
    [aux_sym_record_type_token1] = ACTIONS(5697),
    [aux_sym_basic_type_token21] = ACTIONS(5697),
    [aux_sym_basic_type_token22] = ACTIONS(5697),
    [aux_sym_basic_type_token48] = ACTIONS(5697),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5697),
    [anon_sym_POUNDif] = ACTIONS(5699),
    [anon_sym_POUNDIF] = ACTIONS(5699),
    [anon_sym_POUNDIf] = ACTIONS(5699),
    [anon_sym_not] = ACTIONS(5697),
    [anon_sym_NOT] = ACTIONS(5697),
    [anon_sym_Not] = ACTIONS(5697),
    [anon_sym_POUNDelse] = ACTIONS(5699),
    [anon_sym_POUNDELSE] = ACTIONS(5699),
    [anon_sym_POUNDElse] = ACTIONS(5699),
    [anon_sym_POUNDelse2] = ACTIONS(5699),
    [anon_sym_POUNDELSE2] = ACTIONS(5699),
    [anon_sym_POUNDElse2] = ACTIONS(5699),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5697),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5697),
    [anon_sym_PLUS] = ACTIONS(5699),
    [sym_datetime_literal] = ACTIONS(5699),
    [sym_date_literal] = ACTIONS(5697),
    [sym_time_literal] = ACTIONS(5697),
    [sym_biginteger_literal] = ACTIONS(5699),
    [anon_sym_if] = ACTIONS(5697),
    [anon_sym_IF] = ACTIONS(5697),
    [anon_sym_If] = ACTIONS(5697),
    [anon_sym_else] = ACTIONS(5697),
    [anon_sym_ELSE] = ACTIONS(5697),
    [anon_sym_Else] = ACTIONS(5697),
    [anon_sym_case] = ACTIONS(5697),
    [anon_sym_CASE] = ACTIONS(5697),
    [anon_sym_Case] = ACTIONS(5697),
    [anon_sym_for] = ACTIONS(5697),
    [anon_sym_FOR] = ACTIONS(5697),
    [anon_sym_For] = ACTIONS(5697),
    [anon_sym_foreach] = ACTIONS(5697),
    [anon_sym_FOREACH] = ACTIONS(5697),
    [anon_sym_Foreach] = ACTIONS(5697),
    [anon_sym_while] = ACTIONS(5697),
    [anon_sym_WHILE] = ACTIONS(5697),
    [anon_sym_While] = ACTIONS(5697),
    [anon_sym_repeat] = ACTIONS(5697),
    [anon_sym_REPEAT] = ACTIONS(5697),
    [anon_sym_Repeat] = ACTIONS(5697),
    [anon_sym_exit] = ACTIONS(5697),
    [anon_sym_EXIT] = ACTIONS(5697),
    [anon_sym_Exit] = ACTIONS(5697),
    [anon_sym_continue] = ACTIONS(5697),
    [anon_sym_CONTINUE] = ACTIONS(5697),
    [anon_sym_Continue] = ACTIONS(5697),
    [anon_sym_break] = ACTIONS(5697),
    [anon_sym_BREAK] = ACTIONS(5697),
    [anon_sym_Break] = ACTIONS(5697),
    [anon_sym_with] = ACTIONS(5697),
    [anon_sym_WITH] = ACTIONS(5697),
    [anon_sym_With] = ACTIONS(5697),
    [sym_asserterror_keyword] = ACTIONS(5699),
    [sym_page_keyword] = ACTIONS(5697),
    [anon_sym_codeunit] = ACTIONS(5697),
    [anon_sym_CODEUNIT] = ACTIONS(5697),
    [anon_sym_Codeunit] = ACTIONS(5697),
    [anon_sym_CodeUnit] = ACTIONS(5697),
    [anon_sym_COdeunit] = ACTIONS(5697),
    [anon_sym_codeUnit] = ACTIONS(5697),
    [sym_report_keyword] = ACTIONS(5697),
    [sym_query_keyword] = ACTIONS(5697),
    [anon_sym_xmlport] = ACTIONS(5697),
    [anon_sym_XMLPORT] = ACTIONS(5697),
    [anon_sym_Xmlport] = ACTIONS(5697),
    [anon_sym_XMLport] = ACTIONS(5697),
    [anon_sym_XMLPort] = ACTIONS(5697),
    [anon_sym_XmlPort] = ACTIONS(5697),
    [anon_sym_enum] = ACTIONS(5697),
    [anon_sym_ENUM] = ACTIONS(5697),
    [anon_sym_Enum] = ACTIONS(5697),
    [anon_sym_eNUM] = ACTIONS(5697),
    [anon_sym_eNum] = ACTIONS(5697),
    [anon_sym_ENum] = ACTIONS(5697),
    [sym_quoted_identifier] = ACTIONS(5699),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5699),
    [sym_verbatim_string] = ACTIONS(5699),
    [sym_integer] = ACTIONS(5697),
    [sym_continue_as_identifier] = ACTIONS(5699),
    [sym_preproc_open] = ACTIONS(5699),
    [sym_end_keyword] = ACTIONS(5699),
  },
  [STATE(3285)] = {
    [sym_identifier] = ACTIONS(5701),
    [anon_sym_SEMI] = ACTIONS(5703),
    [anon_sym_DASH] = ACTIONS(5703),
    [aux_sym_boolean_token1] = ACTIONS(5701),
    [aux_sym_boolean_token2] = ACTIONS(5701),
    [sym_decimal] = ACTIONS(5701),
    [anon_sym_LPAREN] = ACTIONS(5703),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5701),
    [anon_sym_LBRACK] = ACTIONS(5703),
    [aux_sym_record_type_token1] = ACTIONS(5701),
    [aux_sym_basic_type_token21] = ACTIONS(5701),
    [aux_sym_basic_type_token22] = ACTIONS(5701),
    [aux_sym_basic_type_token48] = ACTIONS(5701),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5701),
    [anon_sym_POUNDif] = ACTIONS(5703),
    [anon_sym_POUNDIF] = ACTIONS(5703),
    [anon_sym_POUNDIf] = ACTIONS(5703),
    [anon_sym_not] = ACTIONS(5701),
    [anon_sym_NOT] = ACTIONS(5701),
    [anon_sym_Not] = ACTIONS(5701),
    [anon_sym_POUNDelse] = ACTIONS(5703),
    [anon_sym_POUNDELSE] = ACTIONS(5703),
    [anon_sym_POUNDElse] = ACTIONS(5703),
    [anon_sym_POUNDelse2] = ACTIONS(5703),
    [anon_sym_POUNDELSE2] = ACTIONS(5703),
    [anon_sym_POUNDElse2] = ACTIONS(5703),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5701),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5701),
    [anon_sym_PLUS] = ACTIONS(5703),
    [sym_datetime_literal] = ACTIONS(5703),
    [sym_date_literal] = ACTIONS(5701),
    [sym_time_literal] = ACTIONS(5701),
    [sym_biginteger_literal] = ACTIONS(5703),
    [anon_sym_if] = ACTIONS(5701),
    [anon_sym_IF] = ACTIONS(5701),
    [anon_sym_If] = ACTIONS(5701),
    [anon_sym_else] = ACTIONS(5701),
    [anon_sym_ELSE] = ACTIONS(5701),
    [anon_sym_Else] = ACTIONS(5701),
    [anon_sym_case] = ACTIONS(5701),
    [anon_sym_CASE] = ACTIONS(5701),
    [anon_sym_Case] = ACTIONS(5701),
    [anon_sym_for] = ACTIONS(5701),
    [anon_sym_FOR] = ACTIONS(5701),
    [anon_sym_For] = ACTIONS(5701),
    [anon_sym_foreach] = ACTIONS(5701),
    [anon_sym_FOREACH] = ACTIONS(5701),
    [anon_sym_Foreach] = ACTIONS(5701),
    [anon_sym_while] = ACTIONS(5701),
    [anon_sym_WHILE] = ACTIONS(5701),
    [anon_sym_While] = ACTIONS(5701),
    [anon_sym_repeat] = ACTIONS(5701),
    [anon_sym_REPEAT] = ACTIONS(5701),
    [anon_sym_Repeat] = ACTIONS(5701),
    [anon_sym_exit] = ACTIONS(5701),
    [anon_sym_EXIT] = ACTIONS(5701),
    [anon_sym_Exit] = ACTIONS(5701),
    [anon_sym_continue] = ACTIONS(5701),
    [anon_sym_CONTINUE] = ACTIONS(5701),
    [anon_sym_Continue] = ACTIONS(5701),
    [anon_sym_break] = ACTIONS(5701),
    [anon_sym_BREAK] = ACTIONS(5701),
    [anon_sym_Break] = ACTIONS(5701),
    [anon_sym_with] = ACTIONS(5701),
    [anon_sym_WITH] = ACTIONS(5701),
    [anon_sym_With] = ACTIONS(5701),
    [sym_asserterror_keyword] = ACTIONS(5703),
    [sym_page_keyword] = ACTIONS(5701),
    [anon_sym_codeunit] = ACTIONS(5701),
    [anon_sym_CODEUNIT] = ACTIONS(5701),
    [anon_sym_Codeunit] = ACTIONS(5701),
    [anon_sym_CodeUnit] = ACTIONS(5701),
    [anon_sym_COdeunit] = ACTIONS(5701),
    [anon_sym_codeUnit] = ACTIONS(5701),
    [sym_report_keyword] = ACTIONS(5701),
    [sym_query_keyword] = ACTIONS(5701),
    [anon_sym_xmlport] = ACTIONS(5701),
    [anon_sym_XMLPORT] = ACTIONS(5701),
    [anon_sym_Xmlport] = ACTIONS(5701),
    [anon_sym_XMLport] = ACTIONS(5701),
    [anon_sym_XMLPort] = ACTIONS(5701),
    [anon_sym_XmlPort] = ACTIONS(5701),
    [anon_sym_enum] = ACTIONS(5701),
    [anon_sym_ENUM] = ACTIONS(5701),
    [anon_sym_Enum] = ACTIONS(5701),
    [anon_sym_eNUM] = ACTIONS(5701),
    [anon_sym_eNum] = ACTIONS(5701),
    [anon_sym_ENum] = ACTIONS(5701),
    [sym_quoted_identifier] = ACTIONS(5703),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5703),
    [sym_verbatim_string] = ACTIONS(5703),
    [sym_integer] = ACTIONS(5701),
    [sym_continue_as_identifier] = ACTIONS(5703),
    [sym_preproc_open] = ACTIONS(5703),
    [sym_end_keyword] = ACTIONS(5703),
  },
  [STATE(3286)] = {
    [sym_identifier] = ACTIONS(5705),
    [anon_sym_SEMI] = ACTIONS(5707),
    [anon_sym_DASH] = ACTIONS(5707),
    [aux_sym_boolean_token1] = ACTIONS(5705),
    [aux_sym_boolean_token2] = ACTIONS(5705),
    [sym_decimal] = ACTIONS(5705),
    [anon_sym_LPAREN] = ACTIONS(5707),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5705),
    [anon_sym_LBRACK] = ACTIONS(5707),
    [aux_sym_record_type_token1] = ACTIONS(5705),
    [aux_sym_basic_type_token21] = ACTIONS(5705),
    [aux_sym_basic_type_token22] = ACTIONS(5705),
    [aux_sym_basic_type_token48] = ACTIONS(5705),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5705),
    [anon_sym_POUNDif] = ACTIONS(5707),
    [anon_sym_POUNDIF] = ACTIONS(5707),
    [anon_sym_POUNDIf] = ACTIONS(5707),
    [anon_sym_not] = ACTIONS(5705),
    [anon_sym_NOT] = ACTIONS(5705),
    [anon_sym_Not] = ACTIONS(5705),
    [anon_sym_POUNDelse] = ACTIONS(5707),
    [anon_sym_POUNDELSE] = ACTIONS(5707),
    [anon_sym_POUNDElse] = ACTIONS(5707),
    [anon_sym_POUNDelse2] = ACTIONS(5707),
    [anon_sym_POUNDELSE2] = ACTIONS(5707),
    [anon_sym_POUNDElse2] = ACTIONS(5707),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5705),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5705),
    [anon_sym_PLUS] = ACTIONS(5707),
    [sym_datetime_literal] = ACTIONS(5707),
    [sym_date_literal] = ACTIONS(5705),
    [sym_time_literal] = ACTIONS(5705),
    [sym_biginteger_literal] = ACTIONS(5707),
    [anon_sym_if] = ACTIONS(5705),
    [anon_sym_IF] = ACTIONS(5705),
    [anon_sym_If] = ACTIONS(5705),
    [anon_sym_else] = ACTIONS(5705),
    [anon_sym_ELSE] = ACTIONS(5705),
    [anon_sym_Else] = ACTIONS(5705),
    [anon_sym_case] = ACTIONS(5705),
    [anon_sym_CASE] = ACTIONS(5705),
    [anon_sym_Case] = ACTIONS(5705),
    [anon_sym_for] = ACTIONS(5705),
    [anon_sym_FOR] = ACTIONS(5705),
    [anon_sym_For] = ACTIONS(5705),
    [anon_sym_foreach] = ACTIONS(5705),
    [anon_sym_FOREACH] = ACTIONS(5705),
    [anon_sym_Foreach] = ACTIONS(5705),
    [anon_sym_while] = ACTIONS(5705),
    [anon_sym_WHILE] = ACTIONS(5705),
    [anon_sym_While] = ACTIONS(5705),
    [anon_sym_repeat] = ACTIONS(5705),
    [anon_sym_REPEAT] = ACTIONS(5705),
    [anon_sym_Repeat] = ACTIONS(5705),
    [anon_sym_exit] = ACTIONS(5705),
    [anon_sym_EXIT] = ACTIONS(5705),
    [anon_sym_Exit] = ACTIONS(5705),
    [anon_sym_continue] = ACTIONS(5705),
    [anon_sym_CONTINUE] = ACTIONS(5705),
    [anon_sym_Continue] = ACTIONS(5705),
    [anon_sym_break] = ACTIONS(5705),
    [anon_sym_BREAK] = ACTIONS(5705),
    [anon_sym_Break] = ACTIONS(5705),
    [anon_sym_with] = ACTIONS(5705),
    [anon_sym_WITH] = ACTIONS(5705),
    [anon_sym_With] = ACTIONS(5705),
    [sym_asserterror_keyword] = ACTIONS(5707),
    [sym_page_keyword] = ACTIONS(5705),
    [anon_sym_codeunit] = ACTIONS(5705),
    [anon_sym_CODEUNIT] = ACTIONS(5705),
    [anon_sym_Codeunit] = ACTIONS(5705),
    [anon_sym_CodeUnit] = ACTIONS(5705),
    [anon_sym_COdeunit] = ACTIONS(5705),
    [anon_sym_codeUnit] = ACTIONS(5705),
    [sym_report_keyword] = ACTIONS(5705),
    [sym_query_keyword] = ACTIONS(5705),
    [anon_sym_xmlport] = ACTIONS(5705),
    [anon_sym_XMLPORT] = ACTIONS(5705),
    [anon_sym_Xmlport] = ACTIONS(5705),
    [anon_sym_XMLport] = ACTIONS(5705),
    [anon_sym_XMLPort] = ACTIONS(5705),
    [anon_sym_XmlPort] = ACTIONS(5705),
    [anon_sym_enum] = ACTIONS(5705),
    [anon_sym_ENUM] = ACTIONS(5705),
    [anon_sym_Enum] = ACTIONS(5705),
    [anon_sym_eNUM] = ACTIONS(5705),
    [anon_sym_eNum] = ACTIONS(5705),
    [anon_sym_ENum] = ACTIONS(5705),
    [sym_quoted_identifier] = ACTIONS(5707),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5707),
    [sym_verbatim_string] = ACTIONS(5707),
    [sym_integer] = ACTIONS(5705),
    [sym_continue_as_identifier] = ACTIONS(5707),
    [sym_preproc_open] = ACTIONS(5707),
    [sym_end_keyword] = ACTIONS(5707),
  },
  [STATE(3287)] = {
    [sym_identifier] = ACTIONS(5709),
    [anon_sym_SEMI] = ACTIONS(5711),
    [anon_sym_DASH] = ACTIONS(5711),
    [aux_sym_boolean_token1] = ACTIONS(5709),
    [aux_sym_boolean_token2] = ACTIONS(5709),
    [sym_decimal] = ACTIONS(5709),
    [anon_sym_LPAREN] = ACTIONS(5711),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5709),
    [anon_sym_LBRACK] = ACTIONS(5711),
    [aux_sym_record_type_token1] = ACTIONS(5709),
    [aux_sym_basic_type_token21] = ACTIONS(5709),
    [aux_sym_basic_type_token22] = ACTIONS(5709),
    [aux_sym_basic_type_token48] = ACTIONS(5709),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5709),
    [anon_sym_POUNDif] = ACTIONS(5711),
    [anon_sym_POUNDIF] = ACTIONS(5711),
    [anon_sym_POUNDIf] = ACTIONS(5711),
    [anon_sym_not] = ACTIONS(5709),
    [anon_sym_NOT] = ACTIONS(5709),
    [anon_sym_Not] = ACTIONS(5709),
    [anon_sym_POUNDelse] = ACTIONS(5711),
    [anon_sym_POUNDELSE] = ACTIONS(5711),
    [anon_sym_POUNDElse] = ACTIONS(5711),
    [anon_sym_POUNDelse2] = ACTIONS(5711),
    [anon_sym_POUNDELSE2] = ACTIONS(5711),
    [anon_sym_POUNDElse2] = ACTIONS(5711),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5709),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5709),
    [anon_sym_PLUS] = ACTIONS(5711),
    [sym_datetime_literal] = ACTIONS(5711),
    [sym_date_literal] = ACTIONS(5709),
    [sym_time_literal] = ACTIONS(5709),
    [sym_biginteger_literal] = ACTIONS(5711),
    [anon_sym_if] = ACTIONS(5709),
    [anon_sym_IF] = ACTIONS(5709),
    [anon_sym_If] = ACTIONS(5709),
    [anon_sym_else] = ACTIONS(5709),
    [anon_sym_ELSE] = ACTIONS(5709),
    [anon_sym_Else] = ACTIONS(5709),
    [anon_sym_case] = ACTIONS(5709),
    [anon_sym_CASE] = ACTIONS(5709),
    [anon_sym_Case] = ACTIONS(5709),
    [anon_sym_for] = ACTIONS(5709),
    [anon_sym_FOR] = ACTIONS(5709),
    [anon_sym_For] = ACTIONS(5709),
    [anon_sym_foreach] = ACTIONS(5709),
    [anon_sym_FOREACH] = ACTIONS(5709),
    [anon_sym_Foreach] = ACTIONS(5709),
    [anon_sym_while] = ACTIONS(5709),
    [anon_sym_WHILE] = ACTIONS(5709),
    [anon_sym_While] = ACTIONS(5709),
    [anon_sym_repeat] = ACTIONS(5709),
    [anon_sym_REPEAT] = ACTIONS(5709),
    [anon_sym_Repeat] = ACTIONS(5709),
    [anon_sym_exit] = ACTIONS(5709),
    [anon_sym_EXIT] = ACTIONS(5709),
    [anon_sym_Exit] = ACTIONS(5709),
    [anon_sym_continue] = ACTIONS(5709),
    [anon_sym_CONTINUE] = ACTIONS(5709),
    [anon_sym_Continue] = ACTIONS(5709),
    [anon_sym_break] = ACTIONS(5709),
    [anon_sym_BREAK] = ACTIONS(5709),
    [anon_sym_Break] = ACTIONS(5709),
    [anon_sym_with] = ACTIONS(5709),
    [anon_sym_WITH] = ACTIONS(5709),
    [anon_sym_With] = ACTIONS(5709),
    [sym_asserterror_keyword] = ACTIONS(5711),
    [sym_page_keyword] = ACTIONS(5709),
    [anon_sym_codeunit] = ACTIONS(5709),
    [anon_sym_CODEUNIT] = ACTIONS(5709),
    [anon_sym_Codeunit] = ACTIONS(5709),
    [anon_sym_CodeUnit] = ACTIONS(5709),
    [anon_sym_COdeunit] = ACTIONS(5709),
    [anon_sym_codeUnit] = ACTIONS(5709),
    [sym_report_keyword] = ACTIONS(5709),
    [sym_query_keyword] = ACTIONS(5709),
    [anon_sym_xmlport] = ACTIONS(5709),
    [anon_sym_XMLPORT] = ACTIONS(5709),
    [anon_sym_Xmlport] = ACTIONS(5709),
    [anon_sym_XMLport] = ACTIONS(5709),
    [anon_sym_XMLPort] = ACTIONS(5709),
    [anon_sym_XmlPort] = ACTIONS(5709),
    [anon_sym_enum] = ACTIONS(5709),
    [anon_sym_ENUM] = ACTIONS(5709),
    [anon_sym_Enum] = ACTIONS(5709),
    [anon_sym_eNUM] = ACTIONS(5709),
    [anon_sym_eNum] = ACTIONS(5709),
    [anon_sym_ENum] = ACTIONS(5709),
    [sym_quoted_identifier] = ACTIONS(5711),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5711),
    [sym_verbatim_string] = ACTIONS(5711),
    [sym_integer] = ACTIONS(5709),
    [sym_continue_as_identifier] = ACTIONS(5711),
    [sym_preproc_open] = ACTIONS(5711),
    [sym_end_keyword] = ACTIONS(5711),
  },
  [STATE(3288)] = {
    [sym_identifier] = ACTIONS(6014),
    [anon_sym_SEMI] = ACTIONS(6016),
    [anon_sym_DASH] = ACTIONS(6016),
    [aux_sym_boolean_token1] = ACTIONS(6014),
    [aux_sym_boolean_token2] = ACTIONS(6014),
    [sym_decimal] = ACTIONS(6014),
    [anon_sym_LPAREN] = ACTIONS(6016),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6014),
    [anon_sym_LBRACK] = ACTIONS(6016),
    [aux_sym_record_type_token1] = ACTIONS(6014),
    [aux_sym_basic_type_token21] = ACTIONS(6014),
    [aux_sym_basic_type_token22] = ACTIONS(6014),
    [aux_sym_basic_type_token48] = ACTIONS(6014),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6014),
    [anon_sym_POUNDif] = ACTIONS(6016),
    [anon_sym_POUNDIF] = ACTIONS(6016),
    [anon_sym_POUNDIf] = ACTIONS(6016),
    [anon_sym_not] = ACTIONS(6014),
    [anon_sym_NOT] = ACTIONS(6014),
    [anon_sym_Not] = ACTIONS(6014),
    [anon_sym_POUNDelse] = ACTIONS(6016),
    [anon_sym_POUNDELSE] = ACTIONS(6016),
    [anon_sym_POUNDElse] = ACTIONS(6016),
    [anon_sym_POUNDelse2] = ACTIONS(6016),
    [anon_sym_POUNDELSE2] = ACTIONS(6016),
    [anon_sym_POUNDElse2] = ACTIONS(6016),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6014),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6014),
    [anon_sym_PLUS] = ACTIONS(6016),
    [sym_datetime_literal] = ACTIONS(6016),
    [sym_date_literal] = ACTIONS(6014),
    [sym_time_literal] = ACTIONS(6014),
    [sym_biginteger_literal] = ACTIONS(6016),
    [anon_sym_if] = ACTIONS(6014),
    [anon_sym_IF] = ACTIONS(6014),
    [anon_sym_If] = ACTIONS(6014),
    [anon_sym_else] = ACTIONS(6014),
    [anon_sym_ELSE] = ACTIONS(6014),
    [anon_sym_Else] = ACTIONS(6014),
    [anon_sym_case] = ACTIONS(6014),
    [anon_sym_CASE] = ACTIONS(6014),
    [anon_sym_Case] = ACTIONS(6014),
    [anon_sym_for] = ACTIONS(6014),
    [anon_sym_FOR] = ACTIONS(6014),
    [anon_sym_For] = ACTIONS(6014),
    [anon_sym_foreach] = ACTIONS(6014),
    [anon_sym_FOREACH] = ACTIONS(6014),
    [anon_sym_Foreach] = ACTIONS(6014),
    [anon_sym_while] = ACTIONS(6014),
    [anon_sym_WHILE] = ACTIONS(6014),
    [anon_sym_While] = ACTIONS(6014),
    [anon_sym_repeat] = ACTIONS(6014),
    [anon_sym_REPEAT] = ACTIONS(6014),
    [anon_sym_Repeat] = ACTIONS(6014),
    [anon_sym_exit] = ACTIONS(6014),
    [anon_sym_EXIT] = ACTIONS(6014),
    [anon_sym_Exit] = ACTIONS(6014),
    [anon_sym_continue] = ACTIONS(6014),
    [anon_sym_CONTINUE] = ACTIONS(6014),
    [anon_sym_Continue] = ACTIONS(6014),
    [anon_sym_break] = ACTIONS(6014),
    [anon_sym_BREAK] = ACTIONS(6014),
    [anon_sym_Break] = ACTIONS(6014),
    [anon_sym_with] = ACTIONS(6014),
    [anon_sym_WITH] = ACTIONS(6014),
    [anon_sym_With] = ACTIONS(6014),
    [sym_asserterror_keyword] = ACTIONS(6016),
    [sym_page_keyword] = ACTIONS(6014),
    [anon_sym_codeunit] = ACTIONS(6014),
    [anon_sym_CODEUNIT] = ACTIONS(6014),
    [anon_sym_Codeunit] = ACTIONS(6014),
    [anon_sym_CodeUnit] = ACTIONS(6014),
    [anon_sym_COdeunit] = ACTIONS(6014),
    [anon_sym_codeUnit] = ACTIONS(6014),
    [sym_report_keyword] = ACTIONS(6014),
    [sym_query_keyword] = ACTIONS(6014),
    [anon_sym_xmlport] = ACTIONS(6014),
    [anon_sym_XMLPORT] = ACTIONS(6014),
    [anon_sym_Xmlport] = ACTIONS(6014),
    [anon_sym_XMLport] = ACTIONS(6014),
    [anon_sym_XMLPort] = ACTIONS(6014),
    [anon_sym_XmlPort] = ACTIONS(6014),
    [anon_sym_enum] = ACTIONS(6014),
    [anon_sym_ENUM] = ACTIONS(6014),
    [anon_sym_Enum] = ACTIONS(6014),
    [anon_sym_eNUM] = ACTIONS(6014),
    [anon_sym_eNum] = ACTIONS(6014),
    [anon_sym_ENum] = ACTIONS(6014),
    [sym_quoted_identifier] = ACTIONS(6016),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6016),
    [sym_verbatim_string] = ACTIONS(6016),
    [sym_integer] = ACTIONS(6014),
    [sym_continue_as_identifier] = ACTIONS(6016),
    [sym_preproc_open] = ACTIONS(6016),
    [sym_end_keyword] = ACTIONS(6016),
  },
  [STATE(3289)] = {
    [sym_identifier] = ACTIONS(5713),
    [anon_sym_SEMI] = ACTIONS(5715),
    [anon_sym_DASH] = ACTIONS(5715),
    [aux_sym_boolean_token1] = ACTIONS(5713),
    [aux_sym_boolean_token2] = ACTIONS(5713),
    [sym_decimal] = ACTIONS(5713),
    [anon_sym_LPAREN] = ACTIONS(5715),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5713),
    [anon_sym_LBRACK] = ACTIONS(5715),
    [aux_sym_record_type_token1] = ACTIONS(5713),
    [aux_sym_basic_type_token21] = ACTIONS(5713),
    [aux_sym_basic_type_token22] = ACTIONS(5713),
    [aux_sym_basic_type_token48] = ACTIONS(5713),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5713),
    [anon_sym_POUNDif] = ACTIONS(5715),
    [anon_sym_POUNDIF] = ACTIONS(5715),
    [anon_sym_POUNDIf] = ACTIONS(5715),
    [anon_sym_not] = ACTIONS(5713),
    [anon_sym_NOT] = ACTIONS(5713),
    [anon_sym_Not] = ACTIONS(5713),
    [anon_sym_POUNDelse] = ACTIONS(5715),
    [anon_sym_POUNDELSE] = ACTIONS(5715),
    [anon_sym_POUNDElse] = ACTIONS(5715),
    [anon_sym_POUNDelse2] = ACTIONS(5715),
    [anon_sym_POUNDELSE2] = ACTIONS(5715),
    [anon_sym_POUNDElse2] = ACTIONS(5715),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5713),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5713),
    [anon_sym_PLUS] = ACTIONS(5715),
    [sym_datetime_literal] = ACTIONS(5715),
    [sym_date_literal] = ACTIONS(5713),
    [sym_time_literal] = ACTIONS(5713),
    [sym_biginteger_literal] = ACTIONS(5715),
    [anon_sym_if] = ACTIONS(5713),
    [anon_sym_IF] = ACTIONS(5713),
    [anon_sym_If] = ACTIONS(5713),
    [anon_sym_else] = ACTIONS(5713),
    [anon_sym_ELSE] = ACTIONS(5713),
    [anon_sym_Else] = ACTIONS(5713),
    [anon_sym_case] = ACTIONS(5713),
    [anon_sym_CASE] = ACTIONS(5713),
    [anon_sym_Case] = ACTIONS(5713),
    [anon_sym_for] = ACTIONS(5713),
    [anon_sym_FOR] = ACTIONS(5713),
    [anon_sym_For] = ACTIONS(5713),
    [anon_sym_foreach] = ACTIONS(5713),
    [anon_sym_FOREACH] = ACTIONS(5713),
    [anon_sym_Foreach] = ACTIONS(5713),
    [anon_sym_while] = ACTIONS(5713),
    [anon_sym_WHILE] = ACTIONS(5713),
    [anon_sym_While] = ACTIONS(5713),
    [anon_sym_repeat] = ACTIONS(5713),
    [anon_sym_REPEAT] = ACTIONS(5713),
    [anon_sym_Repeat] = ACTIONS(5713),
    [anon_sym_exit] = ACTIONS(5713),
    [anon_sym_EXIT] = ACTIONS(5713),
    [anon_sym_Exit] = ACTIONS(5713),
    [anon_sym_continue] = ACTIONS(5713),
    [anon_sym_CONTINUE] = ACTIONS(5713),
    [anon_sym_Continue] = ACTIONS(5713),
    [anon_sym_break] = ACTIONS(5713),
    [anon_sym_BREAK] = ACTIONS(5713),
    [anon_sym_Break] = ACTIONS(5713),
    [anon_sym_with] = ACTIONS(5713),
    [anon_sym_WITH] = ACTIONS(5713),
    [anon_sym_With] = ACTIONS(5713),
    [sym_asserterror_keyword] = ACTIONS(5715),
    [sym_page_keyword] = ACTIONS(5713),
    [anon_sym_codeunit] = ACTIONS(5713),
    [anon_sym_CODEUNIT] = ACTIONS(5713),
    [anon_sym_Codeunit] = ACTIONS(5713),
    [anon_sym_CodeUnit] = ACTIONS(5713),
    [anon_sym_COdeunit] = ACTIONS(5713),
    [anon_sym_codeUnit] = ACTIONS(5713),
    [sym_report_keyword] = ACTIONS(5713),
    [sym_query_keyword] = ACTIONS(5713),
    [anon_sym_xmlport] = ACTIONS(5713),
    [anon_sym_XMLPORT] = ACTIONS(5713),
    [anon_sym_Xmlport] = ACTIONS(5713),
    [anon_sym_XMLport] = ACTIONS(5713),
    [anon_sym_XMLPort] = ACTIONS(5713),
    [anon_sym_XmlPort] = ACTIONS(5713),
    [anon_sym_enum] = ACTIONS(5713),
    [anon_sym_ENUM] = ACTIONS(5713),
    [anon_sym_Enum] = ACTIONS(5713),
    [anon_sym_eNUM] = ACTIONS(5713),
    [anon_sym_eNum] = ACTIONS(5713),
    [anon_sym_ENum] = ACTIONS(5713),
    [sym_quoted_identifier] = ACTIONS(5715),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5715),
    [sym_verbatim_string] = ACTIONS(5715),
    [sym_integer] = ACTIONS(5713),
    [sym_continue_as_identifier] = ACTIONS(5715),
    [sym_preproc_open] = ACTIONS(5715),
    [sym_end_keyword] = ACTIONS(5715),
  },
  [STATE(3290)] = {
    [sym_identifier] = ACTIONS(6280),
    [anon_sym_SEMI] = ACTIONS(6282),
    [anon_sym_DASH] = ACTIONS(6282),
    [aux_sym_boolean_token1] = ACTIONS(6280),
    [aux_sym_boolean_token2] = ACTIONS(6280),
    [sym_decimal] = ACTIONS(6280),
    [anon_sym_LPAREN] = ACTIONS(6282),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6280),
    [anon_sym_LBRACK] = ACTIONS(6282),
    [aux_sym_record_type_token1] = ACTIONS(6280),
    [aux_sym_basic_type_token21] = ACTIONS(6280),
    [aux_sym_basic_type_token22] = ACTIONS(6280),
    [aux_sym_basic_type_token48] = ACTIONS(6280),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6280),
    [anon_sym_POUNDif] = ACTIONS(6282),
    [anon_sym_POUNDIF] = ACTIONS(6282),
    [anon_sym_POUNDIf] = ACTIONS(6282),
    [anon_sym_not] = ACTIONS(6280),
    [anon_sym_NOT] = ACTIONS(6280),
    [anon_sym_Not] = ACTIONS(6280),
    [anon_sym_POUNDelse] = ACTIONS(6282),
    [anon_sym_POUNDELSE] = ACTIONS(6282),
    [anon_sym_POUNDElse] = ACTIONS(6282),
    [anon_sym_POUNDelse2] = ACTIONS(6282),
    [anon_sym_POUNDELSE2] = ACTIONS(6282),
    [anon_sym_POUNDElse2] = ACTIONS(6282),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6280),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6280),
    [anon_sym_PLUS] = ACTIONS(6282),
    [sym_datetime_literal] = ACTIONS(6282),
    [sym_date_literal] = ACTIONS(6280),
    [sym_time_literal] = ACTIONS(6280),
    [sym_biginteger_literal] = ACTIONS(6282),
    [anon_sym_if] = ACTIONS(6280),
    [anon_sym_IF] = ACTIONS(6280),
    [anon_sym_If] = ACTIONS(6280),
    [anon_sym_else] = ACTIONS(6280),
    [anon_sym_ELSE] = ACTIONS(6280),
    [anon_sym_Else] = ACTIONS(6280),
    [anon_sym_case] = ACTIONS(6280),
    [anon_sym_CASE] = ACTIONS(6280),
    [anon_sym_Case] = ACTIONS(6280),
    [anon_sym_for] = ACTIONS(6280),
    [anon_sym_FOR] = ACTIONS(6280),
    [anon_sym_For] = ACTIONS(6280),
    [anon_sym_foreach] = ACTIONS(6280),
    [anon_sym_FOREACH] = ACTIONS(6280),
    [anon_sym_Foreach] = ACTIONS(6280),
    [anon_sym_while] = ACTIONS(6280),
    [anon_sym_WHILE] = ACTIONS(6280),
    [anon_sym_While] = ACTIONS(6280),
    [anon_sym_repeat] = ACTIONS(6280),
    [anon_sym_REPEAT] = ACTIONS(6280),
    [anon_sym_Repeat] = ACTIONS(6280),
    [anon_sym_exit] = ACTIONS(6280),
    [anon_sym_EXIT] = ACTIONS(6280),
    [anon_sym_Exit] = ACTIONS(6280),
    [anon_sym_continue] = ACTIONS(6280),
    [anon_sym_CONTINUE] = ACTIONS(6280),
    [anon_sym_Continue] = ACTIONS(6280),
    [anon_sym_break] = ACTIONS(6280),
    [anon_sym_BREAK] = ACTIONS(6280),
    [anon_sym_Break] = ACTIONS(6280),
    [anon_sym_with] = ACTIONS(6280),
    [anon_sym_WITH] = ACTIONS(6280),
    [anon_sym_With] = ACTIONS(6280),
    [sym_asserterror_keyword] = ACTIONS(6282),
    [sym_page_keyword] = ACTIONS(6280),
    [anon_sym_codeunit] = ACTIONS(6280),
    [anon_sym_CODEUNIT] = ACTIONS(6280),
    [anon_sym_Codeunit] = ACTIONS(6280),
    [anon_sym_CodeUnit] = ACTIONS(6280),
    [anon_sym_COdeunit] = ACTIONS(6280),
    [anon_sym_codeUnit] = ACTIONS(6280),
    [sym_report_keyword] = ACTIONS(6280),
    [sym_query_keyword] = ACTIONS(6280),
    [anon_sym_xmlport] = ACTIONS(6280),
    [anon_sym_XMLPORT] = ACTIONS(6280),
    [anon_sym_Xmlport] = ACTIONS(6280),
    [anon_sym_XMLport] = ACTIONS(6280),
    [anon_sym_XMLPort] = ACTIONS(6280),
    [anon_sym_XmlPort] = ACTIONS(6280),
    [anon_sym_enum] = ACTIONS(6280),
    [anon_sym_ENUM] = ACTIONS(6280),
    [anon_sym_Enum] = ACTIONS(6280),
    [anon_sym_eNUM] = ACTIONS(6280),
    [anon_sym_eNum] = ACTIONS(6280),
    [anon_sym_ENum] = ACTIONS(6280),
    [sym_quoted_identifier] = ACTIONS(6282),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6282),
    [sym_verbatim_string] = ACTIONS(6282),
    [sym_integer] = ACTIONS(6280),
    [sym_continue_as_identifier] = ACTIONS(6282),
    [sym_preproc_open] = ACTIONS(6282),
    [sym_end_keyword] = ACTIONS(6282),
  },
  [STATE(3291)] = {
    [sym_identifier] = ACTIONS(5609),
    [anon_sym_SEMI] = ACTIONS(5611),
    [anon_sym_DASH] = ACTIONS(5611),
    [aux_sym_boolean_token1] = ACTIONS(5609),
    [aux_sym_boolean_token2] = ACTIONS(5609),
    [sym_decimal] = ACTIONS(5609),
    [anon_sym_LPAREN] = ACTIONS(5611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5609),
    [anon_sym_LBRACK] = ACTIONS(5611),
    [aux_sym_record_type_token1] = ACTIONS(5609),
    [aux_sym_basic_type_token21] = ACTIONS(5609),
    [aux_sym_basic_type_token22] = ACTIONS(5609),
    [aux_sym_basic_type_token48] = ACTIONS(5609),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5609),
    [anon_sym_POUNDif] = ACTIONS(5611),
    [anon_sym_POUNDIF] = ACTIONS(5611),
    [anon_sym_POUNDIf] = ACTIONS(5611),
    [anon_sym_not] = ACTIONS(5609),
    [anon_sym_NOT] = ACTIONS(5609),
    [anon_sym_Not] = ACTIONS(5609),
    [anon_sym_POUNDelse] = ACTIONS(5611),
    [anon_sym_POUNDELSE] = ACTIONS(5611),
    [anon_sym_POUNDElse] = ACTIONS(5611),
    [anon_sym_POUNDelse2] = ACTIONS(5611),
    [anon_sym_POUNDELSE2] = ACTIONS(5611),
    [anon_sym_POUNDElse2] = ACTIONS(5611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5609),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5609),
    [anon_sym_PLUS] = ACTIONS(5611),
    [sym_datetime_literal] = ACTIONS(5611),
    [sym_date_literal] = ACTIONS(5609),
    [sym_time_literal] = ACTIONS(5609),
    [sym_biginteger_literal] = ACTIONS(5611),
    [anon_sym_if] = ACTIONS(5609),
    [anon_sym_IF] = ACTIONS(5609),
    [anon_sym_If] = ACTIONS(5609),
    [anon_sym_else] = ACTIONS(5609),
    [anon_sym_ELSE] = ACTIONS(5609),
    [anon_sym_Else] = ACTIONS(5609),
    [anon_sym_case] = ACTIONS(5609),
    [anon_sym_CASE] = ACTIONS(5609),
    [anon_sym_Case] = ACTIONS(5609),
    [anon_sym_for] = ACTIONS(5609),
    [anon_sym_FOR] = ACTIONS(5609),
    [anon_sym_For] = ACTIONS(5609),
    [anon_sym_foreach] = ACTIONS(5609),
    [anon_sym_FOREACH] = ACTIONS(5609),
    [anon_sym_Foreach] = ACTIONS(5609),
    [anon_sym_while] = ACTIONS(5609),
    [anon_sym_WHILE] = ACTIONS(5609),
    [anon_sym_While] = ACTIONS(5609),
    [anon_sym_repeat] = ACTIONS(5609),
    [anon_sym_REPEAT] = ACTIONS(5609),
    [anon_sym_Repeat] = ACTIONS(5609),
    [anon_sym_exit] = ACTIONS(5609),
    [anon_sym_EXIT] = ACTIONS(5609),
    [anon_sym_Exit] = ACTIONS(5609),
    [anon_sym_continue] = ACTIONS(5609),
    [anon_sym_CONTINUE] = ACTIONS(5609),
    [anon_sym_Continue] = ACTIONS(5609),
    [anon_sym_break] = ACTIONS(5609),
    [anon_sym_BREAK] = ACTIONS(5609),
    [anon_sym_Break] = ACTIONS(5609),
    [anon_sym_with] = ACTIONS(5609),
    [anon_sym_WITH] = ACTIONS(5609),
    [anon_sym_With] = ACTIONS(5609),
    [sym_asserterror_keyword] = ACTIONS(5611),
    [sym_page_keyword] = ACTIONS(5609),
    [anon_sym_codeunit] = ACTIONS(5609),
    [anon_sym_CODEUNIT] = ACTIONS(5609),
    [anon_sym_Codeunit] = ACTIONS(5609),
    [anon_sym_CodeUnit] = ACTIONS(5609),
    [anon_sym_COdeunit] = ACTIONS(5609),
    [anon_sym_codeUnit] = ACTIONS(5609),
    [sym_report_keyword] = ACTIONS(5609),
    [sym_query_keyword] = ACTIONS(5609),
    [anon_sym_xmlport] = ACTIONS(5609),
    [anon_sym_XMLPORT] = ACTIONS(5609),
    [anon_sym_Xmlport] = ACTIONS(5609),
    [anon_sym_XMLport] = ACTIONS(5609),
    [anon_sym_XMLPort] = ACTIONS(5609),
    [anon_sym_XmlPort] = ACTIONS(5609),
    [anon_sym_enum] = ACTIONS(5609),
    [anon_sym_ENUM] = ACTIONS(5609),
    [anon_sym_Enum] = ACTIONS(5609),
    [anon_sym_eNUM] = ACTIONS(5609),
    [anon_sym_eNum] = ACTIONS(5609),
    [anon_sym_ENum] = ACTIONS(5609),
    [sym_quoted_identifier] = ACTIONS(5611),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5611),
    [sym_verbatim_string] = ACTIONS(5611),
    [sym_integer] = ACTIONS(5609),
    [sym_continue_as_identifier] = ACTIONS(5611),
    [sym_preproc_open] = ACTIONS(5611),
    [sym_end_keyword] = ACTIONS(5611),
  },
  [STATE(3292)] = {
    [sym_identifier] = ACTIONS(5789),
    [anon_sym_SEMI] = ACTIONS(7341),
    [anon_sym_DASH] = ACTIONS(5793),
    [aux_sym_boolean_token1] = ACTIONS(5789),
    [aux_sym_boolean_token2] = ACTIONS(5789),
    [sym_decimal] = ACTIONS(5789),
    [anon_sym_LPAREN] = ACTIONS(5793),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5789),
    [anon_sym_LBRACK] = ACTIONS(5793),
    [aux_sym_record_type_token1] = ACTIONS(5789),
    [aux_sym_basic_type_token21] = ACTIONS(5789),
    [aux_sym_basic_type_token22] = ACTIONS(5789),
    [aux_sym_basic_type_token48] = ACTIONS(5789),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5789),
    [anon_sym_POUNDif] = ACTIONS(5793),
    [anon_sym_POUNDIF] = ACTIONS(5793),
    [anon_sym_POUNDIf] = ACTIONS(5793),
    [anon_sym_not] = ACTIONS(5789),
    [anon_sym_NOT] = ACTIONS(5789),
    [anon_sym_Not] = ACTIONS(5789),
    [anon_sym_POUNDelse] = ACTIONS(5793),
    [anon_sym_POUNDELSE] = ACTIONS(5793),
    [anon_sym_POUNDElse] = ACTIONS(5793),
    [anon_sym_POUNDelse2] = ACTIONS(5793),
    [anon_sym_POUNDELSE2] = ACTIONS(5793),
    [anon_sym_POUNDElse2] = ACTIONS(5793),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5789),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5789),
    [anon_sym_PLUS] = ACTIONS(5793),
    [sym_datetime_literal] = ACTIONS(5793),
    [sym_date_literal] = ACTIONS(5789),
    [sym_time_literal] = ACTIONS(5789),
    [sym_biginteger_literal] = ACTIONS(5793),
    [anon_sym_if] = ACTIONS(5789),
    [anon_sym_IF] = ACTIONS(5789),
    [anon_sym_If] = ACTIONS(5789),
    [anon_sym_else] = ACTIONS(5789),
    [anon_sym_ELSE] = ACTIONS(5789),
    [anon_sym_Else] = ACTIONS(5789),
    [anon_sym_case] = ACTIONS(5789),
    [anon_sym_CASE] = ACTIONS(5789),
    [anon_sym_Case] = ACTIONS(5789),
    [anon_sym_for] = ACTIONS(5789),
    [anon_sym_FOR] = ACTIONS(5789),
    [anon_sym_For] = ACTIONS(5789),
    [anon_sym_foreach] = ACTIONS(5789),
    [anon_sym_FOREACH] = ACTIONS(5789),
    [anon_sym_Foreach] = ACTIONS(5789),
    [anon_sym_while] = ACTIONS(5789),
    [anon_sym_WHILE] = ACTIONS(5789),
    [anon_sym_While] = ACTIONS(5789),
    [anon_sym_repeat] = ACTIONS(5789),
    [anon_sym_REPEAT] = ACTIONS(5789),
    [anon_sym_Repeat] = ACTIONS(5789),
    [anon_sym_exit] = ACTIONS(5789),
    [anon_sym_EXIT] = ACTIONS(5789),
    [anon_sym_Exit] = ACTIONS(5789),
    [anon_sym_continue] = ACTIONS(5789),
    [anon_sym_CONTINUE] = ACTIONS(5789),
    [anon_sym_Continue] = ACTIONS(5789),
    [anon_sym_break] = ACTIONS(5789),
    [anon_sym_BREAK] = ACTIONS(5789),
    [anon_sym_Break] = ACTIONS(5789),
    [anon_sym_with] = ACTIONS(5789),
    [anon_sym_WITH] = ACTIONS(5789),
    [anon_sym_With] = ACTIONS(5789),
    [sym_asserterror_keyword] = ACTIONS(5793),
    [sym_page_keyword] = ACTIONS(5789),
    [anon_sym_codeunit] = ACTIONS(5789),
    [anon_sym_CODEUNIT] = ACTIONS(5789),
    [anon_sym_Codeunit] = ACTIONS(5789),
    [anon_sym_CodeUnit] = ACTIONS(5789),
    [anon_sym_COdeunit] = ACTIONS(5789),
    [anon_sym_codeUnit] = ACTIONS(5789),
    [sym_report_keyword] = ACTIONS(5789),
    [sym_query_keyword] = ACTIONS(5789),
    [anon_sym_xmlport] = ACTIONS(5789),
    [anon_sym_XMLPORT] = ACTIONS(5789),
    [anon_sym_Xmlport] = ACTIONS(5789),
    [anon_sym_XMLport] = ACTIONS(5789),
    [anon_sym_XMLPort] = ACTIONS(5789),
    [anon_sym_XmlPort] = ACTIONS(5789),
    [anon_sym_enum] = ACTIONS(5789),
    [anon_sym_ENUM] = ACTIONS(5789),
    [anon_sym_Enum] = ACTIONS(5789),
    [anon_sym_eNUM] = ACTIONS(5789),
    [anon_sym_eNum] = ACTIONS(5789),
    [anon_sym_ENum] = ACTIONS(5789),
    [sym_quoted_identifier] = ACTIONS(5793),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5793),
    [sym_verbatim_string] = ACTIONS(5793),
    [sym_integer] = ACTIONS(5789),
    [sym_continue_as_identifier] = ACTIONS(5793),
    [sym_preproc_open] = ACTIONS(5793),
    [sym_end_keyword] = ACTIONS(5793),
  },
  [STATE(3293)] = {
    [sym_identifier] = ACTIONS(5717),
    [anon_sym_SEMI] = ACTIONS(5719),
    [anon_sym_DASH] = ACTIONS(5719),
    [aux_sym_boolean_token1] = ACTIONS(5717),
    [aux_sym_boolean_token2] = ACTIONS(5717),
    [sym_decimal] = ACTIONS(5717),
    [anon_sym_LPAREN] = ACTIONS(5719),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5717),
    [anon_sym_LBRACK] = ACTIONS(5719),
    [aux_sym_record_type_token1] = ACTIONS(5717),
    [aux_sym_basic_type_token21] = ACTIONS(5717),
    [aux_sym_basic_type_token22] = ACTIONS(5717),
    [aux_sym_basic_type_token48] = ACTIONS(5717),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5717),
    [anon_sym_POUNDif] = ACTIONS(5719),
    [anon_sym_POUNDIF] = ACTIONS(5719),
    [anon_sym_POUNDIf] = ACTIONS(5719),
    [anon_sym_not] = ACTIONS(5717),
    [anon_sym_NOT] = ACTIONS(5717),
    [anon_sym_Not] = ACTIONS(5717),
    [anon_sym_POUNDelse] = ACTIONS(5719),
    [anon_sym_POUNDELSE] = ACTIONS(5719),
    [anon_sym_POUNDElse] = ACTIONS(5719),
    [anon_sym_POUNDelse2] = ACTIONS(5719),
    [anon_sym_POUNDELSE2] = ACTIONS(5719),
    [anon_sym_POUNDElse2] = ACTIONS(5719),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5717),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5717),
    [anon_sym_PLUS] = ACTIONS(5719),
    [sym_datetime_literal] = ACTIONS(5719),
    [sym_date_literal] = ACTIONS(5717),
    [sym_time_literal] = ACTIONS(5717),
    [sym_biginteger_literal] = ACTIONS(5719),
    [anon_sym_if] = ACTIONS(5717),
    [anon_sym_IF] = ACTIONS(5717),
    [anon_sym_If] = ACTIONS(5717),
    [anon_sym_else] = ACTIONS(5717),
    [anon_sym_ELSE] = ACTIONS(5717),
    [anon_sym_Else] = ACTIONS(5717),
    [anon_sym_case] = ACTIONS(5717),
    [anon_sym_CASE] = ACTIONS(5717),
    [anon_sym_Case] = ACTIONS(5717),
    [anon_sym_for] = ACTIONS(5717),
    [anon_sym_FOR] = ACTIONS(5717),
    [anon_sym_For] = ACTIONS(5717),
    [anon_sym_foreach] = ACTIONS(5717),
    [anon_sym_FOREACH] = ACTIONS(5717),
    [anon_sym_Foreach] = ACTIONS(5717),
    [anon_sym_while] = ACTIONS(5717),
    [anon_sym_WHILE] = ACTIONS(5717),
    [anon_sym_While] = ACTIONS(5717),
    [anon_sym_repeat] = ACTIONS(5717),
    [anon_sym_REPEAT] = ACTIONS(5717),
    [anon_sym_Repeat] = ACTIONS(5717),
    [anon_sym_exit] = ACTIONS(5717),
    [anon_sym_EXIT] = ACTIONS(5717),
    [anon_sym_Exit] = ACTIONS(5717),
    [anon_sym_continue] = ACTIONS(5717),
    [anon_sym_CONTINUE] = ACTIONS(5717),
    [anon_sym_Continue] = ACTIONS(5717),
    [anon_sym_break] = ACTIONS(5717),
    [anon_sym_BREAK] = ACTIONS(5717),
    [anon_sym_Break] = ACTIONS(5717),
    [anon_sym_with] = ACTIONS(5717),
    [anon_sym_WITH] = ACTIONS(5717),
    [anon_sym_With] = ACTIONS(5717),
    [sym_asserterror_keyword] = ACTIONS(5719),
    [sym_page_keyword] = ACTIONS(5717),
    [anon_sym_codeunit] = ACTIONS(5717),
    [anon_sym_CODEUNIT] = ACTIONS(5717),
    [anon_sym_Codeunit] = ACTIONS(5717),
    [anon_sym_CodeUnit] = ACTIONS(5717),
    [anon_sym_COdeunit] = ACTIONS(5717),
    [anon_sym_codeUnit] = ACTIONS(5717),
    [sym_report_keyword] = ACTIONS(5717),
    [sym_query_keyword] = ACTIONS(5717),
    [anon_sym_xmlport] = ACTIONS(5717),
    [anon_sym_XMLPORT] = ACTIONS(5717),
    [anon_sym_Xmlport] = ACTIONS(5717),
    [anon_sym_XMLport] = ACTIONS(5717),
    [anon_sym_XMLPort] = ACTIONS(5717),
    [anon_sym_XmlPort] = ACTIONS(5717),
    [anon_sym_enum] = ACTIONS(5717),
    [anon_sym_ENUM] = ACTIONS(5717),
    [anon_sym_Enum] = ACTIONS(5717),
    [anon_sym_eNUM] = ACTIONS(5717),
    [anon_sym_eNum] = ACTIONS(5717),
    [anon_sym_ENum] = ACTIONS(5717),
    [sym_quoted_identifier] = ACTIONS(5719),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5719),
    [sym_verbatim_string] = ACTIONS(5719),
    [sym_integer] = ACTIONS(5717),
    [sym_continue_as_identifier] = ACTIONS(5719),
    [sym_preproc_open] = ACTIONS(5719),
    [sym_end_keyword] = ACTIONS(5719),
  },
  [STATE(3294)] = {
    [sym_identifier] = ACTIONS(5721),
    [anon_sym_SEMI] = ACTIONS(5723),
    [anon_sym_DASH] = ACTIONS(5723),
    [aux_sym_boolean_token1] = ACTIONS(5721),
    [aux_sym_boolean_token2] = ACTIONS(5721),
    [sym_decimal] = ACTIONS(5721),
    [anon_sym_LPAREN] = ACTIONS(5723),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5721),
    [anon_sym_LBRACK] = ACTIONS(5723),
    [aux_sym_record_type_token1] = ACTIONS(5721),
    [aux_sym_basic_type_token21] = ACTIONS(5721),
    [aux_sym_basic_type_token22] = ACTIONS(5721),
    [aux_sym_basic_type_token48] = ACTIONS(5721),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5721),
    [anon_sym_POUNDif] = ACTIONS(5723),
    [anon_sym_POUNDIF] = ACTIONS(5723),
    [anon_sym_POUNDIf] = ACTIONS(5723),
    [anon_sym_not] = ACTIONS(5721),
    [anon_sym_NOT] = ACTIONS(5721),
    [anon_sym_Not] = ACTIONS(5721),
    [anon_sym_POUNDelse] = ACTIONS(5723),
    [anon_sym_POUNDELSE] = ACTIONS(5723),
    [anon_sym_POUNDElse] = ACTIONS(5723),
    [anon_sym_POUNDelse2] = ACTIONS(5723),
    [anon_sym_POUNDELSE2] = ACTIONS(5723),
    [anon_sym_POUNDElse2] = ACTIONS(5723),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5721),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5721),
    [anon_sym_PLUS] = ACTIONS(5723),
    [sym_datetime_literal] = ACTIONS(5723),
    [sym_date_literal] = ACTIONS(5721),
    [sym_time_literal] = ACTIONS(5721),
    [sym_biginteger_literal] = ACTIONS(5723),
    [anon_sym_if] = ACTIONS(5721),
    [anon_sym_IF] = ACTIONS(5721),
    [anon_sym_If] = ACTIONS(5721),
    [anon_sym_else] = ACTIONS(5721),
    [anon_sym_ELSE] = ACTIONS(5721),
    [anon_sym_Else] = ACTIONS(5721),
    [anon_sym_case] = ACTIONS(5721),
    [anon_sym_CASE] = ACTIONS(5721),
    [anon_sym_Case] = ACTIONS(5721),
    [anon_sym_for] = ACTIONS(5721),
    [anon_sym_FOR] = ACTIONS(5721),
    [anon_sym_For] = ACTIONS(5721),
    [anon_sym_foreach] = ACTIONS(5721),
    [anon_sym_FOREACH] = ACTIONS(5721),
    [anon_sym_Foreach] = ACTIONS(5721),
    [anon_sym_while] = ACTIONS(5721),
    [anon_sym_WHILE] = ACTIONS(5721),
    [anon_sym_While] = ACTIONS(5721),
    [anon_sym_repeat] = ACTIONS(5721),
    [anon_sym_REPEAT] = ACTIONS(5721),
    [anon_sym_Repeat] = ACTIONS(5721),
    [anon_sym_exit] = ACTIONS(5721),
    [anon_sym_EXIT] = ACTIONS(5721),
    [anon_sym_Exit] = ACTIONS(5721),
    [anon_sym_continue] = ACTIONS(5721),
    [anon_sym_CONTINUE] = ACTIONS(5721),
    [anon_sym_Continue] = ACTIONS(5721),
    [anon_sym_break] = ACTIONS(5721),
    [anon_sym_BREAK] = ACTIONS(5721),
    [anon_sym_Break] = ACTIONS(5721),
    [anon_sym_with] = ACTIONS(5721),
    [anon_sym_WITH] = ACTIONS(5721),
    [anon_sym_With] = ACTIONS(5721),
    [sym_asserterror_keyword] = ACTIONS(5723),
    [sym_page_keyword] = ACTIONS(5721),
    [anon_sym_codeunit] = ACTIONS(5721),
    [anon_sym_CODEUNIT] = ACTIONS(5721),
    [anon_sym_Codeunit] = ACTIONS(5721),
    [anon_sym_CodeUnit] = ACTIONS(5721),
    [anon_sym_COdeunit] = ACTIONS(5721),
    [anon_sym_codeUnit] = ACTIONS(5721),
    [sym_report_keyword] = ACTIONS(5721),
    [sym_query_keyword] = ACTIONS(5721),
    [anon_sym_xmlport] = ACTIONS(5721),
    [anon_sym_XMLPORT] = ACTIONS(5721),
    [anon_sym_Xmlport] = ACTIONS(5721),
    [anon_sym_XMLport] = ACTIONS(5721),
    [anon_sym_XMLPort] = ACTIONS(5721),
    [anon_sym_XmlPort] = ACTIONS(5721),
    [anon_sym_enum] = ACTIONS(5721),
    [anon_sym_ENUM] = ACTIONS(5721),
    [anon_sym_Enum] = ACTIONS(5721),
    [anon_sym_eNUM] = ACTIONS(5721),
    [anon_sym_eNum] = ACTIONS(5721),
    [anon_sym_ENum] = ACTIONS(5721),
    [sym_quoted_identifier] = ACTIONS(5723),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5723),
    [sym_verbatim_string] = ACTIONS(5723),
    [sym_integer] = ACTIONS(5721),
    [sym_continue_as_identifier] = ACTIONS(5723),
    [sym_preproc_open] = ACTIONS(5723),
    [sym_end_keyword] = ACTIONS(5723),
  },
  [STATE(3295)] = {
    [sym_identifier] = ACTIONS(5725),
    [anon_sym_SEMI] = ACTIONS(5727),
    [anon_sym_DASH] = ACTIONS(5727),
    [aux_sym_boolean_token1] = ACTIONS(5725),
    [aux_sym_boolean_token2] = ACTIONS(5725),
    [sym_decimal] = ACTIONS(5725),
    [anon_sym_LPAREN] = ACTIONS(5727),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5725),
    [anon_sym_LBRACK] = ACTIONS(5727),
    [aux_sym_record_type_token1] = ACTIONS(5725),
    [aux_sym_basic_type_token21] = ACTIONS(5725),
    [aux_sym_basic_type_token22] = ACTIONS(5725),
    [aux_sym_basic_type_token48] = ACTIONS(5725),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5725),
    [anon_sym_POUNDif] = ACTIONS(5727),
    [anon_sym_POUNDIF] = ACTIONS(5727),
    [anon_sym_POUNDIf] = ACTIONS(5727),
    [anon_sym_not] = ACTIONS(5725),
    [anon_sym_NOT] = ACTIONS(5725),
    [anon_sym_Not] = ACTIONS(5725),
    [anon_sym_POUNDelse] = ACTIONS(5727),
    [anon_sym_POUNDELSE] = ACTIONS(5727),
    [anon_sym_POUNDElse] = ACTIONS(5727),
    [anon_sym_POUNDelse2] = ACTIONS(5727),
    [anon_sym_POUNDELSE2] = ACTIONS(5727),
    [anon_sym_POUNDElse2] = ACTIONS(5727),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5725),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5725),
    [anon_sym_PLUS] = ACTIONS(5727),
    [sym_datetime_literal] = ACTIONS(5727),
    [sym_date_literal] = ACTIONS(5725),
    [sym_time_literal] = ACTIONS(5725),
    [sym_biginteger_literal] = ACTIONS(5727),
    [anon_sym_if] = ACTIONS(5725),
    [anon_sym_IF] = ACTIONS(5725),
    [anon_sym_If] = ACTIONS(5725),
    [anon_sym_else] = ACTIONS(5725),
    [anon_sym_ELSE] = ACTIONS(5725),
    [anon_sym_Else] = ACTIONS(5725),
    [anon_sym_case] = ACTIONS(5725),
    [anon_sym_CASE] = ACTIONS(5725),
    [anon_sym_Case] = ACTIONS(5725),
    [anon_sym_for] = ACTIONS(5725),
    [anon_sym_FOR] = ACTIONS(5725),
    [anon_sym_For] = ACTIONS(5725),
    [anon_sym_foreach] = ACTIONS(5725),
    [anon_sym_FOREACH] = ACTIONS(5725),
    [anon_sym_Foreach] = ACTIONS(5725),
    [anon_sym_while] = ACTIONS(5725),
    [anon_sym_WHILE] = ACTIONS(5725),
    [anon_sym_While] = ACTIONS(5725),
    [anon_sym_repeat] = ACTIONS(5725),
    [anon_sym_REPEAT] = ACTIONS(5725),
    [anon_sym_Repeat] = ACTIONS(5725),
    [anon_sym_exit] = ACTIONS(5725),
    [anon_sym_EXIT] = ACTIONS(5725),
    [anon_sym_Exit] = ACTIONS(5725),
    [anon_sym_continue] = ACTIONS(5725),
    [anon_sym_CONTINUE] = ACTIONS(5725),
    [anon_sym_Continue] = ACTIONS(5725),
    [anon_sym_break] = ACTIONS(5725),
    [anon_sym_BREAK] = ACTIONS(5725),
    [anon_sym_Break] = ACTIONS(5725),
    [anon_sym_with] = ACTIONS(5725),
    [anon_sym_WITH] = ACTIONS(5725),
    [anon_sym_With] = ACTIONS(5725),
    [sym_asserterror_keyword] = ACTIONS(5727),
    [sym_page_keyword] = ACTIONS(5725),
    [anon_sym_codeunit] = ACTIONS(5725),
    [anon_sym_CODEUNIT] = ACTIONS(5725),
    [anon_sym_Codeunit] = ACTIONS(5725),
    [anon_sym_CodeUnit] = ACTIONS(5725),
    [anon_sym_COdeunit] = ACTIONS(5725),
    [anon_sym_codeUnit] = ACTIONS(5725),
    [sym_report_keyword] = ACTIONS(5725),
    [sym_query_keyword] = ACTIONS(5725),
    [anon_sym_xmlport] = ACTIONS(5725),
    [anon_sym_XMLPORT] = ACTIONS(5725),
    [anon_sym_Xmlport] = ACTIONS(5725),
    [anon_sym_XMLport] = ACTIONS(5725),
    [anon_sym_XMLPort] = ACTIONS(5725),
    [anon_sym_XmlPort] = ACTIONS(5725),
    [anon_sym_enum] = ACTIONS(5725),
    [anon_sym_ENUM] = ACTIONS(5725),
    [anon_sym_Enum] = ACTIONS(5725),
    [anon_sym_eNUM] = ACTIONS(5725),
    [anon_sym_eNum] = ACTIONS(5725),
    [anon_sym_ENum] = ACTIONS(5725),
    [sym_quoted_identifier] = ACTIONS(5727),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5727),
    [sym_verbatim_string] = ACTIONS(5727),
    [sym_integer] = ACTIONS(5725),
    [sym_continue_as_identifier] = ACTIONS(5727),
    [sym_preproc_open] = ACTIONS(5727),
    [sym_end_keyword] = ACTIONS(5727),
  },
  [STATE(3296)] = {
    [sym_identifier] = ACTIONS(5729),
    [anon_sym_SEMI] = ACTIONS(5731),
    [anon_sym_DASH] = ACTIONS(5731),
    [aux_sym_boolean_token1] = ACTIONS(5729),
    [aux_sym_boolean_token2] = ACTIONS(5729),
    [sym_decimal] = ACTIONS(5729),
    [anon_sym_LPAREN] = ACTIONS(5731),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5729),
    [anon_sym_LBRACK] = ACTIONS(5731),
    [aux_sym_record_type_token1] = ACTIONS(5729),
    [aux_sym_basic_type_token21] = ACTIONS(5729),
    [aux_sym_basic_type_token22] = ACTIONS(5729),
    [aux_sym_basic_type_token48] = ACTIONS(5729),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5729),
    [anon_sym_POUNDif] = ACTIONS(5731),
    [anon_sym_POUNDIF] = ACTIONS(5731),
    [anon_sym_POUNDIf] = ACTIONS(5731),
    [anon_sym_not] = ACTIONS(5729),
    [anon_sym_NOT] = ACTIONS(5729),
    [anon_sym_Not] = ACTIONS(5729),
    [anon_sym_POUNDelse] = ACTIONS(5731),
    [anon_sym_POUNDELSE] = ACTIONS(5731),
    [anon_sym_POUNDElse] = ACTIONS(5731),
    [anon_sym_POUNDelse2] = ACTIONS(5731),
    [anon_sym_POUNDELSE2] = ACTIONS(5731),
    [anon_sym_POUNDElse2] = ACTIONS(5731),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5729),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5729),
    [anon_sym_PLUS] = ACTIONS(5731),
    [sym_datetime_literal] = ACTIONS(5731),
    [sym_date_literal] = ACTIONS(5729),
    [sym_time_literal] = ACTIONS(5729),
    [sym_biginteger_literal] = ACTIONS(5731),
    [anon_sym_if] = ACTIONS(5729),
    [anon_sym_IF] = ACTIONS(5729),
    [anon_sym_If] = ACTIONS(5729),
    [anon_sym_else] = ACTIONS(5729),
    [anon_sym_ELSE] = ACTIONS(5729),
    [anon_sym_Else] = ACTIONS(5729),
    [anon_sym_case] = ACTIONS(5729),
    [anon_sym_CASE] = ACTIONS(5729),
    [anon_sym_Case] = ACTIONS(5729),
    [anon_sym_for] = ACTIONS(5729),
    [anon_sym_FOR] = ACTIONS(5729),
    [anon_sym_For] = ACTIONS(5729),
    [anon_sym_foreach] = ACTIONS(5729),
    [anon_sym_FOREACH] = ACTIONS(5729),
    [anon_sym_Foreach] = ACTIONS(5729),
    [anon_sym_while] = ACTIONS(5729),
    [anon_sym_WHILE] = ACTIONS(5729),
    [anon_sym_While] = ACTIONS(5729),
    [anon_sym_repeat] = ACTIONS(5729),
    [anon_sym_REPEAT] = ACTIONS(5729),
    [anon_sym_Repeat] = ACTIONS(5729),
    [anon_sym_exit] = ACTIONS(5729),
    [anon_sym_EXIT] = ACTIONS(5729),
    [anon_sym_Exit] = ACTIONS(5729),
    [anon_sym_continue] = ACTIONS(5729),
    [anon_sym_CONTINUE] = ACTIONS(5729),
    [anon_sym_Continue] = ACTIONS(5729),
    [anon_sym_break] = ACTIONS(5729),
    [anon_sym_BREAK] = ACTIONS(5729),
    [anon_sym_Break] = ACTIONS(5729),
    [anon_sym_with] = ACTIONS(5729),
    [anon_sym_WITH] = ACTIONS(5729),
    [anon_sym_With] = ACTIONS(5729),
    [sym_asserterror_keyword] = ACTIONS(5731),
    [sym_page_keyword] = ACTIONS(5729),
    [anon_sym_codeunit] = ACTIONS(5729),
    [anon_sym_CODEUNIT] = ACTIONS(5729),
    [anon_sym_Codeunit] = ACTIONS(5729),
    [anon_sym_CodeUnit] = ACTIONS(5729),
    [anon_sym_COdeunit] = ACTIONS(5729),
    [anon_sym_codeUnit] = ACTIONS(5729),
    [sym_report_keyword] = ACTIONS(5729),
    [sym_query_keyword] = ACTIONS(5729),
    [anon_sym_xmlport] = ACTIONS(5729),
    [anon_sym_XMLPORT] = ACTIONS(5729),
    [anon_sym_Xmlport] = ACTIONS(5729),
    [anon_sym_XMLport] = ACTIONS(5729),
    [anon_sym_XMLPort] = ACTIONS(5729),
    [anon_sym_XmlPort] = ACTIONS(5729),
    [anon_sym_enum] = ACTIONS(5729),
    [anon_sym_ENUM] = ACTIONS(5729),
    [anon_sym_Enum] = ACTIONS(5729),
    [anon_sym_eNUM] = ACTIONS(5729),
    [anon_sym_eNum] = ACTIONS(5729),
    [anon_sym_ENum] = ACTIONS(5729),
    [sym_quoted_identifier] = ACTIONS(5731),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5731),
    [sym_verbatim_string] = ACTIONS(5731),
    [sym_integer] = ACTIONS(5729),
    [sym_continue_as_identifier] = ACTIONS(5731),
    [sym_preproc_open] = ACTIONS(5731),
    [sym_end_keyword] = ACTIONS(5731),
  },
  [STATE(3297)] = {
    [sym_identifier] = ACTIONS(5733),
    [anon_sym_SEMI] = ACTIONS(5735),
    [anon_sym_DASH] = ACTIONS(5735),
    [aux_sym_boolean_token1] = ACTIONS(5733),
    [aux_sym_boolean_token2] = ACTIONS(5733),
    [sym_decimal] = ACTIONS(5733),
    [anon_sym_LPAREN] = ACTIONS(5735),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5733),
    [anon_sym_LBRACK] = ACTIONS(5735),
    [aux_sym_record_type_token1] = ACTIONS(5733),
    [aux_sym_basic_type_token21] = ACTIONS(5733),
    [aux_sym_basic_type_token22] = ACTIONS(5733),
    [aux_sym_basic_type_token48] = ACTIONS(5733),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5733),
    [anon_sym_POUNDif] = ACTIONS(5735),
    [anon_sym_POUNDIF] = ACTIONS(5735),
    [anon_sym_POUNDIf] = ACTIONS(5735),
    [anon_sym_not] = ACTIONS(5733),
    [anon_sym_NOT] = ACTIONS(5733),
    [anon_sym_Not] = ACTIONS(5733),
    [anon_sym_POUNDelse] = ACTIONS(5735),
    [anon_sym_POUNDELSE] = ACTIONS(5735),
    [anon_sym_POUNDElse] = ACTIONS(5735),
    [anon_sym_POUNDelse2] = ACTIONS(5735),
    [anon_sym_POUNDELSE2] = ACTIONS(5735),
    [anon_sym_POUNDElse2] = ACTIONS(5735),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5733),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5733),
    [anon_sym_PLUS] = ACTIONS(5735),
    [sym_datetime_literal] = ACTIONS(5735),
    [sym_date_literal] = ACTIONS(5733),
    [sym_time_literal] = ACTIONS(5733),
    [sym_biginteger_literal] = ACTIONS(5735),
    [anon_sym_if] = ACTIONS(5733),
    [anon_sym_IF] = ACTIONS(5733),
    [anon_sym_If] = ACTIONS(5733),
    [anon_sym_else] = ACTIONS(5733),
    [anon_sym_ELSE] = ACTIONS(5733),
    [anon_sym_Else] = ACTIONS(5733),
    [anon_sym_case] = ACTIONS(5733),
    [anon_sym_CASE] = ACTIONS(5733),
    [anon_sym_Case] = ACTIONS(5733),
    [anon_sym_for] = ACTIONS(5733),
    [anon_sym_FOR] = ACTIONS(5733),
    [anon_sym_For] = ACTIONS(5733),
    [anon_sym_foreach] = ACTIONS(5733),
    [anon_sym_FOREACH] = ACTIONS(5733),
    [anon_sym_Foreach] = ACTIONS(5733),
    [anon_sym_while] = ACTIONS(5733),
    [anon_sym_WHILE] = ACTIONS(5733),
    [anon_sym_While] = ACTIONS(5733),
    [anon_sym_repeat] = ACTIONS(5733),
    [anon_sym_REPEAT] = ACTIONS(5733),
    [anon_sym_Repeat] = ACTIONS(5733),
    [anon_sym_exit] = ACTIONS(5733),
    [anon_sym_EXIT] = ACTIONS(5733),
    [anon_sym_Exit] = ACTIONS(5733),
    [anon_sym_continue] = ACTIONS(5733),
    [anon_sym_CONTINUE] = ACTIONS(5733),
    [anon_sym_Continue] = ACTIONS(5733),
    [anon_sym_break] = ACTIONS(5733),
    [anon_sym_BREAK] = ACTIONS(5733),
    [anon_sym_Break] = ACTIONS(5733),
    [anon_sym_with] = ACTIONS(5733),
    [anon_sym_WITH] = ACTIONS(5733),
    [anon_sym_With] = ACTIONS(5733),
    [sym_asserterror_keyword] = ACTIONS(5735),
    [sym_page_keyword] = ACTIONS(5733),
    [anon_sym_codeunit] = ACTIONS(5733),
    [anon_sym_CODEUNIT] = ACTIONS(5733),
    [anon_sym_Codeunit] = ACTIONS(5733),
    [anon_sym_CodeUnit] = ACTIONS(5733),
    [anon_sym_COdeunit] = ACTIONS(5733),
    [anon_sym_codeUnit] = ACTIONS(5733),
    [sym_report_keyword] = ACTIONS(5733),
    [sym_query_keyword] = ACTIONS(5733),
    [anon_sym_xmlport] = ACTIONS(5733),
    [anon_sym_XMLPORT] = ACTIONS(5733),
    [anon_sym_Xmlport] = ACTIONS(5733),
    [anon_sym_XMLport] = ACTIONS(5733),
    [anon_sym_XMLPort] = ACTIONS(5733),
    [anon_sym_XmlPort] = ACTIONS(5733),
    [anon_sym_enum] = ACTIONS(5733),
    [anon_sym_ENUM] = ACTIONS(5733),
    [anon_sym_Enum] = ACTIONS(5733),
    [anon_sym_eNUM] = ACTIONS(5733),
    [anon_sym_eNum] = ACTIONS(5733),
    [anon_sym_ENum] = ACTIONS(5733),
    [sym_quoted_identifier] = ACTIONS(5735),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5735),
    [sym_verbatim_string] = ACTIONS(5735),
    [sym_integer] = ACTIONS(5733),
    [sym_continue_as_identifier] = ACTIONS(5735),
    [sym_preproc_open] = ACTIONS(5735),
    [sym_end_keyword] = ACTIONS(5735),
  },
  [STATE(3298)] = {
    [sym_identifier] = ACTIONS(5737),
    [anon_sym_SEMI] = ACTIONS(5739),
    [anon_sym_DASH] = ACTIONS(5739),
    [aux_sym_boolean_token1] = ACTIONS(5737),
    [aux_sym_boolean_token2] = ACTIONS(5737),
    [sym_decimal] = ACTIONS(5737),
    [anon_sym_LPAREN] = ACTIONS(5739),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5737),
    [anon_sym_LBRACK] = ACTIONS(5739),
    [aux_sym_record_type_token1] = ACTIONS(5737),
    [aux_sym_basic_type_token21] = ACTIONS(5737),
    [aux_sym_basic_type_token22] = ACTIONS(5737),
    [aux_sym_basic_type_token48] = ACTIONS(5737),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5737),
    [anon_sym_POUNDif] = ACTIONS(5739),
    [anon_sym_POUNDIF] = ACTIONS(5739),
    [anon_sym_POUNDIf] = ACTIONS(5739),
    [anon_sym_not] = ACTIONS(5737),
    [anon_sym_NOT] = ACTIONS(5737),
    [anon_sym_Not] = ACTIONS(5737),
    [anon_sym_POUNDelse] = ACTIONS(5739),
    [anon_sym_POUNDELSE] = ACTIONS(5739),
    [anon_sym_POUNDElse] = ACTIONS(5739),
    [anon_sym_POUNDelse2] = ACTIONS(5739),
    [anon_sym_POUNDELSE2] = ACTIONS(5739),
    [anon_sym_POUNDElse2] = ACTIONS(5739),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5737),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5737),
    [anon_sym_PLUS] = ACTIONS(5739),
    [sym_datetime_literal] = ACTIONS(5739),
    [sym_date_literal] = ACTIONS(5737),
    [sym_time_literal] = ACTIONS(5737),
    [sym_biginteger_literal] = ACTIONS(5739),
    [anon_sym_if] = ACTIONS(5737),
    [anon_sym_IF] = ACTIONS(5737),
    [anon_sym_If] = ACTIONS(5737),
    [anon_sym_else] = ACTIONS(5737),
    [anon_sym_ELSE] = ACTIONS(5737),
    [anon_sym_Else] = ACTIONS(5737),
    [anon_sym_case] = ACTIONS(5737),
    [anon_sym_CASE] = ACTIONS(5737),
    [anon_sym_Case] = ACTIONS(5737),
    [anon_sym_for] = ACTIONS(5737),
    [anon_sym_FOR] = ACTIONS(5737),
    [anon_sym_For] = ACTIONS(5737),
    [anon_sym_foreach] = ACTIONS(5737),
    [anon_sym_FOREACH] = ACTIONS(5737),
    [anon_sym_Foreach] = ACTIONS(5737),
    [anon_sym_while] = ACTIONS(5737),
    [anon_sym_WHILE] = ACTIONS(5737),
    [anon_sym_While] = ACTIONS(5737),
    [anon_sym_repeat] = ACTIONS(5737),
    [anon_sym_REPEAT] = ACTIONS(5737),
    [anon_sym_Repeat] = ACTIONS(5737),
    [anon_sym_exit] = ACTIONS(5737),
    [anon_sym_EXIT] = ACTIONS(5737),
    [anon_sym_Exit] = ACTIONS(5737),
    [anon_sym_continue] = ACTIONS(5737),
    [anon_sym_CONTINUE] = ACTIONS(5737),
    [anon_sym_Continue] = ACTIONS(5737),
    [anon_sym_break] = ACTIONS(5737),
    [anon_sym_BREAK] = ACTIONS(5737),
    [anon_sym_Break] = ACTIONS(5737),
    [anon_sym_with] = ACTIONS(5737),
    [anon_sym_WITH] = ACTIONS(5737),
    [anon_sym_With] = ACTIONS(5737),
    [sym_asserterror_keyword] = ACTIONS(5739),
    [sym_page_keyword] = ACTIONS(5737),
    [anon_sym_codeunit] = ACTIONS(5737),
    [anon_sym_CODEUNIT] = ACTIONS(5737),
    [anon_sym_Codeunit] = ACTIONS(5737),
    [anon_sym_CodeUnit] = ACTIONS(5737),
    [anon_sym_COdeunit] = ACTIONS(5737),
    [anon_sym_codeUnit] = ACTIONS(5737),
    [sym_report_keyword] = ACTIONS(5737),
    [sym_query_keyword] = ACTIONS(5737),
    [anon_sym_xmlport] = ACTIONS(5737),
    [anon_sym_XMLPORT] = ACTIONS(5737),
    [anon_sym_Xmlport] = ACTIONS(5737),
    [anon_sym_XMLport] = ACTIONS(5737),
    [anon_sym_XMLPort] = ACTIONS(5737),
    [anon_sym_XmlPort] = ACTIONS(5737),
    [anon_sym_enum] = ACTIONS(5737),
    [anon_sym_ENUM] = ACTIONS(5737),
    [anon_sym_Enum] = ACTIONS(5737),
    [anon_sym_eNUM] = ACTIONS(5737),
    [anon_sym_eNum] = ACTIONS(5737),
    [anon_sym_ENum] = ACTIONS(5737),
    [sym_quoted_identifier] = ACTIONS(5739),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5739),
    [sym_verbatim_string] = ACTIONS(5739),
    [sym_integer] = ACTIONS(5737),
    [sym_continue_as_identifier] = ACTIONS(5739),
    [sym_preproc_open] = ACTIONS(5739),
    [sym_end_keyword] = ACTIONS(5739),
  },
  [STATE(3299)] = {
    [sym_identifier] = ACTIONS(6018),
    [anon_sym_SEMI] = ACTIONS(6020),
    [anon_sym_DASH] = ACTIONS(6020),
    [aux_sym_boolean_token1] = ACTIONS(6018),
    [aux_sym_boolean_token2] = ACTIONS(6018),
    [sym_decimal] = ACTIONS(6018),
    [anon_sym_LPAREN] = ACTIONS(6020),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6018),
    [anon_sym_LBRACK] = ACTIONS(6020),
    [aux_sym_record_type_token1] = ACTIONS(6018),
    [aux_sym_basic_type_token21] = ACTIONS(6018),
    [aux_sym_basic_type_token22] = ACTIONS(6018),
    [aux_sym_basic_type_token48] = ACTIONS(6018),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6018),
    [anon_sym_POUNDif] = ACTIONS(6020),
    [anon_sym_POUNDIF] = ACTIONS(6020),
    [anon_sym_POUNDIf] = ACTIONS(6020),
    [anon_sym_not] = ACTIONS(6018),
    [anon_sym_NOT] = ACTIONS(6018),
    [anon_sym_Not] = ACTIONS(6018),
    [anon_sym_POUNDelse] = ACTIONS(6020),
    [anon_sym_POUNDELSE] = ACTIONS(6020),
    [anon_sym_POUNDElse] = ACTIONS(6020),
    [anon_sym_POUNDelse2] = ACTIONS(6020),
    [anon_sym_POUNDELSE2] = ACTIONS(6020),
    [anon_sym_POUNDElse2] = ACTIONS(6020),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6018),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6018),
    [anon_sym_PLUS] = ACTIONS(6020),
    [sym_datetime_literal] = ACTIONS(6020),
    [sym_date_literal] = ACTIONS(6018),
    [sym_time_literal] = ACTIONS(6018),
    [sym_biginteger_literal] = ACTIONS(6020),
    [anon_sym_if] = ACTIONS(6018),
    [anon_sym_IF] = ACTIONS(6018),
    [anon_sym_If] = ACTIONS(6018),
    [anon_sym_else] = ACTIONS(6018),
    [anon_sym_ELSE] = ACTIONS(6018),
    [anon_sym_Else] = ACTIONS(6018),
    [anon_sym_case] = ACTIONS(6018),
    [anon_sym_CASE] = ACTIONS(6018),
    [anon_sym_Case] = ACTIONS(6018),
    [anon_sym_for] = ACTIONS(6018),
    [anon_sym_FOR] = ACTIONS(6018),
    [anon_sym_For] = ACTIONS(6018),
    [anon_sym_foreach] = ACTIONS(6018),
    [anon_sym_FOREACH] = ACTIONS(6018),
    [anon_sym_Foreach] = ACTIONS(6018),
    [anon_sym_while] = ACTIONS(6018),
    [anon_sym_WHILE] = ACTIONS(6018),
    [anon_sym_While] = ACTIONS(6018),
    [anon_sym_repeat] = ACTIONS(6018),
    [anon_sym_REPEAT] = ACTIONS(6018),
    [anon_sym_Repeat] = ACTIONS(6018),
    [anon_sym_exit] = ACTIONS(6018),
    [anon_sym_EXIT] = ACTIONS(6018),
    [anon_sym_Exit] = ACTIONS(6018),
    [anon_sym_continue] = ACTIONS(6018),
    [anon_sym_CONTINUE] = ACTIONS(6018),
    [anon_sym_Continue] = ACTIONS(6018),
    [anon_sym_break] = ACTIONS(6018),
    [anon_sym_BREAK] = ACTIONS(6018),
    [anon_sym_Break] = ACTIONS(6018),
    [anon_sym_with] = ACTIONS(6018),
    [anon_sym_WITH] = ACTIONS(6018),
    [anon_sym_With] = ACTIONS(6018),
    [sym_asserterror_keyword] = ACTIONS(6020),
    [sym_page_keyword] = ACTIONS(6018),
    [anon_sym_codeunit] = ACTIONS(6018),
    [anon_sym_CODEUNIT] = ACTIONS(6018),
    [anon_sym_Codeunit] = ACTIONS(6018),
    [anon_sym_CodeUnit] = ACTIONS(6018),
    [anon_sym_COdeunit] = ACTIONS(6018),
    [anon_sym_codeUnit] = ACTIONS(6018),
    [sym_report_keyword] = ACTIONS(6018),
    [sym_query_keyword] = ACTIONS(6018),
    [anon_sym_xmlport] = ACTIONS(6018),
    [anon_sym_XMLPORT] = ACTIONS(6018),
    [anon_sym_Xmlport] = ACTIONS(6018),
    [anon_sym_XMLport] = ACTIONS(6018),
    [anon_sym_XMLPort] = ACTIONS(6018),
    [anon_sym_XmlPort] = ACTIONS(6018),
    [anon_sym_enum] = ACTIONS(6018),
    [anon_sym_ENUM] = ACTIONS(6018),
    [anon_sym_Enum] = ACTIONS(6018),
    [anon_sym_eNUM] = ACTIONS(6018),
    [anon_sym_eNum] = ACTIONS(6018),
    [anon_sym_ENum] = ACTIONS(6018),
    [sym_quoted_identifier] = ACTIONS(6020),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6020),
    [sym_verbatim_string] = ACTIONS(6020),
    [sym_integer] = ACTIONS(6018),
    [sym_continue_as_identifier] = ACTIONS(6020),
    [sym_preproc_open] = ACTIONS(6020),
    [sym_end_keyword] = ACTIONS(6020),
  },
  [STATE(3300)] = {
    [sym_identifier] = ACTIONS(5741),
    [anon_sym_SEMI] = ACTIONS(5743),
    [anon_sym_DASH] = ACTIONS(5743),
    [aux_sym_boolean_token1] = ACTIONS(5741),
    [aux_sym_boolean_token2] = ACTIONS(5741),
    [sym_decimal] = ACTIONS(5741),
    [anon_sym_LPAREN] = ACTIONS(5743),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5741),
    [anon_sym_LBRACK] = ACTIONS(5743),
    [aux_sym_record_type_token1] = ACTIONS(5741),
    [aux_sym_basic_type_token21] = ACTIONS(5741),
    [aux_sym_basic_type_token22] = ACTIONS(5741),
    [aux_sym_basic_type_token48] = ACTIONS(5741),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5741),
    [anon_sym_POUNDif] = ACTIONS(5743),
    [anon_sym_POUNDIF] = ACTIONS(5743),
    [anon_sym_POUNDIf] = ACTIONS(5743),
    [anon_sym_not] = ACTIONS(5741),
    [anon_sym_NOT] = ACTIONS(5741),
    [anon_sym_Not] = ACTIONS(5741),
    [anon_sym_POUNDelse] = ACTIONS(5743),
    [anon_sym_POUNDELSE] = ACTIONS(5743),
    [anon_sym_POUNDElse] = ACTIONS(5743),
    [anon_sym_POUNDelse2] = ACTIONS(5743),
    [anon_sym_POUNDELSE2] = ACTIONS(5743),
    [anon_sym_POUNDElse2] = ACTIONS(5743),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5741),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5741),
    [anon_sym_PLUS] = ACTIONS(5743),
    [sym_datetime_literal] = ACTIONS(5743),
    [sym_date_literal] = ACTIONS(5741),
    [sym_time_literal] = ACTIONS(5741),
    [sym_biginteger_literal] = ACTIONS(5743),
    [anon_sym_if] = ACTIONS(5741),
    [anon_sym_IF] = ACTIONS(5741),
    [anon_sym_If] = ACTIONS(5741),
    [anon_sym_else] = ACTIONS(5741),
    [anon_sym_ELSE] = ACTIONS(5741),
    [anon_sym_Else] = ACTIONS(5741),
    [anon_sym_case] = ACTIONS(5741),
    [anon_sym_CASE] = ACTIONS(5741),
    [anon_sym_Case] = ACTIONS(5741),
    [anon_sym_for] = ACTIONS(5741),
    [anon_sym_FOR] = ACTIONS(5741),
    [anon_sym_For] = ACTIONS(5741),
    [anon_sym_foreach] = ACTIONS(5741),
    [anon_sym_FOREACH] = ACTIONS(5741),
    [anon_sym_Foreach] = ACTIONS(5741),
    [anon_sym_while] = ACTIONS(5741),
    [anon_sym_WHILE] = ACTIONS(5741),
    [anon_sym_While] = ACTIONS(5741),
    [anon_sym_repeat] = ACTIONS(5741),
    [anon_sym_REPEAT] = ACTIONS(5741),
    [anon_sym_Repeat] = ACTIONS(5741),
    [anon_sym_exit] = ACTIONS(5741),
    [anon_sym_EXIT] = ACTIONS(5741),
    [anon_sym_Exit] = ACTIONS(5741),
    [anon_sym_continue] = ACTIONS(5741),
    [anon_sym_CONTINUE] = ACTIONS(5741),
    [anon_sym_Continue] = ACTIONS(5741),
    [anon_sym_break] = ACTIONS(5741),
    [anon_sym_BREAK] = ACTIONS(5741),
    [anon_sym_Break] = ACTIONS(5741),
    [anon_sym_with] = ACTIONS(5741),
    [anon_sym_WITH] = ACTIONS(5741),
    [anon_sym_With] = ACTIONS(5741),
    [sym_asserterror_keyword] = ACTIONS(5743),
    [sym_page_keyword] = ACTIONS(5741),
    [anon_sym_codeunit] = ACTIONS(5741),
    [anon_sym_CODEUNIT] = ACTIONS(5741),
    [anon_sym_Codeunit] = ACTIONS(5741),
    [anon_sym_CodeUnit] = ACTIONS(5741),
    [anon_sym_COdeunit] = ACTIONS(5741),
    [anon_sym_codeUnit] = ACTIONS(5741),
    [sym_report_keyword] = ACTIONS(5741),
    [sym_query_keyword] = ACTIONS(5741),
    [anon_sym_xmlport] = ACTIONS(5741),
    [anon_sym_XMLPORT] = ACTIONS(5741),
    [anon_sym_Xmlport] = ACTIONS(5741),
    [anon_sym_XMLport] = ACTIONS(5741),
    [anon_sym_XMLPort] = ACTIONS(5741),
    [anon_sym_XmlPort] = ACTIONS(5741),
    [anon_sym_enum] = ACTIONS(5741),
    [anon_sym_ENUM] = ACTIONS(5741),
    [anon_sym_Enum] = ACTIONS(5741),
    [anon_sym_eNUM] = ACTIONS(5741),
    [anon_sym_eNum] = ACTIONS(5741),
    [anon_sym_ENum] = ACTIONS(5741),
    [sym_quoted_identifier] = ACTIONS(5743),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5743),
    [sym_verbatim_string] = ACTIONS(5743),
    [sym_integer] = ACTIONS(5741),
    [sym_continue_as_identifier] = ACTIONS(5743),
    [sym_preproc_open] = ACTIONS(5743),
    [sym_end_keyword] = ACTIONS(5743),
  },
  [STATE(3301)] = {
    [sym_identifier] = ACTIONS(5745),
    [anon_sym_SEMI] = ACTIONS(5747),
    [anon_sym_DASH] = ACTIONS(5747),
    [aux_sym_boolean_token1] = ACTIONS(5745),
    [aux_sym_boolean_token2] = ACTIONS(5745),
    [sym_decimal] = ACTIONS(5745),
    [anon_sym_LPAREN] = ACTIONS(5747),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5745),
    [anon_sym_LBRACK] = ACTIONS(5747),
    [aux_sym_record_type_token1] = ACTIONS(5745),
    [aux_sym_basic_type_token21] = ACTIONS(5745),
    [aux_sym_basic_type_token22] = ACTIONS(5745),
    [aux_sym_basic_type_token48] = ACTIONS(5745),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5745),
    [anon_sym_POUNDif] = ACTIONS(5747),
    [anon_sym_POUNDIF] = ACTIONS(5747),
    [anon_sym_POUNDIf] = ACTIONS(5747),
    [anon_sym_not] = ACTIONS(5745),
    [anon_sym_NOT] = ACTIONS(5745),
    [anon_sym_Not] = ACTIONS(5745),
    [anon_sym_POUNDelse] = ACTIONS(5747),
    [anon_sym_POUNDELSE] = ACTIONS(5747),
    [anon_sym_POUNDElse] = ACTIONS(5747),
    [anon_sym_POUNDelse2] = ACTIONS(5747),
    [anon_sym_POUNDELSE2] = ACTIONS(5747),
    [anon_sym_POUNDElse2] = ACTIONS(5747),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5745),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5745),
    [anon_sym_PLUS] = ACTIONS(5747),
    [sym_datetime_literal] = ACTIONS(5747),
    [sym_date_literal] = ACTIONS(5745),
    [sym_time_literal] = ACTIONS(5745),
    [sym_biginteger_literal] = ACTIONS(5747),
    [anon_sym_if] = ACTIONS(5745),
    [anon_sym_IF] = ACTIONS(5745),
    [anon_sym_If] = ACTIONS(5745),
    [anon_sym_else] = ACTIONS(5745),
    [anon_sym_ELSE] = ACTIONS(5745),
    [anon_sym_Else] = ACTIONS(5745),
    [anon_sym_case] = ACTIONS(5745),
    [anon_sym_CASE] = ACTIONS(5745),
    [anon_sym_Case] = ACTIONS(5745),
    [anon_sym_for] = ACTIONS(5745),
    [anon_sym_FOR] = ACTIONS(5745),
    [anon_sym_For] = ACTIONS(5745),
    [anon_sym_foreach] = ACTIONS(5745),
    [anon_sym_FOREACH] = ACTIONS(5745),
    [anon_sym_Foreach] = ACTIONS(5745),
    [anon_sym_while] = ACTIONS(5745),
    [anon_sym_WHILE] = ACTIONS(5745),
    [anon_sym_While] = ACTIONS(5745),
    [anon_sym_repeat] = ACTIONS(5745),
    [anon_sym_REPEAT] = ACTIONS(5745),
    [anon_sym_Repeat] = ACTIONS(5745),
    [anon_sym_exit] = ACTIONS(5745),
    [anon_sym_EXIT] = ACTIONS(5745),
    [anon_sym_Exit] = ACTIONS(5745),
    [anon_sym_continue] = ACTIONS(5745),
    [anon_sym_CONTINUE] = ACTIONS(5745),
    [anon_sym_Continue] = ACTIONS(5745),
    [anon_sym_break] = ACTIONS(5745),
    [anon_sym_BREAK] = ACTIONS(5745),
    [anon_sym_Break] = ACTIONS(5745),
    [anon_sym_with] = ACTIONS(5745),
    [anon_sym_WITH] = ACTIONS(5745),
    [anon_sym_With] = ACTIONS(5745),
    [sym_asserterror_keyword] = ACTIONS(5747),
    [sym_page_keyword] = ACTIONS(5745),
    [anon_sym_codeunit] = ACTIONS(5745),
    [anon_sym_CODEUNIT] = ACTIONS(5745),
    [anon_sym_Codeunit] = ACTIONS(5745),
    [anon_sym_CodeUnit] = ACTIONS(5745),
    [anon_sym_COdeunit] = ACTIONS(5745),
    [anon_sym_codeUnit] = ACTIONS(5745),
    [sym_report_keyword] = ACTIONS(5745),
    [sym_query_keyword] = ACTIONS(5745),
    [anon_sym_xmlport] = ACTIONS(5745),
    [anon_sym_XMLPORT] = ACTIONS(5745),
    [anon_sym_Xmlport] = ACTIONS(5745),
    [anon_sym_XMLport] = ACTIONS(5745),
    [anon_sym_XMLPort] = ACTIONS(5745),
    [anon_sym_XmlPort] = ACTIONS(5745),
    [anon_sym_enum] = ACTIONS(5745),
    [anon_sym_ENUM] = ACTIONS(5745),
    [anon_sym_Enum] = ACTIONS(5745),
    [anon_sym_eNUM] = ACTIONS(5745),
    [anon_sym_eNum] = ACTIONS(5745),
    [anon_sym_ENum] = ACTIONS(5745),
    [sym_quoted_identifier] = ACTIONS(5747),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5747),
    [sym_verbatim_string] = ACTIONS(5747),
    [sym_integer] = ACTIONS(5745),
    [sym_continue_as_identifier] = ACTIONS(5747),
    [sym_preproc_open] = ACTIONS(5747),
    [sym_end_keyword] = ACTIONS(5747),
  },
  [STATE(3302)] = {
    [sym_identifier] = ACTIONS(6022),
    [anon_sym_SEMI] = ACTIONS(6024),
    [anon_sym_DASH] = ACTIONS(6024),
    [aux_sym_boolean_token1] = ACTIONS(6022),
    [aux_sym_boolean_token2] = ACTIONS(6022),
    [sym_decimal] = ACTIONS(6022),
    [anon_sym_LPAREN] = ACTIONS(6024),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6022),
    [anon_sym_LBRACK] = ACTIONS(6024),
    [aux_sym_record_type_token1] = ACTIONS(6022),
    [aux_sym_basic_type_token21] = ACTIONS(6022),
    [aux_sym_basic_type_token22] = ACTIONS(6022),
    [aux_sym_basic_type_token48] = ACTIONS(6022),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6022),
    [anon_sym_POUNDif] = ACTIONS(6024),
    [anon_sym_POUNDIF] = ACTIONS(6024),
    [anon_sym_POUNDIf] = ACTIONS(6024),
    [anon_sym_not] = ACTIONS(6022),
    [anon_sym_NOT] = ACTIONS(6022),
    [anon_sym_Not] = ACTIONS(6022),
    [anon_sym_POUNDelse] = ACTIONS(6024),
    [anon_sym_POUNDELSE] = ACTIONS(6024),
    [anon_sym_POUNDElse] = ACTIONS(6024),
    [anon_sym_POUNDelse2] = ACTIONS(6024),
    [anon_sym_POUNDELSE2] = ACTIONS(6024),
    [anon_sym_POUNDElse2] = ACTIONS(6024),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6022),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6022),
    [anon_sym_PLUS] = ACTIONS(6024),
    [sym_datetime_literal] = ACTIONS(6024),
    [sym_date_literal] = ACTIONS(6022),
    [sym_time_literal] = ACTIONS(6022),
    [sym_biginteger_literal] = ACTIONS(6024),
    [anon_sym_if] = ACTIONS(6022),
    [anon_sym_IF] = ACTIONS(6022),
    [anon_sym_If] = ACTIONS(6022),
    [anon_sym_else] = ACTIONS(6022),
    [anon_sym_ELSE] = ACTIONS(6022),
    [anon_sym_Else] = ACTIONS(6022),
    [anon_sym_case] = ACTIONS(6022),
    [anon_sym_CASE] = ACTIONS(6022),
    [anon_sym_Case] = ACTIONS(6022),
    [anon_sym_for] = ACTIONS(6022),
    [anon_sym_FOR] = ACTIONS(6022),
    [anon_sym_For] = ACTIONS(6022),
    [anon_sym_foreach] = ACTIONS(6022),
    [anon_sym_FOREACH] = ACTIONS(6022),
    [anon_sym_Foreach] = ACTIONS(6022),
    [anon_sym_while] = ACTIONS(6022),
    [anon_sym_WHILE] = ACTIONS(6022),
    [anon_sym_While] = ACTIONS(6022),
    [anon_sym_repeat] = ACTIONS(6022),
    [anon_sym_REPEAT] = ACTIONS(6022),
    [anon_sym_Repeat] = ACTIONS(6022),
    [anon_sym_exit] = ACTIONS(6022),
    [anon_sym_EXIT] = ACTIONS(6022),
    [anon_sym_Exit] = ACTIONS(6022),
    [anon_sym_continue] = ACTIONS(6022),
    [anon_sym_CONTINUE] = ACTIONS(6022),
    [anon_sym_Continue] = ACTIONS(6022),
    [anon_sym_break] = ACTIONS(6022),
    [anon_sym_BREAK] = ACTIONS(6022),
    [anon_sym_Break] = ACTIONS(6022),
    [anon_sym_with] = ACTIONS(6022),
    [anon_sym_WITH] = ACTIONS(6022),
    [anon_sym_With] = ACTIONS(6022),
    [sym_asserterror_keyword] = ACTIONS(6024),
    [sym_page_keyword] = ACTIONS(6022),
    [anon_sym_codeunit] = ACTIONS(6022),
    [anon_sym_CODEUNIT] = ACTIONS(6022),
    [anon_sym_Codeunit] = ACTIONS(6022),
    [anon_sym_CodeUnit] = ACTIONS(6022),
    [anon_sym_COdeunit] = ACTIONS(6022),
    [anon_sym_codeUnit] = ACTIONS(6022),
    [sym_report_keyword] = ACTIONS(6022),
    [sym_query_keyword] = ACTIONS(6022),
    [anon_sym_xmlport] = ACTIONS(6022),
    [anon_sym_XMLPORT] = ACTIONS(6022),
    [anon_sym_Xmlport] = ACTIONS(6022),
    [anon_sym_XMLport] = ACTIONS(6022),
    [anon_sym_XMLPort] = ACTIONS(6022),
    [anon_sym_XmlPort] = ACTIONS(6022),
    [anon_sym_enum] = ACTIONS(6022),
    [anon_sym_ENUM] = ACTIONS(6022),
    [anon_sym_Enum] = ACTIONS(6022),
    [anon_sym_eNUM] = ACTIONS(6022),
    [anon_sym_eNum] = ACTIONS(6022),
    [anon_sym_ENum] = ACTIONS(6022),
    [sym_quoted_identifier] = ACTIONS(6024),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6024),
    [sym_verbatim_string] = ACTIONS(6024),
    [sym_integer] = ACTIONS(6022),
    [sym_continue_as_identifier] = ACTIONS(6024),
    [sym_preproc_open] = ACTIONS(6024),
    [sym_end_keyword] = ACTIONS(6024),
  },
  [STATE(3303)] = {
    [sym_identifier] = ACTIONS(6026),
    [anon_sym_SEMI] = ACTIONS(6028),
    [anon_sym_DASH] = ACTIONS(6028),
    [aux_sym_boolean_token1] = ACTIONS(6026),
    [aux_sym_boolean_token2] = ACTIONS(6026),
    [sym_decimal] = ACTIONS(6026),
    [anon_sym_LPAREN] = ACTIONS(6028),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6026),
    [anon_sym_LBRACK] = ACTIONS(6028),
    [aux_sym_record_type_token1] = ACTIONS(6026),
    [aux_sym_basic_type_token21] = ACTIONS(6026),
    [aux_sym_basic_type_token22] = ACTIONS(6026),
    [aux_sym_basic_type_token48] = ACTIONS(6026),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6026),
    [anon_sym_POUNDif] = ACTIONS(6028),
    [anon_sym_POUNDIF] = ACTIONS(6028),
    [anon_sym_POUNDIf] = ACTIONS(6028),
    [anon_sym_not] = ACTIONS(6026),
    [anon_sym_NOT] = ACTIONS(6026),
    [anon_sym_Not] = ACTIONS(6026),
    [anon_sym_POUNDelse] = ACTIONS(6028),
    [anon_sym_POUNDELSE] = ACTIONS(6028),
    [anon_sym_POUNDElse] = ACTIONS(6028),
    [anon_sym_POUNDelse2] = ACTIONS(6028),
    [anon_sym_POUNDELSE2] = ACTIONS(6028),
    [anon_sym_POUNDElse2] = ACTIONS(6028),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6026),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6026),
    [anon_sym_PLUS] = ACTIONS(6028),
    [sym_datetime_literal] = ACTIONS(6028),
    [sym_date_literal] = ACTIONS(6026),
    [sym_time_literal] = ACTIONS(6026),
    [sym_biginteger_literal] = ACTIONS(6028),
    [anon_sym_if] = ACTIONS(6026),
    [anon_sym_IF] = ACTIONS(6026),
    [anon_sym_If] = ACTIONS(6026),
    [anon_sym_else] = ACTIONS(6026),
    [anon_sym_ELSE] = ACTIONS(6026),
    [anon_sym_Else] = ACTIONS(6026),
    [anon_sym_case] = ACTIONS(6026),
    [anon_sym_CASE] = ACTIONS(6026),
    [anon_sym_Case] = ACTIONS(6026),
    [anon_sym_for] = ACTIONS(6026),
    [anon_sym_FOR] = ACTIONS(6026),
    [anon_sym_For] = ACTIONS(6026),
    [anon_sym_foreach] = ACTIONS(6026),
    [anon_sym_FOREACH] = ACTIONS(6026),
    [anon_sym_Foreach] = ACTIONS(6026),
    [anon_sym_while] = ACTIONS(6026),
    [anon_sym_WHILE] = ACTIONS(6026),
    [anon_sym_While] = ACTIONS(6026),
    [anon_sym_repeat] = ACTIONS(6026),
    [anon_sym_REPEAT] = ACTIONS(6026),
    [anon_sym_Repeat] = ACTIONS(6026),
    [anon_sym_exit] = ACTIONS(6026),
    [anon_sym_EXIT] = ACTIONS(6026),
    [anon_sym_Exit] = ACTIONS(6026),
    [anon_sym_continue] = ACTIONS(6026),
    [anon_sym_CONTINUE] = ACTIONS(6026),
    [anon_sym_Continue] = ACTIONS(6026),
    [anon_sym_break] = ACTIONS(6026),
    [anon_sym_BREAK] = ACTIONS(6026),
    [anon_sym_Break] = ACTIONS(6026),
    [anon_sym_with] = ACTIONS(6026),
    [anon_sym_WITH] = ACTIONS(6026),
    [anon_sym_With] = ACTIONS(6026),
    [sym_asserterror_keyword] = ACTIONS(6028),
    [sym_page_keyword] = ACTIONS(6026),
    [anon_sym_codeunit] = ACTIONS(6026),
    [anon_sym_CODEUNIT] = ACTIONS(6026),
    [anon_sym_Codeunit] = ACTIONS(6026),
    [anon_sym_CodeUnit] = ACTIONS(6026),
    [anon_sym_COdeunit] = ACTIONS(6026),
    [anon_sym_codeUnit] = ACTIONS(6026),
    [sym_report_keyword] = ACTIONS(6026),
    [sym_query_keyword] = ACTIONS(6026),
    [anon_sym_xmlport] = ACTIONS(6026),
    [anon_sym_XMLPORT] = ACTIONS(6026),
    [anon_sym_Xmlport] = ACTIONS(6026),
    [anon_sym_XMLport] = ACTIONS(6026),
    [anon_sym_XMLPort] = ACTIONS(6026),
    [anon_sym_XmlPort] = ACTIONS(6026),
    [anon_sym_enum] = ACTIONS(6026),
    [anon_sym_ENUM] = ACTIONS(6026),
    [anon_sym_Enum] = ACTIONS(6026),
    [anon_sym_eNUM] = ACTIONS(6026),
    [anon_sym_eNum] = ACTIONS(6026),
    [anon_sym_ENum] = ACTIONS(6026),
    [sym_quoted_identifier] = ACTIONS(6028),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6028),
    [sym_verbatim_string] = ACTIONS(6028),
    [sym_integer] = ACTIONS(6026),
    [sym_continue_as_identifier] = ACTIONS(6028),
    [sym_preproc_open] = ACTIONS(6028),
    [sym_end_keyword] = ACTIONS(6028),
  },
  [STATE(3304)] = {
    [sym_identifier] = ACTIONS(5505),
    [anon_sym_SEMI] = ACTIONS(5507),
    [anon_sym_DASH] = ACTIONS(5507),
    [aux_sym_boolean_token1] = ACTIONS(5505),
    [aux_sym_boolean_token2] = ACTIONS(5505),
    [sym_decimal] = ACTIONS(5505),
    [anon_sym_LPAREN] = ACTIONS(5507),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5505),
    [anon_sym_LBRACK] = ACTIONS(5507),
    [aux_sym_record_type_token1] = ACTIONS(5505),
    [aux_sym_basic_type_token21] = ACTIONS(5505),
    [aux_sym_basic_type_token22] = ACTIONS(5505),
    [aux_sym_basic_type_token48] = ACTIONS(5505),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5505),
    [anon_sym_POUNDif] = ACTIONS(5507),
    [anon_sym_POUNDIF] = ACTIONS(5507),
    [anon_sym_POUNDIf] = ACTIONS(5507),
    [anon_sym_not] = ACTIONS(5505),
    [anon_sym_NOT] = ACTIONS(5505),
    [anon_sym_Not] = ACTIONS(5505),
    [anon_sym_POUNDelse] = ACTIONS(5507),
    [anon_sym_POUNDELSE] = ACTIONS(5507),
    [anon_sym_POUNDElse] = ACTIONS(5507),
    [anon_sym_POUNDelse2] = ACTIONS(5507),
    [anon_sym_POUNDELSE2] = ACTIONS(5507),
    [anon_sym_POUNDElse2] = ACTIONS(5507),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5505),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5505),
    [anon_sym_PLUS] = ACTIONS(5507),
    [sym_datetime_literal] = ACTIONS(5507),
    [sym_date_literal] = ACTIONS(5505),
    [sym_time_literal] = ACTIONS(5505),
    [sym_biginteger_literal] = ACTIONS(5507),
    [anon_sym_if] = ACTIONS(5505),
    [anon_sym_IF] = ACTIONS(5505),
    [anon_sym_If] = ACTIONS(5505),
    [anon_sym_else] = ACTIONS(5505),
    [anon_sym_ELSE] = ACTIONS(5505),
    [anon_sym_Else] = ACTIONS(5505),
    [anon_sym_case] = ACTIONS(5505),
    [anon_sym_CASE] = ACTIONS(5505),
    [anon_sym_Case] = ACTIONS(5505),
    [anon_sym_for] = ACTIONS(5505),
    [anon_sym_FOR] = ACTIONS(5505),
    [anon_sym_For] = ACTIONS(5505),
    [anon_sym_foreach] = ACTIONS(5505),
    [anon_sym_FOREACH] = ACTIONS(5505),
    [anon_sym_Foreach] = ACTIONS(5505),
    [anon_sym_while] = ACTIONS(5505),
    [anon_sym_WHILE] = ACTIONS(5505),
    [anon_sym_While] = ACTIONS(5505),
    [anon_sym_repeat] = ACTIONS(5505),
    [anon_sym_REPEAT] = ACTIONS(5505),
    [anon_sym_Repeat] = ACTIONS(5505),
    [anon_sym_exit] = ACTIONS(5505),
    [anon_sym_EXIT] = ACTIONS(5505),
    [anon_sym_Exit] = ACTIONS(5505),
    [anon_sym_continue] = ACTIONS(5505),
    [anon_sym_CONTINUE] = ACTIONS(5505),
    [anon_sym_Continue] = ACTIONS(5505),
    [anon_sym_break] = ACTIONS(5505),
    [anon_sym_BREAK] = ACTIONS(5505),
    [anon_sym_Break] = ACTIONS(5505),
    [anon_sym_with] = ACTIONS(5505),
    [anon_sym_WITH] = ACTIONS(5505),
    [anon_sym_With] = ACTIONS(5505),
    [sym_asserterror_keyword] = ACTIONS(5507),
    [sym_page_keyword] = ACTIONS(5505),
    [anon_sym_codeunit] = ACTIONS(5505),
    [anon_sym_CODEUNIT] = ACTIONS(5505),
    [anon_sym_Codeunit] = ACTIONS(5505),
    [anon_sym_CodeUnit] = ACTIONS(5505),
    [anon_sym_COdeunit] = ACTIONS(5505),
    [anon_sym_codeUnit] = ACTIONS(5505),
    [sym_report_keyword] = ACTIONS(5505),
    [sym_query_keyword] = ACTIONS(5505),
    [anon_sym_xmlport] = ACTIONS(5505),
    [anon_sym_XMLPORT] = ACTIONS(5505),
    [anon_sym_Xmlport] = ACTIONS(5505),
    [anon_sym_XMLport] = ACTIONS(5505),
    [anon_sym_XMLPort] = ACTIONS(5505),
    [anon_sym_XmlPort] = ACTIONS(5505),
    [anon_sym_enum] = ACTIONS(5505),
    [anon_sym_ENUM] = ACTIONS(5505),
    [anon_sym_Enum] = ACTIONS(5505),
    [anon_sym_eNUM] = ACTIONS(5505),
    [anon_sym_eNum] = ACTIONS(5505),
    [anon_sym_ENum] = ACTIONS(5505),
    [sym_quoted_identifier] = ACTIONS(5507),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5507),
    [sym_verbatim_string] = ACTIONS(5507),
    [sym_integer] = ACTIONS(5505),
    [sym_continue_as_identifier] = ACTIONS(5507),
    [sym_preproc_open] = ACTIONS(5507),
    [sym_end_keyword] = ACTIONS(5507),
  },
  [STATE(3305)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(7343),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_end_keyword] = ACTIONS(5965),
  },
  [STATE(3306)] = {
    [sym_identifier] = ACTIONS(6132),
    [anon_sym_SEMI] = ACTIONS(6134),
    [anon_sym_DASH] = ACTIONS(6134),
    [aux_sym_boolean_token1] = ACTIONS(6132),
    [aux_sym_boolean_token2] = ACTIONS(6132),
    [sym_decimal] = ACTIONS(6132),
    [anon_sym_LPAREN] = ACTIONS(6134),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6132),
    [anon_sym_LBRACK] = ACTIONS(6134),
    [aux_sym_record_type_token1] = ACTIONS(6132),
    [aux_sym_basic_type_token21] = ACTIONS(6132),
    [aux_sym_basic_type_token22] = ACTIONS(6132),
    [aux_sym_basic_type_token48] = ACTIONS(6132),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6132),
    [anon_sym_POUNDif] = ACTIONS(6134),
    [anon_sym_POUNDIF] = ACTIONS(6134),
    [anon_sym_POUNDIf] = ACTIONS(6134),
    [anon_sym_not] = ACTIONS(6132),
    [anon_sym_NOT] = ACTIONS(6132),
    [anon_sym_Not] = ACTIONS(6132),
    [anon_sym_POUNDelse] = ACTIONS(6134),
    [anon_sym_POUNDELSE] = ACTIONS(6134),
    [anon_sym_POUNDElse] = ACTIONS(6134),
    [anon_sym_POUNDelse2] = ACTIONS(6134),
    [anon_sym_POUNDELSE2] = ACTIONS(6134),
    [anon_sym_POUNDElse2] = ACTIONS(6134),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6132),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6132),
    [anon_sym_PLUS] = ACTIONS(6134),
    [sym_datetime_literal] = ACTIONS(6134),
    [sym_date_literal] = ACTIONS(6132),
    [sym_time_literal] = ACTIONS(6132),
    [sym_biginteger_literal] = ACTIONS(6134),
    [anon_sym_if] = ACTIONS(6132),
    [anon_sym_IF] = ACTIONS(6132),
    [anon_sym_If] = ACTIONS(6132),
    [anon_sym_else] = ACTIONS(6132),
    [anon_sym_ELSE] = ACTIONS(6132),
    [anon_sym_Else] = ACTIONS(6132),
    [anon_sym_case] = ACTIONS(6132),
    [anon_sym_CASE] = ACTIONS(6132),
    [anon_sym_Case] = ACTIONS(6132),
    [anon_sym_for] = ACTIONS(6132),
    [anon_sym_FOR] = ACTIONS(6132),
    [anon_sym_For] = ACTIONS(6132),
    [anon_sym_foreach] = ACTIONS(6132),
    [anon_sym_FOREACH] = ACTIONS(6132),
    [anon_sym_Foreach] = ACTIONS(6132),
    [anon_sym_while] = ACTIONS(6132),
    [anon_sym_WHILE] = ACTIONS(6132),
    [anon_sym_While] = ACTIONS(6132),
    [anon_sym_repeat] = ACTIONS(6132),
    [anon_sym_REPEAT] = ACTIONS(6132),
    [anon_sym_Repeat] = ACTIONS(6132),
    [anon_sym_exit] = ACTIONS(6132),
    [anon_sym_EXIT] = ACTIONS(6132),
    [anon_sym_Exit] = ACTIONS(6132),
    [anon_sym_continue] = ACTIONS(6132),
    [anon_sym_CONTINUE] = ACTIONS(6132),
    [anon_sym_Continue] = ACTIONS(6132),
    [anon_sym_break] = ACTIONS(6132),
    [anon_sym_BREAK] = ACTIONS(6132),
    [anon_sym_Break] = ACTIONS(6132),
    [anon_sym_with] = ACTIONS(6132),
    [anon_sym_WITH] = ACTIONS(6132),
    [anon_sym_With] = ACTIONS(6132),
    [sym_asserterror_keyword] = ACTIONS(6134),
    [sym_page_keyword] = ACTIONS(6132),
    [anon_sym_codeunit] = ACTIONS(6132),
    [anon_sym_CODEUNIT] = ACTIONS(6132),
    [anon_sym_Codeunit] = ACTIONS(6132),
    [anon_sym_CodeUnit] = ACTIONS(6132),
    [anon_sym_COdeunit] = ACTIONS(6132),
    [anon_sym_codeUnit] = ACTIONS(6132),
    [sym_report_keyword] = ACTIONS(6132),
    [sym_query_keyword] = ACTIONS(6132),
    [anon_sym_xmlport] = ACTIONS(6132),
    [anon_sym_XMLPORT] = ACTIONS(6132),
    [anon_sym_Xmlport] = ACTIONS(6132),
    [anon_sym_XMLport] = ACTIONS(6132),
    [anon_sym_XMLPort] = ACTIONS(6132),
    [anon_sym_XmlPort] = ACTIONS(6132),
    [anon_sym_enum] = ACTIONS(6132),
    [anon_sym_ENUM] = ACTIONS(6132),
    [anon_sym_Enum] = ACTIONS(6132),
    [anon_sym_eNUM] = ACTIONS(6132),
    [anon_sym_eNum] = ACTIONS(6132),
    [anon_sym_ENum] = ACTIONS(6132),
    [sym_quoted_identifier] = ACTIONS(6134),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6134),
    [sym_verbatim_string] = ACTIONS(6134),
    [sym_integer] = ACTIONS(6132),
    [sym_continue_as_identifier] = ACTIONS(6134),
    [sym_preproc_open] = ACTIONS(6134),
    [sym_end_keyword] = ACTIONS(6134),
  },
  [STATE(3307)] = {
    [sym_identifier] = ACTIONS(6114),
    [anon_sym_SEMI] = ACTIONS(6116),
    [anon_sym_DASH] = ACTIONS(6116),
    [aux_sym_boolean_token1] = ACTIONS(6114),
    [aux_sym_boolean_token2] = ACTIONS(6114),
    [sym_decimal] = ACTIONS(6114),
    [anon_sym_LPAREN] = ACTIONS(6116),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6114),
    [anon_sym_LBRACK] = ACTIONS(6116),
    [aux_sym_record_type_token1] = ACTIONS(6114),
    [aux_sym_basic_type_token21] = ACTIONS(6114),
    [aux_sym_basic_type_token22] = ACTIONS(6114),
    [aux_sym_basic_type_token48] = ACTIONS(6114),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6114),
    [anon_sym_POUNDif] = ACTIONS(6116),
    [anon_sym_POUNDIF] = ACTIONS(6116),
    [anon_sym_POUNDIf] = ACTIONS(6116),
    [anon_sym_not] = ACTIONS(6114),
    [anon_sym_NOT] = ACTIONS(6114),
    [anon_sym_Not] = ACTIONS(6114),
    [anon_sym_POUNDelse] = ACTIONS(6116),
    [anon_sym_POUNDELSE] = ACTIONS(6116),
    [anon_sym_POUNDElse] = ACTIONS(6116),
    [anon_sym_POUNDelse2] = ACTIONS(6116),
    [anon_sym_POUNDELSE2] = ACTIONS(6116),
    [anon_sym_POUNDElse2] = ACTIONS(6116),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6114),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6114),
    [anon_sym_PLUS] = ACTIONS(6116),
    [sym_datetime_literal] = ACTIONS(6116),
    [sym_date_literal] = ACTIONS(6114),
    [sym_time_literal] = ACTIONS(6114),
    [sym_biginteger_literal] = ACTIONS(6116),
    [anon_sym_if] = ACTIONS(6114),
    [anon_sym_IF] = ACTIONS(6114),
    [anon_sym_If] = ACTIONS(6114),
    [anon_sym_else] = ACTIONS(6114),
    [anon_sym_ELSE] = ACTIONS(6114),
    [anon_sym_Else] = ACTIONS(6114),
    [anon_sym_case] = ACTIONS(6114),
    [anon_sym_CASE] = ACTIONS(6114),
    [anon_sym_Case] = ACTIONS(6114),
    [anon_sym_for] = ACTIONS(6114),
    [anon_sym_FOR] = ACTIONS(6114),
    [anon_sym_For] = ACTIONS(6114),
    [anon_sym_foreach] = ACTIONS(6114),
    [anon_sym_FOREACH] = ACTIONS(6114),
    [anon_sym_Foreach] = ACTIONS(6114),
    [anon_sym_while] = ACTIONS(6114),
    [anon_sym_WHILE] = ACTIONS(6114),
    [anon_sym_While] = ACTIONS(6114),
    [anon_sym_repeat] = ACTIONS(6114),
    [anon_sym_REPEAT] = ACTIONS(6114),
    [anon_sym_Repeat] = ACTIONS(6114),
    [anon_sym_exit] = ACTIONS(6114),
    [anon_sym_EXIT] = ACTIONS(6114),
    [anon_sym_Exit] = ACTIONS(6114),
    [anon_sym_continue] = ACTIONS(6114),
    [anon_sym_CONTINUE] = ACTIONS(6114),
    [anon_sym_Continue] = ACTIONS(6114),
    [anon_sym_break] = ACTIONS(6114),
    [anon_sym_BREAK] = ACTIONS(6114),
    [anon_sym_Break] = ACTIONS(6114),
    [anon_sym_with] = ACTIONS(6114),
    [anon_sym_WITH] = ACTIONS(6114),
    [anon_sym_With] = ACTIONS(6114),
    [sym_asserterror_keyword] = ACTIONS(6116),
    [sym_page_keyword] = ACTIONS(6114),
    [anon_sym_codeunit] = ACTIONS(6114),
    [anon_sym_CODEUNIT] = ACTIONS(6114),
    [anon_sym_Codeunit] = ACTIONS(6114),
    [anon_sym_CodeUnit] = ACTIONS(6114),
    [anon_sym_COdeunit] = ACTIONS(6114),
    [anon_sym_codeUnit] = ACTIONS(6114),
    [sym_report_keyword] = ACTIONS(6114),
    [sym_query_keyword] = ACTIONS(6114),
    [anon_sym_xmlport] = ACTIONS(6114),
    [anon_sym_XMLPORT] = ACTIONS(6114),
    [anon_sym_Xmlport] = ACTIONS(6114),
    [anon_sym_XMLport] = ACTIONS(6114),
    [anon_sym_XMLPort] = ACTIONS(6114),
    [anon_sym_XmlPort] = ACTIONS(6114),
    [anon_sym_enum] = ACTIONS(6114),
    [anon_sym_ENUM] = ACTIONS(6114),
    [anon_sym_Enum] = ACTIONS(6114),
    [anon_sym_eNUM] = ACTIONS(6114),
    [anon_sym_eNum] = ACTIONS(6114),
    [anon_sym_ENum] = ACTIONS(6114),
    [sym_quoted_identifier] = ACTIONS(6116),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6116),
    [sym_verbatim_string] = ACTIONS(6116),
    [sym_integer] = ACTIONS(6114),
    [sym_continue_as_identifier] = ACTIONS(6116),
    [sym_preproc_open] = ACTIONS(6116),
    [sym_end_keyword] = ACTIONS(6116),
  },
  [STATE(3308)] = {
    [sym_identifier] = ACTIONS(6196),
    [anon_sym_SEMI] = ACTIONS(6198),
    [anon_sym_DASH] = ACTIONS(6198),
    [aux_sym_boolean_token1] = ACTIONS(6196),
    [aux_sym_boolean_token2] = ACTIONS(6196),
    [sym_decimal] = ACTIONS(6196),
    [anon_sym_LPAREN] = ACTIONS(6198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6196),
    [anon_sym_LBRACK] = ACTIONS(6198),
    [aux_sym_record_type_token1] = ACTIONS(6196),
    [aux_sym_basic_type_token21] = ACTIONS(6196),
    [aux_sym_basic_type_token22] = ACTIONS(6196),
    [aux_sym_basic_type_token48] = ACTIONS(6196),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6196),
    [anon_sym_POUNDif] = ACTIONS(6198),
    [anon_sym_POUNDIF] = ACTIONS(6198),
    [anon_sym_POUNDIf] = ACTIONS(6198),
    [anon_sym_not] = ACTIONS(6196),
    [anon_sym_NOT] = ACTIONS(6196),
    [anon_sym_Not] = ACTIONS(6196),
    [anon_sym_POUNDelse] = ACTIONS(6198),
    [anon_sym_POUNDELSE] = ACTIONS(6198),
    [anon_sym_POUNDElse] = ACTIONS(6198),
    [anon_sym_POUNDelse2] = ACTIONS(6198),
    [anon_sym_POUNDELSE2] = ACTIONS(6198),
    [anon_sym_POUNDElse2] = ACTIONS(6198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6196),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6196),
    [anon_sym_PLUS] = ACTIONS(6198),
    [sym_datetime_literal] = ACTIONS(6198),
    [sym_date_literal] = ACTIONS(6196),
    [sym_time_literal] = ACTIONS(6196),
    [sym_biginteger_literal] = ACTIONS(6198),
    [anon_sym_if] = ACTIONS(6196),
    [anon_sym_IF] = ACTIONS(6196),
    [anon_sym_If] = ACTIONS(6196),
    [anon_sym_else] = ACTIONS(6196),
    [anon_sym_ELSE] = ACTIONS(6196),
    [anon_sym_Else] = ACTIONS(6196),
    [anon_sym_case] = ACTIONS(6196),
    [anon_sym_CASE] = ACTIONS(6196),
    [anon_sym_Case] = ACTIONS(6196),
    [anon_sym_for] = ACTIONS(6196),
    [anon_sym_FOR] = ACTIONS(6196),
    [anon_sym_For] = ACTIONS(6196),
    [anon_sym_foreach] = ACTIONS(6196),
    [anon_sym_FOREACH] = ACTIONS(6196),
    [anon_sym_Foreach] = ACTIONS(6196),
    [anon_sym_while] = ACTIONS(6196),
    [anon_sym_WHILE] = ACTIONS(6196),
    [anon_sym_While] = ACTIONS(6196),
    [anon_sym_repeat] = ACTIONS(6196),
    [anon_sym_REPEAT] = ACTIONS(6196),
    [anon_sym_Repeat] = ACTIONS(6196),
    [anon_sym_exit] = ACTIONS(6196),
    [anon_sym_EXIT] = ACTIONS(6196),
    [anon_sym_Exit] = ACTIONS(6196),
    [anon_sym_continue] = ACTIONS(6196),
    [anon_sym_CONTINUE] = ACTIONS(6196),
    [anon_sym_Continue] = ACTIONS(6196),
    [anon_sym_break] = ACTIONS(6196),
    [anon_sym_BREAK] = ACTIONS(6196),
    [anon_sym_Break] = ACTIONS(6196),
    [anon_sym_with] = ACTIONS(6196),
    [anon_sym_WITH] = ACTIONS(6196),
    [anon_sym_With] = ACTIONS(6196),
    [sym_asserterror_keyword] = ACTIONS(6198),
    [sym_page_keyword] = ACTIONS(6196),
    [anon_sym_codeunit] = ACTIONS(6196),
    [anon_sym_CODEUNIT] = ACTIONS(6196),
    [anon_sym_Codeunit] = ACTIONS(6196),
    [anon_sym_CodeUnit] = ACTIONS(6196),
    [anon_sym_COdeunit] = ACTIONS(6196),
    [anon_sym_codeUnit] = ACTIONS(6196),
    [sym_report_keyword] = ACTIONS(6196),
    [sym_query_keyword] = ACTIONS(6196),
    [anon_sym_xmlport] = ACTIONS(6196),
    [anon_sym_XMLPORT] = ACTIONS(6196),
    [anon_sym_Xmlport] = ACTIONS(6196),
    [anon_sym_XMLport] = ACTIONS(6196),
    [anon_sym_XMLPort] = ACTIONS(6196),
    [anon_sym_XmlPort] = ACTIONS(6196),
    [anon_sym_enum] = ACTIONS(6196),
    [anon_sym_ENUM] = ACTIONS(6196),
    [anon_sym_Enum] = ACTIONS(6196),
    [anon_sym_eNUM] = ACTIONS(6196),
    [anon_sym_eNum] = ACTIONS(6196),
    [anon_sym_ENum] = ACTIONS(6196),
    [sym_quoted_identifier] = ACTIONS(6198),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6198),
    [sym_verbatim_string] = ACTIONS(6198),
    [sym_integer] = ACTIONS(6196),
    [sym_continue_as_identifier] = ACTIONS(6198),
    [sym_preproc_open] = ACTIONS(6198),
    [sym_end_keyword] = ACTIONS(6198),
  },
  [STATE(3309)] = {
    [sym_identifier] = ACTIONS(6094),
    [anon_sym_SEMI] = ACTIONS(6096),
    [anon_sym_DASH] = ACTIONS(6096),
    [aux_sym_boolean_token1] = ACTIONS(6094),
    [aux_sym_boolean_token2] = ACTIONS(6094),
    [sym_decimal] = ACTIONS(6094),
    [anon_sym_LPAREN] = ACTIONS(6096),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6094),
    [anon_sym_LBRACK] = ACTIONS(6096),
    [aux_sym_record_type_token1] = ACTIONS(6094),
    [aux_sym_basic_type_token21] = ACTIONS(6094),
    [aux_sym_basic_type_token22] = ACTIONS(6094),
    [aux_sym_basic_type_token48] = ACTIONS(6094),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6094),
    [anon_sym_POUNDif] = ACTIONS(6096),
    [anon_sym_POUNDIF] = ACTIONS(6096),
    [anon_sym_POUNDIf] = ACTIONS(6096),
    [anon_sym_not] = ACTIONS(6094),
    [anon_sym_NOT] = ACTIONS(6094),
    [anon_sym_Not] = ACTIONS(6094),
    [anon_sym_POUNDelse] = ACTIONS(6096),
    [anon_sym_POUNDELSE] = ACTIONS(6096),
    [anon_sym_POUNDElse] = ACTIONS(6096),
    [anon_sym_POUNDelse2] = ACTIONS(6096),
    [anon_sym_POUNDELSE2] = ACTIONS(6096),
    [anon_sym_POUNDElse2] = ACTIONS(6096),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6094),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6094),
    [anon_sym_PLUS] = ACTIONS(6096),
    [sym_datetime_literal] = ACTIONS(6096),
    [sym_date_literal] = ACTIONS(6094),
    [sym_time_literal] = ACTIONS(6094),
    [sym_biginteger_literal] = ACTIONS(6096),
    [anon_sym_if] = ACTIONS(6094),
    [anon_sym_IF] = ACTIONS(6094),
    [anon_sym_If] = ACTIONS(6094),
    [anon_sym_else] = ACTIONS(6094),
    [anon_sym_ELSE] = ACTIONS(6094),
    [anon_sym_Else] = ACTIONS(6094),
    [anon_sym_case] = ACTIONS(6094),
    [anon_sym_CASE] = ACTIONS(6094),
    [anon_sym_Case] = ACTIONS(6094),
    [anon_sym_for] = ACTIONS(6094),
    [anon_sym_FOR] = ACTIONS(6094),
    [anon_sym_For] = ACTIONS(6094),
    [anon_sym_foreach] = ACTIONS(6094),
    [anon_sym_FOREACH] = ACTIONS(6094),
    [anon_sym_Foreach] = ACTIONS(6094),
    [anon_sym_while] = ACTIONS(6094),
    [anon_sym_WHILE] = ACTIONS(6094),
    [anon_sym_While] = ACTIONS(6094),
    [anon_sym_repeat] = ACTIONS(6094),
    [anon_sym_REPEAT] = ACTIONS(6094),
    [anon_sym_Repeat] = ACTIONS(6094),
    [anon_sym_exit] = ACTIONS(6094),
    [anon_sym_EXIT] = ACTIONS(6094),
    [anon_sym_Exit] = ACTIONS(6094),
    [anon_sym_continue] = ACTIONS(6094),
    [anon_sym_CONTINUE] = ACTIONS(6094),
    [anon_sym_Continue] = ACTIONS(6094),
    [anon_sym_break] = ACTIONS(6094),
    [anon_sym_BREAK] = ACTIONS(6094),
    [anon_sym_Break] = ACTIONS(6094),
    [anon_sym_with] = ACTIONS(6094),
    [anon_sym_WITH] = ACTIONS(6094),
    [anon_sym_With] = ACTIONS(6094),
    [sym_asserterror_keyword] = ACTIONS(6096),
    [sym_page_keyword] = ACTIONS(6094),
    [anon_sym_codeunit] = ACTIONS(6094),
    [anon_sym_CODEUNIT] = ACTIONS(6094),
    [anon_sym_Codeunit] = ACTIONS(6094),
    [anon_sym_CodeUnit] = ACTIONS(6094),
    [anon_sym_COdeunit] = ACTIONS(6094),
    [anon_sym_codeUnit] = ACTIONS(6094),
    [sym_report_keyword] = ACTIONS(6094),
    [sym_query_keyword] = ACTIONS(6094),
    [anon_sym_xmlport] = ACTIONS(6094),
    [anon_sym_XMLPORT] = ACTIONS(6094),
    [anon_sym_Xmlport] = ACTIONS(6094),
    [anon_sym_XMLport] = ACTIONS(6094),
    [anon_sym_XMLPort] = ACTIONS(6094),
    [anon_sym_XmlPort] = ACTIONS(6094),
    [anon_sym_enum] = ACTIONS(6094),
    [anon_sym_ENUM] = ACTIONS(6094),
    [anon_sym_Enum] = ACTIONS(6094),
    [anon_sym_eNUM] = ACTIONS(6094),
    [anon_sym_eNum] = ACTIONS(6094),
    [anon_sym_ENum] = ACTIONS(6094),
    [sym_quoted_identifier] = ACTIONS(6096),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6096),
    [sym_verbatim_string] = ACTIONS(6096),
    [sym_integer] = ACTIONS(6094),
    [sym_continue_as_identifier] = ACTIONS(6096),
    [sym_preproc_open] = ACTIONS(6096),
    [sym_end_keyword] = ACTIONS(6096),
  },
  [STATE(3310)] = {
    [sym_identifier] = ACTIONS(6200),
    [anon_sym_SEMI] = ACTIONS(6202),
    [anon_sym_DASH] = ACTIONS(6202),
    [aux_sym_boolean_token1] = ACTIONS(6200),
    [aux_sym_boolean_token2] = ACTIONS(6200),
    [sym_decimal] = ACTIONS(6200),
    [anon_sym_LPAREN] = ACTIONS(6202),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6200),
    [anon_sym_LBRACK] = ACTIONS(6202),
    [aux_sym_record_type_token1] = ACTIONS(6200),
    [aux_sym_basic_type_token21] = ACTIONS(6200),
    [aux_sym_basic_type_token22] = ACTIONS(6200),
    [aux_sym_basic_type_token48] = ACTIONS(6200),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6200),
    [anon_sym_POUNDif] = ACTIONS(6202),
    [anon_sym_POUNDIF] = ACTIONS(6202),
    [anon_sym_POUNDIf] = ACTIONS(6202),
    [anon_sym_not] = ACTIONS(6200),
    [anon_sym_NOT] = ACTIONS(6200),
    [anon_sym_Not] = ACTIONS(6200),
    [anon_sym_POUNDelse] = ACTIONS(6202),
    [anon_sym_POUNDELSE] = ACTIONS(6202),
    [anon_sym_POUNDElse] = ACTIONS(6202),
    [anon_sym_POUNDelse2] = ACTIONS(6202),
    [anon_sym_POUNDELSE2] = ACTIONS(6202),
    [anon_sym_POUNDElse2] = ACTIONS(6202),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6200),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6200),
    [anon_sym_PLUS] = ACTIONS(6202),
    [sym_datetime_literal] = ACTIONS(6202),
    [sym_date_literal] = ACTIONS(6200),
    [sym_time_literal] = ACTIONS(6200),
    [sym_biginteger_literal] = ACTIONS(6202),
    [anon_sym_if] = ACTIONS(6200),
    [anon_sym_IF] = ACTIONS(6200),
    [anon_sym_If] = ACTIONS(6200),
    [anon_sym_else] = ACTIONS(6200),
    [anon_sym_ELSE] = ACTIONS(6200),
    [anon_sym_Else] = ACTIONS(6200),
    [anon_sym_case] = ACTIONS(6200),
    [anon_sym_CASE] = ACTIONS(6200),
    [anon_sym_Case] = ACTIONS(6200),
    [anon_sym_for] = ACTIONS(6200),
    [anon_sym_FOR] = ACTIONS(6200),
    [anon_sym_For] = ACTIONS(6200),
    [anon_sym_foreach] = ACTIONS(6200),
    [anon_sym_FOREACH] = ACTIONS(6200),
    [anon_sym_Foreach] = ACTIONS(6200),
    [anon_sym_while] = ACTIONS(6200),
    [anon_sym_WHILE] = ACTIONS(6200),
    [anon_sym_While] = ACTIONS(6200),
    [anon_sym_repeat] = ACTIONS(6200),
    [anon_sym_REPEAT] = ACTIONS(6200),
    [anon_sym_Repeat] = ACTIONS(6200),
    [anon_sym_exit] = ACTIONS(6200),
    [anon_sym_EXIT] = ACTIONS(6200),
    [anon_sym_Exit] = ACTIONS(6200),
    [anon_sym_continue] = ACTIONS(6200),
    [anon_sym_CONTINUE] = ACTIONS(6200),
    [anon_sym_Continue] = ACTIONS(6200),
    [anon_sym_break] = ACTIONS(6200),
    [anon_sym_BREAK] = ACTIONS(6200),
    [anon_sym_Break] = ACTIONS(6200),
    [anon_sym_with] = ACTIONS(6200),
    [anon_sym_WITH] = ACTIONS(6200),
    [anon_sym_With] = ACTIONS(6200),
    [sym_asserterror_keyword] = ACTIONS(6202),
    [sym_page_keyword] = ACTIONS(6200),
    [anon_sym_codeunit] = ACTIONS(6200),
    [anon_sym_CODEUNIT] = ACTIONS(6200),
    [anon_sym_Codeunit] = ACTIONS(6200),
    [anon_sym_CodeUnit] = ACTIONS(6200),
    [anon_sym_COdeunit] = ACTIONS(6200),
    [anon_sym_codeUnit] = ACTIONS(6200),
    [sym_report_keyword] = ACTIONS(6200),
    [sym_query_keyword] = ACTIONS(6200),
    [anon_sym_xmlport] = ACTIONS(6200),
    [anon_sym_XMLPORT] = ACTIONS(6200),
    [anon_sym_Xmlport] = ACTIONS(6200),
    [anon_sym_XMLport] = ACTIONS(6200),
    [anon_sym_XMLPort] = ACTIONS(6200),
    [anon_sym_XmlPort] = ACTIONS(6200),
    [anon_sym_enum] = ACTIONS(6200),
    [anon_sym_ENUM] = ACTIONS(6200),
    [anon_sym_Enum] = ACTIONS(6200),
    [anon_sym_eNUM] = ACTIONS(6200),
    [anon_sym_eNum] = ACTIONS(6200),
    [anon_sym_ENum] = ACTIONS(6200),
    [sym_quoted_identifier] = ACTIONS(6202),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6202),
    [sym_verbatim_string] = ACTIONS(6202),
    [sym_integer] = ACTIONS(6200),
    [sym_continue_as_identifier] = ACTIONS(6202),
    [sym_preproc_open] = ACTIONS(6202),
    [sym_end_keyword] = ACTIONS(6202),
  },
  [STATE(3311)] = {
    [sym_identifier] = ACTIONS(6110),
    [anon_sym_SEMI] = ACTIONS(6112),
    [anon_sym_DASH] = ACTIONS(6112),
    [aux_sym_boolean_token1] = ACTIONS(6110),
    [aux_sym_boolean_token2] = ACTIONS(6110),
    [sym_decimal] = ACTIONS(6110),
    [anon_sym_LPAREN] = ACTIONS(6112),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6110),
    [anon_sym_LBRACK] = ACTIONS(6112),
    [aux_sym_record_type_token1] = ACTIONS(6110),
    [aux_sym_basic_type_token21] = ACTIONS(6110),
    [aux_sym_basic_type_token22] = ACTIONS(6110),
    [aux_sym_basic_type_token48] = ACTIONS(6110),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6110),
    [anon_sym_POUNDif] = ACTIONS(6112),
    [anon_sym_POUNDIF] = ACTIONS(6112),
    [anon_sym_POUNDIf] = ACTIONS(6112),
    [anon_sym_not] = ACTIONS(6110),
    [anon_sym_NOT] = ACTIONS(6110),
    [anon_sym_Not] = ACTIONS(6110),
    [anon_sym_POUNDelse] = ACTIONS(6112),
    [anon_sym_POUNDELSE] = ACTIONS(6112),
    [anon_sym_POUNDElse] = ACTIONS(6112),
    [anon_sym_POUNDelse2] = ACTIONS(6112),
    [anon_sym_POUNDELSE2] = ACTIONS(6112),
    [anon_sym_POUNDElse2] = ACTIONS(6112),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6110),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6110),
    [anon_sym_PLUS] = ACTIONS(6112),
    [sym_datetime_literal] = ACTIONS(6112),
    [sym_date_literal] = ACTIONS(6110),
    [sym_time_literal] = ACTIONS(6110),
    [sym_biginteger_literal] = ACTIONS(6112),
    [anon_sym_if] = ACTIONS(6110),
    [anon_sym_IF] = ACTIONS(6110),
    [anon_sym_If] = ACTIONS(6110),
    [anon_sym_else] = ACTIONS(6110),
    [anon_sym_ELSE] = ACTIONS(6110),
    [anon_sym_Else] = ACTIONS(6110),
    [anon_sym_case] = ACTIONS(6110),
    [anon_sym_CASE] = ACTIONS(6110),
    [anon_sym_Case] = ACTIONS(6110),
    [anon_sym_for] = ACTIONS(6110),
    [anon_sym_FOR] = ACTIONS(6110),
    [anon_sym_For] = ACTIONS(6110),
    [anon_sym_foreach] = ACTIONS(6110),
    [anon_sym_FOREACH] = ACTIONS(6110),
    [anon_sym_Foreach] = ACTIONS(6110),
    [anon_sym_while] = ACTIONS(6110),
    [anon_sym_WHILE] = ACTIONS(6110),
    [anon_sym_While] = ACTIONS(6110),
    [anon_sym_repeat] = ACTIONS(6110),
    [anon_sym_REPEAT] = ACTIONS(6110),
    [anon_sym_Repeat] = ACTIONS(6110),
    [anon_sym_exit] = ACTIONS(6110),
    [anon_sym_EXIT] = ACTIONS(6110),
    [anon_sym_Exit] = ACTIONS(6110),
    [anon_sym_continue] = ACTIONS(6110),
    [anon_sym_CONTINUE] = ACTIONS(6110),
    [anon_sym_Continue] = ACTIONS(6110),
    [anon_sym_break] = ACTIONS(6110),
    [anon_sym_BREAK] = ACTIONS(6110),
    [anon_sym_Break] = ACTIONS(6110),
    [anon_sym_with] = ACTIONS(6110),
    [anon_sym_WITH] = ACTIONS(6110),
    [anon_sym_With] = ACTIONS(6110),
    [sym_asserterror_keyword] = ACTIONS(6112),
    [sym_page_keyword] = ACTIONS(6110),
    [anon_sym_codeunit] = ACTIONS(6110),
    [anon_sym_CODEUNIT] = ACTIONS(6110),
    [anon_sym_Codeunit] = ACTIONS(6110),
    [anon_sym_CodeUnit] = ACTIONS(6110),
    [anon_sym_COdeunit] = ACTIONS(6110),
    [anon_sym_codeUnit] = ACTIONS(6110),
    [sym_report_keyword] = ACTIONS(6110),
    [sym_query_keyword] = ACTIONS(6110),
    [anon_sym_xmlport] = ACTIONS(6110),
    [anon_sym_XMLPORT] = ACTIONS(6110),
    [anon_sym_Xmlport] = ACTIONS(6110),
    [anon_sym_XMLport] = ACTIONS(6110),
    [anon_sym_XMLPort] = ACTIONS(6110),
    [anon_sym_XmlPort] = ACTIONS(6110),
    [anon_sym_enum] = ACTIONS(6110),
    [anon_sym_ENUM] = ACTIONS(6110),
    [anon_sym_Enum] = ACTIONS(6110),
    [anon_sym_eNUM] = ACTIONS(6110),
    [anon_sym_eNum] = ACTIONS(6110),
    [anon_sym_ENum] = ACTIONS(6110),
    [sym_quoted_identifier] = ACTIONS(6112),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6112),
    [sym_verbatim_string] = ACTIONS(6112),
    [sym_integer] = ACTIONS(6110),
    [sym_continue_as_identifier] = ACTIONS(6112),
    [sym_preproc_open] = ACTIONS(6112),
    [sym_end_keyword] = ACTIONS(6112),
  },
  [STATE(3312)] = {
    [sym_identifier] = ACTIONS(6098),
    [anon_sym_SEMI] = ACTIONS(6100),
    [anon_sym_DASH] = ACTIONS(6100),
    [aux_sym_boolean_token1] = ACTIONS(6098),
    [aux_sym_boolean_token2] = ACTIONS(6098),
    [sym_decimal] = ACTIONS(6098),
    [anon_sym_LPAREN] = ACTIONS(6100),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6098),
    [anon_sym_LBRACK] = ACTIONS(6100),
    [aux_sym_record_type_token1] = ACTIONS(6098),
    [aux_sym_basic_type_token21] = ACTIONS(6098),
    [aux_sym_basic_type_token22] = ACTIONS(6098),
    [aux_sym_basic_type_token48] = ACTIONS(6098),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6098),
    [anon_sym_POUNDif] = ACTIONS(6100),
    [anon_sym_POUNDIF] = ACTIONS(6100),
    [anon_sym_POUNDIf] = ACTIONS(6100),
    [anon_sym_not] = ACTIONS(6098),
    [anon_sym_NOT] = ACTIONS(6098),
    [anon_sym_Not] = ACTIONS(6098),
    [anon_sym_POUNDelse] = ACTIONS(6100),
    [anon_sym_POUNDELSE] = ACTIONS(6100),
    [anon_sym_POUNDElse] = ACTIONS(6100),
    [anon_sym_POUNDelse2] = ACTIONS(6100),
    [anon_sym_POUNDELSE2] = ACTIONS(6100),
    [anon_sym_POUNDElse2] = ACTIONS(6100),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6098),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6098),
    [anon_sym_PLUS] = ACTIONS(6100),
    [sym_datetime_literal] = ACTIONS(6100),
    [sym_date_literal] = ACTIONS(6098),
    [sym_time_literal] = ACTIONS(6098),
    [sym_biginteger_literal] = ACTIONS(6100),
    [anon_sym_if] = ACTIONS(6098),
    [anon_sym_IF] = ACTIONS(6098),
    [anon_sym_If] = ACTIONS(6098),
    [anon_sym_else] = ACTIONS(6098),
    [anon_sym_ELSE] = ACTIONS(6098),
    [anon_sym_Else] = ACTIONS(6098),
    [anon_sym_case] = ACTIONS(6098),
    [anon_sym_CASE] = ACTIONS(6098),
    [anon_sym_Case] = ACTIONS(6098),
    [anon_sym_for] = ACTIONS(6098),
    [anon_sym_FOR] = ACTIONS(6098),
    [anon_sym_For] = ACTIONS(6098),
    [anon_sym_foreach] = ACTIONS(6098),
    [anon_sym_FOREACH] = ACTIONS(6098),
    [anon_sym_Foreach] = ACTIONS(6098),
    [anon_sym_while] = ACTIONS(6098),
    [anon_sym_WHILE] = ACTIONS(6098),
    [anon_sym_While] = ACTIONS(6098),
    [anon_sym_repeat] = ACTIONS(6098),
    [anon_sym_REPEAT] = ACTIONS(6098),
    [anon_sym_Repeat] = ACTIONS(6098),
    [anon_sym_exit] = ACTIONS(6098),
    [anon_sym_EXIT] = ACTIONS(6098),
    [anon_sym_Exit] = ACTIONS(6098),
    [anon_sym_continue] = ACTIONS(6098),
    [anon_sym_CONTINUE] = ACTIONS(6098),
    [anon_sym_Continue] = ACTIONS(6098),
    [anon_sym_break] = ACTIONS(6098),
    [anon_sym_BREAK] = ACTIONS(6098),
    [anon_sym_Break] = ACTIONS(6098),
    [anon_sym_with] = ACTIONS(6098),
    [anon_sym_WITH] = ACTIONS(6098),
    [anon_sym_With] = ACTIONS(6098),
    [sym_asserterror_keyword] = ACTIONS(6100),
    [sym_page_keyword] = ACTIONS(6098),
    [anon_sym_codeunit] = ACTIONS(6098),
    [anon_sym_CODEUNIT] = ACTIONS(6098),
    [anon_sym_Codeunit] = ACTIONS(6098),
    [anon_sym_CodeUnit] = ACTIONS(6098),
    [anon_sym_COdeunit] = ACTIONS(6098),
    [anon_sym_codeUnit] = ACTIONS(6098),
    [sym_report_keyword] = ACTIONS(6098),
    [sym_query_keyword] = ACTIONS(6098),
    [anon_sym_xmlport] = ACTIONS(6098),
    [anon_sym_XMLPORT] = ACTIONS(6098),
    [anon_sym_Xmlport] = ACTIONS(6098),
    [anon_sym_XMLport] = ACTIONS(6098),
    [anon_sym_XMLPort] = ACTIONS(6098),
    [anon_sym_XmlPort] = ACTIONS(6098),
    [anon_sym_enum] = ACTIONS(6098),
    [anon_sym_ENUM] = ACTIONS(6098),
    [anon_sym_Enum] = ACTIONS(6098),
    [anon_sym_eNUM] = ACTIONS(6098),
    [anon_sym_eNum] = ACTIONS(6098),
    [anon_sym_ENum] = ACTIONS(6098),
    [sym_quoted_identifier] = ACTIONS(6100),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6100),
    [sym_verbatim_string] = ACTIONS(6100),
    [sym_integer] = ACTIONS(6098),
    [sym_continue_as_identifier] = ACTIONS(6100),
    [sym_preproc_open] = ACTIONS(6100),
    [sym_end_keyword] = ACTIONS(6100),
  },
  [STATE(3313)] = {
    [sym_identifier] = ACTIONS(5513),
    [anon_sym_SEMI] = ACTIONS(5515),
    [anon_sym_DASH] = ACTIONS(5515),
    [aux_sym_boolean_token1] = ACTIONS(5513),
    [aux_sym_boolean_token2] = ACTIONS(5513),
    [sym_decimal] = ACTIONS(5513),
    [anon_sym_LPAREN] = ACTIONS(5515),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5513),
    [anon_sym_LBRACK] = ACTIONS(5515),
    [aux_sym_record_type_token1] = ACTIONS(5513),
    [aux_sym_basic_type_token21] = ACTIONS(5513),
    [aux_sym_basic_type_token22] = ACTIONS(5513),
    [aux_sym_basic_type_token48] = ACTIONS(5513),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5513),
    [anon_sym_POUNDif] = ACTIONS(5515),
    [anon_sym_POUNDIF] = ACTIONS(5515),
    [anon_sym_POUNDIf] = ACTIONS(5515),
    [anon_sym_not] = ACTIONS(5513),
    [anon_sym_NOT] = ACTIONS(5513),
    [anon_sym_Not] = ACTIONS(5513),
    [anon_sym_POUNDelse] = ACTIONS(5515),
    [anon_sym_POUNDELSE] = ACTIONS(5515),
    [anon_sym_POUNDElse] = ACTIONS(5515),
    [anon_sym_POUNDelse2] = ACTIONS(5515),
    [anon_sym_POUNDELSE2] = ACTIONS(5515),
    [anon_sym_POUNDElse2] = ACTIONS(5515),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5513),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5513),
    [anon_sym_PLUS] = ACTIONS(5515),
    [sym_datetime_literal] = ACTIONS(5515),
    [sym_date_literal] = ACTIONS(5513),
    [sym_time_literal] = ACTIONS(5513),
    [sym_biginteger_literal] = ACTIONS(5515),
    [anon_sym_if] = ACTIONS(5513),
    [anon_sym_IF] = ACTIONS(5513),
    [anon_sym_If] = ACTIONS(5513),
    [anon_sym_else] = ACTIONS(5513),
    [anon_sym_ELSE] = ACTIONS(5513),
    [anon_sym_Else] = ACTIONS(5513),
    [anon_sym_case] = ACTIONS(5513),
    [anon_sym_CASE] = ACTIONS(5513),
    [anon_sym_Case] = ACTIONS(5513),
    [anon_sym_for] = ACTIONS(5513),
    [anon_sym_FOR] = ACTIONS(5513),
    [anon_sym_For] = ACTIONS(5513),
    [anon_sym_foreach] = ACTIONS(5513),
    [anon_sym_FOREACH] = ACTIONS(5513),
    [anon_sym_Foreach] = ACTIONS(5513),
    [anon_sym_while] = ACTIONS(5513),
    [anon_sym_WHILE] = ACTIONS(5513),
    [anon_sym_While] = ACTIONS(5513),
    [anon_sym_repeat] = ACTIONS(5513),
    [anon_sym_REPEAT] = ACTIONS(5513),
    [anon_sym_Repeat] = ACTIONS(5513),
    [anon_sym_exit] = ACTIONS(5513),
    [anon_sym_EXIT] = ACTIONS(5513),
    [anon_sym_Exit] = ACTIONS(5513),
    [anon_sym_continue] = ACTIONS(5513),
    [anon_sym_CONTINUE] = ACTIONS(5513),
    [anon_sym_Continue] = ACTIONS(5513),
    [anon_sym_break] = ACTIONS(5513),
    [anon_sym_BREAK] = ACTIONS(5513),
    [anon_sym_Break] = ACTIONS(5513),
    [anon_sym_with] = ACTIONS(5513),
    [anon_sym_WITH] = ACTIONS(5513),
    [anon_sym_With] = ACTIONS(5513),
    [sym_asserterror_keyword] = ACTIONS(5515),
    [sym_page_keyword] = ACTIONS(5513),
    [anon_sym_codeunit] = ACTIONS(5513),
    [anon_sym_CODEUNIT] = ACTIONS(5513),
    [anon_sym_Codeunit] = ACTIONS(5513),
    [anon_sym_CodeUnit] = ACTIONS(5513),
    [anon_sym_COdeunit] = ACTIONS(5513),
    [anon_sym_codeUnit] = ACTIONS(5513),
    [sym_report_keyword] = ACTIONS(5513),
    [sym_query_keyword] = ACTIONS(5513),
    [anon_sym_xmlport] = ACTIONS(5513),
    [anon_sym_XMLPORT] = ACTIONS(5513),
    [anon_sym_Xmlport] = ACTIONS(5513),
    [anon_sym_XMLport] = ACTIONS(5513),
    [anon_sym_XMLPort] = ACTIONS(5513),
    [anon_sym_XmlPort] = ACTIONS(5513),
    [anon_sym_enum] = ACTIONS(5513),
    [anon_sym_ENUM] = ACTIONS(5513),
    [anon_sym_Enum] = ACTIONS(5513),
    [anon_sym_eNUM] = ACTIONS(5513),
    [anon_sym_eNum] = ACTIONS(5513),
    [anon_sym_ENum] = ACTIONS(5513),
    [sym_quoted_identifier] = ACTIONS(5515),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5515),
    [sym_verbatim_string] = ACTIONS(5515),
    [sym_integer] = ACTIONS(5513),
    [sym_continue_as_identifier] = ACTIONS(5515),
    [sym_preproc_open] = ACTIONS(5515),
    [sym_end_keyword] = ACTIONS(5515),
  },
  [STATE(3314)] = {
    [sym_identifier] = ACTIONS(6196),
    [anon_sym_SEMI] = ACTIONS(6198),
    [anon_sym_DASH] = ACTIONS(6198),
    [aux_sym_boolean_token1] = ACTIONS(6196),
    [aux_sym_boolean_token2] = ACTIONS(6196),
    [sym_decimal] = ACTIONS(6196),
    [anon_sym_LPAREN] = ACTIONS(6198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6196),
    [anon_sym_LBRACK] = ACTIONS(6198),
    [aux_sym_record_type_token1] = ACTIONS(6196),
    [aux_sym_basic_type_token21] = ACTIONS(6196),
    [aux_sym_basic_type_token22] = ACTIONS(6196),
    [aux_sym_basic_type_token48] = ACTIONS(6196),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6196),
    [anon_sym_POUNDif] = ACTIONS(6198),
    [anon_sym_POUNDIF] = ACTIONS(6198),
    [anon_sym_POUNDIf] = ACTIONS(6198),
    [anon_sym_not] = ACTIONS(6196),
    [anon_sym_NOT] = ACTIONS(6196),
    [anon_sym_Not] = ACTIONS(6196),
    [anon_sym_POUNDelse] = ACTIONS(6198),
    [anon_sym_POUNDELSE] = ACTIONS(6198),
    [anon_sym_POUNDElse] = ACTIONS(6198),
    [anon_sym_POUNDelse2] = ACTIONS(6198),
    [anon_sym_POUNDELSE2] = ACTIONS(6198),
    [anon_sym_POUNDElse2] = ACTIONS(6198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6196),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6196),
    [anon_sym_PLUS] = ACTIONS(6198),
    [sym_datetime_literal] = ACTIONS(6198),
    [sym_date_literal] = ACTIONS(6196),
    [sym_time_literal] = ACTIONS(6196),
    [sym_biginteger_literal] = ACTIONS(6198),
    [anon_sym_if] = ACTIONS(6196),
    [anon_sym_IF] = ACTIONS(6196),
    [anon_sym_If] = ACTIONS(6196),
    [anon_sym_else] = ACTIONS(6196),
    [anon_sym_ELSE] = ACTIONS(6196),
    [anon_sym_Else] = ACTIONS(6196),
    [anon_sym_case] = ACTIONS(6196),
    [anon_sym_CASE] = ACTIONS(6196),
    [anon_sym_Case] = ACTIONS(6196),
    [anon_sym_for] = ACTIONS(6196),
    [anon_sym_FOR] = ACTIONS(6196),
    [anon_sym_For] = ACTIONS(6196),
    [anon_sym_foreach] = ACTIONS(6196),
    [anon_sym_FOREACH] = ACTIONS(6196),
    [anon_sym_Foreach] = ACTIONS(6196),
    [anon_sym_while] = ACTIONS(6196),
    [anon_sym_WHILE] = ACTIONS(6196),
    [anon_sym_While] = ACTIONS(6196),
    [anon_sym_repeat] = ACTIONS(6196),
    [anon_sym_REPEAT] = ACTIONS(6196),
    [anon_sym_Repeat] = ACTIONS(6196),
    [anon_sym_exit] = ACTIONS(6196),
    [anon_sym_EXIT] = ACTIONS(6196),
    [anon_sym_Exit] = ACTIONS(6196),
    [anon_sym_continue] = ACTIONS(6196),
    [anon_sym_CONTINUE] = ACTIONS(6196),
    [anon_sym_Continue] = ACTIONS(6196),
    [anon_sym_break] = ACTIONS(6196),
    [anon_sym_BREAK] = ACTIONS(6196),
    [anon_sym_Break] = ACTIONS(6196),
    [anon_sym_with] = ACTIONS(6196),
    [anon_sym_WITH] = ACTIONS(6196),
    [anon_sym_With] = ACTIONS(6196),
    [sym_asserterror_keyword] = ACTIONS(6198),
    [sym_page_keyword] = ACTIONS(6196),
    [anon_sym_codeunit] = ACTIONS(6196),
    [anon_sym_CODEUNIT] = ACTIONS(6196),
    [anon_sym_Codeunit] = ACTIONS(6196),
    [anon_sym_CodeUnit] = ACTIONS(6196),
    [anon_sym_COdeunit] = ACTIONS(6196),
    [anon_sym_codeUnit] = ACTIONS(6196),
    [sym_report_keyword] = ACTIONS(6196),
    [sym_query_keyword] = ACTIONS(6196),
    [anon_sym_xmlport] = ACTIONS(6196),
    [anon_sym_XMLPORT] = ACTIONS(6196),
    [anon_sym_Xmlport] = ACTIONS(6196),
    [anon_sym_XMLport] = ACTIONS(6196),
    [anon_sym_XMLPort] = ACTIONS(6196),
    [anon_sym_XmlPort] = ACTIONS(6196),
    [anon_sym_enum] = ACTIONS(6196),
    [anon_sym_ENUM] = ACTIONS(6196),
    [anon_sym_Enum] = ACTIONS(6196),
    [anon_sym_eNUM] = ACTIONS(6196),
    [anon_sym_eNum] = ACTIONS(6196),
    [anon_sym_ENum] = ACTIONS(6196),
    [sym_quoted_identifier] = ACTIONS(6198),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6198),
    [sym_verbatim_string] = ACTIONS(6198),
    [sym_integer] = ACTIONS(6196),
    [sym_continue_as_identifier] = ACTIONS(6198),
    [sym_preproc_open] = ACTIONS(6198),
    [sym_end_keyword] = ACTIONS(6198),
  },
  [STATE(3315)] = {
    [sym_identifier] = ACTIONS(6224),
    [anon_sym_SEMI] = ACTIONS(6226),
    [anon_sym_DASH] = ACTIONS(6226),
    [aux_sym_boolean_token1] = ACTIONS(6224),
    [aux_sym_boolean_token2] = ACTIONS(6224),
    [sym_decimal] = ACTIONS(6224),
    [anon_sym_LPAREN] = ACTIONS(6226),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6224),
    [anon_sym_LBRACK] = ACTIONS(6226),
    [aux_sym_record_type_token1] = ACTIONS(6224),
    [aux_sym_basic_type_token21] = ACTIONS(6224),
    [aux_sym_basic_type_token22] = ACTIONS(6224),
    [aux_sym_basic_type_token48] = ACTIONS(6224),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6224),
    [anon_sym_POUNDif] = ACTIONS(6226),
    [anon_sym_POUNDIF] = ACTIONS(6226),
    [anon_sym_POUNDIf] = ACTIONS(6226),
    [anon_sym_not] = ACTIONS(6224),
    [anon_sym_NOT] = ACTIONS(6224),
    [anon_sym_Not] = ACTIONS(6224),
    [anon_sym_POUNDelse] = ACTIONS(6226),
    [anon_sym_POUNDELSE] = ACTIONS(6226),
    [anon_sym_POUNDElse] = ACTIONS(6226),
    [anon_sym_POUNDelse2] = ACTIONS(6226),
    [anon_sym_POUNDELSE2] = ACTIONS(6226),
    [anon_sym_POUNDElse2] = ACTIONS(6226),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6224),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6224),
    [anon_sym_PLUS] = ACTIONS(6226),
    [sym_datetime_literal] = ACTIONS(6226),
    [sym_date_literal] = ACTIONS(6224),
    [sym_time_literal] = ACTIONS(6224),
    [sym_biginteger_literal] = ACTIONS(6226),
    [anon_sym_if] = ACTIONS(6224),
    [anon_sym_IF] = ACTIONS(6224),
    [anon_sym_If] = ACTIONS(6224),
    [anon_sym_else] = ACTIONS(6224),
    [anon_sym_ELSE] = ACTIONS(6224),
    [anon_sym_Else] = ACTIONS(6224),
    [anon_sym_case] = ACTIONS(6224),
    [anon_sym_CASE] = ACTIONS(6224),
    [anon_sym_Case] = ACTIONS(6224),
    [anon_sym_for] = ACTIONS(6224),
    [anon_sym_FOR] = ACTIONS(6224),
    [anon_sym_For] = ACTIONS(6224),
    [anon_sym_foreach] = ACTIONS(6224),
    [anon_sym_FOREACH] = ACTIONS(6224),
    [anon_sym_Foreach] = ACTIONS(6224),
    [anon_sym_while] = ACTIONS(6224),
    [anon_sym_WHILE] = ACTIONS(6224),
    [anon_sym_While] = ACTIONS(6224),
    [anon_sym_repeat] = ACTIONS(6224),
    [anon_sym_REPEAT] = ACTIONS(6224),
    [anon_sym_Repeat] = ACTIONS(6224),
    [anon_sym_exit] = ACTIONS(6224),
    [anon_sym_EXIT] = ACTIONS(6224),
    [anon_sym_Exit] = ACTIONS(6224),
    [anon_sym_continue] = ACTIONS(6224),
    [anon_sym_CONTINUE] = ACTIONS(6224),
    [anon_sym_Continue] = ACTIONS(6224),
    [anon_sym_break] = ACTIONS(6224),
    [anon_sym_BREAK] = ACTIONS(6224),
    [anon_sym_Break] = ACTIONS(6224),
    [anon_sym_with] = ACTIONS(6224),
    [anon_sym_WITH] = ACTIONS(6224),
    [anon_sym_With] = ACTIONS(6224),
    [sym_asserterror_keyword] = ACTIONS(6226),
    [sym_page_keyword] = ACTIONS(6224),
    [anon_sym_codeunit] = ACTIONS(6224),
    [anon_sym_CODEUNIT] = ACTIONS(6224),
    [anon_sym_Codeunit] = ACTIONS(6224),
    [anon_sym_CodeUnit] = ACTIONS(6224),
    [anon_sym_COdeunit] = ACTIONS(6224),
    [anon_sym_codeUnit] = ACTIONS(6224),
    [sym_report_keyword] = ACTIONS(6224),
    [sym_query_keyword] = ACTIONS(6224),
    [anon_sym_xmlport] = ACTIONS(6224),
    [anon_sym_XMLPORT] = ACTIONS(6224),
    [anon_sym_Xmlport] = ACTIONS(6224),
    [anon_sym_XMLport] = ACTIONS(6224),
    [anon_sym_XMLPort] = ACTIONS(6224),
    [anon_sym_XmlPort] = ACTIONS(6224),
    [anon_sym_enum] = ACTIONS(6224),
    [anon_sym_ENUM] = ACTIONS(6224),
    [anon_sym_Enum] = ACTIONS(6224),
    [anon_sym_eNUM] = ACTIONS(6224),
    [anon_sym_eNum] = ACTIONS(6224),
    [anon_sym_ENum] = ACTIONS(6224),
    [sym_quoted_identifier] = ACTIONS(6226),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6226),
    [sym_verbatim_string] = ACTIONS(6226),
    [sym_integer] = ACTIONS(6224),
    [sym_continue_as_identifier] = ACTIONS(6226),
    [sym_preproc_open] = ACTIONS(6226),
    [sym_end_keyword] = ACTIONS(6226),
  },
  [STATE(3316)] = {
    [sym_identifier] = ACTIONS(6204),
    [anon_sym_SEMI] = ACTIONS(6206),
    [anon_sym_DASH] = ACTIONS(6206),
    [aux_sym_boolean_token1] = ACTIONS(6204),
    [aux_sym_boolean_token2] = ACTIONS(6204),
    [sym_decimal] = ACTIONS(6204),
    [anon_sym_LPAREN] = ACTIONS(6206),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6204),
    [anon_sym_LBRACK] = ACTIONS(6206),
    [aux_sym_record_type_token1] = ACTIONS(6204),
    [aux_sym_basic_type_token21] = ACTIONS(6204),
    [aux_sym_basic_type_token22] = ACTIONS(6204),
    [aux_sym_basic_type_token48] = ACTIONS(6204),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6204),
    [anon_sym_POUNDif] = ACTIONS(6206),
    [anon_sym_POUNDIF] = ACTIONS(6206),
    [anon_sym_POUNDIf] = ACTIONS(6206),
    [anon_sym_not] = ACTIONS(6204),
    [anon_sym_NOT] = ACTIONS(6204),
    [anon_sym_Not] = ACTIONS(6204),
    [anon_sym_POUNDelse] = ACTIONS(6206),
    [anon_sym_POUNDELSE] = ACTIONS(6206),
    [anon_sym_POUNDElse] = ACTIONS(6206),
    [anon_sym_POUNDelse2] = ACTIONS(6206),
    [anon_sym_POUNDELSE2] = ACTIONS(6206),
    [anon_sym_POUNDElse2] = ACTIONS(6206),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6204),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6204),
    [anon_sym_PLUS] = ACTIONS(6206),
    [sym_datetime_literal] = ACTIONS(6206),
    [sym_date_literal] = ACTIONS(6204),
    [sym_time_literal] = ACTIONS(6204),
    [sym_biginteger_literal] = ACTIONS(6206),
    [anon_sym_if] = ACTIONS(6204),
    [anon_sym_IF] = ACTIONS(6204),
    [anon_sym_If] = ACTIONS(6204),
    [anon_sym_else] = ACTIONS(6204),
    [anon_sym_ELSE] = ACTIONS(6204),
    [anon_sym_Else] = ACTIONS(6204),
    [anon_sym_case] = ACTIONS(6204),
    [anon_sym_CASE] = ACTIONS(6204),
    [anon_sym_Case] = ACTIONS(6204),
    [anon_sym_for] = ACTIONS(6204),
    [anon_sym_FOR] = ACTIONS(6204),
    [anon_sym_For] = ACTIONS(6204),
    [anon_sym_foreach] = ACTIONS(6204),
    [anon_sym_FOREACH] = ACTIONS(6204),
    [anon_sym_Foreach] = ACTIONS(6204),
    [anon_sym_while] = ACTIONS(6204),
    [anon_sym_WHILE] = ACTIONS(6204),
    [anon_sym_While] = ACTIONS(6204),
    [anon_sym_repeat] = ACTIONS(6204),
    [anon_sym_REPEAT] = ACTIONS(6204),
    [anon_sym_Repeat] = ACTIONS(6204),
    [anon_sym_exit] = ACTIONS(6204),
    [anon_sym_EXIT] = ACTIONS(6204),
    [anon_sym_Exit] = ACTIONS(6204),
    [anon_sym_continue] = ACTIONS(6204),
    [anon_sym_CONTINUE] = ACTIONS(6204),
    [anon_sym_Continue] = ACTIONS(6204),
    [anon_sym_break] = ACTIONS(6204),
    [anon_sym_BREAK] = ACTIONS(6204),
    [anon_sym_Break] = ACTIONS(6204),
    [anon_sym_with] = ACTIONS(6204),
    [anon_sym_WITH] = ACTIONS(6204),
    [anon_sym_With] = ACTIONS(6204),
    [sym_asserterror_keyword] = ACTIONS(6206),
    [sym_page_keyword] = ACTIONS(6204),
    [anon_sym_codeunit] = ACTIONS(6204),
    [anon_sym_CODEUNIT] = ACTIONS(6204),
    [anon_sym_Codeunit] = ACTIONS(6204),
    [anon_sym_CodeUnit] = ACTIONS(6204),
    [anon_sym_COdeunit] = ACTIONS(6204),
    [anon_sym_codeUnit] = ACTIONS(6204),
    [sym_report_keyword] = ACTIONS(6204),
    [sym_query_keyword] = ACTIONS(6204),
    [anon_sym_xmlport] = ACTIONS(6204),
    [anon_sym_XMLPORT] = ACTIONS(6204),
    [anon_sym_Xmlport] = ACTIONS(6204),
    [anon_sym_XMLport] = ACTIONS(6204),
    [anon_sym_XMLPort] = ACTIONS(6204),
    [anon_sym_XmlPort] = ACTIONS(6204),
    [anon_sym_enum] = ACTIONS(6204),
    [anon_sym_ENUM] = ACTIONS(6204),
    [anon_sym_Enum] = ACTIONS(6204),
    [anon_sym_eNUM] = ACTIONS(6204),
    [anon_sym_eNum] = ACTIONS(6204),
    [anon_sym_ENum] = ACTIONS(6204),
    [sym_quoted_identifier] = ACTIONS(6206),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6206),
    [sym_verbatim_string] = ACTIONS(6206),
    [sym_integer] = ACTIONS(6204),
    [sym_continue_as_identifier] = ACTIONS(6206),
    [sym_preproc_open] = ACTIONS(6206),
    [sym_end_keyword] = ACTIONS(6206),
  },
  [STATE(3317)] = {
    [sym_identifier] = ACTIONS(6208),
    [anon_sym_SEMI] = ACTIONS(6210),
    [anon_sym_DASH] = ACTIONS(6210),
    [aux_sym_boolean_token1] = ACTIONS(6208),
    [aux_sym_boolean_token2] = ACTIONS(6208),
    [sym_decimal] = ACTIONS(6208),
    [anon_sym_LPAREN] = ACTIONS(6210),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6208),
    [anon_sym_LBRACK] = ACTIONS(6210),
    [aux_sym_record_type_token1] = ACTIONS(6208),
    [aux_sym_basic_type_token21] = ACTIONS(6208),
    [aux_sym_basic_type_token22] = ACTIONS(6208),
    [aux_sym_basic_type_token48] = ACTIONS(6208),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6208),
    [anon_sym_POUNDif] = ACTIONS(6210),
    [anon_sym_POUNDIF] = ACTIONS(6210),
    [anon_sym_POUNDIf] = ACTIONS(6210),
    [anon_sym_not] = ACTIONS(6208),
    [anon_sym_NOT] = ACTIONS(6208),
    [anon_sym_Not] = ACTIONS(6208),
    [anon_sym_POUNDelse] = ACTIONS(6210),
    [anon_sym_POUNDELSE] = ACTIONS(6210),
    [anon_sym_POUNDElse] = ACTIONS(6210),
    [anon_sym_POUNDelse2] = ACTIONS(6210),
    [anon_sym_POUNDELSE2] = ACTIONS(6210),
    [anon_sym_POUNDElse2] = ACTIONS(6210),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6208),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6208),
    [anon_sym_PLUS] = ACTIONS(6210),
    [sym_datetime_literal] = ACTIONS(6210),
    [sym_date_literal] = ACTIONS(6208),
    [sym_time_literal] = ACTIONS(6208),
    [sym_biginteger_literal] = ACTIONS(6210),
    [anon_sym_if] = ACTIONS(6208),
    [anon_sym_IF] = ACTIONS(6208),
    [anon_sym_If] = ACTIONS(6208),
    [anon_sym_else] = ACTIONS(6208),
    [anon_sym_ELSE] = ACTIONS(6208),
    [anon_sym_Else] = ACTIONS(6208),
    [anon_sym_case] = ACTIONS(6208),
    [anon_sym_CASE] = ACTIONS(6208),
    [anon_sym_Case] = ACTIONS(6208),
    [anon_sym_for] = ACTIONS(6208),
    [anon_sym_FOR] = ACTIONS(6208),
    [anon_sym_For] = ACTIONS(6208),
    [anon_sym_foreach] = ACTIONS(6208),
    [anon_sym_FOREACH] = ACTIONS(6208),
    [anon_sym_Foreach] = ACTIONS(6208),
    [anon_sym_while] = ACTIONS(6208),
    [anon_sym_WHILE] = ACTIONS(6208),
    [anon_sym_While] = ACTIONS(6208),
    [anon_sym_repeat] = ACTIONS(6208),
    [anon_sym_REPEAT] = ACTIONS(6208),
    [anon_sym_Repeat] = ACTIONS(6208),
    [anon_sym_exit] = ACTIONS(6208),
    [anon_sym_EXIT] = ACTIONS(6208),
    [anon_sym_Exit] = ACTIONS(6208),
    [anon_sym_continue] = ACTIONS(6208),
    [anon_sym_CONTINUE] = ACTIONS(6208),
    [anon_sym_Continue] = ACTIONS(6208),
    [anon_sym_break] = ACTIONS(6208),
    [anon_sym_BREAK] = ACTIONS(6208),
    [anon_sym_Break] = ACTIONS(6208),
    [anon_sym_with] = ACTIONS(6208),
    [anon_sym_WITH] = ACTIONS(6208),
    [anon_sym_With] = ACTIONS(6208),
    [sym_asserterror_keyword] = ACTIONS(6210),
    [sym_page_keyword] = ACTIONS(6208),
    [anon_sym_codeunit] = ACTIONS(6208),
    [anon_sym_CODEUNIT] = ACTIONS(6208),
    [anon_sym_Codeunit] = ACTIONS(6208),
    [anon_sym_CodeUnit] = ACTIONS(6208),
    [anon_sym_COdeunit] = ACTIONS(6208),
    [anon_sym_codeUnit] = ACTIONS(6208),
    [sym_report_keyword] = ACTIONS(6208),
    [sym_query_keyword] = ACTIONS(6208),
    [anon_sym_xmlport] = ACTIONS(6208),
    [anon_sym_XMLPORT] = ACTIONS(6208),
    [anon_sym_Xmlport] = ACTIONS(6208),
    [anon_sym_XMLport] = ACTIONS(6208),
    [anon_sym_XMLPort] = ACTIONS(6208),
    [anon_sym_XmlPort] = ACTIONS(6208),
    [anon_sym_enum] = ACTIONS(6208),
    [anon_sym_ENUM] = ACTIONS(6208),
    [anon_sym_Enum] = ACTIONS(6208),
    [anon_sym_eNUM] = ACTIONS(6208),
    [anon_sym_eNum] = ACTIONS(6208),
    [anon_sym_ENum] = ACTIONS(6208),
    [sym_quoted_identifier] = ACTIONS(6210),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6210),
    [sym_verbatim_string] = ACTIONS(6210),
    [sym_integer] = ACTIONS(6208),
    [sym_continue_as_identifier] = ACTIONS(6210),
    [sym_preproc_open] = ACTIONS(6210),
    [sym_end_keyword] = ACTIONS(6210),
  },
  [STATE(3318)] = {
    [sym_identifier] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5519),
    [anon_sym_DASH] = ACTIONS(5519),
    [aux_sym_boolean_token1] = ACTIONS(5517),
    [aux_sym_boolean_token2] = ACTIONS(5517),
    [sym_decimal] = ACTIONS(5517),
    [anon_sym_LPAREN] = ACTIONS(5519),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5519),
    [aux_sym_record_type_token1] = ACTIONS(5517),
    [aux_sym_basic_type_token21] = ACTIONS(5517),
    [aux_sym_basic_type_token22] = ACTIONS(5517),
    [aux_sym_basic_type_token48] = ACTIONS(5517),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5517),
    [anon_sym_POUNDif] = ACTIONS(5519),
    [anon_sym_POUNDIF] = ACTIONS(5519),
    [anon_sym_POUNDIf] = ACTIONS(5519),
    [anon_sym_not] = ACTIONS(5517),
    [anon_sym_NOT] = ACTIONS(5517),
    [anon_sym_Not] = ACTIONS(5517),
    [anon_sym_POUNDelse] = ACTIONS(5519),
    [anon_sym_POUNDELSE] = ACTIONS(5519),
    [anon_sym_POUNDElse] = ACTIONS(5519),
    [anon_sym_POUNDelse2] = ACTIONS(5519),
    [anon_sym_POUNDELSE2] = ACTIONS(5519),
    [anon_sym_POUNDElse2] = ACTIONS(5519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5517),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5517),
    [anon_sym_PLUS] = ACTIONS(5519),
    [sym_datetime_literal] = ACTIONS(5519),
    [sym_date_literal] = ACTIONS(5517),
    [sym_time_literal] = ACTIONS(5517),
    [sym_biginteger_literal] = ACTIONS(5519),
    [anon_sym_if] = ACTIONS(5517),
    [anon_sym_IF] = ACTIONS(5517),
    [anon_sym_If] = ACTIONS(5517),
    [anon_sym_else] = ACTIONS(5517),
    [anon_sym_ELSE] = ACTIONS(5517),
    [anon_sym_Else] = ACTIONS(5517),
    [anon_sym_case] = ACTIONS(5517),
    [anon_sym_CASE] = ACTIONS(5517),
    [anon_sym_Case] = ACTIONS(5517),
    [anon_sym_for] = ACTIONS(5517),
    [anon_sym_FOR] = ACTIONS(5517),
    [anon_sym_For] = ACTIONS(5517),
    [anon_sym_foreach] = ACTIONS(5517),
    [anon_sym_FOREACH] = ACTIONS(5517),
    [anon_sym_Foreach] = ACTIONS(5517),
    [anon_sym_while] = ACTIONS(5517),
    [anon_sym_WHILE] = ACTIONS(5517),
    [anon_sym_While] = ACTIONS(5517),
    [anon_sym_repeat] = ACTIONS(5517),
    [anon_sym_REPEAT] = ACTIONS(5517),
    [anon_sym_Repeat] = ACTIONS(5517),
    [anon_sym_exit] = ACTIONS(5517),
    [anon_sym_EXIT] = ACTIONS(5517),
    [anon_sym_Exit] = ACTIONS(5517),
    [anon_sym_continue] = ACTIONS(5517),
    [anon_sym_CONTINUE] = ACTIONS(5517),
    [anon_sym_Continue] = ACTIONS(5517),
    [anon_sym_break] = ACTIONS(5517),
    [anon_sym_BREAK] = ACTIONS(5517),
    [anon_sym_Break] = ACTIONS(5517),
    [anon_sym_with] = ACTIONS(5517),
    [anon_sym_WITH] = ACTIONS(5517),
    [anon_sym_With] = ACTIONS(5517),
    [sym_asserterror_keyword] = ACTIONS(5519),
    [sym_page_keyword] = ACTIONS(5517),
    [anon_sym_codeunit] = ACTIONS(5517),
    [anon_sym_CODEUNIT] = ACTIONS(5517),
    [anon_sym_Codeunit] = ACTIONS(5517),
    [anon_sym_CodeUnit] = ACTIONS(5517),
    [anon_sym_COdeunit] = ACTIONS(5517),
    [anon_sym_codeUnit] = ACTIONS(5517),
    [sym_report_keyword] = ACTIONS(5517),
    [sym_query_keyword] = ACTIONS(5517),
    [anon_sym_xmlport] = ACTIONS(5517),
    [anon_sym_XMLPORT] = ACTIONS(5517),
    [anon_sym_Xmlport] = ACTIONS(5517),
    [anon_sym_XMLport] = ACTIONS(5517),
    [anon_sym_XMLPort] = ACTIONS(5517),
    [anon_sym_XmlPort] = ACTIONS(5517),
    [anon_sym_enum] = ACTIONS(5517),
    [anon_sym_ENUM] = ACTIONS(5517),
    [anon_sym_Enum] = ACTIONS(5517),
    [anon_sym_eNUM] = ACTIONS(5517),
    [anon_sym_eNum] = ACTIONS(5517),
    [anon_sym_ENum] = ACTIONS(5517),
    [sym_quoted_identifier] = ACTIONS(5519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5519),
    [sym_verbatim_string] = ACTIONS(5519),
    [sym_integer] = ACTIONS(5517),
    [sym_continue_as_identifier] = ACTIONS(5519),
    [sym_preproc_open] = ACTIONS(5519),
    [sym_end_keyword] = ACTIONS(5519),
  },
  [STATE(3319)] = {
    [sym_identifier] = ACTIONS(5749),
    [anon_sym_SEMI] = ACTIONS(5751),
    [anon_sym_DASH] = ACTIONS(5751),
    [aux_sym_boolean_token1] = ACTIONS(5749),
    [aux_sym_boolean_token2] = ACTIONS(5749),
    [sym_decimal] = ACTIONS(5749),
    [anon_sym_LPAREN] = ACTIONS(5751),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5749),
    [anon_sym_LBRACK] = ACTIONS(5751),
    [aux_sym_record_type_token1] = ACTIONS(5749),
    [aux_sym_basic_type_token21] = ACTIONS(5749),
    [aux_sym_basic_type_token22] = ACTIONS(5749),
    [aux_sym_basic_type_token48] = ACTIONS(5749),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5749),
    [anon_sym_POUNDif] = ACTIONS(5751),
    [anon_sym_POUNDIF] = ACTIONS(5751),
    [anon_sym_POUNDIf] = ACTIONS(5751),
    [anon_sym_not] = ACTIONS(5749),
    [anon_sym_NOT] = ACTIONS(5749),
    [anon_sym_Not] = ACTIONS(5749),
    [anon_sym_POUNDelse] = ACTIONS(5751),
    [anon_sym_POUNDELSE] = ACTIONS(5751),
    [anon_sym_POUNDElse] = ACTIONS(5751),
    [anon_sym_POUNDelse2] = ACTIONS(5751),
    [anon_sym_POUNDELSE2] = ACTIONS(5751),
    [anon_sym_POUNDElse2] = ACTIONS(5751),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5749),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5749),
    [anon_sym_PLUS] = ACTIONS(5751),
    [sym_datetime_literal] = ACTIONS(5751),
    [sym_date_literal] = ACTIONS(5749),
    [sym_time_literal] = ACTIONS(5749),
    [sym_biginteger_literal] = ACTIONS(5751),
    [anon_sym_if] = ACTIONS(5749),
    [anon_sym_IF] = ACTIONS(5749),
    [anon_sym_If] = ACTIONS(5749),
    [anon_sym_else] = ACTIONS(5749),
    [anon_sym_ELSE] = ACTIONS(5749),
    [anon_sym_Else] = ACTIONS(5749),
    [anon_sym_case] = ACTIONS(5749),
    [anon_sym_CASE] = ACTIONS(5749),
    [anon_sym_Case] = ACTIONS(5749),
    [anon_sym_for] = ACTIONS(5749),
    [anon_sym_FOR] = ACTIONS(5749),
    [anon_sym_For] = ACTIONS(5749),
    [anon_sym_foreach] = ACTIONS(5749),
    [anon_sym_FOREACH] = ACTIONS(5749),
    [anon_sym_Foreach] = ACTIONS(5749),
    [anon_sym_while] = ACTIONS(5749),
    [anon_sym_WHILE] = ACTIONS(5749),
    [anon_sym_While] = ACTIONS(5749),
    [anon_sym_repeat] = ACTIONS(5749),
    [anon_sym_REPEAT] = ACTIONS(5749),
    [anon_sym_Repeat] = ACTIONS(5749),
    [anon_sym_exit] = ACTIONS(5749),
    [anon_sym_EXIT] = ACTIONS(5749),
    [anon_sym_Exit] = ACTIONS(5749),
    [anon_sym_continue] = ACTIONS(5749),
    [anon_sym_CONTINUE] = ACTIONS(5749),
    [anon_sym_Continue] = ACTIONS(5749),
    [anon_sym_break] = ACTIONS(5749),
    [anon_sym_BREAK] = ACTIONS(5749),
    [anon_sym_Break] = ACTIONS(5749),
    [anon_sym_with] = ACTIONS(5749),
    [anon_sym_WITH] = ACTIONS(5749),
    [anon_sym_With] = ACTIONS(5749),
    [sym_asserterror_keyword] = ACTIONS(5751),
    [sym_page_keyword] = ACTIONS(5749),
    [anon_sym_codeunit] = ACTIONS(5749),
    [anon_sym_CODEUNIT] = ACTIONS(5749),
    [anon_sym_Codeunit] = ACTIONS(5749),
    [anon_sym_CodeUnit] = ACTIONS(5749),
    [anon_sym_COdeunit] = ACTIONS(5749),
    [anon_sym_codeUnit] = ACTIONS(5749),
    [sym_report_keyword] = ACTIONS(5749),
    [sym_query_keyword] = ACTIONS(5749),
    [anon_sym_xmlport] = ACTIONS(5749),
    [anon_sym_XMLPORT] = ACTIONS(5749),
    [anon_sym_Xmlport] = ACTIONS(5749),
    [anon_sym_XMLport] = ACTIONS(5749),
    [anon_sym_XMLPort] = ACTIONS(5749),
    [anon_sym_XmlPort] = ACTIONS(5749),
    [anon_sym_enum] = ACTIONS(5749),
    [anon_sym_ENUM] = ACTIONS(5749),
    [anon_sym_Enum] = ACTIONS(5749),
    [anon_sym_eNUM] = ACTIONS(5749),
    [anon_sym_eNum] = ACTIONS(5749),
    [anon_sym_ENum] = ACTIONS(5749),
    [sym_quoted_identifier] = ACTIONS(5751),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5751),
    [sym_verbatim_string] = ACTIONS(5751),
    [sym_integer] = ACTIONS(5749),
    [sym_continue_as_identifier] = ACTIONS(5751),
    [sym_preproc_open] = ACTIONS(5751),
    [sym_end_keyword] = ACTIONS(5751),
  },
  [STATE(3320)] = {
    [sym_identifier] = ACTIONS(5753),
    [anon_sym_SEMI] = ACTIONS(5755),
    [anon_sym_DASH] = ACTIONS(5755),
    [aux_sym_boolean_token1] = ACTIONS(5753),
    [aux_sym_boolean_token2] = ACTIONS(5753),
    [sym_decimal] = ACTIONS(5753),
    [anon_sym_LPAREN] = ACTIONS(5755),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5753),
    [anon_sym_LBRACK] = ACTIONS(5755),
    [aux_sym_record_type_token1] = ACTIONS(5753),
    [aux_sym_basic_type_token21] = ACTIONS(5753),
    [aux_sym_basic_type_token22] = ACTIONS(5753),
    [aux_sym_basic_type_token48] = ACTIONS(5753),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5753),
    [anon_sym_POUNDif] = ACTIONS(5755),
    [anon_sym_POUNDIF] = ACTIONS(5755),
    [anon_sym_POUNDIf] = ACTIONS(5755),
    [anon_sym_not] = ACTIONS(5753),
    [anon_sym_NOT] = ACTIONS(5753),
    [anon_sym_Not] = ACTIONS(5753),
    [anon_sym_POUNDelse] = ACTIONS(5755),
    [anon_sym_POUNDELSE] = ACTIONS(5755),
    [anon_sym_POUNDElse] = ACTIONS(5755),
    [anon_sym_POUNDelse2] = ACTIONS(5755),
    [anon_sym_POUNDELSE2] = ACTIONS(5755),
    [anon_sym_POUNDElse2] = ACTIONS(5755),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5753),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5753),
    [anon_sym_PLUS] = ACTIONS(5755),
    [sym_datetime_literal] = ACTIONS(5755),
    [sym_date_literal] = ACTIONS(5753),
    [sym_time_literal] = ACTIONS(5753),
    [sym_biginteger_literal] = ACTIONS(5755),
    [anon_sym_if] = ACTIONS(5753),
    [anon_sym_IF] = ACTIONS(5753),
    [anon_sym_If] = ACTIONS(5753),
    [anon_sym_else] = ACTIONS(5753),
    [anon_sym_ELSE] = ACTIONS(5753),
    [anon_sym_Else] = ACTIONS(5753),
    [anon_sym_case] = ACTIONS(5753),
    [anon_sym_CASE] = ACTIONS(5753),
    [anon_sym_Case] = ACTIONS(5753),
    [anon_sym_for] = ACTIONS(5753),
    [anon_sym_FOR] = ACTIONS(5753),
    [anon_sym_For] = ACTIONS(5753),
    [anon_sym_foreach] = ACTIONS(5753),
    [anon_sym_FOREACH] = ACTIONS(5753),
    [anon_sym_Foreach] = ACTIONS(5753),
    [anon_sym_while] = ACTIONS(5753),
    [anon_sym_WHILE] = ACTIONS(5753),
    [anon_sym_While] = ACTIONS(5753),
    [anon_sym_repeat] = ACTIONS(5753),
    [anon_sym_REPEAT] = ACTIONS(5753),
    [anon_sym_Repeat] = ACTIONS(5753),
    [anon_sym_exit] = ACTIONS(5753),
    [anon_sym_EXIT] = ACTIONS(5753),
    [anon_sym_Exit] = ACTIONS(5753),
    [anon_sym_continue] = ACTIONS(5753),
    [anon_sym_CONTINUE] = ACTIONS(5753),
    [anon_sym_Continue] = ACTIONS(5753),
    [anon_sym_break] = ACTIONS(5753),
    [anon_sym_BREAK] = ACTIONS(5753),
    [anon_sym_Break] = ACTIONS(5753),
    [anon_sym_with] = ACTIONS(5753),
    [anon_sym_WITH] = ACTIONS(5753),
    [anon_sym_With] = ACTIONS(5753),
    [sym_asserterror_keyword] = ACTIONS(5755),
    [sym_page_keyword] = ACTIONS(5753),
    [anon_sym_codeunit] = ACTIONS(5753),
    [anon_sym_CODEUNIT] = ACTIONS(5753),
    [anon_sym_Codeunit] = ACTIONS(5753),
    [anon_sym_CodeUnit] = ACTIONS(5753),
    [anon_sym_COdeunit] = ACTIONS(5753),
    [anon_sym_codeUnit] = ACTIONS(5753),
    [sym_report_keyword] = ACTIONS(5753),
    [sym_query_keyword] = ACTIONS(5753),
    [anon_sym_xmlport] = ACTIONS(5753),
    [anon_sym_XMLPORT] = ACTIONS(5753),
    [anon_sym_Xmlport] = ACTIONS(5753),
    [anon_sym_XMLport] = ACTIONS(5753),
    [anon_sym_XMLPort] = ACTIONS(5753),
    [anon_sym_XmlPort] = ACTIONS(5753),
    [anon_sym_enum] = ACTIONS(5753),
    [anon_sym_ENUM] = ACTIONS(5753),
    [anon_sym_Enum] = ACTIONS(5753),
    [anon_sym_eNUM] = ACTIONS(5753),
    [anon_sym_eNum] = ACTIONS(5753),
    [anon_sym_ENum] = ACTIONS(5753),
    [sym_quoted_identifier] = ACTIONS(5755),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5755),
    [sym_verbatim_string] = ACTIONS(5755),
    [sym_integer] = ACTIONS(5753),
    [sym_continue_as_identifier] = ACTIONS(5755),
    [sym_preproc_open] = ACTIONS(5755),
    [sym_end_keyword] = ACTIONS(5755),
  },
  [STATE(3321)] = {
    [sym_identifier] = ACTIONS(5757),
    [anon_sym_SEMI] = ACTIONS(5759),
    [anon_sym_DASH] = ACTIONS(5759),
    [aux_sym_boolean_token1] = ACTIONS(5757),
    [aux_sym_boolean_token2] = ACTIONS(5757),
    [sym_decimal] = ACTIONS(5757),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5757),
    [anon_sym_LBRACK] = ACTIONS(5759),
    [aux_sym_record_type_token1] = ACTIONS(5757),
    [aux_sym_basic_type_token21] = ACTIONS(5757),
    [aux_sym_basic_type_token22] = ACTIONS(5757),
    [aux_sym_basic_type_token48] = ACTIONS(5757),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5757),
    [anon_sym_POUNDif] = ACTIONS(5759),
    [anon_sym_POUNDIF] = ACTIONS(5759),
    [anon_sym_POUNDIf] = ACTIONS(5759),
    [anon_sym_not] = ACTIONS(5757),
    [anon_sym_NOT] = ACTIONS(5757),
    [anon_sym_Not] = ACTIONS(5757),
    [anon_sym_POUNDelse] = ACTIONS(5759),
    [anon_sym_POUNDELSE] = ACTIONS(5759),
    [anon_sym_POUNDElse] = ACTIONS(5759),
    [anon_sym_POUNDelse2] = ACTIONS(5759),
    [anon_sym_POUNDELSE2] = ACTIONS(5759),
    [anon_sym_POUNDElse2] = ACTIONS(5759),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5757),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5757),
    [anon_sym_PLUS] = ACTIONS(5759),
    [sym_datetime_literal] = ACTIONS(5759),
    [sym_date_literal] = ACTIONS(5757),
    [sym_time_literal] = ACTIONS(5757),
    [sym_biginteger_literal] = ACTIONS(5759),
    [anon_sym_if] = ACTIONS(5757),
    [anon_sym_IF] = ACTIONS(5757),
    [anon_sym_If] = ACTIONS(5757),
    [anon_sym_else] = ACTIONS(5757),
    [anon_sym_ELSE] = ACTIONS(5757),
    [anon_sym_Else] = ACTIONS(5757),
    [anon_sym_case] = ACTIONS(5757),
    [anon_sym_CASE] = ACTIONS(5757),
    [anon_sym_Case] = ACTIONS(5757),
    [anon_sym_for] = ACTIONS(5757),
    [anon_sym_FOR] = ACTIONS(5757),
    [anon_sym_For] = ACTIONS(5757),
    [anon_sym_foreach] = ACTIONS(5757),
    [anon_sym_FOREACH] = ACTIONS(5757),
    [anon_sym_Foreach] = ACTIONS(5757),
    [anon_sym_while] = ACTIONS(5757),
    [anon_sym_WHILE] = ACTIONS(5757),
    [anon_sym_While] = ACTIONS(5757),
    [anon_sym_repeat] = ACTIONS(5757),
    [anon_sym_REPEAT] = ACTIONS(5757),
    [anon_sym_Repeat] = ACTIONS(5757),
    [anon_sym_exit] = ACTIONS(5757),
    [anon_sym_EXIT] = ACTIONS(5757),
    [anon_sym_Exit] = ACTIONS(5757),
    [anon_sym_continue] = ACTIONS(5757),
    [anon_sym_CONTINUE] = ACTIONS(5757),
    [anon_sym_Continue] = ACTIONS(5757),
    [anon_sym_break] = ACTIONS(5757),
    [anon_sym_BREAK] = ACTIONS(5757),
    [anon_sym_Break] = ACTIONS(5757),
    [anon_sym_with] = ACTIONS(5757),
    [anon_sym_WITH] = ACTIONS(5757),
    [anon_sym_With] = ACTIONS(5757),
    [sym_asserterror_keyword] = ACTIONS(5759),
    [sym_page_keyword] = ACTIONS(5757),
    [anon_sym_codeunit] = ACTIONS(5757),
    [anon_sym_CODEUNIT] = ACTIONS(5757),
    [anon_sym_Codeunit] = ACTIONS(5757),
    [anon_sym_CodeUnit] = ACTIONS(5757),
    [anon_sym_COdeunit] = ACTIONS(5757),
    [anon_sym_codeUnit] = ACTIONS(5757),
    [sym_report_keyword] = ACTIONS(5757),
    [sym_query_keyword] = ACTIONS(5757),
    [anon_sym_xmlport] = ACTIONS(5757),
    [anon_sym_XMLPORT] = ACTIONS(5757),
    [anon_sym_Xmlport] = ACTIONS(5757),
    [anon_sym_XMLport] = ACTIONS(5757),
    [anon_sym_XMLPort] = ACTIONS(5757),
    [anon_sym_XmlPort] = ACTIONS(5757),
    [anon_sym_enum] = ACTIONS(5757),
    [anon_sym_ENUM] = ACTIONS(5757),
    [anon_sym_Enum] = ACTIONS(5757),
    [anon_sym_eNUM] = ACTIONS(5757),
    [anon_sym_eNum] = ACTIONS(5757),
    [anon_sym_ENum] = ACTIONS(5757),
    [sym_quoted_identifier] = ACTIONS(5759),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5759),
    [sym_verbatim_string] = ACTIONS(5759),
    [sym_integer] = ACTIONS(5757),
    [sym_continue_as_identifier] = ACTIONS(5759),
    [sym_preproc_open] = ACTIONS(5759),
    [sym_end_keyword] = ACTIONS(5759),
  },
  [STATE(3322)] = {
    [sym_identifier] = ACTIONS(5761),
    [anon_sym_SEMI] = ACTIONS(5763),
    [anon_sym_DASH] = ACTIONS(5763),
    [aux_sym_boolean_token1] = ACTIONS(5761),
    [aux_sym_boolean_token2] = ACTIONS(5761),
    [sym_decimal] = ACTIONS(5761),
    [anon_sym_LPAREN] = ACTIONS(5763),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5761),
    [anon_sym_LBRACK] = ACTIONS(5763),
    [aux_sym_record_type_token1] = ACTIONS(5761),
    [aux_sym_basic_type_token21] = ACTIONS(5761),
    [aux_sym_basic_type_token22] = ACTIONS(5761),
    [aux_sym_basic_type_token48] = ACTIONS(5761),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5761),
    [anon_sym_POUNDif] = ACTIONS(5763),
    [anon_sym_POUNDIF] = ACTIONS(5763),
    [anon_sym_POUNDIf] = ACTIONS(5763),
    [anon_sym_not] = ACTIONS(5761),
    [anon_sym_NOT] = ACTIONS(5761),
    [anon_sym_Not] = ACTIONS(5761),
    [anon_sym_POUNDelse] = ACTIONS(5763),
    [anon_sym_POUNDELSE] = ACTIONS(5763),
    [anon_sym_POUNDElse] = ACTIONS(5763),
    [anon_sym_POUNDelse2] = ACTIONS(5763),
    [anon_sym_POUNDELSE2] = ACTIONS(5763),
    [anon_sym_POUNDElse2] = ACTIONS(5763),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5761),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5761),
    [anon_sym_PLUS] = ACTIONS(5763),
    [sym_datetime_literal] = ACTIONS(5763),
    [sym_date_literal] = ACTIONS(5761),
    [sym_time_literal] = ACTIONS(5761),
    [sym_biginteger_literal] = ACTIONS(5763),
    [anon_sym_if] = ACTIONS(5761),
    [anon_sym_IF] = ACTIONS(5761),
    [anon_sym_If] = ACTIONS(5761),
    [anon_sym_else] = ACTIONS(5761),
    [anon_sym_ELSE] = ACTIONS(5761),
    [anon_sym_Else] = ACTIONS(5761),
    [anon_sym_case] = ACTIONS(5761),
    [anon_sym_CASE] = ACTIONS(5761),
    [anon_sym_Case] = ACTIONS(5761),
    [anon_sym_for] = ACTIONS(5761),
    [anon_sym_FOR] = ACTIONS(5761),
    [anon_sym_For] = ACTIONS(5761),
    [anon_sym_foreach] = ACTIONS(5761),
    [anon_sym_FOREACH] = ACTIONS(5761),
    [anon_sym_Foreach] = ACTIONS(5761),
    [anon_sym_while] = ACTIONS(5761),
    [anon_sym_WHILE] = ACTIONS(5761),
    [anon_sym_While] = ACTIONS(5761),
    [anon_sym_repeat] = ACTIONS(5761),
    [anon_sym_REPEAT] = ACTIONS(5761),
    [anon_sym_Repeat] = ACTIONS(5761),
    [anon_sym_exit] = ACTIONS(5761),
    [anon_sym_EXIT] = ACTIONS(5761),
    [anon_sym_Exit] = ACTIONS(5761),
    [anon_sym_continue] = ACTIONS(5761),
    [anon_sym_CONTINUE] = ACTIONS(5761),
    [anon_sym_Continue] = ACTIONS(5761),
    [anon_sym_break] = ACTIONS(5761),
    [anon_sym_BREAK] = ACTIONS(5761),
    [anon_sym_Break] = ACTIONS(5761),
    [anon_sym_with] = ACTIONS(5761),
    [anon_sym_WITH] = ACTIONS(5761),
    [anon_sym_With] = ACTIONS(5761),
    [sym_asserterror_keyword] = ACTIONS(5763),
    [sym_page_keyword] = ACTIONS(5761),
    [anon_sym_codeunit] = ACTIONS(5761),
    [anon_sym_CODEUNIT] = ACTIONS(5761),
    [anon_sym_Codeunit] = ACTIONS(5761),
    [anon_sym_CodeUnit] = ACTIONS(5761),
    [anon_sym_COdeunit] = ACTIONS(5761),
    [anon_sym_codeUnit] = ACTIONS(5761),
    [sym_report_keyword] = ACTIONS(5761),
    [sym_query_keyword] = ACTIONS(5761),
    [anon_sym_xmlport] = ACTIONS(5761),
    [anon_sym_XMLPORT] = ACTIONS(5761),
    [anon_sym_Xmlport] = ACTIONS(5761),
    [anon_sym_XMLport] = ACTIONS(5761),
    [anon_sym_XMLPort] = ACTIONS(5761),
    [anon_sym_XmlPort] = ACTIONS(5761),
    [anon_sym_enum] = ACTIONS(5761),
    [anon_sym_ENUM] = ACTIONS(5761),
    [anon_sym_Enum] = ACTIONS(5761),
    [anon_sym_eNUM] = ACTIONS(5761),
    [anon_sym_eNum] = ACTIONS(5761),
    [anon_sym_ENum] = ACTIONS(5761),
    [sym_quoted_identifier] = ACTIONS(5763),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5763),
    [sym_verbatim_string] = ACTIONS(5763),
    [sym_integer] = ACTIONS(5761),
    [sym_continue_as_identifier] = ACTIONS(5763),
    [sym_preproc_open] = ACTIONS(5763),
    [sym_end_keyword] = ACTIONS(5763),
  },
  [STATE(3323)] = {
    [sym_identifier] = ACTIONS(5765),
    [anon_sym_SEMI] = ACTIONS(5767),
    [anon_sym_DASH] = ACTIONS(5767),
    [aux_sym_boolean_token1] = ACTIONS(5765),
    [aux_sym_boolean_token2] = ACTIONS(5765),
    [sym_decimal] = ACTIONS(5765),
    [anon_sym_LPAREN] = ACTIONS(5767),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5765),
    [anon_sym_LBRACK] = ACTIONS(5767),
    [aux_sym_record_type_token1] = ACTIONS(5765),
    [aux_sym_basic_type_token21] = ACTIONS(5765),
    [aux_sym_basic_type_token22] = ACTIONS(5765),
    [aux_sym_basic_type_token48] = ACTIONS(5765),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5765),
    [anon_sym_POUNDif] = ACTIONS(5767),
    [anon_sym_POUNDIF] = ACTIONS(5767),
    [anon_sym_POUNDIf] = ACTIONS(5767),
    [anon_sym_not] = ACTIONS(5765),
    [anon_sym_NOT] = ACTIONS(5765),
    [anon_sym_Not] = ACTIONS(5765),
    [anon_sym_POUNDelse] = ACTIONS(5767),
    [anon_sym_POUNDELSE] = ACTIONS(5767),
    [anon_sym_POUNDElse] = ACTIONS(5767),
    [anon_sym_POUNDelse2] = ACTIONS(5767),
    [anon_sym_POUNDELSE2] = ACTIONS(5767),
    [anon_sym_POUNDElse2] = ACTIONS(5767),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5765),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5765),
    [anon_sym_PLUS] = ACTIONS(5767),
    [sym_datetime_literal] = ACTIONS(5767),
    [sym_date_literal] = ACTIONS(5765),
    [sym_time_literal] = ACTIONS(5765),
    [sym_biginteger_literal] = ACTIONS(5767),
    [anon_sym_if] = ACTIONS(5765),
    [anon_sym_IF] = ACTIONS(5765),
    [anon_sym_If] = ACTIONS(5765),
    [anon_sym_else] = ACTIONS(5765),
    [anon_sym_ELSE] = ACTIONS(5765),
    [anon_sym_Else] = ACTIONS(5765),
    [anon_sym_case] = ACTIONS(5765),
    [anon_sym_CASE] = ACTIONS(5765),
    [anon_sym_Case] = ACTIONS(5765),
    [anon_sym_for] = ACTIONS(5765),
    [anon_sym_FOR] = ACTIONS(5765),
    [anon_sym_For] = ACTIONS(5765),
    [anon_sym_foreach] = ACTIONS(5765),
    [anon_sym_FOREACH] = ACTIONS(5765),
    [anon_sym_Foreach] = ACTIONS(5765),
    [anon_sym_while] = ACTIONS(5765),
    [anon_sym_WHILE] = ACTIONS(5765),
    [anon_sym_While] = ACTIONS(5765),
    [anon_sym_repeat] = ACTIONS(5765),
    [anon_sym_REPEAT] = ACTIONS(5765),
    [anon_sym_Repeat] = ACTIONS(5765),
    [anon_sym_exit] = ACTIONS(5765),
    [anon_sym_EXIT] = ACTIONS(5765),
    [anon_sym_Exit] = ACTIONS(5765),
    [anon_sym_continue] = ACTIONS(5765),
    [anon_sym_CONTINUE] = ACTIONS(5765),
    [anon_sym_Continue] = ACTIONS(5765),
    [anon_sym_break] = ACTIONS(5765),
    [anon_sym_BREAK] = ACTIONS(5765),
    [anon_sym_Break] = ACTIONS(5765),
    [anon_sym_with] = ACTIONS(5765),
    [anon_sym_WITH] = ACTIONS(5765),
    [anon_sym_With] = ACTIONS(5765),
    [sym_asserterror_keyword] = ACTIONS(5767),
    [sym_page_keyword] = ACTIONS(5765),
    [anon_sym_codeunit] = ACTIONS(5765),
    [anon_sym_CODEUNIT] = ACTIONS(5765),
    [anon_sym_Codeunit] = ACTIONS(5765),
    [anon_sym_CodeUnit] = ACTIONS(5765),
    [anon_sym_COdeunit] = ACTIONS(5765),
    [anon_sym_codeUnit] = ACTIONS(5765),
    [sym_report_keyword] = ACTIONS(5765),
    [sym_query_keyword] = ACTIONS(5765),
    [anon_sym_xmlport] = ACTIONS(5765),
    [anon_sym_XMLPORT] = ACTIONS(5765),
    [anon_sym_Xmlport] = ACTIONS(5765),
    [anon_sym_XMLport] = ACTIONS(5765),
    [anon_sym_XMLPort] = ACTIONS(5765),
    [anon_sym_XmlPort] = ACTIONS(5765),
    [anon_sym_enum] = ACTIONS(5765),
    [anon_sym_ENUM] = ACTIONS(5765),
    [anon_sym_Enum] = ACTIONS(5765),
    [anon_sym_eNUM] = ACTIONS(5765),
    [anon_sym_eNum] = ACTIONS(5765),
    [anon_sym_ENum] = ACTIONS(5765),
    [sym_quoted_identifier] = ACTIONS(5767),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5767),
    [sym_verbatim_string] = ACTIONS(5767),
    [sym_integer] = ACTIONS(5765),
    [sym_continue_as_identifier] = ACTIONS(5767),
    [sym_preproc_open] = ACTIONS(5767),
    [sym_end_keyword] = ACTIONS(5767),
  },
  [STATE(3324)] = {
    [sym_identifier] = ACTIONS(5769),
    [anon_sym_SEMI] = ACTIONS(5771),
    [anon_sym_DASH] = ACTIONS(5771),
    [aux_sym_boolean_token1] = ACTIONS(5769),
    [aux_sym_boolean_token2] = ACTIONS(5769),
    [sym_decimal] = ACTIONS(5769),
    [anon_sym_LPAREN] = ACTIONS(5771),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5769),
    [anon_sym_LBRACK] = ACTIONS(5771),
    [aux_sym_record_type_token1] = ACTIONS(5769),
    [aux_sym_basic_type_token21] = ACTIONS(5769),
    [aux_sym_basic_type_token22] = ACTIONS(5769),
    [aux_sym_basic_type_token48] = ACTIONS(5769),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5769),
    [anon_sym_POUNDif] = ACTIONS(5771),
    [anon_sym_POUNDIF] = ACTIONS(5771),
    [anon_sym_POUNDIf] = ACTIONS(5771),
    [anon_sym_not] = ACTIONS(5769),
    [anon_sym_NOT] = ACTIONS(5769),
    [anon_sym_Not] = ACTIONS(5769),
    [anon_sym_POUNDelse] = ACTIONS(5771),
    [anon_sym_POUNDELSE] = ACTIONS(5771),
    [anon_sym_POUNDElse] = ACTIONS(5771),
    [anon_sym_POUNDelse2] = ACTIONS(5771),
    [anon_sym_POUNDELSE2] = ACTIONS(5771),
    [anon_sym_POUNDElse2] = ACTIONS(5771),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5769),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5769),
    [anon_sym_PLUS] = ACTIONS(5771),
    [sym_datetime_literal] = ACTIONS(5771),
    [sym_date_literal] = ACTIONS(5769),
    [sym_time_literal] = ACTIONS(5769),
    [sym_biginteger_literal] = ACTIONS(5771),
    [anon_sym_if] = ACTIONS(5769),
    [anon_sym_IF] = ACTIONS(5769),
    [anon_sym_If] = ACTIONS(5769),
    [anon_sym_else] = ACTIONS(5769),
    [anon_sym_ELSE] = ACTIONS(5769),
    [anon_sym_Else] = ACTIONS(5769),
    [anon_sym_case] = ACTIONS(5769),
    [anon_sym_CASE] = ACTIONS(5769),
    [anon_sym_Case] = ACTIONS(5769),
    [anon_sym_for] = ACTIONS(5769),
    [anon_sym_FOR] = ACTIONS(5769),
    [anon_sym_For] = ACTIONS(5769),
    [anon_sym_foreach] = ACTIONS(5769),
    [anon_sym_FOREACH] = ACTIONS(5769),
    [anon_sym_Foreach] = ACTIONS(5769),
    [anon_sym_while] = ACTIONS(5769),
    [anon_sym_WHILE] = ACTIONS(5769),
    [anon_sym_While] = ACTIONS(5769),
    [anon_sym_repeat] = ACTIONS(5769),
    [anon_sym_REPEAT] = ACTIONS(5769),
    [anon_sym_Repeat] = ACTIONS(5769),
    [anon_sym_exit] = ACTIONS(5769),
    [anon_sym_EXIT] = ACTIONS(5769),
    [anon_sym_Exit] = ACTIONS(5769),
    [anon_sym_continue] = ACTIONS(5769),
    [anon_sym_CONTINUE] = ACTIONS(5769),
    [anon_sym_Continue] = ACTIONS(5769),
    [anon_sym_break] = ACTIONS(5769),
    [anon_sym_BREAK] = ACTIONS(5769),
    [anon_sym_Break] = ACTIONS(5769),
    [anon_sym_with] = ACTIONS(5769),
    [anon_sym_WITH] = ACTIONS(5769),
    [anon_sym_With] = ACTIONS(5769),
    [sym_asserterror_keyword] = ACTIONS(5771),
    [sym_page_keyword] = ACTIONS(5769),
    [anon_sym_codeunit] = ACTIONS(5769),
    [anon_sym_CODEUNIT] = ACTIONS(5769),
    [anon_sym_Codeunit] = ACTIONS(5769),
    [anon_sym_CodeUnit] = ACTIONS(5769),
    [anon_sym_COdeunit] = ACTIONS(5769),
    [anon_sym_codeUnit] = ACTIONS(5769),
    [sym_report_keyword] = ACTIONS(5769),
    [sym_query_keyword] = ACTIONS(5769),
    [anon_sym_xmlport] = ACTIONS(5769),
    [anon_sym_XMLPORT] = ACTIONS(5769),
    [anon_sym_Xmlport] = ACTIONS(5769),
    [anon_sym_XMLport] = ACTIONS(5769),
    [anon_sym_XMLPort] = ACTIONS(5769),
    [anon_sym_XmlPort] = ACTIONS(5769),
    [anon_sym_enum] = ACTIONS(5769),
    [anon_sym_ENUM] = ACTIONS(5769),
    [anon_sym_Enum] = ACTIONS(5769),
    [anon_sym_eNUM] = ACTIONS(5769),
    [anon_sym_eNum] = ACTIONS(5769),
    [anon_sym_ENum] = ACTIONS(5769),
    [sym_quoted_identifier] = ACTIONS(5771),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5771),
    [sym_verbatim_string] = ACTIONS(5771),
    [sym_integer] = ACTIONS(5769),
    [sym_continue_as_identifier] = ACTIONS(5771),
    [sym_preproc_open] = ACTIONS(5771),
    [sym_end_keyword] = ACTIONS(5771),
  },
  [STATE(3325)] = {
    [sym_identifier] = ACTIONS(6212),
    [anon_sym_SEMI] = ACTIONS(6214),
    [anon_sym_DASH] = ACTIONS(6214),
    [aux_sym_boolean_token1] = ACTIONS(6212),
    [aux_sym_boolean_token2] = ACTIONS(6212),
    [sym_decimal] = ACTIONS(6212),
    [anon_sym_LPAREN] = ACTIONS(6214),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6212),
    [anon_sym_LBRACK] = ACTIONS(6214),
    [aux_sym_record_type_token1] = ACTIONS(6212),
    [aux_sym_basic_type_token21] = ACTIONS(6212),
    [aux_sym_basic_type_token22] = ACTIONS(6212),
    [aux_sym_basic_type_token48] = ACTIONS(6212),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6212),
    [anon_sym_POUNDif] = ACTIONS(6214),
    [anon_sym_POUNDIF] = ACTIONS(6214),
    [anon_sym_POUNDIf] = ACTIONS(6214),
    [anon_sym_not] = ACTIONS(6212),
    [anon_sym_NOT] = ACTIONS(6212),
    [anon_sym_Not] = ACTIONS(6212),
    [anon_sym_POUNDelse] = ACTIONS(6214),
    [anon_sym_POUNDELSE] = ACTIONS(6214),
    [anon_sym_POUNDElse] = ACTIONS(6214),
    [anon_sym_POUNDelse2] = ACTIONS(6214),
    [anon_sym_POUNDELSE2] = ACTIONS(6214),
    [anon_sym_POUNDElse2] = ACTIONS(6214),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6212),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6212),
    [anon_sym_PLUS] = ACTIONS(6214),
    [sym_datetime_literal] = ACTIONS(6214),
    [sym_date_literal] = ACTIONS(6212),
    [sym_time_literal] = ACTIONS(6212),
    [sym_biginteger_literal] = ACTIONS(6214),
    [anon_sym_if] = ACTIONS(6212),
    [anon_sym_IF] = ACTIONS(6212),
    [anon_sym_If] = ACTIONS(6212),
    [anon_sym_else] = ACTIONS(6212),
    [anon_sym_ELSE] = ACTIONS(6212),
    [anon_sym_Else] = ACTIONS(6212),
    [anon_sym_case] = ACTIONS(6212),
    [anon_sym_CASE] = ACTIONS(6212),
    [anon_sym_Case] = ACTIONS(6212),
    [anon_sym_for] = ACTIONS(6212),
    [anon_sym_FOR] = ACTIONS(6212),
    [anon_sym_For] = ACTIONS(6212),
    [anon_sym_foreach] = ACTIONS(6212),
    [anon_sym_FOREACH] = ACTIONS(6212),
    [anon_sym_Foreach] = ACTIONS(6212),
    [anon_sym_while] = ACTIONS(6212),
    [anon_sym_WHILE] = ACTIONS(6212),
    [anon_sym_While] = ACTIONS(6212),
    [anon_sym_repeat] = ACTIONS(6212),
    [anon_sym_REPEAT] = ACTIONS(6212),
    [anon_sym_Repeat] = ACTIONS(6212),
    [anon_sym_exit] = ACTIONS(6212),
    [anon_sym_EXIT] = ACTIONS(6212),
    [anon_sym_Exit] = ACTIONS(6212),
    [anon_sym_continue] = ACTIONS(6212),
    [anon_sym_CONTINUE] = ACTIONS(6212),
    [anon_sym_Continue] = ACTIONS(6212),
    [anon_sym_break] = ACTIONS(6212),
    [anon_sym_BREAK] = ACTIONS(6212),
    [anon_sym_Break] = ACTIONS(6212),
    [anon_sym_with] = ACTIONS(6212),
    [anon_sym_WITH] = ACTIONS(6212),
    [anon_sym_With] = ACTIONS(6212),
    [sym_asserterror_keyword] = ACTIONS(6214),
    [sym_page_keyword] = ACTIONS(6212),
    [anon_sym_codeunit] = ACTIONS(6212),
    [anon_sym_CODEUNIT] = ACTIONS(6212),
    [anon_sym_Codeunit] = ACTIONS(6212),
    [anon_sym_CodeUnit] = ACTIONS(6212),
    [anon_sym_COdeunit] = ACTIONS(6212),
    [anon_sym_codeUnit] = ACTIONS(6212),
    [sym_report_keyword] = ACTIONS(6212),
    [sym_query_keyword] = ACTIONS(6212),
    [anon_sym_xmlport] = ACTIONS(6212),
    [anon_sym_XMLPORT] = ACTIONS(6212),
    [anon_sym_Xmlport] = ACTIONS(6212),
    [anon_sym_XMLport] = ACTIONS(6212),
    [anon_sym_XMLPort] = ACTIONS(6212),
    [anon_sym_XmlPort] = ACTIONS(6212),
    [anon_sym_enum] = ACTIONS(6212),
    [anon_sym_ENUM] = ACTIONS(6212),
    [anon_sym_Enum] = ACTIONS(6212),
    [anon_sym_eNUM] = ACTIONS(6212),
    [anon_sym_eNum] = ACTIONS(6212),
    [anon_sym_ENum] = ACTIONS(6212),
    [sym_quoted_identifier] = ACTIONS(6214),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6214),
    [sym_verbatim_string] = ACTIONS(6214),
    [sym_integer] = ACTIONS(6212),
    [sym_continue_as_identifier] = ACTIONS(6214),
    [sym_preproc_open] = ACTIONS(6214),
    [sym_end_keyword] = ACTIONS(6214),
  },
  [STATE(3326)] = {
    [sym_identifier] = ACTIONS(6240),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6242),
    [aux_sym_boolean_token1] = ACTIONS(6240),
    [aux_sym_boolean_token2] = ACTIONS(6240),
    [sym_decimal] = ACTIONS(6240),
    [anon_sym_LPAREN] = ACTIONS(6242),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6240),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [aux_sym_record_type_token1] = ACTIONS(6240),
    [aux_sym_basic_type_token21] = ACTIONS(6240),
    [aux_sym_basic_type_token22] = ACTIONS(6240),
    [aux_sym_basic_type_token48] = ACTIONS(6240),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6240),
    [anon_sym_POUNDif] = ACTIONS(6242),
    [anon_sym_POUNDIF] = ACTIONS(6242),
    [anon_sym_POUNDIf] = ACTIONS(6242),
    [anon_sym_not] = ACTIONS(6240),
    [anon_sym_NOT] = ACTIONS(6240),
    [anon_sym_Not] = ACTIONS(6240),
    [anon_sym_POUNDelse] = ACTIONS(6242),
    [anon_sym_POUNDELSE] = ACTIONS(6242),
    [anon_sym_POUNDElse] = ACTIONS(6242),
    [anon_sym_POUNDelse2] = ACTIONS(6242),
    [anon_sym_POUNDELSE2] = ACTIONS(6242),
    [anon_sym_POUNDElse2] = ACTIONS(6242),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6240),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6242),
    [sym_datetime_literal] = ACTIONS(6242),
    [sym_date_literal] = ACTIONS(6240),
    [sym_time_literal] = ACTIONS(6240),
    [sym_biginteger_literal] = ACTIONS(6242),
    [anon_sym_if] = ACTIONS(6240),
    [anon_sym_IF] = ACTIONS(6240),
    [anon_sym_If] = ACTIONS(6240),
    [anon_sym_else] = ACTIONS(6240),
    [anon_sym_ELSE] = ACTIONS(6240),
    [anon_sym_Else] = ACTIONS(6240),
    [anon_sym_case] = ACTIONS(6240),
    [anon_sym_CASE] = ACTIONS(6240),
    [anon_sym_Case] = ACTIONS(6240),
    [anon_sym_for] = ACTIONS(6240),
    [anon_sym_FOR] = ACTIONS(6240),
    [anon_sym_For] = ACTIONS(6240),
    [anon_sym_foreach] = ACTIONS(6240),
    [anon_sym_FOREACH] = ACTIONS(6240),
    [anon_sym_Foreach] = ACTIONS(6240),
    [anon_sym_while] = ACTIONS(6240),
    [anon_sym_WHILE] = ACTIONS(6240),
    [anon_sym_While] = ACTIONS(6240),
    [anon_sym_repeat] = ACTIONS(6240),
    [anon_sym_REPEAT] = ACTIONS(6240),
    [anon_sym_Repeat] = ACTIONS(6240),
    [anon_sym_exit] = ACTIONS(6240),
    [anon_sym_EXIT] = ACTIONS(6240),
    [anon_sym_Exit] = ACTIONS(6240),
    [anon_sym_continue] = ACTIONS(6240),
    [anon_sym_CONTINUE] = ACTIONS(6240),
    [anon_sym_Continue] = ACTIONS(6240),
    [anon_sym_break] = ACTIONS(6240),
    [anon_sym_BREAK] = ACTIONS(6240),
    [anon_sym_Break] = ACTIONS(6240),
    [anon_sym_with] = ACTIONS(6240),
    [anon_sym_WITH] = ACTIONS(6240),
    [anon_sym_With] = ACTIONS(6240),
    [sym_asserterror_keyword] = ACTIONS(6242),
    [sym_page_keyword] = ACTIONS(6240),
    [anon_sym_codeunit] = ACTIONS(6240),
    [anon_sym_CODEUNIT] = ACTIONS(6240),
    [anon_sym_Codeunit] = ACTIONS(6240),
    [anon_sym_CodeUnit] = ACTIONS(6240),
    [anon_sym_COdeunit] = ACTIONS(6240),
    [anon_sym_codeUnit] = ACTIONS(6240),
    [sym_report_keyword] = ACTIONS(6240),
    [sym_query_keyword] = ACTIONS(6240),
    [anon_sym_xmlport] = ACTIONS(6240),
    [anon_sym_XMLPORT] = ACTIONS(6240),
    [anon_sym_Xmlport] = ACTIONS(6240),
    [anon_sym_XMLport] = ACTIONS(6240),
    [anon_sym_XMLPort] = ACTIONS(6240),
    [anon_sym_XmlPort] = ACTIONS(6240),
    [anon_sym_enum] = ACTIONS(6240),
    [anon_sym_ENUM] = ACTIONS(6240),
    [anon_sym_Enum] = ACTIONS(6240),
    [anon_sym_eNUM] = ACTIONS(6240),
    [anon_sym_eNum] = ACTIONS(6240),
    [anon_sym_ENum] = ACTIONS(6240),
    [sym_quoted_identifier] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6242),
    [sym_verbatim_string] = ACTIONS(6242),
    [sym_integer] = ACTIONS(6240),
    [sym_continue_as_identifier] = ACTIONS(6242),
    [sym_preproc_open] = ACTIONS(6242),
    [sym_end_keyword] = ACTIONS(6242),
  },
  [STATE(3327)] = {
    [sym_identifier] = ACTIONS(6244),
    [anon_sym_SEMI] = ACTIONS(6246),
    [anon_sym_DASH] = ACTIONS(6246),
    [aux_sym_boolean_token1] = ACTIONS(6244),
    [aux_sym_boolean_token2] = ACTIONS(6244),
    [sym_decimal] = ACTIONS(6244),
    [anon_sym_LPAREN] = ACTIONS(6246),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6244),
    [anon_sym_LBRACK] = ACTIONS(6246),
    [aux_sym_record_type_token1] = ACTIONS(6244),
    [aux_sym_basic_type_token21] = ACTIONS(6244),
    [aux_sym_basic_type_token22] = ACTIONS(6244),
    [aux_sym_basic_type_token48] = ACTIONS(6244),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6244),
    [anon_sym_POUNDif] = ACTIONS(6246),
    [anon_sym_POUNDIF] = ACTIONS(6246),
    [anon_sym_POUNDIf] = ACTIONS(6246),
    [anon_sym_not] = ACTIONS(6244),
    [anon_sym_NOT] = ACTIONS(6244),
    [anon_sym_Not] = ACTIONS(6244),
    [anon_sym_POUNDelse] = ACTIONS(6246),
    [anon_sym_POUNDELSE] = ACTIONS(6246),
    [anon_sym_POUNDElse] = ACTIONS(6246),
    [anon_sym_POUNDelse2] = ACTIONS(6246),
    [anon_sym_POUNDELSE2] = ACTIONS(6246),
    [anon_sym_POUNDElse2] = ACTIONS(6246),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6244),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6244),
    [anon_sym_PLUS] = ACTIONS(6246),
    [sym_datetime_literal] = ACTIONS(6246),
    [sym_date_literal] = ACTIONS(6244),
    [sym_time_literal] = ACTIONS(6244),
    [sym_biginteger_literal] = ACTIONS(6246),
    [anon_sym_if] = ACTIONS(6244),
    [anon_sym_IF] = ACTIONS(6244),
    [anon_sym_If] = ACTIONS(6244),
    [anon_sym_else] = ACTIONS(6244),
    [anon_sym_ELSE] = ACTIONS(6244),
    [anon_sym_Else] = ACTIONS(6244),
    [anon_sym_case] = ACTIONS(6244),
    [anon_sym_CASE] = ACTIONS(6244),
    [anon_sym_Case] = ACTIONS(6244),
    [anon_sym_for] = ACTIONS(6244),
    [anon_sym_FOR] = ACTIONS(6244),
    [anon_sym_For] = ACTIONS(6244),
    [anon_sym_foreach] = ACTIONS(6244),
    [anon_sym_FOREACH] = ACTIONS(6244),
    [anon_sym_Foreach] = ACTIONS(6244),
    [anon_sym_while] = ACTIONS(6244),
    [anon_sym_WHILE] = ACTIONS(6244),
    [anon_sym_While] = ACTIONS(6244),
    [anon_sym_repeat] = ACTIONS(6244),
    [anon_sym_REPEAT] = ACTIONS(6244),
    [anon_sym_Repeat] = ACTIONS(6244),
    [anon_sym_exit] = ACTIONS(6244),
    [anon_sym_EXIT] = ACTIONS(6244),
    [anon_sym_Exit] = ACTIONS(6244),
    [anon_sym_continue] = ACTIONS(6244),
    [anon_sym_CONTINUE] = ACTIONS(6244),
    [anon_sym_Continue] = ACTIONS(6244),
    [anon_sym_break] = ACTIONS(6244),
    [anon_sym_BREAK] = ACTIONS(6244),
    [anon_sym_Break] = ACTIONS(6244),
    [anon_sym_with] = ACTIONS(6244),
    [anon_sym_WITH] = ACTIONS(6244),
    [anon_sym_With] = ACTIONS(6244),
    [sym_asserterror_keyword] = ACTIONS(6246),
    [sym_page_keyword] = ACTIONS(6244),
    [anon_sym_codeunit] = ACTIONS(6244),
    [anon_sym_CODEUNIT] = ACTIONS(6244),
    [anon_sym_Codeunit] = ACTIONS(6244),
    [anon_sym_CodeUnit] = ACTIONS(6244),
    [anon_sym_COdeunit] = ACTIONS(6244),
    [anon_sym_codeUnit] = ACTIONS(6244),
    [sym_report_keyword] = ACTIONS(6244),
    [sym_query_keyword] = ACTIONS(6244),
    [anon_sym_xmlport] = ACTIONS(6244),
    [anon_sym_XMLPORT] = ACTIONS(6244),
    [anon_sym_Xmlport] = ACTIONS(6244),
    [anon_sym_XMLport] = ACTIONS(6244),
    [anon_sym_XMLPort] = ACTIONS(6244),
    [anon_sym_XmlPort] = ACTIONS(6244),
    [anon_sym_enum] = ACTIONS(6244),
    [anon_sym_ENUM] = ACTIONS(6244),
    [anon_sym_Enum] = ACTIONS(6244),
    [anon_sym_eNUM] = ACTIONS(6244),
    [anon_sym_eNum] = ACTIONS(6244),
    [anon_sym_ENum] = ACTIONS(6244),
    [sym_quoted_identifier] = ACTIONS(6246),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6246),
    [sym_verbatim_string] = ACTIONS(6246),
    [sym_integer] = ACTIONS(6244),
    [sym_continue_as_identifier] = ACTIONS(6246),
    [sym_preproc_open] = ACTIONS(6246),
    [sym_end_keyword] = ACTIONS(6246),
  },
  [STATE(3328)] = {
    [sym_identifier] = ACTIONS(5773),
    [anon_sym_SEMI] = ACTIONS(5775),
    [anon_sym_DASH] = ACTIONS(5775),
    [aux_sym_boolean_token1] = ACTIONS(5773),
    [aux_sym_boolean_token2] = ACTIONS(5773),
    [sym_decimal] = ACTIONS(5773),
    [anon_sym_LPAREN] = ACTIONS(5775),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5773),
    [anon_sym_LBRACK] = ACTIONS(5775),
    [aux_sym_record_type_token1] = ACTIONS(5773),
    [aux_sym_basic_type_token21] = ACTIONS(5773),
    [aux_sym_basic_type_token22] = ACTIONS(5773),
    [aux_sym_basic_type_token48] = ACTIONS(5773),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5773),
    [anon_sym_POUNDif] = ACTIONS(5775),
    [anon_sym_POUNDIF] = ACTIONS(5775),
    [anon_sym_POUNDIf] = ACTIONS(5775),
    [anon_sym_not] = ACTIONS(5773),
    [anon_sym_NOT] = ACTIONS(5773),
    [anon_sym_Not] = ACTIONS(5773),
    [anon_sym_POUNDelse] = ACTIONS(5775),
    [anon_sym_POUNDELSE] = ACTIONS(5775),
    [anon_sym_POUNDElse] = ACTIONS(5775),
    [anon_sym_POUNDelse2] = ACTIONS(5775),
    [anon_sym_POUNDELSE2] = ACTIONS(5775),
    [anon_sym_POUNDElse2] = ACTIONS(5775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5773),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5773),
    [anon_sym_PLUS] = ACTIONS(5775),
    [sym_datetime_literal] = ACTIONS(5775),
    [sym_date_literal] = ACTIONS(5773),
    [sym_time_literal] = ACTIONS(5773),
    [sym_biginteger_literal] = ACTIONS(5775),
    [anon_sym_if] = ACTIONS(5773),
    [anon_sym_IF] = ACTIONS(5773),
    [anon_sym_If] = ACTIONS(5773),
    [anon_sym_else] = ACTIONS(5773),
    [anon_sym_ELSE] = ACTIONS(5773),
    [anon_sym_Else] = ACTIONS(5773),
    [anon_sym_case] = ACTIONS(5773),
    [anon_sym_CASE] = ACTIONS(5773),
    [anon_sym_Case] = ACTIONS(5773),
    [anon_sym_for] = ACTIONS(5773),
    [anon_sym_FOR] = ACTIONS(5773),
    [anon_sym_For] = ACTIONS(5773),
    [anon_sym_foreach] = ACTIONS(5773),
    [anon_sym_FOREACH] = ACTIONS(5773),
    [anon_sym_Foreach] = ACTIONS(5773),
    [anon_sym_while] = ACTIONS(5773),
    [anon_sym_WHILE] = ACTIONS(5773),
    [anon_sym_While] = ACTIONS(5773),
    [anon_sym_repeat] = ACTIONS(5773),
    [anon_sym_REPEAT] = ACTIONS(5773),
    [anon_sym_Repeat] = ACTIONS(5773),
    [anon_sym_exit] = ACTIONS(5773),
    [anon_sym_EXIT] = ACTIONS(5773),
    [anon_sym_Exit] = ACTIONS(5773),
    [anon_sym_continue] = ACTIONS(5773),
    [anon_sym_CONTINUE] = ACTIONS(5773),
    [anon_sym_Continue] = ACTIONS(5773),
    [anon_sym_break] = ACTIONS(5773),
    [anon_sym_BREAK] = ACTIONS(5773),
    [anon_sym_Break] = ACTIONS(5773),
    [anon_sym_with] = ACTIONS(5773),
    [anon_sym_WITH] = ACTIONS(5773),
    [anon_sym_With] = ACTIONS(5773),
    [sym_asserterror_keyword] = ACTIONS(5775),
    [sym_page_keyword] = ACTIONS(5773),
    [anon_sym_codeunit] = ACTIONS(5773),
    [anon_sym_CODEUNIT] = ACTIONS(5773),
    [anon_sym_Codeunit] = ACTIONS(5773),
    [anon_sym_CodeUnit] = ACTIONS(5773),
    [anon_sym_COdeunit] = ACTIONS(5773),
    [anon_sym_codeUnit] = ACTIONS(5773),
    [sym_report_keyword] = ACTIONS(5773),
    [sym_query_keyword] = ACTIONS(5773),
    [anon_sym_xmlport] = ACTIONS(5773),
    [anon_sym_XMLPORT] = ACTIONS(5773),
    [anon_sym_Xmlport] = ACTIONS(5773),
    [anon_sym_XMLport] = ACTIONS(5773),
    [anon_sym_XMLPort] = ACTIONS(5773),
    [anon_sym_XmlPort] = ACTIONS(5773),
    [anon_sym_enum] = ACTIONS(5773),
    [anon_sym_ENUM] = ACTIONS(5773),
    [anon_sym_Enum] = ACTIONS(5773),
    [anon_sym_eNUM] = ACTIONS(5773),
    [anon_sym_eNum] = ACTIONS(5773),
    [anon_sym_ENum] = ACTIONS(5773),
    [sym_quoted_identifier] = ACTIONS(5775),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5775),
    [sym_verbatim_string] = ACTIONS(5775),
    [sym_integer] = ACTIONS(5773),
    [sym_continue_as_identifier] = ACTIONS(5775),
    [sym_preproc_open] = ACTIONS(5775),
    [sym_end_keyword] = ACTIONS(5775),
  },
  [STATE(3329)] = {
    [sym_identifier] = ACTIONS(6240),
    [anon_sym_SEMI] = ACTIONS(6242),
    [anon_sym_DASH] = ACTIONS(6242),
    [aux_sym_boolean_token1] = ACTIONS(6240),
    [aux_sym_boolean_token2] = ACTIONS(6240),
    [sym_decimal] = ACTIONS(6240),
    [anon_sym_LPAREN] = ACTIONS(6242),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6240),
    [anon_sym_LBRACK] = ACTIONS(6242),
    [aux_sym_record_type_token1] = ACTIONS(6240),
    [aux_sym_basic_type_token21] = ACTIONS(6240),
    [aux_sym_basic_type_token22] = ACTIONS(6240),
    [aux_sym_basic_type_token48] = ACTIONS(6240),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6240),
    [anon_sym_POUNDif] = ACTIONS(6242),
    [anon_sym_POUNDIF] = ACTIONS(6242),
    [anon_sym_POUNDIf] = ACTIONS(6242),
    [anon_sym_not] = ACTIONS(6240),
    [anon_sym_NOT] = ACTIONS(6240),
    [anon_sym_Not] = ACTIONS(6240),
    [anon_sym_POUNDelse] = ACTIONS(6242),
    [anon_sym_POUNDELSE] = ACTIONS(6242),
    [anon_sym_POUNDElse] = ACTIONS(6242),
    [anon_sym_POUNDelse2] = ACTIONS(6242),
    [anon_sym_POUNDELSE2] = ACTIONS(6242),
    [anon_sym_POUNDElse2] = ACTIONS(6242),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6240),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6240),
    [anon_sym_PLUS] = ACTIONS(6242),
    [sym_datetime_literal] = ACTIONS(6242),
    [sym_date_literal] = ACTIONS(6240),
    [sym_time_literal] = ACTIONS(6240),
    [sym_biginteger_literal] = ACTIONS(6242),
    [anon_sym_if] = ACTIONS(6240),
    [anon_sym_IF] = ACTIONS(6240),
    [anon_sym_If] = ACTIONS(6240),
    [anon_sym_else] = ACTIONS(6240),
    [anon_sym_ELSE] = ACTIONS(6240),
    [anon_sym_Else] = ACTIONS(6240),
    [anon_sym_case] = ACTIONS(6240),
    [anon_sym_CASE] = ACTIONS(6240),
    [anon_sym_Case] = ACTIONS(6240),
    [anon_sym_for] = ACTIONS(6240),
    [anon_sym_FOR] = ACTIONS(6240),
    [anon_sym_For] = ACTIONS(6240),
    [anon_sym_foreach] = ACTIONS(6240),
    [anon_sym_FOREACH] = ACTIONS(6240),
    [anon_sym_Foreach] = ACTIONS(6240),
    [anon_sym_while] = ACTIONS(6240),
    [anon_sym_WHILE] = ACTIONS(6240),
    [anon_sym_While] = ACTIONS(6240),
    [anon_sym_repeat] = ACTIONS(6240),
    [anon_sym_REPEAT] = ACTIONS(6240),
    [anon_sym_Repeat] = ACTIONS(6240),
    [anon_sym_exit] = ACTIONS(6240),
    [anon_sym_EXIT] = ACTIONS(6240),
    [anon_sym_Exit] = ACTIONS(6240),
    [anon_sym_continue] = ACTIONS(6240),
    [anon_sym_CONTINUE] = ACTIONS(6240),
    [anon_sym_Continue] = ACTIONS(6240),
    [anon_sym_break] = ACTIONS(6240),
    [anon_sym_BREAK] = ACTIONS(6240),
    [anon_sym_Break] = ACTIONS(6240),
    [anon_sym_with] = ACTIONS(6240),
    [anon_sym_WITH] = ACTIONS(6240),
    [anon_sym_With] = ACTIONS(6240),
    [sym_asserterror_keyword] = ACTIONS(6242),
    [sym_page_keyword] = ACTIONS(6240),
    [anon_sym_codeunit] = ACTIONS(6240),
    [anon_sym_CODEUNIT] = ACTIONS(6240),
    [anon_sym_Codeunit] = ACTIONS(6240),
    [anon_sym_CodeUnit] = ACTIONS(6240),
    [anon_sym_COdeunit] = ACTIONS(6240),
    [anon_sym_codeUnit] = ACTIONS(6240),
    [sym_report_keyword] = ACTIONS(6240),
    [sym_query_keyword] = ACTIONS(6240),
    [anon_sym_xmlport] = ACTIONS(6240),
    [anon_sym_XMLPORT] = ACTIONS(6240),
    [anon_sym_Xmlport] = ACTIONS(6240),
    [anon_sym_XMLport] = ACTIONS(6240),
    [anon_sym_XMLPort] = ACTIONS(6240),
    [anon_sym_XmlPort] = ACTIONS(6240),
    [anon_sym_enum] = ACTIONS(6240),
    [anon_sym_ENUM] = ACTIONS(6240),
    [anon_sym_Enum] = ACTIONS(6240),
    [anon_sym_eNUM] = ACTIONS(6240),
    [anon_sym_eNum] = ACTIONS(6240),
    [anon_sym_ENum] = ACTIONS(6240),
    [sym_quoted_identifier] = ACTIONS(6242),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6242),
    [sym_verbatim_string] = ACTIONS(6242),
    [sym_integer] = ACTIONS(6240),
    [sym_continue_as_identifier] = ACTIONS(6242),
    [sym_preproc_open] = ACTIONS(6242),
    [sym_end_keyword] = ACTIONS(6242),
  },
  [STATE(3330)] = {
    [sym_identifier] = ACTIONS(5521),
    [anon_sym_SEMI] = ACTIONS(5523),
    [anon_sym_DASH] = ACTIONS(5523),
    [aux_sym_boolean_token1] = ACTIONS(5521),
    [aux_sym_boolean_token2] = ACTIONS(5521),
    [sym_decimal] = ACTIONS(5521),
    [anon_sym_LPAREN] = ACTIONS(5523),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5521),
    [anon_sym_LBRACK] = ACTIONS(5523),
    [aux_sym_record_type_token1] = ACTIONS(5521),
    [aux_sym_basic_type_token21] = ACTIONS(5521),
    [aux_sym_basic_type_token22] = ACTIONS(5521),
    [aux_sym_basic_type_token48] = ACTIONS(5521),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5521),
    [anon_sym_POUNDif] = ACTIONS(5523),
    [anon_sym_POUNDIF] = ACTIONS(5523),
    [anon_sym_POUNDIf] = ACTIONS(5523),
    [anon_sym_not] = ACTIONS(5521),
    [anon_sym_NOT] = ACTIONS(5521),
    [anon_sym_Not] = ACTIONS(5521),
    [anon_sym_POUNDelse] = ACTIONS(5523),
    [anon_sym_POUNDELSE] = ACTIONS(5523),
    [anon_sym_POUNDElse] = ACTIONS(5523),
    [anon_sym_POUNDelse2] = ACTIONS(5523),
    [anon_sym_POUNDELSE2] = ACTIONS(5523),
    [anon_sym_POUNDElse2] = ACTIONS(5523),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5521),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5521),
    [anon_sym_PLUS] = ACTIONS(5523),
    [sym_datetime_literal] = ACTIONS(5523),
    [sym_date_literal] = ACTIONS(5521),
    [sym_time_literal] = ACTIONS(5521),
    [sym_biginteger_literal] = ACTIONS(5523),
    [anon_sym_if] = ACTIONS(5521),
    [anon_sym_IF] = ACTIONS(5521),
    [anon_sym_If] = ACTIONS(5521),
    [anon_sym_else] = ACTIONS(5521),
    [anon_sym_ELSE] = ACTIONS(5521),
    [anon_sym_Else] = ACTIONS(5521),
    [anon_sym_case] = ACTIONS(5521),
    [anon_sym_CASE] = ACTIONS(5521),
    [anon_sym_Case] = ACTIONS(5521),
    [anon_sym_for] = ACTIONS(5521),
    [anon_sym_FOR] = ACTIONS(5521),
    [anon_sym_For] = ACTIONS(5521),
    [anon_sym_foreach] = ACTIONS(5521),
    [anon_sym_FOREACH] = ACTIONS(5521),
    [anon_sym_Foreach] = ACTIONS(5521),
    [anon_sym_while] = ACTIONS(5521),
    [anon_sym_WHILE] = ACTIONS(5521),
    [anon_sym_While] = ACTIONS(5521),
    [anon_sym_repeat] = ACTIONS(5521),
    [anon_sym_REPEAT] = ACTIONS(5521),
    [anon_sym_Repeat] = ACTIONS(5521),
    [anon_sym_exit] = ACTIONS(5521),
    [anon_sym_EXIT] = ACTIONS(5521),
    [anon_sym_Exit] = ACTIONS(5521),
    [anon_sym_continue] = ACTIONS(5521),
    [anon_sym_CONTINUE] = ACTIONS(5521),
    [anon_sym_Continue] = ACTIONS(5521),
    [anon_sym_break] = ACTIONS(5521),
    [anon_sym_BREAK] = ACTIONS(5521),
    [anon_sym_Break] = ACTIONS(5521),
    [anon_sym_with] = ACTIONS(5521),
    [anon_sym_WITH] = ACTIONS(5521),
    [anon_sym_With] = ACTIONS(5521),
    [sym_asserterror_keyword] = ACTIONS(5523),
    [sym_page_keyword] = ACTIONS(5521),
    [anon_sym_codeunit] = ACTIONS(5521),
    [anon_sym_CODEUNIT] = ACTIONS(5521),
    [anon_sym_Codeunit] = ACTIONS(5521),
    [anon_sym_CodeUnit] = ACTIONS(5521),
    [anon_sym_COdeunit] = ACTIONS(5521),
    [anon_sym_codeUnit] = ACTIONS(5521),
    [sym_report_keyword] = ACTIONS(5521),
    [sym_query_keyword] = ACTIONS(5521),
    [anon_sym_xmlport] = ACTIONS(5521),
    [anon_sym_XMLPORT] = ACTIONS(5521),
    [anon_sym_Xmlport] = ACTIONS(5521),
    [anon_sym_XMLport] = ACTIONS(5521),
    [anon_sym_XMLPort] = ACTIONS(5521),
    [anon_sym_XmlPort] = ACTIONS(5521),
    [anon_sym_enum] = ACTIONS(5521),
    [anon_sym_ENUM] = ACTIONS(5521),
    [anon_sym_Enum] = ACTIONS(5521),
    [anon_sym_eNUM] = ACTIONS(5521),
    [anon_sym_eNum] = ACTIONS(5521),
    [anon_sym_ENum] = ACTIONS(5521),
    [sym_quoted_identifier] = ACTIONS(5523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5523),
    [sym_verbatim_string] = ACTIONS(5523),
    [sym_integer] = ACTIONS(5521),
    [sym_continue_as_identifier] = ACTIONS(5523),
    [sym_preproc_open] = ACTIONS(5523),
    [sym_end_keyword] = ACTIONS(5523),
  },
  [STATE(3331)] = {
    [sym_identifier] = ACTIONS(5967),
    [anon_sym_SEMI] = ACTIONS(5969),
    [anon_sym_DASH] = ACTIONS(5969),
    [aux_sym_boolean_token1] = ACTIONS(5967),
    [aux_sym_boolean_token2] = ACTIONS(5967),
    [sym_decimal] = ACTIONS(5967),
    [anon_sym_LPAREN] = ACTIONS(5969),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5967),
    [anon_sym_LBRACK] = ACTIONS(5969),
    [aux_sym_record_type_token1] = ACTIONS(5967),
    [aux_sym_basic_type_token21] = ACTIONS(5967),
    [aux_sym_basic_type_token22] = ACTIONS(5967),
    [aux_sym_basic_type_token48] = ACTIONS(5967),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5967),
    [anon_sym_POUNDif] = ACTIONS(5969),
    [anon_sym_POUNDIF] = ACTIONS(5969),
    [anon_sym_POUNDIf] = ACTIONS(5969),
    [anon_sym_not] = ACTIONS(5967),
    [anon_sym_NOT] = ACTIONS(5967),
    [anon_sym_Not] = ACTIONS(5967),
    [anon_sym_POUNDelse] = ACTIONS(5969),
    [anon_sym_POUNDELSE] = ACTIONS(5969),
    [anon_sym_POUNDElse] = ACTIONS(5969),
    [anon_sym_POUNDelse2] = ACTIONS(5969),
    [anon_sym_POUNDELSE2] = ACTIONS(5969),
    [anon_sym_POUNDElse2] = ACTIONS(5969),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5967),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5967),
    [anon_sym_PLUS] = ACTIONS(5969),
    [sym_datetime_literal] = ACTIONS(5969),
    [sym_date_literal] = ACTIONS(5967),
    [sym_time_literal] = ACTIONS(5967),
    [sym_biginteger_literal] = ACTIONS(5969),
    [anon_sym_if] = ACTIONS(5967),
    [anon_sym_IF] = ACTIONS(5967),
    [anon_sym_If] = ACTIONS(5967),
    [anon_sym_else] = ACTIONS(5967),
    [anon_sym_ELSE] = ACTIONS(5967),
    [anon_sym_Else] = ACTIONS(5967),
    [anon_sym_case] = ACTIONS(5967),
    [anon_sym_CASE] = ACTIONS(5967),
    [anon_sym_Case] = ACTIONS(5967),
    [anon_sym_for] = ACTIONS(5967),
    [anon_sym_FOR] = ACTIONS(5967),
    [anon_sym_For] = ACTIONS(5967),
    [anon_sym_foreach] = ACTIONS(5967),
    [anon_sym_FOREACH] = ACTIONS(5967),
    [anon_sym_Foreach] = ACTIONS(5967),
    [anon_sym_while] = ACTIONS(5967),
    [anon_sym_WHILE] = ACTIONS(5967),
    [anon_sym_While] = ACTIONS(5967),
    [anon_sym_repeat] = ACTIONS(5967),
    [anon_sym_REPEAT] = ACTIONS(5967),
    [anon_sym_Repeat] = ACTIONS(5967),
    [anon_sym_exit] = ACTIONS(5967),
    [anon_sym_EXIT] = ACTIONS(5967),
    [anon_sym_Exit] = ACTIONS(5967),
    [anon_sym_continue] = ACTIONS(5967),
    [anon_sym_CONTINUE] = ACTIONS(5967),
    [anon_sym_Continue] = ACTIONS(5967),
    [anon_sym_break] = ACTIONS(5967),
    [anon_sym_BREAK] = ACTIONS(5967),
    [anon_sym_Break] = ACTIONS(5967),
    [anon_sym_with] = ACTIONS(5967),
    [anon_sym_WITH] = ACTIONS(5967),
    [anon_sym_With] = ACTIONS(5967),
    [sym_asserterror_keyword] = ACTIONS(5969),
    [sym_page_keyword] = ACTIONS(5967),
    [anon_sym_codeunit] = ACTIONS(5967),
    [anon_sym_CODEUNIT] = ACTIONS(5967),
    [anon_sym_Codeunit] = ACTIONS(5967),
    [anon_sym_CodeUnit] = ACTIONS(5967),
    [anon_sym_COdeunit] = ACTIONS(5967),
    [anon_sym_codeUnit] = ACTIONS(5967),
    [sym_report_keyword] = ACTIONS(5967),
    [sym_query_keyword] = ACTIONS(5967),
    [anon_sym_xmlport] = ACTIONS(5967),
    [anon_sym_XMLPORT] = ACTIONS(5967),
    [anon_sym_Xmlport] = ACTIONS(5967),
    [anon_sym_XMLport] = ACTIONS(5967),
    [anon_sym_XMLPort] = ACTIONS(5967),
    [anon_sym_XmlPort] = ACTIONS(5967),
    [anon_sym_enum] = ACTIONS(5967),
    [anon_sym_ENUM] = ACTIONS(5967),
    [anon_sym_Enum] = ACTIONS(5967),
    [anon_sym_eNUM] = ACTIONS(5967),
    [anon_sym_eNum] = ACTIONS(5967),
    [anon_sym_ENum] = ACTIONS(5967),
    [sym_quoted_identifier] = ACTIONS(5969),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5969),
    [sym_verbatim_string] = ACTIONS(5969),
    [sym_integer] = ACTIONS(5967),
    [sym_continue_as_identifier] = ACTIONS(5969),
    [sym_preproc_open] = ACTIONS(5969),
    [sym_end_keyword] = ACTIONS(5969),
  },
  [STATE(3332)] = {
    [sym_identifier] = ACTIONS(5777),
    [anon_sym_SEMI] = ACTIONS(5779),
    [anon_sym_DASH] = ACTIONS(5779),
    [aux_sym_boolean_token1] = ACTIONS(5777),
    [aux_sym_boolean_token2] = ACTIONS(5777),
    [sym_decimal] = ACTIONS(5777),
    [anon_sym_LPAREN] = ACTIONS(5779),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5777),
    [anon_sym_LBRACK] = ACTIONS(5779),
    [aux_sym_record_type_token1] = ACTIONS(5777),
    [aux_sym_basic_type_token21] = ACTIONS(5777),
    [aux_sym_basic_type_token22] = ACTIONS(5777),
    [aux_sym_basic_type_token48] = ACTIONS(5777),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5777),
    [anon_sym_POUNDif] = ACTIONS(5779),
    [anon_sym_POUNDIF] = ACTIONS(5779),
    [anon_sym_POUNDIf] = ACTIONS(5779),
    [anon_sym_not] = ACTIONS(5777),
    [anon_sym_NOT] = ACTIONS(5777),
    [anon_sym_Not] = ACTIONS(5777),
    [anon_sym_POUNDelse] = ACTIONS(5779),
    [anon_sym_POUNDELSE] = ACTIONS(5779),
    [anon_sym_POUNDElse] = ACTIONS(5779),
    [anon_sym_POUNDelse2] = ACTIONS(5779),
    [anon_sym_POUNDELSE2] = ACTIONS(5779),
    [anon_sym_POUNDElse2] = ACTIONS(5779),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5777),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5777),
    [anon_sym_PLUS] = ACTIONS(5779),
    [sym_datetime_literal] = ACTIONS(5779),
    [sym_date_literal] = ACTIONS(5777),
    [sym_time_literal] = ACTIONS(5777),
    [sym_biginteger_literal] = ACTIONS(5779),
    [anon_sym_if] = ACTIONS(5777),
    [anon_sym_IF] = ACTIONS(5777),
    [anon_sym_If] = ACTIONS(5777),
    [anon_sym_else] = ACTIONS(5777),
    [anon_sym_ELSE] = ACTIONS(5777),
    [anon_sym_Else] = ACTIONS(5777),
    [anon_sym_case] = ACTIONS(5777),
    [anon_sym_CASE] = ACTIONS(5777),
    [anon_sym_Case] = ACTIONS(5777),
    [anon_sym_for] = ACTIONS(5777),
    [anon_sym_FOR] = ACTIONS(5777),
    [anon_sym_For] = ACTIONS(5777),
    [anon_sym_foreach] = ACTIONS(5777),
    [anon_sym_FOREACH] = ACTIONS(5777),
    [anon_sym_Foreach] = ACTIONS(5777),
    [anon_sym_while] = ACTIONS(5777),
    [anon_sym_WHILE] = ACTIONS(5777),
    [anon_sym_While] = ACTIONS(5777),
    [anon_sym_repeat] = ACTIONS(5777),
    [anon_sym_REPEAT] = ACTIONS(5777),
    [anon_sym_Repeat] = ACTIONS(5777),
    [anon_sym_exit] = ACTIONS(5777),
    [anon_sym_EXIT] = ACTIONS(5777),
    [anon_sym_Exit] = ACTIONS(5777),
    [anon_sym_continue] = ACTIONS(5777),
    [anon_sym_CONTINUE] = ACTIONS(5777),
    [anon_sym_Continue] = ACTIONS(5777),
    [anon_sym_break] = ACTIONS(5777),
    [anon_sym_BREAK] = ACTIONS(5777),
    [anon_sym_Break] = ACTIONS(5777),
    [anon_sym_with] = ACTIONS(5777),
    [anon_sym_WITH] = ACTIONS(5777),
    [anon_sym_With] = ACTIONS(5777),
    [sym_asserterror_keyword] = ACTIONS(5779),
    [sym_page_keyword] = ACTIONS(5777),
    [anon_sym_codeunit] = ACTIONS(5777),
    [anon_sym_CODEUNIT] = ACTIONS(5777),
    [anon_sym_Codeunit] = ACTIONS(5777),
    [anon_sym_CodeUnit] = ACTIONS(5777),
    [anon_sym_COdeunit] = ACTIONS(5777),
    [anon_sym_codeUnit] = ACTIONS(5777),
    [sym_report_keyword] = ACTIONS(5777),
    [sym_query_keyword] = ACTIONS(5777),
    [anon_sym_xmlport] = ACTIONS(5777),
    [anon_sym_XMLPORT] = ACTIONS(5777),
    [anon_sym_Xmlport] = ACTIONS(5777),
    [anon_sym_XMLport] = ACTIONS(5777),
    [anon_sym_XMLPort] = ACTIONS(5777),
    [anon_sym_XmlPort] = ACTIONS(5777),
    [anon_sym_enum] = ACTIONS(5777),
    [anon_sym_ENUM] = ACTIONS(5777),
    [anon_sym_Enum] = ACTIONS(5777),
    [anon_sym_eNUM] = ACTIONS(5777),
    [anon_sym_eNum] = ACTIONS(5777),
    [anon_sym_ENum] = ACTIONS(5777),
    [sym_quoted_identifier] = ACTIONS(5779),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5779),
    [sym_verbatim_string] = ACTIONS(5779),
    [sym_integer] = ACTIONS(5777),
    [sym_continue_as_identifier] = ACTIONS(5779),
    [sym_preproc_open] = ACTIONS(5779),
    [sym_end_keyword] = ACTIONS(5779),
  },
  [STATE(3333)] = {
    [sym_identifier] = ACTIONS(5781),
    [anon_sym_SEMI] = ACTIONS(5783),
    [anon_sym_DASH] = ACTIONS(5783),
    [aux_sym_boolean_token1] = ACTIONS(5781),
    [aux_sym_boolean_token2] = ACTIONS(5781),
    [sym_decimal] = ACTIONS(5781),
    [anon_sym_LPAREN] = ACTIONS(5783),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5781),
    [anon_sym_LBRACK] = ACTIONS(5783),
    [aux_sym_record_type_token1] = ACTIONS(5781),
    [aux_sym_basic_type_token21] = ACTIONS(5781),
    [aux_sym_basic_type_token22] = ACTIONS(5781),
    [aux_sym_basic_type_token48] = ACTIONS(5781),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5781),
    [anon_sym_POUNDif] = ACTIONS(5783),
    [anon_sym_POUNDIF] = ACTIONS(5783),
    [anon_sym_POUNDIf] = ACTIONS(5783),
    [anon_sym_not] = ACTIONS(5781),
    [anon_sym_NOT] = ACTIONS(5781),
    [anon_sym_Not] = ACTIONS(5781),
    [anon_sym_POUNDelse] = ACTIONS(5783),
    [anon_sym_POUNDELSE] = ACTIONS(5783),
    [anon_sym_POUNDElse] = ACTIONS(5783),
    [anon_sym_POUNDelse2] = ACTIONS(5783),
    [anon_sym_POUNDELSE2] = ACTIONS(5783),
    [anon_sym_POUNDElse2] = ACTIONS(5783),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5781),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5781),
    [anon_sym_PLUS] = ACTIONS(5783),
    [sym_datetime_literal] = ACTIONS(5783),
    [sym_date_literal] = ACTIONS(5781),
    [sym_time_literal] = ACTIONS(5781),
    [sym_biginteger_literal] = ACTIONS(5783),
    [anon_sym_if] = ACTIONS(5781),
    [anon_sym_IF] = ACTIONS(5781),
    [anon_sym_If] = ACTIONS(5781),
    [anon_sym_else] = ACTIONS(5781),
    [anon_sym_ELSE] = ACTIONS(5781),
    [anon_sym_Else] = ACTIONS(5781),
    [anon_sym_case] = ACTIONS(5781),
    [anon_sym_CASE] = ACTIONS(5781),
    [anon_sym_Case] = ACTIONS(5781),
    [anon_sym_for] = ACTIONS(5781),
    [anon_sym_FOR] = ACTIONS(5781),
    [anon_sym_For] = ACTIONS(5781),
    [anon_sym_foreach] = ACTIONS(5781),
    [anon_sym_FOREACH] = ACTIONS(5781),
    [anon_sym_Foreach] = ACTIONS(5781),
    [anon_sym_while] = ACTIONS(5781),
    [anon_sym_WHILE] = ACTIONS(5781),
    [anon_sym_While] = ACTIONS(5781),
    [anon_sym_repeat] = ACTIONS(5781),
    [anon_sym_REPEAT] = ACTIONS(5781),
    [anon_sym_Repeat] = ACTIONS(5781),
    [anon_sym_exit] = ACTIONS(5781),
    [anon_sym_EXIT] = ACTIONS(5781),
    [anon_sym_Exit] = ACTIONS(5781),
    [anon_sym_continue] = ACTIONS(5781),
    [anon_sym_CONTINUE] = ACTIONS(5781),
    [anon_sym_Continue] = ACTIONS(5781),
    [anon_sym_break] = ACTIONS(5781),
    [anon_sym_BREAK] = ACTIONS(5781),
    [anon_sym_Break] = ACTIONS(5781),
    [anon_sym_with] = ACTIONS(5781),
    [anon_sym_WITH] = ACTIONS(5781),
    [anon_sym_With] = ACTIONS(5781),
    [sym_asserterror_keyword] = ACTIONS(5783),
    [sym_page_keyword] = ACTIONS(5781),
    [anon_sym_codeunit] = ACTIONS(5781),
    [anon_sym_CODEUNIT] = ACTIONS(5781),
    [anon_sym_Codeunit] = ACTIONS(5781),
    [anon_sym_CodeUnit] = ACTIONS(5781),
    [anon_sym_COdeunit] = ACTIONS(5781),
    [anon_sym_codeUnit] = ACTIONS(5781),
    [sym_report_keyword] = ACTIONS(5781),
    [sym_query_keyword] = ACTIONS(5781),
    [anon_sym_xmlport] = ACTIONS(5781),
    [anon_sym_XMLPORT] = ACTIONS(5781),
    [anon_sym_Xmlport] = ACTIONS(5781),
    [anon_sym_XMLport] = ACTIONS(5781),
    [anon_sym_XMLPort] = ACTIONS(5781),
    [anon_sym_XmlPort] = ACTIONS(5781),
    [anon_sym_enum] = ACTIONS(5781),
    [anon_sym_ENUM] = ACTIONS(5781),
    [anon_sym_Enum] = ACTIONS(5781),
    [anon_sym_eNUM] = ACTIONS(5781),
    [anon_sym_eNum] = ACTIONS(5781),
    [anon_sym_ENum] = ACTIONS(5781),
    [sym_quoted_identifier] = ACTIONS(5783),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5783),
    [sym_verbatim_string] = ACTIONS(5783),
    [sym_integer] = ACTIONS(5781),
    [sym_continue_as_identifier] = ACTIONS(5783),
    [sym_preproc_open] = ACTIONS(5783),
    [sym_end_keyword] = ACTIONS(5783),
  },
  [STATE(3334)] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5527),
    [aux_sym_boolean_token1] = ACTIONS(5525),
    [aux_sym_boolean_token2] = ACTIONS(5525),
    [sym_decimal] = ACTIONS(5525),
    [anon_sym_LPAREN] = ACTIONS(5527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [aux_sym_record_type_token1] = ACTIONS(5525),
    [aux_sym_basic_type_token21] = ACTIONS(5525),
    [aux_sym_basic_type_token22] = ACTIONS(5525),
    [aux_sym_basic_type_token48] = ACTIONS(5525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5525),
    [anon_sym_POUNDif] = ACTIONS(5527),
    [anon_sym_POUNDIF] = ACTIONS(5527),
    [anon_sym_POUNDIf] = ACTIONS(5527),
    [anon_sym_not] = ACTIONS(5525),
    [anon_sym_NOT] = ACTIONS(5525),
    [anon_sym_Not] = ACTIONS(5525),
    [anon_sym_POUNDelse] = ACTIONS(5527),
    [anon_sym_POUNDELSE] = ACTIONS(5527),
    [anon_sym_POUNDElse] = ACTIONS(5527),
    [anon_sym_POUNDelse2] = ACTIONS(5527),
    [anon_sym_POUNDELSE2] = ACTIONS(5527),
    [anon_sym_POUNDElse2] = ACTIONS(5527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5527),
    [sym_datetime_literal] = ACTIONS(5527),
    [sym_date_literal] = ACTIONS(5525),
    [sym_time_literal] = ACTIONS(5525),
    [sym_biginteger_literal] = ACTIONS(5527),
    [anon_sym_if] = ACTIONS(5525),
    [anon_sym_IF] = ACTIONS(5525),
    [anon_sym_If] = ACTIONS(5525),
    [anon_sym_else] = ACTIONS(5525),
    [anon_sym_ELSE] = ACTIONS(5525),
    [anon_sym_Else] = ACTIONS(5525),
    [anon_sym_case] = ACTIONS(5525),
    [anon_sym_CASE] = ACTIONS(5525),
    [anon_sym_Case] = ACTIONS(5525),
    [anon_sym_for] = ACTIONS(5525),
    [anon_sym_FOR] = ACTIONS(5525),
    [anon_sym_For] = ACTIONS(5525),
    [anon_sym_foreach] = ACTIONS(5525),
    [anon_sym_FOREACH] = ACTIONS(5525),
    [anon_sym_Foreach] = ACTIONS(5525),
    [anon_sym_while] = ACTIONS(5525),
    [anon_sym_WHILE] = ACTIONS(5525),
    [anon_sym_While] = ACTIONS(5525),
    [anon_sym_repeat] = ACTIONS(5525),
    [anon_sym_REPEAT] = ACTIONS(5525),
    [anon_sym_Repeat] = ACTIONS(5525),
    [anon_sym_exit] = ACTIONS(5525),
    [anon_sym_EXIT] = ACTIONS(5525),
    [anon_sym_Exit] = ACTIONS(5525),
    [anon_sym_continue] = ACTIONS(5525),
    [anon_sym_CONTINUE] = ACTIONS(5525),
    [anon_sym_Continue] = ACTIONS(5525),
    [anon_sym_break] = ACTIONS(5525),
    [anon_sym_BREAK] = ACTIONS(5525),
    [anon_sym_Break] = ACTIONS(5525),
    [anon_sym_with] = ACTIONS(5525),
    [anon_sym_WITH] = ACTIONS(5525),
    [anon_sym_With] = ACTIONS(5525),
    [sym_asserterror_keyword] = ACTIONS(5527),
    [sym_page_keyword] = ACTIONS(5525),
    [anon_sym_codeunit] = ACTIONS(5525),
    [anon_sym_CODEUNIT] = ACTIONS(5525),
    [anon_sym_Codeunit] = ACTIONS(5525),
    [anon_sym_CodeUnit] = ACTIONS(5525),
    [anon_sym_COdeunit] = ACTIONS(5525),
    [anon_sym_codeUnit] = ACTIONS(5525),
    [sym_report_keyword] = ACTIONS(5525),
    [sym_query_keyword] = ACTIONS(5525),
    [anon_sym_xmlport] = ACTIONS(5525),
    [anon_sym_XMLPORT] = ACTIONS(5525),
    [anon_sym_Xmlport] = ACTIONS(5525),
    [anon_sym_XMLport] = ACTIONS(5525),
    [anon_sym_XMLPort] = ACTIONS(5525),
    [anon_sym_XmlPort] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_ENUM] = ACTIONS(5525),
    [anon_sym_Enum] = ACTIONS(5525),
    [anon_sym_eNUM] = ACTIONS(5525),
    [anon_sym_eNum] = ACTIONS(5525),
    [anon_sym_ENum] = ACTIONS(5525),
    [sym_quoted_identifier] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5527),
    [sym_verbatim_string] = ACTIONS(5527),
    [sym_integer] = ACTIONS(5525),
    [sym_continue_as_identifier] = ACTIONS(5527),
    [sym_preproc_open] = ACTIONS(5527),
    [sym_end_keyword] = ACTIONS(5527),
  },
  [STATE(3335)] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5527),
    [aux_sym_boolean_token1] = ACTIONS(5525),
    [aux_sym_boolean_token2] = ACTIONS(5525),
    [sym_decimal] = ACTIONS(5525),
    [anon_sym_LPAREN] = ACTIONS(5527),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [aux_sym_record_type_token1] = ACTIONS(5525),
    [aux_sym_basic_type_token21] = ACTIONS(5525),
    [aux_sym_basic_type_token22] = ACTIONS(5525),
    [aux_sym_basic_type_token48] = ACTIONS(5525),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5525),
    [anon_sym_POUNDif] = ACTIONS(5527),
    [anon_sym_POUNDIF] = ACTIONS(5527),
    [anon_sym_POUNDIf] = ACTIONS(5527),
    [anon_sym_not] = ACTIONS(5525),
    [anon_sym_NOT] = ACTIONS(5525),
    [anon_sym_Not] = ACTIONS(5525),
    [anon_sym_POUNDelse] = ACTIONS(5527),
    [anon_sym_POUNDELSE] = ACTIONS(5527),
    [anon_sym_POUNDElse] = ACTIONS(5527),
    [anon_sym_POUNDelse2] = ACTIONS(5527),
    [anon_sym_POUNDELSE2] = ACTIONS(5527),
    [anon_sym_POUNDElse2] = ACTIONS(5527),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5525),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5527),
    [sym_datetime_literal] = ACTIONS(5527),
    [sym_date_literal] = ACTIONS(5525),
    [sym_time_literal] = ACTIONS(5525),
    [sym_biginteger_literal] = ACTIONS(5527),
    [anon_sym_if] = ACTIONS(5525),
    [anon_sym_IF] = ACTIONS(5525),
    [anon_sym_If] = ACTIONS(5525),
    [anon_sym_else] = ACTIONS(5525),
    [anon_sym_ELSE] = ACTIONS(5525),
    [anon_sym_Else] = ACTIONS(5525),
    [anon_sym_case] = ACTIONS(5525),
    [anon_sym_CASE] = ACTIONS(5525),
    [anon_sym_Case] = ACTIONS(5525),
    [anon_sym_for] = ACTIONS(5525),
    [anon_sym_FOR] = ACTIONS(5525),
    [anon_sym_For] = ACTIONS(5525),
    [anon_sym_foreach] = ACTIONS(5525),
    [anon_sym_FOREACH] = ACTIONS(5525),
    [anon_sym_Foreach] = ACTIONS(5525),
    [anon_sym_while] = ACTIONS(5525),
    [anon_sym_WHILE] = ACTIONS(5525),
    [anon_sym_While] = ACTIONS(5525),
    [anon_sym_repeat] = ACTIONS(5525),
    [anon_sym_REPEAT] = ACTIONS(5525),
    [anon_sym_Repeat] = ACTIONS(5525),
    [anon_sym_exit] = ACTIONS(5525),
    [anon_sym_EXIT] = ACTIONS(5525),
    [anon_sym_Exit] = ACTIONS(5525),
    [anon_sym_continue] = ACTIONS(5525),
    [anon_sym_CONTINUE] = ACTIONS(5525),
    [anon_sym_Continue] = ACTIONS(5525),
    [anon_sym_break] = ACTIONS(5525),
    [anon_sym_BREAK] = ACTIONS(5525),
    [anon_sym_Break] = ACTIONS(5525),
    [anon_sym_with] = ACTIONS(5525),
    [anon_sym_WITH] = ACTIONS(5525),
    [anon_sym_With] = ACTIONS(5525),
    [sym_asserterror_keyword] = ACTIONS(5527),
    [sym_page_keyword] = ACTIONS(5525),
    [anon_sym_codeunit] = ACTIONS(5525),
    [anon_sym_CODEUNIT] = ACTIONS(5525),
    [anon_sym_Codeunit] = ACTIONS(5525),
    [anon_sym_CodeUnit] = ACTIONS(5525),
    [anon_sym_COdeunit] = ACTIONS(5525),
    [anon_sym_codeUnit] = ACTIONS(5525),
    [sym_report_keyword] = ACTIONS(5525),
    [sym_query_keyword] = ACTIONS(5525),
    [anon_sym_xmlport] = ACTIONS(5525),
    [anon_sym_XMLPORT] = ACTIONS(5525),
    [anon_sym_Xmlport] = ACTIONS(5525),
    [anon_sym_XMLport] = ACTIONS(5525),
    [anon_sym_XMLPort] = ACTIONS(5525),
    [anon_sym_XmlPort] = ACTIONS(5525),
    [anon_sym_enum] = ACTIONS(5525),
    [anon_sym_ENUM] = ACTIONS(5525),
    [anon_sym_Enum] = ACTIONS(5525),
    [anon_sym_eNUM] = ACTIONS(5525),
    [anon_sym_eNum] = ACTIONS(5525),
    [anon_sym_ENum] = ACTIONS(5525),
    [sym_quoted_identifier] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5527),
    [sym_verbatim_string] = ACTIONS(5527),
    [sym_integer] = ACTIONS(5525),
    [sym_continue_as_identifier] = ACTIONS(5527),
    [sym_preproc_open] = ACTIONS(5527),
    [sym_end_keyword] = ACTIONS(5527),
  },
  [STATE(3336)] = {
    [sym_identifier] = ACTIONS(6248),
    [anon_sym_SEMI] = ACTIONS(6250),
    [anon_sym_DASH] = ACTIONS(6250),
    [aux_sym_boolean_token1] = ACTIONS(6248),
    [aux_sym_boolean_token2] = ACTIONS(6248),
    [sym_decimal] = ACTIONS(6248),
    [anon_sym_LPAREN] = ACTIONS(6250),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6248),
    [anon_sym_LBRACK] = ACTIONS(6250),
    [aux_sym_record_type_token1] = ACTIONS(6248),
    [aux_sym_basic_type_token21] = ACTIONS(6248),
    [aux_sym_basic_type_token22] = ACTIONS(6248),
    [aux_sym_basic_type_token48] = ACTIONS(6248),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6248),
    [anon_sym_POUNDif] = ACTIONS(6250),
    [anon_sym_POUNDIF] = ACTIONS(6250),
    [anon_sym_POUNDIf] = ACTIONS(6250),
    [anon_sym_not] = ACTIONS(6248),
    [anon_sym_NOT] = ACTIONS(6248),
    [anon_sym_Not] = ACTIONS(6248),
    [anon_sym_POUNDelse] = ACTIONS(6250),
    [anon_sym_POUNDELSE] = ACTIONS(6250),
    [anon_sym_POUNDElse] = ACTIONS(6250),
    [anon_sym_POUNDelse2] = ACTIONS(6250),
    [anon_sym_POUNDELSE2] = ACTIONS(6250),
    [anon_sym_POUNDElse2] = ACTIONS(6250),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6248),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6248),
    [anon_sym_PLUS] = ACTIONS(6250),
    [sym_datetime_literal] = ACTIONS(6250),
    [sym_date_literal] = ACTIONS(6248),
    [sym_time_literal] = ACTIONS(6248),
    [sym_biginteger_literal] = ACTIONS(6250),
    [anon_sym_if] = ACTIONS(6248),
    [anon_sym_IF] = ACTIONS(6248),
    [anon_sym_If] = ACTIONS(6248),
    [anon_sym_else] = ACTIONS(6248),
    [anon_sym_ELSE] = ACTIONS(6248),
    [anon_sym_Else] = ACTIONS(6248),
    [anon_sym_case] = ACTIONS(6248),
    [anon_sym_CASE] = ACTIONS(6248),
    [anon_sym_Case] = ACTIONS(6248),
    [anon_sym_for] = ACTIONS(6248),
    [anon_sym_FOR] = ACTIONS(6248),
    [anon_sym_For] = ACTIONS(6248),
    [anon_sym_foreach] = ACTIONS(6248),
    [anon_sym_FOREACH] = ACTIONS(6248),
    [anon_sym_Foreach] = ACTIONS(6248),
    [anon_sym_while] = ACTIONS(6248),
    [anon_sym_WHILE] = ACTIONS(6248),
    [anon_sym_While] = ACTIONS(6248),
    [anon_sym_repeat] = ACTIONS(6248),
    [anon_sym_REPEAT] = ACTIONS(6248),
    [anon_sym_Repeat] = ACTIONS(6248),
    [anon_sym_exit] = ACTIONS(6248),
    [anon_sym_EXIT] = ACTIONS(6248),
    [anon_sym_Exit] = ACTIONS(6248),
    [anon_sym_continue] = ACTIONS(6248),
    [anon_sym_CONTINUE] = ACTIONS(6248),
    [anon_sym_Continue] = ACTIONS(6248),
    [anon_sym_break] = ACTIONS(6248),
    [anon_sym_BREAK] = ACTIONS(6248),
    [anon_sym_Break] = ACTIONS(6248),
    [anon_sym_with] = ACTIONS(6248),
    [anon_sym_WITH] = ACTIONS(6248),
    [anon_sym_With] = ACTIONS(6248),
    [sym_asserterror_keyword] = ACTIONS(6250),
    [sym_page_keyword] = ACTIONS(6248),
    [anon_sym_codeunit] = ACTIONS(6248),
    [anon_sym_CODEUNIT] = ACTIONS(6248),
    [anon_sym_Codeunit] = ACTIONS(6248),
    [anon_sym_CodeUnit] = ACTIONS(6248),
    [anon_sym_COdeunit] = ACTIONS(6248),
    [anon_sym_codeUnit] = ACTIONS(6248),
    [sym_report_keyword] = ACTIONS(6248),
    [sym_query_keyword] = ACTIONS(6248),
    [anon_sym_xmlport] = ACTIONS(6248),
    [anon_sym_XMLPORT] = ACTIONS(6248),
    [anon_sym_Xmlport] = ACTIONS(6248),
    [anon_sym_XMLport] = ACTIONS(6248),
    [anon_sym_XMLPort] = ACTIONS(6248),
    [anon_sym_XmlPort] = ACTIONS(6248),
    [anon_sym_enum] = ACTIONS(6248),
    [anon_sym_ENUM] = ACTIONS(6248),
    [anon_sym_Enum] = ACTIONS(6248),
    [anon_sym_eNUM] = ACTIONS(6248),
    [anon_sym_eNum] = ACTIONS(6248),
    [anon_sym_ENum] = ACTIONS(6248),
    [sym_quoted_identifier] = ACTIONS(6250),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6250),
    [sym_verbatim_string] = ACTIONS(6250),
    [sym_integer] = ACTIONS(6248),
    [sym_continue_as_identifier] = ACTIONS(6250),
    [sym_preproc_open] = ACTIONS(6250),
    [sym_end_keyword] = ACTIONS(6250),
  },
  [STATE(3337)] = {
    [sym_identifier] = ACTIONS(5785),
    [anon_sym_SEMI] = ACTIONS(5787),
    [anon_sym_DASH] = ACTIONS(5787),
    [aux_sym_boolean_token1] = ACTIONS(5785),
    [aux_sym_boolean_token2] = ACTIONS(5785),
    [sym_decimal] = ACTIONS(5785),
    [anon_sym_LPAREN] = ACTIONS(5787),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5785),
    [anon_sym_LBRACK] = ACTIONS(5787),
    [aux_sym_record_type_token1] = ACTIONS(5785),
    [aux_sym_basic_type_token21] = ACTIONS(5785),
    [aux_sym_basic_type_token22] = ACTIONS(5785),
    [aux_sym_basic_type_token48] = ACTIONS(5785),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5785),
    [anon_sym_POUNDif] = ACTIONS(5787),
    [anon_sym_POUNDIF] = ACTIONS(5787),
    [anon_sym_POUNDIf] = ACTIONS(5787),
    [anon_sym_not] = ACTIONS(5785),
    [anon_sym_NOT] = ACTIONS(5785),
    [anon_sym_Not] = ACTIONS(5785),
    [anon_sym_POUNDelse] = ACTIONS(5787),
    [anon_sym_POUNDELSE] = ACTIONS(5787),
    [anon_sym_POUNDElse] = ACTIONS(5787),
    [anon_sym_POUNDelse2] = ACTIONS(5787),
    [anon_sym_POUNDELSE2] = ACTIONS(5787),
    [anon_sym_POUNDElse2] = ACTIONS(5787),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5785),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5785),
    [anon_sym_PLUS] = ACTIONS(5787),
    [sym_datetime_literal] = ACTIONS(5787),
    [sym_date_literal] = ACTIONS(5785),
    [sym_time_literal] = ACTIONS(5785),
    [sym_biginteger_literal] = ACTIONS(5787),
    [anon_sym_if] = ACTIONS(5785),
    [anon_sym_IF] = ACTIONS(5785),
    [anon_sym_If] = ACTIONS(5785),
    [anon_sym_else] = ACTIONS(5785),
    [anon_sym_ELSE] = ACTIONS(5785),
    [anon_sym_Else] = ACTIONS(5785),
    [anon_sym_case] = ACTIONS(5785),
    [anon_sym_CASE] = ACTIONS(5785),
    [anon_sym_Case] = ACTIONS(5785),
    [anon_sym_for] = ACTIONS(5785),
    [anon_sym_FOR] = ACTIONS(5785),
    [anon_sym_For] = ACTIONS(5785),
    [anon_sym_foreach] = ACTIONS(5785),
    [anon_sym_FOREACH] = ACTIONS(5785),
    [anon_sym_Foreach] = ACTIONS(5785),
    [anon_sym_while] = ACTIONS(5785),
    [anon_sym_WHILE] = ACTIONS(5785),
    [anon_sym_While] = ACTIONS(5785),
    [anon_sym_repeat] = ACTIONS(5785),
    [anon_sym_REPEAT] = ACTIONS(5785),
    [anon_sym_Repeat] = ACTIONS(5785),
    [anon_sym_exit] = ACTIONS(5785),
    [anon_sym_EXIT] = ACTIONS(5785),
    [anon_sym_Exit] = ACTIONS(5785),
    [anon_sym_continue] = ACTIONS(5785),
    [anon_sym_CONTINUE] = ACTIONS(5785),
    [anon_sym_Continue] = ACTIONS(5785),
    [anon_sym_break] = ACTIONS(5785),
    [anon_sym_BREAK] = ACTIONS(5785),
    [anon_sym_Break] = ACTIONS(5785),
    [anon_sym_with] = ACTIONS(5785),
    [anon_sym_WITH] = ACTIONS(5785),
    [anon_sym_With] = ACTIONS(5785),
    [sym_asserterror_keyword] = ACTIONS(5787),
    [sym_page_keyword] = ACTIONS(5785),
    [anon_sym_codeunit] = ACTIONS(5785),
    [anon_sym_CODEUNIT] = ACTIONS(5785),
    [anon_sym_Codeunit] = ACTIONS(5785),
    [anon_sym_CodeUnit] = ACTIONS(5785),
    [anon_sym_COdeunit] = ACTIONS(5785),
    [anon_sym_codeUnit] = ACTIONS(5785),
    [sym_report_keyword] = ACTIONS(5785),
    [sym_query_keyword] = ACTIONS(5785),
    [anon_sym_xmlport] = ACTIONS(5785),
    [anon_sym_XMLPORT] = ACTIONS(5785),
    [anon_sym_Xmlport] = ACTIONS(5785),
    [anon_sym_XMLport] = ACTIONS(5785),
    [anon_sym_XMLPort] = ACTIONS(5785),
    [anon_sym_XmlPort] = ACTIONS(5785),
    [anon_sym_enum] = ACTIONS(5785),
    [anon_sym_ENUM] = ACTIONS(5785),
    [anon_sym_Enum] = ACTIONS(5785),
    [anon_sym_eNUM] = ACTIONS(5785),
    [anon_sym_eNum] = ACTIONS(5785),
    [anon_sym_ENum] = ACTIONS(5785),
    [sym_quoted_identifier] = ACTIONS(5787),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5787),
    [sym_verbatim_string] = ACTIONS(5787),
    [sym_integer] = ACTIONS(5785),
    [sym_continue_as_identifier] = ACTIONS(5787),
    [sym_preproc_open] = ACTIONS(5787),
    [sym_end_keyword] = ACTIONS(5787),
  },
  [STATE(3338)] = {
    [sym_identifier] = ACTIONS(5795),
    [anon_sym_SEMI] = ACTIONS(5797),
    [anon_sym_DASH] = ACTIONS(5797),
    [aux_sym_boolean_token1] = ACTIONS(5795),
    [aux_sym_boolean_token2] = ACTIONS(5795),
    [sym_decimal] = ACTIONS(5795),
    [anon_sym_LPAREN] = ACTIONS(5797),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5795),
    [anon_sym_LBRACK] = ACTIONS(5797),
    [aux_sym_record_type_token1] = ACTIONS(5795),
    [aux_sym_basic_type_token21] = ACTIONS(5795),
    [aux_sym_basic_type_token22] = ACTIONS(5795),
    [aux_sym_basic_type_token48] = ACTIONS(5795),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5795),
    [anon_sym_POUNDif] = ACTIONS(5797),
    [anon_sym_POUNDIF] = ACTIONS(5797),
    [anon_sym_POUNDIf] = ACTIONS(5797),
    [anon_sym_not] = ACTIONS(5795),
    [anon_sym_NOT] = ACTIONS(5795),
    [anon_sym_Not] = ACTIONS(5795),
    [anon_sym_POUNDelse] = ACTIONS(5797),
    [anon_sym_POUNDELSE] = ACTIONS(5797),
    [anon_sym_POUNDElse] = ACTIONS(5797),
    [anon_sym_POUNDelse2] = ACTIONS(5797),
    [anon_sym_POUNDELSE2] = ACTIONS(5797),
    [anon_sym_POUNDElse2] = ACTIONS(5797),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5795),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5795),
    [anon_sym_PLUS] = ACTIONS(5797),
    [sym_datetime_literal] = ACTIONS(5797),
    [sym_date_literal] = ACTIONS(5795),
    [sym_time_literal] = ACTIONS(5795),
    [sym_biginteger_literal] = ACTIONS(5797),
    [anon_sym_if] = ACTIONS(5795),
    [anon_sym_IF] = ACTIONS(5795),
    [anon_sym_If] = ACTIONS(5795),
    [anon_sym_else] = ACTIONS(5795),
    [anon_sym_ELSE] = ACTIONS(5795),
    [anon_sym_Else] = ACTIONS(5795),
    [anon_sym_case] = ACTIONS(5795),
    [anon_sym_CASE] = ACTIONS(5795),
    [anon_sym_Case] = ACTIONS(5795),
    [anon_sym_for] = ACTIONS(5795),
    [anon_sym_FOR] = ACTIONS(5795),
    [anon_sym_For] = ACTIONS(5795),
    [anon_sym_foreach] = ACTIONS(5795),
    [anon_sym_FOREACH] = ACTIONS(5795),
    [anon_sym_Foreach] = ACTIONS(5795),
    [anon_sym_while] = ACTIONS(5795),
    [anon_sym_WHILE] = ACTIONS(5795),
    [anon_sym_While] = ACTIONS(5795),
    [anon_sym_repeat] = ACTIONS(5795),
    [anon_sym_REPEAT] = ACTIONS(5795),
    [anon_sym_Repeat] = ACTIONS(5795),
    [anon_sym_exit] = ACTIONS(5795),
    [anon_sym_EXIT] = ACTIONS(5795),
    [anon_sym_Exit] = ACTIONS(5795),
    [anon_sym_continue] = ACTIONS(5795),
    [anon_sym_CONTINUE] = ACTIONS(5795),
    [anon_sym_Continue] = ACTIONS(5795),
    [anon_sym_break] = ACTIONS(5795),
    [anon_sym_BREAK] = ACTIONS(5795),
    [anon_sym_Break] = ACTIONS(5795),
    [anon_sym_with] = ACTIONS(5795),
    [anon_sym_WITH] = ACTIONS(5795),
    [anon_sym_With] = ACTIONS(5795),
    [sym_asserterror_keyword] = ACTIONS(5797),
    [sym_page_keyword] = ACTIONS(5795),
    [anon_sym_codeunit] = ACTIONS(5795),
    [anon_sym_CODEUNIT] = ACTIONS(5795),
    [anon_sym_Codeunit] = ACTIONS(5795),
    [anon_sym_CodeUnit] = ACTIONS(5795),
    [anon_sym_COdeunit] = ACTIONS(5795),
    [anon_sym_codeUnit] = ACTIONS(5795),
    [sym_report_keyword] = ACTIONS(5795),
    [sym_query_keyword] = ACTIONS(5795),
    [anon_sym_xmlport] = ACTIONS(5795),
    [anon_sym_XMLPORT] = ACTIONS(5795),
    [anon_sym_Xmlport] = ACTIONS(5795),
    [anon_sym_XMLport] = ACTIONS(5795),
    [anon_sym_XMLPort] = ACTIONS(5795),
    [anon_sym_XmlPort] = ACTIONS(5795),
    [anon_sym_enum] = ACTIONS(5795),
    [anon_sym_ENUM] = ACTIONS(5795),
    [anon_sym_Enum] = ACTIONS(5795),
    [anon_sym_eNUM] = ACTIONS(5795),
    [anon_sym_eNum] = ACTIONS(5795),
    [anon_sym_ENum] = ACTIONS(5795),
    [sym_quoted_identifier] = ACTIONS(5797),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5797),
    [sym_verbatim_string] = ACTIONS(5797),
    [sym_integer] = ACTIONS(5795),
    [sym_continue_as_identifier] = ACTIONS(5797),
    [sym_preproc_open] = ACTIONS(5797),
    [sym_end_keyword] = ACTIONS(5797),
  },
  [STATE(3339)] = {
    [sym_identifier] = ACTIONS(6252),
    [anon_sym_SEMI] = ACTIONS(6254),
    [anon_sym_DASH] = ACTIONS(6254),
    [aux_sym_boolean_token1] = ACTIONS(6252),
    [aux_sym_boolean_token2] = ACTIONS(6252),
    [sym_decimal] = ACTIONS(6252),
    [anon_sym_LPAREN] = ACTIONS(6254),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6252),
    [anon_sym_LBRACK] = ACTIONS(6254),
    [aux_sym_record_type_token1] = ACTIONS(6252),
    [aux_sym_basic_type_token21] = ACTIONS(6252),
    [aux_sym_basic_type_token22] = ACTIONS(6252),
    [aux_sym_basic_type_token48] = ACTIONS(6252),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6252),
    [anon_sym_POUNDif] = ACTIONS(6254),
    [anon_sym_POUNDIF] = ACTIONS(6254),
    [anon_sym_POUNDIf] = ACTIONS(6254),
    [anon_sym_not] = ACTIONS(6252),
    [anon_sym_NOT] = ACTIONS(6252),
    [anon_sym_Not] = ACTIONS(6252),
    [anon_sym_POUNDelse] = ACTIONS(6254),
    [anon_sym_POUNDELSE] = ACTIONS(6254),
    [anon_sym_POUNDElse] = ACTIONS(6254),
    [anon_sym_POUNDelse2] = ACTIONS(6254),
    [anon_sym_POUNDELSE2] = ACTIONS(6254),
    [anon_sym_POUNDElse2] = ACTIONS(6254),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6252),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6252),
    [anon_sym_PLUS] = ACTIONS(6254),
    [sym_datetime_literal] = ACTIONS(6254),
    [sym_date_literal] = ACTIONS(6252),
    [sym_time_literal] = ACTIONS(6252),
    [sym_biginteger_literal] = ACTIONS(6254),
    [anon_sym_if] = ACTIONS(6252),
    [anon_sym_IF] = ACTIONS(6252),
    [anon_sym_If] = ACTIONS(6252),
    [anon_sym_else] = ACTIONS(6252),
    [anon_sym_ELSE] = ACTIONS(6252),
    [anon_sym_Else] = ACTIONS(6252),
    [anon_sym_case] = ACTIONS(6252),
    [anon_sym_CASE] = ACTIONS(6252),
    [anon_sym_Case] = ACTIONS(6252),
    [anon_sym_for] = ACTIONS(6252),
    [anon_sym_FOR] = ACTIONS(6252),
    [anon_sym_For] = ACTIONS(6252),
    [anon_sym_foreach] = ACTIONS(6252),
    [anon_sym_FOREACH] = ACTIONS(6252),
    [anon_sym_Foreach] = ACTIONS(6252),
    [anon_sym_while] = ACTIONS(6252),
    [anon_sym_WHILE] = ACTIONS(6252),
    [anon_sym_While] = ACTIONS(6252),
    [anon_sym_repeat] = ACTIONS(6252),
    [anon_sym_REPEAT] = ACTIONS(6252),
    [anon_sym_Repeat] = ACTIONS(6252),
    [anon_sym_exit] = ACTIONS(6252),
    [anon_sym_EXIT] = ACTIONS(6252),
    [anon_sym_Exit] = ACTIONS(6252),
    [anon_sym_continue] = ACTIONS(6252),
    [anon_sym_CONTINUE] = ACTIONS(6252),
    [anon_sym_Continue] = ACTIONS(6252),
    [anon_sym_break] = ACTIONS(6252),
    [anon_sym_BREAK] = ACTIONS(6252),
    [anon_sym_Break] = ACTIONS(6252),
    [anon_sym_with] = ACTIONS(6252),
    [anon_sym_WITH] = ACTIONS(6252),
    [anon_sym_With] = ACTIONS(6252),
    [sym_asserterror_keyword] = ACTIONS(6254),
    [sym_page_keyword] = ACTIONS(6252),
    [anon_sym_codeunit] = ACTIONS(6252),
    [anon_sym_CODEUNIT] = ACTIONS(6252),
    [anon_sym_Codeunit] = ACTIONS(6252),
    [anon_sym_CodeUnit] = ACTIONS(6252),
    [anon_sym_COdeunit] = ACTIONS(6252),
    [anon_sym_codeUnit] = ACTIONS(6252),
    [sym_report_keyword] = ACTIONS(6252),
    [sym_query_keyword] = ACTIONS(6252),
    [anon_sym_xmlport] = ACTIONS(6252),
    [anon_sym_XMLPORT] = ACTIONS(6252),
    [anon_sym_Xmlport] = ACTIONS(6252),
    [anon_sym_XMLport] = ACTIONS(6252),
    [anon_sym_XMLPort] = ACTIONS(6252),
    [anon_sym_XmlPort] = ACTIONS(6252),
    [anon_sym_enum] = ACTIONS(6252),
    [anon_sym_ENUM] = ACTIONS(6252),
    [anon_sym_Enum] = ACTIONS(6252),
    [anon_sym_eNUM] = ACTIONS(6252),
    [anon_sym_eNum] = ACTIONS(6252),
    [anon_sym_ENum] = ACTIONS(6252),
    [sym_quoted_identifier] = ACTIONS(6254),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6254),
    [sym_verbatim_string] = ACTIONS(6254),
    [sym_integer] = ACTIONS(6252),
    [sym_continue_as_identifier] = ACTIONS(6254),
    [sym_preproc_open] = ACTIONS(6254),
    [sym_end_keyword] = ACTIONS(6254),
  },
  [STATE(3340)] = {
    [sym_identifier] = ACTIONS(6094),
    [anon_sym_SEMI] = ACTIONS(6096),
    [anon_sym_DASH] = ACTIONS(6096),
    [aux_sym_boolean_token1] = ACTIONS(6094),
    [aux_sym_boolean_token2] = ACTIONS(6094),
    [sym_decimal] = ACTIONS(6094),
    [anon_sym_LPAREN] = ACTIONS(6096),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6094),
    [anon_sym_LBRACK] = ACTIONS(6096),
    [aux_sym_record_type_token1] = ACTIONS(6094),
    [aux_sym_basic_type_token21] = ACTIONS(6094),
    [aux_sym_basic_type_token22] = ACTIONS(6094),
    [aux_sym_basic_type_token48] = ACTIONS(6094),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6094),
    [anon_sym_POUNDif] = ACTIONS(6096),
    [anon_sym_POUNDIF] = ACTIONS(6096),
    [anon_sym_POUNDIf] = ACTIONS(6096),
    [anon_sym_not] = ACTIONS(6094),
    [anon_sym_NOT] = ACTIONS(6094),
    [anon_sym_Not] = ACTIONS(6094),
    [anon_sym_POUNDelse] = ACTIONS(6096),
    [anon_sym_POUNDELSE] = ACTIONS(6096),
    [anon_sym_POUNDElse] = ACTIONS(6096),
    [anon_sym_POUNDelse2] = ACTIONS(6096),
    [anon_sym_POUNDELSE2] = ACTIONS(6096),
    [anon_sym_POUNDElse2] = ACTIONS(6096),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6094),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6094),
    [anon_sym_PLUS] = ACTIONS(6096),
    [sym_datetime_literal] = ACTIONS(6096),
    [sym_date_literal] = ACTIONS(6094),
    [sym_time_literal] = ACTIONS(6094),
    [sym_biginteger_literal] = ACTIONS(6096),
    [anon_sym_if] = ACTIONS(6094),
    [anon_sym_IF] = ACTIONS(6094),
    [anon_sym_If] = ACTIONS(6094),
    [anon_sym_else] = ACTIONS(6094),
    [anon_sym_ELSE] = ACTIONS(6094),
    [anon_sym_Else] = ACTIONS(6094),
    [anon_sym_case] = ACTIONS(6094),
    [anon_sym_CASE] = ACTIONS(6094),
    [anon_sym_Case] = ACTIONS(6094),
    [anon_sym_for] = ACTIONS(6094),
    [anon_sym_FOR] = ACTIONS(6094),
    [anon_sym_For] = ACTIONS(6094),
    [anon_sym_foreach] = ACTIONS(6094),
    [anon_sym_FOREACH] = ACTIONS(6094),
    [anon_sym_Foreach] = ACTIONS(6094),
    [anon_sym_while] = ACTIONS(6094),
    [anon_sym_WHILE] = ACTIONS(6094),
    [anon_sym_While] = ACTIONS(6094),
    [anon_sym_repeat] = ACTIONS(6094),
    [anon_sym_REPEAT] = ACTIONS(6094),
    [anon_sym_Repeat] = ACTIONS(6094),
    [anon_sym_exit] = ACTIONS(6094),
    [anon_sym_EXIT] = ACTIONS(6094),
    [anon_sym_Exit] = ACTIONS(6094),
    [anon_sym_continue] = ACTIONS(6094),
    [anon_sym_CONTINUE] = ACTIONS(6094),
    [anon_sym_Continue] = ACTIONS(6094),
    [anon_sym_break] = ACTIONS(6094),
    [anon_sym_BREAK] = ACTIONS(6094),
    [anon_sym_Break] = ACTIONS(6094),
    [anon_sym_with] = ACTIONS(6094),
    [anon_sym_WITH] = ACTIONS(6094),
    [anon_sym_With] = ACTIONS(6094),
    [sym_asserterror_keyword] = ACTIONS(6096),
    [sym_page_keyword] = ACTIONS(6094),
    [anon_sym_codeunit] = ACTIONS(6094),
    [anon_sym_CODEUNIT] = ACTIONS(6094),
    [anon_sym_Codeunit] = ACTIONS(6094),
    [anon_sym_CodeUnit] = ACTIONS(6094),
    [anon_sym_COdeunit] = ACTIONS(6094),
    [anon_sym_codeUnit] = ACTIONS(6094),
    [sym_report_keyword] = ACTIONS(6094),
    [sym_query_keyword] = ACTIONS(6094),
    [anon_sym_xmlport] = ACTIONS(6094),
    [anon_sym_XMLPORT] = ACTIONS(6094),
    [anon_sym_Xmlport] = ACTIONS(6094),
    [anon_sym_XMLport] = ACTIONS(6094),
    [anon_sym_XMLPort] = ACTIONS(6094),
    [anon_sym_XmlPort] = ACTIONS(6094),
    [anon_sym_enum] = ACTIONS(6094),
    [anon_sym_ENUM] = ACTIONS(6094),
    [anon_sym_Enum] = ACTIONS(6094),
    [anon_sym_eNUM] = ACTIONS(6094),
    [anon_sym_eNum] = ACTIONS(6094),
    [anon_sym_ENum] = ACTIONS(6094),
    [sym_quoted_identifier] = ACTIONS(6096),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6096),
    [sym_verbatim_string] = ACTIONS(6096),
    [sym_integer] = ACTIONS(6094),
    [sym_continue_as_identifier] = ACTIONS(6096),
    [sym_preproc_open] = ACTIONS(6096),
    [sym_end_keyword] = ACTIONS(6096),
  },
  [STATE(3341)] = {
    [sym_identifier] = ACTIONS(5945),
    [anon_sym_SEMI] = ACTIONS(5947),
    [anon_sym_DASH] = ACTIONS(5947),
    [aux_sym_boolean_token1] = ACTIONS(5945),
    [aux_sym_boolean_token2] = ACTIONS(5945),
    [sym_decimal] = ACTIONS(5945),
    [anon_sym_LPAREN] = ACTIONS(5947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5945),
    [anon_sym_LBRACK] = ACTIONS(5947),
    [aux_sym_record_type_token1] = ACTIONS(5945),
    [aux_sym_basic_type_token21] = ACTIONS(5945),
    [aux_sym_basic_type_token22] = ACTIONS(5945),
    [aux_sym_basic_type_token48] = ACTIONS(5945),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5945),
    [anon_sym_POUNDif] = ACTIONS(5947),
    [anon_sym_POUNDIF] = ACTIONS(5947),
    [anon_sym_POUNDIf] = ACTIONS(5947),
    [anon_sym_not] = ACTIONS(5945),
    [anon_sym_NOT] = ACTIONS(5945),
    [anon_sym_Not] = ACTIONS(5945),
    [anon_sym_POUNDelse] = ACTIONS(5947),
    [anon_sym_POUNDELSE] = ACTIONS(5947),
    [anon_sym_POUNDElse] = ACTIONS(5947),
    [anon_sym_POUNDelse2] = ACTIONS(5947),
    [anon_sym_POUNDELSE2] = ACTIONS(5947),
    [anon_sym_POUNDElse2] = ACTIONS(5947),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5945),
    [anon_sym_PLUS] = ACTIONS(5947),
    [sym_datetime_literal] = ACTIONS(5947),
    [sym_date_literal] = ACTIONS(5945),
    [sym_time_literal] = ACTIONS(5945),
    [sym_biginteger_literal] = ACTIONS(5947),
    [anon_sym_if] = ACTIONS(5945),
    [anon_sym_IF] = ACTIONS(5945),
    [anon_sym_If] = ACTIONS(5945),
    [anon_sym_else] = ACTIONS(5945),
    [anon_sym_ELSE] = ACTIONS(5945),
    [anon_sym_Else] = ACTIONS(5945),
    [anon_sym_case] = ACTIONS(5945),
    [anon_sym_CASE] = ACTIONS(5945),
    [anon_sym_Case] = ACTIONS(5945),
    [anon_sym_for] = ACTIONS(5945),
    [anon_sym_FOR] = ACTIONS(5945),
    [anon_sym_For] = ACTIONS(5945),
    [anon_sym_foreach] = ACTIONS(5945),
    [anon_sym_FOREACH] = ACTIONS(5945),
    [anon_sym_Foreach] = ACTIONS(5945),
    [anon_sym_while] = ACTIONS(5945),
    [anon_sym_WHILE] = ACTIONS(5945),
    [anon_sym_While] = ACTIONS(5945),
    [anon_sym_repeat] = ACTIONS(5945),
    [anon_sym_REPEAT] = ACTIONS(5945),
    [anon_sym_Repeat] = ACTIONS(5945),
    [anon_sym_exit] = ACTIONS(5945),
    [anon_sym_EXIT] = ACTIONS(5945),
    [anon_sym_Exit] = ACTIONS(5945),
    [anon_sym_continue] = ACTIONS(5945),
    [anon_sym_CONTINUE] = ACTIONS(5945),
    [anon_sym_Continue] = ACTIONS(5945),
    [anon_sym_break] = ACTIONS(5945),
    [anon_sym_BREAK] = ACTIONS(5945),
    [anon_sym_Break] = ACTIONS(5945),
    [anon_sym_with] = ACTIONS(5945),
    [anon_sym_WITH] = ACTIONS(5945),
    [anon_sym_With] = ACTIONS(5945),
    [sym_asserterror_keyword] = ACTIONS(5947),
    [sym_page_keyword] = ACTIONS(5945),
    [anon_sym_codeunit] = ACTIONS(5945),
    [anon_sym_CODEUNIT] = ACTIONS(5945),
    [anon_sym_Codeunit] = ACTIONS(5945),
    [anon_sym_CodeUnit] = ACTIONS(5945),
    [anon_sym_COdeunit] = ACTIONS(5945),
    [anon_sym_codeUnit] = ACTIONS(5945),
    [sym_report_keyword] = ACTIONS(5945),
    [sym_query_keyword] = ACTIONS(5945),
    [anon_sym_xmlport] = ACTIONS(5945),
    [anon_sym_XMLPORT] = ACTIONS(5945),
    [anon_sym_Xmlport] = ACTIONS(5945),
    [anon_sym_XMLport] = ACTIONS(5945),
    [anon_sym_XMLPort] = ACTIONS(5945),
    [anon_sym_XmlPort] = ACTIONS(5945),
    [anon_sym_enum] = ACTIONS(5945),
    [anon_sym_ENUM] = ACTIONS(5945),
    [anon_sym_Enum] = ACTIONS(5945),
    [anon_sym_eNUM] = ACTIONS(5945),
    [anon_sym_eNum] = ACTIONS(5945),
    [anon_sym_ENum] = ACTIONS(5945),
    [sym_quoted_identifier] = ACTIONS(5947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5947),
    [sym_verbatim_string] = ACTIONS(5947),
    [sym_integer] = ACTIONS(5945),
    [sym_continue_as_identifier] = ACTIONS(5947),
    [sym_preproc_open] = ACTIONS(5947),
    [sym_end_keyword] = ACTIONS(5947),
  },
  [STATE(3342)] = {
    [sym_identifier] = ACTIONS(6216),
    [anon_sym_SEMI] = ACTIONS(7345),
    [anon_sym_DASH] = ACTIONS(6220),
    [aux_sym_boolean_token1] = ACTIONS(6216),
    [aux_sym_boolean_token2] = ACTIONS(6216),
    [sym_decimal] = ACTIONS(6216),
    [anon_sym_LPAREN] = ACTIONS(6220),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6220),
    [aux_sym_record_type_token1] = ACTIONS(6216),
    [aux_sym_basic_type_token21] = ACTIONS(6216),
    [aux_sym_basic_type_token22] = ACTIONS(6216),
    [aux_sym_basic_type_token48] = ACTIONS(6216),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6216),
    [anon_sym_POUNDif] = ACTIONS(6220),
    [anon_sym_POUNDIF] = ACTIONS(6220),
    [anon_sym_POUNDIf] = ACTIONS(6220),
    [anon_sym_not] = ACTIONS(6216),
    [anon_sym_NOT] = ACTIONS(6216),
    [anon_sym_Not] = ACTIONS(6216),
    [anon_sym_POUNDelse] = ACTIONS(6220),
    [anon_sym_POUNDELSE] = ACTIONS(6220),
    [anon_sym_POUNDElse] = ACTIONS(6220),
    [anon_sym_POUNDelse2] = ACTIONS(6220),
    [anon_sym_POUNDELSE2] = ACTIONS(6220),
    [anon_sym_POUNDElse2] = ACTIONS(6220),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6216),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6216),
    [anon_sym_PLUS] = ACTIONS(6220),
    [sym_datetime_literal] = ACTIONS(6220),
    [sym_date_literal] = ACTIONS(6216),
    [sym_time_literal] = ACTIONS(6216),
    [sym_biginteger_literal] = ACTIONS(6220),
    [anon_sym_if] = ACTIONS(6216),
    [anon_sym_IF] = ACTIONS(6216),
    [anon_sym_If] = ACTIONS(6216),
    [anon_sym_else] = ACTIONS(6216),
    [anon_sym_ELSE] = ACTIONS(6216),
    [anon_sym_Else] = ACTIONS(6216),
    [anon_sym_case] = ACTIONS(6216),
    [anon_sym_CASE] = ACTIONS(6216),
    [anon_sym_Case] = ACTIONS(6216),
    [anon_sym_for] = ACTIONS(6216),
    [anon_sym_FOR] = ACTIONS(6216),
    [anon_sym_For] = ACTIONS(6216),
    [anon_sym_foreach] = ACTIONS(6216),
    [anon_sym_FOREACH] = ACTIONS(6216),
    [anon_sym_Foreach] = ACTIONS(6216),
    [anon_sym_while] = ACTIONS(6216),
    [anon_sym_WHILE] = ACTIONS(6216),
    [anon_sym_While] = ACTIONS(6216),
    [anon_sym_repeat] = ACTIONS(6216),
    [anon_sym_REPEAT] = ACTIONS(6216),
    [anon_sym_Repeat] = ACTIONS(6216),
    [anon_sym_exit] = ACTIONS(6216),
    [anon_sym_EXIT] = ACTIONS(6216),
    [anon_sym_Exit] = ACTIONS(6216),
    [anon_sym_continue] = ACTIONS(6216),
    [anon_sym_CONTINUE] = ACTIONS(6216),
    [anon_sym_Continue] = ACTIONS(6216),
    [anon_sym_break] = ACTIONS(6216),
    [anon_sym_BREAK] = ACTIONS(6216),
    [anon_sym_Break] = ACTIONS(6216),
    [anon_sym_with] = ACTIONS(6216),
    [anon_sym_WITH] = ACTIONS(6216),
    [anon_sym_With] = ACTIONS(6216),
    [sym_asserterror_keyword] = ACTIONS(6220),
    [sym_page_keyword] = ACTIONS(6216),
    [anon_sym_codeunit] = ACTIONS(6216),
    [anon_sym_CODEUNIT] = ACTIONS(6216),
    [anon_sym_Codeunit] = ACTIONS(6216),
    [anon_sym_CodeUnit] = ACTIONS(6216),
    [anon_sym_COdeunit] = ACTIONS(6216),
    [anon_sym_codeUnit] = ACTIONS(6216),
    [sym_report_keyword] = ACTIONS(6216),
    [sym_query_keyword] = ACTIONS(6216),
    [anon_sym_xmlport] = ACTIONS(6216),
    [anon_sym_XMLPORT] = ACTIONS(6216),
    [anon_sym_Xmlport] = ACTIONS(6216),
    [anon_sym_XMLport] = ACTIONS(6216),
    [anon_sym_XMLPort] = ACTIONS(6216),
    [anon_sym_XmlPort] = ACTIONS(6216),
    [anon_sym_enum] = ACTIONS(6216),
    [anon_sym_ENUM] = ACTIONS(6216),
    [anon_sym_Enum] = ACTIONS(6216),
    [anon_sym_eNUM] = ACTIONS(6216),
    [anon_sym_eNum] = ACTIONS(6216),
    [anon_sym_ENum] = ACTIONS(6216),
    [sym_quoted_identifier] = ACTIONS(6220),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6220),
    [sym_verbatim_string] = ACTIONS(6220),
    [sym_integer] = ACTIONS(6216),
    [sym_continue_as_identifier] = ACTIONS(6220),
    [sym_preproc_open] = ACTIONS(6220),
    [sym_end_keyword] = ACTIONS(6220),
  },
  [STATE(3343)] = {
    [sym_identifier] = ACTIONS(5903),
    [anon_sym_SEMI] = ACTIONS(5905),
    [anon_sym_DASH] = ACTIONS(5905),
    [aux_sym_boolean_token1] = ACTIONS(5903),
    [aux_sym_boolean_token2] = ACTIONS(5903),
    [sym_decimal] = ACTIONS(5903),
    [anon_sym_LPAREN] = ACTIONS(5905),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5903),
    [anon_sym_LBRACK] = ACTIONS(5905),
    [aux_sym_record_type_token1] = ACTIONS(5903),
    [aux_sym_basic_type_token21] = ACTIONS(5903),
    [aux_sym_basic_type_token22] = ACTIONS(5903),
    [aux_sym_basic_type_token48] = ACTIONS(5903),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5903),
    [anon_sym_POUNDif] = ACTIONS(5905),
    [anon_sym_POUNDIF] = ACTIONS(5905),
    [anon_sym_POUNDIf] = ACTIONS(5905),
    [anon_sym_not] = ACTIONS(5903),
    [anon_sym_NOT] = ACTIONS(5903),
    [anon_sym_Not] = ACTIONS(5903),
    [anon_sym_POUNDelse] = ACTIONS(5905),
    [anon_sym_POUNDELSE] = ACTIONS(5905),
    [anon_sym_POUNDElse] = ACTIONS(5905),
    [anon_sym_POUNDelse2] = ACTIONS(5905),
    [anon_sym_POUNDELSE2] = ACTIONS(5905),
    [anon_sym_POUNDElse2] = ACTIONS(5905),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5903),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5903),
    [anon_sym_PLUS] = ACTIONS(5905),
    [sym_datetime_literal] = ACTIONS(5905),
    [sym_date_literal] = ACTIONS(5903),
    [sym_time_literal] = ACTIONS(5903),
    [sym_biginteger_literal] = ACTIONS(5905),
    [anon_sym_if] = ACTIONS(5903),
    [anon_sym_IF] = ACTIONS(5903),
    [anon_sym_If] = ACTIONS(5903),
    [anon_sym_else] = ACTIONS(5903),
    [anon_sym_ELSE] = ACTIONS(5903),
    [anon_sym_Else] = ACTIONS(5903),
    [anon_sym_case] = ACTIONS(5903),
    [anon_sym_CASE] = ACTIONS(5903),
    [anon_sym_Case] = ACTIONS(5903),
    [anon_sym_for] = ACTIONS(5903),
    [anon_sym_FOR] = ACTIONS(5903),
    [anon_sym_For] = ACTIONS(5903),
    [anon_sym_foreach] = ACTIONS(5903),
    [anon_sym_FOREACH] = ACTIONS(5903),
    [anon_sym_Foreach] = ACTIONS(5903),
    [anon_sym_while] = ACTIONS(5903),
    [anon_sym_WHILE] = ACTIONS(5903),
    [anon_sym_While] = ACTIONS(5903),
    [anon_sym_repeat] = ACTIONS(5903),
    [anon_sym_REPEAT] = ACTIONS(5903),
    [anon_sym_Repeat] = ACTIONS(5903),
    [anon_sym_exit] = ACTIONS(5903),
    [anon_sym_EXIT] = ACTIONS(5903),
    [anon_sym_Exit] = ACTIONS(5903),
    [anon_sym_continue] = ACTIONS(5903),
    [anon_sym_CONTINUE] = ACTIONS(5903),
    [anon_sym_Continue] = ACTIONS(5903),
    [anon_sym_break] = ACTIONS(5903),
    [anon_sym_BREAK] = ACTIONS(5903),
    [anon_sym_Break] = ACTIONS(5903),
    [anon_sym_with] = ACTIONS(5903),
    [anon_sym_WITH] = ACTIONS(5903),
    [anon_sym_With] = ACTIONS(5903),
    [sym_asserterror_keyword] = ACTIONS(5905),
    [sym_page_keyword] = ACTIONS(5903),
    [anon_sym_codeunit] = ACTIONS(5903),
    [anon_sym_CODEUNIT] = ACTIONS(5903),
    [anon_sym_Codeunit] = ACTIONS(5903),
    [anon_sym_CodeUnit] = ACTIONS(5903),
    [anon_sym_COdeunit] = ACTIONS(5903),
    [anon_sym_codeUnit] = ACTIONS(5903),
    [sym_report_keyword] = ACTIONS(5903),
    [sym_query_keyword] = ACTIONS(5903),
    [anon_sym_xmlport] = ACTIONS(5903),
    [anon_sym_XMLPORT] = ACTIONS(5903),
    [anon_sym_Xmlport] = ACTIONS(5903),
    [anon_sym_XMLport] = ACTIONS(5903),
    [anon_sym_XMLPort] = ACTIONS(5903),
    [anon_sym_XmlPort] = ACTIONS(5903),
    [anon_sym_enum] = ACTIONS(5903),
    [anon_sym_ENUM] = ACTIONS(5903),
    [anon_sym_Enum] = ACTIONS(5903),
    [anon_sym_eNUM] = ACTIONS(5903),
    [anon_sym_eNum] = ACTIONS(5903),
    [anon_sym_ENum] = ACTIONS(5903),
    [sym_quoted_identifier] = ACTIONS(5905),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5905),
    [sym_verbatim_string] = ACTIONS(5905),
    [sym_integer] = ACTIONS(5903),
    [sym_continue_as_identifier] = ACTIONS(5905),
    [sym_preproc_open] = ACTIONS(5905),
    [sym_end_keyword] = ACTIONS(5905),
  },
  [STATE(3344)] = {
    [sym_identifier] = ACTIONS(6216),
    [anon_sym_SEMI] = ACTIONS(7347),
    [anon_sym_DASH] = ACTIONS(6220),
    [aux_sym_boolean_token1] = ACTIONS(6216),
    [aux_sym_boolean_token2] = ACTIONS(6216),
    [sym_decimal] = ACTIONS(6216),
    [anon_sym_LPAREN] = ACTIONS(6220),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6216),
    [anon_sym_LBRACK] = ACTIONS(6220),
    [aux_sym_record_type_token1] = ACTIONS(6216),
    [aux_sym_basic_type_token21] = ACTIONS(6216),
    [aux_sym_basic_type_token22] = ACTIONS(6216),
    [aux_sym_basic_type_token48] = ACTIONS(6216),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6216),
    [anon_sym_POUNDif] = ACTIONS(6220),
    [anon_sym_POUNDIF] = ACTIONS(6220),
    [anon_sym_POUNDIf] = ACTIONS(6220),
    [anon_sym_not] = ACTIONS(6216),
    [anon_sym_NOT] = ACTIONS(6216),
    [anon_sym_Not] = ACTIONS(6216),
    [anon_sym_POUNDelse] = ACTIONS(6220),
    [anon_sym_POUNDELSE] = ACTIONS(6220),
    [anon_sym_POUNDElse] = ACTIONS(6220),
    [anon_sym_POUNDelse2] = ACTIONS(6220),
    [anon_sym_POUNDELSE2] = ACTIONS(6220),
    [anon_sym_POUNDElse2] = ACTIONS(6220),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6216),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6216),
    [anon_sym_PLUS] = ACTIONS(6220),
    [sym_datetime_literal] = ACTIONS(6220),
    [sym_date_literal] = ACTIONS(6216),
    [sym_time_literal] = ACTIONS(6216),
    [sym_biginteger_literal] = ACTIONS(6220),
    [anon_sym_if] = ACTIONS(6216),
    [anon_sym_IF] = ACTIONS(6216),
    [anon_sym_If] = ACTIONS(6216),
    [anon_sym_else] = ACTIONS(6216),
    [anon_sym_ELSE] = ACTIONS(6216),
    [anon_sym_Else] = ACTIONS(6216),
    [anon_sym_case] = ACTIONS(6216),
    [anon_sym_CASE] = ACTIONS(6216),
    [anon_sym_Case] = ACTIONS(6216),
    [anon_sym_for] = ACTIONS(6216),
    [anon_sym_FOR] = ACTIONS(6216),
    [anon_sym_For] = ACTIONS(6216),
    [anon_sym_foreach] = ACTIONS(6216),
    [anon_sym_FOREACH] = ACTIONS(6216),
    [anon_sym_Foreach] = ACTIONS(6216),
    [anon_sym_while] = ACTIONS(6216),
    [anon_sym_WHILE] = ACTIONS(6216),
    [anon_sym_While] = ACTIONS(6216),
    [anon_sym_repeat] = ACTIONS(6216),
    [anon_sym_REPEAT] = ACTIONS(6216),
    [anon_sym_Repeat] = ACTIONS(6216),
    [anon_sym_exit] = ACTIONS(6216),
    [anon_sym_EXIT] = ACTIONS(6216),
    [anon_sym_Exit] = ACTIONS(6216),
    [anon_sym_continue] = ACTIONS(6216),
    [anon_sym_CONTINUE] = ACTIONS(6216),
    [anon_sym_Continue] = ACTIONS(6216),
    [anon_sym_break] = ACTIONS(6216),
    [anon_sym_BREAK] = ACTIONS(6216),
    [anon_sym_Break] = ACTIONS(6216),
    [anon_sym_with] = ACTIONS(6216),
    [anon_sym_WITH] = ACTIONS(6216),
    [anon_sym_With] = ACTIONS(6216),
    [sym_asserterror_keyword] = ACTIONS(6220),
    [sym_page_keyword] = ACTIONS(6216),
    [anon_sym_codeunit] = ACTIONS(6216),
    [anon_sym_CODEUNIT] = ACTIONS(6216),
    [anon_sym_Codeunit] = ACTIONS(6216),
    [anon_sym_CodeUnit] = ACTIONS(6216),
    [anon_sym_COdeunit] = ACTIONS(6216),
    [anon_sym_codeUnit] = ACTIONS(6216),
    [sym_report_keyword] = ACTIONS(6216),
    [sym_query_keyword] = ACTIONS(6216),
    [anon_sym_xmlport] = ACTIONS(6216),
    [anon_sym_XMLPORT] = ACTIONS(6216),
    [anon_sym_Xmlport] = ACTIONS(6216),
    [anon_sym_XMLport] = ACTIONS(6216),
    [anon_sym_XMLPort] = ACTIONS(6216),
    [anon_sym_XmlPort] = ACTIONS(6216),
    [anon_sym_enum] = ACTIONS(6216),
    [anon_sym_ENUM] = ACTIONS(6216),
    [anon_sym_Enum] = ACTIONS(6216),
    [anon_sym_eNUM] = ACTIONS(6216),
    [anon_sym_eNum] = ACTIONS(6216),
    [anon_sym_ENum] = ACTIONS(6216),
    [sym_quoted_identifier] = ACTIONS(6220),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6220),
    [sym_verbatim_string] = ACTIONS(6220),
    [sym_integer] = ACTIONS(6216),
    [sym_continue_as_identifier] = ACTIONS(6220),
    [sym_preproc_open] = ACTIONS(6220),
    [sym_end_keyword] = ACTIONS(6220),
  },
  [STATE(3345)] = {
    [sym_identifier] = ACTIONS(5907),
    [anon_sym_SEMI] = ACTIONS(5909),
    [anon_sym_DASH] = ACTIONS(5909),
    [aux_sym_boolean_token1] = ACTIONS(5907),
    [aux_sym_boolean_token2] = ACTIONS(5907),
    [sym_decimal] = ACTIONS(5907),
    [anon_sym_LPAREN] = ACTIONS(5909),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5907),
    [anon_sym_LBRACK] = ACTIONS(5909),
    [aux_sym_record_type_token1] = ACTIONS(5907),
    [aux_sym_basic_type_token21] = ACTIONS(5907),
    [aux_sym_basic_type_token22] = ACTIONS(5907),
    [aux_sym_basic_type_token48] = ACTIONS(5907),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5907),
    [anon_sym_POUNDif] = ACTIONS(5909),
    [anon_sym_POUNDIF] = ACTIONS(5909),
    [anon_sym_POUNDIf] = ACTIONS(5909),
    [anon_sym_not] = ACTIONS(5907),
    [anon_sym_NOT] = ACTIONS(5907),
    [anon_sym_Not] = ACTIONS(5907),
    [anon_sym_POUNDelse] = ACTIONS(5909),
    [anon_sym_POUNDELSE] = ACTIONS(5909),
    [anon_sym_POUNDElse] = ACTIONS(5909),
    [anon_sym_POUNDelse2] = ACTIONS(5909),
    [anon_sym_POUNDELSE2] = ACTIONS(5909),
    [anon_sym_POUNDElse2] = ACTIONS(5909),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5907),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5907),
    [anon_sym_PLUS] = ACTIONS(5909),
    [sym_datetime_literal] = ACTIONS(5909),
    [sym_date_literal] = ACTIONS(5907),
    [sym_time_literal] = ACTIONS(5907),
    [sym_biginteger_literal] = ACTIONS(5909),
    [anon_sym_if] = ACTIONS(5907),
    [anon_sym_IF] = ACTIONS(5907),
    [anon_sym_If] = ACTIONS(5907),
    [anon_sym_else] = ACTIONS(5907),
    [anon_sym_ELSE] = ACTIONS(5907),
    [anon_sym_Else] = ACTIONS(5907),
    [anon_sym_case] = ACTIONS(5907),
    [anon_sym_CASE] = ACTIONS(5907),
    [anon_sym_Case] = ACTIONS(5907),
    [anon_sym_for] = ACTIONS(5907),
    [anon_sym_FOR] = ACTIONS(5907),
    [anon_sym_For] = ACTIONS(5907),
    [anon_sym_foreach] = ACTIONS(5907),
    [anon_sym_FOREACH] = ACTIONS(5907),
    [anon_sym_Foreach] = ACTIONS(5907),
    [anon_sym_while] = ACTIONS(5907),
    [anon_sym_WHILE] = ACTIONS(5907),
    [anon_sym_While] = ACTIONS(5907),
    [anon_sym_repeat] = ACTIONS(5907),
    [anon_sym_REPEAT] = ACTIONS(5907),
    [anon_sym_Repeat] = ACTIONS(5907),
    [anon_sym_exit] = ACTIONS(5907),
    [anon_sym_EXIT] = ACTIONS(5907),
    [anon_sym_Exit] = ACTIONS(5907),
    [anon_sym_continue] = ACTIONS(5907),
    [anon_sym_CONTINUE] = ACTIONS(5907),
    [anon_sym_Continue] = ACTIONS(5907),
    [anon_sym_break] = ACTIONS(5907),
    [anon_sym_BREAK] = ACTIONS(5907),
    [anon_sym_Break] = ACTIONS(5907),
    [anon_sym_with] = ACTIONS(5907),
    [anon_sym_WITH] = ACTIONS(5907),
    [anon_sym_With] = ACTIONS(5907),
    [sym_asserterror_keyword] = ACTIONS(5909),
    [sym_page_keyword] = ACTIONS(5907),
    [anon_sym_codeunit] = ACTIONS(5907),
    [anon_sym_CODEUNIT] = ACTIONS(5907),
    [anon_sym_Codeunit] = ACTIONS(5907),
    [anon_sym_CodeUnit] = ACTIONS(5907),
    [anon_sym_COdeunit] = ACTIONS(5907),
    [anon_sym_codeUnit] = ACTIONS(5907),
    [sym_report_keyword] = ACTIONS(5907),
    [sym_query_keyword] = ACTIONS(5907),
    [anon_sym_xmlport] = ACTIONS(5907),
    [anon_sym_XMLPORT] = ACTIONS(5907),
    [anon_sym_Xmlport] = ACTIONS(5907),
    [anon_sym_XMLport] = ACTIONS(5907),
    [anon_sym_XMLPort] = ACTIONS(5907),
    [anon_sym_XmlPort] = ACTIONS(5907),
    [anon_sym_enum] = ACTIONS(5907),
    [anon_sym_ENUM] = ACTIONS(5907),
    [anon_sym_Enum] = ACTIONS(5907),
    [anon_sym_eNUM] = ACTIONS(5907),
    [anon_sym_eNum] = ACTIONS(5907),
    [anon_sym_ENum] = ACTIONS(5907),
    [sym_quoted_identifier] = ACTIONS(5909),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5909),
    [sym_verbatim_string] = ACTIONS(5909),
    [sym_integer] = ACTIONS(5907),
    [sym_continue_as_identifier] = ACTIONS(5909),
    [sym_preproc_open] = ACTIONS(5909),
    [sym_end_keyword] = ACTIONS(5909),
  },
  [STATE(3346)] = {
    [sym_identifier] = ACTIONS(5799),
    [anon_sym_SEMI] = ACTIONS(5801),
    [anon_sym_DASH] = ACTIONS(5801),
    [aux_sym_boolean_token1] = ACTIONS(5799),
    [aux_sym_boolean_token2] = ACTIONS(5799),
    [sym_decimal] = ACTIONS(5799),
    [anon_sym_LPAREN] = ACTIONS(5801),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5799),
    [anon_sym_LBRACK] = ACTIONS(5801),
    [aux_sym_record_type_token1] = ACTIONS(5799),
    [aux_sym_basic_type_token21] = ACTIONS(5799),
    [aux_sym_basic_type_token22] = ACTIONS(5799),
    [aux_sym_basic_type_token48] = ACTIONS(5799),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5799),
    [anon_sym_POUNDif] = ACTIONS(5801),
    [anon_sym_POUNDIF] = ACTIONS(5801),
    [anon_sym_POUNDIf] = ACTIONS(5801),
    [anon_sym_not] = ACTIONS(5799),
    [anon_sym_NOT] = ACTIONS(5799),
    [anon_sym_Not] = ACTIONS(5799),
    [anon_sym_POUNDelse] = ACTIONS(5801),
    [anon_sym_POUNDELSE] = ACTIONS(5801),
    [anon_sym_POUNDElse] = ACTIONS(5801),
    [anon_sym_POUNDelse2] = ACTIONS(5801),
    [anon_sym_POUNDELSE2] = ACTIONS(5801),
    [anon_sym_POUNDElse2] = ACTIONS(5801),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5799),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5799),
    [anon_sym_PLUS] = ACTIONS(5801),
    [sym_datetime_literal] = ACTIONS(5801),
    [sym_date_literal] = ACTIONS(5799),
    [sym_time_literal] = ACTIONS(5799),
    [sym_biginteger_literal] = ACTIONS(5801),
    [anon_sym_if] = ACTIONS(5799),
    [anon_sym_IF] = ACTIONS(5799),
    [anon_sym_If] = ACTIONS(5799),
    [anon_sym_else] = ACTIONS(5799),
    [anon_sym_ELSE] = ACTIONS(5799),
    [anon_sym_Else] = ACTIONS(5799),
    [anon_sym_case] = ACTIONS(5799),
    [anon_sym_CASE] = ACTIONS(5799),
    [anon_sym_Case] = ACTIONS(5799),
    [anon_sym_for] = ACTIONS(5799),
    [anon_sym_FOR] = ACTIONS(5799),
    [anon_sym_For] = ACTIONS(5799),
    [anon_sym_foreach] = ACTIONS(5799),
    [anon_sym_FOREACH] = ACTIONS(5799),
    [anon_sym_Foreach] = ACTIONS(5799),
    [anon_sym_while] = ACTIONS(5799),
    [anon_sym_WHILE] = ACTIONS(5799),
    [anon_sym_While] = ACTIONS(5799),
    [anon_sym_repeat] = ACTIONS(5799),
    [anon_sym_REPEAT] = ACTIONS(5799),
    [anon_sym_Repeat] = ACTIONS(5799),
    [anon_sym_exit] = ACTIONS(5799),
    [anon_sym_EXIT] = ACTIONS(5799),
    [anon_sym_Exit] = ACTIONS(5799),
    [anon_sym_continue] = ACTIONS(5799),
    [anon_sym_CONTINUE] = ACTIONS(5799),
    [anon_sym_Continue] = ACTIONS(5799),
    [anon_sym_break] = ACTIONS(5799),
    [anon_sym_BREAK] = ACTIONS(5799),
    [anon_sym_Break] = ACTIONS(5799),
    [anon_sym_with] = ACTIONS(5799),
    [anon_sym_WITH] = ACTIONS(5799),
    [anon_sym_With] = ACTIONS(5799),
    [sym_asserterror_keyword] = ACTIONS(5801),
    [sym_page_keyword] = ACTIONS(5799),
    [anon_sym_codeunit] = ACTIONS(5799),
    [anon_sym_CODEUNIT] = ACTIONS(5799),
    [anon_sym_Codeunit] = ACTIONS(5799),
    [anon_sym_CodeUnit] = ACTIONS(5799),
    [anon_sym_COdeunit] = ACTIONS(5799),
    [anon_sym_codeUnit] = ACTIONS(5799),
    [sym_report_keyword] = ACTIONS(5799),
    [sym_query_keyword] = ACTIONS(5799),
    [anon_sym_xmlport] = ACTIONS(5799),
    [anon_sym_XMLPORT] = ACTIONS(5799),
    [anon_sym_Xmlport] = ACTIONS(5799),
    [anon_sym_XMLport] = ACTIONS(5799),
    [anon_sym_XMLPort] = ACTIONS(5799),
    [anon_sym_XmlPort] = ACTIONS(5799),
    [anon_sym_enum] = ACTIONS(5799),
    [anon_sym_ENUM] = ACTIONS(5799),
    [anon_sym_Enum] = ACTIONS(5799),
    [anon_sym_eNUM] = ACTIONS(5799),
    [anon_sym_eNum] = ACTIONS(5799),
    [anon_sym_ENum] = ACTIONS(5799),
    [sym_quoted_identifier] = ACTIONS(5801),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5801),
    [sym_verbatim_string] = ACTIONS(5801),
    [sym_integer] = ACTIONS(5799),
    [sym_continue_as_identifier] = ACTIONS(5801),
    [sym_preproc_open] = ACTIONS(5801),
    [sym_end_keyword] = ACTIONS(5801),
  },
  [STATE(3347)] = {
    [sym_identifier] = ACTIONS(5803),
    [anon_sym_SEMI] = ACTIONS(5805),
    [anon_sym_DASH] = ACTIONS(5805),
    [aux_sym_boolean_token1] = ACTIONS(5803),
    [aux_sym_boolean_token2] = ACTIONS(5803),
    [sym_decimal] = ACTIONS(5803),
    [anon_sym_LPAREN] = ACTIONS(5805),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5803),
    [anon_sym_LBRACK] = ACTIONS(5805),
    [aux_sym_record_type_token1] = ACTIONS(5803),
    [aux_sym_basic_type_token21] = ACTIONS(5803),
    [aux_sym_basic_type_token22] = ACTIONS(5803),
    [aux_sym_basic_type_token48] = ACTIONS(5803),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5803),
    [anon_sym_POUNDif] = ACTIONS(5805),
    [anon_sym_POUNDIF] = ACTIONS(5805),
    [anon_sym_POUNDIf] = ACTIONS(5805),
    [anon_sym_not] = ACTIONS(5803),
    [anon_sym_NOT] = ACTIONS(5803),
    [anon_sym_Not] = ACTIONS(5803),
    [anon_sym_POUNDelse] = ACTIONS(5805),
    [anon_sym_POUNDELSE] = ACTIONS(5805),
    [anon_sym_POUNDElse] = ACTIONS(5805),
    [anon_sym_POUNDelse2] = ACTIONS(5805),
    [anon_sym_POUNDELSE2] = ACTIONS(5805),
    [anon_sym_POUNDElse2] = ACTIONS(5805),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5803),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5803),
    [anon_sym_PLUS] = ACTIONS(5805),
    [sym_datetime_literal] = ACTIONS(5805),
    [sym_date_literal] = ACTIONS(5803),
    [sym_time_literal] = ACTIONS(5803),
    [sym_biginteger_literal] = ACTIONS(5805),
    [anon_sym_if] = ACTIONS(5803),
    [anon_sym_IF] = ACTIONS(5803),
    [anon_sym_If] = ACTIONS(5803),
    [anon_sym_else] = ACTIONS(5803),
    [anon_sym_ELSE] = ACTIONS(5803),
    [anon_sym_Else] = ACTIONS(5803),
    [anon_sym_case] = ACTIONS(5803),
    [anon_sym_CASE] = ACTIONS(5803),
    [anon_sym_Case] = ACTIONS(5803),
    [anon_sym_for] = ACTIONS(5803),
    [anon_sym_FOR] = ACTIONS(5803),
    [anon_sym_For] = ACTIONS(5803),
    [anon_sym_foreach] = ACTIONS(5803),
    [anon_sym_FOREACH] = ACTIONS(5803),
    [anon_sym_Foreach] = ACTIONS(5803),
    [anon_sym_while] = ACTIONS(5803),
    [anon_sym_WHILE] = ACTIONS(5803),
    [anon_sym_While] = ACTIONS(5803),
    [anon_sym_repeat] = ACTIONS(5803),
    [anon_sym_REPEAT] = ACTIONS(5803),
    [anon_sym_Repeat] = ACTIONS(5803),
    [anon_sym_exit] = ACTIONS(5803),
    [anon_sym_EXIT] = ACTIONS(5803),
    [anon_sym_Exit] = ACTIONS(5803),
    [anon_sym_continue] = ACTIONS(5803),
    [anon_sym_CONTINUE] = ACTIONS(5803),
    [anon_sym_Continue] = ACTIONS(5803),
    [anon_sym_break] = ACTIONS(5803),
    [anon_sym_BREAK] = ACTIONS(5803),
    [anon_sym_Break] = ACTIONS(5803),
    [anon_sym_with] = ACTIONS(5803),
    [anon_sym_WITH] = ACTIONS(5803),
    [anon_sym_With] = ACTIONS(5803),
    [sym_asserterror_keyword] = ACTIONS(5805),
    [sym_page_keyword] = ACTIONS(5803),
    [anon_sym_codeunit] = ACTIONS(5803),
    [anon_sym_CODEUNIT] = ACTIONS(5803),
    [anon_sym_Codeunit] = ACTIONS(5803),
    [anon_sym_CodeUnit] = ACTIONS(5803),
    [anon_sym_COdeunit] = ACTIONS(5803),
    [anon_sym_codeUnit] = ACTIONS(5803),
    [sym_report_keyword] = ACTIONS(5803),
    [sym_query_keyword] = ACTIONS(5803),
    [anon_sym_xmlport] = ACTIONS(5803),
    [anon_sym_XMLPORT] = ACTIONS(5803),
    [anon_sym_Xmlport] = ACTIONS(5803),
    [anon_sym_XMLport] = ACTIONS(5803),
    [anon_sym_XMLPort] = ACTIONS(5803),
    [anon_sym_XmlPort] = ACTIONS(5803),
    [anon_sym_enum] = ACTIONS(5803),
    [anon_sym_ENUM] = ACTIONS(5803),
    [anon_sym_Enum] = ACTIONS(5803),
    [anon_sym_eNUM] = ACTIONS(5803),
    [anon_sym_eNum] = ACTIONS(5803),
    [anon_sym_ENum] = ACTIONS(5803),
    [sym_quoted_identifier] = ACTIONS(5805),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5805),
    [sym_verbatim_string] = ACTIONS(5805),
    [sym_integer] = ACTIONS(5803),
    [sym_continue_as_identifier] = ACTIONS(5805),
    [sym_preproc_open] = ACTIONS(5805),
    [sym_end_keyword] = ACTIONS(5805),
  },
  [STATE(3348)] = {
    [sym_identifier] = ACTIONS(5957),
    [anon_sym_SEMI] = ACTIONS(5959),
    [anon_sym_DASH] = ACTIONS(5959),
    [aux_sym_boolean_token1] = ACTIONS(5957),
    [aux_sym_boolean_token2] = ACTIONS(5957),
    [sym_decimal] = ACTIONS(5957),
    [anon_sym_LPAREN] = ACTIONS(5959),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5957),
    [anon_sym_LBRACK] = ACTIONS(5959),
    [aux_sym_record_type_token1] = ACTIONS(5957),
    [aux_sym_basic_type_token21] = ACTIONS(5957),
    [aux_sym_basic_type_token22] = ACTIONS(5957),
    [aux_sym_basic_type_token48] = ACTIONS(5957),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5957),
    [anon_sym_POUNDif] = ACTIONS(5959),
    [anon_sym_POUNDIF] = ACTIONS(5959),
    [anon_sym_POUNDIf] = ACTIONS(5959),
    [anon_sym_not] = ACTIONS(5957),
    [anon_sym_NOT] = ACTIONS(5957),
    [anon_sym_Not] = ACTIONS(5957),
    [anon_sym_POUNDelse] = ACTIONS(5959),
    [anon_sym_POUNDELSE] = ACTIONS(5959),
    [anon_sym_POUNDElse] = ACTIONS(5959),
    [anon_sym_POUNDelse2] = ACTIONS(5959),
    [anon_sym_POUNDELSE2] = ACTIONS(5959),
    [anon_sym_POUNDElse2] = ACTIONS(5959),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5957),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5957),
    [anon_sym_PLUS] = ACTIONS(5959),
    [sym_datetime_literal] = ACTIONS(5959),
    [sym_date_literal] = ACTIONS(5957),
    [sym_time_literal] = ACTIONS(5957),
    [sym_biginteger_literal] = ACTIONS(5959),
    [anon_sym_if] = ACTIONS(5957),
    [anon_sym_IF] = ACTIONS(5957),
    [anon_sym_If] = ACTIONS(5957),
    [anon_sym_else] = ACTIONS(5957),
    [anon_sym_ELSE] = ACTIONS(5957),
    [anon_sym_Else] = ACTIONS(5957),
    [anon_sym_case] = ACTIONS(5957),
    [anon_sym_CASE] = ACTIONS(5957),
    [anon_sym_Case] = ACTIONS(5957),
    [anon_sym_for] = ACTIONS(5957),
    [anon_sym_FOR] = ACTIONS(5957),
    [anon_sym_For] = ACTIONS(5957),
    [anon_sym_foreach] = ACTIONS(5957),
    [anon_sym_FOREACH] = ACTIONS(5957),
    [anon_sym_Foreach] = ACTIONS(5957),
    [anon_sym_while] = ACTIONS(5957),
    [anon_sym_WHILE] = ACTIONS(5957),
    [anon_sym_While] = ACTIONS(5957),
    [anon_sym_repeat] = ACTIONS(5957),
    [anon_sym_REPEAT] = ACTIONS(5957),
    [anon_sym_Repeat] = ACTIONS(5957),
    [anon_sym_exit] = ACTIONS(5957),
    [anon_sym_EXIT] = ACTIONS(5957),
    [anon_sym_Exit] = ACTIONS(5957),
    [anon_sym_continue] = ACTIONS(5957),
    [anon_sym_CONTINUE] = ACTIONS(5957),
    [anon_sym_Continue] = ACTIONS(5957),
    [anon_sym_break] = ACTIONS(5957),
    [anon_sym_BREAK] = ACTIONS(5957),
    [anon_sym_Break] = ACTIONS(5957),
    [anon_sym_with] = ACTIONS(5957),
    [anon_sym_WITH] = ACTIONS(5957),
    [anon_sym_With] = ACTIONS(5957),
    [sym_asserterror_keyword] = ACTIONS(5959),
    [sym_page_keyword] = ACTIONS(5957),
    [anon_sym_codeunit] = ACTIONS(5957),
    [anon_sym_CODEUNIT] = ACTIONS(5957),
    [anon_sym_Codeunit] = ACTIONS(5957),
    [anon_sym_CodeUnit] = ACTIONS(5957),
    [anon_sym_COdeunit] = ACTIONS(5957),
    [anon_sym_codeUnit] = ACTIONS(5957),
    [sym_report_keyword] = ACTIONS(5957),
    [sym_query_keyword] = ACTIONS(5957),
    [anon_sym_xmlport] = ACTIONS(5957),
    [anon_sym_XMLPORT] = ACTIONS(5957),
    [anon_sym_Xmlport] = ACTIONS(5957),
    [anon_sym_XMLport] = ACTIONS(5957),
    [anon_sym_XMLPort] = ACTIONS(5957),
    [anon_sym_XmlPort] = ACTIONS(5957),
    [anon_sym_enum] = ACTIONS(5957),
    [anon_sym_ENUM] = ACTIONS(5957),
    [anon_sym_Enum] = ACTIONS(5957),
    [anon_sym_eNUM] = ACTIONS(5957),
    [anon_sym_eNum] = ACTIONS(5957),
    [anon_sym_ENum] = ACTIONS(5957),
    [sym_quoted_identifier] = ACTIONS(5959),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5959),
    [sym_verbatim_string] = ACTIONS(5959),
    [sym_integer] = ACTIONS(5957),
    [sym_continue_as_identifier] = ACTIONS(5959),
    [sym_preproc_open] = ACTIONS(5959),
    [sym_end_keyword] = ACTIONS(5959),
  },
  [STATE(3349)] = {
    [sym_identifier] = ACTIONS(6256),
    [anon_sym_SEMI] = ACTIONS(6258),
    [anon_sym_DASH] = ACTIONS(6258),
    [aux_sym_boolean_token1] = ACTIONS(6256),
    [aux_sym_boolean_token2] = ACTIONS(6256),
    [sym_decimal] = ACTIONS(6256),
    [anon_sym_LPAREN] = ACTIONS(6258),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6256),
    [anon_sym_LBRACK] = ACTIONS(6258),
    [aux_sym_record_type_token1] = ACTIONS(6256),
    [aux_sym_basic_type_token21] = ACTIONS(6256),
    [aux_sym_basic_type_token22] = ACTIONS(6256),
    [aux_sym_basic_type_token48] = ACTIONS(6256),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6256),
    [anon_sym_POUNDif] = ACTIONS(6258),
    [anon_sym_POUNDIF] = ACTIONS(6258),
    [anon_sym_POUNDIf] = ACTIONS(6258),
    [anon_sym_not] = ACTIONS(6256),
    [anon_sym_NOT] = ACTIONS(6256),
    [anon_sym_Not] = ACTIONS(6256),
    [anon_sym_POUNDelse] = ACTIONS(6258),
    [anon_sym_POUNDELSE] = ACTIONS(6258),
    [anon_sym_POUNDElse] = ACTIONS(6258),
    [anon_sym_POUNDelse2] = ACTIONS(6258),
    [anon_sym_POUNDELSE2] = ACTIONS(6258),
    [anon_sym_POUNDElse2] = ACTIONS(6258),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6256),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6256),
    [anon_sym_PLUS] = ACTIONS(6258),
    [sym_datetime_literal] = ACTIONS(6258),
    [sym_date_literal] = ACTIONS(6256),
    [sym_time_literal] = ACTIONS(6256),
    [sym_biginteger_literal] = ACTIONS(6258),
    [anon_sym_if] = ACTIONS(6256),
    [anon_sym_IF] = ACTIONS(6256),
    [anon_sym_If] = ACTIONS(6256),
    [anon_sym_else] = ACTIONS(6256),
    [anon_sym_ELSE] = ACTIONS(6256),
    [anon_sym_Else] = ACTIONS(6256),
    [anon_sym_case] = ACTIONS(6256),
    [anon_sym_CASE] = ACTIONS(6256),
    [anon_sym_Case] = ACTIONS(6256),
    [anon_sym_for] = ACTIONS(6256),
    [anon_sym_FOR] = ACTIONS(6256),
    [anon_sym_For] = ACTIONS(6256),
    [anon_sym_foreach] = ACTIONS(6256),
    [anon_sym_FOREACH] = ACTIONS(6256),
    [anon_sym_Foreach] = ACTIONS(6256),
    [anon_sym_while] = ACTIONS(6256),
    [anon_sym_WHILE] = ACTIONS(6256),
    [anon_sym_While] = ACTIONS(6256),
    [anon_sym_repeat] = ACTIONS(6256),
    [anon_sym_REPEAT] = ACTIONS(6256),
    [anon_sym_Repeat] = ACTIONS(6256),
    [anon_sym_exit] = ACTIONS(6256),
    [anon_sym_EXIT] = ACTIONS(6256),
    [anon_sym_Exit] = ACTIONS(6256),
    [anon_sym_continue] = ACTIONS(6256),
    [anon_sym_CONTINUE] = ACTIONS(6256),
    [anon_sym_Continue] = ACTIONS(6256),
    [anon_sym_break] = ACTIONS(6256),
    [anon_sym_BREAK] = ACTIONS(6256),
    [anon_sym_Break] = ACTIONS(6256),
    [anon_sym_with] = ACTIONS(6256),
    [anon_sym_WITH] = ACTIONS(6256),
    [anon_sym_With] = ACTIONS(6256),
    [sym_asserterror_keyword] = ACTIONS(6258),
    [sym_page_keyword] = ACTIONS(6256),
    [anon_sym_codeunit] = ACTIONS(6256),
    [anon_sym_CODEUNIT] = ACTIONS(6256),
    [anon_sym_Codeunit] = ACTIONS(6256),
    [anon_sym_CodeUnit] = ACTIONS(6256),
    [anon_sym_COdeunit] = ACTIONS(6256),
    [anon_sym_codeUnit] = ACTIONS(6256),
    [sym_report_keyword] = ACTIONS(6256),
    [sym_query_keyword] = ACTIONS(6256),
    [anon_sym_xmlport] = ACTIONS(6256),
    [anon_sym_XMLPORT] = ACTIONS(6256),
    [anon_sym_Xmlport] = ACTIONS(6256),
    [anon_sym_XMLport] = ACTIONS(6256),
    [anon_sym_XMLPort] = ACTIONS(6256),
    [anon_sym_XmlPort] = ACTIONS(6256),
    [anon_sym_enum] = ACTIONS(6256),
    [anon_sym_ENUM] = ACTIONS(6256),
    [anon_sym_Enum] = ACTIONS(6256),
    [anon_sym_eNUM] = ACTIONS(6256),
    [anon_sym_eNum] = ACTIONS(6256),
    [anon_sym_ENum] = ACTIONS(6256),
    [sym_quoted_identifier] = ACTIONS(6258),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6258),
    [sym_verbatim_string] = ACTIONS(6258),
    [sym_integer] = ACTIONS(6256),
    [sym_continue_as_identifier] = ACTIONS(6258),
    [sym_preproc_open] = ACTIONS(6258),
    [sym_end_keyword] = ACTIONS(6258),
  },
  [STATE(3350)] = {
    [sym_identifier] = ACTIONS(5957),
    [anon_sym_SEMI] = ACTIONS(5959),
    [anon_sym_DASH] = ACTIONS(5959),
    [aux_sym_boolean_token1] = ACTIONS(5957),
    [aux_sym_boolean_token2] = ACTIONS(5957),
    [sym_decimal] = ACTIONS(5957),
    [anon_sym_LPAREN] = ACTIONS(5959),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5957),
    [anon_sym_LBRACK] = ACTIONS(5959),
    [aux_sym_record_type_token1] = ACTIONS(5957),
    [aux_sym_basic_type_token21] = ACTIONS(5957),
    [aux_sym_basic_type_token22] = ACTIONS(5957),
    [aux_sym_basic_type_token48] = ACTIONS(5957),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5957),
    [anon_sym_POUNDif] = ACTIONS(5959),
    [anon_sym_POUNDIF] = ACTIONS(5959),
    [anon_sym_POUNDIf] = ACTIONS(5959),
    [anon_sym_not] = ACTIONS(5957),
    [anon_sym_NOT] = ACTIONS(5957),
    [anon_sym_Not] = ACTIONS(5957),
    [anon_sym_POUNDelse] = ACTIONS(5959),
    [anon_sym_POUNDELSE] = ACTIONS(5959),
    [anon_sym_POUNDElse] = ACTIONS(5959),
    [anon_sym_POUNDelse2] = ACTIONS(5959),
    [anon_sym_POUNDELSE2] = ACTIONS(5959),
    [anon_sym_POUNDElse2] = ACTIONS(5959),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5957),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5957),
    [anon_sym_PLUS] = ACTIONS(5959),
    [sym_datetime_literal] = ACTIONS(5959),
    [sym_date_literal] = ACTIONS(5957),
    [sym_time_literal] = ACTIONS(5957),
    [sym_biginteger_literal] = ACTIONS(5959),
    [anon_sym_if] = ACTIONS(5957),
    [anon_sym_IF] = ACTIONS(5957),
    [anon_sym_If] = ACTIONS(5957),
    [anon_sym_else] = ACTIONS(5957),
    [anon_sym_ELSE] = ACTIONS(5957),
    [anon_sym_Else] = ACTIONS(5957),
    [anon_sym_case] = ACTIONS(5957),
    [anon_sym_CASE] = ACTIONS(5957),
    [anon_sym_Case] = ACTIONS(5957),
    [anon_sym_for] = ACTIONS(5957),
    [anon_sym_FOR] = ACTIONS(5957),
    [anon_sym_For] = ACTIONS(5957),
    [anon_sym_foreach] = ACTIONS(5957),
    [anon_sym_FOREACH] = ACTIONS(5957),
    [anon_sym_Foreach] = ACTIONS(5957),
    [anon_sym_while] = ACTIONS(5957),
    [anon_sym_WHILE] = ACTIONS(5957),
    [anon_sym_While] = ACTIONS(5957),
    [anon_sym_repeat] = ACTIONS(5957),
    [anon_sym_REPEAT] = ACTIONS(5957),
    [anon_sym_Repeat] = ACTIONS(5957),
    [anon_sym_exit] = ACTIONS(5957),
    [anon_sym_EXIT] = ACTIONS(5957),
    [anon_sym_Exit] = ACTIONS(5957),
    [anon_sym_continue] = ACTIONS(5957),
    [anon_sym_CONTINUE] = ACTIONS(5957),
    [anon_sym_Continue] = ACTIONS(5957),
    [anon_sym_break] = ACTIONS(5957),
    [anon_sym_BREAK] = ACTIONS(5957),
    [anon_sym_Break] = ACTIONS(5957),
    [anon_sym_with] = ACTIONS(5957),
    [anon_sym_WITH] = ACTIONS(5957),
    [anon_sym_With] = ACTIONS(5957),
    [sym_asserterror_keyword] = ACTIONS(5959),
    [sym_page_keyword] = ACTIONS(5957),
    [anon_sym_codeunit] = ACTIONS(5957),
    [anon_sym_CODEUNIT] = ACTIONS(5957),
    [anon_sym_Codeunit] = ACTIONS(5957),
    [anon_sym_CodeUnit] = ACTIONS(5957),
    [anon_sym_COdeunit] = ACTIONS(5957),
    [anon_sym_codeUnit] = ACTIONS(5957),
    [sym_report_keyword] = ACTIONS(5957),
    [sym_query_keyword] = ACTIONS(5957),
    [anon_sym_xmlport] = ACTIONS(5957),
    [anon_sym_XMLPORT] = ACTIONS(5957),
    [anon_sym_Xmlport] = ACTIONS(5957),
    [anon_sym_XMLport] = ACTIONS(5957),
    [anon_sym_XMLPort] = ACTIONS(5957),
    [anon_sym_XmlPort] = ACTIONS(5957),
    [anon_sym_enum] = ACTIONS(5957),
    [anon_sym_ENUM] = ACTIONS(5957),
    [anon_sym_Enum] = ACTIONS(5957),
    [anon_sym_eNUM] = ACTIONS(5957),
    [anon_sym_eNum] = ACTIONS(5957),
    [anon_sym_ENum] = ACTIONS(5957),
    [sym_quoted_identifier] = ACTIONS(5959),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5959),
    [sym_verbatim_string] = ACTIONS(5959),
    [sym_integer] = ACTIONS(5957),
    [sym_continue_as_identifier] = ACTIONS(5959),
    [sym_preproc_open] = ACTIONS(5959),
    [sym_end_keyword] = ACTIONS(5959),
  },
  [STATE(3351)] = {
    [sym_identifier] = ACTIONS(5529),
    [anon_sym_SEMI] = ACTIONS(5531),
    [anon_sym_DASH] = ACTIONS(5531),
    [aux_sym_boolean_token1] = ACTIONS(5529),
    [aux_sym_boolean_token2] = ACTIONS(5529),
    [sym_decimal] = ACTIONS(5529),
    [anon_sym_LPAREN] = ACTIONS(5531),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5529),
    [anon_sym_LBRACK] = ACTIONS(5531),
    [aux_sym_record_type_token1] = ACTIONS(5529),
    [aux_sym_basic_type_token21] = ACTIONS(5529),
    [aux_sym_basic_type_token22] = ACTIONS(5529),
    [aux_sym_basic_type_token48] = ACTIONS(5529),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5529),
    [anon_sym_POUNDif] = ACTIONS(5531),
    [anon_sym_POUNDIF] = ACTIONS(5531),
    [anon_sym_POUNDIf] = ACTIONS(5531),
    [anon_sym_not] = ACTIONS(5529),
    [anon_sym_NOT] = ACTIONS(5529),
    [anon_sym_Not] = ACTIONS(5529),
    [anon_sym_POUNDelse] = ACTIONS(5531),
    [anon_sym_POUNDELSE] = ACTIONS(5531),
    [anon_sym_POUNDElse] = ACTIONS(5531),
    [anon_sym_POUNDelse2] = ACTIONS(5531),
    [anon_sym_POUNDELSE2] = ACTIONS(5531),
    [anon_sym_POUNDElse2] = ACTIONS(5531),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5529),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5529),
    [anon_sym_PLUS] = ACTIONS(5531),
    [sym_datetime_literal] = ACTIONS(5531),
    [sym_date_literal] = ACTIONS(5529),
    [sym_time_literal] = ACTIONS(5529),
    [sym_biginteger_literal] = ACTIONS(5531),
    [anon_sym_if] = ACTIONS(5529),
    [anon_sym_IF] = ACTIONS(5529),
    [anon_sym_If] = ACTIONS(5529),
    [anon_sym_else] = ACTIONS(5529),
    [anon_sym_ELSE] = ACTIONS(5529),
    [anon_sym_Else] = ACTIONS(5529),
    [anon_sym_case] = ACTIONS(5529),
    [anon_sym_CASE] = ACTIONS(5529),
    [anon_sym_Case] = ACTIONS(5529),
    [anon_sym_for] = ACTIONS(5529),
    [anon_sym_FOR] = ACTIONS(5529),
    [anon_sym_For] = ACTIONS(5529),
    [anon_sym_foreach] = ACTIONS(5529),
    [anon_sym_FOREACH] = ACTIONS(5529),
    [anon_sym_Foreach] = ACTIONS(5529),
    [anon_sym_while] = ACTIONS(5529),
    [anon_sym_WHILE] = ACTIONS(5529),
    [anon_sym_While] = ACTIONS(5529),
    [anon_sym_repeat] = ACTIONS(5529),
    [anon_sym_REPEAT] = ACTIONS(5529),
    [anon_sym_Repeat] = ACTIONS(5529),
    [anon_sym_exit] = ACTIONS(5529),
    [anon_sym_EXIT] = ACTIONS(5529),
    [anon_sym_Exit] = ACTIONS(5529),
    [anon_sym_continue] = ACTIONS(5529),
    [anon_sym_CONTINUE] = ACTIONS(5529),
    [anon_sym_Continue] = ACTIONS(5529),
    [anon_sym_break] = ACTIONS(5529),
    [anon_sym_BREAK] = ACTIONS(5529),
    [anon_sym_Break] = ACTIONS(5529),
    [anon_sym_with] = ACTIONS(5529),
    [anon_sym_WITH] = ACTIONS(5529),
    [anon_sym_With] = ACTIONS(5529),
    [sym_asserterror_keyword] = ACTIONS(5531),
    [sym_page_keyword] = ACTIONS(5529),
    [anon_sym_codeunit] = ACTIONS(5529),
    [anon_sym_CODEUNIT] = ACTIONS(5529),
    [anon_sym_Codeunit] = ACTIONS(5529),
    [anon_sym_CodeUnit] = ACTIONS(5529),
    [anon_sym_COdeunit] = ACTIONS(5529),
    [anon_sym_codeUnit] = ACTIONS(5529),
    [sym_report_keyword] = ACTIONS(5529),
    [sym_query_keyword] = ACTIONS(5529),
    [anon_sym_xmlport] = ACTIONS(5529),
    [anon_sym_XMLPORT] = ACTIONS(5529),
    [anon_sym_Xmlport] = ACTIONS(5529),
    [anon_sym_XMLport] = ACTIONS(5529),
    [anon_sym_XMLPort] = ACTIONS(5529),
    [anon_sym_XmlPort] = ACTIONS(5529),
    [anon_sym_enum] = ACTIONS(5529),
    [anon_sym_ENUM] = ACTIONS(5529),
    [anon_sym_Enum] = ACTIONS(5529),
    [anon_sym_eNUM] = ACTIONS(5529),
    [anon_sym_eNum] = ACTIONS(5529),
    [anon_sym_ENum] = ACTIONS(5529),
    [sym_quoted_identifier] = ACTIONS(5531),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5531),
    [sym_verbatim_string] = ACTIONS(5531),
    [sym_integer] = ACTIONS(5529),
    [sym_continue_as_identifier] = ACTIONS(5531),
    [sym_preproc_open] = ACTIONS(5531),
    [sym_end_keyword] = ACTIONS(5531),
  },
  [STATE(3352)] = {
    [sym_identifier] = ACTIONS(6038),
    [anon_sym_SEMI] = ACTIONS(6040),
    [anon_sym_DASH] = ACTIONS(6040),
    [aux_sym_boolean_token1] = ACTIONS(6038),
    [aux_sym_boolean_token2] = ACTIONS(6038),
    [sym_decimal] = ACTIONS(6038),
    [anon_sym_LPAREN] = ACTIONS(6040),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6038),
    [anon_sym_LBRACK] = ACTIONS(6040),
    [aux_sym_record_type_token1] = ACTIONS(6038),
    [aux_sym_basic_type_token21] = ACTIONS(6038),
    [aux_sym_basic_type_token22] = ACTIONS(6038),
    [aux_sym_basic_type_token48] = ACTIONS(6038),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6038),
    [anon_sym_POUNDif] = ACTIONS(6040),
    [anon_sym_POUNDIF] = ACTIONS(6040),
    [anon_sym_POUNDIf] = ACTIONS(6040),
    [anon_sym_not] = ACTIONS(6038),
    [anon_sym_NOT] = ACTIONS(6038),
    [anon_sym_Not] = ACTIONS(6038),
    [anon_sym_POUNDelse] = ACTIONS(6040),
    [anon_sym_POUNDELSE] = ACTIONS(6040),
    [anon_sym_POUNDElse] = ACTIONS(6040),
    [anon_sym_POUNDelse2] = ACTIONS(6040),
    [anon_sym_POUNDELSE2] = ACTIONS(6040),
    [anon_sym_POUNDElse2] = ACTIONS(6040),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6038),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6038),
    [anon_sym_PLUS] = ACTIONS(6040),
    [sym_datetime_literal] = ACTIONS(6040),
    [sym_date_literal] = ACTIONS(6038),
    [sym_time_literal] = ACTIONS(6038),
    [sym_biginteger_literal] = ACTIONS(6040),
    [anon_sym_if] = ACTIONS(6038),
    [anon_sym_IF] = ACTIONS(6038),
    [anon_sym_If] = ACTIONS(6038),
    [anon_sym_else] = ACTIONS(6038),
    [anon_sym_ELSE] = ACTIONS(6038),
    [anon_sym_Else] = ACTIONS(6038),
    [anon_sym_case] = ACTIONS(6038),
    [anon_sym_CASE] = ACTIONS(6038),
    [anon_sym_Case] = ACTIONS(6038),
    [anon_sym_for] = ACTIONS(6038),
    [anon_sym_FOR] = ACTIONS(6038),
    [anon_sym_For] = ACTIONS(6038),
    [anon_sym_foreach] = ACTIONS(6038),
    [anon_sym_FOREACH] = ACTIONS(6038),
    [anon_sym_Foreach] = ACTIONS(6038),
    [anon_sym_while] = ACTIONS(6038),
    [anon_sym_WHILE] = ACTIONS(6038),
    [anon_sym_While] = ACTIONS(6038),
    [anon_sym_repeat] = ACTIONS(6038),
    [anon_sym_REPEAT] = ACTIONS(6038),
    [anon_sym_Repeat] = ACTIONS(6038),
    [anon_sym_exit] = ACTIONS(6038),
    [anon_sym_EXIT] = ACTIONS(6038),
    [anon_sym_Exit] = ACTIONS(6038),
    [anon_sym_continue] = ACTIONS(6038),
    [anon_sym_CONTINUE] = ACTIONS(6038),
    [anon_sym_Continue] = ACTIONS(6038),
    [anon_sym_break] = ACTIONS(6038),
    [anon_sym_BREAK] = ACTIONS(6038),
    [anon_sym_Break] = ACTIONS(6038),
    [anon_sym_with] = ACTIONS(6038),
    [anon_sym_WITH] = ACTIONS(6038),
    [anon_sym_With] = ACTIONS(6038),
    [sym_asserterror_keyword] = ACTIONS(6040),
    [sym_page_keyword] = ACTIONS(6038),
    [anon_sym_codeunit] = ACTIONS(6038),
    [anon_sym_CODEUNIT] = ACTIONS(6038),
    [anon_sym_Codeunit] = ACTIONS(6038),
    [anon_sym_CodeUnit] = ACTIONS(6038),
    [anon_sym_COdeunit] = ACTIONS(6038),
    [anon_sym_codeUnit] = ACTIONS(6038),
    [sym_report_keyword] = ACTIONS(6038),
    [sym_query_keyword] = ACTIONS(6038),
    [anon_sym_xmlport] = ACTIONS(6038),
    [anon_sym_XMLPORT] = ACTIONS(6038),
    [anon_sym_Xmlport] = ACTIONS(6038),
    [anon_sym_XMLport] = ACTIONS(6038),
    [anon_sym_XMLPort] = ACTIONS(6038),
    [anon_sym_XmlPort] = ACTIONS(6038),
    [anon_sym_enum] = ACTIONS(6038),
    [anon_sym_ENUM] = ACTIONS(6038),
    [anon_sym_Enum] = ACTIONS(6038),
    [anon_sym_eNUM] = ACTIONS(6038),
    [anon_sym_eNum] = ACTIONS(6038),
    [anon_sym_ENum] = ACTIONS(6038),
    [sym_quoted_identifier] = ACTIONS(6040),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6040),
    [sym_verbatim_string] = ACTIONS(6040),
    [sym_integer] = ACTIONS(6038),
    [sym_continue_as_identifier] = ACTIONS(6040),
    [sym_preproc_open] = ACTIONS(6040),
    [sym_end_keyword] = ACTIONS(6040),
  },
  [STATE(3353)] = {
    [sym_identifier] = ACTIONS(5533),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym_DASH] = ACTIONS(5535),
    [aux_sym_boolean_token1] = ACTIONS(5533),
    [aux_sym_boolean_token2] = ACTIONS(5533),
    [sym_decimal] = ACTIONS(5533),
    [anon_sym_LPAREN] = ACTIONS(5535),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5533),
    [anon_sym_LBRACK] = ACTIONS(5535),
    [aux_sym_record_type_token1] = ACTIONS(5533),
    [aux_sym_basic_type_token21] = ACTIONS(5533),
    [aux_sym_basic_type_token22] = ACTIONS(5533),
    [aux_sym_basic_type_token48] = ACTIONS(5533),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5533),
    [anon_sym_POUNDif] = ACTIONS(5535),
    [anon_sym_POUNDIF] = ACTIONS(5535),
    [anon_sym_POUNDIf] = ACTIONS(5535),
    [anon_sym_not] = ACTIONS(5533),
    [anon_sym_NOT] = ACTIONS(5533),
    [anon_sym_Not] = ACTIONS(5533),
    [anon_sym_POUNDelse] = ACTIONS(5535),
    [anon_sym_POUNDELSE] = ACTIONS(5535),
    [anon_sym_POUNDElse] = ACTIONS(5535),
    [anon_sym_POUNDelse2] = ACTIONS(5535),
    [anon_sym_POUNDELSE2] = ACTIONS(5535),
    [anon_sym_POUNDElse2] = ACTIONS(5535),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5533),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5533),
    [anon_sym_PLUS] = ACTIONS(5535),
    [sym_datetime_literal] = ACTIONS(5535),
    [sym_date_literal] = ACTIONS(5533),
    [sym_time_literal] = ACTIONS(5533),
    [sym_biginteger_literal] = ACTIONS(5535),
    [anon_sym_if] = ACTIONS(5533),
    [anon_sym_IF] = ACTIONS(5533),
    [anon_sym_If] = ACTIONS(5533),
    [anon_sym_else] = ACTIONS(5533),
    [anon_sym_ELSE] = ACTIONS(5533),
    [anon_sym_Else] = ACTIONS(5533),
    [anon_sym_case] = ACTIONS(5533),
    [anon_sym_CASE] = ACTIONS(5533),
    [anon_sym_Case] = ACTIONS(5533),
    [anon_sym_for] = ACTIONS(5533),
    [anon_sym_FOR] = ACTIONS(5533),
    [anon_sym_For] = ACTIONS(5533),
    [anon_sym_foreach] = ACTIONS(5533),
    [anon_sym_FOREACH] = ACTIONS(5533),
    [anon_sym_Foreach] = ACTIONS(5533),
    [anon_sym_while] = ACTIONS(5533),
    [anon_sym_WHILE] = ACTIONS(5533),
    [anon_sym_While] = ACTIONS(5533),
    [anon_sym_repeat] = ACTIONS(5533),
    [anon_sym_REPEAT] = ACTIONS(5533),
    [anon_sym_Repeat] = ACTIONS(5533),
    [anon_sym_exit] = ACTIONS(5533),
    [anon_sym_EXIT] = ACTIONS(5533),
    [anon_sym_Exit] = ACTIONS(5533),
    [anon_sym_continue] = ACTIONS(5533),
    [anon_sym_CONTINUE] = ACTIONS(5533),
    [anon_sym_Continue] = ACTIONS(5533),
    [anon_sym_break] = ACTIONS(5533),
    [anon_sym_BREAK] = ACTIONS(5533),
    [anon_sym_Break] = ACTIONS(5533),
    [anon_sym_with] = ACTIONS(5533),
    [anon_sym_WITH] = ACTIONS(5533),
    [anon_sym_With] = ACTIONS(5533),
    [sym_asserterror_keyword] = ACTIONS(5535),
    [sym_page_keyword] = ACTIONS(5533),
    [anon_sym_codeunit] = ACTIONS(5533),
    [anon_sym_CODEUNIT] = ACTIONS(5533),
    [anon_sym_Codeunit] = ACTIONS(5533),
    [anon_sym_CodeUnit] = ACTIONS(5533),
    [anon_sym_COdeunit] = ACTIONS(5533),
    [anon_sym_codeUnit] = ACTIONS(5533),
    [sym_report_keyword] = ACTIONS(5533),
    [sym_query_keyword] = ACTIONS(5533),
    [anon_sym_xmlport] = ACTIONS(5533),
    [anon_sym_XMLPORT] = ACTIONS(5533),
    [anon_sym_Xmlport] = ACTIONS(5533),
    [anon_sym_XMLport] = ACTIONS(5533),
    [anon_sym_XMLPort] = ACTIONS(5533),
    [anon_sym_XmlPort] = ACTIONS(5533),
    [anon_sym_enum] = ACTIONS(5533),
    [anon_sym_ENUM] = ACTIONS(5533),
    [anon_sym_Enum] = ACTIONS(5533),
    [anon_sym_eNUM] = ACTIONS(5533),
    [anon_sym_eNum] = ACTIONS(5533),
    [anon_sym_ENum] = ACTIONS(5533),
    [sym_quoted_identifier] = ACTIONS(5535),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5535),
    [sym_verbatim_string] = ACTIONS(5535),
    [sym_integer] = ACTIONS(5533),
    [sym_continue_as_identifier] = ACTIONS(5535),
    [sym_preproc_open] = ACTIONS(5535),
    [sym_end_keyword] = ACTIONS(5535),
  },
  [STATE(3354)] = {
    [sym_identifier] = ACTIONS(5537),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym_DASH] = ACTIONS(5539),
    [aux_sym_boolean_token1] = ACTIONS(5537),
    [aux_sym_boolean_token2] = ACTIONS(5537),
    [sym_decimal] = ACTIONS(5537),
    [anon_sym_LPAREN] = ACTIONS(5539),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5537),
    [anon_sym_LBRACK] = ACTIONS(5539),
    [aux_sym_record_type_token1] = ACTIONS(5537),
    [aux_sym_basic_type_token21] = ACTIONS(5537),
    [aux_sym_basic_type_token22] = ACTIONS(5537),
    [aux_sym_basic_type_token48] = ACTIONS(5537),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5537),
    [anon_sym_POUNDif] = ACTIONS(5539),
    [anon_sym_POUNDIF] = ACTIONS(5539),
    [anon_sym_POUNDIf] = ACTIONS(5539),
    [anon_sym_not] = ACTIONS(5537),
    [anon_sym_NOT] = ACTIONS(5537),
    [anon_sym_Not] = ACTIONS(5537),
    [anon_sym_POUNDelse] = ACTIONS(5539),
    [anon_sym_POUNDELSE] = ACTIONS(5539),
    [anon_sym_POUNDElse] = ACTIONS(5539),
    [anon_sym_POUNDelse2] = ACTIONS(5539),
    [anon_sym_POUNDELSE2] = ACTIONS(5539),
    [anon_sym_POUNDElse2] = ACTIONS(5539),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5537),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5537),
    [anon_sym_PLUS] = ACTIONS(5539),
    [sym_datetime_literal] = ACTIONS(5539),
    [sym_date_literal] = ACTIONS(5537),
    [sym_time_literal] = ACTIONS(5537),
    [sym_biginteger_literal] = ACTIONS(5539),
    [anon_sym_if] = ACTIONS(5537),
    [anon_sym_IF] = ACTIONS(5537),
    [anon_sym_If] = ACTIONS(5537),
    [anon_sym_else] = ACTIONS(5537),
    [anon_sym_ELSE] = ACTIONS(5537),
    [anon_sym_Else] = ACTIONS(5537),
    [anon_sym_case] = ACTIONS(5537),
    [anon_sym_CASE] = ACTIONS(5537),
    [anon_sym_Case] = ACTIONS(5537),
    [anon_sym_for] = ACTIONS(5537),
    [anon_sym_FOR] = ACTIONS(5537),
    [anon_sym_For] = ACTIONS(5537),
    [anon_sym_foreach] = ACTIONS(5537),
    [anon_sym_FOREACH] = ACTIONS(5537),
    [anon_sym_Foreach] = ACTIONS(5537),
    [anon_sym_while] = ACTIONS(5537),
    [anon_sym_WHILE] = ACTIONS(5537),
    [anon_sym_While] = ACTIONS(5537),
    [anon_sym_repeat] = ACTIONS(5537),
    [anon_sym_REPEAT] = ACTIONS(5537),
    [anon_sym_Repeat] = ACTIONS(5537),
    [anon_sym_exit] = ACTIONS(5537),
    [anon_sym_EXIT] = ACTIONS(5537),
    [anon_sym_Exit] = ACTIONS(5537),
    [anon_sym_continue] = ACTIONS(5537),
    [anon_sym_CONTINUE] = ACTIONS(5537),
    [anon_sym_Continue] = ACTIONS(5537),
    [anon_sym_break] = ACTIONS(5537),
    [anon_sym_BREAK] = ACTIONS(5537),
    [anon_sym_Break] = ACTIONS(5537),
    [anon_sym_with] = ACTIONS(5537),
    [anon_sym_WITH] = ACTIONS(5537),
    [anon_sym_With] = ACTIONS(5537),
    [sym_asserterror_keyword] = ACTIONS(5539),
    [sym_page_keyword] = ACTIONS(5537),
    [anon_sym_codeunit] = ACTIONS(5537),
    [anon_sym_CODEUNIT] = ACTIONS(5537),
    [anon_sym_Codeunit] = ACTIONS(5537),
    [anon_sym_CodeUnit] = ACTIONS(5537),
    [anon_sym_COdeunit] = ACTIONS(5537),
    [anon_sym_codeUnit] = ACTIONS(5537),
    [sym_report_keyword] = ACTIONS(5537),
    [sym_query_keyword] = ACTIONS(5537),
    [anon_sym_xmlport] = ACTIONS(5537),
    [anon_sym_XMLPORT] = ACTIONS(5537),
    [anon_sym_Xmlport] = ACTIONS(5537),
    [anon_sym_XMLport] = ACTIONS(5537),
    [anon_sym_XMLPort] = ACTIONS(5537),
    [anon_sym_XmlPort] = ACTIONS(5537),
    [anon_sym_enum] = ACTIONS(5537),
    [anon_sym_ENUM] = ACTIONS(5537),
    [anon_sym_Enum] = ACTIONS(5537),
    [anon_sym_eNUM] = ACTIONS(5537),
    [anon_sym_eNum] = ACTIONS(5537),
    [anon_sym_ENum] = ACTIONS(5537),
    [sym_quoted_identifier] = ACTIONS(5539),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5539),
    [sym_verbatim_string] = ACTIONS(5539),
    [sym_integer] = ACTIONS(5537),
    [sym_continue_as_identifier] = ACTIONS(5539),
    [sym_preproc_open] = ACTIONS(5539),
    [sym_end_keyword] = ACTIONS(5539),
  },
  [STATE(3355)] = {
    [sym_identifier] = ACTIONS(6260),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6262),
    [aux_sym_boolean_token1] = ACTIONS(6260),
    [aux_sym_boolean_token2] = ACTIONS(6260),
    [sym_decimal] = ACTIONS(6260),
    [anon_sym_LPAREN] = ACTIONS(6262),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6260),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [aux_sym_record_type_token1] = ACTIONS(6260),
    [aux_sym_basic_type_token21] = ACTIONS(6260),
    [aux_sym_basic_type_token22] = ACTIONS(6260),
    [aux_sym_basic_type_token48] = ACTIONS(6260),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6260),
    [anon_sym_POUNDif] = ACTIONS(6262),
    [anon_sym_POUNDIF] = ACTIONS(6262),
    [anon_sym_POUNDIf] = ACTIONS(6262),
    [anon_sym_not] = ACTIONS(6260),
    [anon_sym_NOT] = ACTIONS(6260),
    [anon_sym_Not] = ACTIONS(6260),
    [anon_sym_POUNDelse] = ACTIONS(6262),
    [anon_sym_POUNDELSE] = ACTIONS(6262),
    [anon_sym_POUNDElse] = ACTIONS(6262),
    [anon_sym_POUNDelse2] = ACTIONS(6262),
    [anon_sym_POUNDELSE2] = ACTIONS(6262),
    [anon_sym_POUNDElse2] = ACTIONS(6262),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6260),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6262),
    [sym_datetime_literal] = ACTIONS(6262),
    [sym_date_literal] = ACTIONS(6260),
    [sym_time_literal] = ACTIONS(6260),
    [sym_biginteger_literal] = ACTIONS(6262),
    [anon_sym_if] = ACTIONS(6260),
    [anon_sym_IF] = ACTIONS(6260),
    [anon_sym_If] = ACTIONS(6260),
    [anon_sym_else] = ACTIONS(6260),
    [anon_sym_ELSE] = ACTIONS(6260),
    [anon_sym_Else] = ACTIONS(6260),
    [anon_sym_case] = ACTIONS(6260),
    [anon_sym_CASE] = ACTIONS(6260),
    [anon_sym_Case] = ACTIONS(6260),
    [anon_sym_for] = ACTIONS(6260),
    [anon_sym_FOR] = ACTIONS(6260),
    [anon_sym_For] = ACTIONS(6260),
    [anon_sym_foreach] = ACTIONS(6260),
    [anon_sym_FOREACH] = ACTIONS(6260),
    [anon_sym_Foreach] = ACTIONS(6260),
    [anon_sym_while] = ACTIONS(6260),
    [anon_sym_WHILE] = ACTIONS(6260),
    [anon_sym_While] = ACTIONS(6260),
    [anon_sym_repeat] = ACTIONS(6260),
    [anon_sym_REPEAT] = ACTIONS(6260),
    [anon_sym_Repeat] = ACTIONS(6260),
    [anon_sym_exit] = ACTIONS(6260),
    [anon_sym_EXIT] = ACTIONS(6260),
    [anon_sym_Exit] = ACTIONS(6260),
    [anon_sym_continue] = ACTIONS(6260),
    [anon_sym_CONTINUE] = ACTIONS(6260),
    [anon_sym_Continue] = ACTIONS(6260),
    [anon_sym_break] = ACTIONS(6260),
    [anon_sym_BREAK] = ACTIONS(6260),
    [anon_sym_Break] = ACTIONS(6260),
    [anon_sym_with] = ACTIONS(6260),
    [anon_sym_WITH] = ACTIONS(6260),
    [anon_sym_With] = ACTIONS(6260),
    [sym_asserterror_keyword] = ACTIONS(6262),
    [sym_page_keyword] = ACTIONS(6260),
    [anon_sym_codeunit] = ACTIONS(6260),
    [anon_sym_CODEUNIT] = ACTIONS(6260),
    [anon_sym_Codeunit] = ACTIONS(6260),
    [anon_sym_CodeUnit] = ACTIONS(6260),
    [anon_sym_COdeunit] = ACTIONS(6260),
    [anon_sym_codeUnit] = ACTIONS(6260),
    [sym_report_keyword] = ACTIONS(6260),
    [sym_query_keyword] = ACTIONS(6260),
    [anon_sym_xmlport] = ACTIONS(6260),
    [anon_sym_XMLPORT] = ACTIONS(6260),
    [anon_sym_Xmlport] = ACTIONS(6260),
    [anon_sym_XMLport] = ACTIONS(6260),
    [anon_sym_XMLPort] = ACTIONS(6260),
    [anon_sym_XmlPort] = ACTIONS(6260),
    [anon_sym_enum] = ACTIONS(6260),
    [anon_sym_ENUM] = ACTIONS(6260),
    [anon_sym_Enum] = ACTIONS(6260),
    [anon_sym_eNUM] = ACTIONS(6260),
    [anon_sym_eNum] = ACTIONS(6260),
    [anon_sym_ENum] = ACTIONS(6260),
    [sym_quoted_identifier] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6262),
    [sym_verbatim_string] = ACTIONS(6262),
    [sym_integer] = ACTIONS(6260),
    [sym_continue_as_identifier] = ACTIONS(6262),
    [sym_preproc_open] = ACTIONS(6262),
    [sym_end_keyword] = ACTIONS(6262),
  },
  [STATE(3356)] = {
    [sym_identifier] = ACTIONS(6260),
    [anon_sym_SEMI] = ACTIONS(6262),
    [anon_sym_DASH] = ACTIONS(6262),
    [aux_sym_boolean_token1] = ACTIONS(6260),
    [aux_sym_boolean_token2] = ACTIONS(6260),
    [sym_decimal] = ACTIONS(6260),
    [anon_sym_LPAREN] = ACTIONS(6262),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6260),
    [anon_sym_LBRACK] = ACTIONS(6262),
    [aux_sym_record_type_token1] = ACTIONS(6260),
    [aux_sym_basic_type_token21] = ACTIONS(6260),
    [aux_sym_basic_type_token22] = ACTIONS(6260),
    [aux_sym_basic_type_token48] = ACTIONS(6260),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6260),
    [anon_sym_POUNDif] = ACTIONS(6262),
    [anon_sym_POUNDIF] = ACTIONS(6262),
    [anon_sym_POUNDIf] = ACTIONS(6262),
    [anon_sym_not] = ACTIONS(6260),
    [anon_sym_NOT] = ACTIONS(6260),
    [anon_sym_Not] = ACTIONS(6260),
    [anon_sym_POUNDelse] = ACTIONS(6262),
    [anon_sym_POUNDELSE] = ACTIONS(6262),
    [anon_sym_POUNDElse] = ACTIONS(6262),
    [anon_sym_POUNDelse2] = ACTIONS(6262),
    [anon_sym_POUNDELSE2] = ACTIONS(6262),
    [anon_sym_POUNDElse2] = ACTIONS(6262),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6260),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6260),
    [anon_sym_PLUS] = ACTIONS(6262),
    [sym_datetime_literal] = ACTIONS(6262),
    [sym_date_literal] = ACTIONS(6260),
    [sym_time_literal] = ACTIONS(6260),
    [sym_biginteger_literal] = ACTIONS(6262),
    [anon_sym_if] = ACTIONS(6260),
    [anon_sym_IF] = ACTIONS(6260),
    [anon_sym_If] = ACTIONS(6260),
    [anon_sym_else] = ACTIONS(6260),
    [anon_sym_ELSE] = ACTIONS(6260),
    [anon_sym_Else] = ACTIONS(6260),
    [anon_sym_case] = ACTIONS(6260),
    [anon_sym_CASE] = ACTIONS(6260),
    [anon_sym_Case] = ACTIONS(6260),
    [anon_sym_for] = ACTIONS(6260),
    [anon_sym_FOR] = ACTIONS(6260),
    [anon_sym_For] = ACTIONS(6260),
    [anon_sym_foreach] = ACTIONS(6260),
    [anon_sym_FOREACH] = ACTIONS(6260),
    [anon_sym_Foreach] = ACTIONS(6260),
    [anon_sym_while] = ACTIONS(6260),
    [anon_sym_WHILE] = ACTIONS(6260),
    [anon_sym_While] = ACTIONS(6260),
    [anon_sym_repeat] = ACTIONS(6260),
    [anon_sym_REPEAT] = ACTIONS(6260),
    [anon_sym_Repeat] = ACTIONS(6260),
    [anon_sym_exit] = ACTIONS(6260),
    [anon_sym_EXIT] = ACTIONS(6260),
    [anon_sym_Exit] = ACTIONS(6260),
    [anon_sym_continue] = ACTIONS(6260),
    [anon_sym_CONTINUE] = ACTIONS(6260),
    [anon_sym_Continue] = ACTIONS(6260),
    [anon_sym_break] = ACTIONS(6260),
    [anon_sym_BREAK] = ACTIONS(6260),
    [anon_sym_Break] = ACTIONS(6260),
    [anon_sym_with] = ACTIONS(6260),
    [anon_sym_WITH] = ACTIONS(6260),
    [anon_sym_With] = ACTIONS(6260),
    [sym_asserterror_keyword] = ACTIONS(6262),
    [sym_page_keyword] = ACTIONS(6260),
    [anon_sym_codeunit] = ACTIONS(6260),
    [anon_sym_CODEUNIT] = ACTIONS(6260),
    [anon_sym_Codeunit] = ACTIONS(6260),
    [anon_sym_CodeUnit] = ACTIONS(6260),
    [anon_sym_COdeunit] = ACTIONS(6260),
    [anon_sym_codeUnit] = ACTIONS(6260),
    [sym_report_keyword] = ACTIONS(6260),
    [sym_query_keyword] = ACTIONS(6260),
    [anon_sym_xmlport] = ACTIONS(6260),
    [anon_sym_XMLPORT] = ACTIONS(6260),
    [anon_sym_Xmlport] = ACTIONS(6260),
    [anon_sym_XMLport] = ACTIONS(6260),
    [anon_sym_XMLPort] = ACTIONS(6260),
    [anon_sym_XmlPort] = ACTIONS(6260),
    [anon_sym_enum] = ACTIONS(6260),
    [anon_sym_ENUM] = ACTIONS(6260),
    [anon_sym_Enum] = ACTIONS(6260),
    [anon_sym_eNUM] = ACTIONS(6260),
    [anon_sym_eNum] = ACTIONS(6260),
    [anon_sym_ENum] = ACTIONS(6260),
    [sym_quoted_identifier] = ACTIONS(6262),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6262),
    [sym_verbatim_string] = ACTIONS(6262),
    [sym_integer] = ACTIONS(6260),
    [sym_continue_as_identifier] = ACTIONS(6262),
    [sym_preproc_open] = ACTIONS(6262),
    [sym_end_keyword] = ACTIONS(6262),
  },
  [STATE(3357)] = {
    [sym_identifier] = ACTIONS(6046),
    [anon_sym_SEMI] = ACTIONS(6048),
    [anon_sym_DASH] = ACTIONS(6048),
    [aux_sym_boolean_token1] = ACTIONS(6046),
    [aux_sym_boolean_token2] = ACTIONS(6046),
    [sym_decimal] = ACTIONS(6046),
    [anon_sym_LPAREN] = ACTIONS(6048),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6046),
    [anon_sym_LBRACK] = ACTIONS(6048),
    [aux_sym_record_type_token1] = ACTIONS(6046),
    [aux_sym_basic_type_token21] = ACTIONS(6046),
    [aux_sym_basic_type_token22] = ACTIONS(6046),
    [aux_sym_basic_type_token48] = ACTIONS(6046),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6046),
    [anon_sym_POUNDif] = ACTIONS(6048),
    [anon_sym_POUNDIF] = ACTIONS(6048),
    [anon_sym_POUNDIf] = ACTIONS(6048),
    [anon_sym_not] = ACTIONS(6046),
    [anon_sym_NOT] = ACTIONS(6046),
    [anon_sym_Not] = ACTIONS(6046),
    [anon_sym_POUNDelse] = ACTIONS(6048),
    [anon_sym_POUNDELSE] = ACTIONS(6048),
    [anon_sym_POUNDElse] = ACTIONS(6048),
    [anon_sym_POUNDelse2] = ACTIONS(6048),
    [anon_sym_POUNDELSE2] = ACTIONS(6048),
    [anon_sym_POUNDElse2] = ACTIONS(6048),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6046),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6046),
    [anon_sym_PLUS] = ACTIONS(6048),
    [sym_datetime_literal] = ACTIONS(6048),
    [sym_date_literal] = ACTIONS(6046),
    [sym_time_literal] = ACTIONS(6046),
    [sym_biginteger_literal] = ACTIONS(6048),
    [anon_sym_if] = ACTIONS(6046),
    [anon_sym_IF] = ACTIONS(6046),
    [anon_sym_If] = ACTIONS(6046),
    [anon_sym_else] = ACTIONS(6046),
    [anon_sym_ELSE] = ACTIONS(6046),
    [anon_sym_Else] = ACTIONS(6046),
    [anon_sym_case] = ACTIONS(6046),
    [anon_sym_CASE] = ACTIONS(6046),
    [anon_sym_Case] = ACTIONS(6046),
    [anon_sym_for] = ACTIONS(6046),
    [anon_sym_FOR] = ACTIONS(6046),
    [anon_sym_For] = ACTIONS(6046),
    [anon_sym_foreach] = ACTIONS(6046),
    [anon_sym_FOREACH] = ACTIONS(6046),
    [anon_sym_Foreach] = ACTIONS(6046),
    [anon_sym_while] = ACTIONS(6046),
    [anon_sym_WHILE] = ACTIONS(6046),
    [anon_sym_While] = ACTIONS(6046),
    [anon_sym_repeat] = ACTIONS(6046),
    [anon_sym_REPEAT] = ACTIONS(6046),
    [anon_sym_Repeat] = ACTIONS(6046),
    [anon_sym_exit] = ACTIONS(6046),
    [anon_sym_EXIT] = ACTIONS(6046),
    [anon_sym_Exit] = ACTIONS(6046),
    [anon_sym_continue] = ACTIONS(6046),
    [anon_sym_CONTINUE] = ACTIONS(6046),
    [anon_sym_Continue] = ACTIONS(6046),
    [anon_sym_break] = ACTIONS(6046),
    [anon_sym_BREAK] = ACTIONS(6046),
    [anon_sym_Break] = ACTIONS(6046),
    [anon_sym_with] = ACTIONS(6046),
    [anon_sym_WITH] = ACTIONS(6046),
    [anon_sym_With] = ACTIONS(6046),
    [sym_asserterror_keyword] = ACTIONS(6048),
    [sym_page_keyword] = ACTIONS(6046),
    [anon_sym_codeunit] = ACTIONS(6046),
    [anon_sym_CODEUNIT] = ACTIONS(6046),
    [anon_sym_Codeunit] = ACTIONS(6046),
    [anon_sym_CodeUnit] = ACTIONS(6046),
    [anon_sym_COdeunit] = ACTIONS(6046),
    [anon_sym_codeUnit] = ACTIONS(6046),
    [sym_report_keyword] = ACTIONS(6046),
    [sym_query_keyword] = ACTIONS(6046),
    [anon_sym_xmlport] = ACTIONS(6046),
    [anon_sym_XMLPORT] = ACTIONS(6046),
    [anon_sym_Xmlport] = ACTIONS(6046),
    [anon_sym_XMLport] = ACTIONS(6046),
    [anon_sym_XMLPort] = ACTIONS(6046),
    [anon_sym_XmlPort] = ACTIONS(6046),
    [anon_sym_enum] = ACTIONS(6046),
    [anon_sym_ENUM] = ACTIONS(6046),
    [anon_sym_Enum] = ACTIONS(6046),
    [anon_sym_eNUM] = ACTIONS(6046),
    [anon_sym_eNum] = ACTIONS(6046),
    [anon_sym_ENum] = ACTIONS(6046),
    [sym_quoted_identifier] = ACTIONS(6048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6048),
    [sym_verbatim_string] = ACTIONS(6048),
    [sym_integer] = ACTIONS(6046),
    [sym_continue_as_identifier] = ACTIONS(6048),
    [sym_preproc_open] = ACTIONS(6048),
    [sym_end_keyword] = ACTIONS(6048),
  },
  [STATE(3358)] = {
    [sym_identifier] = ACTIONS(6050),
    [anon_sym_SEMI] = ACTIONS(6052),
    [anon_sym_DASH] = ACTIONS(6052),
    [aux_sym_boolean_token1] = ACTIONS(6050),
    [aux_sym_boolean_token2] = ACTIONS(6050),
    [sym_decimal] = ACTIONS(6050),
    [anon_sym_LPAREN] = ACTIONS(6052),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6050),
    [anon_sym_LBRACK] = ACTIONS(6052),
    [aux_sym_record_type_token1] = ACTIONS(6050),
    [aux_sym_basic_type_token21] = ACTIONS(6050),
    [aux_sym_basic_type_token22] = ACTIONS(6050),
    [aux_sym_basic_type_token48] = ACTIONS(6050),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6050),
    [anon_sym_POUNDif] = ACTIONS(6052),
    [anon_sym_POUNDIF] = ACTIONS(6052),
    [anon_sym_POUNDIf] = ACTIONS(6052),
    [anon_sym_not] = ACTIONS(6050),
    [anon_sym_NOT] = ACTIONS(6050),
    [anon_sym_Not] = ACTIONS(6050),
    [anon_sym_POUNDelse] = ACTIONS(6052),
    [anon_sym_POUNDELSE] = ACTIONS(6052),
    [anon_sym_POUNDElse] = ACTIONS(6052),
    [anon_sym_POUNDelse2] = ACTIONS(6052),
    [anon_sym_POUNDELSE2] = ACTIONS(6052),
    [anon_sym_POUNDElse2] = ACTIONS(6052),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6050),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6050),
    [anon_sym_PLUS] = ACTIONS(6052),
    [sym_datetime_literal] = ACTIONS(6052),
    [sym_date_literal] = ACTIONS(6050),
    [sym_time_literal] = ACTIONS(6050),
    [sym_biginteger_literal] = ACTIONS(6052),
    [anon_sym_if] = ACTIONS(6050),
    [anon_sym_IF] = ACTIONS(6050),
    [anon_sym_If] = ACTIONS(6050),
    [anon_sym_else] = ACTIONS(6050),
    [anon_sym_ELSE] = ACTIONS(6050),
    [anon_sym_Else] = ACTIONS(6050),
    [anon_sym_case] = ACTIONS(6050),
    [anon_sym_CASE] = ACTIONS(6050),
    [anon_sym_Case] = ACTIONS(6050),
    [anon_sym_for] = ACTIONS(6050),
    [anon_sym_FOR] = ACTIONS(6050),
    [anon_sym_For] = ACTIONS(6050),
    [anon_sym_foreach] = ACTIONS(6050),
    [anon_sym_FOREACH] = ACTIONS(6050),
    [anon_sym_Foreach] = ACTIONS(6050),
    [anon_sym_while] = ACTIONS(6050),
    [anon_sym_WHILE] = ACTIONS(6050),
    [anon_sym_While] = ACTIONS(6050),
    [anon_sym_repeat] = ACTIONS(6050),
    [anon_sym_REPEAT] = ACTIONS(6050),
    [anon_sym_Repeat] = ACTIONS(6050),
    [anon_sym_exit] = ACTIONS(6050),
    [anon_sym_EXIT] = ACTIONS(6050),
    [anon_sym_Exit] = ACTIONS(6050),
    [anon_sym_continue] = ACTIONS(6050),
    [anon_sym_CONTINUE] = ACTIONS(6050),
    [anon_sym_Continue] = ACTIONS(6050),
    [anon_sym_break] = ACTIONS(6050),
    [anon_sym_BREAK] = ACTIONS(6050),
    [anon_sym_Break] = ACTIONS(6050),
    [anon_sym_with] = ACTIONS(6050),
    [anon_sym_WITH] = ACTIONS(6050),
    [anon_sym_With] = ACTIONS(6050),
    [sym_asserterror_keyword] = ACTIONS(6052),
    [sym_page_keyword] = ACTIONS(6050),
    [anon_sym_codeunit] = ACTIONS(6050),
    [anon_sym_CODEUNIT] = ACTIONS(6050),
    [anon_sym_Codeunit] = ACTIONS(6050),
    [anon_sym_CodeUnit] = ACTIONS(6050),
    [anon_sym_COdeunit] = ACTIONS(6050),
    [anon_sym_codeUnit] = ACTIONS(6050),
    [sym_report_keyword] = ACTIONS(6050),
    [sym_query_keyword] = ACTIONS(6050),
    [anon_sym_xmlport] = ACTIONS(6050),
    [anon_sym_XMLPORT] = ACTIONS(6050),
    [anon_sym_Xmlport] = ACTIONS(6050),
    [anon_sym_XMLport] = ACTIONS(6050),
    [anon_sym_XMLPort] = ACTIONS(6050),
    [anon_sym_XmlPort] = ACTIONS(6050),
    [anon_sym_enum] = ACTIONS(6050),
    [anon_sym_ENUM] = ACTIONS(6050),
    [anon_sym_Enum] = ACTIONS(6050),
    [anon_sym_eNUM] = ACTIONS(6050),
    [anon_sym_eNum] = ACTIONS(6050),
    [anon_sym_ENum] = ACTIONS(6050),
    [sym_quoted_identifier] = ACTIONS(6052),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6052),
    [sym_verbatim_string] = ACTIONS(6052),
    [sym_integer] = ACTIONS(6050),
    [sym_continue_as_identifier] = ACTIONS(6052),
    [sym_preproc_open] = ACTIONS(6052),
    [sym_end_keyword] = ACTIONS(6052),
  },
  [STATE(3359)] = {
    [sym_identifier] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym_DASH] = ACTIONS(5543),
    [aux_sym_boolean_token1] = ACTIONS(5541),
    [aux_sym_boolean_token2] = ACTIONS(5541),
    [sym_decimal] = ACTIONS(5541),
    [anon_sym_LPAREN] = ACTIONS(5543),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5543),
    [aux_sym_record_type_token1] = ACTIONS(5541),
    [aux_sym_basic_type_token21] = ACTIONS(5541),
    [aux_sym_basic_type_token22] = ACTIONS(5541),
    [aux_sym_basic_type_token48] = ACTIONS(5541),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5541),
    [anon_sym_POUNDif] = ACTIONS(5543),
    [anon_sym_POUNDIF] = ACTIONS(5543),
    [anon_sym_POUNDIf] = ACTIONS(5543),
    [anon_sym_not] = ACTIONS(5541),
    [anon_sym_NOT] = ACTIONS(5541),
    [anon_sym_Not] = ACTIONS(5541),
    [anon_sym_POUNDelse] = ACTIONS(5543),
    [anon_sym_POUNDELSE] = ACTIONS(5543),
    [anon_sym_POUNDElse] = ACTIONS(5543),
    [anon_sym_POUNDelse2] = ACTIONS(5543),
    [anon_sym_POUNDELSE2] = ACTIONS(5543),
    [anon_sym_POUNDElse2] = ACTIONS(5543),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5541),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5541),
    [anon_sym_PLUS] = ACTIONS(5543),
    [sym_datetime_literal] = ACTIONS(5543),
    [sym_date_literal] = ACTIONS(5541),
    [sym_time_literal] = ACTIONS(5541),
    [sym_biginteger_literal] = ACTIONS(5543),
    [anon_sym_if] = ACTIONS(5541),
    [anon_sym_IF] = ACTIONS(5541),
    [anon_sym_If] = ACTIONS(5541),
    [anon_sym_else] = ACTIONS(5541),
    [anon_sym_ELSE] = ACTIONS(5541),
    [anon_sym_Else] = ACTIONS(5541),
    [anon_sym_case] = ACTIONS(5541),
    [anon_sym_CASE] = ACTIONS(5541),
    [anon_sym_Case] = ACTIONS(5541),
    [anon_sym_for] = ACTIONS(5541),
    [anon_sym_FOR] = ACTIONS(5541),
    [anon_sym_For] = ACTIONS(5541),
    [anon_sym_foreach] = ACTIONS(5541),
    [anon_sym_FOREACH] = ACTIONS(5541),
    [anon_sym_Foreach] = ACTIONS(5541),
    [anon_sym_while] = ACTIONS(5541),
    [anon_sym_WHILE] = ACTIONS(5541),
    [anon_sym_While] = ACTIONS(5541),
    [anon_sym_repeat] = ACTIONS(5541),
    [anon_sym_REPEAT] = ACTIONS(5541),
    [anon_sym_Repeat] = ACTIONS(5541),
    [anon_sym_exit] = ACTIONS(5541),
    [anon_sym_EXIT] = ACTIONS(5541),
    [anon_sym_Exit] = ACTIONS(5541),
    [anon_sym_continue] = ACTIONS(5541),
    [anon_sym_CONTINUE] = ACTIONS(5541),
    [anon_sym_Continue] = ACTIONS(5541),
    [anon_sym_break] = ACTIONS(5541),
    [anon_sym_BREAK] = ACTIONS(5541),
    [anon_sym_Break] = ACTIONS(5541),
    [anon_sym_with] = ACTIONS(5541),
    [anon_sym_WITH] = ACTIONS(5541),
    [anon_sym_With] = ACTIONS(5541),
    [sym_asserterror_keyword] = ACTIONS(5543),
    [sym_page_keyword] = ACTIONS(5541),
    [anon_sym_codeunit] = ACTIONS(5541),
    [anon_sym_CODEUNIT] = ACTIONS(5541),
    [anon_sym_Codeunit] = ACTIONS(5541),
    [anon_sym_CodeUnit] = ACTIONS(5541),
    [anon_sym_COdeunit] = ACTIONS(5541),
    [anon_sym_codeUnit] = ACTIONS(5541),
    [sym_report_keyword] = ACTIONS(5541),
    [sym_query_keyword] = ACTIONS(5541),
    [anon_sym_xmlport] = ACTIONS(5541),
    [anon_sym_XMLPORT] = ACTIONS(5541),
    [anon_sym_Xmlport] = ACTIONS(5541),
    [anon_sym_XMLport] = ACTIONS(5541),
    [anon_sym_XMLPort] = ACTIONS(5541),
    [anon_sym_XmlPort] = ACTIONS(5541),
    [anon_sym_enum] = ACTIONS(5541),
    [anon_sym_ENUM] = ACTIONS(5541),
    [anon_sym_Enum] = ACTIONS(5541),
    [anon_sym_eNUM] = ACTIONS(5541),
    [anon_sym_eNum] = ACTIONS(5541),
    [anon_sym_ENum] = ACTIONS(5541),
    [sym_quoted_identifier] = ACTIONS(5543),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5543),
    [sym_verbatim_string] = ACTIONS(5543),
    [sym_integer] = ACTIONS(5541),
    [sym_continue_as_identifier] = ACTIONS(5543),
    [sym_preproc_open] = ACTIONS(5543),
    [sym_end_keyword] = ACTIONS(5543),
  },
  [STATE(3360)] = {
    [sym_identifier] = ACTIONS(5807),
    [anon_sym_SEMI] = ACTIONS(5809),
    [anon_sym_DASH] = ACTIONS(5809),
    [aux_sym_boolean_token1] = ACTIONS(5807),
    [aux_sym_boolean_token2] = ACTIONS(5807),
    [sym_decimal] = ACTIONS(5807),
    [anon_sym_LPAREN] = ACTIONS(5809),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5809),
    [aux_sym_record_type_token1] = ACTIONS(5807),
    [aux_sym_basic_type_token21] = ACTIONS(5807),
    [aux_sym_basic_type_token22] = ACTIONS(5807),
    [aux_sym_basic_type_token48] = ACTIONS(5807),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5807),
    [anon_sym_POUNDif] = ACTIONS(5809),
    [anon_sym_POUNDIF] = ACTIONS(5809),
    [anon_sym_POUNDIf] = ACTIONS(5809),
    [anon_sym_not] = ACTIONS(5807),
    [anon_sym_NOT] = ACTIONS(5807),
    [anon_sym_Not] = ACTIONS(5807),
    [anon_sym_POUNDelse] = ACTIONS(5809),
    [anon_sym_POUNDELSE] = ACTIONS(5809),
    [anon_sym_POUNDElse] = ACTIONS(5809),
    [anon_sym_POUNDelse2] = ACTIONS(5809),
    [anon_sym_POUNDELSE2] = ACTIONS(5809),
    [anon_sym_POUNDElse2] = ACTIONS(5809),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5807),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5807),
    [anon_sym_PLUS] = ACTIONS(5809),
    [sym_datetime_literal] = ACTIONS(5809),
    [sym_date_literal] = ACTIONS(5807),
    [sym_time_literal] = ACTIONS(5807),
    [sym_biginteger_literal] = ACTIONS(5809),
    [anon_sym_if] = ACTIONS(5807),
    [anon_sym_IF] = ACTIONS(5807),
    [anon_sym_If] = ACTIONS(5807),
    [anon_sym_else] = ACTIONS(5807),
    [anon_sym_ELSE] = ACTIONS(5807),
    [anon_sym_Else] = ACTIONS(5807),
    [anon_sym_case] = ACTIONS(5807),
    [anon_sym_CASE] = ACTIONS(5807),
    [anon_sym_Case] = ACTIONS(5807),
    [anon_sym_for] = ACTIONS(5807),
    [anon_sym_FOR] = ACTIONS(5807),
    [anon_sym_For] = ACTIONS(5807),
    [anon_sym_foreach] = ACTIONS(5807),
    [anon_sym_FOREACH] = ACTIONS(5807),
    [anon_sym_Foreach] = ACTIONS(5807),
    [anon_sym_while] = ACTIONS(5807),
    [anon_sym_WHILE] = ACTIONS(5807),
    [anon_sym_While] = ACTIONS(5807),
    [anon_sym_repeat] = ACTIONS(5807),
    [anon_sym_REPEAT] = ACTIONS(5807),
    [anon_sym_Repeat] = ACTIONS(5807),
    [anon_sym_exit] = ACTIONS(5807),
    [anon_sym_EXIT] = ACTIONS(5807),
    [anon_sym_Exit] = ACTIONS(5807),
    [anon_sym_continue] = ACTIONS(5807),
    [anon_sym_CONTINUE] = ACTIONS(5807),
    [anon_sym_Continue] = ACTIONS(5807),
    [anon_sym_break] = ACTIONS(5807),
    [anon_sym_BREAK] = ACTIONS(5807),
    [anon_sym_Break] = ACTIONS(5807),
    [anon_sym_with] = ACTIONS(5807),
    [anon_sym_WITH] = ACTIONS(5807),
    [anon_sym_With] = ACTIONS(5807),
    [sym_asserterror_keyword] = ACTIONS(5809),
    [sym_page_keyword] = ACTIONS(5807),
    [anon_sym_codeunit] = ACTIONS(5807),
    [anon_sym_CODEUNIT] = ACTIONS(5807),
    [anon_sym_Codeunit] = ACTIONS(5807),
    [anon_sym_CodeUnit] = ACTIONS(5807),
    [anon_sym_COdeunit] = ACTIONS(5807),
    [anon_sym_codeUnit] = ACTIONS(5807),
    [sym_report_keyword] = ACTIONS(5807),
    [sym_query_keyword] = ACTIONS(5807),
    [anon_sym_xmlport] = ACTIONS(5807),
    [anon_sym_XMLPORT] = ACTIONS(5807),
    [anon_sym_Xmlport] = ACTIONS(5807),
    [anon_sym_XMLport] = ACTIONS(5807),
    [anon_sym_XMLPort] = ACTIONS(5807),
    [anon_sym_XmlPort] = ACTIONS(5807),
    [anon_sym_enum] = ACTIONS(5807),
    [anon_sym_ENUM] = ACTIONS(5807),
    [anon_sym_Enum] = ACTIONS(5807),
    [anon_sym_eNUM] = ACTIONS(5807),
    [anon_sym_eNum] = ACTIONS(5807),
    [anon_sym_ENum] = ACTIONS(5807),
    [sym_quoted_identifier] = ACTIONS(5809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5809),
    [sym_verbatim_string] = ACTIONS(5809),
    [sym_integer] = ACTIONS(5807),
    [sym_continue_as_identifier] = ACTIONS(5809),
    [sym_preproc_open] = ACTIONS(5809),
    [sym_end_keyword] = ACTIONS(5809),
  },
  [STATE(3361)] = {
    [sym_identifier] = ACTIONS(5811),
    [anon_sym_SEMI] = ACTIONS(5813),
    [anon_sym_DASH] = ACTIONS(5813),
    [aux_sym_boolean_token1] = ACTIONS(5811),
    [aux_sym_boolean_token2] = ACTIONS(5811),
    [sym_decimal] = ACTIONS(5811),
    [anon_sym_LPAREN] = ACTIONS(5813),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5811),
    [anon_sym_LBRACK] = ACTIONS(5813),
    [aux_sym_record_type_token1] = ACTIONS(5811),
    [aux_sym_basic_type_token21] = ACTIONS(5811),
    [aux_sym_basic_type_token22] = ACTIONS(5811),
    [aux_sym_basic_type_token48] = ACTIONS(5811),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5811),
    [anon_sym_POUNDif] = ACTIONS(5813),
    [anon_sym_POUNDIF] = ACTIONS(5813),
    [anon_sym_POUNDIf] = ACTIONS(5813),
    [anon_sym_not] = ACTIONS(5811),
    [anon_sym_NOT] = ACTIONS(5811),
    [anon_sym_Not] = ACTIONS(5811),
    [anon_sym_POUNDelse] = ACTIONS(5813),
    [anon_sym_POUNDELSE] = ACTIONS(5813),
    [anon_sym_POUNDElse] = ACTIONS(5813),
    [anon_sym_POUNDelse2] = ACTIONS(5813),
    [anon_sym_POUNDELSE2] = ACTIONS(5813),
    [anon_sym_POUNDElse2] = ACTIONS(5813),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5811),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5811),
    [anon_sym_PLUS] = ACTIONS(5813),
    [sym_datetime_literal] = ACTIONS(5813),
    [sym_date_literal] = ACTIONS(5811),
    [sym_time_literal] = ACTIONS(5811),
    [sym_biginteger_literal] = ACTIONS(5813),
    [anon_sym_if] = ACTIONS(5811),
    [anon_sym_IF] = ACTIONS(5811),
    [anon_sym_If] = ACTIONS(5811),
    [anon_sym_else] = ACTIONS(5811),
    [anon_sym_ELSE] = ACTIONS(5811),
    [anon_sym_Else] = ACTIONS(5811),
    [anon_sym_case] = ACTIONS(5811),
    [anon_sym_CASE] = ACTIONS(5811),
    [anon_sym_Case] = ACTIONS(5811),
    [anon_sym_for] = ACTIONS(5811),
    [anon_sym_FOR] = ACTIONS(5811),
    [anon_sym_For] = ACTIONS(5811),
    [anon_sym_foreach] = ACTIONS(5811),
    [anon_sym_FOREACH] = ACTIONS(5811),
    [anon_sym_Foreach] = ACTIONS(5811),
    [anon_sym_while] = ACTIONS(5811),
    [anon_sym_WHILE] = ACTIONS(5811),
    [anon_sym_While] = ACTIONS(5811),
    [anon_sym_repeat] = ACTIONS(5811),
    [anon_sym_REPEAT] = ACTIONS(5811),
    [anon_sym_Repeat] = ACTIONS(5811),
    [anon_sym_exit] = ACTIONS(5811),
    [anon_sym_EXIT] = ACTIONS(5811),
    [anon_sym_Exit] = ACTIONS(5811),
    [anon_sym_continue] = ACTIONS(5811),
    [anon_sym_CONTINUE] = ACTIONS(5811),
    [anon_sym_Continue] = ACTIONS(5811),
    [anon_sym_break] = ACTIONS(5811),
    [anon_sym_BREAK] = ACTIONS(5811),
    [anon_sym_Break] = ACTIONS(5811),
    [anon_sym_with] = ACTIONS(5811),
    [anon_sym_WITH] = ACTIONS(5811),
    [anon_sym_With] = ACTIONS(5811),
    [sym_asserterror_keyword] = ACTIONS(5813),
    [sym_page_keyword] = ACTIONS(5811),
    [anon_sym_codeunit] = ACTIONS(5811),
    [anon_sym_CODEUNIT] = ACTIONS(5811),
    [anon_sym_Codeunit] = ACTIONS(5811),
    [anon_sym_CodeUnit] = ACTIONS(5811),
    [anon_sym_COdeunit] = ACTIONS(5811),
    [anon_sym_codeUnit] = ACTIONS(5811),
    [sym_report_keyword] = ACTIONS(5811),
    [sym_query_keyword] = ACTIONS(5811),
    [anon_sym_xmlport] = ACTIONS(5811),
    [anon_sym_XMLPORT] = ACTIONS(5811),
    [anon_sym_Xmlport] = ACTIONS(5811),
    [anon_sym_XMLport] = ACTIONS(5811),
    [anon_sym_XMLPort] = ACTIONS(5811),
    [anon_sym_XmlPort] = ACTIONS(5811),
    [anon_sym_enum] = ACTIONS(5811),
    [anon_sym_ENUM] = ACTIONS(5811),
    [anon_sym_Enum] = ACTIONS(5811),
    [anon_sym_eNUM] = ACTIONS(5811),
    [anon_sym_eNum] = ACTIONS(5811),
    [anon_sym_ENum] = ACTIONS(5811),
    [sym_quoted_identifier] = ACTIONS(5813),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5813),
    [sym_verbatim_string] = ACTIONS(5813),
    [sym_integer] = ACTIONS(5811),
    [sym_continue_as_identifier] = ACTIONS(5813),
    [sym_preproc_open] = ACTIONS(5813),
    [sym_end_keyword] = ACTIONS(5813),
  },
  [STATE(3362)] = {
    [sym_identifier] = ACTIONS(5815),
    [anon_sym_SEMI] = ACTIONS(5817),
    [anon_sym_DASH] = ACTIONS(5817),
    [aux_sym_boolean_token1] = ACTIONS(5815),
    [aux_sym_boolean_token2] = ACTIONS(5815),
    [sym_decimal] = ACTIONS(5815),
    [anon_sym_LPAREN] = ACTIONS(5817),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5815),
    [anon_sym_LBRACK] = ACTIONS(5817),
    [aux_sym_record_type_token1] = ACTIONS(5815),
    [aux_sym_basic_type_token21] = ACTIONS(5815),
    [aux_sym_basic_type_token22] = ACTIONS(5815),
    [aux_sym_basic_type_token48] = ACTIONS(5815),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5815),
    [anon_sym_POUNDif] = ACTIONS(5817),
    [anon_sym_POUNDIF] = ACTIONS(5817),
    [anon_sym_POUNDIf] = ACTIONS(5817),
    [anon_sym_not] = ACTIONS(5815),
    [anon_sym_NOT] = ACTIONS(5815),
    [anon_sym_Not] = ACTIONS(5815),
    [anon_sym_POUNDelse] = ACTIONS(5817),
    [anon_sym_POUNDELSE] = ACTIONS(5817),
    [anon_sym_POUNDElse] = ACTIONS(5817),
    [anon_sym_POUNDelse2] = ACTIONS(5817),
    [anon_sym_POUNDELSE2] = ACTIONS(5817),
    [anon_sym_POUNDElse2] = ACTIONS(5817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5815),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5815),
    [anon_sym_PLUS] = ACTIONS(5817),
    [sym_datetime_literal] = ACTIONS(5817),
    [sym_date_literal] = ACTIONS(5815),
    [sym_time_literal] = ACTIONS(5815),
    [sym_biginteger_literal] = ACTIONS(5817),
    [anon_sym_if] = ACTIONS(5815),
    [anon_sym_IF] = ACTIONS(5815),
    [anon_sym_If] = ACTIONS(5815),
    [anon_sym_else] = ACTIONS(5815),
    [anon_sym_ELSE] = ACTIONS(5815),
    [anon_sym_Else] = ACTIONS(5815),
    [anon_sym_case] = ACTIONS(5815),
    [anon_sym_CASE] = ACTIONS(5815),
    [anon_sym_Case] = ACTIONS(5815),
    [anon_sym_for] = ACTIONS(5815),
    [anon_sym_FOR] = ACTIONS(5815),
    [anon_sym_For] = ACTIONS(5815),
    [anon_sym_foreach] = ACTIONS(5815),
    [anon_sym_FOREACH] = ACTIONS(5815),
    [anon_sym_Foreach] = ACTIONS(5815),
    [anon_sym_while] = ACTIONS(5815),
    [anon_sym_WHILE] = ACTIONS(5815),
    [anon_sym_While] = ACTIONS(5815),
    [anon_sym_repeat] = ACTIONS(5815),
    [anon_sym_REPEAT] = ACTIONS(5815),
    [anon_sym_Repeat] = ACTIONS(5815),
    [anon_sym_exit] = ACTIONS(5815),
    [anon_sym_EXIT] = ACTIONS(5815),
    [anon_sym_Exit] = ACTIONS(5815),
    [anon_sym_continue] = ACTIONS(5815),
    [anon_sym_CONTINUE] = ACTIONS(5815),
    [anon_sym_Continue] = ACTIONS(5815),
    [anon_sym_break] = ACTIONS(5815),
    [anon_sym_BREAK] = ACTIONS(5815),
    [anon_sym_Break] = ACTIONS(5815),
    [anon_sym_with] = ACTIONS(5815),
    [anon_sym_WITH] = ACTIONS(5815),
    [anon_sym_With] = ACTIONS(5815),
    [sym_asserterror_keyword] = ACTIONS(5817),
    [sym_page_keyword] = ACTIONS(5815),
    [anon_sym_codeunit] = ACTIONS(5815),
    [anon_sym_CODEUNIT] = ACTIONS(5815),
    [anon_sym_Codeunit] = ACTIONS(5815),
    [anon_sym_CodeUnit] = ACTIONS(5815),
    [anon_sym_COdeunit] = ACTIONS(5815),
    [anon_sym_codeUnit] = ACTIONS(5815),
    [sym_report_keyword] = ACTIONS(5815),
    [sym_query_keyword] = ACTIONS(5815),
    [anon_sym_xmlport] = ACTIONS(5815),
    [anon_sym_XMLPORT] = ACTIONS(5815),
    [anon_sym_Xmlport] = ACTIONS(5815),
    [anon_sym_XMLport] = ACTIONS(5815),
    [anon_sym_XMLPort] = ACTIONS(5815),
    [anon_sym_XmlPort] = ACTIONS(5815),
    [anon_sym_enum] = ACTIONS(5815),
    [anon_sym_ENUM] = ACTIONS(5815),
    [anon_sym_Enum] = ACTIONS(5815),
    [anon_sym_eNUM] = ACTIONS(5815),
    [anon_sym_eNum] = ACTIONS(5815),
    [anon_sym_ENum] = ACTIONS(5815),
    [sym_quoted_identifier] = ACTIONS(5817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5817),
    [sym_verbatim_string] = ACTIONS(5817),
    [sym_integer] = ACTIONS(5815),
    [sym_continue_as_identifier] = ACTIONS(5817),
    [sym_preproc_open] = ACTIONS(5817),
    [sym_end_keyword] = ACTIONS(5817),
  },
  [STATE(3363)] = {
    [sym_identifier] = ACTIONS(5819),
    [anon_sym_SEMI] = ACTIONS(5821),
    [anon_sym_DASH] = ACTIONS(5821),
    [aux_sym_boolean_token1] = ACTIONS(5819),
    [aux_sym_boolean_token2] = ACTIONS(5819),
    [sym_decimal] = ACTIONS(5819),
    [anon_sym_LPAREN] = ACTIONS(5821),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5819),
    [anon_sym_LBRACK] = ACTIONS(5821),
    [aux_sym_record_type_token1] = ACTIONS(5819),
    [aux_sym_basic_type_token21] = ACTIONS(5819),
    [aux_sym_basic_type_token22] = ACTIONS(5819),
    [aux_sym_basic_type_token48] = ACTIONS(5819),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5819),
    [anon_sym_POUNDif] = ACTIONS(5821),
    [anon_sym_POUNDIF] = ACTIONS(5821),
    [anon_sym_POUNDIf] = ACTIONS(5821),
    [anon_sym_not] = ACTIONS(5819),
    [anon_sym_NOT] = ACTIONS(5819),
    [anon_sym_Not] = ACTIONS(5819),
    [anon_sym_POUNDelse] = ACTIONS(5821),
    [anon_sym_POUNDELSE] = ACTIONS(5821),
    [anon_sym_POUNDElse] = ACTIONS(5821),
    [anon_sym_POUNDelse2] = ACTIONS(5821),
    [anon_sym_POUNDELSE2] = ACTIONS(5821),
    [anon_sym_POUNDElse2] = ACTIONS(5821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5819),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5819),
    [anon_sym_PLUS] = ACTIONS(5821),
    [sym_datetime_literal] = ACTIONS(5821),
    [sym_date_literal] = ACTIONS(5819),
    [sym_time_literal] = ACTIONS(5819),
    [sym_biginteger_literal] = ACTIONS(5821),
    [anon_sym_if] = ACTIONS(5819),
    [anon_sym_IF] = ACTIONS(5819),
    [anon_sym_If] = ACTIONS(5819),
    [anon_sym_else] = ACTIONS(5819),
    [anon_sym_ELSE] = ACTIONS(5819),
    [anon_sym_Else] = ACTIONS(5819),
    [anon_sym_case] = ACTIONS(5819),
    [anon_sym_CASE] = ACTIONS(5819),
    [anon_sym_Case] = ACTIONS(5819),
    [anon_sym_for] = ACTIONS(5819),
    [anon_sym_FOR] = ACTIONS(5819),
    [anon_sym_For] = ACTIONS(5819),
    [anon_sym_foreach] = ACTIONS(5819),
    [anon_sym_FOREACH] = ACTIONS(5819),
    [anon_sym_Foreach] = ACTIONS(5819),
    [anon_sym_while] = ACTIONS(5819),
    [anon_sym_WHILE] = ACTIONS(5819),
    [anon_sym_While] = ACTIONS(5819),
    [anon_sym_repeat] = ACTIONS(5819),
    [anon_sym_REPEAT] = ACTIONS(5819),
    [anon_sym_Repeat] = ACTIONS(5819),
    [anon_sym_exit] = ACTIONS(5819),
    [anon_sym_EXIT] = ACTIONS(5819),
    [anon_sym_Exit] = ACTIONS(5819),
    [anon_sym_continue] = ACTIONS(5819),
    [anon_sym_CONTINUE] = ACTIONS(5819),
    [anon_sym_Continue] = ACTIONS(5819),
    [anon_sym_break] = ACTIONS(5819),
    [anon_sym_BREAK] = ACTIONS(5819),
    [anon_sym_Break] = ACTIONS(5819),
    [anon_sym_with] = ACTIONS(5819),
    [anon_sym_WITH] = ACTIONS(5819),
    [anon_sym_With] = ACTIONS(5819),
    [sym_asserterror_keyword] = ACTIONS(5821),
    [sym_page_keyword] = ACTIONS(5819),
    [anon_sym_codeunit] = ACTIONS(5819),
    [anon_sym_CODEUNIT] = ACTIONS(5819),
    [anon_sym_Codeunit] = ACTIONS(5819),
    [anon_sym_CodeUnit] = ACTIONS(5819),
    [anon_sym_COdeunit] = ACTIONS(5819),
    [anon_sym_codeUnit] = ACTIONS(5819),
    [sym_report_keyword] = ACTIONS(5819),
    [sym_query_keyword] = ACTIONS(5819),
    [anon_sym_xmlport] = ACTIONS(5819),
    [anon_sym_XMLPORT] = ACTIONS(5819),
    [anon_sym_Xmlport] = ACTIONS(5819),
    [anon_sym_XMLport] = ACTIONS(5819),
    [anon_sym_XMLPort] = ACTIONS(5819),
    [anon_sym_XmlPort] = ACTIONS(5819),
    [anon_sym_enum] = ACTIONS(5819),
    [anon_sym_ENUM] = ACTIONS(5819),
    [anon_sym_Enum] = ACTIONS(5819),
    [anon_sym_eNUM] = ACTIONS(5819),
    [anon_sym_eNum] = ACTIONS(5819),
    [anon_sym_ENum] = ACTIONS(5819),
    [sym_quoted_identifier] = ACTIONS(5821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5821),
    [sym_verbatim_string] = ACTIONS(5821),
    [sym_integer] = ACTIONS(5819),
    [sym_continue_as_identifier] = ACTIONS(5821),
    [sym_preproc_open] = ACTIONS(5821),
    [sym_end_keyword] = ACTIONS(5821),
  },
  [STATE(3364)] = {
    [sym_identifier] = ACTIONS(5823),
    [anon_sym_SEMI] = ACTIONS(5825),
    [anon_sym_DASH] = ACTIONS(5825),
    [aux_sym_boolean_token1] = ACTIONS(5823),
    [aux_sym_boolean_token2] = ACTIONS(5823),
    [sym_decimal] = ACTIONS(5823),
    [anon_sym_LPAREN] = ACTIONS(5825),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5823),
    [anon_sym_LBRACK] = ACTIONS(5825),
    [aux_sym_record_type_token1] = ACTIONS(5823),
    [aux_sym_basic_type_token21] = ACTIONS(5823),
    [aux_sym_basic_type_token22] = ACTIONS(5823),
    [aux_sym_basic_type_token48] = ACTIONS(5823),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5823),
    [anon_sym_POUNDif] = ACTIONS(5825),
    [anon_sym_POUNDIF] = ACTIONS(5825),
    [anon_sym_POUNDIf] = ACTIONS(5825),
    [anon_sym_not] = ACTIONS(5823),
    [anon_sym_NOT] = ACTIONS(5823),
    [anon_sym_Not] = ACTIONS(5823),
    [anon_sym_POUNDelse] = ACTIONS(5825),
    [anon_sym_POUNDELSE] = ACTIONS(5825),
    [anon_sym_POUNDElse] = ACTIONS(5825),
    [anon_sym_POUNDelse2] = ACTIONS(5825),
    [anon_sym_POUNDELSE2] = ACTIONS(5825),
    [anon_sym_POUNDElse2] = ACTIONS(5825),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5823),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5823),
    [anon_sym_PLUS] = ACTIONS(5825),
    [sym_datetime_literal] = ACTIONS(5825),
    [sym_date_literal] = ACTIONS(5823),
    [sym_time_literal] = ACTIONS(5823),
    [sym_biginteger_literal] = ACTIONS(5825),
    [anon_sym_if] = ACTIONS(5823),
    [anon_sym_IF] = ACTIONS(5823),
    [anon_sym_If] = ACTIONS(5823),
    [anon_sym_else] = ACTIONS(5823),
    [anon_sym_ELSE] = ACTIONS(5823),
    [anon_sym_Else] = ACTIONS(5823),
    [anon_sym_case] = ACTIONS(5823),
    [anon_sym_CASE] = ACTIONS(5823),
    [anon_sym_Case] = ACTIONS(5823),
    [anon_sym_for] = ACTIONS(5823),
    [anon_sym_FOR] = ACTIONS(5823),
    [anon_sym_For] = ACTIONS(5823),
    [anon_sym_foreach] = ACTIONS(5823),
    [anon_sym_FOREACH] = ACTIONS(5823),
    [anon_sym_Foreach] = ACTIONS(5823),
    [anon_sym_while] = ACTIONS(5823),
    [anon_sym_WHILE] = ACTIONS(5823),
    [anon_sym_While] = ACTIONS(5823),
    [anon_sym_repeat] = ACTIONS(5823),
    [anon_sym_REPEAT] = ACTIONS(5823),
    [anon_sym_Repeat] = ACTIONS(5823),
    [anon_sym_exit] = ACTIONS(5823),
    [anon_sym_EXIT] = ACTIONS(5823),
    [anon_sym_Exit] = ACTIONS(5823),
    [anon_sym_continue] = ACTIONS(5823),
    [anon_sym_CONTINUE] = ACTIONS(5823),
    [anon_sym_Continue] = ACTIONS(5823),
    [anon_sym_break] = ACTIONS(5823),
    [anon_sym_BREAK] = ACTIONS(5823),
    [anon_sym_Break] = ACTIONS(5823),
    [anon_sym_with] = ACTIONS(5823),
    [anon_sym_WITH] = ACTIONS(5823),
    [anon_sym_With] = ACTIONS(5823),
    [sym_asserterror_keyword] = ACTIONS(5825),
    [sym_page_keyword] = ACTIONS(5823),
    [anon_sym_codeunit] = ACTIONS(5823),
    [anon_sym_CODEUNIT] = ACTIONS(5823),
    [anon_sym_Codeunit] = ACTIONS(5823),
    [anon_sym_CodeUnit] = ACTIONS(5823),
    [anon_sym_COdeunit] = ACTIONS(5823),
    [anon_sym_codeUnit] = ACTIONS(5823),
    [sym_report_keyword] = ACTIONS(5823),
    [sym_query_keyword] = ACTIONS(5823),
    [anon_sym_xmlport] = ACTIONS(5823),
    [anon_sym_XMLPORT] = ACTIONS(5823),
    [anon_sym_Xmlport] = ACTIONS(5823),
    [anon_sym_XMLport] = ACTIONS(5823),
    [anon_sym_XMLPort] = ACTIONS(5823),
    [anon_sym_XmlPort] = ACTIONS(5823),
    [anon_sym_enum] = ACTIONS(5823),
    [anon_sym_ENUM] = ACTIONS(5823),
    [anon_sym_Enum] = ACTIONS(5823),
    [anon_sym_eNUM] = ACTIONS(5823),
    [anon_sym_eNum] = ACTIONS(5823),
    [anon_sym_ENum] = ACTIONS(5823),
    [sym_quoted_identifier] = ACTIONS(5825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5825),
    [sym_verbatim_string] = ACTIONS(5825),
    [sym_integer] = ACTIONS(5823),
    [sym_continue_as_identifier] = ACTIONS(5825),
    [sym_preproc_open] = ACTIONS(5825),
    [sym_end_keyword] = ACTIONS(5825),
  },
  [STATE(3365)] = {
    [sym_identifier] = ACTIONS(5827),
    [anon_sym_SEMI] = ACTIONS(5829),
    [anon_sym_DASH] = ACTIONS(5829),
    [aux_sym_boolean_token1] = ACTIONS(5827),
    [aux_sym_boolean_token2] = ACTIONS(5827),
    [sym_decimal] = ACTIONS(5827),
    [anon_sym_LPAREN] = ACTIONS(5829),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5827),
    [anon_sym_LBRACK] = ACTIONS(5829),
    [aux_sym_record_type_token1] = ACTIONS(5827),
    [aux_sym_basic_type_token21] = ACTIONS(5827),
    [aux_sym_basic_type_token22] = ACTIONS(5827),
    [aux_sym_basic_type_token48] = ACTIONS(5827),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5827),
    [anon_sym_POUNDif] = ACTIONS(5829),
    [anon_sym_POUNDIF] = ACTIONS(5829),
    [anon_sym_POUNDIf] = ACTIONS(5829),
    [anon_sym_not] = ACTIONS(5827),
    [anon_sym_NOT] = ACTIONS(5827),
    [anon_sym_Not] = ACTIONS(5827),
    [anon_sym_POUNDelse] = ACTIONS(5829),
    [anon_sym_POUNDELSE] = ACTIONS(5829),
    [anon_sym_POUNDElse] = ACTIONS(5829),
    [anon_sym_POUNDelse2] = ACTIONS(5829),
    [anon_sym_POUNDELSE2] = ACTIONS(5829),
    [anon_sym_POUNDElse2] = ACTIONS(5829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5827),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5827),
    [anon_sym_PLUS] = ACTIONS(5829),
    [sym_datetime_literal] = ACTIONS(5829),
    [sym_date_literal] = ACTIONS(5827),
    [sym_time_literal] = ACTIONS(5827),
    [sym_biginteger_literal] = ACTIONS(5829),
    [anon_sym_if] = ACTIONS(5827),
    [anon_sym_IF] = ACTIONS(5827),
    [anon_sym_If] = ACTIONS(5827),
    [anon_sym_else] = ACTIONS(5827),
    [anon_sym_ELSE] = ACTIONS(5827),
    [anon_sym_Else] = ACTIONS(5827),
    [anon_sym_case] = ACTIONS(5827),
    [anon_sym_CASE] = ACTIONS(5827),
    [anon_sym_Case] = ACTIONS(5827),
    [anon_sym_for] = ACTIONS(5827),
    [anon_sym_FOR] = ACTIONS(5827),
    [anon_sym_For] = ACTIONS(5827),
    [anon_sym_foreach] = ACTIONS(5827),
    [anon_sym_FOREACH] = ACTIONS(5827),
    [anon_sym_Foreach] = ACTIONS(5827),
    [anon_sym_while] = ACTIONS(5827),
    [anon_sym_WHILE] = ACTIONS(5827),
    [anon_sym_While] = ACTIONS(5827),
    [anon_sym_repeat] = ACTIONS(5827),
    [anon_sym_REPEAT] = ACTIONS(5827),
    [anon_sym_Repeat] = ACTIONS(5827),
    [anon_sym_exit] = ACTIONS(5827),
    [anon_sym_EXIT] = ACTIONS(5827),
    [anon_sym_Exit] = ACTIONS(5827),
    [anon_sym_continue] = ACTIONS(5827),
    [anon_sym_CONTINUE] = ACTIONS(5827),
    [anon_sym_Continue] = ACTIONS(5827),
    [anon_sym_break] = ACTIONS(5827),
    [anon_sym_BREAK] = ACTIONS(5827),
    [anon_sym_Break] = ACTIONS(5827),
    [anon_sym_with] = ACTIONS(5827),
    [anon_sym_WITH] = ACTIONS(5827),
    [anon_sym_With] = ACTIONS(5827),
    [sym_asserterror_keyword] = ACTIONS(5829),
    [sym_page_keyword] = ACTIONS(5827),
    [anon_sym_codeunit] = ACTIONS(5827),
    [anon_sym_CODEUNIT] = ACTIONS(5827),
    [anon_sym_Codeunit] = ACTIONS(5827),
    [anon_sym_CodeUnit] = ACTIONS(5827),
    [anon_sym_COdeunit] = ACTIONS(5827),
    [anon_sym_codeUnit] = ACTIONS(5827),
    [sym_report_keyword] = ACTIONS(5827),
    [sym_query_keyword] = ACTIONS(5827),
    [anon_sym_xmlport] = ACTIONS(5827),
    [anon_sym_XMLPORT] = ACTIONS(5827),
    [anon_sym_Xmlport] = ACTIONS(5827),
    [anon_sym_XMLport] = ACTIONS(5827),
    [anon_sym_XMLPort] = ACTIONS(5827),
    [anon_sym_XmlPort] = ACTIONS(5827),
    [anon_sym_enum] = ACTIONS(5827),
    [anon_sym_ENUM] = ACTIONS(5827),
    [anon_sym_Enum] = ACTIONS(5827),
    [anon_sym_eNUM] = ACTIONS(5827),
    [anon_sym_eNum] = ACTIONS(5827),
    [anon_sym_ENum] = ACTIONS(5827),
    [sym_quoted_identifier] = ACTIONS(5829),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5829),
    [sym_verbatim_string] = ACTIONS(5829),
    [sym_integer] = ACTIONS(5827),
    [sym_continue_as_identifier] = ACTIONS(5829),
    [sym_preproc_open] = ACTIONS(5829),
    [sym_end_keyword] = ACTIONS(5829),
  },
  [STATE(3366)] = {
    [sym_identifier] = ACTIONS(5831),
    [anon_sym_SEMI] = ACTIONS(5833),
    [anon_sym_DASH] = ACTIONS(5833),
    [aux_sym_boolean_token1] = ACTIONS(5831),
    [aux_sym_boolean_token2] = ACTIONS(5831),
    [sym_decimal] = ACTIONS(5831),
    [anon_sym_LPAREN] = ACTIONS(5833),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5831),
    [anon_sym_LBRACK] = ACTIONS(5833),
    [aux_sym_record_type_token1] = ACTIONS(5831),
    [aux_sym_basic_type_token21] = ACTIONS(5831),
    [aux_sym_basic_type_token22] = ACTIONS(5831),
    [aux_sym_basic_type_token48] = ACTIONS(5831),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5831),
    [anon_sym_POUNDif] = ACTIONS(5833),
    [anon_sym_POUNDIF] = ACTIONS(5833),
    [anon_sym_POUNDIf] = ACTIONS(5833),
    [anon_sym_not] = ACTIONS(5831),
    [anon_sym_NOT] = ACTIONS(5831),
    [anon_sym_Not] = ACTIONS(5831),
    [anon_sym_POUNDelse] = ACTIONS(5833),
    [anon_sym_POUNDELSE] = ACTIONS(5833),
    [anon_sym_POUNDElse] = ACTIONS(5833),
    [anon_sym_POUNDelse2] = ACTIONS(5833),
    [anon_sym_POUNDELSE2] = ACTIONS(5833),
    [anon_sym_POUNDElse2] = ACTIONS(5833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5831),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5831),
    [anon_sym_PLUS] = ACTIONS(5833),
    [sym_datetime_literal] = ACTIONS(5833),
    [sym_date_literal] = ACTIONS(5831),
    [sym_time_literal] = ACTIONS(5831),
    [sym_biginteger_literal] = ACTIONS(5833),
    [anon_sym_if] = ACTIONS(5831),
    [anon_sym_IF] = ACTIONS(5831),
    [anon_sym_If] = ACTIONS(5831),
    [anon_sym_else] = ACTIONS(5831),
    [anon_sym_ELSE] = ACTIONS(5831),
    [anon_sym_Else] = ACTIONS(5831),
    [anon_sym_case] = ACTIONS(5831),
    [anon_sym_CASE] = ACTIONS(5831),
    [anon_sym_Case] = ACTIONS(5831),
    [anon_sym_for] = ACTIONS(5831),
    [anon_sym_FOR] = ACTIONS(5831),
    [anon_sym_For] = ACTIONS(5831),
    [anon_sym_foreach] = ACTIONS(5831),
    [anon_sym_FOREACH] = ACTIONS(5831),
    [anon_sym_Foreach] = ACTIONS(5831),
    [anon_sym_while] = ACTIONS(5831),
    [anon_sym_WHILE] = ACTIONS(5831),
    [anon_sym_While] = ACTIONS(5831),
    [anon_sym_repeat] = ACTIONS(5831),
    [anon_sym_REPEAT] = ACTIONS(5831),
    [anon_sym_Repeat] = ACTIONS(5831),
    [anon_sym_exit] = ACTIONS(5831),
    [anon_sym_EXIT] = ACTIONS(5831),
    [anon_sym_Exit] = ACTIONS(5831),
    [anon_sym_continue] = ACTIONS(5831),
    [anon_sym_CONTINUE] = ACTIONS(5831),
    [anon_sym_Continue] = ACTIONS(5831),
    [anon_sym_break] = ACTIONS(5831),
    [anon_sym_BREAK] = ACTIONS(5831),
    [anon_sym_Break] = ACTIONS(5831),
    [anon_sym_with] = ACTIONS(5831),
    [anon_sym_WITH] = ACTIONS(5831),
    [anon_sym_With] = ACTIONS(5831),
    [sym_asserterror_keyword] = ACTIONS(5833),
    [sym_page_keyword] = ACTIONS(5831),
    [anon_sym_codeunit] = ACTIONS(5831),
    [anon_sym_CODEUNIT] = ACTIONS(5831),
    [anon_sym_Codeunit] = ACTIONS(5831),
    [anon_sym_CodeUnit] = ACTIONS(5831),
    [anon_sym_COdeunit] = ACTIONS(5831),
    [anon_sym_codeUnit] = ACTIONS(5831),
    [sym_report_keyword] = ACTIONS(5831),
    [sym_query_keyword] = ACTIONS(5831),
    [anon_sym_xmlport] = ACTIONS(5831),
    [anon_sym_XMLPORT] = ACTIONS(5831),
    [anon_sym_Xmlport] = ACTIONS(5831),
    [anon_sym_XMLport] = ACTIONS(5831),
    [anon_sym_XMLPort] = ACTIONS(5831),
    [anon_sym_XmlPort] = ACTIONS(5831),
    [anon_sym_enum] = ACTIONS(5831),
    [anon_sym_ENUM] = ACTIONS(5831),
    [anon_sym_Enum] = ACTIONS(5831),
    [anon_sym_eNUM] = ACTIONS(5831),
    [anon_sym_eNum] = ACTIONS(5831),
    [anon_sym_ENum] = ACTIONS(5831),
    [sym_quoted_identifier] = ACTIONS(5833),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5833),
    [sym_verbatim_string] = ACTIONS(5833),
    [sym_integer] = ACTIONS(5831),
    [sym_continue_as_identifier] = ACTIONS(5833),
    [sym_preproc_open] = ACTIONS(5833),
    [sym_end_keyword] = ACTIONS(5833),
  },
  [STATE(3367)] = {
    [sym_identifier] = ACTIONS(6082),
    [anon_sym_SEMI] = ACTIONS(6084),
    [anon_sym_DASH] = ACTIONS(6084),
    [aux_sym_boolean_token1] = ACTIONS(6082),
    [aux_sym_boolean_token2] = ACTIONS(6082),
    [sym_decimal] = ACTIONS(6082),
    [anon_sym_LPAREN] = ACTIONS(6084),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6082),
    [anon_sym_LBRACK] = ACTIONS(6084),
    [aux_sym_record_type_token1] = ACTIONS(6082),
    [aux_sym_basic_type_token21] = ACTIONS(6082),
    [aux_sym_basic_type_token22] = ACTIONS(6082),
    [aux_sym_basic_type_token48] = ACTIONS(6082),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6082),
    [anon_sym_POUNDif] = ACTIONS(6084),
    [anon_sym_POUNDIF] = ACTIONS(6084),
    [anon_sym_POUNDIf] = ACTIONS(6084),
    [anon_sym_not] = ACTIONS(6082),
    [anon_sym_NOT] = ACTIONS(6082),
    [anon_sym_Not] = ACTIONS(6082),
    [anon_sym_POUNDelse] = ACTIONS(6084),
    [anon_sym_POUNDELSE] = ACTIONS(6084),
    [anon_sym_POUNDElse] = ACTIONS(6084),
    [anon_sym_POUNDelse2] = ACTIONS(6084),
    [anon_sym_POUNDELSE2] = ACTIONS(6084),
    [anon_sym_POUNDElse2] = ACTIONS(6084),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6082),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6082),
    [anon_sym_PLUS] = ACTIONS(6084),
    [sym_datetime_literal] = ACTIONS(6084),
    [sym_date_literal] = ACTIONS(6082),
    [sym_time_literal] = ACTIONS(6082),
    [sym_biginteger_literal] = ACTIONS(6084),
    [anon_sym_if] = ACTIONS(6082),
    [anon_sym_IF] = ACTIONS(6082),
    [anon_sym_If] = ACTIONS(6082),
    [anon_sym_else] = ACTIONS(6082),
    [anon_sym_ELSE] = ACTIONS(6082),
    [anon_sym_Else] = ACTIONS(6082),
    [anon_sym_case] = ACTIONS(6082),
    [anon_sym_CASE] = ACTIONS(6082),
    [anon_sym_Case] = ACTIONS(6082),
    [anon_sym_for] = ACTIONS(6082),
    [anon_sym_FOR] = ACTIONS(6082),
    [anon_sym_For] = ACTIONS(6082),
    [anon_sym_foreach] = ACTIONS(6082),
    [anon_sym_FOREACH] = ACTIONS(6082),
    [anon_sym_Foreach] = ACTIONS(6082),
    [anon_sym_while] = ACTIONS(6082),
    [anon_sym_WHILE] = ACTIONS(6082),
    [anon_sym_While] = ACTIONS(6082),
    [anon_sym_repeat] = ACTIONS(6082),
    [anon_sym_REPEAT] = ACTIONS(6082),
    [anon_sym_Repeat] = ACTIONS(6082),
    [anon_sym_exit] = ACTIONS(6082),
    [anon_sym_EXIT] = ACTIONS(6082),
    [anon_sym_Exit] = ACTIONS(6082),
    [anon_sym_continue] = ACTIONS(6082),
    [anon_sym_CONTINUE] = ACTIONS(6082),
    [anon_sym_Continue] = ACTIONS(6082),
    [anon_sym_break] = ACTIONS(6082),
    [anon_sym_BREAK] = ACTIONS(6082),
    [anon_sym_Break] = ACTIONS(6082),
    [anon_sym_with] = ACTIONS(6082),
    [anon_sym_WITH] = ACTIONS(6082),
    [anon_sym_With] = ACTIONS(6082),
    [sym_asserterror_keyword] = ACTIONS(6084),
    [sym_page_keyword] = ACTIONS(6082),
    [anon_sym_codeunit] = ACTIONS(6082),
    [anon_sym_CODEUNIT] = ACTIONS(6082),
    [anon_sym_Codeunit] = ACTIONS(6082),
    [anon_sym_CodeUnit] = ACTIONS(6082),
    [anon_sym_COdeunit] = ACTIONS(6082),
    [anon_sym_codeUnit] = ACTIONS(6082),
    [sym_report_keyword] = ACTIONS(6082),
    [sym_query_keyword] = ACTIONS(6082),
    [anon_sym_xmlport] = ACTIONS(6082),
    [anon_sym_XMLPORT] = ACTIONS(6082),
    [anon_sym_Xmlport] = ACTIONS(6082),
    [anon_sym_XMLport] = ACTIONS(6082),
    [anon_sym_XMLPort] = ACTIONS(6082),
    [anon_sym_XmlPort] = ACTIONS(6082),
    [anon_sym_enum] = ACTIONS(6082),
    [anon_sym_ENUM] = ACTIONS(6082),
    [anon_sym_Enum] = ACTIONS(6082),
    [anon_sym_eNUM] = ACTIONS(6082),
    [anon_sym_eNum] = ACTIONS(6082),
    [anon_sym_ENum] = ACTIONS(6082),
    [sym_quoted_identifier] = ACTIONS(6084),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6084),
    [sym_verbatim_string] = ACTIONS(6084),
    [sym_integer] = ACTIONS(6082),
    [sym_continue_as_identifier] = ACTIONS(6084),
    [sym_preproc_open] = ACTIONS(6084),
    [sym_end_keyword] = ACTIONS(6084),
  },
  [STATE(3368)] = {
    [sym_identifier] = ACTIONS(5839),
    [anon_sym_SEMI] = ACTIONS(5841),
    [anon_sym_DASH] = ACTIONS(5841),
    [aux_sym_boolean_token1] = ACTIONS(5839),
    [aux_sym_boolean_token2] = ACTIONS(5839),
    [sym_decimal] = ACTIONS(5839),
    [anon_sym_LPAREN] = ACTIONS(5841),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5839),
    [anon_sym_LBRACK] = ACTIONS(5841),
    [aux_sym_record_type_token1] = ACTIONS(5839),
    [aux_sym_basic_type_token21] = ACTIONS(5839),
    [aux_sym_basic_type_token22] = ACTIONS(5839),
    [aux_sym_basic_type_token48] = ACTIONS(5839),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5839),
    [anon_sym_POUNDif] = ACTIONS(5841),
    [anon_sym_POUNDIF] = ACTIONS(5841),
    [anon_sym_POUNDIf] = ACTIONS(5841),
    [anon_sym_not] = ACTIONS(5839),
    [anon_sym_NOT] = ACTIONS(5839),
    [anon_sym_Not] = ACTIONS(5839),
    [anon_sym_POUNDelse] = ACTIONS(5841),
    [anon_sym_POUNDELSE] = ACTIONS(5841),
    [anon_sym_POUNDElse] = ACTIONS(5841),
    [anon_sym_POUNDelse2] = ACTIONS(5841),
    [anon_sym_POUNDELSE2] = ACTIONS(5841),
    [anon_sym_POUNDElse2] = ACTIONS(5841),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5839),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5839),
    [anon_sym_PLUS] = ACTIONS(5841),
    [sym_datetime_literal] = ACTIONS(5841),
    [sym_date_literal] = ACTIONS(5839),
    [sym_time_literal] = ACTIONS(5839),
    [sym_biginteger_literal] = ACTIONS(5841),
    [anon_sym_if] = ACTIONS(5839),
    [anon_sym_IF] = ACTIONS(5839),
    [anon_sym_If] = ACTIONS(5839),
    [anon_sym_else] = ACTIONS(5839),
    [anon_sym_ELSE] = ACTIONS(5839),
    [anon_sym_Else] = ACTIONS(5839),
    [anon_sym_case] = ACTIONS(5839),
    [anon_sym_CASE] = ACTIONS(5839),
    [anon_sym_Case] = ACTIONS(5839),
    [anon_sym_for] = ACTIONS(5839),
    [anon_sym_FOR] = ACTIONS(5839),
    [anon_sym_For] = ACTIONS(5839),
    [anon_sym_foreach] = ACTIONS(5839),
    [anon_sym_FOREACH] = ACTIONS(5839),
    [anon_sym_Foreach] = ACTIONS(5839),
    [anon_sym_while] = ACTIONS(5839),
    [anon_sym_WHILE] = ACTIONS(5839),
    [anon_sym_While] = ACTIONS(5839),
    [anon_sym_repeat] = ACTIONS(5839),
    [anon_sym_REPEAT] = ACTIONS(5839),
    [anon_sym_Repeat] = ACTIONS(5839),
    [anon_sym_exit] = ACTIONS(5839),
    [anon_sym_EXIT] = ACTIONS(5839),
    [anon_sym_Exit] = ACTIONS(5839),
    [anon_sym_continue] = ACTIONS(5839),
    [anon_sym_CONTINUE] = ACTIONS(5839),
    [anon_sym_Continue] = ACTIONS(5839),
    [anon_sym_break] = ACTIONS(5839),
    [anon_sym_BREAK] = ACTIONS(5839),
    [anon_sym_Break] = ACTIONS(5839),
    [anon_sym_with] = ACTIONS(5839),
    [anon_sym_WITH] = ACTIONS(5839),
    [anon_sym_With] = ACTIONS(5839),
    [sym_asserterror_keyword] = ACTIONS(5841),
    [sym_page_keyword] = ACTIONS(5839),
    [anon_sym_codeunit] = ACTIONS(5839),
    [anon_sym_CODEUNIT] = ACTIONS(5839),
    [anon_sym_Codeunit] = ACTIONS(5839),
    [anon_sym_CodeUnit] = ACTIONS(5839),
    [anon_sym_COdeunit] = ACTIONS(5839),
    [anon_sym_codeUnit] = ACTIONS(5839),
    [sym_report_keyword] = ACTIONS(5839),
    [sym_query_keyword] = ACTIONS(5839),
    [anon_sym_xmlport] = ACTIONS(5839),
    [anon_sym_XMLPORT] = ACTIONS(5839),
    [anon_sym_Xmlport] = ACTIONS(5839),
    [anon_sym_XMLport] = ACTIONS(5839),
    [anon_sym_XMLPort] = ACTIONS(5839),
    [anon_sym_XmlPort] = ACTIONS(5839),
    [anon_sym_enum] = ACTIONS(5839),
    [anon_sym_ENUM] = ACTIONS(5839),
    [anon_sym_Enum] = ACTIONS(5839),
    [anon_sym_eNUM] = ACTIONS(5839),
    [anon_sym_eNum] = ACTIONS(5839),
    [anon_sym_ENum] = ACTIONS(5839),
    [sym_quoted_identifier] = ACTIONS(5841),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5841),
    [sym_verbatim_string] = ACTIONS(5841),
    [sym_integer] = ACTIONS(5839),
    [sym_continue_as_identifier] = ACTIONS(5841),
    [sym_preproc_open] = ACTIONS(5841),
    [sym_end_keyword] = ACTIONS(5841),
  },
  [STATE(3369)] = {
    [sym_identifier] = ACTIONS(5843),
    [anon_sym_SEMI] = ACTIONS(5845),
    [anon_sym_DASH] = ACTIONS(5845),
    [aux_sym_boolean_token1] = ACTIONS(5843),
    [aux_sym_boolean_token2] = ACTIONS(5843),
    [sym_decimal] = ACTIONS(5843),
    [anon_sym_LPAREN] = ACTIONS(5845),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5843),
    [anon_sym_LBRACK] = ACTIONS(5845),
    [aux_sym_record_type_token1] = ACTIONS(5843),
    [aux_sym_basic_type_token21] = ACTIONS(5843),
    [aux_sym_basic_type_token22] = ACTIONS(5843),
    [aux_sym_basic_type_token48] = ACTIONS(5843),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5843),
    [anon_sym_POUNDif] = ACTIONS(5845),
    [anon_sym_POUNDIF] = ACTIONS(5845),
    [anon_sym_POUNDIf] = ACTIONS(5845),
    [anon_sym_not] = ACTIONS(5843),
    [anon_sym_NOT] = ACTIONS(5843),
    [anon_sym_Not] = ACTIONS(5843),
    [anon_sym_POUNDelse] = ACTIONS(5845),
    [anon_sym_POUNDELSE] = ACTIONS(5845),
    [anon_sym_POUNDElse] = ACTIONS(5845),
    [anon_sym_POUNDelse2] = ACTIONS(5845),
    [anon_sym_POUNDELSE2] = ACTIONS(5845),
    [anon_sym_POUNDElse2] = ACTIONS(5845),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5843),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5843),
    [anon_sym_PLUS] = ACTIONS(5845),
    [sym_datetime_literal] = ACTIONS(5845),
    [sym_date_literal] = ACTIONS(5843),
    [sym_time_literal] = ACTIONS(5843),
    [sym_biginteger_literal] = ACTIONS(5845),
    [anon_sym_if] = ACTIONS(5843),
    [anon_sym_IF] = ACTIONS(5843),
    [anon_sym_If] = ACTIONS(5843),
    [anon_sym_else] = ACTIONS(5843),
    [anon_sym_ELSE] = ACTIONS(5843),
    [anon_sym_Else] = ACTIONS(5843),
    [anon_sym_case] = ACTIONS(5843),
    [anon_sym_CASE] = ACTIONS(5843),
    [anon_sym_Case] = ACTIONS(5843),
    [anon_sym_for] = ACTIONS(5843),
    [anon_sym_FOR] = ACTIONS(5843),
    [anon_sym_For] = ACTIONS(5843),
    [anon_sym_foreach] = ACTIONS(5843),
    [anon_sym_FOREACH] = ACTIONS(5843),
    [anon_sym_Foreach] = ACTIONS(5843),
    [anon_sym_while] = ACTIONS(5843),
    [anon_sym_WHILE] = ACTIONS(5843),
    [anon_sym_While] = ACTIONS(5843),
    [anon_sym_repeat] = ACTIONS(5843),
    [anon_sym_REPEAT] = ACTIONS(5843),
    [anon_sym_Repeat] = ACTIONS(5843),
    [anon_sym_exit] = ACTIONS(5843),
    [anon_sym_EXIT] = ACTIONS(5843),
    [anon_sym_Exit] = ACTIONS(5843),
    [anon_sym_continue] = ACTIONS(5843),
    [anon_sym_CONTINUE] = ACTIONS(5843),
    [anon_sym_Continue] = ACTIONS(5843),
    [anon_sym_break] = ACTIONS(5843),
    [anon_sym_BREAK] = ACTIONS(5843),
    [anon_sym_Break] = ACTIONS(5843),
    [anon_sym_with] = ACTIONS(5843),
    [anon_sym_WITH] = ACTIONS(5843),
    [anon_sym_With] = ACTIONS(5843),
    [sym_asserterror_keyword] = ACTIONS(5845),
    [sym_page_keyword] = ACTIONS(5843),
    [anon_sym_codeunit] = ACTIONS(5843),
    [anon_sym_CODEUNIT] = ACTIONS(5843),
    [anon_sym_Codeunit] = ACTIONS(5843),
    [anon_sym_CodeUnit] = ACTIONS(5843),
    [anon_sym_COdeunit] = ACTIONS(5843),
    [anon_sym_codeUnit] = ACTIONS(5843),
    [sym_report_keyword] = ACTIONS(5843),
    [sym_query_keyword] = ACTIONS(5843),
    [anon_sym_xmlport] = ACTIONS(5843),
    [anon_sym_XMLPORT] = ACTIONS(5843),
    [anon_sym_Xmlport] = ACTIONS(5843),
    [anon_sym_XMLport] = ACTIONS(5843),
    [anon_sym_XMLPort] = ACTIONS(5843),
    [anon_sym_XmlPort] = ACTIONS(5843),
    [anon_sym_enum] = ACTIONS(5843),
    [anon_sym_ENUM] = ACTIONS(5843),
    [anon_sym_Enum] = ACTIONS(5843),
    [anon_sym_eNUM] = ACTIONS(5843),
    [anon_sym_eNum] = ACTIONS(5843),
    [anon_sym_ENum] = ACTIONS(5843),
    [sym_quoted_identifier] = ACTIONS(5845),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5845),
    [sym_verbatim_string] = ACTIONS(5845),
    [sym_integer] = ACTIONS(5843),
    [sym_continue_as_identifier] = ACTIONS(5845),
    [sym_preproc_open] = ACTIONS(5845),
    [sym_end_keyword] = ACTIONS(5845),
  },
  [STATE(3370)] = {
    [sym_identifier] = ACTIONS(5847),
    [anon_sym_SEMI] = ACTIONS(5849),
    [anon_sym_DASH] = ACTIONS(5849),
    [aux_sym_boolean_token1] = ACTIONS(5847),
    [aux_sym_boolean_token2] = ACTIONS(5847),
    [sym_decimal] = ACTIONS(5847),
    [anon_sym_LPAREN] = ACTIONS(5849),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5847),
    [anon_sym_LBRACK] = ACTIONS(5849),
    [aux_sym_record_type_token1] = ACTIONS(5847),
    [aux_sym_basic_type_token21] = ACTIONS(5847),
    [aux_sym_basic_type_token22] = ACTIONS(5847),
    [aux_sym_basic_type_token48] = ACTIONS(5847),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5847),
    [anon_sym_POUNDif] = ACTIONS(5849),
    [anon_sym_POUNDIF] = ACTIONS(5849),
    [anon_sym_POUNDIf] = ACTIONS(5849),
    [anon_sym_not] = ACTIONS(5847),
    [anon_sym_NOT] = ACTIONS(5847),
    [anon_sym_Not] = ACTIONS(5847),
    [anon_sym_POUNDelse] = ACTIONS(5849),
    [anon_sym_POUNDELSE] = ACTIONS(5849),
    [anon_sym_POUNDElse] = ACTIONS(5849),
    [anon_sym_POUNDelse2] = ACTIONS(5849),
    [anon_sym_POUNDELSE2] = ACTIONS(5849),
    [anon_sym_POUNDElse2] = ACTIONS(5849),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5847),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5847),
    [anon_sym_PLUS] = ACTIONS(5849),
    [sym_datetime_literal] = ACTIONS(5849),
    [sym_date_literal] = ACTIONS(5847),
    [sym_time_literal] = ACTIONS(5847),
    [sym_biginteger_literal] = ACTIONS(5849),
    [anon_sym_if] = ACTIONS(5847),
    [anon_sym_IF] = ACTIONS(5847),
    [anon_sym_If] = ACTIONS(5847),
    [anon_sym_else] = ACTIONS(5847),
    [anon_sym_ELSE] = ACTIONS(5847),
    [anon_sym_Else] = ACTIONS(5847),
    [anon_sym_case] = ACTIONS(5847),
    [anon_sym_CASE] = ACTIONS(5847),
    [anon_sym_Case] = ACTIONS(5847),
    [anon_sym_for] = ACTIONS(5847),
    [anon_sym_FOR] = ACTIONS(5847),
    [anon_sym_For] = ACTIONS(5847),
    [anon_sym_foreach] = ACTIONS(5847),
    [anon_sym_FOREACH] = ACTIONS(5847),
    [anon_sym_Foreach] = ACTIONS(5847),
    [anon_sym_while] = ACTIONS(5847),
    [anon_sym_WHILE] = ACTIONS(5847),
    [anon_sym_While] = ACTIONS(5847),
    [anon_sym_repeat] = ACTIONS(5847),
    [anon_sym_REPEAT] = ACTIONS(5847),
    [anon_sym_Repeat] = ACTIONS(5847),
    [anon_sym_exit] = ACTIONS(5847),
    [anon_sym_EXIT] = ACTIONS(5847),
    [anon_sym_Exit] = ACTIONS(5847),
    [anon_sym_continue] = ACTIONS(5847),
    [anon_sym_CONTINUE] = ACTIONS(5847),
    [anon_sym_Continue] = ACTIONS(5847),
    [anon_sym_break] = ACTIONS(5847),
    [anon_sym_BREAK] = ACTIONS(5847),
    [anon_sym_Break] = ACTIONS(5847),
    [anon_sym_with] = ACTIONS(5847),
    [anon_sym_WITH] = ACTIONS(5847),
    [anon_sym_With] = ACTIONS(5847),
    [sym_asserterror_keyword] = ACTIONS(5849),
    [sym_page_keyword] = ACTIONS(5847),
    [anon_sym_codeunit] = ACTIONS(5847),
    [anon_sym_CODEUNIT] = ACTIONS(5847),
    [anon_sym_Codeunit] = ACTIONS(5847),
    [anon_sym_CodeUnit] = ACTIONS(5847),
    [anon_sym_COdeunit] = ACTIONS(5847),
    [anon_sym_codeUnit] = ACTIONS(5847),
    [sym_report_keyword] = ACTIONS(5847),
    [sym_query_keyword] = ACTIONS(5847),
    [anon_sym_xmlport] = ACTIONS(5847),
    [anon_sym_XMLPORT] = ACTIONS(5847),
    [anon_sym_Xmlport] = ACTIONS(5847),
    [anon_sym_XMLport] = ACTIONS(5847),
    [anon_sym_XMLPort] = ACTIONS(5847),
    [anon_sym_XmlPort] = ACTIONS(5847),
    [anon_sym_enum] = ACTIONS(5847),
    [anon_sym_ENUM] = ACTIONS(5847),
    [anon_sym_Enum] = ACTIONS(5847),
    [anon_sym_eNUM] = ACTIONS(5847),
    [anon_sym_eNum] = ACTIONS(5847),
    [anon_sym_ENum] = ACTIONS(5847),
    [sym_quoted_identifier] = ACTIONS(5849),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5849),
    [sym_verbatim_string] = ACTIONS(5849),
    [sym_integer] = ACTIONS(5847),
    [sym_continue_as_identifier] = ACTIONS(5849),
    [sym_preproc_open] = ACTIONS(5849),
    [sym_end_keyword] = ACTIONS(5849),
  },
  [STATE(3371)] = {
    [sym_identifier] = ACTIONS(5851),
    [anon_sym_SEMI] = ACTIONS(5853),
    [anon_sym_DASH] = ACTIONS(5853),
    [aux_sym_boolean_token1] = ACTIONS(5851),
    [aux_sym_boolean_token2] = ACTIONS(5851),
    [sym_decimal] = ACTIONS(5851),
    [anon_sym_LPAREN] = ACTIONS(5853),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5851),
    [anon_sym_LBRACK] = ACTIONS(5853),
    [aux_sym_record_type_token1] = ACTIONS(5851),
    [aux_sym_basic_type_token21] = ACTIONS(5851),
    [aux_sym_basic_type_token22] = ACTIONS(5851),
    [aux_sym_basic_type_token48] = ACTIONS(5851),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5851),
    [anon_sym_POUNDif] = ACTIONS(5853),
    [anon_sym_POUNDIF] = ACTIONS(5853),
    [anon_sym_POUNDIf] = ACTIONS(5853),
    [anon_sym_not] = ACTIONS(5851),
    [anon_sym_NOT] = ACTIONS(5851),
    [anon_sym_Not] = ACTIONS(5851),
    [anon_sym_POUNDelse] = ACTIONS(5853),
    [anon_sym_POUNDELSE] = ACTIONS(5853),
    [anon_sym_POUNDElse] = ACTIONS(5853),
    [anon_sym_POUNDelse2] = ACTIONS(5853),
    [anon_sym_POUNDELSE2] = ACTIONS(5853),
    [anon_sym_POUNDElse2] = ACTIONS(5853),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5851),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5851),
    [anon_sym_PLUS] = ACTIONS(5853),
    [sym_datetime_literal] = ACTIONS(5853),
    [sym_date_literal] = ACTIONS(5851),
    [sym_time_literal] = ACTIONS(5851),
    [sym_biginteger_literal] = ACTIONS(5853),
    [anon_sym_if] = ACTIONS(5851),
    [anon_sym_IF] = ACTIONS(5851),
    [anon_sym_If] = ACTIONS(5851),
    [anon_sym_else] = ACTIONS(5851),
    [anon_sym_ELSE] = ACTIONS(5851),
    [anon_sym_Else] = ACTIONS(5851),
    [anon_sym_case] = ACTIONS(5851),
    [anon_sym_CASE] = ACTIONS(5851),
    [anon_sym_Case] = ACTIONS(5851),
    [anon_sym_for] = ACTIONS(5851),
    [anon_sym_FOR] = ACTIONS(5851),
    [anon_sym_For] = ACTIONS(5851),
    [anon_sym_foreach] = ACTIONS(5851),
    [anon_sym_FOREACH] = ACTIONS(5851),
    [anon_sym_Foreach] = ACTIONS(5851),
    [anon_sym_while] = ACTIONS(5851),
    [anon_sym_WHILE] = ACTIONS(5851),
    [anon_sym_While] = ACTIONS(5851),
    [anon_sym_repeat] = ACTIONS(5851),
    [anon_sym_REPEAT] = ACTIONS(5851),
    [anon_sym_Repeat] = ACTIONS(5851),
    [anon_sym_exit] = ACTIONS(5851),
    [anon_sym_EXIT] = ACTIONS(5851),
    [anon_sym_Exit] = ACTIONS(5851),
    [anon_sym_continue] = ACTIONS(5851),
    [anon_sym_CONTINUE] = ACTIONS(5851),
    [anon_sym_Continue] = ACTIONS(5851),
    [anon_sym_break] = ACTIONS(5851),
    [anon_sym_BREAK] = ACTIONS(5851),
    [anon_sym_Break] = ACTIONS(5851),
    [anon_sym_with] = ACTIONS(5851),
    [anon_sym_WITH] = ACTIONS(5851),
    [anon_sym_With] = ACTIONS(5851),
    [sym_asserterror_keyword] = ACTIONS(5853),
    [sym_page_keyword] = ACTIONS(5851),
    [anon_sym_codeunit] = ACTIONS(5851),
    [anon_sym_CODEUNIT] = ACTIONS(5851),
    [anon_sym_Codeunit] = ACTIONS(5851),
    [anon_sym_CodeUnit] = ACTIONS(5851),
    [anon_sym_COdeunit] = ACTIONS(5851),
    [anon_sym_codeUnit] = ACTIONS(5851),
    [sym_report_keyword] = ACTIONS(5851),
    [sym_query_keyword] = ACTIONS(5851),
    [anon_sym_xmlport] = ACTIONS(5851),
    [anon_sym_XMLPORT] = ACTIONS(5851),
    [anon_sym_Xmlport] = ACTIONS(5851),
    [anon_sym_XMLport] = ACTIONS(5851),
    [anon_sym_XMLPort] = ACTIONS(5851),
    [anon_sym_XmlPort] = ACTIONS(5851),
    [anon_sym_enum] = ACTIONS(5851),
    [anon_sym_ENUM] = ACTIONS(5851),
    [anon_sym_Enum] = ACTIONS(5851),
    [anon_sym_eNUM] = ACTIONS(5851),
    [anon_sym_eNum] = ACTIONS(5851),
    [anon_sym_ENum] = ACTIONS(5851),
    [sym_quoted_identifier] = ACTIONS(5853),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5853),
    [sym_verbatim_string] = ACTIONS(5853),
    [sym_integer] = ACTIONS(5851),
    [sym_continue_as_identifier] = ACTIONS(5853),
    [sym_preproc_open] = ACTIONS(5853),
    [sym_end_keyword] = ACTIONS(5853),
  },
  [STATE(3372)] = {
    [sym_identifier] = ACTIONS(6046),
    [anon_sym_SEMI] = ACTIONS(6048),
    [anon_sym_DASH] = ACTIONS(6048),
    [aux_sym_boolean_token1] = ACTIONS(6046),
    [aux_sym_boolean_token2] = ACTIONS(6046),
    [sym_decimal] = ACTIONS(6046),
    [anon_sym_LPAREN] = ACTIONS(6048),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6046),
    [anon_sym_LBRACK] = ACTIONS(6048),
    [aux_sym_record_type_token1] = ACTIONS(6046),
    [aux_sym_basic_type_token21] = ACTIONS(6046),
    [aux_sym_basic_type_token22] = ACTIONS(6046),
    [aux_sym_basic_type_token48] = ACTIONS(6046),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6046),
    [anon_sym_POUNDif] = ACTIONS(6048),
    [anon_sym_POUNDIF] = ACTIONS(6048),
    [anon_sym_POUNDIf] = ACTIONS(6048),
    [anon_sym_not] = ACTIONS(6046),
    [anon_sym_NOT] = ACTIONS(6046),
    [anon_sym_Not] = ACTIONS(6046),
    [anon_sym_POUNDelse] = ACTIONS(6048),
    [anon_sym_POUNDELSE] = ACTIONS(6048),
    [anon_sym_POUNDElse] = ACTIONS(6048),
    [anon_sym_POUNDelse2] = ACTIONS(6048),
    [anon_sym_POUNDELSE2] = ACTIONS(6048),
    [anon_sym_POUNDElse2] = ACTIONS(6048),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6046),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6046),
    [anon_sym_PLUS] = ACTIONS(6048),
    [sym_datetime_literal] = ACTIONS(6048),
    [sym_date_literal] = ACTIONS(6046),
    [sym_time_literal] = ACTIONS(6046),
    [sym_biginteger_literal] = ACTIONS(6048),
    [anon_sym_if] = ACTIONS(6046),
    [anon_sym_IF] = ACTIONS(6046),
    [anon_sym_If] = ACTIONS(6046),
    [anon_sym_else] = ACTIONS(6046),
    [anon_sym_ELSE] = ACTIONS(6046),
    [anon_sym_Else] = ACTIONS(6046),
    [anon_sym_case] = ACTIONS(6046),
    [anon_sym_CASE] = ACTIONS(6046),
    [anon_sym_Case] = ACTIONS(6046),
    [anon_sym_for] = ACTIONS(6046),
    [anon_sym_FOR] = ACTIONS(6046),
    [anon_sym_For] = ACTIONS(6046),
    [anon_sym_foreach] = ACTIONS(6046),
    [anon_sym_FOREACH] = ACTIONS(6046),
    [anon_sym_Foreach] = ACTIONS(6046),
    [anon_sym_while] = ACTIONS(6046),
    [anon_sym_WHILE] = ACTIONS(6046),
    [anon_sym_While] = ACTIONS(6046),
    [anon_sym_repeat] = ACTIONS(6046),
    [anon_sym_REPEAT] = ACTIONS(6046),
    [anon_sym_Repeat] = ACTIONS(6046),
    [anon_sym_exit] = ACTIONS(6046),
    [anon_sym_EXIT] = ACTIONS(6046),
    [anon_sym_Exit] = ACTIONS(6046),
    [anon_sym_continue] = ACTIONS(6046),
    [anon_sym_CONTINUE] = ACTIONS(6046),
    [anon_sym_Continue] = ACTIONS(6046),
    [anon_sym_break] = ACTIONS(6046),
    [anon_sym_BREAK] = ACTIONS(6046),
    [anon_sym_Break] = ACTIONS(6046),
    [anon_sym_with] = ACTIONS(6046),
    [anon_sym_WITH] = ACTIONS(6046),
    [anon_sym_With] = ACTIONS(6046),
    [sym_asserterror_keyword] = ACTIONS(6048),
    [sym_page_keyword] = ACTIONS(6046),
    [anon_sym_codeunit] = ACTIONS(6046),
    [anon_sym_CODEUNIT] = ACTIONS(6046),
    [anon_sym_Codeunit] = ACTIONS(6046),
    [anon_sym_CodeUnit] = ACTIONS(6046),
    [anon_sym_COdeunit] = ACTIONS(6046),
    [anon_sym_codeUnit] = ACTIONS(6046),
    [sym_report_keyword] = ACTIONS(6046),
    [sym_query_keyword] = ACTIONS(6046),
    [anon_sym_xmlport] = ACTIONS(6046),
    [anon_sym_XMLPORT] = ACTIONS(6046),
    [anon_sym_Xmlport] = ACTIONS(6046),
    [anon_sym_XMLport] = ACTIONS(6046),
    [anon_sym_XMLPort] = ACTIONS(6046),
    [anon_sym_XmlPort] = ACTIONS(6046),
    [anon_sym_enum] = ACTIONS(6046),
    [anon_sym_ENUM] = ACTIONS(6046),
    [anon_sym_Enum] = ACTIONS(6046),
    [anon_sym_eNUM] = ACTIONS(6046),
    [anon_sym_eNum] = ACTIONS(6046),
    [anon_sym_ENum] = ACTIONS(6046),
    [sym_quoted_identifier] = ACTIONS(6048),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6048),
    [sym_verbatim_string] = ACTIONS(6048),
    [sym_integer] = ACTIONS(6046),
    [sym_continue_as_identifier] = ACTIONS(6048),
    [sym_preproc_open] = ACTIONS(6048),
    [sym_end_keyword] = ACTIONS(6048),
  },
  [STATE(3373)] = {
    [sym_identifier] = ACTIONS(5493),
    [anon_sym_SEMI] = ACTIONS(5495),
    [anon_sym_DASH] = ACTIONS(5495),
    [aux_sym_boolean_token1] = ACTIONS(5493),
    [aux_sym_boolean_token2] = ACTIONS(5493),
    [sym_decimal] = ACTIONS(5493),
    [anon_sym_LPAREN] = ACTIONS(5495),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5493),
    [anon_sym_LBRACK] = ACTIONS(5495),
    [aux_sym_record_type_token1] = ACTIONS(5493),
    [aux_sym_basic_type_token21] = ACTIONS(5493),
    [aux_sym_basic_type_token22] = ACTIONS(5493),
    [aux_sym_basic_type_token48] = ACTIONS(5493),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5493),
    [anon_sym_POUNDif] = ACTIONS(5495),
    [anon_sym_POUNDIF] = ACTIONS(5495),
    [anon_sym_POUNDIf] = ACTIONS(5495),
    [anon_sym_not] = ACTIONS(5493),
    [anon_sym_NOT] = ACTIONS(5493),
    [anon_sym_Not] = ACTIONS(5493),
    [anon_sym_POUNDelse] = ACTIONS(5495),
    [anon_sym_POUNDELSE] = ACTIONS(5495),
    [anon_sym_POUNDElse] = ACTIONS(5495),
    [anon_sym_POUNDelse2] = ACTIONS(5495),
    [anon_sym_POUNDELSE2] = ACTIONS(5495),
    [anon_sym_POUNDElse2] = ACTIONS(5495),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5493),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5493),
    [anon_sym_PLUS] = ACTIONS(5495),
    [sym_datetime_literal] = ACTIONS(5495),
    [sym_date_literal] = ACTIONS(5493),
    [sym_time_literal] = ACTIONS(5493),
    [sym_biginteger_literal] = ACTIONS(5495),
    [anon_sym_if] = ACTIONS(5493),
    [anon_sym_IF] = ACTIONS(5493),
    [anon_sym_If] = ACTIONS(5493),
    [anon_sym_else] = ACTIONS(5493),
    [anon_sym_ELSE] = ACTIONS(5493),
    [anon_sym_Else] = ACTIONS(5493),
    [anon_sym_case] = ACTIONS(5493),
    [anon_sym_CASE] = ACTIONS(5493),
    [anon_sym_Case] = ACTIONS(5493),
    [anon_sym_for] = ACTIONS(5493),
    [anon_sym_FOR] = ACTIONS(5493),
    [anon_sym_For] = ACTIONS(5493),
    [anon_sym_foreach] = ACTIONS(5493),
    [anon_sym_FOREACH] = ACTIONS(5493),
    [anon_sym_Foreach] = ACTIONS(5493),
    [anon_sym_while] = ACTIONS(5493),
    [anon_sym_WHILE] = ACTIONS(5493),
    [anon_sym_While] = ACTIONS(5493),
    [anon_sym_repeat] = ACTIONS(5493),
    [anon_sym_REPEAT] = ACTIONS(5493),
    [anon_sym_Repeat] = ACTIONS(5493),
    [anon_sym_exit] = ACTIONS(5493),
    [anon_sym_EXIT] = ACTIONS(5493),
    [anon_sym_Exit] = ACTIONS(5493),
    [anon_sym_continue] = ACTIONS(5493),
    [anon_sym_CONTINUE] = ACTIONS(5493),
    [anon_sym_Continue] = ACTIONS(5493),
    [anon_sym_break] = ACTIONS(5493),
    [anon_sym_BREAK] = ACTIONS(5493),
    [anon_sym_Break] = ACTIONS(5493),
    [anon_sym_with] = ACTIONS(5493),
    [anon_sym_WITH] = ACTIONS(5493),
    [anon_sym_With] = ACTIONS(5493),
    [sym_asserterror_keyword] = ACTIONS(5495),
    [sym_page_keyword] = ACTIONS(5493),
    [anon_sym_codeunit] = ACTIONS(5493),
    [anon_sym_CODEUNIT] = ACTIONS(5493),
    [anon_sym_Codeunit] = ACTIONS(5493),
    [anon_sym_CodeUnit] = ACTIONS(5493),
    [anon_sym_COdeunit] = ACTIONS(5493),
    [anon_sym_codeUnit] = ACTIONS(5493),
    [sym_report_keyword] = ACTIONS(5493),
    [sym_query_keyword] = ACTIONS(5493),
    [anon_sym_xmlport] = ACTIONS(5493),
    [anon_sym_XMLPORT] = ACTIONS(5493),
    [anon_sym_Xmlport] = ACTIONS(5493),
    [anon_sym_XMLport] = ACTIONS(5493),
    [anon_sym_XMLPort] = ACTIONS(5493),
    [anon_sym_XmlPort] = ACTIONS(5493),
    [anon_sym_enum] = ACTIONS(5493),
    [anon_sym_ENUM] = ACTIONS(5493),
    [anon_sym_Enum] = ACTIONS(5493),
    [anon_sym_eNUM] = ACTIONS(5493),
    [anon_sym_eNum] = ACTIONS(5493),
    [anon_sym_ENum] = ACTIONS(5493),
    [sym_quoted_identifier] = ACTIONS(5495),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5495),
    [sym_verbatim_string] = ACTIONS(5495),
    [sym_integer] = ACTIONS(5493),
    [sym_continue_as_identifier] = ACTIONS(5495),
    [sym_preproc_open] = ACTIONS(5495),
    [sym_end_keyword] = ACTIONS(5495),
  },
  [STATE(3374)] = {
    [sym_identifier] = ACTIONS(5911),
    [anon_sym_SEMI] = ACTIONS(5913),
    [anon_sym_DASH] = ACTIONS(5913),
    [aux_sym_boolean_token1] = ACTIONS(5911),
    [aux_sym_boolean_token2] = ACTIONS(5911),
    [sym_decimal] = ACTIONS(5911),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5911),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [aux_sym_record_type_token1] = ACTIONS(5911),
    [aux_sym_basic_type_token21] = ACTIONS(5911),
    [aux_sym_basic_type_token22] = ACTIONS(5911),
    [aux_sym_basic_type_token48] = ACTIONS(5911),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5911),
    [anon_sym_POUNDif] = ACTIONS(5913),
    [anon_sym_POUNDIF] = ACTIONS(5913),
    [anon_sym_POUNDIf] = ACTIONS(5913),
    [anon_sym_not] = ACTIONS(5911),
    [anon_sym_NOT] = ACTIONS(5911),
    [anon_sym_Not] = ACTIONS(5911),
    [anon_sym_POUNDelse] = ACTIONS(5913),
    [anon_sym_POUNDELSE] = ACTIONS(5913),
    [anon_sym_POUNDElse] = ACTIONS(5913),
    [anon_sym_POUNDelse2] = ACTIONS(5913),
    [anon_sym_POUNDELSE2] = ACTIONS(5913),
    [anon_sym_POUNDElse2] = ACTIONS(5913),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5911),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5911),
    [anon_sym_PLUS] = ACTIONS(5913),
    [sym_datetime_literal] = ACTIONS(5913),
    [sym_date_literal] = ACTIONS(5911),
    [sym_time_literal] = ACTIONS(5911),
    [sym_biginteger_literal] = ACTIONS(5913),
    [anon_sym_if] = ACTIONS(5911),
    [anon_sym_IF] = ACTIONS(5911),
    [anon_sym_If] = ACTIONS(5911),
    [anon_sym_else] = ACTIONS(5911),
    [anon_sym_ELSE] = ACTIONS(5911),
    [anon_sym_Else] = ACTIONS(5911),
    [anon_sym_case] = ACTIONS(5911),
    [anon_sym_CASE] = ACTIONS(5911),
    [anon_sym_Case] = ACTIONS(5911),
    [anon_sym_for] = ACTIONS(5911),
    [anon_sym_FOR] = ACTIONS(5911),
    [anon_sym_For] = ACTIONS(5911),
    [anon_sym_foreach] = ACTIONS(5911),
    [anon_sym_FOREACH] = ACTIONS(5911),
    [anon_sym_Foreach] = ACTIONS(5911),
    [anon_sym_while] = ACTIONS(5911),
    [anon_sym_WHILE] = ACTIONS(5911),
    [anon_sym_While] = ACTIONS(5911),
    [anon_sym_repeat] = ACTIONS(5911),
    [anon_sym_REPEAT] = ACTIONS(5911),
    [anon_sym_Repeat] = ACTIONS(5911),
    [anon_sym_exit] = ACTIONS(5911),
    [anon_sym_EXIT] = ACTIONS(5911),
    [anon_sym_Exit] = ACTIONS(5911),
    [anon_sym_continue] = ACTIONS(5911),
    [anon_sym_CONTINUE] = ACTIONS(5911),
    [anon_sym_Continue] = ACTIONS(5911),
    [anon_sym_break] = ACTIONS(5911),
    [anon_sym_BREAK] = ACTIONS(5911),
    [anon_sym_Break] = ACTIONS(5911),
    [anon_sym_with] = ACTIONS(5911),
    [anon_sym_WITH] = ACTIONS(5911),
    [anon_sym_With] = ACTIONS(5911),
    [sym_asserterror_keyword] = ACTIONS(5913),
    [sym_page_keyword] = ACTIONS(5911),
    [anon_sym_codeunit] = ACTIONS(5911),
    [anon_sym_CODEUNIT] = ACTIONS(5911),
    [anon_sym_Codeunit] = ACTIONS(5911),
    [anon_sym_CodeUnit] = ACTIONS(5911),
    [anon_sym_COdeunit] = ACTIONS(5911),
    [anon_sym_codeUnit] = ACTIONS(5911),
    [sym_report_keyword] = ACTIONS(5911),
    [sym_query_keyword] = ACTIONS(5911),
    [anon_sym_xmlport] = ACTIONS(5911),
    [anon_sym_XMLPORT] = ACTIONS(5911),
    [anon_sym_Xmlport] = ACTIONS(5911),
    [anon_sym_XMLport] = ACTIONS(5911),
    [anon_sym_XMLPort] = ACTIONS(5911),
    [anon_sym_XmlPort] = ACTIONS(5911),
    [anon_sym_enum] = ACTIONS(5911),
    [anon_sym_ENUM] = ACTIONS(5911),
    [anon_sym_Enum] = ACTIONS(5911),
    [anon_sym_eNUM] = ACTIONS(5911),
    [anon_sym_eNum] = ACTIONS(5911),
    [anon_sym_ENum] = ACTIONS(5911),
    [sym_quoted_identifier] = ACTIONS(5913),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5913),
    [sym_verbatim_string] = ACTIONS(5913),
    [sym_integer] = ACTIONS(5911),
    [sym_continue_as_identifier] = ACTIONS(5913),
    [sym_preproc_open] = ACTIONS(5913),
    [sym_end_keyword] = ACTIONS(5913),
  },
  [STATE(3375)] = {
    [sym_identifier] = ACTIONS(5949),
    [anon_sym_SEMI] = ACTIONS(5951),
    [anon_sym_DASH] = ACTIONS(5951),
    [aux_sym_boolean_token1] = ACTIONS(5949),
    [aux_sym_boolean_token2] = ACTIONS(5949),
    [sym_decimal] = ACTIONS(5949),
    [anon_sym_LPAREN] = ACTIONS(5951),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5949),
    [anon_sym_LBRACK] = ACTIONS(5951),
    [aux_sym_record_type_token1] = ACTIONS(5949),
    [aux_sym_basic_type_token21] = ACTIONS(5949),
    [aux_sym_basic_type_token22] = ACTIONS(5949),
    [aux_sym_basic_type_token48] = ACTIONS(5949),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5949),
    [anon_sym_POUNDif] = ACTIONS(5951),
    [anon_sym_POUNDIF] = ACTIONS(5951),
    [anon_sym_POUNDIf] = ACTIONS(5951),
    [anon_sym_not] = ACTIONS(5949),
    [anon_sym_NOT] = ACTIONS(5949),
    [anon_sym_Not] = ACTIONS(5949),
    [anon_sym_POUNDelse] = ACTIONS(5951),
    [anon_sym_POUNDELSE] = ACTIONS(5951),
    [anon_sym_POUNDElse] = ACTIONS(5951),
    [anon_sym_POUNDelse2] = ACTIONS(5951),
    [anon_sym_POUNDELSE2] = ACTIONS(5951),
    [anon_sym_POUNDElse2] = ACTIONS(5951),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5949),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5949),
    [anon_sym_PLUS] = ACTIONS(5951),
    [sym_datetime_literal] = ACTIONS(5951),
    [sym_date_literal] = ACTIONS(5949),
    [sym_time_literal] = ACTIONS(5949),
    [sym_biginteger_literal] = ACTIONS(5951),
    [anon_sym_if] = ACTIONS(5949),
    [anon_sym_IF] = ACTIONS(5949),
    [anon_sym_If] = ACTIONS(5949),
    [anon_sym_else] = ACTIONS(5949),
    [anon_sym_ELSE] = ACTIONS(5949),
    [anon_sym_Else] = ACTIONS(5949),
    [anon_sym_case] = ACTIONS(5949),
    [anon_sym_CASE] = ACTIONS(5949),
    [anon_sym_Case] = ACTIONS(5949),
    [anon_sym_for] = ACTIONS(5949),
    [anon_sym_FOR] = ACTIONS(5949),
    [anon_sym_For] = ACTIONS(5949),
    [anon_sym_foreach] = ACTIONS(5949),
    [anon_sym_FOREACH] = ACTIONS(5949),
    [anon_sym_Foreach] = ACTIONS(5949),
    [anon_sym_while] = ACTIONS(5949),
    [anon_sym_WHILE] = ACTIONS(5949),
    [anon_sym_While] = ACTIONS(5949),
    [anon_sym_repeat] = ACTIONS(5949),
    [anon_sym_REPEAT] = ACTIONS(5949),
    [anon_sym_Repeat] = ACTIONS(5949),
    [anon_sym_exit] = ACTIONS(5949),
    [anon_sym_EXIT] = ACTIONS(5949),
    [anon_sym_Exit] = ACTIONS(5949),
    [anon_sym_continue] = ACTIONS(5949),
    [anon_sym_CONTINUE] = ACTIONS(5949),
    [anon_sym_Continue] = ACTIONS(5949),
    [anon_sym_break] = ACTIONS(5949),
    [anon_sym_BREAK] = ACTIONS(5949),
    [anon_sym_Break] = ACTIONS(5949),
    [anon_sym_with] = ACTIONS(5949),
    [anon_sym_WITH] = ACTIONS(5949),
    [anon_sym_With] = ACTIONS(5949),
    [sym_asserterror_keyword] = ACTIONS(5951),
    [sym_page_keyword] = ACTIONS(5949),
    [anon_sym_codeunit] = ACTIONS(5949),
    [anon_sym_CODEUNIT] = ACTIONS(5949),
    [anon_sym_Codeunit] = ACTIONS(5949),
    [anon_sym_CodeUnit] = ACTIONS(5949),
    [anon_sym_COdeunit] = ACTIONS(5949),
    [anon_sym_codeUnit] = ACTIONS(5949),
    [sym_report_keyword] = ACTIONS(5949),
    [sym_query_keyword] = ACTIONS(5949),
    [anon_sym_xmlport] = ACTIONS(5949),
    [anon_sym_XMLPORT] = ACTIONS(5949),
    [anon_sym_Xmlport] = ACTIONS(5949),
    [anon_sym_XMLport] = ACTIONS(5949),
    [anon_sym_XMLPort] = ACTIONS(5949),
    [anon_sym_XmlPort] = ACTIONS(5949),
    [anon_sym_enum] = ACTIONS(5949),
    [anon_sym_ENUM] = ACTIONS(5949),
    [anon_sym_Enum] = ACTIONS(5949),
    [anon_sym_eNUM] = ACTIONS(5949),
    [anon_sym_eNum] = ACTIONS(5949),
    [anon_sym_ENum] = ACTIONS(5949),
    [sym_quoted_identifier] = ACTIONS(5951),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5951),
    [sym_verbatim_string] = ACTIONS(5951),
    [sym_integer] = ACTIONS(5949),
    [sym_continue_as_identifier] = ACTIONS(5951),
    [sym_preproc_open] = ACTIONS(5951),
    [sym_end_keyword] = ACTIONS(5951),
  },
  [STATE(3376)] = {
    [sym_identifier] = ACTIONS(5545),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym_DASH] = ACTIONS(5547),
    [aux_sym_boolean_token1] = ACTIONS(5545),
    [aux_sym_boolean_token2] = ACTIONS(5545),
    [sym_decimal] = ACTIONS(5545),
    [anon_sym_LPAREN] = ACTIONS(5547),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5547),
    [aux_sym_record_type_token1] = ACTIONS(5545),
    [aux_sym_basic_type_token21] = ACTIONS(5545),
    [aux_sym_basic_type_token22] = ACTIONS(5545),
    [aux_sym_basic_type_token48] = ACTIONS(5545),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5545),
    [anon_sym_POUNDif] = ACTIONS(5547),
    [anon_sym_POUNDIF] = ACTIONS(5547),
    [anon_sym_POUNDIf] = ACTIONS(5547),
    [anon_sym_not] = ACTIONS(5545),
    [anon_sym_NOT] = ACTIONS(5545),
    [anon_sym_Not] = ACTIONS(5545),
    [anon_sym_POUNDelse] = ACTIONS(5547),
    [anon_sym_POUNDELSE] = ACTIONS(5547),
    [anon_sym_POUNDElse] = ACTIONS(5547),
    [anon_sym_POUNDelse2] = ACTIONS(5547),
    [anon_sym_POUNDELSE2] = ACTIONS(5547),
    [anon_sym_POUNDElse2] = ACTIONS(5547),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5545),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5545),
    [anon_sym_PLUS] = ACTIONS(5547),
    [sym_datetime_literal] = ACTIONS(5547),
    [sym_date_literal] = ACTIONS(5545),
    [sym_time_literal] = ACTIONS(5545),
    [sym_biginteger_literal] = ACTIONS(5547),
    [anon_sym_if] = ACTIONS(5545),
    [anon_sym_IF] = ACTIONS(5545),
    [anon_sym_If] = ACTIONS(5545),
    [anon_sym_else] = ACTIONS(5545),
    [anon_sym_ELSE] = ACTIONS(5545),
    [anon_sym_Else] = ACTIONS(5545),
    [anon_sym_case] = ACTIONS(5545),
    [anon_sym_CASE] = ACTIONS(5545),
    [anon_sym_Case] = ACTIONS(5545),
    [anon_sym_for] = ACTIONS(5545),
    [anon_sym_FOR] = ACTIONS(5545),
    [anon_sym_For] = ACTIONS(5545),
    [anon_sym_foreach] = ACTIONS(5545),
    [anon_sym_FOREACH] = ACTIONS(5545),
    [anon_sym_Foreach] = ACTIONS(5545),
    [anon_sym_while] = ACTIONS(5545),
    [anon_sym_WHILE] = ACTIONS(5545),
    [anon_sym_While] = ACTIONS(5545),
    [anon_sym_repeat] = ACTIONS(5545),
    [anon_sym_REPEAT] = ACTIONS(5545),
    [anon_sym_Repeat] = ACTIONS(5545),
    [anon_sym_exit] = ACTIONS(5545),
    [anon_sym_EXIT] = ACTIONS(5545),
    [anon_sym_Exit] = ACTIONS(5545),
    [anon_sym_continue] = ACTIONS(5545),
    [anon_sym_CONTINUE] = ACTIONS(5545),
    [anon_sym_Continue] = ACTIONS(5545),
    [anon_sym_break] = ACTIONS(5545),
    [anon_sym_BREAK] = ACTIONS(5545),
    [anon_sym_Break] = ACTIONS(5545),
    [anon_sym_with] = ACTIONS(5545),
    [anon_sym_WITH] = ACTIONS(5545),
    [anon_sym_With] = ACTIONS(5545),
    [sym_asserterror_keyword] = ACTIONS(5547),
    [sym_page_keyword] = ACTIONS(5545),
    [anon_sym_codeunit] = ACTIONS(5545),
    [anon_sym_CODEUNIT] = ACTIONS(5545),
    [anon_sym_Codeunit] = ACTIONS(5545),
    [anon_sym_CodeUnit] = ACTIONS(5545),
    [anon_sym_COdeunit] = ACTIONS(5545),
    [anon_sym_codeUnit] = ACTIONS(5545),
    [sym_report_keyword] = ACTIONS(5545),
    [sym_query_keyword] = ACTIONS(5545),
    [anon_sym_xmlport] = ACTIONS(5545),
    [anon_sym_XMLPORT] = ACTIONS(5545),
    [anon_sym_Xmlport] = ACTIONS(5545),
    [anon_sym_XMLport] = ACTIONS(5545),
    [anon_sym_XMLPort] = ACTIONS(5545),
    [anon_sym_XmlPort] = ACTIONS(5545),
    [anon_sym_enum] = ACTIONS(5545),
    [anon_sym_ENUM] = ACTIONS(5545),
    [anon_sym_Enum] = ACTIONS(5545),
    [anon_sym_eNUM] = ACTIONS(5545),
    [anon_sym_eNum] = ACTIONS(5545),
    [anon_sym_ENum] = ACTIONS(5545),
    [sym_quoted_identifier] = ACTIONS(5547),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5547),
    [sym_verbatim_string] = ACTIONS(5547),
    [sym_integer] = ACTIONS(5545),
    [sym_continue_as_identifier] = ACTIONS(5547),
    [sym_preproc_open] = ACTIONS(5547),
    [sym_end_keyword] = ACTIONS(5547),
  },
  [STATE(3377)] = {
    [sym_identifier] = ACTIONS(5931),
    [anon_sym_SEMI] = ACTIONS(5933),
    [anon_sym_DASH] = ACTIONS(5933),
    [aux_sym_boolean_token1] = ACTIONS(5931),
    [aux_sym_boolean_token2] = ACTIONS(5931),
    [sym_decimal] = ACTIONS(5931),
    [anon_sym_LPAREN] = ACTIONS(5933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5931),
    [anon_sym_LBRACK] = ACTIONS(5933),
    [aux_sym_record_type_token1] = ACTIONS(5931),
    [aux_sym_basic_type_token21] = ACTIONS(5931),
    [aux_sym_basic_type_token22] = ACTIONS(5931),
    [aux_sym_basic_type_token48] = ACTIONS(5931),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5931),
    [anon_sym_POUNDif] = ACTIONS(5933),
    [anon_sym_POUNDIF] = ACTIONS(5933),
    [anon_sym_POUNDIf] = ACTIONS(5933),
    [anon_sym_not] = ACTIONS(5931),
    [anon_sym_NOT] = ACTIONS(5931),
    [anon_sym_Not] = ACTIONS(5931),
    [anon_sym_POUNDelse] = ACTIONS(5933),
    [anon_sym_POUNDELSE] = ACTIONS(5933),
    [anon_sym_POUNDElse] = ACTIONS(5933),
    [anon_sym_POUNDelse2] = ACTIONS(5933),
    [anon_sym_POUNDELSE2] = ACTIONS(5933),
    [anon_sym_POUNDElse2] = ACTIONS(5933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5931),
    [anon_sym_PLUS] = ACTIONS(5933),
    [sym_datetime_literal] = ACTIONS(5933),
    [sym_date_literal] = ACTIONS(5931),
    [sym_time_literal] = ACTIONS(5931),
    [sym_biginteger_literal] = ACTIONS(5933),
    [anon_sym_if] = ACTIONS(5931),
    [anon_sym_IF] = ACTIONS(5931),
    [anon_sym_If] = ACTIONS(5931),
    [anon_sym_else] = ACTIONS(5931),
    [anon_sym_ELSE] = ACTIONS(5931),
    [anon_sym_Else] = ACTIONS(5931),
    [anon_sym_case] = ACTIONS(5931),
    [anon_sym_CASE] = ACTIONS(5931),
    [anon_sym_Case] = ACTIONS(5931),
    [anon_sym_for] = ACTIONS(5931),
    [anon_sym_FOR] = ACTIONS(5931),
    [anon_sym_For] = ACTIONS(5931),
    [anon_sym_foreach] = ACTIONS(5931),
    [anon_sym_FOREACH] = ACTIONS(5931),
    [anon_sym_Foreach] = ACTIONS(5931),
    [anon_sym_while] = ACTIONS(5931),
    [anon_sym_WHILE] = ACTIONS(5931),
    [anon_sym_While] = ACTIONS(5931),
    [anon_sym_repeat] = ACTIONS(5931),
    [anon_sym_REPEAT] = ACTIONS(5931),
    [anon_sym_Repeat] = ACTIONS(5931),
    [anon_sym_exit] = ACTIONS(5931),
    [anon_sym_EXIT] = ACTIONS(5931),
    [anon_sym_Exit] = ACTIONS(5931),
    [anon_sym_continue] = ACTIONS(5931),
    [anon_sym_CONTINUE] = ACTIONS(5931),
    [anon_sym_Continue] = ACTIONS(5931),
    [anon_sym_break] = ACTIONS(5931),
    [anon_sym_BREAK] = ACTIONS(5931),
    [anon_sym_Break] = ACTIONS(5931),
    [anon_sym_with] = ACTIONS(5931),
    [anon_sym_WITH] = ACTIONS(5931),
    [anon_sym_With] = ACTIONS(5931),
    [sym_asserterror_keyword] = ACTIONS(5933),
    [sym_page_keyword] = ACTIONS(5931),
    [anon_sym_codeunit] = ACTIONS(5931),
    [anon_sym_CODEUNIT] = ACTIONS(5931),
    [anon_sym_Codeunit] = ACTIONS(5931),
    [anon_sym_CodeUnit] = ACTIONS(5931),
    [anon_sym_COdeunit] = ACTIONS(5931),
    [anon_sym_codeUnit] = ACTIONS(5931),
    [sym_report_keyword] = ACTIONS(5931),
    [sym_query_keyword] = ACTIONS(5931),
    [anon_sym_xmlport] = ACTIONS(5931),
    [anon_sym_XMLPORT] = ACTIONS(5931),
    [anon_sym_Xmlport] = ACTIONS(5931),
    [anon_sym_XMLport] = ACTIONS(5931),
    [anon_sym_XMLPort] = ACTIONS(5931),
    [anon_sym_XmlPort] = ACTIONS(5931),
    [anon_sym_enum] = ACTIONS(5931),
    [anon_sym_ENUM] = ACTIONS(5931),
    [anon_sym_Enum] = ACTIONS(5931),
    [anon_sym_eNUM] = ACTIONS(5931),
    [anon_sym_eNum] = ACTIONS(5931),
    [anon_sym_ENum] = ACTIONS(5931),
    [sym_quoted_identifier] = ACTIONS(5933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5933),
    [sym_verbatim_string] = ACTIONS(5933),
    [sym_integer] = ACTIONS(5931),
    [sym_continue_as_identifier] = ACTIONS(5933),
    [sym_preproc_open] = ACTIONS(5933),
    [sym_end_keyword] = ACTIONS(5933),
  },
  [STATE(3378)] = {
    [sym_identifier] = ACTIONS(5859),
    [anon_sym_SEMI] = ACTIONS(5861),
    [anon_sym_DASH] = ACTIONS(5861),
    [aux_sym_boolean_token1] = ACTIONS(5859),
    [aux_sym_boolean_token2] = ACTIONS(5859),
    [sym_decimal] = ACTIONS(5859),
    [anon_sym_LPAREN] = ACTIONS(5861),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5859),
    [anon_sym_LBRACK] = ACTIONS(5861),
    [aux_sym_record_type_token1] = ACTIONS(5859),
    [aux_sym_basic_type_token21] = ACTIONS(5859),
    [aux_sym_basic_type_token22] = ACTIONS(5859),
    [aux_sym_basic_type_token48] = ACTIONS(5859),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5859),
    [anon_sym_POUNDif] = ACTIONS(5861),
    [anon_sym_POUNDIF] = ACTIONS(5861),
    [anon_sym_POUNDIf] = ACTIONS(5861),
    [anon_sym_not] = ACTIONS(5859),
    [anon_sym_NOT] = ACTIONS(5859),
    [anon_sym_Not] = ACTIONS(5859),
    [anon_sym_POUNDelse] = ACTIONS(5861),
    [anon_sym_POUNDELSE] = ACTIONS(5861),
    [anon_sym_POUNDElse] = ACTIONS(5861),
    [anon_sym_POUNDelse2] = ACTIONS(5861),
    [anon_sym_POUNDELSE2] = ACTIONS(5861),
    [anon_sym_POUNDElse2] = ACTIONS(5861),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5859),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5859),
    [anon_sym_PLUS] = ACTIONS(5861),
    [sym_datetime_literal] = ACTIONS(5861),
    [sym_date_literal] = ACTIONS(5859),
    [sym_time_literal] = ACTIONS(5859),
    [sym_biginteger_literal] = ACTIONS(5861),
    [anon_sym_if] = ACTIONS(5859),
    [anon_sym_IF] = ACTIONS(5859),
    [anon_sym_If] = ACTIONS(5859),
    [anon_sym_else] = ACTIONS(5859),
    [anon_sym_ELSE] = ACTIONS(5859),
    [anon_sym_Else] = ACTIONS(5859),
    [anon_sym_case] = ACTIONS(5859),
    [anon_sym_CASE] = ACTIONS(5859),
    [anon_sym_Case] = ACTIONS(5859),
    [anon_sym_for] = ACTIONS(5859),
    [anon_sym_FOR] = ACTIONS(5859),
    [anon_sym_For] = ACTIONS(5859),
    [anon_sym_foreach] = ACTIONS(5859),
    [anon_sym_FOREACH] = ACTIONS(5859),
    [anon_sym_Foreach] = ACTIONS(5859),
    [anon_sym_while] = ACTIONS(5859),
    [anon_sym_WHILE] = ACTIONS(5859),
    [anon_sym_While] = ACTIONS(5859),
    [anon_sym_repeat] = ACTIONS(5859),
    [anon_sym_REPEAT] = ACTIONS(5859),
    [anon_sym_Repeat] = ACTIONS(5859),
    [anon_sym_exit] = ACTIONS(5859),
    [anon_sym_EXIT] = ACTIONS(5859),
    [anon_sym_Exit] = ACTIONS(5859),
    [anon_sym_continue] = ACTIONS(5859),
    [anon_sym_CONTINUE] = ACTIONS(5859),
    [anon_sym_Continue] = ACTIONS(5859),
    [anon_sym_break] = ACTIONS(5859),
    [anon_sym_BREAK] = ACTIONS(5859),
    [anon_sym_Break] = ACTIONS(5859),
    [anon_sym_with] = ACTIONS(5859),
    [anon_sym_WITH] = ACTIONS(5859),
    [anon_sym_With] = ACTIONS(5859),
    [sym_asserterror_keyword] = ACTIONS(5861),
    [sym_page_keyword] = ACTIONS(5859),
    [anon_sym_codeunit] = ACTIONS(5859),
    [anon_sym_CODEUNIT] = ACTIONS(5859),
    [anon_sym_Codeunit] = ACTIONS(5859),
    [anon_sym_CodeUnit] = ACTIONS(5859),
    [anon_sym_COdeunit] = ACTIONS(5859),
    [anon_sym_codeUnit] = ACTIONS(5859),
    [sym_report_keyword] = ACTIONS(5859),
    [sym_query_keyword] = ACTIONS(5859),
    [anon_sym_xmlport] = ACTIONS(5859),
    [anon_sym_XMLPORT] = ACTIONS(5859),
    [anon_sym_Xmlport] = ACTIONS(5859),
    [anon_sym_XMLport] = ACTIONS(5859),
    [anon_sym_XMLPort] = ACTIONS(5859),
    [anon_sym_XmlPort] = ACTIONS(5859),
    [anon_sym_enum] = ACTIONS(5859),
    [anon_sym_ENUM] = ACTIONS(5859),
    [anon_sym_Enum] = ACTIONS(5859),
    [anon_sym_eNUM] = ACTIONS(5859),
    [anon_sym_eNum] = ACTIONS(5859),
    [anon_sym_ENum] = ACTIONS(5859),
    [sym_quoted_identifier] = ACTIONS(5861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5861),
    [sym_verbatim_string] = ACTIONS(5861),
    [sym_integer] = ACTIONS(5859),
    [sym_continue_as_identifier] = ACTIONS(5861),
    [sym_preproc_open] = ACTIONS(5861),
    [sym_end_keyword] = ACTIONS(5861),
  },
  [STATE(3379)] = {
    [sym_identifier] = ACTIONS(5549),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym_DASH] = ACTIONS(5551),
    [aux_sym_boolean_token1] = ACTIONS(5549),
    [aux_sym_boolean_token2] = ACTIONS(5549),
    [sym_decimal] = ACTIONS(5549),
    [anon_sym_LPAREN] = ACTIONS(5551),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5549),
    [anon_sym_LBRACK] = ACTIONS(5551),
    [aux_sym_record_type_token1] = ACTIONS(5549),
    [aux_sym_basic_type_token21] = ACTIONS(5549),
    [aux_sym_basic_type_token22] = ACTIONS(5549),
    [aux_sym_basic_type_token48] = ACTIONS(5549),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5549),
    [anon_sym_POUNDif] = ACTIONS(5551),
    [anon_sym_POUNDIF] = ACTIONS(5551),
    [anon_sym_POUNDIf] = ACTIONS(5551),
    [anon_sym_not] = ACTIONS(5549),
    [anon_sym_NOT] = ACTIONS(5549),
    [anon_sym_Not] = ACTIONS(5549),
    [anon_sym_POUNDelse] = ACTIONS(5551),
    [anon_sym_POUNDELSE] = ACTIONS(5551),
    [anon_sym_POUNDElse] = ACTIONS(5551),
    [anon_sym_POUNDelse2] = ACTIONS(5551),
    [anon_sym_POUNDELSE2] = ACTIONS(5551),
    [anon_sym_POUNDElse2] = ACTIONS(5551),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5549),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5549),
    [anon_sym_PLUS] = ACTIONS(5551),
    [sym_datetime_literal] = ACTIONS(5551),
    [sym_date_literal] = ACTIONS(5549),
    [sym_time_literal] = ACTIONS(5549),
    [sym_biginteger_literal] = ACTIONS(5551),
    [anon_sym_if] = ACTIONS(5549),
    [anon_sym_IF] = ACTIONS(5549),
    [anon_sym_If] = ACTIONS(5549),
    [anon_sym_else] = ACTIONS(5549),
    [anon_sym_ELSE] = ACTIONS(5549),
    [anon_sym_Else] = ACTIONS(5549),
    [anon_sym_case] = ACTIONS(5549),
    [anon_sym_CASE] = ACTIONS(5549),
    [anon_sym_Case] = ACTIONS(5549),
    [anon_sym_for] = ACTIONS(5549),
    [anon_sym_FOR] = ACTIONS(5549),
    [anon_sym_For] = ACTIONS(5549),
    [anon_sym_foreach] = ACTIONS(5549),
    [anon_sym_FOREACH] = ACTIONS(5549),
    [anon_sym_Foreach] = ACTIONS(5549),
    [anon_sym_while] = ACTIONS(5549),
    [anon_sym_WHILE] = ACTIONS(5549),
    [anon_sym_While] = ACTIONS(5549),
    [anon_sym_repeat] = ACTIONS(5549),
    [anon_sym_REPEAT] = ACTIONS(5549),
    [anon_sym_Repeat] = ACTIONS(5549),
    [anon_sym_exit] = ACTIONS(5549),
    [anon_sym_EXIT] = ACTIONS(5549),
    [anon_sym_Exit] = ACTIONS(5549),
    [anon_sym_continue] = ACTIONS(5549),
    [anon_sym_CONTINUE] = ACTIONS(5549),
    [anon_sym_Continue] = ACTIONS(5549),
    [anon_sym_break] = ACTIONS(5549),
    [anon_sym_BREAK] = ACTIONS(5549),
    [anon_sym_Break] = ACTIONS(5549),
    [anon_sym_with] = ACTIONS(5549),
    [anon_sym_WITH] = ACTIONS(5549),
    [anon_sym_With] = ACTIONS(5549),
    [sym_asserterror_keyword] = ACTIONS(5551),
    [sym_page_keyword] = ACTIONS(5549),
    [anon_sym_codeunit] = ACTIONS(5549),
    [anon_sym_CODEUNIT] = ACTIONS(5549),
    [anon_sym_Codeunit] = ACTIONS(5549),
    [anon_sym_CodeUnit] = ACTIONS(5549),
    [anon_sym_COdeunit] = ACTIONS(5549),
    [anon_sym_codeUnit] = ACTIONS(5549),
    [sym_report_keyword] = ACTIONS(5549),
    [sym_query_keyword] = ACTIONS(5549),
    [anon_sym_xmlport] = ACTIONS(5549),
    [anon_sym_XMLPORT] = ACTIONS(5549),
    [anon_sym_Xmlport] = ACTIONS(5549),
    [anon_sym_XMLport] = ACTIONS(5549),
    [anon_sym_XMLPort] = ACTIONS(5549),
    [anon_sym_XmlPort] = ACTIONS(5549),
    [anon_sym_enum] = ACTIONS(5549),
    [anon_sym_ENUM] = ACTIONS(5549),
    [anon_sym_Enum] = ACTIONS(5549),
    [anon_sym_eNUM] = ACTIONS(5549),
    [anon_sym_eNum] = ACTIONS(5549),
    [anon_sym_ENum] = ACTIONS(5549),
    [sym_quoted_identifier] = ACTIONS(5551),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5551),
    [sym_verbatim_string] = ACTIONS(5551),
    [sym_integer] = ACTIONS(5549),
    [sym_continue_as_identifier] = ACTIONS(5551),
    [sym_preproc_open] = ACTIONS(5551),
    [sym_end_keyword] = ACTIONS(5551),
  },
  [STATE(3380)] = {
    [sym_identifier] = ACTIONS(5863),
    [anon_sym_SEMI] = ACTIONS(5865),
    [anon_sym_DASH] = ACTIONS(5865),
    [aux_sym_boolean_token1] = ACTIONS(5863),
    [aux_sym_boolean_token2] = ACTIONS(5863),
    [sym_decimal] = ACTIONS(5863),
    [anon_sym_LPAREN] = ACTIONS(5865),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5863),
    [anon_sym_LBRACK] = ACTIONS(5865),
    [aux_sym_record_type_token1] = ACTIONS(5863),
    [aux_sym_basic_type_token21] = ACTIONS(5863),
    [aux_sym_basic_type_token22] = ACTIONS(5863),
    [aux_sym_basic_type_token48] = ACTIONS(5863),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5863),
    [anon_sym_POUNDif] = ACTIONS(5865),
    [anon_sym_POUNDIF] = ACTIONS(5865),
    [anon_sym_POUNDIf] = ACTIONS(5865),
    [anon_sym_not] = ACTIONS(5863),
    [anon_sym_NOT] = ACTIONS(5863),
    [anon_sym_Not] = ACTIONS(5863),
    [anon_sym_POUNDelse] = ACTIONS(5865),
    [anon_sym_POUNDELSE] = ACTIONS(5865),
    [anon_sym_POUNDElse] = ACTIONS(5865),
    [anon_sym_POUNDelse2] = ACTIONS(5865),
    [anon_sym_POUNDELSE2] = ACTIONS(5865),
    [anon_sym_POUNDElse2] = ACTIONS(5865),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5863),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5863),
    [anon_sym_PLUS] = ACTIONS(5865),
    [sym_datetime_literal] = ACTIONS(5865),
    [sym_date_literal] = ACTIONS(5863),
    [sym_time_literal] = ACTIONS(5863),
    [sym_biginteger_literal] = ACTIONS(5865),
    [anon_sym_if] = ACTIONS(5863),
    [anon_sym_IF] = ACTIONS(5863),
    [anon_sym_If] = ACTIONS(5863),
    [anon_sym_else] = ACTIONS(5863),
    [anon_sym_ELSE] = ACTIONS(5863),
    [anon_sym_Else] = ACTIONS(5863),
    [anon_sym_case] = ACTIONS(5863),
    [anon_sym_CASE] = ACTIONS(5863),
    [anon_sym_Case] = ACTIONS(5863),
    [anon_sym_for] = ACTIONS(5863),
    [anon_sym_FOR] = ACTIONS(5863),
    [anon_sym_For] = ACTIONS(5863),
    [anon_sym_foreach] = ACTIONS(5863),
    [anon_sym_FOREACH] = ACTIONS(5863),
    [anon_sym_Foreach] = ACTIONS(5863),
    [anon_sym_while] = ACTIONS(5863),
    [anon_sym_WHILE] = ACTIONS(5863),
    [anon_sym_While] = ACTIONS(5863),
    [anon_sym_repeat] = ACTIONS(5863),
    [anon_sym_REPEAT] = ACTIONS(5863),
    [anon_sym_Repeat] = ACTIONS(5863),
    [anon_sym_exit] = ACTIONS(5863),
    [anon_sym_EXIT] = ACTIONS(5863),
    [anon_sym_Exit] = ACTIONS(5863),
    [anon_sym_continue] = ACTIONS(5863),
    [anon_sym_CONTINUE] = ACTIONS(5863),
    [anon_sym_Continue] = ACTIONS(5863),
    [anon_sym_break] = ACTIONS(5863),
    [anon_sym_BREAK] = ACTIONS(5863),
    [anon_sym_Break] = ACTIONS(5863),
    [anon_sym_with] = ACTIONS(5863),
    [anon_sym_WITH] = ACTIONS(5863),
    [anon_sym_With] = ACTIONS(5863),
    [sym_asserterror_keyword] = ACTIONS(5865),
    [sym_page_keyword] = ACTIONS(5863),
    [anon_sym_codeunit] = ACTIONS(5863),
    [anon_sym_CODEUNIT] = ACTIONS(5863),
    [anon_sym_Codeunit] = ACTIONS(5863),
    [anon_sym_CodeUnit] = ACTIONS(5863),
    [anon_sym_COdeunit] = ACTIONS(5863),
    [anon_sym_codeUnit] = ACTIONS(5863),
    [sym_report_keyword] = ACTIONS(5863),
    [sym_query_keyword] = ACTIONS(5863),
    [anon_sym_xmlport] = ACTIONS(5863),
    [anon_sym_XMLPORT] = ACTIONS(5863),
    [anon_sym_Xmlport] = ACTIONS(5863),
    [anon_sym_XMLport] = ACTIONS(5863),
    [anon_sym_XMLPort] = ACTIONS(5863),
    [anon_sym_XmlPort] = ACTIONS(5863),
    [anon_sym_enum] = ACTIONS(5863),
    [anon_sym_ENUM] = ACTIONS(5863),
    [anon_sym_Enum] = ACTIONS(5863),
    [anon_sym_eNUM] = ACTIONS(5863),
    [anon_sym_eNum] = ACTIONS(5863),
    [anon_sym_ENum] = ACTIONS(5863),
    [sym_quoted_identifier] = ACTIONS(5865),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5865),
    [sym_verbatim_string] = ACTIONS(5865),
    [sym_integer] = ACTIONS(5863),
    [sym_continue_as_identifier] = ACTIONS(5865),
    [sym_preproc_open] = ACTIONS(5865),
    [sym_end_keyword] = ACTIONS(5865),
  },
  [STATE(3381)] = {
    [sym_identifier] = ACTIONS(5915),
    [anon_sym_SEMI] = ACTIONS(5917),
    [anon_sym_DASH] = ACTIONS(5917),
    [aux_sym_boolean_token1] = ACTIONS(5915),
    [aux_sym_boolean_token2] = ACTIONS(5915),
    [sym_decimal] = ACTIONS(5915),
    [anon_sym_LPAREN] = ACTIONS(5917),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5915),
    [anon_sym_LBRACK] = ACTIONS(5917),
    [aux_sym_record_type_token1] = ACTIONS(5915),
    [aux_sym_basic_type_token21] = ACTIONS(5915),
    [aux_sym_basic_type_token22] = ACTIONS(5915),
    [aux_sym_basic_type_token48] = ACTIONS(5915),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5915),
    [anon_sym_POUNDif] = ACTIONS(5917),
    [anon_sym_POUNDIF] = ACTIONS(5917),
    [anon_sym_POUNDIf] = ACTIONS(5917),
    [anon_sym_not] = ACTIONS(5915),
    [anon_sym_NOT] = ACTIONS(5915),
    [anon_sym_Not] = ACTIONS(5915),
    [anon_sym_POUNDelse] = ACTIONS(5917),
    [anon_sym_POUNDELSE] = ACTIONS(5917),
    [anon_sym_POUNDElse] = ACTIONS(5917),
    [anon_sym_POUNDelse2] = ACTIONS(5917),
    [anon_sym_POUNDELSE2] = ACTIONS(5917),
    [anon_sym_POUNDElse2] = ACTIONS(5917),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5915),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5915),
    [anon_sym_PLUS] = ACTIONS(5917),
    [sym_datetime_literal] = ACTIONS(5917),
    [sym_date_literal] = ACTIONS(5915),
    [sym_time_literal] = ACTIONS(5915),
    [sym_biginteger_literal] = ACTIONS(5917),
    [anon_sym_if] = ACTIONS(5915),
    [anon_sym_IF] = ACTIONS(5915),
    [anon_sym_If] = ACTIONS(5915),
    [anon_sym_else] = ACTIONS(5915),
    [anon_sym_ELSE] = ACTIONS(5915),
    [anon_sym_Else] = ACTIONS(5915),
    [anon_sym_case] = ACTIONS(5915),
    [anon_sym_CASE] = ACTIONS(5915),
    [anon_sym_Case] = ACTIONS(5915),
    [anon_sym_for] = ACTIONS(5915),
    [anon_sym_FOR] = ACTIONS(5915),
    [anon_sym_For] = ACTIONS(5915),
    [anon_sym_foreach] = ACTIONS(5915),
    [anon_sym_FOREACH] = ACTIONS(5915),
    [anon_sym_Foreach] = ACTIONS(5915),
    [anon_sym_while] = ACTIONS(5915),
    [anon_sym_WHILE] = ACTIONS(5915),
    [anon_sym_While] = ACTIONS(5915),
    [anon_sym_repeat] = ACTIONS(5915),
    [anon_sym_REPEAT] = ACTIONS(5915),
    [anon_sym_Repeat] = ACTIONS(5915),
    [anon_sym_exit] = ACTIONS(5915),
    [anon_sym_EXIT] = ACTIONS(5915),
    [anon_sym_Exit] = ACTIONS(5915),
    [anon_sym_continue] = ACTIONS(5915),
    [anon_sym_CONTINUE] = ACTIONS(5915),
    [anon_sym_Continue] = ACTIONS(5915),
    [anon_sym_break] = ACTIONS(5915),
    [anon_sym_BREAK] = ACTIONS(5915),
    [anon_sym_Break] = ACTIONS(5915),
    [anon_sym_with] = ACTIONS(5915),
    [anon_sym_WITH] = ACTIONS(5915),
    [anon_sym_With] = ACTIONS(5915),
    [sym_asserterror_keyword] = ACTIONS(5917),
    [sym_page_keyword] = ACTIONS(5915),
    [anon_sym_codeunit] = ACTIONS(5915),
    [anon_sym_CODEUNIT] = ACTIONS(5915),
    [anon_sym_Codeunit] = ACTIONS(5915),
    [anon_sym_CodeUnit] = ACTIONS(5915),
    [anon_sym_COdeunit] = ACTIONS(5915),
    [anon_sym_codeUnit] = ACTIONS(5915),
    [sym_report_keyword] = ACTIONS(5915),
    [sym_query_keyword] = ACTIONS(5915),
    [anon_sym_xmlport] = ACTIONS(5915),
    [anon_sym_XMLPORT] = ACTIONS(5915),
    [anon_sym_Xmlport] = ACTIONS(5915),
    [anon_sym_XMLport] = ACTIONS(5915),
    [anon_sym_XMLPort] = ACTIONS(5915),
    [anon_sym_XmlPort] = ACTIONS(5915),
    [anon_sym_enum] = ACTIONS(5915),
    [anon_sym_ENUM] = ACTIONS(5915),
    [anon_sym_Enum] = ACTIONS(5915),
    [anon_sym_eNUM] = ACTIONS(5915),
    [anon_sym_eNum] = ACTIONS(5915),
    [anon_sym_ENum] = ACTIONS(5915),
    [sym_quoted_identifier] = ACTIONS(5917),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5917),
    [sym_verbatim_string] = ACTIONS(5917),
    [sym_integer] = ACTIONS(5915),
    [sym_continue_as_identifier] = ACTIONS(5917),
    [sym_preproc_open] = ACTIONS(5917),
    [sym_end_keyword] = ACTIONS(5917),
  },
  [STATE(3382)] = {
    [sym_identifier] = ACTIONS(5919),
    [anon_sym_SEMI] = ACTIONS(5921),
    [anon_sym_DASH] = ACTIONS(5921),
    [aux_sym_boolean_token1] = ACTIONS(5919),
    [aux_sym_boolean_token2] = ACTIONS(5919),
    [sym_decimal] = ACTIONS(5919),
    [anon_sym_LPAREN] = ACTIONS(5921),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5919),
    [anon_sym_LBRACK] = ACTIONS(5921),
    [aux_sym_record_type_token1] = ACTIONS(5919),
    [aux_sym_basic_type_token21] = ACTIONS(5919),
    [aux_sym_basic_type_token22] = ACTIONS(5919),
    [aux_sym_basic_type_token48] = ACTIONS(5919),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5919),
    [anon_sym_POUNDif] = ACTIONS(5921),
    [anon_sym_POUNDIF] = ACTIONS(5921),
    [anon_sym_POUNDIf] = ACTIONS(5921),
    [anon_sym_not] = ACTIONS(5919),
    [anon_sym_NOT] = ACTIONS(5919),
    [anon_sym_Not] = ACTIONS(5919),
    [anon_sym_POUNDelse] = ACTIONS(5921),
    [anon_sym_POUNDELSE] = ACTIONS(5921),
    [anon_sym_POUNDElse] = ACTIONS(5921),
    [anon_sym_POUNDelse2] = ACTIONS(5921),
    [anon_sym_POUNDELSE2] = ACTIONS(5921),
    [anon_sym_POUNDElse2] = ACTIONS(5921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5919),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5919),
    [anon_sym_PLUS] = ACTIONS(5921),
    [sym_datetime_literal] = ACTIONS(5921),
    [sym_date_literal] = ACTIONS(5919),
    [sym_time_literal] = ACTIONS(5919),
    [sym_biginteger_literal] = ACTIONS(5921),
    [anon_sym_if] = ACTIONS(5919),
    [anon_sym_IF] = ACTIONS(5919),
    [anon_sym_If] = ACTIONS(5919),
    [anon_sym_else] = ACTIONS(5919),
    [anon_sym_ELSE] = ACTIONS(5919),
    [anon_sym_Else] = ACTIONS(5919),
    [anon_sym_case] = ACTIONS(5919),
    [anon_sym_CASE] = ACTIONS(5919),
    [anon_sym_Case] = ACTIONS(5919),
    [anon_sym_for] = ACTIONS(5919),
    [anon_sym_FOR] = ACTIONS(5919),
    [anon_sym_For] = ACTIONS(5919),
    [anon_sym_foreach] = ACTIONS(5919),
    [anon_sym_FOREACH] = ACTIONS(5919),
    [anon_sym_Foreach] = ACTIONS(5919),
    [anon_sym_while] = ACTIONS(5919),
    [anon_sym_WHILE] = ACTIONS(5919),
    [anon_sym_While] = ACTIONS(5919),
    [anon_sym_repeat] = ACTIONS(5919),
    [anon_sym_REPEAT] = ACTIONS(5919),
    [anon_sym_Repeat] = ACTIONS(5919),
    [anon_sym_exit] = ACTIONS(5919),
    [anon_sym_EXIT] = ACTIONS(5919),
    [anon_sym_Exit] = ACTIONS(5919),
    [anon_sym_continue] = ACTIONS(5919),
    [anon_sym_CONTINUE] = ACTIONS(5919),
    [anon_sym_Continue] = ACTIONS(5919),
    [anon_sym_break] = ACTIONS(5919),
    [anon_sym_BREAK] = ACTIONS(5919),
    [anon_sym_Break] = ACTIONS(5919),
    [anon_sym_with] = ACTIONS(5919),
    [anon_sym_WITH] = ACTIONS(5919),
    [anon_sym_With] = ACTIONS(5919),
    [sym_asserterror_keyword] = ACTIONS(5921),
    [sym_page_keyword] = ACTIONS(5919),
    [anon_sym_codeunit] = ACTIONS(5919),
    [anon_sym_CODEUNIT] = ACTIONS(5919),
    [anon_sym_Codeunit] = ACTIONS(5919),
    [anon_sym_CodeUnit] = ACTIONS(5919),
    [anon_sym_COdeunit] = ACTIONS(5919),
    [anon_sym_codeUnit] = ACTIONS(5919),
    [sym_report_keyword] = ACTIONS(5919),
    [sym_query_keyword] = ACTIONS(5919),
    [anon_sym_xmlport] = ACTIONS(5919),
    [anon_sym_XMLPORT] = ACTIONS(5919),
    [anon_sym_Xmlport] = ACTIONS(5919),
    [anon_sym_XMLport] = ACTIONS(5919),
    [anon_sym_XMLPort] = ACTIONS(5919),
    [anon_sym_XmlPort] = ACTIONS(5919),
    [anon_sym_enum] = ACTIONS(5919),
    [anon_sym_ENUM] = ACTIONS(5919),
    [anon_sym_Enum] = ACTIONS(5919),
    [anon_sym_eNUM] = ACTIONS(5919),
    [anon_sym_eNum] = ACTIONS(5919),
    [anon_sym_ENum] = ACTIONS(5919),
    [sym_quoted_identifier] = ACTIONS(5921),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5921),
    [sym_verbatim_string] = ACTIONS(5921),
    [sym_integer] = ACTIONS(5919),
    [sym_continue_as_identifier] = ACTIONS(5921),
    [sym_preproc_open] = ACTIONS(5921),
    [sym_end_keyword] = ACTIONS(5921),
  },
  [STATE(3383)] = {
    [sym_identifier] = ACTIONS(5939),
    [anon_sym_SEMI] = ACTIONS(7349),
    [anon_sym_DASH] = ACTIONS(5943),
    [aux_sym_boolean_token1] = ACTIONS(5939),
    [aux_sym_boolean_token2] = ACTIONS(5939),
    [sym_decimal] = ACTIONS(5939),
    [anon_sym_LPAREN] = ACTIONS(5943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5939),
    [anon_sym_LBRACK] = ACTIONS(5943),
    [aux_sym_record_type_token1] = ACTIONS(5939),
    [aux_sym_basic_type_token21] = ACTIONS(5939),
    [aux_sym_basic_type_token22] = ACTIONS(5939),
    [aux_sym_basic_type_token48] = ACTIONS(5939),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5939),
    [anon_sym_POUNDif] = ACTIONS(5943),
    [anon_sym_POUNDIF] = ACTIONS(5943),
    [anon_sym_POUNDIf] = ACTIONS(5943),
    [anon_sym_not] = ACTIONS(5939),
    [anon_sym_NOT] = ACTIONS(5939),
    [anon_sym_Not] = ACTIONS(5939),
    [anon_sym_POUNDelse] = ACTIONS(5943),
    [anon_sym_POUNDELSE] = ACTIONS(5943),
    [anon_sym_POUNDElse] = ACTIONS(5943),
    [anon_sym_POUNDelse2] = ACTIONS(5943),
    [anon_sym_POUNDELSE2] = ACTIONS(5943),
    [anon_sym_POUNDElse2] = ACTIONS(5943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5939),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5939),
    [anon_sym_PLUS] = ACTIONS(5943),
    [sym_datetime_literal] = ACTIONS(5943),
    [sym_date_literal] = ACTIONS(5939),
    [sym_time_literal] = ACTIONS(5939),
    [sym_biginteger_literal] = ACTIONS(5943),
    [anon_sym_if] = ACTIONS(5939),
    [anon_sym_IF] = ACTIONS(5939),
    [anon_sym_If] = ACTIONS(5939),
    [anon_sym_else] = ACTIONS(5939),
    [anon_sym_ELSE] = ACTIONS(5939),
    [anon_sym_Else] = ACTIONS(5939),
    [anon_sym_case] = ACTIONS(5939),
    [anon_sym_CASE] = ACTIONS(5939),
    [anon_sym_Case] = ACTIONS(5939),
    [anon_sym_for] = ACTIONS(5939),
    [anon_sym_FOR] = ACTIONS(5939),
    [anon_sym_For] = ACTIONS(5939),
    [anon_sym_foreach] = ACTIONS(5939),
    [anon_sym_FOREACH] = ACTIONS(5939),
    [anon_sym_Foreach] = ACTIONS(5939),
    [anon_sym_while] = ACTIONS(5939),
    [anon_sym_WHILE] = ACTIONS(5939),
    [anon_sym_While] = ACTIONS(5939),
    [anon_sym_repeat] = ACTIONS(5939),
    [anon_sym_REPEAT] = ACTIONS(5939),
    [anon_sym_Repeat] = ACTIONS(5939),
    [anon_sym_exit] = ACTIONS(5939),
    [anon_sym_EXIT] = ACTIONS(5939),
    [anon_sym_Exit] = ACTIONS(5939),
    [anon_sym_continue] = ACTIONS(5939),
    [anon_sym_CONTINUE] = ACTIONS(5939),
    [anon_sym_Continue] = ACTIONS(5939),
    [anon_sym_break] = ACTIONS(5939),
    [anon_sym_BREAK] = ACTIONS(5939),
    [anon_sym_Break] = ACTIONS(5939),
    [anon_sym_with] = ACTIONS(5939),
    [anon_sym_WITH] = ACTIONS(5939),
    [anon_sym_With] = ACTIONS(5939),
    [sym_asserterror_keyword] = ACTIONS(5943),
    [sym_page_keyword] = ACTIONS(5939),
    [anon_sym_codeunit] = ACTIONS(5939),
    [anon_sym_CODEUNIT] = ACTIONS(5939),
    [anon_sym_Codeunit] = ACTIONS(5939),
    [anon_sym_CodeUnit] = ACTIONS(5939),
    [anon_sym_COdeunit] = ACTIONS(5939),
    [anon_sym_codeUnit] = ACTIONS(5939),
    [sym_report_keyword] = ACTIONS(5939),
    [sym_query_keyword] = ACTIONS(5939),
    [anon_sym_xmlport] = ACTIONS(5939),
    [anon_sym_XMLPORT] = ACTIONS(5939),
    [anon_sym_Xmlport] = ACTIONS(5939),
    [anon_sym_XMLport] = ACTIONS(5939),
    [anon_sym_XMLPort] = ACTIONS(5939),
    [anon_sym_XmlPort] = ACTIONS(5939),
    [anon_sym_enum] = ACTIONS(5939),
    [anon_sym_ENUM] = ACTIONS(5939),
    [anon_sym_Enum] = ACTIONS(5939),
    [anon_sym_eNUM] = ACTIONS(5939),
    [anon_sym_eNum] = ACTIONS(5939),
    [anon_sym_ENum] = ACTIONS(5939),
    [sym_quoted_identifier] = ACTIONS(5943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5943),
    [sym_verbatim_string] = ACTIONS(5943),
    [sym_integer] = ACTIONS(5939),
    [sym_continue_as_identifier] = ACTIONS(5943),
    [sym_preproc_open] = ACTIONS(5943),
    [sym_end_keyword] = ACTIONS(5943),
  },
  [STATE(3384)] = {
    [sym_identifier] = ACTIONS(5867),
    [anon_sym_SEMI] = ACTIONS(5869),
    [anon_sym_DASH] = ACTIONS(5869),
    [aux_sym_boolean_token1] = ACTIONS(5867),
    [aux_sym_boolean_token2] = ACTIONS(5867),
    [sym_decimal] = ACTIONS(5867),
    [anon_sym_LPAREN] = ACTIONS(5869),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5867),
    [anon_sym_LBRACK] = ACTIONS(5869),
    [aux_sym_record_type_token1] = ACTIONS(5867),
    [aux_sym_basic_type_token21] = ACTIONS(5867),
    [aux_sym_basic_type_token22] = ACTIONS(5867),
    [aux_sym_basic_type_token48] = ACTIONS(5867),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5867),
    [anon_sym_POUNDif] = ACTIONS(5869),
    [anon_sym_POUNDIF] = ACTIONS(5869),
    [anon_sym_POUNDIf] = ACTIONS(5869),
    [anon_sym_not] = ACTIONS(5867),
    [anon_sym_NOT] = ACTIONS(5867),
    [anon_sym_Not] = ACTIONS(5867),
    [anon_sym_POUNDelse] = ACTIONS(5869),
    [anon_sym_POUNDELSE] = ACTIONS(5869),
    [anon_sym_POUNDElse] = ACTIONS(5869),
    [anon_sym_POUNDelse2] = ACTIONS(5869),
    [anon_sym_POUNDELSE2] = ACTIONS(5869),
    [anon_sym_POUNDElse2] = ACTIONS(5869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5867),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5867),
    [anon_sym_PLUS] = ACTIONS(5869),
    [sym_datetime_literal] = ACTIONS(5869),
    [sym_date_literal] = ACTIONS(5867),
    [sym_time_literal] = ACTIONS(5867),
    [sym_biginteger_literal] = ACTIONS(5869),
    [anon_sym_if] = ACTIONS(5867),
    [anon_sym_IF] = ACTIONS(5867),
    [anon_sym_If] = ACTIONS(5867),
    [anon_sym_else] = ACTIONS(5867),
    [anon_sym_ELSE] = ACTIONS(5867),
    [anon_sym_Else] = ACTIONS(5867),
    [anon_sym_case] = ACTIONS(5867),
    [anon_sym_CASE] = ACTIONS(5867),
    [anon_sym_Case] = ACTIONS(5867),
    [anon_sym_for] = ACTIONS(5867),
    [anon_sym_FOR] = ACTIONS(5867),
    [anon_sym_For] = ACTIONS(5867),
    [anon_sym_foreach] = ACTIONS(5867),
    [anon_sym_FOREACH] = ACTIONS(5867),
    [anon_sym_Foreach] = ACTIONS(5867),
    [anon_sym_while] = ACTIONS(5867),
    [anon_sym_WHILE] = ACTIONS(5867),
    [anon_sym_While] = ACTIONS(5867),
    [anon_sym_repeat] = ACTIONS(5867),
    [anon_sym_REPEAT] = ACTIONS(5867),
    [anon_sym_Repeat] = ACTIONS(5867),
    [anon_sym_exit] = ACTIONS(5867),
    [anon_sym_EXIT] = ACTIONS(5867),
    [anon_sym_Exit] = ACTIONS(5867),
    [anon_sym_continue] = ACTIONS(5867),
    [anon_sym_CONTINUE] = ACTIONS(5867),
    [anon_sym_Continue] = ACTIONS(5867),
    [anon_sym_break] = ACTIONS(5867),
    [anon_sym_BREAK] = ACTIONS(5867),
    [anon_sym_Break] = ACTIONS(5867),
    [anon_sym_with] = ACTIONS(5867),
    [anon_sym_WITH] = ACTIONS(5867),
    [anon_sym_With] = ACTIONS(5867),
    [sym_asserterror_keyword] = ACTIONS(5869),
    [sym_page_keyword] = ACTIONS(5867),
    [anon_sym_codeunit] = ACTIONS(5867),
    [anon_sym_CODEUNIT] = ACTIONS(5867),
    [anon_sym_Codeunit] = ACTIONS(5867),
    [anon_sym_CodeUnit] = ACTIONS(5867),
    [anon_sym_COdeunit] = ACTIONS(5867),
    [anon_sym_codeUnit] = ACTIONS(5867),
    [sym_report_keyword] = ACTIONS(5867),
    [sym_query_keyword] = ACTIONS(5867),
    [anon_sym_xmlport] = ACTIONS(5867),
    [anon_sym_XMLPORT] = ACTIONS(5867),
    [anon_sym_Xmlport] = ACTIONS(5867),
    [anon_sym_XMLport] = ACTIONS(5867),
    [anon_sym_XMLPort] = ACTIONS(5867),
    [anon_sym_XmlPort] = ACTIONS(5867),
    [anon_sym_enum] = ACTIONS(5867),
    [anon_sym_ENUM] = ACTIONS(5867),
    [anon_sym_Enum] = ACTIONS(5867),
    [anon_sym_eNUM] = ACTIONS(5867),
    [anon_sym_eNum] = ACTIONS(5867),
    [anon_sym_ENum] = ACTIONS(5867),
    [sym_quoted_identifier] = ACTIONS(5869),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5869),
    [sym_verbatim_string] = ACTIONS(5869),
    [sym_integer] = ACTIONS(5867),
    [sym_continue_as_identifier] = ACTIONS(5869),
    [sym_preproc_open] = ACTIONS(5869),
    [sym_end_keyword] = ACTIONS(5869),
  },
  [STATE(3385)] = {
    [sym_boolean] = STATE(8303),
    [sym_option_member] = STATE(8341),
    [sym_keyword_identifier] = STATE(8303),
    [sym_codeunit_keyword] = STATE(8241),
    [sym_xmlport_keyword] = STATE(8241),
    [sym_enum_keyword] = STATE(8241),
    [sym_keyword_as_identifier] = STATE(8303),
    [sym_identifier] = ACTIONS(7217),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(7351),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [aux_sym_where_condition_token1] = ACTIONS(7225),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7229),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [aux_sym_basic_type_token53] = ACTIONS(7225),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7225),
    [aux_sym_separator_action_token1] = ACTIONS(7225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7225),
    [aux_sym_type_declaration_token1] = ACTIONS(7225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7227),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [anon_sym_to] = ACTIONS(613),
    [anon_sym_TO] = ACTIONS(613),
    [anon_sym_To] = ACTIONS(613),
    [anon_sym_downto] = ACTIONS(613),
    [anon_sym_DOWNTO] = ACTIONS(613),
    [anon_sym_Downto] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(7225),
    [sym_page_keyword] = ACTIONS(7227),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(7227),
    [sym_query_keyword] = ACTIONS(7227),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_local_keyword] = ACTIONS(7217),
    [sym_internal_keyword] = ACTIONS(7217),
    [sym_protected_keyword] = ACTIONS(7217),
    [sym_key_keyword] = ACTIONS(7225),
    [sym_dataset_keyword] = ACTIONS(7225),
    [sym_quoted_identifier] = ACTIONS(7237),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7237),
    [sym_integer] = ACTIONS(7237),
  },
  [STATE(3386)] = {
    [sym_identifier] = ACTIONS(5871),
    [anon_sym_SEMI] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [aux_sym_boolean_token1] = ACTIONS(5871),
    [aux_sym_boolean_token2] = ACTIONS(5871),
    [sym_decimal] = ACTIONS(5871),
    [anon_sym_LPAREN] = ACTIONS(5873),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5871),
    [anon_sym_LBRACK] = ACTIONS(5873),
    [aux_sym_record_type_token1] = ACTIONS(5871),
    [aux_sym_basic_type_token21] = ACTIONS(5871),
    [aux_sym_basic_type_token22] = ACTIONS(5871),
    [aux_sym_basic_type_token48] = ACTIONS(5871),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5871),
    [anon_sym_POUNDif] = ACTIONS(5873),
    [anon_sym_POUNDIF] = ACTIONS(5873),
    [anon_sym_POUNDIf] = ACTIONS(5873),
    [anon_sym_not] = ACTIONS(5871),
    [anon_sym_NOT] = ACTIONS(5871),
    [anon_sym_Not] = ACTIONS(5871),
    [anon_sym_POUNDelse] = ACTIONS(5873),
    [anon_sym_POUNDELSE] = ACTIONS(5873),
    [anon_sym_POUNDElse] = ACTIONS(5873),
    [anon_sym_POUNDelse2] = ACTIONS(5873),
    [anon_sym_POUNDELSE2] = ACTIONS(5873),
    [anon_sym_POUNDElse2] = ACTIONS(5873),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5871),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5871),
    [anon_sym_PLUS] = ACTIONS(5873),
    [sym_datetime_literal] = ACTIONS(5873),
    [sym_date_literal] = ACTIONS(5871),
    [sym_time_literal] = ACTIONS(5871),
    [sym_biginteger_literal] = ACTIONS(5873),
    [anon_sym_if] = ACTIONS(5871),
    [anon_sym_IF] = ACTIONS(5871),
    [anon_sym_If] = ACTIONS(5871),
    [anon_sym_else] = ACTIONS(5871),
    [anon_sym_ELSE] = ACTIONS(5871),
    [anon_sym_Else] = ACTIONS(5871),
    [anon_sym_case] = ACTIONS(5871),
    [anon_sym_CASE] = ACTIONS(5871),
    [anon_sym_Case] = ACTIONS(5871),
    [anon_sym_for] = ACTIONS(5871),
    [anon_sym_FOR] = ACTIONS(5871),
    [anon_sym_For] = ACTIONS(5871),
    [anon_sym_foreach] = ACTIONS(5871),
    [anon_sym_FOREACH] = ACTIONS(5871),
    [anon_sym_Foreach] = ACTIONS(5871),
    [anon_sym_while] = ACTIONS(5871),
    [anon_sym_WHILE] = ACTIONS(5871),
    [anon_sym_While] = ACTIONS(5871),
    [anon_sym_repeat] = ACTIONS(5871),
    [anon_sym_REPEAT] = ACTIONS(5871),
    [anon_sym_Repeat] = ACTIONS(5871),
    [anon_sym_exit] = ACTIONS(5871),
    [anon_sym_EXIT] = ACTIONS(5871),
    [anon_sym_Exit] = ACTIONS(5871),
    [anon_sym_continue] = ACTIONS(5871),
    [anon_sym_CONTINUE] = ACTIONS(5871),
    [anon_sym_Continue] = ACTIONS(5871),
    [anon_sym_break] = ACTIONS(5871),
    [anon_sym_BREAK] = ACTIONS(5871),
    [anon_sym_Break] = ACTIONS(5871),
    [anon_sym_with] = ACTIONS(5871),
    [anon_sym_WITH] = ACTIONS(5871),
    [anon_sym_With] = ACTIONS(5871),
    [sym_asserterror_keyword] = ACTIONS(5873),
    [sym_page_keyword] = ACTIONS(5871),
    [anon_sym_codeunit] = ACTIONS(5871),
    [anon_sym_CODEUNIT] = ACTIONS(5871),
    [anon_sym_Codeunit] = ACTIONS(5871),
    [anon_sym_CodeUnit] = ACTIONS(5871),
    [anon_sym_COdeunit] = ACTIONS(5871),
    [anon_sym_codeUnit] = ACTIONS(5871),
    [sym_report_keyword] = ACTIONS(5871),
    [sym_query_keyword] = ACTIONS(5871),
    [anon_sym_xmlport] = ACTIONS(5871),
    [anon_sym_XMLPORT] = ACTIONS(5871),
    [anon_sym_Xmlport] = ACTIONS(5871),
    [anon_sym_XMLport] = ACTIONS(5871),
    [anon_sym_XMLPort] = ACTIONS(5871),
    [anon_sym_XmlPort] = ACTIONS(5871),
    [anon_sym_enum] = ACTIONS(5871),
    [anon_sym_ENUM] = ACTIONS(5871),
    [anon_sym_Enum] = ACTIONS(5871),
    [anon_sym_eNUM] = ACTIONS(5871),
    [anon_sym_eNum] = ACTIONS(5871),
    [anon_sym_ENum] = ACTIONS(5871),
    [sym_quoted_identifier] = ACTIONS(5873),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5873),
    [sym_verbatim_string] = ACTIONS(5873),
    [sym_integer] = ACTIONS(5871),
    [sym_continue_as_identifier] = ACTIONS(5873),
    [sym_preproc_open] = ACTIONS(5873),
    [sym_end_keyword] = ACTIONS(5873),
  },
  [STATE(3387)] = {
    [sym_identifier] = ACTIONS(5953),
    [anon_sym_SEMI] = ACTIONS(5955),
    [anon_sym_DASH] = ACTIONS(5955),
    [aux_sym_boolean_token1] = ACTIONS(5953),
    [aux_sym_boolean_token2] = ACTIONS(5953),
    [sym_decimal] = ACTIONS(5953),
    [anon_sym_LPAREN] = ACTIONS(5955),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5953),
    [anon_sym_LBRACK] = ACTIONS(5955),
    [aux_sym_record_type_token1] = ACTIONS(5953),
    [aux_sym_basic_type_token21] = ACTIONS(5953),
    [aux_sym_basic_type_token22] = ACTIONS(5953),
    [aux_sym_basic_type_token48] = ACTIONS(5953),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5953),
    [anon_sym_POUNDif] = ACTIONS(5955),
    [anon_sym_POUNDIF] = ACTIONS(5955),
    [anon_sym_POUNDIf] = ACTIONS(5955),
    [anon_sym_not] = ACTIONS(5953),
    [anon_sym_NOT] = ACTIONS(5953),
    [anon_sym_Not] = ACTIONS(5953),
    [anon_sym_POUNDelse] = ACTIONS(5955),
    [anon_sym_POUNDELSE] = ACTIONS(5955),
    [anon_sym_POUNDElse] = ACTIONS(5955),
    [anon_sym_POUNDelse2] = ACTIONS(5955),
    [anon_sym_POUNDELSE2] = ACTIONS(5955),
    [anon_sym_POUNDElse2] = ACTIONS(5955),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5953),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5953),
    [anon_sym_PLUS] = ACTIONS(5955),
    [sym_datetime_literal] = ACTIONS(5955),
    [sym_date_literal] = ACTIONS(5953),
    [sym_time_literal] = ACTIONS(5953),
    [sym_biginteger_literal] = ACTIONS(5955),
    [anon_sym_if] = ACTIONS(5953),
    [anon_sym_IF] = ACTIONS(5953),
    [anon_sym_If] = ACTIONS(5953),
    [anon_sym_else] = ACTIONS(5953),
    [anon_sym_ELSE] = ACTIONS(5953),
    [anon_sym_Else] = ACTIONS(5953),
    [anon_sym_case] = ACTIONS(5953),
    [anon_sym_CASE] = ACTIONS(5953),
    [anon_sym_Case] = ACTIONS(5953),
    [anon_sym_for] = ACTIONS(5953),
    [anon_sym_FOR] = ACTIONS(5953),
    [anon_sym_For] = ACTIONS(5953),
    [anon_sym_foreach] = ACTIONS(5953),
    [anon_sym_FOREACH] = ACTIONS(5953),
    [anon_sym_Foreach] = ACTIONS(5953),
    [anon_sym_while] = ACTIONS(5953),
    [anon_sym_WHILE] = ACTIONS(5953),
    [anon_sym_While] = ACTIONS(5953),
    [anon_sym_repeat] = ACTIONS(5953),
    [anon_sym_REPEAT] = ACTIONS(5953),
    [anon_sym_Repeat] = ACTIONS(5953),
    [anon_sym_exit] = ACTIONS(5953),
    [anon_sym_EXIT] = ACTIONS(5953),
    [anon_sym_Exit] = ACTIONS(5953),
    [anon_sym_continue] = ACTIONS(5953),
    [anon_sym_CONTINUE] = ACTIONS(5953),
    [anon_sym_Continue] = ACTIONS(5953),
    [anon_sym_break] = ACTIONS(5953),
    [anon_sym_BREAK] = ACTIONS(5953),
    [anon_sym_Break] = ACTIONS(5953),
    [anon_sym_with] = ACTIONS(5953),
    [anon_sym_WITH] = ACTIONS(5953),
    [anon_sym_With] = ACTIONS(5953),
    [sym_asserterror_keyword] = ACTIONS(5955),
    [sym_page_keyword] = ACTIONS(5953),
    [anon_sym_codeunit] = ACTIONS(5953),
    [anon_sym_CODEUNIT] = ACTIONS(5953),
    [anon_sym_Codeunit] = ACTIONS(5953),
    [anon_sym_CodeUnit] = ACTIONS(5953),
    [anon_sym_COdeunit] = ACTIONS(5953),
    [anon_sym_codeUnit] = ACTIONS(5953),
    [sym_report_keyword] = ACTIONS(5953),
    [sym_query_keyword] = ACTIONS(5953),
    [anon_sym_xmlport] = ACTIONS(5953),
    [anon_sym_XMLPORT] = ACTIONS(5953),
    [anon_sym_Xmlport] = ACTIONS(5953),
    [anon_sym_XMLport] = ACTIONS(5953),
    [anon_sym_XMLPort] = ACTIONS(5953),
    [anon_sym_XmlPort] = ACTIONS(5953),
    [anon_sym_enum] = ACTIONS(5953),
    [anon_sym_ENUM] = ACTIONS(5953),
    [anon_sym_Enum] = ACTIONS(5953),
    [anon_sym_eNUM] = ACTIONS(5953),
    [anon_sym_eNum] = ACTIONS(5953),
    [anon_sym_ENum] = ACTIONS(5953),
    [sym_quoted_identifier] = ACTIONS(5955),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5955),
    [sym_verbatim_string] = ACTIONS(5955),
    [sym_integer] = ACTIONS(5953),
    [sym_continue_as_identifier] = ACTIONS(5955),
    [sym_preproc_open] = ACTIONS(5955),
    [sym_end_keyword] = ACTIONS(5955),
  },
  [STATE(3388)] = {
    [sym_identifier] = ACTIONS(5553),
    [anon_sym_SEMI] = ACTIONS(5555),
    [anon_sym_DASH] = ACTIONS(5555),
    [aux_sym_boolean_token1] = ACTIONS(5553),
    [aux_sym_boolean_token2] = ACTIONS(5553),
    [sym_decimal] = ACTIONS(5553),
    [anon_sym_LPAREN] = ACTIONS(5555),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5553),
    [anon_sym_LBRACK] = ACTIONS(5555),
    [aux_sym_record_type_token1] = ACTIONS(5553),
    [aux_sym_basic_type_token21] = ACTIONS(5553),
    [aux_sym_basic_type_token22] = ACTIONS(5553),
    [aux_sym_basic_type_token48] = ACTIONS(5553),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5553),
    [anon_sym_POUNDif] = ACTIONS(5555),
    [anon_sym_POUNDIF] = ACTIONS(5555),
    [anon_sym_POUNDIf] = ACTIONS(5555),
    [anon_sym_not] = ACTIONS(5553),
    [anon_sym_NOT] = ACTIONS(5553),
    [anon_sym_Not] = ACTIONS(5553),
    [anon_sym_POUNDelse] = ACTIONS(5555),
    [anon_sym_POUNDELSE] = ACTIONS(5555),
    [anon_sym_POUNDElse] = ACTIONS(5555),
    [anon_sym_POUNDelse2] = ACTIONS(5555),
    [anon_sym_POUNDELSE2] = ACTIONS(5555),
    [anon_sym_POUNDElse2] = ACTIONS(5555),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5553),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5553),
    [anon_sym_PLUS] = ACTIONS(5555),
    [sym_datetime_literal] = ACTIONS(5555),
    [sym_date_literal] = ACTIONS(5553),
    [sym_time_literal] = ACTIONS(5553),
    [sym_biginteger_literal] = ACTIONS(5555),
    [anon_sym_if] = ACTIONS(5553),
    [anon_sym_IF] = ACTIONS(5553),
    [anon_sym_If] = ACTIONS(5553),
    [anon_sym_else] = ACTIONS(5553),
    [anon_sym_ELSE] = ACTIONS(5553),
    [anon_sym_Else] = ACTIONS(5553),
    [anon_sym_case] = ACTIONS(5553),
    [anon_sym_CASE] = ACTIONS(5553),
    [anon_sym_Case] = ACTIONS(5553),
    [anon_sym_for] = ACTIONS(5553),
    [anon_sym_FOR] = ACTIONS(5553),
    [anon_sym_For] = ACTIONS(5553),
    [anon_sym_foreach] = ACTIONS(5553),
    [anon_sym_FOREACH] = ACTIONS(5553),
    [anon_sym_Foreach] = ACTIONS(5553),
    [anon_sym_while] = ACTIONS(5553),
    [anon_sym_WHILE] = ACTIONS(5553),
    [anon_sym_While] = ACTIONS(5553),
    [anon_sym_repeat] = ACTIONS(5553),
    [anon_sym_REPEAT] = ACTIONS(5553),
    [anon_sym_Repeat] = ACTIONS(5553),
    [anon_sym_exit] = ACTIONS(5553),
    [anon_sym_EXIT] = ACTIONS(5553),
    [anon_sym_Exit] = ACTIONS(5553),
    [anon_sym_continue] = ACTIONS(5553),
    [anon_sym_CONTINUE] = ACTIONS(5553),
    [anon_sym_Continue] = ACTIONS(5553),
    [anon_sym_break] = ACTIONS(5553),
    [anon_sym_BREAK] = ACTIONS(5553),
    [anon_sym_Break] = ACTIONS(5553),
    [anon_sym_with] = ACTIONS(5553),
    [anon_sym_WITH] = ACTIONS(5553),
    [anon_sym_With] = ACTIONS(5553),
    [sym_asserterror_keyword] = ACTIONS(5555),
    [sym_page_keyword] = ACTIONS(5553),
    [anon_sym_codeunit] = ACTIONS(5553),
    [anon_sym_CODEUNIT] = ACTIONS(5553),
    [anon_sym_Codeunit] = ACTIONS(5553),
    [anon_sym_CodeUnit] = ACTIONS(5553),
    [anon_sym_COdeunit] = ACTIONS(5553),
    [anon_sym_codeUnit] = ACTIONS(5553),
    [sym_report_keyword] = ACTIONS(5553),
    [sym_query_keyword] = ACTIONS(5553),
    [anon_sym_xmlport] = ACTIONS(5553),
    [anon_sym_XMLPORT] = ACTIONS(5553),
    [anon_sym_Xmlport] = ACTIONS(5553),
    [anon_sym_XMLport] = ACTIONS(5553),
    [anon_sym_XMLPort] = ACTIONS(5553),
    [anon_sym_XmlPort] = ACTIONS(5553),
    [anon_sym_enum] = ACTIONS(5553),
    [anon_sym_ENUM] = ACTIONS(5553),
    [anon_sym_Enum] = ACTIONS(5553),
    [anon_sym_eNUM] = ACTIONS(5553),
    [anon_sym_eNum] = ACTIONS(5553),
    [anon_sym_ENum] = ACTIONS(5553),
    [sym_quoted_identifier] = ACTIONS(5555),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5555),
    [sym_verbatim_string] = ACTIONS(5555),
    [sym_integer] = ACTIONS(5553),
    [sym_continue_as_identifier] = ACTIONS(5555),
    [sym_preproc_open] = ACTIONS(5555),
    [sym_end_keyword] = ACTIONS(5555),
  },
  [STATE(3389)] = {
    [sym_identifier] = ACTIONS(6090),
    [anon_sym_SEMI] = ACTIONS(6092),
    [anon_sym_DASH] = ACTIONS(6092),
    [aux_sym_boolean_token1] = ACTIONS(6090),
    [aux_sym_boolean_token2] = ACTIONS(6090),
    [sym_decimal] = ACTIONS(6090),
    [anon_sym_LPAREN] = ACTIONS(6092),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6090),
    [anon_sym_LBRACK] = ACTIONS(6092),
    [aux_sym_record_type_token1] = ACTIONS(6090),
    [aux_sym_basic_type_token21] = ACTIONS(6090),
    [aux_sym_basic_type_token22] = ACTIONS(6090),
    [aux_sym_basic_type_token48] = ACTIONS(6090),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6090),
    [anon_sym_POUNDif] = ACTIONS(6092),
    [anon_sym_POUNDIF] = ACTIONS(6092),
    [anon_sym_POUNDIf] = ACTIONS(6092),
    [anon_sym_not] = ACTIONS(6090),
    [anon_sym_NOT] = ACTIONS(6090),
    [anon_sym_Not] = ACTIONS(6090),
    [anon_sym_POUNDelse] = ACTIONS(6092),
    [anon_sym_POUNDELSE] = ACTIONS(6092),
    [anon_sym_POUNDElse] = ACTIONS(6092),
    [anon_sym_POUNDelse2] = ACTIONS(6092),
    [anon_sym_POUNDELSE2] = ACTIONS(6092),
    [anon_sym_POUNDElse2] = ACTIONS(6092),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6090),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6090),
    [anon_sym_PLUS] = ACTIONS(6092),
    [sym_datetime_literal] = ACTIONS(6092),
    [sym_date_literal] = ACTIONS(6090),
    [sym_time_literal] = ACTIONS(6090),
    [sym_biginteger_literal] = ACTIONS(6092),
    [anon_sym_if] = ACTIONS(6090),
    [anon_sym_IF] = ACTIONS(6090),
    [anon_sym_If] = ACTIONS(6090),
    [anon_sym_else] = ACTIONS(6090),
    [anon_sym_ELSE] = ACTIONS(6090),
    [anon_sym_Else] = ACTIONS(6090),
    [anon_sym_case] = ACTIONS(6090),
    [anon_sym_CASE] = ACTIONS(6090),
    [anon_sym_Case] = ACTIONS(6090),
    [anon_sym_for] = ACTIONS(6090),
    [anon_sym_FOR] = ACTIONS(6090),
    [anon_sym_For] = ACTIONS(6090),
    [anon_sym_foreach] = ACTIONS(6090),
    [anon_sym_FOREACH] = ACTIONS(6090),
    [anon_sym_Foreach] = ACTIONS(6090),
    [anon_sym_while] = ACTIONS(6090),
    [anon_sym_WHILE] = ACTIONS(6090),
    [anon_sym_While] = ACTIONS(6090),
    [anon_sym_repeat] = ACTIONS(6090),
    [anon_sym_REPEAT] = ACTIONS(6090),
    [anon_sym_Repeat] = ACTIONS(6090),
    [anon_sym_exit] = ACTIONS(6090),
    [anon_sym_EXIT] = ACTIONS(6090),
    [anon_sym_Exit] = ACTIONS(6090),
    [anon_sym_continue] = ACTIONS(6090),
    [anon_sym_CONTINUE] = ACTIONS(6090),
    [anon_sym_Continue] = ACTIONS(6090),
    [anon_sym_break] = ACTIONS(6090),
    [anon_sym_BREAK] = ACTIONS(6090),
    [anon_sym_Break] = ACTIONS(6090),
    [anon_sym_with] = ACTIONS(6090),
    [anon_sym_WITH] = ACTIONS(6090),
    [anon_sym_With] = ACTIONS(6090),
    [sym_asserterror_keyword] = ACTIONS(6092),
    [sym_page_keyword] = ACTIONS(6090),
    [anon_sym_codeunit] = ACTIONS(6090),
    [anon_sym_CODEUNIT] = ACTIONS(6090),
    [anon_sym_Codeunit] = ACTIONS(6090),
    [anon_sym_CodeUnit] = ACTIONS(6090),
    [anon_sym_COdeunit] = ACTIONS(6090),
    [anon_sym_codeUnit] = ACTIONS(6090),
    [sym_report_keyword] = ACTIONS(6090),
    [sym_query_keyword] = ACTIONS(6090),
    [anon_sym_xmlport] = ACTIONS(6090),
    [anon_sym_XMLPORT] = ACTIONS(6090),
    [anon_sym_Xmlport] = ACTIONS(6090),
    [anon_sym_XMLport] = ACTIONS(6090),
    [anon_sym_XMLPort] = ACTIONS(6090),
    [anon_sym_XmlPort] = ACTIONS(6090),
    [anon_sym_enum] = ACTIONS(6090),
    [anon_sym_ENUM] = ACTIONS(6090),
    [anon_sym_Enum] = ACTIONS(6090),
    [anon_sym_eNUM] = ACTIONS(6090),
    [anon_sym_eNum] = ACTIONS(6090),
    [anon_sym_ENum] = ACTIONS(6090),
    [sym_quoted_identifier] = ACTIONS(6092),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6092),
    [sym_verbatim_string] = ACTIONS(6092),
    [sym_integer] = ACTIONS(6090),
    [sym_continue_as_identifier] = ACTIONS(6092),
    [sym_preproc_open] = ACTIONS(6092),
    [sym_end_keyword] = ACTIONS(6092),
  },
  [STATE(3390)] = {
    [sym_identifier] = ACTIONS(5980),
    [anon_sym_SEMI] = ACTIONS(5982),
    [anon_sym_DASH] = ACTIONS(5982),
    [aux_sym_boolean_token1] = ACTIONS(5980),
    [aux_sym_boolean_token2] = ACTIONS(5980),
    [sym_decimal] = ACTIONS(5980),
    [anon_sym_LPAREN] = ACTIONS(5982),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5980),
    [anon_sym_LBRACK] = ACTIONS(5982),
    [aux_sym_record_type_token1] = ACTIONS(5980),
    [aux_sym_basic_type_token21] = ACTIONS(5980),
    [aux_sym_basic_type_token22] = ACTIONS(5980),
    [aux_sym_basic_type_token48] = ACTIONS(5980),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5980),
    [anon_sym_POUNDif] = ACTIONS(5982),
    [anon_sym_POUNDIF] = ACTIONS(5982),
    [anon_sym_POUNDIf] = ACTIONS(5982),
    [anon_sym_not] = ACTIONS(5980),
    [anon_sym_NOT] = ACTIONS(5980),
    [anon_sym_Not] = ACTIONS(5980),
    [anon_sym_POUNDelse] = ACTIONS(5982),
    [anon_sym_POUNDELSE] = ACTIONS(5982),
    [anon_sym_POUNDElse] = ACTIONS(5982),
    [anon_sym_POUNDelse2] = ACTIONS(5982),
    [anon_sym_POUNDELSE2] = ACTIONS(5982),
    [anon_sym_POUNDElse2] = ACTIONS(5982),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5980),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5980),
    [anon_sym_PLUS] = ACTIONS(5982),
    [sym_datetime_literal] = ACTIONS(5982),
    [sym_date_literal] = ACTIONS(5980),
    [sym_time_literal] = ACTIONS(5980),
    [sym_biginteger_literal] = ACTIONS(5982),
    [anon_sym_if] = ACTIONS(5980),
    [anon_sym_IF] = ACTIONS(5980),
    [anon_sym_If] = ACTIONS(5980),
    [anon_sym_else] = ACTIONS(5980),
    [anon_sym_ELSE] = ACTIONS(5980),
    [anon_sym_Else] = ACTIONS(5980),
    [anon_sym_case] = ACTIONS(5980),
    [anon_sym_CASE] = ACTIONS(5980),
    [anon_sym_Case] = ACTIONS(5980),
    [anon_sym_for] = ACTIONS(5980),
    [anon_sym_FOR] = ACTIONS(5980),
    [anon_sym_For] = ACTIONS(5980),
    [anon_sym_foreach] = ACTIONS(5980),
    [anon_sym_FOREACH] = ACTIONS(5980),
    [anon_sym_Foreach] = ACTIONS(5980),
    [anon_sym_while] = ACTIONS(5980),
    [anon_sym_WHILE] = ACTIONS(5980),
    [anon_sym_While] = ACTIONS(5980),
    [anon_sym_repeat] = ACTIONS(5980),
    [anon_sym_REPEAT] = ACTIONS(5980),
    [anon_sym_Repeat] = ACTIONS(5980),
    [anon_sym_exit] = ACTIONS(5980),
    [anon_sym_EXIT] = ACTIONS(5980),
    [anon_sym_Exit] = ACTIONS(5980),
    [anon_sym_continue] = ACTIONS(5980),
    [anon_sym_CONTINUE] = ACTIONS(5980),
    [anon_sym_Continue] = ACTIONS(5980),
    [anon_sym_break] = ACTIONS(5980),
    [anon_sym_BREAK] = ACTIONS(5980),
    [anon_sym_Break] = ACTIONS(5980),
    [anon_sym_with] = ACTIONS(5980),
    [anon_sym_WITH] = ACTIONS(5980),
    [anon_sym_With] = ACTIONS(5980),
    [sym_asserterror_keyword] = ACTIONS(5982),
    [sym_page_keyword] = ACTIONS(5980),
    [anon_sym_codeunit] = ACTIONS(5980),
    [anon_sym_CODEUNIT] = ACTIONS(5980),
    [anon_sym_Codeunit] = ACTIONS(5980),
    [anon_sym_CodeUnit] = ACTIONS(5980),
    [anon_sym_COdeunit] = ACTIONS(5980),
    [anon_sym_codeUnit] = ACTIONS(5980),
    [sym_report_keyword] = ACTIONS(5980),
    [sym_query_keyword] = ACTIONS(5980),
    [anon_sym_xmlport] = ACTIONS(5980),
    [anon_sym_XMLPORT] = ACTIONS(5980),
    [anon_sym_Xmlport] = ACTIONS(5980),
    [anon_sym_XMLport] = ACTIONS(5980),
    [anon_sym_XMLPort] = ACTIONS(5980),
    [anon_sym_XmlPort] = ACTIONS(5980),
    [anon_sym_enum] = ACTIONS(5980),
    [anon_sym_ENUM] = ACTIONS(5980),
    [anon_sym_Enum] = ACTIONS(5980),
    [anon_sym_eNUM] = ACTIONS(5980),
    [anon_sym_eNum] = ACTIONS(5980),
    [anon_sym_ENum] = ACTIONS(5980),
    [sym_quoted_identifier] = ACTIONS(5982),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5982),
    [sym_verbatim_string] = ACTIONS(5982),
    [sym_integer] = ACTIONS(5980),
    [sym_continue_as_identifier] = ACTIONS(5982),
    [sym_preproc_open] = ACTIONS(5982),
    [sym_end_keyword] = ACTIONS(5982),
  },
  [STATE(3391)] = {
    [sym_boolean] = STATE(2717),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_endif] = STATE(3693),
    [sym_assignment_expression] = STATE(8840),
    [sym_case_branch] = STATE(3412),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(4801),
    [sym_case_else_branch] = STATE(14583),
    [sym__expression] = STATE(8840),
    [sym_keyword_identifier] = STATE(2518),
    [sym_range_expression] = STATE(2717),
    [sym_multiplicative_expression] = STATE(2717),
    [sym_additive_expression] = STATE(2717),
    [sym_comparison_expression] = STATE(2717),
    [sym_logical_expression] = STATE(2717),
    [sym_ternary_expression] = STATE(8840),
    [sym_unary_expression] = STATE(2717),
    [sym_call_expression] = STATE(2648),
    [sym_member_expression] = STATE(2518),
    [sym_subscript_expression] = STATE(2518),
    [sym_parenthesized_expression] = STATE(2717),
    [sym_list_literal] = STATE(8840),
    [sym_qualified_enum_value] = STATE(2518),
    [sym_database_reference] = STATE(2717),
    [sym__literal_value] = STATE(2717),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3412),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3839),
    [sym_identifier] = ACTIONS(5340),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(5342),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(5346),
    [sym_date_literal] = ACTIONS(5342),
    [sym_time_literal] = ACTIONS(5342),
    [sym_biginteger_literal] = ACTIONS(5346),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(5350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5346),
    [sym_verbatim_string] = ACTIONS(5346),
    [sym_integer] = ACTIONS(5342),
    [sym_continue_as_identifier] = ACTIONS(5352),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3392)] = {
    [sym_identifier] = ACTIONS(5875),
    [anon_sym_SEMI] = ACTIONS(5877),
    [anon_sym_DASH] = ACTIONS(5877),
    [aux_sym_boolean_token1] = ACTIONS(5875),
    [aux_sym_boolean_token2] = ACTIONS(5875),
    [sym_decimal] = ACTIONS(5875),
    [anon_sym_LPAREN] = ACTIONS(5877),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5875),
    [anon_sym_LBRACK] = ACTIONS(5877),
    [aux_sym_record_type_token1] = ACTIONS(5875),
    [aux_sym_basic_type_token21] = ACTIONS(5875),
    [aux_sym_basic_type_token22] = ACTIONS(5875),
    [aux_sym_basic_type_token48] = ACTIONS(5875),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5875),
    [anon_sym_POUNDif] = ACTIONS(5877),
    [anon_sym_POUNDIF] = ACTIONS(5877),
    [anon_sym_POUNDIf] = ACTIONS(5877),
    [anon_sym_not] = ACTIONS(5875),
    [anon_sym_NOT] = ACTIONS(5875),
    [anon_sym_Not] = ACTIONS(5875),
    [anon_sym_POUNDelse] = ACTIONS(5877),
    [anon_sym_POUNDELSE] = ACTIONS(5877),
    [anon_sym_POUNDElse] = ACTIONS(5877),
    [anon_sym_POUNDelse2] = ACTIONS(5877),
    [anon_sym_POUNDELSE2] = ACTIONS(5877),
    [anon_sym_POUNDElse2] = ACTIONS(5877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5875),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5875),
    [anon_sym_PLUS] = ACTIONS(5877),
    [sym_datetime_literal] = ACTIONS(5877),
    [sym_date_literal] = ACTIONS(5875),
    [sym_time_literal] = ACTIONS(5875),
    [sym_biginteger_literal] = ACTIONS(5877),
    [anon_sym_if] = ACTIONS(5875),
    [anon_sym_IF] = ACTIONS(5875),
    [anon_sym_If] = ACTIONS(5875),
    [anon_sym_else] = ACTIONS(5875),
    [anon_sym_ELSE] = ACTIONS(5875),
    [anon_sym_Else] = ACTIONS(5875),
    [anon_sym_case] = ACTIONS(5875),
    [anon_sym_CASE] = ACTIONS(5875),
    [anon_sym_Case] = ACTIONS(5875),
    [anon_sym_for] = ACTIONS(5875),
    [anon_sym_FOR] = ACTIONS(5875),
    [anon_sym_For] = ACTIONS(5875),
    [anon_sym_foreach] = ACTIONS(5875),
    [anon_sym_FOREACH] = ACTIONS(5875),
    [anon_sym_Foreach] = ACTIONS(5875),
    [anon_sym_while] = ACTIONS(5875),
    [anon_sym_WHILE] = ACTIONS(5875),
    [anon_sym_While] = ACTIONS(5875),
    [anon_sym_repeat] = ACTIONS(5875),
    [anon_sym_REPEAT] = ACTIONS(5875),
    [anon_sym_Repeat] = ACTIONS(5875),
    [anon_sym_exit] = ACTIONS(5875),
    [anon_sym_EXIT] = ACTIONS(5875),
    [anon_sym_Exit] = ACTIONS(5875),
    [anon_sym_continue] = ACTIONS(5875),
    [anon_sym_CONTINUE] = ACTIONS(5875),
    [anon_sym_Continue] = ACTIONS(5875),
    [anon_sym_break] = ACTIONS(5875),
    [anon_sym_BREAK] = ACTIONS(5875),
    [anon_sym_Break] = ACTIONS(5875),
    [anon_sym_with] = ACTIONS(5875),
    [anon_sym_WITH] = ACTIONS(5875),
    [anon_sym_With] = ACTIONS(5875),
    [sym_asserterror_keyword] = ACTIONS(5877),
    [sym_page_keyword] = ACTIONS(5875),
    [anon_sym_codeunit] = ACTIONS(5875),
    [anon_sym_CODEUNIT] = ACTIONS(5875),
    [anon_sym_Codeunit] = ACTIONS(5875),
    [anon_sym_CodeUnit] = ACTIONS(5875),
    [anon_sym_COdeunit] = ACTIONS(5875),
    [anon_sym_codeUnit] = ACTIONS(5875),
    [sym_report_keyword] = ACTIONS(5875),
    [sym_query_keyword] = ACTIONS(5875),
    [anon_sym_xmlport] = ACTIONS(5875),
    [anon_sym_XMLPORT] = ACTIONS(5875),
    [anon_sym_Xmlport] = ACTIONS(5875),
    [anon_sym_XMLport] = ACTIONS(5875),
    [anon_sym_XMLPort] = ACTIONS(5875),
    [anon_sym_XmlPort] = ACTIONS(5875),
    [anon_sym_enum] = ACTIONS(5875),
    [anon_sym_ENUM] = ACTIONS(5875),
    [anon_sym_Enum] = ACTIONS(5875),
    [anon_sym_eNUM] = ACTIONS(5875),
    [anon_sym_eNum] = ACTIONS(5875),
    [anon_sym_ENum] = ACTIONS(5875),
    [sym_quoted_identifier] = ACTIONS(5877),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5877),
    [sym_verbatim_string] = ACTIONS(5877),
    [sym_integer] = ACTIONS(5875),
    [sym_continue_as_identifier] = ACTIONS(5877),
    [sym_preproc_open] = ACTIONS(5877),
    [sym_end_keyword] = ACTIONS(5877),
  },
  [STATE(3393)] = {
    [sym_identifier] = ACTIONS(5879),
    [anon_sym_SEMI] = ACTIONS(5881),
    [anon_sym_DASH] = ACTIONS(5881),
    [aux_sym_boolean_token1] = ACTIONS(5879),
    [aux_sym_boolean_token2] = ACTIONS(5879),
    [sym_decimal] = ACTIONS(5879),
    [anon_sym_LPAREN] = ACTIONS(5881),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5879),
    [anon_sym_LBRACK] = ACTIONS(5881),
    [aux_sym_record_type_token1] = ACTIONS(5879),
    [aux_sym_basic_type_token21] = ACTIONS(5879),
    [aux_sym_basic_type_token22] = ACTIONS(5879),
    [aux_sym_basic_type_token48] = ACTIONS(5879),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5879),
    [anon_sym_POUNDif] = ACTIONS(5881),
    [anon_sym_POUNDIF] = ACTIONS(5881),
    [anon_sym_POUNDIf] = ACTIONS(5881),
    [anon_sym_not] = ACTIONS(5879),
    [anon_sym_NOT] = ACTIONS(5879),
    [anon_sym_Not] = ACTIONS(5879),
    [anon_sym_POUNDelse] = ACTIONS(5881),
    [anon_sym_POUNDELSE] = ACTIONS(5881),
    [anon_sym_POUNDElse] = ACTIONS(5881),
    [anon_sym_POUNDelse2] = ACTIONS(5881),
    [anon_sym_POUNDELSE2] = ACTIONS(5881),
    [anon_sym_POUNDElse2] = ACTIONS(5881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5879),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5879),
    [anon_sym_PLUS] = ACTIONS(5881),
    [sym_datetime_literal] = ACTIONS(5881),
    [sym_date_literal] = ACTIONS(5879),
    [sym_time_literal] = ACTIONS(5879),
    [sym_biginteger_literal] = ACTIONS(5881),
    [anon_sym_if] = ACTIONS(5879),
    [anon_sym_IF] = ACTIONS(5879),
    [anon_sym_If] = ACTIONS(5879),
    [anon_sym_else] = ACTIONS(5879),
    [anon_sym_ELSE] = ACTIONS(5879),
    [anon_sym_Else] = ACTIONS(5879),
    [anon_sym_case] = ACTIONS(5879),
    [anon_sym_CASE] = ACTIONS(5879),
    [anon_sym_Case] = ACTIONS(5879),
    [anon_sym_for] = ACTIONS(5879),
    [anon_sym_FOR] = ACTIONS(5879),
    [anon_sym_For] = ACTIONS(5879),
    [anon_sym_foreach] = ACTIONS(5879),
    [anon_sym_FOREACH] = ACTIONS(5879),
    [anon_sym_Foreach] = ACTIONS(5879),
    [anon_sym_while] = ACTIONS(5879),
    [anon_sym_WHILE] = ACTIONS(5879),
    [anon_sym_While] = ACTIONS(5879),
    [anon_sym_repeat] = ACTIONS(5879),
    [anon_sym_REPEAT] = ACTIONS(5879),
    [anon_sym_Repeat] = ACTIONS(5879),
    [anon_sym_exit] = ACTIONS(5879),
    [anon_sym_EXIT] = ACTIONS(5879),
    [anon_sym_Exit] = ACTIONS(5879),
    [anon_sym_continue] = ACTIONS(5879),
    [anon_sym_CONTINUE] = ACTIONS(5879),
    [anon_sym_Continue] = ACTIONS(5879),
    [anon_sym_break] = ACTIONS(5879),
    [anon_sym_BREAK] = ACTIONS(5879),
    [anon_sym_Break] = ACTIONS(5879),
    [anon_sym_with] = ACTIONS(5879),
    [anon_sym_WITH] = ACTIONS(5879),
    [anon_sym_With] = ACTIONS(5879),
    [sym_asserterror_keyword] = ACTIONS(5881),
    [sym_page_keyword] = ACTIONS(5879),
    [anon_sym_codeunit] = ACTIONS(5879),
    [anon_sym_CODEUNIT] = ACTIONS(5879),
    [anon_sym_Codeunit] = ACTIONS(5879),
    [anon_sym_CodeUnit] = ACTIONS(5879),
    [anon_sym_COdeunit] = ACTIONS(5879),
    [anon_sym_codeUnit] = ACTIONS(5879),
    [sym_report_keyword] = ACTIONS(5879),
    [sym_query_keyword] = ACTIONS(5879),
    [anon_sym_xmlport] = ACTIONS(5879),
    [anon_sym_XMLPORT] = ACTIONS(5879),
    [anon_sym_Xmlport] = ACTIONS(5879),
    [anon_sym_XMLport] = ACTIONS(5879),
    [anon_sym_XMLPort] = ACTIONS(5879),
    [anon_sym_XmlPort] = ACTIONS(5879),
    [anon_sym_enum] = ACTIONS(5879),
    [anon_sym_ENUM] = ACTIONS(5879),
    [anon_sym_Enum] = ACTIONS(5879),
    [anon_sym_eNUM] = ACTIONS(5879),
    [anon_sym_eNum] = ACTIONS(5879),
    [anon_sym_ENum] = ACTIONS(5879),
    [sym_quoted_identifier] = ACTIONS(5881),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5881),
    [sym_verbatim_string] = ACTIONS(5881),
    [sym_integer] = ACTIONS(5879),
    [sym_continue_as_identifier] = ACTIONS(5881),
    [sym_preproc_open] = ACTIONS(5881),
    [sym_end_keyword] = ACTIONS(5881),
  },
  [STATE(3394)] = {
    [sym_identifier] = ACTIONS(5891),
    [anon_sym_SEMI] = ACTIONS(5893),
    [anon_sym_DASH] = ACTIONS(5893),
    [aux_sym_boolean_token1] = ACTIONS(5891),
    [aux_sym_boolean_token2] = ACTIONS(5891),
    [sym_decimal] = ACTIONS(5891),
    [anon_sym_LPAREN] = ACTIONS(5893),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5891),
    [anon_sym_LBRACK] = ACTIONS(5893),
    [aux_sym_record_type_token1] = ACTIONS(5891),
    [aux_sym_basic_type_token21] = ACTIONS(5891),
    [aux_sym_basic_type_token22] = ACTIONS(5891),
    [aux_sym_basic_type_token48] = ACTIONS(5891),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5891),
    [anon_sym_POUNDif] = ACTIONS(5893),
    [anon_sym_POUNDIF] = ACTIONS(5893),
    [anon_sym_POUNDIf] = ACTIONS(5893),
    [anon_sym_not] = ACTIONS(5891),
    [anon_sym_NOT] = ACTIONS(5891),
    [anon_sym_Not] = ACTIONS(5891),
    [anon_sym_POUNDelse] = ACTIONS(5893),
    [anon_sym_POUNDELSE] = ACTIONS(5893),
    [anon_sym_POUNDElse] = ACTIONS(5893),
    [anon_sym_POUNDelse2] = ACTIONS(5893),
    [anon_sym_POUNDELSE2] = ACTIONS(5893),
    [anon_sym_POUNDElse2] = ACTIONS(5893),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5891),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5891),
    [anon_sym_PLUS] = ACTIONS(5893),
    [sym_datetime_literal] = ACTIONS(5893),
    [sym_date_literal] = ACTIONS(5891),
    [sym_time_literal] = ACTIONS(5891),
    [sym_biginteger_literal] = ACTIONS(5893),
    [anon_sym_if] = ACTIONS(5891),
    [anon_sym_IF] = ACTIONS(5891),
    [anon_sym_If] = ACTIONS(5891),
    [anon_sym_else] = ACTIONS(5891),
    [anon_sym_ELSE] = ACTIONS(5891),
    [anon_sym_Else] = ACTIONS(5891),
    [anon_sym_case] = ACTIONS(5891),
    [anon_sym_CASE] = ACTIONS(5891),
    [anon_sym_Case] = ACTIONS(5891),
    [anon_sym_for] = ACTIONS(5891),
    [anon_sym_FOR] = ACTIONS(5891),
    [anon_sym_For] = ACTIONS(5891),
    [anon_sym_foreach] = ACTIONS(5891),
    [anon_sym_FOREACH] = ACTIONS(5891),
    [anon_sym_Foreach] = ACTIONS(5891),
    [anon_sym_while] = ACTIONS(5891),
    [anon_sym_WHILE] = ACTIONS(5891),
    [anon_sym_While] = ACTIONS(5891),
    [anon_sym_repeat] = ACTIONS(5891),
    [anon_sym_REPEAT] = ACTIONS(5891),
    [anon_sym_Repeat] = ACTIONS(5891),
    [anon_sym_exit] = ACTIONS(5891),
    [anon_sym_EXIT] = ACTIONS(5891),
    [anon_sym_Exit] = ACTIONS(5891),
    [anon_sym_continue] = ACTIONS(5891),
    [anon_sym_CONTINUE] = ACTIONS(5891),
    [anon_sym_Continue] = ACTIONS(5891),
    [anon_sym_break] = ACTIONS(5891),
    [anon_sym_BREAK] = ACTIONS(5891),
    [anon_sym_Break] = ACTIONS(5891),
    [anon_sym_with] = ACTIONS(5891),
    [anon_sym_WITH] = ACTIONS(5891),
    [anon_sym_With] = ACTIONS(5891),
    [sym_asserterror_keyword] = ACTIONS(5893),
    [sym_page_keyword] = ACTIONS(5891),
    [anon_sym_codeunit] = ACTIONS(5891),
    [anon_sym_CODEUNIT] = ACTIONS(5891),
    [anon_sym_Codeunit] = ACTIONS(5891),
    [anon_sym_CodeUnit] = ACTIONS(5891),
    [anon_sym_COdeunit] = ACTIONS(5891),
    [anon_sym_codeUnit] = ACTIONS(5891),
    [sym_report_keyword] = ACTIONS(5891),
    [sym_query_keyword] = ACTIONS(5891),
    [anon_sym_xmlport] = ACTIONS(5891),
    [anon_sym_XMLPORT] = ACTIONS(5891),
    [anon_sym_Xmlport] = ACTIONS(5891),
    [anon_sym_XMLport] = ACTIONS(5891),
    [anon_sym_XMLPort] = ACTIONS(5891),
    [anon_sym_XmlPort] = ACTIONS(5891),
    [anon_sym_enum] = ACTIONS(5891),
    [anon_sym_ENUM] = ACTIONS(5891),
    [anon_sym_Enum] = ACTIONS(5891),
    [anon_sym_eNUM] = ACTIONS(5891),
    [anon_sym_eNum] = ACTIONS(5891),
    [anon_sym_ENum] = ACTIONS(5891),
    [sym_quoted_identifier] = ACTIONS(5893),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5893),
    [sym_verbatim_string] = ACTIONS(5893),
    [sym_integer] = ACTIONS(5891),
    [sym_continue_as_identifier] = ACTIONS(5893),
    [sym_preproc_open] = ACTIONS(5893),
    [sym_end_keyword] = ACTIONS(5893),
  },
  [STATE(3395)] = {
    [sym_identifier] = ACTIONS(5895),
    [anon_sym_SEMI] = ACTIONS(5897),
    [anon_sym_DASH] = ACTIONS(5897),
    [aux_sym_boolean_token1] = ACTIONS(5895),
    [aux_sym_boolean_token2] = ACTIONS(5895),
    [sym_decimal] = ACTIONS(5895),
    [anon_sym_LPAREN] = ACTIONS(5897),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5895),
    [anon_sym_LBRACK] = ACTIONS(5897),
    [aux_sym_record_type_token1] = ACTIONS(5895),
    [aux_sym_basic_type_token21] = ACTIONS(5895),
    [aux_sym_basic_type_token22] = ACTIONS(5895),
    [aux_sym_basic_type_token48] = ACTIONS(5895),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5895),
    [anon_sym_POUNDif] = ACTIONS(5897),
    [anon_sym_POUNDIF] = ACTIONS(5897),
    [anon_sym_POUNDIf] = ACTIONS(5897),
    [anon_sym_not] = ACTIONS(5895),
    [anon_sym_NOT] = ACTIONS(5895),
    [anon_sym_Not] = ACTIONS(5895),
    [anon_sym_POUNDelse] = ACTIONS(5897),
    [anon_sym_POUNDELSE] = ACTIONS(5897),
    [anon_sym_POUNDElse] = ACTIONS(5897),
    [anon_sym_POUNDelse2] = ACTIONS(5897),
    [anon_sym_POUNDELSE2] = ACTIONS(5897),
    [anon_sym_POUNDElse2] = ACTIONS(5897),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5895),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5895),
    [anon_sym_PLUS] = ACTIONS(5897),
    [sym_datetime_literal] = ACTIONS(5897),
    [sym_date_literal] = ACTIONS(5895),
    [sym_time_literal] = ACTIONS(5895),
    [sym_biginteger_literal] = ACTIONS(5897),
    [anon_sym_if] = ACTIONS(5895),
    [anon_sym_IF] = ACTIONS(5895),
    [anon_sym_If] = ACTIONS(5895),
    [anon_sym_else] = ACTIONS(5895),
    [anon_sym_ELSE] = ACTIONS(5895),
    [anon_sym_Else] = ACTIONS(5895),
    [anon_sym_case] = ACTIONS(5895),
    [anon_sym_CASE] = ACTIONS(5895),
    [anon_sym_Case] = ACTIONS(5895),
    [anon_sym_for] = ACTIONS(5895),
    [anon_sym_FOR] = ACTIONS(5895),
    [anon_sym_For] = ACTIONS(5895),
    [anon_sym_foreach] = ACTIONS(5895),
    [anon_sym_FOREACH] = ACTIONS(5895),
    [anon_sym_Foreach] = ACTIONS(5895),
    [anon_sym_while] = ACTIONS(5895),
    [anon_sym_WHILE] = ACTIONS(5895),
    [anon_sym_While] = ACTIONS(5895),
    [anon_sym_repeat] = ACTIONS(5895),
    [anon_sym_REPEAT] = ACTIONS(5895),
    [anon_sym_Repeat] = ACTIONS(5895),
    [anon_sym_exit] = ACTIONS(5895),
    [anon_sym_EXIT] = ACTIONS(5895),
    [anon_sym_Exit] = ACTIONS(5895),
    [anon_sym_continue] = ACTIONS(5895),
    [anon_sym_CONTINUE] = ACTIONS(5895),
    [anon_sym_Continue] = ACTIONS(5895),
    [anon_sym_break] = ACTIONS(5895),
    [anon_sym_BREAK] = ACTIONS(5895),
    [anon_sym_Break] = ACTIONS(5895),
    [anon_sym_with] = ACTIONS(5895),
    [anon_sym_WITH] = ACTIONS(5895),
    [anon_sym_With] = ACTIONS(5895),
    [sym_asserterror_keyword] = ACTIONS(5897),
    [sym_page_keyword] = ACTIONS(5895),
    [anon_sym_codeunit] = ACTIONS(5895),
    [anon_sym_CODEUNIT] = ACTIONS(5895),
    [anon_sym_Codeunit] = ACTIONS(5895),
    [anon_sym_CodeUnit] = ACTIONS(5895),
    [anon_sym_COdeunit] = ACTIONS(5895),
    [anon_sym_codeUnit] = ACTIONS(5895),
    [sym_report_keyword] = ACTIONS(5895),
    [sym_query_keyword] = ACTIONS(5895),
    [anon_sym_xmlport] = ACTIONS(5895),
    [anon_sym_XMLPORT] = ACTIONS(5895),
    [anon_sym_Xmlport] = ACTIONS(5895),
    [anon_sym_XMLport] = ACTIONS(5895),
    [anon_sym_XMLPort] = ACTIONS(5895),
    [anon_sym_XmlPort] = ACTIONS(5895),
    [anon_sym_enum] = ACTIONS(5895),
    [anon_sym_ENUM] = ACTIONS(5895),
    [anon_sym_Enum] = ACTIONS(5895),
    [anon_sym_eNUM] = ACTIONS(5895),
    [anon_sym_eNum] = ACTIONS(5895),
    [anon_sym_ENum] = ACTIONS(5895),
    [sym_quoted_identifier] = ACTIONS(5897),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5897),
    [sym_verbatim_string] = ACTIONS(5897),
    [sym_integer] = ACTIONS(5895),
    [sym_continue_as_identifier] = ACTIONS(5897),
    [sym_preproc_open] = ACTIONS(5897),
    [sym_end_keyword] = ACTIONS(5897),
  },
  [STATE(3396)] = {
    [sym_identifier] = ACTIONS(5923),
    [anon_sym_SEMI] = ACTIONS(5925),
    [anon_sym_DASH] = ACTIONS(5925),
    [aux_sym_boolean_token1] = ACTIONS(5923),
    [aux_sym_boolean_token2] = ACTIONS(5923),
    [sym_decimal] = ACTIONS(5923),
    [anon_sym_LPAREN] = ACTIONS(5925),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5923),
    [anon_sym_LBRACK] = ACTIONS(5925),
    [aux_sym_record_type_token1] = ACTIONS(5923),
    [aux_sym_basic_type_token21] = ACTIONS(5923),
    [aux_sym_basic_type_token22] = ACTIONS(5923),
    [aux_sym_basic_type_token48] = ACTIONS(5923),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5923),
    [anon_sym_POUNDif] = ACTIONS(5925),
    [anon_sym_POUNDIF] = ACTIONS(5925),
    [anon_sym_POUNDIf] = ACTIONS(5925),
    [anon_sym_not] = ACTIONS(5923),
    [anon_sym_NOT] = ACTIONS(5923),
    [anon_sym_Not] = ACTIONS(5923),
    [anon_sym_POUNDelse] = ACTIONS(5925),
    [anon_sym_POUNDELSE] = ACTIONS(5925),
    [anon_sym_POUNDElse] = ACTIONS(5925),
    [anon_sym_POUNDelse2] = ACTIONS(5925),
    [anon_sym_POUNDELSE2] = ACTIONS(5925),
    [anon_sym_POUNDElse2] = ACTIONS(5925),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5923),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5923),
    [anon_sym_PLUS] = ACTIONS(5925),
    [sym_datetime_literal] = ACTIONS(5925),
    [sym_date_literal] = ACTIONS(5923),
    [sym_time_literal] = ACTIONS(5923),
    [sym_biginteger_literal] = ACTIONS(5925),
    [anon_sym_if] = ACTIONS(5923),
    [anon_sym_IF] = ACTIONS(5923),
    [anon_sym_If] = ACTIONS(5923),
    [anon_sym_else] = ACTIONS(5923),
    [anon_sym_ELSE] = ACTIONS(5923),
    [anon_sym_Else] = ACTIONS(5923),
    [anon_sym_case] = ACTIONS(5923),
    [anon_sym_CASE] = ACTIONS(5923),
    [anon_sym_Case] = ACTIONS(5923),
    [anon_sym_for] = ACTIONS(5923),
    [anon_sym_FOR] = ACTIONS(5923),
    [anon_sym_For] = ACTIONS(5923),
    [anon_sym_foreach] = ACTIONS(5923),
    [anon_sym_FOREACH] = ACTIONS(5923),
    [anon_sym_Foreach] = ACTIONS(5923),
    [anon_sym_while] = ACTIONS(5923),
    [anon_sym_WHILE] = ACTIONS(5923),
    [anon_sym_While] = ACTIONS(5923),
    [anon_sym_repeat] = ACTIONS(5923),
    [anon_sym_REPEAT] = ACTIONS(5923),
    [anon_sym_Repeat] = ACTIONS(5923),
    [anon_sym_exit] = ACTIONS(5923),
    [anon_sym_EXIT] = ACTIONS(5923),
    [anon_sym_Exit] = ACTIONS(5923),
    [anon_sym_continue] = ACTIONS(5923),
    [anon_sym_CONTINUE] = ACTIONS(5923),
    [anon_sym_Continue] = ACTIONS(5923),
    [anon_sym_break] = ACTIONS(5923),
    [anon_sym_BREAK] = ACTIONS(5923),
    [anon_sym_Break] = ACTIONS(5923),
    [anon_sym_with] = ACTIONS(5923),
    [anon_sym_WITH] = ACTIONS(5923),
    [anon_sym_With] = ACTIONS(5923),
    [sym_asserterror_keyword] = ACTIONS(5925),
    [sym_page_keyword] = ACTIONS(5923),
    [anon_sym_codeunit] = ACTIONS(5923),
    [anon_sym_CODEUNIT] = ACTIONS(5923),
    [anon_sym_Codeunit] = ACTIONS(5923),
    [anon_sym_CodeUnit] = ACTIONS(5923),
    [anon_sym_COdeunit] = ACTIONS(5923),
    [anon_sym_codeUnit] = ACTIONS(5923),
    [sym_report_keyword] = ACTIONS(5923),
    [sym_query_keyword] = ACTIONS(5923),
    [anon_sym_xmlport] = ACTIONS(5923),
    [anon_sym_XMLPORT] = ACTIONS(5923),
    [anon_sym_Xmlport] = ACTIONS(5923),
    [anon_sym_XMLport] = ACTIONS(5923),
    [anon_sym_XMLPort] = ACTIONS(5923),
    [anon_sym_XmlPort] = ACTIONS(5923),
    [anon_sym_enum] = ACTIONS(5923),
    [anon_sym_ENUM] = ACTIONS(5923),
    [anon_sym_Enum] = ACTIONS(5923),
    [anon_sym_eNUM] = ACTIONS(5923),
    [anon_sym_eNum] = ACTIONS(5923),
    [anon_sym_ENum] = ACTIONS(5923),
    [sym_quoted_identifier] = ACTIONS(5925),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5925),
    [sym_verbatim_string] = ACTIONS(5925),
    [sym_integer] = ACTIONS(5923),
    [sym_continue_as_identifier] = ACTIONS(5925),
    [sym_preproc_open] = ACTIONS(5925),
    [sym_end_keyword] = ACTIONS(5925),
  },
  [STATE(3397)] = {
    [sym_identifier] = ACTIONS(6054),
    [anon_sym_SEMI] = ACTIONS(6056),
    [anon_sym_DASH] = ACTIONS(6056),
    [aux_sym_boolean_token1] = ACTIONS(6054),
    [aux_sym_boolean_token2] = ACTIONS(6054),
    [sym_decimal] = ACTIONS(6054),
    [anon_sym_LPAREN] = ACTIONS(6056),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6054),
    [anon_sym_LBRACK] = ACTIONS(6056),
    [aux_sym_record_type_token1] = ACTIONS(6054),
    [aux_sym_basic_type_token21] = ACTIONS(6054),
    [aux_sym_basic_type_token22] = ACTIONS(6054),
    [aux_sym_basic_type_token48] = ACTIONS(6054),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6054),
    [anon_sym_POUNDif] = ACTIONS(6056),
    [anon_sym_POUNDIF] = ACTIONS(6056),
    [anon_sym_POUNDIf] = ACTIONS(6056),
    [anon_sym_not] = ACTIONS(6054),
    [anon_sym_NOT] = ACTIONS(6054),
    [anon_sym_Not] = ACTIONS(6054),
    [anon_sym_POUNDelse] = ACTIONS(6056),
    [anon_sym_POUNDELSE] = ACTIONS(6056),
    [anon_sym_POUNDElse] = ACTIONS(6056),
    [anon_sym_POUNDelse2] = ACTIONS(6056),
    [anon_sym_POUNDELSE2] = ACTIONS(6056),
    [anon_sym_POUNDElse2] = ACTIONS(6056),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6054),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6054),
    [anon_sym_PLUS] = ACTIONS(6056),
    [sym_datetime_literal] = ACTIONS(6056),
    [sym_date_literal] = ACTIONS(6054),
    [sym_time_literal] = ACTIONS(6054),
    [sym_biginteger_literal] = ACTIONS(6056),
    [anon_sym_if] = ACTIONS(6054),
    [anon_sym_IF] = ACTIONS(6054),
    [anon_sym_If] = ACTIONS(6054),
    [anon_sym_else] = ACTIONS(6054),
    [anon_sym_ELSE] = ACTIONS(6054),
    [anon_sym_Else] = ACTIONS(6054),
    [anon_sym_case] = ACTIONS(6054),
    [anon_sym_CASE] = ACTIONS(6054),
    [anon_sym_Case] = ACTIONS(6054),
    [anon_sym_for] = ACTIONS(6054),
    [anon_sym_FOR] = ACTIONS(6054),
    [anon_sym_For] = ACTIONS(6054),
    [anon_sym_foreach] = ACTIONS(6054),
    [anon_sym_FOREACH] = ACTIONS(6054),
    [anon_sym_Foreach] = ACTIONS(6054),
    [anon_sym_while] = ACTIONS(6054),
    [anon_sym_WHILE] = ACTIONS(6054),
    [anon_sym_While] = ACTIONS(6054),
    [anon_sym_repeat] = ACTIONS(6054),
    [anon_sym_REPEAT] = ACTIONS(6054),
    [anon_sym_Repeat] = ACTIONS(6054),
    [anon_sym_exit] = ACTIONS(6054),
    [anon_sym_EXIT] = ACTIONS(6054),
    [anon_sym_Exit] = ACTIONS(6054),
    [anon_sym_continue] = ACTIONS(6054),
    [anon_sym_CONTINUE] = ACTIONS(6054),
    [anon_sym_Continue] = ACTIONS(6054),
    [anon_sym_break] = ACTIONS(6054),
    [anon_sym_BREAK] = ACTIONS(6054),
    [anon_sym_Break] = ACTIONS(6054),
    [anon_sym_with] = ACTIONS(6054),
    [anon_sym_WITH] = ACTIONS(6054),
    [anon_sym_With] = ACTIONS(6054),
    [sym_asserterror_keyword] = ACTIONS(6056),
    [sym_page_keyword] = ACTIONS(6054),
    [anon_sym_codeunit] = ACTIONS(6054),
    [anon_sym_CODEUNIT] = ACTIONS(6054),
    [anon_sym_Codeunit] = ACTIONS(6054),
    [anon_sym_CodeUnit] = ACTIONS(6054),
    [anon_sym_COdeunit] = ACTIONS(6054),
    [anon_sym_codeUnit] = ACTIONS(6054),
    [sym_report_keyword] = ACTIONS(6054),
    [sym_query_keyword] = ACTIONS(6054),
    [anon_sym_xmlport] = ACTIONS(6054),
    [anon_sym_XMLPORT] = ACTIONS(6054),
    [anon_sym_Xmlport] = ACTIONS(6054),
    [anon_sym_XMLport] = ACTIONS(6054),
    [anon_sym_XMLPort] = ACTIONS(6054),
    [anon_sym_XmlPort] = ACTIONS(6054),
    [anon_sym_enum] = ACTIONS(6054),
    [anon_sym_ENUM] = ACTIONS(6054),
    [anon_sym_Enum] = ACTIONS(6054),
    [anon_sym_eNUM] = ACTIONS(6054),
    [anon_sym_eNum] = ACTIONS(6054),
    [anon_sym_ENum] = ACTIONS(6054),
    [sym_quoted_identifier] = ACTIONS(6056),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6056),
    [sym_verbatim_string] = ACTIONS(6056),
    [sym_integer] = ACTIONS(6054),
    [sym_continue_as_identifier] = ACTIONS(6056),
    [sym_preproc_open] = ACTIONS(6056),
    [sym_end_keyword] = ACTIONS(6056),
  },
  [STATE(3398)] = {
    [sym_identifier] = ACTIONS(5557),
    [anon_sym_SEMI] = ACTIONS(5559),
    [anon_sym_DASH] = ACTIONS(5559),
    [aux_sym_boolean_token1] = ACTIONS(5557),
    [aux_sym_boolean_token2] = ACTIONS(5557),
    [sym_decimal] = ACTIONS(5557),
    [anon_sym_LPAREN] = ACTIONS(5559),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5557),
    [anon_sym_LBRACK] = ACTIONS(5559),
    [aux_sym_record_type_token1] = ACTIONS(5557),
    [aux_sym_basic_type_token21] = ACTIONS(5557),
    [aux_sym_basic_type_token22] = ACTIONS(5557),
    [aux_sym_basic_type_token48] = ACTIONS(5557),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5557),
    [anon_sym_POUNDif] = ACTIONS(5559),
    [anon_sym_POUNDIF] = ACTIONS(5559),
    [anon_sym_POUNDIf] = ACTIONS(5559),
    [anon_sym_not] = ACTIONS(5557),
    [anon_sym_NOT] = ACTIONS(5557),
    [anon_sym_Not] = ACTIONS(5557),
    [anon_sym_POUNDelse] = ACTIONS(5559),
    [anon_sym_POUNDELSE] = ACTIONS(5559),
    [anon_sym_POUNDElse] = ACTIONS(5559),
    [anon_sym_POUNDelse2] = ACTIONS(5559),
    [anon_sym_POUNDELSE2] = ACTIONS(5559),
    [anon_sym_POUNDElse2] = ACTIONS(5559),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5557),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5557),
    [anon_sym_PLUS] = ACTIONS(5559),
    [sym_datetime_literal] = ACTIONS(5559),
    [sym_date_literal] = ACTIONS(5557),
    [sym_time_literal] = ACTIONS(5557),
    [sym_biginteger_literal] = ACTIONS(5559),
    [anon_sym_if] = ACTIONS(5557),
    [anon_sym_IF] = ACTIONS(5557),
    [anon_sym_If] = ACTIONS(5557),
    [anon_sym_else] = ACTIONS(5557),
    [anon_sym_ELSE] = ACTIONS(5557),
    [anon_sym_Else] = ACTIONS(5557),
    [anon_sym_case] = ACTIONS(5557),
    [anon_sym_CASE] = ACTIONS(5557),
    [anon_sym_Case] = ACTIONS(5557),
    [anon_sym_for] = ACTIONS(5557),
    [anon_sym_FOR] = ACTIONS(5557),
    [anon_sym_For] = ACTIONS(5557),
    [anon_sym_foreach] = ACTIONS(5557),
    [anon_sym_FOREACH] = ACTIONS(5557),
    [anon_sym_Foreach] = ACTIONS(5557),
    [anon_sym_while] = ACTIONS(5557),
    [anon_sym_WHILE] = ACTIONS(5557),
    [anon_sym_While] = ACTIONS(5557),
    [anon_sym_repeat] = ACTIONS(5557),
    [anon_sym_REPEAT] = ACTIONS(5557),
    [anon_sym_Repeat] = ACTIONS(5557),
    [anon_sym_exit] = ACTIONS(5557),
    [anon_sym_EXIT] = ACTIONS(5557),
    [anon_sym_Exit] = ACTIONS(5557),
    [anon_sym_continue] = ACTIONS(5557),
    [anon_sym_CONTINUE] = ACTIONS(5557),
    [anon_sym_Continue] = ACTIONS(5557),
    [anon_sym_break] = ACTIONS(5557),
    [anon_sym_BREAK] = ACTIONS(5557),
    [anon_sym_Break] = ACTIONS(5557),
    [anon_sym_with] = ACTIONS(5557),
    [anon_sym_WITH] = ACTIONS(5557),
    [anon_sym_With] = ACTIONS(5557),
    [sym_asserterror_keyword] = ACTIONS(5559),
    [sym_page_keyword] = ACTIONS(5557),
    [anon_sym_codeunit] = ACTIONS(5557),
    [anon_sym_CODEUNIT] = ACTIONS(5557),
    [anon_sym_Codeunit] = ACTIONS(5557),
    [anon_sym_CodeUnit] = ACTIONS(5557),
    [anon_sym_COdeunit] = ACTIONS(5557),
    [anon_sym_codeUnit] = ACTIONS(5557),
    [sym_report_keyword] = ACTIONS(5557),
    [sym_query_keyword] = ACTIONS(5557),
    [anon_sym_xmlport] = ACTIONS(5557),
    [anon_sym_XMLPORT] = ACTIONS(5557),
    [anon_sym_Xmlport] = ACTIONS(5557),
    [anon_sym_XMLport] = ACTIONS(5557),
    [anon_sym_XMLPort] = ACTIONS(5557),
    [anon_sym_XmlPort] = ACTIONS(5557),
    [anon_sym_enum] = ACTIONS(5557),
    [anon_sym_ENUM] = ACTIONS(5557),
    [anon_sym_Enum] = ACTIONS(5557),
    [anon_sym_eNUM] = ACTIONS(5557),
    [anon_sym_eNum] = ACTIONS(5557),
    [anon_sym_ENum] = ACTIONS(5557),
    [sym_quoted_identifier] = ACTIONS(5559),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5559),
    [sym_verbatim_string] = ACTIONS(5559),
    [sym_integer] = ACTIONS(5557),
    [sym_continue_as_identifier] = ACTIONS(5559),
    [sym_preproc_open] = ACTIONS(5559),
    [sym_end_keyword] = ACTIONS(5559),
  },
  [STATE(3399)] = {
    [sym_identifier] = ACTIONS(6054),
    [anon_sym_SEMI] = ACTIONS(6056),
    [anon_sym_DASH] = ACTIONS(6056),
    [aux_sym_boolean_token1] = ACTIONS(6054),
    [aux_sym_boolean_token2] = ACTIONS(6054),
    [sym_decimal] = ACTIONS(6054),
    [anon_sym_LPAREN] = ACTIONS(6056),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6054),
    [anon_sym_LBRACK] = ACTIONS(6056),
    [aux_sym_record_type_token1] = ACTIONS(6054),
    [aux_sym_basic_type_token21] = ACTIONS(6054),
    [aux_sym_basic_type_token22] = ACTIONS(6054),
    [aux_sym_basic_type_token48] = ACTIONS(6054),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6054),
    [anon_sym_POUNDif] = ACTIONS(6056),
    [anon_sym_POUNDIF] = ACTIONS(6056),
    [anon_sym_POUNDIf] = ACTIONS(6056),
    [anon_sym_not] = ACTIONS(6054),
    [anon_sym_NOT] = ACTIONS(6054),
    [anon_sym_Not] = ACTIONS(6054),
    [anon_sym_POUNDelse] = ACTIONS(6056),
    [anon_sym_POUNDELSE] = ACTIONS(6056),
    [anon_sym_POUNDElse] = ACTIONS(6056),
    [anon_sym_POUNDelse2] = ACTIONS(6056),
    [anon_sym_POUNDELSE2] = ACTIONS(6056),
    [anon_sym_POUNDElse2] = ACTIONS(6056),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6054),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6054),
    [anon_sym_PLUS] = ACTIONS(6056),
    [sym_datetime_literal] = ACTIONS(6056),
    [sym_date_literal] = ACTIONS(6054),
    [sym_time_literal] = ACTIONS(6054),
    [sym_biginteger_literal] = ACTIONS(6056),
    [anon_sym_if] = ACTIONS(6054),
    [anon_sym_IF] = ACTIONS(6054),
    [anon_sym_If] = ACTIONS(6054),
    [anon_sym_else] = ACTIONS(6054),
    [anon_sym_ELSE] = ACTIONS(6054),
    [anon_sym_Else] = ACTIONS(6054),
    [anon_sym_case] = ACTIONS(6054),
    [anon_sym_CASE] = ACTIONS(6054),
    [anon_sym_Case] = ACTIONS(6054),
    [anon_sym_for] = ACTIONS(6054),
    [anon_sym_FOR] = ACTIONS(6054),
    [anon_sym_For] = ACTIONS(6054),
    [anon_sym_foreach] = ACTIONS(6054),
    [anon_sym_FOREACH] = ACTIONS(6054),
    [anon_sym_Foreach] = ACTIONS(6054),
    [anon_sym_while] = ACTIONS(6054),
    [anon_sym_WHILE] = ACTIONS(6054),
    [anon_sym_While] = ACTIONS(6054),
    [anon_sym_repeat] = ACTIONS(6054),
    [anon_sym_REPEAT] = ACTIONS(6054),
    [anon_sym_Repeat] = ACTIONS(6054),
    [anon_sym_exit] = ACTIONS(6054),
    [anon_sym_EXIT] = ACTIONS(6054),
    [anon_sym_Exit] = ACTIONS(6054),
    [anon_sym_continue] = ACTIONS(6054),
    [anon_sym_CONTINUE] = ACTIONS(6054),
    [anon_sym_Continue] = ACTIONS(6054),
    [anon_sym_break] = ACTIONS(6054),
    [anon_sym_BREAK] = ACTIONS(6054),
    [anon_sym_Break] = ACTIONS(6054),
    [anon_sym_with] = ACTIONS(6054),
    [anon_sym_WITH] = ACTIONS(6054),
    [anon_sym_With] = ACTIONS(6054),
    [sym_asserterror_keyword] = ACTIONS(6056),
    [sym_page_keyword] = ACTIONS(6054),
    [anon_sym_codeunit] = ACTIONS(6054),
    [anon_sym_CODEUNIT] = ACTIONS(6054),
    [anon_sym_Codeunit] = ACTIONS(6054),
    [anon_sym_CodeUnit] = ACTIONS(6054),
    [anon_sym_COdeunit] = ACTIONS(6054),
    [anon_sym_codeUnit] = ACTIONS(6054),
    [sym_report_keyword] = ACTIONS(6054),
    [sym_query_keyword] = ACTIONS(6054),
    [anon_sym_xmlport] = ACTIONS(6054),
    [anon_sym_XMLPORT] = ACTIONS(6054),
    [anon_sym_Xmlport] = ACTIONS(6054),
    [anon_sym_XMLport] = ACTIONS(6054),
    [anon_sym_XMLPort] = ACTIONS(6054),
    [anon_sym_XmlPort] = ACTIONS(6054),
    [anon_sym_enum] = ACTIONS(6054),
    [anon_sym_ENUM] = ACTIONS(6054),
    [anon_sym_Enum] = ACTIONS(6054),
    [anon_sym_eNUM] = ACTIONS(6054),
    [anon_sym_eNum] = ACTIONS(6054),
    [anon_sym_ENum] = ACTIONS(6054),
    [sym_quoted_identifier] = ACTIONS(6056),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6056),
    [sym_verbatim_string] = ACTIONS(6056),
    [sym_integer] = ACTIONS(6054),
    [sym_continue_as_identifier] = ACTIONS(6056),
    [sym_preproc_open] = ACTIONS(6056),
    [sym_end_keyword] = ACTIONS(6056),
  },
  [STATE(3400)] = {
    [sym_identifier] = ACTIONS(5561),
    [anon_sym_SEMI] = ACTIONS(5563),
    [anon_sym_DASH] = ACTIONS(5563),
    [aux_sym_boolean_token1] = ACTIONS(5561),
    [aux_sym_boolean_token2] = ACTIONS(5561),
    [sym_decimal] = ACTIONS(5561),
    [anon_sym_LPAREN] = ACTIONS(5563),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5561),
    [anon_sym_LBRACK] = ACTIONS(5563),
    [aux_sym_record_type_token1] = ACTIONS(5561),
    [aux_sym_basic_type_token21] = ACTIONS(5561),
    [aux_sym_basic_type_token22] = ACTIONS(5561),
    [aux_sym_basic_type_token48] = ACTIONS(5561),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5561),
    [anon_sym_POUNDif] = ACTIONS(5563),
    [anon_sym_POUNDIF] = ACTIONS(5563),
    [anon_sym_POUNDIf] = ACTIONS(5563),
    [anon_sym_not] = ACTIONS(5561),
    [anon_sym_NOT] = ACTIONS(5561),
    [anon_sym_Not] = ACTIONS(5561),
    [anon_sym_POUNDelse] = ACTIONS(5563),
    [anon_sym_POUNDELSE] = ACTIONS(5563),
    [anon_sym_POUNDElse] = ACTIONS(5563),
    [anon_sym_POUNDelse2] = ACTIONS(5563),
    [anon_sym_POUNDELSE2] = ACTIONS(5563),
    [anon_sym_POUNDElse2] = ACTIONS(5563),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5561),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5561),
    [anon_sym_PLUS] = ACTIONS(5563),
    [sym_datetime_literal] = ACTIONS(5563),
    [sym_date_literal] = ACTIONS(5561),
    [sym_time_literal] = ACTIONS(5561),
    [sym_biginteger_literal] = ACTIONS(5563),
    [anon_sym_if] = ACTIONS(5561),
    [anon_sym_IF] = ACTIONS(5561),
    [anon_sym_If] = ACTIONS(5561),
    [anon_sym_else] = ACTIONS(5561),
    [anon_sym_ELSE] = ACTIONS(5561),
    [anon_sym_Else] = ACTIONS(5561),
    [anon_sym_case] = ACTIONS(5561),
    [anon_sym_CASE] = ACTIONS(5561),
    [anon_sym_Case] = ACTIONS(5561),
    [anon_sym_for] = ACTIONS(5561),
    [anon_sym_FOR] = ACTIONS(5561),
    [anon_sym_For] = ACTIONS(5561),
    [anon_sym_foreach] = ACTIONS(5561),
    [anon_sym_FOREACH] = ACTIONS(5561),
    [anon_sym_Foreach] = ACTIONS(5561),
    [anon_sym_while] = ACTIONS(5561),
    [anon_sym_WHILE] = ACTIONS(5561),
    [anon_sym_While] = ACTIONS(5561),
    [anon_sym_repeat] = ACTIONS(5561),
    [anon_sym_REPEAT] = ACTIONS(5561),
    [anon_sym_Repeat] = ACTIONS(5561),
    [anon_sym_exit] = ACTIONS(5561),
    [anon_sym_EXIT] = ACTIONS(5561),
    [anon_sym_Exit] = ACTIONS(5561),
    [anon_sym_continue] = ACTIONS(5561),
    [anon_sym_CONTINUE] = ACTIONS(5561),
    [anon_sym_Continue] = ACTIONS(5561),
    [anon_sym_break] = ACTIONS(5561),
    [anon_sym_BREAK] = ACTIONS(5561),
    [anon_sym_Break] = ACTIONS(5561),
    [anon_sym_with] = ACTIONS(5561),
    [anon_sym_WITH] = ACTIONS(5561),
    [anon_sym_With] = ACTIONS(5561),
    [sym_asserterror_keyword] = ACTIONS(5563),
    [sym_page_keyword] = ACTIONS(5561),
    [anon_sym_codeunit] = ACTIONS(5561),
    [anon_sym_CODEUNIT] = ACTIONS(5561),
    [anon_sym_Codeunit] = ACTIONS(5561),
    [anon_sym_CodeUnit] = ACTIONS(5561),
    [anon_sym_COdeunit] = ACTIONS(5561),
    [anon_sym_codeUnit] = ACTIONS(5561),
    [sym_report_keyword] = ACTIONS(5561),
    [sym_query_keyword] = ACTIONS(5561),
    [anon_sym_xmlport] = ACTIONS(5561),
    [anon_sym_XMLPORT] = ACTIONS(5561),
    [anon_sym_Xmlport] = ACTIONS(5561),
    [anon_sym_XMLport] = ACTIONS(5561),
    [anon_sym_XMLPort] = ACTIONS(5561),
    [anon_sym_XmlPort] = ACTIONS(5561),
    [anon_sym_enum] = ACTIONS(5561),
    [anon_sym_ENUM] = ACTIONS(5561),
    [anon_sym_Enum] = ACTIONS(5561),
    [anon_sym_eNUM] = ACTIONS(5561),
    [anon_sym_eNum] = ACTIONS(5561),
    [anon_sym_ENum] = ACTIONS(5561),
    [sym_quoted_identifier] = ACTIONS(5563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5563),
    [sym_verbatim_string] = ACTIONS(5563),
    [sym_integer] = ACTIONS(5561),
    [sym_continue_as_identifier] = ACTIONS(5563),
    [sym_preproc_open] = ACTIONS(5563),
    [sym_end_keyword] = ACTIONS(5563),
  },
  [STATE(3401)] = {
    [sym_identifier] = ACTIONS(5883),
    [anon_sym_SEMI] = ACTIONS(5885),
    [anon_sym_DASH] = ACTIONS(5885),
    [aux_sym_boolean_token1] = ACTIONS(5883),
    [aux_sym_boolean_token2] = ACTIONS(5883),
    [sym_decimal] = ACTIONS(5883),
    [anon_sym_LPAREN] = ACTIONS(5885),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5883),
    [anon_sym_LBRACK] = ACTIONS(5885),
    [aux_sym_record_type_token1] = ACTIONS(5883),
    [aux_sym_basic_type_token21] = ACTIONS(5883),
    [aux_sym_basic_type_token22] = ACTIONS(5883),
    [aux_sym_basic_type_token48] = ACTIONS(5883),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5883),
    [anon_sym_POUNDif] = ACTIONS(5885),
    [anon_sym_POUNDIF] = ACTIONS(5885),
    [anon_sym_POUNDIf] = ACTIONS(5885),
    [anon_sym_not] = ACTIONS(5883),
    [anon_sym_NOT] = ACTIONS(5883),
    [anon_sym_Not] = ACTIONS(5883),
    [anon_sym_POUNDelse] = ACTIONS(5885),
    [anon_sym_POUNDELSE] = ACTIONS(5885),
    [anon_sym_POUNDElse] = ACTIONS(5885),
    [anon_sym_POUNDelse2] = ACTIONS(5885),
    [anon_sym_POUNDELSE2] = ACTIONS(5885),
    [anon_sym_POUNDElse2] = ACTIONS(5885),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5883),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5883),
    [anon_sym_PLUS] = ACTIONS(5885),
    [sym_datetime_literal] = ACTIONS(5885),
    [sym_date_literal] = ACTIONS(5883),
    [sym_time_literal] = ACTIONS(5883),
    [sym_biginteger_literal] = ACTIONS(5885),
    [anon_sym_if] = ACTIONS(5883),
    [anon_sym_IF] = ACTIONS(5883),
    [anon_sym_If] = ACTIONS(5883),
    [anon_sym_else] = ACTIONS(5883),
    [anon_sym_ELSE] = ACTIONS(5883),
    [anon_sym_Else] = ACTIONS(5883),
    [anon_sym_case] = ACTIONS(5883),
    [anon_sym_CASE] = ACTIONS(5883),
    [anon_sym_Case] = ACTIONS(5883),
    [anon_sym_for] = ACTIONS(5883),
    [anon_sym_FOR] = ACTIONS(5883),
    [anon_sym_For] = ACTIONS(5883),
    [anon_sym_foreach] = ACTIONS(5883),
    [anon_sym_FOREACH] = ACTIONS(5883),
    [anon_sym_Foreach] = ACTIONS(5883),
    [anon_sym_while] = ACTIONS(5883),
    [anon_sym_WHILE] = ACTIONS(5883),
    [anon_sym_While] = ACTIONS(5883),
    [anon_sym_repeat] = ACTIONS(5883),
    [anon_sym_REPEAT] = ACTIONS(5883),
    [anon_sym_Repeat] = ACTIONS(5883),
    [anon_sym_exit] = ACTIONS(5883),
    [anon_sym_EXIT] = ACTIONS(5883),
    [anon_sym_Exit] = ACTIONS(5883),
    [anon_sym_continue] = ACTIONS(5883),
    [anon_sym_CONTINUE] = ACTIONS(5883),
    [anon_sym_Continue] = ACTIONS(5883),
    [anon_sym_break] = ACTIONS(5883),
    [anon_sym_BREAK] = ACTIONS(5883),
    [anon_sym_Break] = ACTIONS(5883),
    [anon_sym_with] = ACTIONS(5883),
    [anon_sym_WITH] = ACTIONS(5883),
    [anon_sym_With] = ACTIONS(5883),
    [sym_asserterror_keyword] = ACTIONS(5885),
    [sym_page_keyword] = ACTIONS(5883),
    [anon_sym_codeunit] = ACTIONS(5883),
    [anon_sym_CODEUNIT] = ACTIONS(5883),
    [anon_sym_Codeunit] = ACTIONS(5883),
    [anon_sym_CodeUnit] = ACTIONS(5883),
    [anon_sym_COdeunit] = ACTIONS(5883),
    [anon_sym_codeUnit] = ACTIONS(5883),
    [sym_report_keyword] = ACTIONS(5883),
    [sym_query_keyword] = ACTIONS(5883),
    [anon_sym_xmlport] = ACTIONS(5883),
    [anon_sym_XMLPORT] = ACTIONS(5883),
    [anon_sym_Xmlport] = ACTIONS(5883),
    [anon_sym_XMLport] = ACTIONS(5883),
    [anon_sym_XMLPort] = ACTIONS(5883),
    [anon_sym_XmlPort] = ACTIONS(5883),
    [anon_sym_enum] = ACTIONS(5883),
    [anon_sym_ENUM] = ACTIONS(5883),
    [anon_sym_Enum] = ACTIONS(5883),
    [anon_sym_eNUM] = ACTIONS(5883),
    [anon_sym_eNum] = ACTIONS(5883),
    [anon_sym_ENum] = ACTIONS(5883),
    [sym_quoted_identifier] = ACTIONS(5885),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5885),
    [sym_verbatim_string] = ACTIONS(5885),
    [sym_integer] = ACTIONS(5883),
    [sym_continue_as_identifier] = ACTIONS(5885),
    [sym_preproc_open] = ACTIONS(5885),
    [sym_end_keyword] = ACTIONS(5885),
  },
  [STATE(3402)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(7354),
    [anon_sym_DASH] = ACTIONS(6122),
    [aux_sym_boolean_token1] = ACTIONS(6118),
    [aux_sym_boolean_token2] = ACTIONS(6118),
    [sym_decimal] = ACTIONS(6118),
    [anon_sym_LPAREN] = ACTIONS(6122),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_record_type_token1] = ACTIONS(6118),
    [aux_sym_basic_type_token21] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token48] = ACTIONS(6118),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_not] = ACTIONS(6118),
    [anon_sym_NOT] = ACTIONS(6118),
    [anon_sym_Not] = ACTIONS(6118),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6118),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6118),
    [anon_sym_PLUS] = ACTIONS(6122),
    [sym_datetime_literal] = ACTIONS(6122),
    [sym_date_literal] = ACTIONS(6118),
    [sym_time_literal] = ACTIONS(6118),
    [sym_biginteger_literal] = ACTIONS(6122),
    [anon_sym_if] = ACTIONS(6118),
    [anon_sym_IF] = ACTIONS(6118),
    [anon_sym_If] = ACTIONS(6118),
    [anon_sym_else] = ACTIONS(6118),
    [anon_sym_ELSE] = ACTIONS(6118),
    [anon_sym_Else] = ACTIONS(6118),
    [anon_sym_case] = ACTIONS(6118),
    [anon_sym_CASE] = ACTIONS(6118),
    [anon_sym_Case] = ACTIONS(6118),
    [anon_sym_for] = ACTIONS(6118),
    [anon_sym_FOR] = ACTIONS(6118),
    [anon_sym_For] = ACTIONS(6118),
    [anon_sym_foreach] = ACTIONS(6118),
    [anon_sym_FOREACH] = ACTIONS(6118),
    [anon_sym_Foreach] = ACTIONS(6118),
    [anon_sym_while] = ACTIONS(6118),
    [anon_sym_WHILE] = ACTIONS(6118),
    [anon_sym_While] = ACTIONS(6118),
    [anon_sym_repeat] = ACTIONS(6118),
    [anon_sym_REPEAT] = ACTIONS(6118),
    [anon_sym_Repeat] = ACTIONS(6118),
    [anon_sym_exit] = ACTIONS(6118),
    [anon_sym_EXIT] = ACTIONS(6118),
    [anon_sym_Exit] = ACTIONS(6118),
    [anon_sym_continue] = ACTIONS(6118),
    [anon_sym_CONTINUE] = ACTIONS(6118),
    [anon_sym_Continue] = ACTIONS(6118),
    [anon_sym_break] = ACTIONS(6118),
    [anon_sym_BREAK] = ACTIONS(6118),
    [anon_sym_Break] = ACTIONS(6118),
    [anon_sym_with] = ACTIONS(6118),
    [anon_sym_WITH] = ACTIONS(6118),
    [anon_sym_With] = ACTIONS(6118),
    [sym_asserterror_keyword] = ACTIONS(6122),
    [sym_page_keyword] = ACTIONS(6118),
    [anon_sym_codeunit] = ACTIONS(6118),
    [anon_sym_CODEUNIT] = ACTIONS(6118),
    [anon_sym_Codeunit] = ACTIONS(6118),
    [anon_sym_CodeUnit] = ACTIONS(6118),
    [anon_sym_COdeunit] = ACTIONS(6118),
    [anon_sym_codeUnit] = ACTIONS(6118),
    [sym_report_keyword] = ACTIONS(6118),
    [sym_query_keyword] = ACTIONS(6118),
    [anon_sym_xmlport] = ACTIONS(6118),
    [anon_sym_XMLPORT] = ACTIONS(6118),
    [anon_sym_Xmlport] = ACTIONS(6118),
    [anon_sym_XMLport] = ACTIONS(6118),
    [anon_sym_XMLPort] = ACTIONS(6118),
    [anon_sym_XmlPort] = ACTIONS(6118),
    [anon_sym_enum] = ACTIONS(6118),
    [anon_sym_ENUM] = ACTIONS(6118),
    [anon_sym_Enum] = ACTIONS(6118),
    [anon_sym_eNUM] = ACTIONS(6118),
    [anon_sym_eNum] = ACTIONS(6118),
    [anon_sym_ENum] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6122),
    [sym_verbatim_string] = ACTIONS(6122),
    [sym_integer] = ACTIONS(6118),
    [sym_continue_as_identifier] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_end_keyword] = ACTIONS(6122),
  },
  [STATE(3403)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(6122),
    [anon_sym_DASH] = ACTIONS(6122),
    [aux_sym_boolean_token1] = ACTIONS(6118),
    [aux_sym_boolean_token2] = ACTIONS(6118),
    [sym_decimal] = ACTIONS(6118),
    [anon_sym_LPAREN] = ACTIONS(6122),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_record_type_token1] = ACTIONS(6118),
    [aux_sym_basic_type_token21] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token48] = ACTIONS(6118),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_not] = ACTIONS(6118),
    [anon_sym_NOT] = ACTIONS(6118),
    [anon_sym_Not] = ACTIONS(6118),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6118),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6118),
    [anon_sym_PLUS] = ACTIONS(6122),
    [sym_datetime_literal] = ACTIONS(6122),
    [sym_date_literal] = ACTIONS(6118),
    [sym_time_literal] = ACTIONS(6118),
    [sym_biginteger_literal] = ACTIONS(6122),
    [anon_sym_if] = ACTIONS(6118),
    [anon_sym_IF] = ACTIONS(6118),
    [anon_sym_If] = ACTIONS(6118),
    [anon_sym_else] = ACTIONS(6118),
    [anon_sym_ELSE] = ACTIONS(6118),
    [anon_sym_Else] = ACTIONS(6118),
    [anon_sym_case] = ACTIONS(6118),
    [anon_sym_CASE] = ACTIONS(6118),
    [anon_sym_Case] = ACTIONS(6118),
    [anon_sym_for] = ACTIONS(6118),
    [anon_sym_FOR] = ACTIONS(6118),
    [anon_sym_For] = ACTIONS(6118),
    [anon_sym_foreach] = ACTIONS(6118),
    [anon_sym_FOREACH] = ACTIONS(6118),
    [anon_sym_Foreach] = ACTIONS(6118),
    [anon_sym_while] = ACTIONS(6118),
    [anon_sym_WHILE] = ACTIONS(6118),
    [anon_sym_While] = ACTIONS(6118),
    [anon_sym_repeat] = ACTIONS(6118),
    [anon_sym_REPEAT] = ACTIONS(6118),
    [anon_sym_Repeat] = ACTIONS(6118),
    [anon_sym_exit] = ACTIONS(6118),
    [anon_sym_EXIT] = ACTIONS(6118),
    [anon_sym_Exit] = ACTIONS(6118),
    [anon_sym_continue] = ACTIONS(6118),
    [anon_sym_CONTINUE] = ACTIONS(6118),
    [anon_sym_Continue] = ACTIONS(6118),
    [anon_sym_break] = ACTIONS(6118),
    [anon_sym_BREAK] = ACTIONS(6118),
    [anon_sym_Break] = ACTIONS(6118),
    [anon_sym_with] = ACTIONS(6118),
    [anon_sym_WITH] = ACTIONS(6118),
    [anon_sym_With] = ACTIONS(6118),
    [sym_asserterror_keyword] = ACTIONS(6122),
    [sym_page_keyword] = ACTIONS(6118),
    [anon_sym_codeunit] = ACTIONS(6118),
    [anon_sym_CODEUNIT] = ACTIONS(6118),
    [anon_sym_Codeunit] = ACTIONS(6118),
    [anon_sym_CodeUnit] = ACTIONS(6118),
    [anon_sym_COdeunit] = ACTIONS(6118),
    [anon_sym_codeUnit] = ACTIONS(6118),
    [sym_report_keyword] = ACTIONS(6118),
    [sym_query_keyword] = ACTIONS(6118),
    [anon_sym_xmlport] = ACTIONS(6118),
    [anon_sym_XMLPORT] = ACTIONS(6118),
    [anon_sym_Xmlport] = ACTIONS(6118),
    [anon_sym_XMLport] = ACTIONS(6118),
    [anon_sym_XMLPort] = ACTIONS(6118),
    [anon_sym_XmlPort] = ACTIONS(6118),
    [anon_sym_enum] = ACTIONS(6118),
    [anon_sym_ENUM] = ACTIONS(6118),
    [anon_sym_Enum] = ACTIONS(6118),
    [anon_sym_eNUM] = ACTIONS(6118),
    [anon_sym_eNum] = ACTIONS(6118),
    [anon_sym_ENum] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6122),
    [sym_verbatim_string] = ACTIONS(6122),
    [sym_integer] = ACTIONS(6118),
    [sym_continue_as_identifier] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_end_keyword] = ACTIONS(6122),
  },
  [STATE(3404)] = {
    [sym_identifier] = ACTIONS(5887),
    [anon_sym_SEMI] = ACTIONS(5889),
    [anon_sym_DASH] = ACTIONS(5889),
    [aux_sym_boolean_token1] = ACTIONS(5887),
    [aux_sym_boolean_token2] = ACTIONS(5887),
    [sym_decimal] = ACTIONS(5887),
    [anon_sym_LPAREN] = ACTIONS(5889),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5887),
    [anon_sym_LBRACK] = ACTIONS(5889),
    [aux_sym_record_type_token1] = ACTIONS(5887),
    [aux_sym_basic_type_token21] = ACTIONS(5887),
    [aux_sym_basic_type_token22] = ACTIONS(5887),
    [aux_sym_basic_type_token48] = ACTIONS(5887),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5887),
    [anon_sym_POUNDif] = ACTIONS(5889),
    [anon_sym_POUNDIF] = ACTIONS(5889),
    [anon_sym_POUNDIf] = ACTIONS(5889),
    [anon_sym_not] = ACTIONS(5887),
    [anon_sym_NOT] = ACTIONS(5887),
    [anon_sym_Not] = ACTIONS(5887),
    [anon_sym_POUNDelse] = ACTIONS(5889),
    [anon_sym_POUNDELSE] = ACTIONS(5889),
    [anon_sym_POUNDElse] = ACTIONS(5889),
    [anon_sym_POUNDelse2] = ACTIONS(5889),
    [anon_sym_POUNDELSE2] = ACTIONS(5889),
    [anon_sym_POUNDElse2] = ACTIONS(5889),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5887),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5887),
    [anon_sym_PLUS] = ACTIONS(5889),
    [sym_datetime_literal] = ACTIONS(5889),
    [sym_date_literal] = ACTIONS(5887),
    [sym_time_literal] = ACTIONS(5887),
    [sym_biginteger_literal] = ACTIONS(5889),
    [anon_sym_if] = ACTIONS(5887),
    [anon_sym_IF] = ACTIONS(5887),
    [anon_sym_If] = ACTIONS(5887),
    [anon_sym_else] = ACTIONS(5887),
    [anon_sym_ELSE] = ACTIONS(5887),
    [anon_sym_Else] = ACTIONS(5887),
    [anon_sym_case] = ACTIONS(5887),
    [anon_sym_CASE] = ACTIONS(5887),
    [anon_sym_Case] = ACTIONS(5887),
    [anon_sym_for] = ACTIONS(5887),
    [anon_sym_FOR] = ACTIONS(5887),
    [anon_sym_For] = ACTIONS(5887),
    [anon_sym_foreach] = ACTIONS(5887),
    [anon_sym_FOREACH] = ACTIONS(5887),
    [anon_sym_Foreach] = ACTIONS(5887),
    [anon_sym_while] = ACTIONS(5887),
    [anon_sym_WHILE] = ACTIONS(5887),
    [anon_sym_While] = ACTIONS(5887),
    [anon_sym_repeat] = ACTIONS(5887),
    [anon_sym_REPEAT] = ACTIONS(5887),
    [anon_sym_Repeat] = ACTIONS(5887),
    [anon_sym_exit] = ACTIONS(5887),
    [anon_sym_EXIT] = ACTIONS(5887),
    [anon_sym_Exit] = ACTIONS(5887),
    [anon_sym_continue] = ACTIONS(5887),
    [anon_sym_CONTINUE] = ACTIONS(5887),
    [anon_sym_Continue] = ACTIONS(5887),
    [anon_sym_break] = ACTIONS(5887),
    [anon_sym_BREAK] = ACTIONS(5887),
    [anon_sym_Break] = ACTIONS(5887),
    [anon_sym_with] = ACTIONS(5887),
    [anon_sym_WITH] = ACTIONS(5887),
    [anon_sym_With] = ACTIONS(5887),
    [sym_asserterror_keyword] = ACTIONS(5889),
    [sym_page_keyword] = ACTIONS(5887),
    [anon_sym_codeunit] = ACTIONS(5887),
    [anon_sym_CODEUNIT] = ACTIONS(5887),
    [anon_sym_Codeunit] = ACTIONS(5887),
    [anon_sym_CodeUnit] = ACTIONS(5887),
    [anon_sym_COdeunit] = ACTIONS(5887),
    [anon_sym_codeUnit] = ACTIONS(5887),
    [sym_report_keyword] = ACTIONS(5887),
    [sym_query_keyword] = ACTIONS(5887),
    [anon_sym_xmlport] = ACTIONS(5887),
    [anon_sym_XMLPORT] = ACTIONS(5887),
    [anon_sym_Xmlport] = ACTIONS(5887),
    [anon_sym_XMLport] = ACTIONS(5887),
    [anon_sym_XMLPort] = ACTIONS(5887),
    [anon_sym_XmlPort] = ACTIONS(5887),
    [anon_sym_enum] = ACTIONS(5887),
    [anon_sym_ENUM] = ACTIONS(5887),
    [anon_sym_Enum] = ACTIONS(5887),
    [anon_sym_eNUM] = ACTIONS(5887),
    [anon_sym_eNum] = ACTIONS(5887),
    [anon_sym_ENum] = ACTIONS(5887),
    [sym_quoted_identifier] = ACTIONS(5889),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5889),
    [sym_verbatim_string] = ACTIONS(5889),
    [sym_integer] = ACTIONS(5887),
    [sym_continue_as_identifier] = ACTIONS(5889),
    [sym_preproc_open] = ACTIONS(5889),
    [sym_end_keyword] = ACTIONS(5889),
  },
  [STATE(3405)] = {
    [sym_identifier] = ACTIONS(6228),
    [anon_sym_SEMI] = ACTIONS(6230),
    [anon_sym_DASH] = ACTIONS(6230),
    [aux_sym_boolean_token1] = ACTIONS(6228),
    [aux_sym_boolean_token2] = ACTIONS(6228),
    [sym_decimal] = ACTIONS(6228),
    [anon_sym_LPAREN] = ACTIONS(6230),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6228),
    [anon_sym_LBRACK] = ACTIONS(6230),
    [aux_sym_record_type_token1] = ACTIONS(6228),
    [aux_sym_basic_type_token21] = ACTIONS(6228),
    [aux_sym_basic_type_token22] = ACTIONS(6228),
    [aux_sym_basic_type_token48] = ACTIONS(6228),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6228),
    [anon_sym_POUNDif] = ACTIONS(6230),
    [anon_sym_POUNDIF] = ACTIONS(6230),
    [anon_sym_POUNDIf] = ACTIONS(6230),
    [anon_sym_not] = ACTIONS(6228),
    [anon_sym_NOT] = ACTIONS(6228),
    [anon_sym_Not] = ACTIONS(6228),
    [anon_sym_POUNDelse] = ACTIONS(6230),
    [anon_sym_POUNDELSE] = ACTIONS(6230),
    [anon_sym_POUNDElse] = ACTIONS(6230),
    [anon_sym_POUNDelse2] = ACTIONS(6230),
    [anon_sym_POUNDELSE2] = ACTIONS(6230),
    [anon_sym_POUNDElse2] = ACTIONS(6230),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6228),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6228),
    [anon_sym_PLUS] = ACTIONS(6230),
    [sym_datetime_literal] = ACTIONS(6230),
    [sym_date_literal] = ACTIONS(6228),
    [sym_time_literal] = ACTIONS(6228),
    [sym_biginteger_literal] = ACTIONS(6230),
    [anon_sym_if] = ACTIONS(6228),
    [anon_sym_IF] = ACTIONS(6228),
    [anon_sym_If] = ACTIONS(6228),
    [anon_sym_else] = ACTIONS(6228),
    [anon_sym_ELSE] = ACTIONS(6228),
    [anon_sym_Else] = ACTIONS(6228),
    [anon_sym_case] = ACTIONS(6228),
    [anon_sym_CASE] = ACTIONS(6228),
    [anon_sym_Case] = ACTIONS(6228),
    [anon_sym_for] = ACTIONS(6228),
    [anon_sym_FOR] = ACTIONS(6228),
    [anon_sym_For] = ACTIONS(6228),
    [anon_sym_foreach] = ACTIONS(6228),
    [anon_sym_FOREACH] = ACTIONS(6228),
    [anon_sym_Foreach] = ACTIONS(6228),
    [anon_sym_while] = ACTIONS(6228),
    [anon_sym_WHILE] = ACTIONS(6228),
    [anon_sym_While] = ACTIONS(6228),
    [anon_sym_repeat] = ACTIONS(6228),
    [anon_sym_REPEAT] = ACTIONS(6228),
    [anon_sym_Repeat] = ACTIONS(6228),
    [anon_sym_exit] = ACTIONS(6228),
    [anon_sym_EXIT] = ACTIONS(6228),
    [anon_sym_Exit] = ACTIONS(6228),
    [anon_sym_continue] = ACTIONS(6228),
    [anon_sym_CONTINUE] = ACTIONS(6228),
    [anon_sym_Continue] = ACTIONS(6228),
    [anon_sym_break] = ACTIONS(6228),
    [anon_sym_BREAK] = ACTIONS(6228),
    [anon_sym_Break] = ACTIONS(6228),
    [anon_sym_with] = ACTIONS(6228),
    [anon_sym_WITH] = ACTIONS(6228),
    [anon_sym_With] = ACTIONS(6228),
    [sym_asserterror_keyword] = ACTIONS(6230),
    [sym_page_keyword] = ACTIONS(6228),
    [anon_sym_codeunit] = ACTIONS(6228),
    [anon_sym_CODEUNIT] = ACTIONS(6228),
    [anon_sym_Codeunit] = ACTIONS(6228),
    [anon_sym_CodeUnit] = ACTIONS(6228),
    [anon_sym_COdeunit] = ACTIONS(6228),
    [anon_sym_codeUnit] = ACTIONS(6228),
    [sym_report_keyword] = ACTIONS(6228),
    [sym_query_keyword] = ACTIONS(6228),
    [anon_sym_xmlport] = ACTIONS(6228),
    [anon_sym_XMLPORT] = ACTIONS(6228),
    [anon_sym_Xmlport] = ACTIONS(6228),
    [anon_sym_XMLport] = ACTIONS(6228),
    [anon_sym_XMLPort] = ACTIONS(6228),
    [anon_sym_XmlPort] = ACTIONS(6228),
    [anon_sym_enum] = ACTIONS(6228),
    [anon_sym_ENUM] = ACTIONS(6228),
    [anon_sym_Enum] = ACTIONS(6228),
    [anon_sym_eNUM] = ACTIONS(6228),
    [anon_sym_eNum] = ACTIONS(6228),
    [anon_sym_ENum] = ACTIONS(6228),
    [sym_quoted_identifier] = ACTIONS(6230),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6230),
    [sym_verbatim_string] = ACTIONS(6230),
    [sym_integer] = ACTIONS(6228),
    [sym_continue_as_identifier] = ACTIONS(6230),
    [sym_preproc_open] = ACTIONS(6230),
    [sym_end_keyword] = ACTIONS(6230),
  },
  [STATE(3406)] = {
    [sym_identifier] = ACTIONS(6124),
    [anon_sym_SEMI] = ACTIONS(6126),
    [anon_sym_DASH] = ACTIONS(6126),
    [aux_sym_boolean_token1] = ACTIONS(6124),
    [aux_sym_boolean_token2] = ACTIONS(6124),
    [sym_decimal] = ACTIONS(6124),
    [anon_sym_LPAREN] = ACTIONS(6126),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6124),
    [anon_sym_LBRACK] = ACTIONS(6126),
    [aux_sym_record_type_token1] = ACTIONS(6124),
    [aux_sym_basic_type_token21] = ACTIONS(6124),
    [aux_sym_basic_type_token22] = ACTIONS(6124),
    [aux_sym_basic_type_token48] = ACTIONS(6124),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6124),
    [anon_sym_POUNDif] = ACTIONS(6126),
    [anon_sym_POUNDIF] = ACTIONS(6126),
    [anon_sym_POUNDIf] = ACTIONS(6126),
    [anon_sym_not] = ACTIONS(6124),
    [anon_sym_NOT] = ACTIONS(6124),
    [anon_sym_Not] = ACTIONS(6124),
    [anon_sym_POUNDelse] = ACTIONS(6126),
    [anon_sym_POUNDELSE] = ACTIONS(6126),
    [anon_sym_POUNDElse] = ACTIONS(6126),
    [anon_sym_POUNDelse2] = ACTIONS(6126),
    [anon_sym_POUNDELSE2] = ACTIONS(6126),
    [anon_sym_POUNDElse2] = ACTIONS(6126),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6124),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6124),
    [anon_sym_PLUS] = ACTIONS(6126),
    [sym_datetime_literal] = ACTIONS(6126),
    [sym_date_literal] = ACTIONS(6124),
    [sym_time_literal] = ACTIONS(6124),
    [sym_biginteger_literal] = ACTIONS(6126),
    [anon_sym_if] = ACTIONS(6124),
    [anon_sym_IF] = ACTIONS(6124),
    [anon_sym_If] = ACTIONS(6124),
    [anon_sym_else] = ACTIONS(6124),
    [anon_sym_ELSE] = ACTIONS(6124),
    [anon_sym_Else] = ACTIONS(6124),
    [anon_sym_case] = ACTIONS(6124),
    [anon_sym_CASE] = ACTIONS(6124),
    [anon_sym_Case] = ACTIONS(6124),
    [anon_sym_for] = ACTIONS(6124),
    [anon_sym_FOR] = ACTIONS(6124),
    [anon_sym_For] = ACTIONS(6124),
    [anon_sym_foreach] = ACTIONS(6124),
    [anon_sym_FOREACH] = ACTIONS(6124),
    [anon_sym_Foreach] = ACTIONS(6124),
    [anon_sym_while] = ACTIONS(6124),
    [anon_sym_WHILE] = ACTIONS(6124),
    [anon_sym_While] = ACTIONS(6124),
    [anon_sym_repeat] = ACTIONS(6124),
    [anon_sym_REPEAT] = ACTIONS(6124),
    [anon_sym_Repeat] = ACTIONS(6124),
    [anon_sym_exit] = ACTIONS(6124),
    [anon_sym_EXIT] = ACTIONS(6124),
    [anon_sym_Exit] = ACTIONS(6124),
    [anon_sym_continue] = ACTIONS(6124),
    [anon_sym_CONTINUE] = ACTIONS(6124),
    [anon_sym_Continue] = ACTIONS(6124),
    [anon_sym_break] = ACTIONS(6124),
    [anon_sym_BREAK] = ACTIONS(6124),
    [anon_sym_Break] = ACTIONS(6124),
    [anon_sym_with] = ACTIONS(6124),
    [anon_sym_WITH] = ACTIONS(6124),
    [anon_sym_With] = ACTIONS(6124),
    [sym_asserterror_keyword] = ACTIONS(6126),
    [sym_page_keyword] = ACTIONS(6124),
    [anon_sym_codeunit] = ACTIONS(6124),
    [anon_sym_CODEUNIT] = ACTIONS(6124),
    [anon_sym_Codeunit] = ACTIONS(6124),
    [anon_sym_CodeUnit] = ACTIONS(6124),
    [anon_sym_COdeunit] = ACTIONS(6124),
    [anon_sym_codeUnit] = ACTIONS(6124),
    [sym_report_keyword] = ACTIONS(6124),
    [sym_query_keyword] = ACTIONS(6124),
    [anon_sym_xmlport] = ACTIONS(6124),
    [anon_sym_XMLPORT] = ACTIONS(6124),
    [anon_sym_Xmlport] = ACTIONS(6124),
    [anon_sym_XMLport] = ACTIONS(6124),
    [anon_sym_XMLPort] = ACTIONS(6124),
    [anon_sym_XmlPort] = ACTIONS(6124),
    [anon_sym_enum] = ACTIONS(6124),
    [anon_sym_ENUM] = ACTIONS(6124),
    [anon_sym_Enum] = ACTIONS(6124),
    [anon_sym_eNUM] = ACTIONS(6124),
    [anon_sym_eNum] = ACTIONS(6124),
    [anon_sym_ENum] = ACTIONS(6124),
    [sym_quoted_identifier] = ACTIONS(6126),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6126),
    [sym_verbatim_string] = ACTIONS(6126),
    [sym_integer] = ACTIONS(6124),
    [sym_continue_as_identifier] = ACTIONS(6126),
    [sym_preproc_open] = ACTIONS(6126),
    [sym_end_keyword] = ACTIONS(6126),
  },
  [STATE(3407)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(7356),
    [anon_sym_DASH] = ACTIONS(5965),
    [aux_sym_boolean_token1] = ACTIONS(5961),
    [aux_sym_boolean_token2] = ACTIONS(5961),
    [sym_decimal] = ACTIONS(5961),
    [anon_sym_LPAREN] = ACTIONS(5965),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_record_type_token1] = ACTIONS(5961),
    [aux_sym_basic_type_token21] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token48] = ACTIONS(5961),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5961),
    [anon_sym_NOT] = ACTIONS(5961),
    [anon_sym_Not] = ACTIONS(5961),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5961),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5961),
    [anon_sym_PLUS] = ACTIONS(5965),
    [sym_datetime_literal] = ACTIONS(5965),
    [sym_date_literal] = ACTIONS(5961),
    [sym_time_literal] = ACTIONS(5961),
    [sym_biginteger_literal] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5961),
    [anon_sym_IF] = ACTIONS(5961),
    [anon_sym_If] = ACTIONS(5961),
    [anon_sym_else] = ACTIONS(5961),
    [anon_sym_ELSE] = ACTIONS(5961),
    [anon_sym_Else] = ACTIONS(5961),
    [anon_sym_case] = ACTIONS(5961),
    [anon_sym_CASE] = ACTIONS(5961),
    [anon_sym_Case] = ACTIONS(5961),
    [anon_sym_for] = ACTIONS(5961),
    [anon_sym_FOR] = ACTIONS(5961),
    [anon_sym_For] = ACTIONS(5961),
    [anon_sym_foreach] = ACTIONS(5961),
    [anon_sym_FOREACH] = ACTIONS(5961),
    [anon_sym_Foreach] = ACTIONS(5961),
    [anon_sym_while] = ACTIONS(5961),
    [anon_sym_WHILE] = ACTIONS(5961),
    [anon_sym_While] = ACTIONS(5961),
    [anon_sym_repeat] = ACTIONS(5961),
    [anon_sym_REPEAT] = ACTIONS(5961),
    [anon_sym_Repeat] = ACTIONS(5961),
    [anon_sym_exit] = ACTIONS(5961),
    [anon_sym_EXIT] = ACTIONS(5961),
    [anon_sym_Exit] = ACTIONS(5961),
    [anon_sym_continue] = ACTIONS(5961),
    [anon_sym_CONTINUE] = ACTIONS(5961),
    [anon_sym_Continue] = ACTIONS(5961),
    [anon_sym_break] = ACTIONS(5961),
    [anon_sym_BREAK] = ACTIONS(5961),
    [anon_sym_Break] = ACTIONS(5961),
    [anon_sym_with] = ACTIONS(5961),
    [anon_sym_WITH] = ACTIONS(5961),
    [anon_sym_With] = ACTIONS(5961),
    [sym_asserterror_keyword] = ACTIONS(5965),
    [sym_page_keyword] = ACTIONS(5961),
    [anon_sym_codeunit] = ACTIONS(5961),
    [anon_sym_CODEUNIT] = ACTIONS(5961),
    [anon_sym_Codeunit] = ACTIONS(5961),
    [anon_sym_CodeUnit] = ACTIONS(5961),
    [anon_sym_COdeunit] = ACTIONS(5961),
    [anon_sym_codeUnit] = ACTIONS(5961),
    [sym_report_keyword] = ACTIONS(5961),
    [sym_query_keyword] = ACTIONS(5961),
    [anon_sym_xmlport] = ACTIONS(5961),
    [anon_sym_XMLPORT] = ACTIONS(5961),
    [anon_sym_Xmlport] = ACTIONS(5961),
    [anon_sym_XMLport] = ACTIONS(5961),
    [anon_sym_XMLPort] = ACTIONS(5961),
    [anon_sym_XmlPort] = ACTIONS(5961),
    [anon_sym_enum] = ACTIONS(5961),
    [anon_sym_ENUM] = ACTIONS(5961),
    [anon_sym_Enum] = ACTIONS(5961),
    [anon_sym_eNUM] = ACTIONS(5961),
    [anon_sym_eNum] = ACTIONS(5961),
    [anon_sym_ENum] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5965),
    [sym_verbatim_string] = ACTIONS(5965),
    [sym_integer] = ACTIONS(5961),
    [sym_continue_as_identifier] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_end_keyword] = ACTIONS(5965),
  },
  [STATE(3408)] = {
    [sym_identifier] = ACTIONS(5509),
    [anon_sym_SEMI] = ACTIONS(5511),
    [anon_sym_DASH] = ACTIONS(5511),
    [aux_sym_boolean_token1] = ACTIONS(5509),
    [aux_sym_boolean_token2] = ACTIONS(5509),
    [sym_decimal] = ACTIONS(5509),
    [anon_sym_LPAREN] = ACTIONS(5511),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5509),
    [anon_sym_LBRACK] = ACTIONS(5511),
    [aux_sym_record_type_token1] = ACTIONS(5509),
    [aux_sym_basic_type_token21] = ACTIONS(5509),
    [aux_sym_basic_type_token22] = ACTIONS(5509),
    [aux_sym_basic_type_token48] = ACTIONS(5509),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(5509),
    [anon_sym_POUNDif] = ACTIONS(5511),
    [anon_sym_POUNDIF] = ACTIONS(5511),
    [anon_sym_POUNDIf] = ACTIONS(5511),
    [anon_sym_not] = ACTIONS(5509),
    [anon_sym_NOT] = ACTIONS(5509),
    [anon_sym_Not] = ACTIONS(5509),
    [anon_sym_POUNDelse] = ACTIONS(5511),
    [anon_sym_POUNDELSE] = ACTIONS(5511),
    [anon_sym_POUNDElse] = ACTIONS(5511),
    [anon_sym_POUNDelse2] = ACTIONS(5511),
    [anon_sym_POUNDELSE2] = ACTIONS(5511),
    [anon_sym_POUNDElse2] = ACTIONS(5511),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5509),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5509),
    [anon_sym_PLUS] = ACTIONS(5511),
    [sym_datetime_literal] = ACTIONS(5511),
    [sym_date_literal] = ACTIONS(5509),
    [sym_time_literal] = ACTIONS(5509),
    [sym_biginteger_literal] = ACTIONS(5511),
    [anon_sym_if] = ACTIONS(5509),
    [anon_sym_IF] = ACTIONS(5509),
    [anon_sym_If] = ACTIONS(5509),
    [anon_sym_else] = ACTIONS(5509),
    [anon_sym_ELSE] = ACTIONS(5509),
    [anon_sym_Else] = ACTIONS(5509),
    [anon_sym_case] = ACTIONS(5509),
    [anon_sym_CASE] = ACTIONS(5509),
    [anon_sym_Case] = ACTIONS(5509),
    [anon_sym_for] = ACTIONS(5509),
    [anon_sym_FOR] = ACTIONS(5509),
    [anon_sym_For] = ACTIONS(5509),
    [anon_sym_foreach] = ACTIONS(5509),
    [anon_sym_FOREACH] = ACTIONS(5509),
    [anon_sym_Foreach] = ACTIONS(5509),
    [anon_sym_while] = ACTIONS(5509),
    [anon_sym_WHILE] = ACTIONS(5509),
    [anon_sym_While] = ACTIONS(5509),
    [anon_sym_repeat] = ACTIONS(5509),
    [anon_sym_REPEAT] = ACTIONS(5509),
    [anon_sym_Repeat] = ACTIONS(5509),
    [anon_sym_exit] = ACTIONS(5509),
    [anon_sym_EXIT] = ACTIONS(5509),
    [anon_sym_Exit] = ACTIONS(5509),
    [anon_sym_continue] = ACTIONS(5509),
    [anon_sym_CONTINUE] = ACTIONS(5509),
    [anon_sym_Continue] = ACTIONS(5509),
    [anon_sym_break] = ACTIONS(5509),
    [anon_sym_BREAK] = ACTIONS(5509),
    [anon_sym_Break] = ACTIONS(5509),
    [anon_sym_with] = ACTIONS(5509),
    [anon_sym_WITH] = ACTIONS(5509),
    [anon_sym_With] = ACTIONS(5509),
    [sym_asserterror_keyword] = ACTIONS(5511),
    [sym_page_keyword] = ACTIONS(5509),
    [anon_sym_codeunit] = ACTIONS(5509),
    [anon_sym_CODEUNIT] = ACTIONS(5509),
    [anon_sym_Codeunit] = ACTIONS(5509),
    [anon_sym_CodeUnit] = ACTIONS(5509),
    [anon_sym_COdeunit] = ACTIONS(5509),
    [anon_sym_codeUnit] = ACTIONS(5509),
    [sym_report_keyword] = ACTIONS(5509),
    [sym_query_keyword] = ACTIONS(5509),
    [anon_sym_xmlport] = ACTIONS(5509),
    [anon_sym_XMLPORT] = ACTIONS(5509),
    [anon_sym_Xmlport] = ACTIONS(5509),
    [anon_sym_XMLport] = ACTIONS(5509),
    [anon_sym_XMLPort] = ACTIONS(5509),
    [anon_sym_XmlPort] = ACTIONS(5509),
    [anon_sym_enum] = ACTIONS(5509),
    [anon_sym_ENUM] = ACTIONS(5509),
    [anon_sym_Enum] = ACTIONS(5509),
    [anon_sym_eNUM] = ACTIONS(5509),
    [anon_sym_eNum] = ACTIONS(5509),
    [anon_sym_ENum] = ACTIONS(5509),
    [sym_quoted_identifier] = ACTIONS(5511),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5511),
    [sym_verbatim_string] = ACTIONS(5511),
    [sym_integer] = ACTIONS(5509),
    [sym_continue_as_identifier] = ACTIONS(5511),
    [sym_preproc_open] = ACTIONS(5511),
    [sym_end_keyword] = ACTIONS(5511),
  },
  [STATE(3409)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_endif] = STATE(6518),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3431),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(13794),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3431),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3410)] = {
    [sym_argument_list] = STATE(7165),
    [sym_identifier] = ACTIONS(5410),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [aux_sym_where_condition_token1] = ACTIONS(5410),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5410),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_basic_type_token22] = ACTIONS(5410),
    [aux_sym_basic_type_token53] = ACTIONS(5410),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5410),
    [aux_sym_modify_modification_token1] = ACTIONS(5410),
    [aux_sym_separator_action_token1] = ACTIONS(5410),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [aux_sym_type_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [anon_sym_POUNDelif] = ACTIONS(5405),
    [anon_sym_POUNDELIF] = ACTIONS(5405),
    [anon_sym_POUNDElif] = ACTIONS(5405),
    [anon_sym_POUNDelse] = ACTIONS(5405),
    [anon_sym_POUNDELSE] = ACTIONS(5405),
    [anon_sym_POUNDElse] = ACTIONS(5405),
    [anon_sym_POUNDelse2] = ACTIONS(5405),
    [anon_sym_POUNDELSE2] = ACTIONS(5405),
    [anon_sym_POUNDElse2] = ACTIONS(5405),
    [anon_sym_POUNDendif] = ACTIONS(5405),
    [anon_sym_POUNDENDIF] = ACTIONS(5405),
    [anon_sym_POUNDEndif] = ACTIONS(5405),
    [anon_sym_POUNDendif2] = ACTIONS(5405),
    [anon_sym_POUNDENDIF2] = ACTIONS(5405),
    [anon_sym_POUNDEndif2] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_table_keyword] = ACTIONS(5410),
    [sym_procedure_keyword] = ACTIONS(5410),
    [sym_trigger_keyword] = ACTIONS(5410),
    [sym_var_keyword] = ACTIONS(5410),
    [sym_local_keyword] = ACTIONS(5410),
    [sym_internal_keyword] = ACTIONS(5410),
    [sym_protected_keyword] = ACTIONS(5410),
    [sym_event_keyword] = ACTIONS(5410),
    [sym_fields_keyword] = ACTIONS(5410),
    [sym_keys_keyword] = ACTIONS(5410),
    [sym_key_keyword] = ACTIONS(5410),
    [sym_fieldgroups_keyword] = ACTIONS(5410),
    [sym_actions_keyword] = ACTIONS(5410),
    [sym_layout_keyword] = ACTIONS(5410),
    [sym_dataset_keyword] = ACTIONS(5410),
    [sym_elements_keyword] = ACTIONS(5410),
    [sym_labels_keyword] = ACTIONS(5410),
    [sym_rendering_keyword] = ACTIONS(5410),
    [sym_requestpage_keyword] = ACTIONS(5410),
    [sym_schema_keyword] = ACTIONS(5410),
    [sym_views_keyword] = ACTIONS(5410),
    [sym_quoted_identifier] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
    [sym_preproc_close] = ACTIONS(5405),
    [sym_var_attribute_open] = ACTIONS(5405),
  },
  [STATE(3411)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_endif] = STATE(6561),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(2726),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(13790),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2726),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3412)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_endif] = STATE(6518),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(2726),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(13794),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2726),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3413)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_endif] = STATE(6561),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3425),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(13790),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3425),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3414)] = {
    [sym_where_clause] = STATE(6878),
    [sym_argument_list] = STATE(7165),
    [sym_identifier] = ACTIONS(5392),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(7358),
    [aux_sym_where_condition_token1] = ACTIONS(5392),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [aux_sym_basic_type_token22] = ACTIONS(5392),
    [aux_sym_basic_type_token53] = ACTIONS(5392),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5392),
    [aux_sym_modify_modification_token1] = ACTIONS(5392),
    [aux_sym_separator_action_token1] = ACTIONS(5392),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5392),
    [aux_sym_type_declaration_token1] = ACTIONS(5392),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5386),
    [anon_sym_POUNDIF] = ACTIONS(5386),
    [anon_sym_POUNDIf] = ACTIONS(5386),
    [anon_sym_POUNDelif] = ACTIONS(5386),
    [anon_sym_POUNDELIF] = ACTIONS(5386),
    [anon_sym_POUNDElif] = ACTIONS(5386),
    [anon_sym_POUNDelse] = ACTIONS(5386),
    [anon_sym_POUNDELSE] = ACTIONS(5386),
    [anon_sym_POUNDElse] = ACTIONS(5386),
    [anon_sym_POUNDelse2] = ACTIONS(5386),
    [anon_sym_POUNDELSE2] = ACTIONS(5386),
    [anon_sym_POUNDElse2] = ACTIONS(5386),
    [anon_sym_POUNDendif] = ACTIONS(5386),
    [anon_sym_POUNDENDIF] = ACTIONS(5386),
    [anon_sym_POUNDEndif] = ACTIONS(5386),
    [anon_sym_POUNDendif2] = ACTIONS(5386),
    [anon_sym_POUNDENDIF2] = ACTIONS(5386),
    [anon_sym_POUNDEndif2] = ACTIONS(5386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_table_keyword] = ACTIONS(5392),
    [sym_procedure_keyword] = ACTIONS(5392),
    [sym_trigger_keyword] = ACTIONS(5392),
    [sym_var_keyword] = ACTIONS(5392),
    [sym_local_keyword] = ACTIONS(5392),
    [sym_internal_keyword] = ACTIONS(5392),
    [sym_protected_keyword] = ACTIONS(5392),
    [sym_event_keyword] = ACTIONS(5392),
    [sym_fields_keyword] = ACTIONS(5392),
    [sym_keys_keyword] = ACTIONS(5392),
    [sym_key_keyword] = ACTIONS(5392),
    [sym_fieldgroups_keyword] = ACTIONS(5392),
    [sym_actions_keyword] = ACTIONS(5392),
    [sym_layout_keyword] = ACTIONS(5392),
    [sym_dataset_keyword] = ACTIONS(5392),
    [sym_elements_keyword] = ACTIONS(5392),
    [sym_labels_keyword] = ACTIONS(5392),
    [sym_rendering_keyword] = ACTIONS(5392),
    [sym_requestpage_keyword] = ACTIONS(5392),
    [sym_schema_keyword] = ACTIONS(5392),
    [sym_views_keyword] = ACTIONS(5392),
    [sym_quoted_identifier] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5386),
    [sym_preproc_open] = ACTIONS(5386),
    [sym_preproc_close] = ACTIONS(5386),
    [sym_var_attribute_open] = ACTIONS(5386),
  },
  [STATE(3415)] = {
    [sym_boolean] = STATE(7226),
    [sym_option_member] = STATE(8435),
    [sym_keyword_identifier] = STATE(7226),
    [sym_codeunit_keyword] = STATE(6858),
    [sym_xmlport_keyword] = STATE(6858),
    [sym_enum_keyword] = STATE(6858),
    [sym_keyword_as_identifier] = STATE(7226),
    [aux_sym_option_member_list_repeat2] = STATE(2727),
    [sym_identifier] = ACTIONS(3993),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(6615),
    [anon_sym_DASH] = ACTIONS(6032),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [aux_sym_where_condition_token1] = ACTIONS(7225),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(6034),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7225),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7225),
    [aux_sym_separator_action_token1] = ACTIONS(7225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7225),
    [aux_sym_type_declaration_token1] = ACTIONS(7225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1382),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_table_keyword] = ACTIONS(7225),
    [sym_page_keyword] = ACTIONS(1382),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1382),
    [sym_query_keyword] = ACTIONS(1382),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(7225),
    [sym_dataset_keyword] = ACTIONS(7225),
    [sym_quoted_identifier] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6036),
    [sym_integer] = ACTIONS(6036),
  },
  [STATE(3416)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3788),
    [sym_preproc_endif] = STATE(7884),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10858),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7313),
    [anon_sym_POUNDENDIF] = ACTIONS(7313),
    [anon_sym_POUNDEndif] = ACTIONS(7313),
    [anon_sym_POUNDendif2] = ACTIONS(7313),
    [anon_sym_POUNDENDIF2] = ACTIONS(7313),
    [anon_sym_POUNDEndif2] = ACTIONS(7313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7313),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3417)] = {
    [sym__body_element] = STATE(7554),
    [sym_empty_statement] = STATE(7554),
    [sym_property] = STATE(7554),
    [sym_permissions_property] = STATE(7554),
    [sym_table_relation_property] = STATE(7554),
    [sym_fields_section] = STATE(7554),
    [sym_keys_section] = STATE(7554),
    [sym_fieldgroups_section] = STATE(7554),
    [sym_enum_value_declaration] = STATE(7554),
    [sym_labels_section] = STATE(7554),
    [sym_layout_section] = STATE(7554),
    [sym_modify_modification] = STATE(7554),
    [sym_actions_section] = STATE(7554),
    [sym_views_section] = STATE(7554),
    [sym_dataset_section] = STATE(7554),
    [sym_requestpage_section] = STATE(7554),
    [sym_rendering_section] = STATE(7554),
    [sym_elements_section] = STATE(7554),
    [sym_schema_section] = STATE(7554),
    [sym_xmlport_element] = STATE(3569),
    [sym__xmlport_body_element] = STATE(3569),
    [sym_preproc_conditional_xmlport] = STATE(3569),
    [sym_xmlport_attribute] = STATE(3569),
    [sym_assembly_declaration] = STATE(7554),
    [sym_event_declaration] = STATE(7554),
    [sym_procedure] = STATE(7554),
    [sym_preproc_split_procedure] = STATE(7554),
    [sym__procedure_preamble] = STATE(10668),
    [sym_preproc_split_procedure_preamble] = STATE(7554),
    [sym__procedure_header] = STATE(9971),
    [sym_procedure_modifier] = STATE(17533),
    [sym_trigger_declaration] = STATE(7554),
    [sym_var_section] = STATE(7554),
    [sym_attribute_item] = STATE(7606),
    [sym_preproc_conditional] = STATE(7554),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_elif] = STATE(3609),
    [sym_preproc_else] = STATE(3958),
    [sym_preproc_endif] = STATE(9487),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3862),
    [aux_sym_xmlport_element_repeat1] = STATE(3569),
    [aux_sym_preproc_conditional_xmlport_repeat1] = STATE(10747),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10709),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDelif] = ACTIONS(7378),
    [anon_sym_POUNDELIF] = ACTIONS(7378),
    [anon_sym_POUNDElif] = ACTIONS(7378),
    [anon_sym_POUNDelse] = ACTIONS(7380),
    [anon_sym_POUNDELSE] = ACTIONS(7380),
    [anon_sym_POUNDElse] = ACTIONS(7380),
    [anon_sym_POUNDelse2] = ACTIONS(7380),
    [anon_sym_POUNDELSE2] = ACTIONS(7380),
    [anon_sym_POUNDElse2] = ACTIONS(7380),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7382),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3418)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_endif] = STATE(6544),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3411),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(14528),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3411),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3419)] = {
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(6589),
    [anon_sym_RBRACE] = ACTIONS(3695),
    [anon_sym_EQ] = ACTIONS(6591),
    [anon_sym_DASH] = ACTIONS(6589),
    [aux_sym_where_clause_token1] = ACTIONS(3695),
    [aux_sym_where_condition_token1] = ACTIONS(3693),
    [anon_sym_DOT_DOT] = ACTIONS(6591),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3695),
    [anon_sym_STAR] = ACTIONS(6589),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3695),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3695),
    [anon_sym_LBRACK] = ACTIONS(6593),
    [aux_sym_basic_type_token6] = ACTIONS(3693),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3695),
    [aux_sym_addafter_modification_token1] = ACTIONS(3695),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3695),
    [aux_sym_modify_modification_token1] = ACTIONS(3695),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3695),
    [aux_sym_movelast_modification_token1] = ACTIONS(3695),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3695),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3695),
    [aux_sym_separator_action_token1] = ACTIONS(3695),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3695),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3695),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3695),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3695),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6591),
    [aux_sym__expression_token1] = ACTIONS(6591),
    [aux_sym__expression_token2] = ACTIONS(6591),
    [anon_sym_SLASH] = ACTIONS(6589),
    [anon_sym_div] = ACTIONS(6591),
    [anon_sym_DIV] = ACTIONS(6591),
    [anon_sym_Div] = ACTIONS(6591),
    [anon_sym_mod] = ACTIONS(6589),
    [anon_sym_MOD] = ACTIONS(6589),
    [anon_sym_Mod] = ACTIONS(6589),
    [anon_sym_PLUS] = ACTIONS(6589),
    [anon_sym_GT_EQ] = ACTIONS(6591),
    [anon_sym_LT_EQ] = ACTIONS(6591),
    [anon_sym_GT] = ACTIONS(6589),
    [anon_sym_LT] = ACTIONS(6589),
    [anon_sym_LT_GT] = ACTIONS(6591),
    [anon_sym_and] = ACTIONS(6591),
    [anon_sym_AND] = ACTIONS(6591),
    [anon_sym_And] = ACTIONS(6591),
    [anon_sym_or] = ACTIONS(6591),
    [anon_sym_OR] = ACTIONS(6591),
    [anon_sym_Or] = ACTIONS(6591),
    [anon_sym_xor] = ACTIONS(6591),
    [anon_sym_XOR] = ACTIONS(6591),
    [anon_sym_Xor] = ACTIONS(6591),
    [anon_sym_QMARK] = ACTIONS(6591),
    [anon_sym_in] = ACTIONS(6589),
    [anon_sym_IN] = ACTIONS(6589),
    [anon_sym_In] = ACTIONS(6589),
    [sym_procedure_keyword] = ACTIONS(3695),
    [sym_trigger_keyword] = ACTIONS(3695),
    [sym_var_keyword] = ACTIONS(3695),
    [sym_local_keyword] = ACTIONS(3695),
    [sym_internal_keyword] = ACTIONS(3695),
    [sym_protected_keyword] = ACTIONS(3695),
    [sym_event_keyword] = ACTIONS(3695),
    [sym_fields_keyword] = ACTIONS(3695),
    [sym_keys_keyword] = ACTIONS(3695),
    [sym_fieldgroups_keyword] = ACTIONS(3695),
    [sym_actions_keyword] = ACTIONS(3695),
    [sym_layout_keyword] = ACTIONS(3695),
    [sym_area_keyword] = ACTIONS(3695),
    [sym_group_keyword] = ACTIONS(3695),
    [sym_repeater_keyword] = ACTIONS(3695),
    [sym_cuegroup_keyword] = ACTIONS(3695),
    [sym_fixed_keyword] = ACTIONS(3695),
    [sym_grid_keyword] = ACTIONS(3695),
    [sym_part_keyword] = ACTIONS(3695),
    [sym_systempart_keyword] = ACTIONS(3695),
    [sym_usercontrol_keyword] = ACTIONS(3695),
    [sym_dataset_keyword] = ACTIONS(3695),
    [sym_elements_keyword] = ACTIONS(3695),
    [sym_dataitem_keyword] = ACTIONS(3695),
    [sym_column_keyword] = ACTIONS(3695),
    [sym_filter_keyword] = ACTIONS(3695),
    [sym_labels_keyword] = ACTIONS(3695),
    [sym_rendering_keyword] = ACTIONS(3695),
    [sym_requestpage_keyword] = ACTIONS(3695),
    [sym_schema_keyword] = ACTIONS(3695),
    [sym_views_keyword] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
  },
  [STATE(3420)] = {
    [sym_identifier] = ACTIONS(7418),
    [anon_sym_SEMI] = ACTIONS(7420),
    [anon_sym_DASH] = ACTIONS(7420),
    [aux_sym_boolean_token1] = ACTIONS(7418),
    [aux_sym_boolean_token2] = ACTIONS(7418),
    [sym_decimal] = ACTIONS(7418),
    [anon_sym_LPAREN] = ACTIONS(7420),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7418),
    [anon_sym_LBRACK] = ACTIONS(7420),
    [aux_sym_record_type_token1] = ACTIONS(7418),
    [aux_sym_basic_type_token21] = ACTIONS(7418),
    [aux_sym_basic_type_token22] = ACTIONS(7418),
    [aux_sym_basic_type_token48] = ACTIONS(7418),
    [anon_sym_POUNDif] = ACTIONS(7420),
    [anon_sym_POUNDIF] = ACTIONS(7420),
    [anon_sym_POUNDIf] = ACTIONS(7420),
    [anon_sym_not] = ACTIONS(7418),
    [anon_sym_NOT] = ACTIONS(7418),
    [anon_sym_Not] = ACTIONS(7418),
    [anon_sym_POUNDendif] = ACTIONS(7420),
    [anon_sym_POUNDENDIF] = ACTIONS(7420),
    [anon_sym_POUNDEndif] = ACTIONS(7420),
    [anon_sym_POUNDendif2] = ACTIONS(7420),
    [anon_sym_POUNDENDIF2] = ACTIONS(7420),
    [anon_sym_POUNDEndif2] = ACTIONS(7420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7418),
    [anon_sym_PLUS] = ACTIONS(7420),
    [sym_datetime_literal] = ACTIONS(7420),
    [sym_date_literal] = ACTIONS(7418),
    [sym_time_literal] = ACTIONS(7418),
    [sym_biginteger_literal] = ACTIONS(7420),
    [anon_sym_if] = ACTIONS(7418),
    [anon_sym_IF] = ACTIONS(7418),
    [anon_sym_If] = ACTIONS(7418),
    [anon_sym_else] = ACTIONS(7418),
    [anon_sym_ELSE] = ACTIONS(7418),
    [anon_sym_Else] = ACTIONS(7418),
    [anon_sym_case] = ACTIONS(7418),
    [anon_sym_CASE] = ACTIONS(7418),
    [anon_sym_Case] = ACTIONS(7418),
    [anon_sym_for] = ACTIONS(7418),
    [anon_sym_FOR] = ACTIONS(7418),
    [anon_sym_For] = ACTIONS(7418),
    [anon_sym_foreach] = ACTIONS(7418),
    [anon_sym_FOREACH] = ACTIONS(7418),
    [anon_sym_Foreach] = ACTIONS(7418),
    [anon_sym_while] = ACTIONS(7418),
    [anon_sym_WHILE] = ACTIONS(7418),
    [anon_sym_While] = ACTIONS(7418),
    [anon_sym_repeat] = ACTIONS(7418),
    [anon_sym_REPEAT] = ACTIONS(7418),
    [anon_sym_Repeat] = ACTIONS(7418),
    [anon_sym_exit] = ACTIONS(7418),
    [anon_sym_EXIT] = ACTIONS(7418),
    [anon_sym_Exit] = ACTIONS(7418),
    [anon_sym_continue] = ACTIONS(7418),
    [anon_sym_CONTINUE] = ACTIONS(7418),
    [anon_sym_Continue] = ACTIONS(7418),
    [anon_sym_break] = ACTIONS(7418),
    [anon_sym_BREAK] = ACTIONS(7418),
    [anon_sym_Break] = ACTIONS(7418),
    [anon_sym_with] = ACTIONS(7418),
    [anon_sym_WITH] = ACTIONS(7418),
    [anon_sym_With] = ACTIONS(7418),
    [sym_asserterror_keyword] = ACTIONS(7420),
    [sym_page_keyword] = ACTIONS(7418),
    [anon_sym_codeunit] = ACTIONS(7418),
    [anon_sym_CODEUNIT] = ACTIONS(7418),
    [anon_sym_Codeunit] = ACTIONS(7418),
    [anon_sym_CodeUnit] = ACTIONS(7418),
    [anon_sym_COdeunit] = ACTIONS(7418),
    [anon_sym_codeUnit] = ACTIONS(7418),
    [sym_report_keyword] = ACTIONS(7418),
    [sym_query_keyword] = ACTIONS(7418),
    [anon_sym_xmlport] = ACTIONS(7418),
    [anon_sym_XMLPORT] = ACTIONS(7418),
    [anon_sym_Xmlport] = ACTIONS(7418),
    [anon_sym_XMLport] = ACTIONS(7418),
    [anon_sym_XMLPort] = ACTIONS(7418),
    [anon_sym_XmlPort] = ACTIONS(7418),
    [anon_sym_enum] = ACTIONS(7418),
    [anon_sym_ENUM] = ACTIONS(7418),
    [anon_sym_Enum] = ACTIONS(7418),
    [anon_sym_eNUM] = ACTIONS(7418),
    [anon_sym_eNum] = ACTIONS(7418),
    [anon_sym_ENum] = ACTIONS(7418),
    [sym_quoted_identifier] = ACTIONS(7420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7420),
    [sym_verbatim_string] = ACTIONS(7420),
    [sym_integer] = ACTIONS(7418),
    [sym_continue_as_identifier] = ACTIONS(7420),
    [sym_preproc_open] = ACTIONS(7420),
    [sym_preproc_close] = ACTIONS(7420),
  },
  [STATE(3421)] = {
    [sym_identifier] = ACTIONS(6698),
    [anon_sym_SEMI] = ACTIONS(6700),
    [anon_sym_DASH] = ACTIONS(6700),
    [aux_sym_boolean_token1] = ACTIONS(6698),
    [aux_sym_boolean_token2] = ACTIONS(6698),
    [sym_decimal] = ACTIONS(6698),
    [anon_sym_LPAREN] = ACTIONS(6700),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6698),
    [anon_sym_LBRACK] = ACTIONS(6700),
    [aux_sym_record_type_token1] = ACTIONS(6698),
    [aux_sym_basic_type_token21] = ACTIONS(6698),
    [aux_sym_basic_type_token22] = ACTIONS(6698),
    [aux_sym_basic_type_token48] = ACTIONS(6698),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6698),
    [anon_sym_POUNDif] = ACTIONS(6700),
    [anon_sym_POUNDIF] = ACTIONS(6700),
    [anon_sym_POUNDIf] = ACTIONS(6700),
    [anon_sym_not] = ACTIONS(6698),
    [anon_sym_NOT] = ACTIONS(6698),
    [anon_sym_Not] = ACTIONS(6698),
    [anon_sym_POUNDelse] = ACTIONS(6700),
    [anon_sym_POUNDELSE] = ACTIONS(6700),
    [anon_sym_POUNDElse] = ACTIONS(6700),
    [anon_sym_POUNDelse2] = ACTIONS(6700),
    [anon_sym_POUNDELSE2] = ACTIONS(6700),
    [anon_sym_POUNDElse2] = ACTIONS(6700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6698),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6698),
    [anon_sym_PLUS] = ACTIONS(6700),
    [sym_datetime_literal] = ACTIONS(6700),
    [sym_date_literal] = ACTIONS(6698),
    [sym_time_literal] = ACTIONS(6698),
    [sym_biginteger_literal] = ACTIONS(6700),
    [anon_sym_if] = ACTIONS(6698),
    [anon_sym_IF] = ACTIONS(6698),
    [anon_sym_If] = ACTIONS(6698),
    [anon_sym_case] = ACTIONS(6698),
    [anon_sym_CASE] = ACTIONS(6698),
    [anon_sym_Case] = ACTIONS(6698),
    [anon_sym_for] = ACTIONS(6698),
    [anon_sym_FOR] = ACTIONS(6698),
    [anon_sym_For] = ACTIONS(6698),
    [anon_sym_foreach] = ACTIONS(6698),
    [anon_sym_FOREACH] = ACTIONS(6698),
    [anon_sym_Foreach] = ACTIONS(6698),
    [anon_sym_while] = ACTIONS(6698),
    [anon_sym_WHILE] = ACTIONS(6698),
    [anon_sym_While] = ACTIONS(6698),
    [anon_sym_repeat] = ACTIONS(6698),
    [anon_sym_REPEAT] = ACTIONS(6698),
    [anon_sym_Repeat] = ACTIONS(6698),
    [anon_sym_until] = ACTIONS(6698),
    [anon_sym_UNTIL] = ACTIONS(6698),
    [anon_sym_Until] = ACTIONS(6698),
    [anon_sym_exit] = ACTIONS(6698),
    [anon_sym_EXIT] = ACTIONS(6698),
    [anon_sym_Exit] = ACTIONS(6698),
    [anon_sym_continue] = ACTIONS(6698),
    [anon_sym_CONTINUE] = ACTIONS(6698),
    [anon_sym_Continue] = ACTIONS(6698),
    [anon_sym_break] = ACTIONS(6698),
    [anon_sym_BREAK] = ACTIONS(6698),
    [anon_sym_Break] = ACTIONS(6698),
    [anon_sym_with] = ACTIONS(6698),
    [anon_sym_WITH] = ACTIONS(6698),
    [anon_sym_With] = ACTIONS(6698),
    [sym_asserterror_keyword] = ACTIONS(6700),
    [sym_page_keyword] = ACTIONS(6698),
    [anon_sym_codeunit] = ACTIONS(6698),
    [anon_sym_CODEUNIT] = ACTIONS(6698),
    [anon_sym_Codeunit] = ACTIONS(6698),
    [anon_sym_CodeUnit] = ACTIONS(6698),
    [anon_sym_COdeunit] = ACTIONS(6698),
    [anon_sym_codeUnit] = ACTIONS(6698),
    [sym_report_keyword] = ACTIONS(6698),
    [sym_query_keyword] = ACTIONS(6698),
    [anon_sym_xmlport] = ACTIONS(6698),
    [anon_sym_XMLPORT] = ACTIONS(6698),
    [anon_sym_Xmlport] = ACTIONS(6698),
    [anon_sym_XMLport] = ACTIONS(6698),
    [anon_sym_XMLPort] = ACTIONS(6698),
    [anon_sym_XmlPort] = ACTIONS(6698),
    [anon_sym_enum] = ACTIONS(6698),
    [anon_sym_ENUM] = ACTIONS(6698),
    [anon_sym_Enum] = ACTIONS(6698),
    [anon_sym_eNUM] = ACTIONS(6698),
    [anon_sym_eNum] = ACTIONS(6698),
    [anon_sym_ENum] = ACTIONS(6698),
    [sym_quoted_identifier] = ACTIONS(6700),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6700),
    [sym_verbatim_string] = ACTIONS(6700),
    [sym_integer] = ACTIONS(6698),
    [sym_continue_as_identifier] = ACTIONS(6700),
    [sym_preproc_open] = ACTIONS(6700),
  },
  [STATE(3422)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3774),
    [sym_preproc_endif] = STATE(11095),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10913),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7307),
    [anon_sym_POUNDENDIF] = ACTIONS(7307),
    [anon_sym_POUNDEndif] = ACTIONS(7307),
    [anon_sym_POUNDendif2] = ACTIONS(7307),
    [anon_sym_POUNDENDIF2] = ACTIONS(7307),
    [anon_sym_POUNDEndif2] = ACTIONS(7307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7307),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3423)] = {
    [sym__body_element] = STATE(7554),
    [sym_empty_statement] = STATE(7554),
    [sym_property] = STATE(7554),
    [sym_permissions_property] = STATE(7554),
    [sym_table_relation_property] = STATE(7554),
    [sym_fields_section] = STATE(7554),
    [sym_keys_section] = STATE(7554),
    [sym_fieldgroups_section] = STATE(7554),
    [sym_enum_value_declaration] = STATE(7554),
    [sym_labels_section] = STATE(7554),
    [sym_layout_section] = STATE(7554),
    [sym_modify_modification] = STATE(7554),
    [sym_actions_section] = STATE(7554),
    [sym_views_section] = STATE(7554),
    [sym_dataset_section] = STATE(7554),
    [sym_requestpage_section] = STATE(7554),
    [sym_rendering_section] = STATE(7554),
    [sym_elements_section] = STATE(7554),
    [sym_schema_section] = STATE(7554),
    [sym_xmlport_element] = STATE(3568),
    [sym__xmlport_body_element] = STATE(3568),
    [sym_preproc_conditional_xmlport] = STATE(3568),
    [sym_xmlport_attribute] = STATE(3568),
    [sym_assembly_declaration] = STATE(7554),
    [sym_event_declaration] = STATE(7554),
    [sym_procedure] = STATE(7554),
    [sym_preproc_split_procedure] = STATE(7554),
    [sym__procedure_preamble] = STATE(10708),
    [sym_preproc_split_procedure_preamble] = STATE(7554),
    [sym__procedure_header] = STATE(9985),
    [sym_procedure_modifier] = STATE(17533),
    [sym_trigger_declaration] = STATE(7554),
    [sym_var_section] = STATE(7554),
    [sym_attribute_item] = STATE(7606),
    [sym_preproc_conditional] = STATE(7554),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_elif] = STATE(3609),
    [sym_preproc_else] = STATE(3954),
    [sym_preproc_endif] = STATE(7501),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3825),
    [aux_sym_xmlport_element_repeat1] = STATE(3568),
    [aux_sym_preproc_conditional_xmlport_repeat1] = STATE(10783),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10907),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDelif] = ACTIONS(7378),
    [anon_sym_POUNDELIF] = ACTIONS(7378),
    [anon_sym_POUNDElif] = ACTIONS(7378),
    [anon_sym_POUNDelse] = ACTIONS(7380),
    [anon_sym_POUNDELSE] = ACTIONS(7380),
    [anon_sym_POUNDElse] = ACTIONS(7380),
    [anon_sym_POUNDelse2] = ACTIONS(7380),
    [anon_sym_POUNDELSE2] = ACTIONS(7380),
    [anon_sym_POUNDElse2] = ACTIONS(7380),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7382),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3424)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3761),
    [sym_preproc_endif] = STATE(4025),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10695),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3425)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_endif] = STATE(6549),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(2726),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(14163),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2726),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3426)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3782),
    [sym_preproc_endif] = STATE(11188),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10739),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7259),
    [anon_sym_POUNDENDIF] = ACTIONS(7259),
    [anon_sym_POUNDEndif] = ACTIONS(7259),
    [anon_sym_POUNDendif2] = ACTIONS(7259),
    [anon_sym_POUNDENDIF2] = ACTIONS(7259),
    [anon_sym_POUNDEndif2] = ACTIONS(7259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7259),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3427)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3750),
    [sym_preproc_endif] = STATE(5693),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10834),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7303),
    [anon_sym_POUNDENDIF] = ACTIONS(7303),
    [anon_sym_POUNDEndif] = ACTIONS(7303),
    [anon_sym_POUNDendif2] = ACTIONS(7303),
    [anon_sym_POUNDENDIF2] = ACTIONS(7303),
    [anon_sym_POUNDEndif2] = ACTIONS(7303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7303),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3428)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3794),
    [sym_preproc_endif] = STATE(8223),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10920),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7315),
    [anon_sym_POUNDENDIF] = ACTIONS(7315),
    [anon_sym_POUNDEndif] = ACTIONS(7315),
    [anon_sym_POUNDendif2] = ACTIONS(7315),
    [anon_sym_POUNDENDIF2] = ACTIONS(7315),
    [anon_sym_POUNDEndif2] = ACTIONS(7315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7315),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3429)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3768),
    [sym_preproc_endif] = STATE(9764),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(11029),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7309),
    [anon_sym_POUNDENDIF] = ACTIONS(7309),
    [anon_sym_POUNDEndif] = ACTIONS(7309),
    [anon_sym_POUNDendif2] = ACTIONS(7309),
    [anon_sym_POUNDENDIF2] = ACTIONS(7309),
    [anon_sym_POUNDEndif2] = ACTIONS(7309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7309),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3430)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_elif] = STATE(3557),
    [sym_preproc_else] = STATE(3800),
    [sym_preproc_endif] = STATE(5915),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [aux_sym_preproc_conditional_var_repeat2] = STATE(10962),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7255),
    [anon_sym_POUNDELIF] = ACTIONS(7255),
    [anon_sym_POUNDElif] = ACTIONS(7255),
    [anon_sym_POUNDelse] = ACTIONS(7257),
    [anon_sym_POUNDELSE] = ACTIONS(7257),
    [anon_sym_POUNDElse] = ACTIONS(7257),
    [anon_sym_POUNDelse2] = ACTIONS(7257),
    [anon_sym_POUNDELSE2] = ACTIONS(7257),
    [anon_sym_POUNDElse2] = ACTIONS(7257),
    [anon_sym_POUNDendif] = ACTIONS(7323),
    [anon_sym_POUNDENDIF] = ACTIONS(7323),
    [anon_sym_POUNDEndif] = ACTIONS(7323),
    [anon_sym_POUNDendif2] = ACTIONS(7323),
    [anon_sym_POUNDENDIF2] = ACTIONS(7323),
    [anon_sym_POUNDEndif2] = ACTIONS(7323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7323),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3431)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3509),
    [sym_preproc_endif] = STATE(6544),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(2726),
    [sym_preproc_split_case_branch] = STATE(4390),
    [aux_sym__case_pattern] = STATE(3865),
    [sym_preproc_conditional_case_patterns] = STATE(3865),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(14528),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(153),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(2726),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_ELSE] = ACTIONS(5348),
    [anon_sym_Else] = ACTIONS(5348),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3432)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_COMMA] = ACTIONS(3564),
    [anon_sym_COLON] = ACTIONS(3562),
    [anon_sym_DASH] = ACTIONS(3562),
    [aux_sym_boolean_token1] = ACTIONS(3562),
    [aux_sym_boolean_token2] = ACTIONS(3562),
    [sym_decimal] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_record_type_token1] = ACTIONS(3562),
    [aux_sym_basic_type_token21] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token48] = ACTIONS(3562),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_not] = ACTIONS(3562),
    [anon_sym_NOT] = ACTIONS(3562),
    [anon_sym_Not] = ACTIONS(3562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3562),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [sym_datetime_literal] = ACTIONS(3564),
    [sym_date_literal] = ACTIONS(3562),
    [sym_time_literal] = ACTIONS(3562),
    [sym_biginteger_literal] = ACTIONS(3564),
    [anon_sym_else] = ACTIONS(3562),
    [anon_sym_ELSE] = ACTIONS(3562),
    [anon_sym_Else] = ACTIONS(3562),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_page_keyword] = ACTIONS(3562),
    [anon_sym_codeunit] = ACTIONS(3562),
    [anon_sym_CODEUNIT] = ACTIONS(3562),
    [anon_sym_Codeunit] = ACTIONS(3562),
    [anon_sym_CodeUnit] = ACTIONS(3562),
    [anon_sym_COdeunit] = ACTIONS(3562),
    [anon_sym_codeUnit] = ACTIONS(3562),
    [sym_report_keyword] = ACTIONS(3562),
    [sym_query_keyword] = ACTIONS(3562),
    [anon_sym_xmlport] = ACTIONS(3562),
    [anon_sym_XMLPORT] = ACTIONS(3562),
    [anon_sym_Xmlport] = ACTIONS(3562),
    [anon_sym_XMLport] = ACTIONS(3562),
    [anon_sym_XMLPort] = ACTIONS(3562),
    [anon_sym_XmlPort] = ACTIONS(3562),
    [anon_sym_enum] = ACTIONS(3562),
    [anon_sym_ENUM] = ACTIONS(3562),
    [anon_sym_Enum] = ACTIONS(3562),
    [anon_sym_eNUM] = ACTIONS(3562),
    [anon_sym_eNum] = ACTIONS(3562),
    [anon_sym_ENum] = ACTIONS(3562),
    [sym_temporary_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3564),
    [sym_verbatim_string] = ACTIONS(3564),
    [sym_integer] = ACTIONS(3562),
    [sym_continue_as_identifier] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
  },
  [STATE(3433)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_COMMA] = ACTIONS(3679),
    [anon_sym_COLON] = ACTIONS(3677),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
  },
  [STATE(3434)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3639),
    [anon_sym_SEMI] = ACTIONS(3641),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3641),
    [anon_sym_COMMA] = ACTIONS(3641),
    [anon_sym_COLON] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3639),
    [aux_sym_boolean_token1] = ACTIONS(3639),
    [aux_sym_boolean_token2] = ACTIONS(3639),
    [sym_decimal] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3641),
    [anon_sym_DOT_DOT] = ACTIONS(3641),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3639),
    [anon_sym_STAR] = ACTIONS(3639),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3639),
    [aux_sym_basic_type_token21] = ACTIONS(3639),
    [aux_sym_basic_type_token22] = ACTIONS(3639),
    [aux_sym_basic_type_token48] = ACTIONS(3639),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3639),
    [anon_sym_POUNDif] = ACTIONS(3641),
    [anon_sym_POUNDIF] = ACTIONS(3641),
    [anon_sym_POUNDIf] = ACTIONS(3641),
    [anon_sym_not] = ACTIONS(3639),
    [anon_sym_NOT] = ACTIONS(3639),
    [anon_sym_Not] = ACTIONS(3639),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3641),
    [aux_sym__expression_token1] = ACTIONS(3641),
    [aux_sym__expression_token2] = ACTIONS(3641),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3639),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3639),
    [anon_sym_SLASH] = ACTIONS(3639),
    [anon_sym_div] = ACTIONS(3639),
    [anon_sym_DIV] = ACTIONS(3639),
    [anon_sym_Div] = ACTIONS(3639),
    [anon_sym_mod] = ACTIONS(3639),
    [anon_sym_MOD] = ACTIONS(3639),
    [anon_sym_Mod] = ACTIONS(3639),
    [anon_sym_PLUS] = ACTIONS(3639),
    [anon_sym_GT_EQ] = ACTIONS(3641),
    [anon_sym_LT_EQ] = ACTIONS(3641),
    [anon_sym_GT] = ACTIONS(3639),
    [anon_sym_LT] = ACTIONS(3639),
    [anon_sym_LT_GT] = ACTIONS(3641),
    [anon_sym_and] = ACTIONS(3639),
    [anon_sym_AND] = ACTIONS(3639),
    [anon_sym_And] = ACTIONS(3639),
    [anon_sym_or] = ACTIONS(3639),
    [anon_sym_OR] = ACTIONS(3639),
    [anon_sym_Or] = ACTIONS(3639),
    [anon_sym_xor] = ACTIONS(3639),
    [anon_sym_XOR] = ACTIONS(3639),
    [anon_sym_Xor] = ACTIONS(3639),
    [anon_sym_QMARK] = ACTIONS(3641),
    [sym_datetime_literal] = ACTIONS(3641),
    [sym_date_literal] = ACTIONS(3639),
    [sym_time_literal] = ACTIONS(3639),
    [sym_biginteger_literal] = ACTIONS(3641),
    [anon_sym_else] = ACTIONS(3639),
    [anon_sym_ELSE] = ACTIONS(3639),
    [anon_sym_Else] = ACTIONS(3639),
    [anon_sym_in] = ACTIONS(3639),
    [anon_sym_IN] = ACTIONS(3639),
    [anon_sym_In] = ACTIONS(3639),
    [sym_page_keyword] = ACTIONS(3639),
    [anon_sym_codeunit] = ACTIONS(3639),
    [anon_sym_CODEUNIT] = ACTIONS(3639),
    [anon_sym_Codeunit] = ACTIONS(3639),
    [anon_sym_CodeUnit] = ACTIONS(3639),
    [anon_sym_COdeunit] = ACTIONS(3639),
    [anon_sym_codeUnit] = ACTIONS(3639),
    [sym_report_keyword] = ACTIONS(3639),
    [sym_query_keyword] = ACTIONS(3639),
    [anon_sym_xmlport] = ACTIONS(3639),
    [anon_sym_XMLPORT] = ACTIONS(3639),
    [anon_sym_Xmlport] = ACTIONS(3639),
    [anon_sym_XMLport] = ACTIONS(3639),
    [anon_sym_XMLPort] = ACTIONS(3639),
    [anon_sym_XmlPort] = ACTIONS(3639),
    [anon_sym_enum] = ACTIONS(3639),
    [anon_sym_ENUM] = ACTIONS(3639),
    [anon_sym_Enum] = ACTIONS(3639),
    [anon_sym_eNUM] = ACTIONS(3639),
    [anon_sym_eNum] = ACTIONS(3639),
    [anon_sym_ENum] = ACTIONS(3639),
    [sym_quoted_identifier] = ACTIONS(3641),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3641),
    [sym_verbatim_string] = ACTIONS(3641),
    [sym_integer] = ACTIONS(3639),
    [sym_continue_as_identifier] = ACTIONS(3641),
    [sym_preproc_open] = ACTIONS(3641),
  },
  [STATE(3435)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(3436)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(3438),
    [sym_identifier] = ACTIONS(3699),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(7444),
    [anon_sym_EQ] = ACTIONS(3701),
    [anon_sym_COMMA] = ACTIONS(3701),
    [anon_sym_COLON] = ACTIONS(3699),
    [anon_sym_DASH] = ACTIONS(3699),
    [aux_sym_boolean_token1] = ACTIONS(3699),
    [aux_sym_boolean_token2] = ACTIONS(3699),
    [sym_decimal] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_DOT_DOT] = ACTIONS(3701),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3699),
    [anon_sym_STAR] = ACTIONS(3699),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [aux_sym_record_type_token1] = ACTIONS(3699),
    [aux_sym_basic_type_token21] = ACTIONS(3699),
    [aux_sym_basic_type_token22] = ACTIONS(3699),
    [aux_sym_basic_type_token48] = ACTIONS(3699),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3699),
    [anon_sym_POUNDif] = ACTIONS(3701),
    [anon_sym_POUNDIF] = ACTIONS(3701),
    [anon_sym_POUNDIf] = ACTIONS(3701),
    [anon_sym_not] = ACTIONS(3699),
    [anon_sym_NOT] = ACTIONS(3699),
    [anon_sym_Not] = ACTIONS(3699),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3701),
    [aux_sym__expression_token1] = ACTIONS(3701),
    [aux_sym__expression_token2] = ACTIONS(3701),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3699),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3699),
    [anon_sym_SLASH] = ACTIONS(3699),
    [anon_sym_div] = ACTIONS(3699),
    [anon_sym_DIV] = ACTIONS(3699),
    [anon_sym_Div] = ACTIONS(3699),
    [anon_sym_mod] = ACTIONS(3699),
    [anon_sym_MOD] = ACTIONS(3699),
    [anon_sym_Mod] = ACTIONS(3699),
    [anon_sym_PLUS] = ACTIONS(3699),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT] = ACTIONS(3699),
    [anon_sym_LT] = ACTIONS(3699),
    [anon_sym_LT_GT] = ACTIONS(3701),
    [anon_sym_and] = ACTIONS(3699),
    [anon_sym_AND] = ACTIONS(3699),
    [anon_sym_And] = ACTIONS(3699),
    [anon_sym_or] = ACTIONS(3699),
    [anon_sym_OR] = ACTIONS(3699),
    [anon_sym_Or] = ACTIONS(3699),
    [anon_sym_xor] = ACTIONS(3699),
    [anon_sym_XOR] = ACTIONS(3699),
    [anon_sym_Xor] = ACTIONS(3699),
    [anon_sym_QMARK] = ACTIONS(3701),
    [sym_datetime_literal] = ACTIONS(3701),
    [sym_date_literal] = ACTIONS(3699),
    [sym_time_literal] = ACTIONS(3699),
    [sym_biginteger_literal] = ACTIONS(3701),
    [anon_sym_else] = ACTIONS(3699),
    [anon_sym_ELSE] = ACTIONS(3699),
    [anon_sym_Else] = ACTIONS(3699),
    [anon_sym_in] = ACTIONS(3699),
    [anon_sym_IN] = ACTIONS(3699),
    [anon_sym_In] = ACTIONS(3699),
    [sym_page_keyword] = ACTIONS(3699),
    [anon_sym_codeunit] = ACTIONS(3699),
    [anon_sym_CODEUNIT] = ACTIONS(3699),
    [anon_sym_Codeunit] = ACTIONS(3699),
    [anon_sym_CodeUnit] = ACTIONS(3699),
    [anon_sym_COdeunit] = ACTIONS(3699),
    [anon_sym_codeUnit] = ACTIONS(3699),
    [sym_report_keyword] = ACTIONS(3699),
    [sym_query_keyword] = ACTIONS(3699),
    [anon_sym_xmlport] = ACTIONS(3699),
    [anon_sym_XMLPORT] = ACTIONS(3699),
    [anon_sym_Xmlport] = ACTIONS(3699),
    [anon_sym_XMLport] = ACTIONS(3699),
    [anon_sym_XMLPort] = ACTIONS(3699),
    [anon_sym_XmlPort] = ACTIONS(3699),
    [anon_sym_enum] = ACTIONS(3699),
    [anon_sym_ENUM] = ACTIONS(3699),
    [anon_sym_Enum] = ACTIONS(3699),
    [anon_sym_eNUM] = ACTIONS(3699),
    [anon_sym_eNum] = ACTIONS(3699),
    [anon_sym_ENum] = ACTIONS(3699),
    [sym_temporary_keyword] = ACTIONS(3699),
    [sym_quoted_identifier] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3701),
    [sym_verbatim_string] = ACTIONS(3701),
    [sym_integer] = ACTIONS(3699),
    [sym_continue_as_identifier] = ACTIONS(3701),
    [sym_preproc_open] = ACTIONS(3701),
  },
  [STATE(3437)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(3438)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(3438),
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(7446),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_COMMA] = ACTIONS(3705),
    [anon_sym_COLON] = ACTIONS(3703),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3705),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
  },
  [STATE(3439)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(3440)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(3441)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(3442)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(3443)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(3444)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3566),
    [anon_sym_SEMI] = ACTIONS(3568),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3568),
    [anon_sym_COMMA] = ACTIONS(3568),
    [anon_sym_COLON] = ACTIONS(3566),
    [anon_sym_DASH] = ACTIONS(3566),
    [aux_sym_boolean_token1] = ACTIONS(3566),
    [aux_sym_boolean_token2] = ACTIONS(3566),
    [sym_decimal] = ACTIONS(3566),
    [anon_sym_LPAREN] = ACTIONS(3568),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3566),
    [anon_sym_STAR] = ACTIONS(3566),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3566),
    [aux_sym_basic_type_token21] = ACTIONS(3566),
    [aux_sym_basic_type_token22] = ACTIONS(3566),
    [aux_sym_basic_type_token48] = ACTIONS(3566),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3566),
    [anon_sym_POUNDif] = ACTIONS(3568),
    [anon_sym_POUNDIF] = ACTIONS(3568),
    [anon_sym_POUNDIf] = ACTIONS(3568),
    [anon_sym_not] = ACTIONS(3566),
    [anon_sym_NOT] = ACTIONS(3566),
    [anon_sym_Not] = ACTIONS(3566),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3568),
    [aux_sym__expression_token1] = ACTIONS(3568),
    [aux_sym__expression_token2] = ACTIONS(3568),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3566),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3566),
    [anon_sym_SLASH] = ACTIONS(3566),
    [anon_sym_div] = ACTIONS(3566),
    [anon_sym_DIV] = ACTIONS(3566),
    [anon_sym_Div] = ACTIONS(3566),
    [anon_sym_mod] = ACTIONS(3566),
    [anon_sym_MOD] = ACTIONS(3566),
    [anon_sym_Mod] = ACTIONS(3566),
    [anon_sym_PLUS] = ACTIONS(3566),
    [anon_sym_GT_EQ] = ACTIONS(3568),
    [anon_sym_LT_EQ] = ACTIONS(3568),
    [anon_sym_GT] = ACTIONS(3566),
    [anon_sym_LT] = ACTIONS(3566),
    [anon_sym_LT_GT] = ACTIONS(3568),
    [anon_sym_and] = ACTIONS(3566),
    [anon_sym_AND] = ACTIONS(3566),
    [anon_sym_And] = ACTIONS(3566),
    [anon_sym_or] = ACTIONS(3566),
    [anon_sym_OR] = ACTIONS(3566),
    [anon_sym_Or] = ACTIONS(3566),
    [anon_sym_xor] = ACTIONS(3566),
    [anon_sym_XOR] = ACTIONS(3566),
    [anon_sym_Xor] = ACTIONS(3566),
    [anon_sym_QMARK] = ACTIONS(3568),
    [sym_datetime_literal] = ACTIONS(3568),
    [sym_date_literal] = ACTIONS(3566),
    [sym_time_literal] = ACTIONS(3566),
    [sym_biginteger_literal] = ACTIONS(3568),
    [anon_sym_else] = ACTIONS(3566),
    [anon_sym_ELSE] = ACTIONS(3566),
    [anon_sym_Else] = ACTIONS(3566),
    [anon_sym_in] = ACTIONS(3566),
    [anon_sym_IN] = ACTIONS(3566),
    [anon_sym_In] = ACTIONS(3566),
    [sym_page_keyword] = ACTIONS(3566),
    [anon_sym_codeunit] = ACTIONS(3566),
    [anon_sym_CODEUNIT] = ACTIONS(3566),
    [anon_sym_Codeunit] = ACTIONS(3566),
    [anon_sym_CodeUnit] = ACTIONS(3566),
    [anon_sym_COdeunit] = ACTIONS(3566),
    [anon_sym_codeUnit] = ACTIONS(3566),
    [sym_report_keyword] = ACTIONS(3566),
    [sym_query_keyword] = ACTIONS(3566),
    [anon_sym_xmlport] = ACTIONS(3566),
    [anon_sym_XMLPORT] = ACTIONS(3566),
    [anon_sym_Xmlport] = ACTIONS(3566),
    [anon_sym_XMLport] = ACTIONS(3566),
    [anon_sym_XMLPort] = ACTIONS(3566),
    [anon_sym_XmlPort] = ACTIONS(3566),
    [anon_sym_enum] = ACTIONS(3566),
    [anon_sym_ENUM] = ACTIONS(3566),
    [anon_sym_Enum] = ACTIONS(3566),
    [anon_sym_eNUM] = ACTIONS(3566),
    [anon_sym_eNum] = ACTIONS(3566),
    [anon_sym_ENum] = ACTIONS(3566),
    [sym_quoted_identifier] = ACTIONS(3568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3568),
    [sym_verbatim_string] = ACTIONS(3568),
    [sym_integer] = ACTIONS(3566),
    [sym_continue_as_identifier] = ACTIONS(3568),
    [sym_preproc_open] = ACTIONS(3568),
  },
  [STATE(3445)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3679),
    [anon_sym_COMMA] = ACTIONS(3679),
    [anon_sym_COLON] = ACTIONS(3677),
    [anon_sym_DASH] = ACTIONS(3677),
    [aux_sym_boolean_token1] = ACTIONS(3677),
    [aux_sym_boolean_token2] = ACTIONS(3677),
    [sym_decimal] = ACTIONS(3677),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3677),
    [aux_sym_basic_type_token21] = ACTIONS(3677),
    [aux_sym_basic_type_token22] = ACTIONS(3677),
    [aux_sym_basic_type_token48] = ACTIONS(3677),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3677),
    [anon_sym_POUNDif] = ACTIONS(3679),
    [anon_sym_POUNDIF] = ACTIONS(3679),
    [anon_sym_POUNDIf] = ACTIONS(3679),
    [anon_sym_not] = ACTIONS(3677),
    [anon_sym_NOT] = ACTIONS(3677),
    [anon_sym_Not] = ACTIONS(3677),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3679),
    [aux_sym__expression_token1] = ACTIONS(3679),
    [aux_sym__expression_token2] = ACTIONS(3679),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3677),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3677),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_GT_EQ] = ACTIONS(3679),
    [anon_sym_LT_EQ] = ACTIONS(3679),
    [anon_sym_GT] = ACTIONS(3677),
    [anon_sym_LT] = ACTIONS(3677),
    [anon_sym_LT_GT] = ACTIONS(3679),
    [anon_sym_and] = ACTIONS(3677),
    [anon_sym_AND] = ACTIONS(3677),
    [anon_sym_And] = ACTIONS(3677),
    [anon_sym_or] = ACTIONS(3677),
    [anon_sym_OR] = ACTIONS(3677),
    [anon_sym_Or] = ACTIONS(3677),
    [anon_sym_xor] = ACTIONS(3677),
    [anon_sym_XOR] = ACTIONS(3677),
    [anon_sym_Xor] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3679),
    [sym_datetime_literal] = ACTIONS(3679),
    [sym_date_literal] = ACTIONS(3677),
    [sym_time_literal] = ACTIONS(3677),
    [sym_biginteger_literal] = ACTIONS(3679),
    [anon_sym_else] = ACTIONS(3677),
    [anon_sym_ELSE] = ACTIONS(3677),
    [anon_sym_Else] = ACTIONS(3677),
    [anon_sym_in] = ACTIONS(3677),
    [anon_sym_IN] = ACTIONS(3677),
    [anon_sym_In] = ACTIONS(3677),
    [sym_page_keyword] = ACTIONS(3677),
    [anon_sym_codeunit] = ACTIONS(3677),
    [anon_sym_CODEUNIT] = ACTIONS(3677),
    [anon_sym_Codeunit] = ACTIONS(3677),
    [anon_sym_CodeUnit] = ACTIONS(3677),
    [anon_sym_COdeunit] = ACTIONS(3677),
    [anon_sym_codeUnit] = ACTIONS(3677),
    [sym_report_keyword] = ACTIONS(3677),
    [sym_query_keyword] = ACTIONS(3677),
    [anon_sym_xmlport] = ACTIONS(3677),
    [anon_sym_XMLPORT] = ACTIONS(3677),
    [anon_sym_Xmlport] = ACTIONS(3677),
    [anon_sym_XMLport] = ACTIONS(3677),
    [anon_sym_XMLPort] = ACTIONS(3677),
    [anon_sym_XmlPort] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_ENUM] = ACTIONS(3677),
    [anon_sym_Enum] = ACTIONS(3677),
    [anon_sym_eNUM] = ACTIONS(3677),
    [anon_sym_eNum] = ACTIONS(3677),
    [anon_sym_ENum] = ACTIONS(3677),
    [sym_quoted_identifier] = ACTIONS(3679),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3679),
    [sym_verbatim_string] = ACTIONS(3679),
    [sym_integer] = ACTIONS(3677),
    [sym_continue_as_identifier] = ACTIONS(3679),
    [sym_preproc_open] = ACTIONS(3679),
  },
  [STATE(3446)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3447)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3448)] = {
    [sym_argument_list] = STATE(7165),
    [sym_identifier] = ACTIONS(5410),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [aux_sym_where_condition_token1] = ACTIONS(5410),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_basic_type_token22] = ACTIONS(5410),
    [aux_sym_basic_type_token53] = ACTIONS(5410),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5410),
    [aux_sym_modify_modification_token1] = ACTIONS(5410),
    [aux_sym_separator_action_token1] = ACTIONS(5410),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [aux_sym_type_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [anon_sym_POUNDelif] = ACTIONS(5405),
    [anon_sym_POUNDELIF] = ACTIONS(5405),
    [anon_sym_POUNDElif] = ACTIONS(5405),
    [anon_sym_POUNDelse] = ACTIONS(5405),
    [anon_sym_POUNDELSE] = ACTIONS(5405),
    [anon_sym_POUNDElse] = ACTIONS(5405),
    [anon_sym_POUNDelse2] = ACTIONS(5405),
    [anon_sym_POUNDELSE2] = ACTIONS(5405),
    [anon_sym_POUNDElse2] = ACTIONS(5405),
    [anon_sym_POUNDendif] = ACTIONS(5405),
    [anon_sym_POUNDENDIF] = ACTIONS(5405),
    [anon_sym_POUNDEndif] = ACTIONS(5405),
    [anon_sym_POUNDendif2] = ACTIONS(5405),
    [anon_sym_POUNDENDIF2] = ACTIONS(5405),
    [anon_sym_POUNDEndif2] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_table_keyword] = ACTIONS(5410),
    [sym_procedure_keyword] = ACTIONS(5410),
    [sym_trigger_keyword] = ACTIONS(5410),
    [sym_var_keyword] = ACTIONS(5410),
    [sym_local_keyword] = ACTIONS(5410),
    [sym_internal_keyword] = ACTIONS(5410),
    [sym_protected_keyword] = ACTIONS(5410),
    [sym_event_keyword] = ACTIONS(5410),
    [sym_fields_keyword] = ACTIONS(5410),
    [sym_keys_keyword] = ACTIONS(5410),
    [sym_key_keyword] = ACTIONS(5410),
    [sym_fieldgroups_keyword] = ACTIONS(5410),
    [sym_actions_keyword] = ACTIONS(5410),
    [sym_layout_keyword] = ACTIONS(5410),
    [sym_dataset_keyword] = ACTIONS(5410),
    [sym_elements_keyword] = ACTIONS(5410),
    [sym_labels_keyword] = ACTIONS(5410),
    [sym_rendering_keyword] = ACTIONS(5410),
    [sym_requestpage_keyword] = ACTIONS(5410),
    [sym_schema_keyword] = ACTIONS(5410),
    [sym_views_keyword] = ACTIONS(5410),
    [sym_quoted_identifier] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
    [sym_preproc_close] = ACTIONS(5405),
    [sym_var_attribute_open] = ACTIONS(5405),
  },
  [STATE(3449)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3450)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3451)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3452)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3453)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3454)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3455)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3647),
    [anon_sym_SEMI] = ACTIONS(3649),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3649),
    [anon_sym_COMMA] = ACTIONS(3649),
    [anon_sym_COLON] = ACTIONS(3647),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3647),
    [aux_sym_boolean_token2] = ACTIONS(3647),
    [sym_decimal] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3649),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3647),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3647),
    [aux_sym_basic_type_token21] = ACTIONS(3647),
    [aux_sym_basic_type_token22] = ACTIONS(3647),
    [aux_sym_basic_type_token48] = ACTIONS(3647),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3647),
    [anon_sym_POUNDif] = ACTIONS(3649),
    [anon_sym_POUNDIF] = ACTIONS(3649),
    [anon_sym_POUNDIf] = ACTIONS(3649),
    [anon_sym_not] = ACTIONS(3647),
    [anon_sym_NOT] = ACTIONS(3647),
    [anon_sym_Not] = ACTIONS(3647),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3649),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3647),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3647),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3649),
    [anon_sym_LT_EQ] = ACTIONS(3649),
    [anon_sym_GT] = ACTIONS(3647),
    [anon_sym_LT] = ACTIONS(3647),
    [anon_sym_LT_GT] = ACTIONS(3649),
    [anon_sym_and] = ACTIONS(3647),
    [anon_sym_AND] = ACTIONS(3647),
    [anon_sym_And] = ACTIONS(3647),
    [anon_sym_or] = ACTIONS(3647),
    [anon_sym_OR] = ACTIONS(3647),
    [anon_sym_Or] = ACTIONS(3647),
    [anon_sym_xor] = ACTIONS(3647),
    [anon_sym_XOR] = ACTIONS(3647),
    [anon_sym_Xor] = ACTIONS(3647),
    [anon_sym_QMARK] = ACTIONS(3649),
    [sym_datetime_literal] = ACTIONS(3649),
    [sym_date_literal] = ACTIONS(3647),
    [sym_time_literal] = ACTIONS(3647),
    [sym_biginteger_literal] = ACTIONS(3649),
    [anon_sym_else] = ACTIONS(3647),
    [anon_sym_ELSE] = ACTIONS(3647),
    [anon_sym_Else] = ACTIONS(3647),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3647),
    [anon_sym_codeunit] = ACTIONS(3647),
    [anon_sym_CODEUNIT] = ACTIONS(3647),
    [anon_sym_Codeunit] = ACTIONS(3647),
    [anon_sym_CodeUnit] = ACTIONS(3647),
    [anon_sym_COdeunit] = ACTIONS(3647),
    [anon_sym_codeUnit] = ACTIONS(3647),
    [sym_report_keyword] = ACTIONS(3647),
    [sym_query_keyword] = ACTIONS(3647),
    [anon_sym_xmlport] = ACTIONS(3647),
    [anon_sym_XMLPORT] = ACTIONS(3647),
    [anon_sym_Xmlport] = ACTIONS(3647),
    [anon_sym_XMLport] = ACTIONS(3647),
    [anon_sym_XMLPort] = ACTIONS(3647),
    [anon_sym_XmlPort] = ACTIONS(3647),
    [anon_sym_enum] = ACTIONS(3647),
    [anon_sym_ENUM] = ACTIONS(3647),
    [anon_sym_Enum] = ACTIONS(3647),
    [anon_sym_eNUM] = ACTIONS(3647),
    [anon_sym_eNum] = ACTIONS(3647),
    [anon_sym_ENum] = ACTIONS(3647),
    [sym_quoted_identifier] = ACTIONS(3649),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3649),
    [sym_verbatim_string] = ACTIONS(3649),
    [sym_integer] = ACTIONS(3647),
    [sym_continue_as_identifier] = ACTIONS(3649),
    [sym_preproc_open] = ACTIONS(3649),
  },
  [STATE(3456)] = {
    [sym_identifier] = ACTIONS(6641),
    [anon_sym_SEMI] = ACTIONS(6643),
    [anon_sym_DASH] = ACTIONS(6643),
    [aux_sym_boolean_token1] = ACTIONS(6641),
    [aux_sym_boolean_token2] = ACTIONS(6641),
    [sym_decimal] = ACTIONS(6641),
    [anon_sym_LPAREN] = ACTIONS(6643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6641),
    [anon_sym_LBRACK] = ACTIONS(6643),
    [aux_sym_record_type_token1] = ACTIONS(6641),
    [aux_sym_basic_type_token21] = ACTIONS(6641),
    [aux_sym_basic_type_token22] = ACTIONS(6641),
    [aux_sym_basic_type_token48] = ACTIONS(6641),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(6641),
    [anon_sym_POUNDif] = ACTIONS(6643),
    [anon_sym_POUNDIF] = ACTIONS(6643),
    [anon_sym_POUNDIf] = ACTIONS(6643),
    [anon_sym_not] = ACTIONS(6641),
    [anon_sym_NOT] = ACTIONS(6641),
    [anon_sym_Not] = ACTIONS(6641),
    [anon_sym_POUNDendif] = ACTIONS(6643),
    [anon_sym_POUNDENDIF] = ACTIONS(6643),
    [anon_sym_POUNDEndif] = ACTIONS(6643),
    [anon_sym_POUNDendif2] = ACTIONS(6643),
    [anon_sym_POUNDENDIF2] = ACTIONS(6643),
    [anon_sym_POUNDEndif2] = ACTIONS(6643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6641),
    [anon_sym_PLUS] = ACTIONS(6643),
    [sym_datetime_literal] = ACTIONS(6643),
    [sym_date_literal] = ACTIONS(6641),
    [sym_time_literal] = ACTIONS(6641),
    [sym_biginteger_literal] = ACTIONS(6643),
    [anon_sym_if] = ACTIONS(6641),
    [anon_sym_IF] = ACTIONS(6641),
    [anon_sym_If] = ACTIONS(6641),
    [anon_sym_case] = ACTIONS(6641),
    [anon_sym_CASE] = ACTIONS(6641),
    [anon_sym_Case] = ACTIONS(6641),
    [anon_sym_for] = ACTIONS(6641),
    [anon_sym_FOR] = ACTIONS(6641),
    [anon_sym_For] = ACTIONS(6641),
    [anon_sym_foreach] = ACTIONS(6641),
    [anon_sym_FOREACH] = ACTIONS(6641),
    [anon_sym_Foreach] = ACTIONS(6641),
    [anon_sym_while] = ACTIONS(6641),
    [anon_sym_WHILE] = ACTIONS(6641),
    [anon_sym_While] = ACTIONS(6641),
    [anon_sym_repeat] = ACTIONS(6641),
    [anon_sym_REPEAT] = ACTIONS(6641),
    [anon_sym_Repeat] = ACTIONS(6641),
    [anon_sym_exit] = ACTIONS(6641),
    [anon_sym_EXIT] = ACTIONS(6641),
    [anon_sym_Exit] = ACTIONS(6641),
    [anon_sym_continue] = ACTIONS(6641),
    [anon_sym_CONTINUE] = ACTIONS(6641),
    [anon_sym_Continue] = ACTIONS(6641),
    [anon_sym_break] = ACTIONS(6641),
    [anon_sym_BREAK] = ACTIONS(6641),
    [anon_sym_Break] = ACTIONS(6641),
    [anon_sym_with] = ACTIONS(6641),
    [anon_sym_WITH] = ACTIONS(6641),
    [anon_sym_With] = ACTIONS(6641),
    [sym_asserterror_keyword] = ACTIONS(6643),
    [sym_page_keyword] = ACTIONS(6641),
    [anon_sym_codeunit] = ACTIONS(6641),
    [anon_sym_CODEUNIT] = ACTIONS(6641),
    [anon_sym_Codeunit] = ACTIONS(6641),
    [anon_sym_CodeUnit] = ACTIONS(6641),
    [anon_sym_COdeunit] = ACTIONS(6641),
    [anon_sym_codeUnit] = ACTIONS(6641),
    [sym_report_keyword] = ACTIONS(6641),
    [sym_query_keyword] = ACTIONS(6641),
    [anon_sym_xmlport] = ACTIONS(6641),
    [anon_sym_XMLPORT] = ACTIONS(6641),
    [anon_sym_Xmlport] = ACTIONS(6641),
    [anon_sym_XMLport] = ACTIONS(6641),
    [anon_sym_XMLPort] = ACTIONS(6641),
    [anon_sym_XmlPort] = ACTIONS(6641),
    [anon_sym_enum] = ACTIONS(6641),
    [anon_sym_ENUM] = ACTIONS(6641),
    [anon_sym_Enum] = ACTIONS(6641),
    [anon_sym_eNUM] = ACTIONS(6641),
    [anon_sym_eNum] = ACTIONS(6641),
    [anon_sym_ENum] = ACTIONS(6641),
    [sym_quoted_identifier] = ACTIONS(6643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6643),
    [sym_verbatim_string] = ACTIONS(6643),
    [sym_integer] = ACTIONS(6641),
    [sym_continue_as_identifier] = ACTIONS(6643),
    [sym_preproc_open] = ACTIONS(6643),
    [sym_preproc_close] = ACTIONS(6643),
    [sym_begin_keyword] = ACTIONS(6643),
  },
  [STATE(3457)] = {
    [sym__body_element] = STATE(8030),
    [sym_empty_statement] = STATE(8030),
    [sym_property] = STATE(8030),
    [sym_permissions_property] = STATE(8030),
    [sym_table_relation_property] = STATE(8030),
    [sym_fields_section] = STATE(8030),
    [sym_keys_section] = STATE(8030),
    [sym_fieldgroups_section] = STATE(8030),
    [sym_enum_value_declaration] = STATE(8030),
    [sym_labels_section] = STATE(8030),
    [sym_layout_section] = STATE(8030),
    [sym_modify_modification] = STATE(8030),
    [sym_actions_section] = STATE(8030),
    [sym_views_section] = STATE(8030),
    [sym_dataset_section] = STATE(8030),
    [sym_requestpage_section] = STATE(8030),
    [sym_rendering_section] = STATE(8030),
    [sym_elements_section] = STATE(8030),
    [sym_query_dataitem] = STATE(3581),
    [sym__query_body_element] = STATE(3581),
    [sym_preproc_conditional_query] = STATE(3581),
    [sym_query_column] = STATE(3581),
    [sym_query_filter] = STATE(3581),
    [sym_schema_section] = STATE(8030),
    [sym_assembly_declaration] = STATE(8030),
    [sym_event_declaration] = STATE(8030),
    [sym_procedure] = STATE(8030),
    [sym_preproc_split_procedure] = STATE(8030),
    [sym__procedure_preamble] = STATE(10810),
    [sym_preproc_split_procedure_preamble] = STATE(8030),
    [sym__procedure_header] = STATE(9981),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(8030),
    [sym_var_section] = STATE(8030),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(8030),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_elif] = STATE(3617),
    [sym_preproc_else] = STATE(3967),
    [sym_preproc_endif] = STATE(9783),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3826),
    [aux_sym_query_dataitem_repeat1] = STATE(3581),
    [aux_sym_preproc_conditional_query_repeat1] = STATE(10976),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10844),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3458)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token53] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3562),
    [aux_sym_modify_modification_token1] = ACTIONS(3562),
    [aux_sym_separator_action_token1] = ACTIONS(3562),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [aux_sym_type_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_table_keyword] = ACTIONS(3562),
    [sym_procedure_keyword] = ACTIONS(3562),
    [sym_trigger_keyword] = ACTIONS(3562),
    [sym_var_keyword] = ACTIONS(3562),
    [sym_local_keyword] = ACTIONS(3562),
    [sym_internal_keyword] = ACTIONS(3562),
    [sym_protected_keyword] = ACTIONS(3562),
    [sym_event_keyword] = ACTIONS(3562),
    [sym_fields_keyword] = ACTIONS(3562),
    [sym_keys_keyword] = ACTIONS(3562),
    [sym_key_keyword] = ACTIONS(3562),
    [sym_fieldgroups_keyword] = ACTIONS(3562),
    [sym_actions_keyword] = ACTIONS(3562),
    [sym_layout_keyword] = ACTIONS(3562),
    [sym_dataset_keyword] = ACTIONS(3562),
    [sym_elements_keyword] = ACTIONS(3562),
    [sym_labels_keyword] = ACTIONS(3562),
    [sym_rendering_keyword] = ACTIONS(3562),
    [sym_requestpage_keyword] = ACTIONS(3562),
    [sym_schema_keyword] = ACTIONS(3562),
    [sym_views_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
    [sym_var_attribute_open] = ACTIONS(3564),
  },
  [STATE(3459)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3576),
    [anon_sym_SEMI] = ACTIONS(3578),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3578),
    [anon_sym_COLON] = ACTIONS(3576),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3576),
    [aux_sym_boolean_token2] = ACTIONS(3576),
    [sym_decimal] = ACTIONS(3576),
    [anon_sym_LPAREN] = ACTIONS(3578),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3576),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3576),
    [aux_sym_basic_type_token21] = ACTIONS(3576),
    [aux_sym_basic_type_token22] = ACTIONS(3576),
    [aux_sym_basic_type_token48] = ACTIONS(3576),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3576),
    [anon_sym_POUNDif] = ACTIONS(3578),
    [anon_sym_POUNDIF] = ACTIONS(3578),
    [anon_sym_POUNDIf] = ACTIONS(3578),
    [anon_sym_not] = ACTIONS(3576),
    [anon_sym_NOT] = ACTIONS(3576),
    [anon_sym_Not] = ACTIONS(3576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(7469),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3576),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3576),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(7471),
    [anon_sym_OR] = ACTIONS(7473),
    [anon_sym_Or] = ACTIONS(7475),
    [anon_sym_xor] = ACTIONS(7477),
    [anon_sym_XOR] = ACTIONS(7479),
    [anon_sym_Xor] = ACTIONS(7481),
    [anon_sym_QMARK] = ACTIONS(7483),
    [sym_datetime_literal] = ACTIONS(3578),
    [sym_date_literal] = ACTIONS(3576),
    [sym_time_literal] = ACTIONS(3576),
    [sym_biginteger_literal] = ACTIONS(3578),
    [anon_sym_else] = ACTIONS(3576),
    [anon_sym_ELSE] = ACTIONS(3576),
    [anon_sym_Else] = ACTIONS(3576),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3576),
    [anon_sym_codeunit] = ACTIONS(3576),
    [anon_sym_CODEUNIT] = ACTIONS(3576),
    [anon_sym_Codeunit] = ACTIONS(3576),
    [anon_sym_CodeUnit] = ACTIONS(3576),
    [anon_sym_COdeunit] = ACTIONS(3576),
    [anon_sym_codeUnit] = ACTIONS(3576),
    [sym_report_keyword] = ACTIONS(3576),
    [sym_query_keyword] = ACTIONS(3576),
    [anon_sym_xmlport] = ACTIONS(3576),
    [anon_sym_XMLPORT] = ACTIONS(3576),
    [anon_sym_Xmlport] = ACTIONS(3576),
    [anon_sym_XMLport] = ACTIONS(3576),
    [anon_sym_XMLPort] = ACTIONS(3576),
    [anon_sym_XmlPort] = ACTIONS(3576),
    [anon_sym_enum] = ACTIONS(3576),
    [anon_sym_ENUM] = ACTIONS(3576),
    [anon_sym_Enum] = ACTIONS(3576),
    [anon_sym_eNUM] = ACTIONS(3576),
    [anon_sym_eNum] = ACTIONS(3576),
    [anon_sym_ENum] = ACTIONS(3576),
    [sym_quoted_identifier] = ACTIONS(3578),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3578),
    [sym_verbatim_string] = ACTIONS(3578),
    [sym_integer] = ACTIONS(3576),
    [sym_continue_as_identifier] = ACTIONS(3578),
    [sym_preproc_open] = ACTIONS(3578),
  },
  [STATE(3460)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token53] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3562),
    [aux_sym_modify_modification_token1] = ACTIONS(3562),
    [aux_sym_separator_action_token1] = ACTIONS(3562),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [aux_sym_type_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_table_keyword] = ACTIONS(3562),
    [sym_procedure_keyword] = ACTIONS(3562),
    [sym_trigger_keyword] = ACTIONS(3562),
    [sym_var_keyword] = ACTIONS(3562),
    [sym_local_keyword] = ACTIONS(3562),
    [sym_internal_keyword] = ACTIONS(3562),
    [sym_protected_keyword] = ACTIONS(3562),
    [sym_event_keyword] = ACTIONS(3562),
    [sym_fields_keyword] = ACTIONS(3562),
    [sym_keys_keyword] = ACTIONS(3562),
    [sym_key_keyword] = ACTIONS(3562),
    [sym_fieldgroups_keyword] = ACTIONS(3562),
    [sym_actions_keyword] = ACTIONS(3562),
    [sym_layout_keyword] = ACTIONS(3562),
    [sym_dataset_keyword] = ACTIONS(3562),
    [sym_elements_keyword] = ACTIONS(3562),
    [sym_labels_keyword] = ACTIONS(3562),
    [sym_rendering_keyword] = ACTIONS(3562),
    [sym_requestpage_keyword] = ACTIONS(3562),
    [sym_schema_keyword] = ACTIONS(3562),
    [sym_views_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
    [sym_var_attribute_open] = ACTIONS(3564),
  },
  [STATE(3461)] = {
    [sym_identifier] = ACTIONS(3784),
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [aux_sym_where_clause_token1] = ACTIONS(3786),
    [aux_sym_where_condition_token1] = ACTIONS(3784),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3784),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_basic_type_token53] = ACTIONS(3784),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3784),
    [aux_sym_modify_modification_token1] = ACTIONS(3784),
    [aux_sym_separator_action_token1] = ACTIONS(3784),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3784),
    [aux_sym_type_declaration_token1] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_POUNDelif] = ACTIONS(3786),
    [anon_sym_POUNDELIF] = ACTIONS(3786),
    [anon_sym_POUNDElif] = ACTIONS(3786),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [anon_sym_POUNDendif] = ACTIONS(3786),
    [anon_sym_POUNDENDIF] = ACTIONS(3786),
    [anon_sym_POUNDEndif] = ACTIONS(3786),
    [anon_sym_POUNDendif2] = ACTIONS(3786),
    [anon_sym_POUNDENDIF2] = ACTIONS(3786),
    [anon_sym_POUNDEndif2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3784),
    [anon_sym_DIV] = ACTIONS(3784),
    [anon_sym_Div] = ACTIONS(3784),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3784),
    [anon_sym_AND] = ACTIONS(3784),
    [anon_sym_And] = ACTIONS(3784),
    [anon_sym_or] = ACTIONS(3784),
    [anon_sym_OR] = ACTIONS(3784),
    [anon_sym_Or] = ACTIONS(3784),
    [anon_sym_xor] = ACTIONS(3784),
    [anon_sym_XOR] = ACTIONS(3784),
    [anon_sym_Xor] = ACTIONS(3784),
    [anon_sym_QMARK] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_table_keyword] = ACTIONS(3784),
    [sym_procedure_keyword] = ACTIONS(3784),
    [sym_trigger_keyword] = ACTIONS(3784),
    [sym_var_keyword] = ACTIONS(3784),
    [sym_local_keyword] = ACTIONS(3784),
    [sym_internal_keyword] = ACTIONS(3784),
    [sym_protected_keyword] = ACTIONS(3784),
    [sym_event_keyword] = ACTIONS(3784),
    [sym_fields_keyword] = ACTIONS(3784),
    [sym_keys_keyword] = ACTIONS(3784),
    [sym_key_keyword] = ACTIONS(3784),
    [sym_fieldgroups_keyword] = ACTIONS(3784),
    [sym_actions_keyword] = ACTIONS(3784),
    [sym_layout_keyword] = ACTIONS(3784),
    [sym_dataset_keyword] = ACTIONS(3784),
    [sym_elements_keyword] = ACTIONS(3784),
    [sym_labels_keyword] = ACTIONS(3784),
    [sym_rendering_keyword] = ACTIONS(3784),
    [sym_requestpage_keyword] = ACTIONS(3784),
    [sym_schema_keyword] = ACTIONS(3784),
    [sym_views_keyword] = ACTIONS(3784),
    [sym_quoted_identifier] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
    [sym_preproc_close] = ACTIONS(3786),
    [sym_var_attribute_open] = ACTIONS(3786),
  },
  [STATE(3462)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3673),
    [anon_sym_SEMI] = ACTIONS(3675),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3675),
    [anon_sym_COLON] = ACTIONS(3673),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3673),
    [aux_sym_boolean_token2] = ACTIONS(3673),
    [sym_decimal] = ACTIONS(3673),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3673),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3673),
    [aux_sym_basic_type_token21] = ACTIONS(3673),
    [aux_sym_basic_type_token22] = ACTIONS(3673),
    [aux_sym_basic_type_token48] = ACTIONS(3673),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3673),
    [anon_sym_POUNDif] = ACTIONS(3675),
    [anon_sym_POUNDIF] = ACTIONS(3675),
    [anon_sym_POUNDIf] = ACTIONS(3675),
    [anon_sym_not] = ACTIONS(3673),
    [anon_sym_NOT] = ACTIONS(3673),
    [anon_sym_Not] = ACTIONS(3673),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3675),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3673),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(7471),
    [anon_sym_OR] = ACTIONS(7473),
    [anon_sym_Or] = ACTIONS(7475),
    [anon_sym_xor] = ACTIONS(7477),
    [anon_sym_XOR] = ACTIONS(7479),
    [anon_sym_Xor] = ACTIONS(7481),
    [anon_sym_QMARK] = ACTIONS(7483),
    [sym_datetime_literal] = ACTIONS(3675),
    [sym_date_literal] = ACTIONS(3673),
    [sym_time_literal] = ACTIONS(3673),
    [sym_biginteger_literal] = ACTIONS(3675),
    [anon_sym_else] = ACTIONS(3673),
    [anon_sym_ELSE] = ACTIONS(3673),
    [anon_sym_Else] = ACTIONS(3673),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3673),
    [anon_sym_codeunit] = ACTIONS(3673),
    [anon_sym_CODEUNIT] = ACTIONS(3673),
    [anon_sym_Codeunit] = ACTIONS(3673),
    [anon_sym_CodeUnit] = ACTIONS(3673),
    [anon_sym_COdeunit] = ACTIONS(3673),
    [anon_sym_codeUnit] = ACTIONS(3673),
    [sym_report_keyword] = ACTIONS(3673),
    [sym_query_keyword] = ACTIONS(3673),
    [anon_sym_xmlport] = ACTIONS(3673),
    [anon_sym_XMLPORT] = ACTIONS(3673),
    [anon_sym_Xmlport] = ACTIONS(3673),
    [anon_sym_XMLport] = ACTIONS(3673),
    [anon_sym_XMLPort] = ACTIONS(3673),
    [anon_sym_XmlPort] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_ENUM] = ACTIONS(3673),
    [anon_sym_Enum] = ACTIONS(3673),
    [anon_sym_eNUM] = ACTIONS(3673),
    [anon_sym_eNum] = ACTIONS(3673),
    [anon_sym_ENum] = ACTIONS(3673),
    [sym_quoted_identifier] = ACTIONS(3675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3675),
    [sym_verbatim_string] = ACTIONS(3675),
    [sym_integer] = ACTIONS(3673),
    [sym_continue_as_identifier] = ACTIONS(3675),
    [sym_preproc_open] = ACTIONS(3675),
  },
  [STATE(3463)] = {
    [sym__body_element] = STATE(8030),
    [sym_empty_statement] = STATE(8030),
    [sym_property] = STATE(8030),
    [sym_permissions_property] = STATE(8030),
    [sym_table_relation_property] = STATE(8030),
    [sym_fields_section] = STATE(8030),
    [sym_keys_section] = STATE(8030),
    [sym_fieldgroups_section] = STATE(8030),
    [sym_enum_value_declaration] = STATE(8030),
    [sym_labels_section] = STATE(8030),
    [sym_layout_section] = STATE(8030),
    [sym_modify_modification] = STATE(8030),
    [sym_actions_section] = STATE(8030),
    [sym_views_section] = STATE(8030),
    [sym_dataset_section] = STATE(8030),
    [sym_requestpage_section] = STATE(8030),
    [sym_rendering_section] = STATE(8030),
    [sym_elements_section] = STATE(8030),
    [sym_query_dataitem] = STATE(3589),
    [sym__query_body_element] = STATE(3589),
    [sym_preproc_conditional_query] = STATE(3589),
    [sym_query_column] = STATE(3589),
    [sym_query_filter] = STATE(3589),
    [sym_schema_section] = STATE(8030),
    [sym_assembly_declaration] = STATE(8030),
    [sym_event_declaration] = STATE(8030),
    [sym_procedure] = STATE(8030),
    [sym_preproc_split_procedure] = STATE(8030),
    [sym__procedure_preamble] = STATE(10930),
    [sym_preproc_split_procedure_preamble] = STATE(8030),
    [sym__procedure_header] = STATE(9970),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(8030),
    [sym_var_section] = STATE(8030),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(8030),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_elif] = STATE(3617),
    [sym_preproc_else] = STATE(3970),
    [sym_preproc_endif] = STATE(8056),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3834),
    [aux_sym_query_dataitem_repeat1] = STATE(3589),
    [aux_sym_preproc_conditional_query_repeat1] = STATE(10823),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10978),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3464)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3726),
    [anon_sym_SEMI] = ACTIONS(3728),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3728),
    [anon_sym_COMMA] = ACTIONS(3728),
    [anon_sym_COLON] = ACTIONS(3726),
    [anon_sym_DASH] = ACTIONS(3726),
    [aux_sym_boolean_token1] = ACTIONS(3726),
    [aux_sym_boolean_token2] = ACTIONS(3726),
    [sym_decimal] = ACTIONS(3726),
    [anon_sym_LPAREN] = ACTIONS(3728),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3726),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3726),
    [aux_sym_basic_type_token21] = ACTIONS(3726),
    [aux_sym_basic_type_token22] = ACTIONS(3726),
    [aux_sym_basic_type_token48] = ACTIONS(3726),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3726),
    [anon_sym_POUNDif] = ACTIONS(3728),
    [anon_sym_POUNDIF] = ACTIONS(3728),
    [anon_sym_POUNDIf] = ACTIONS(3728),
    [anon_sym_not] = ACTIONS(3726),
    [anon_sym_NOT] = ACTIONS(3726),
    [anon_sym_Not] = ACTIONS(3726),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3728),
    [aux_sym__expression_token1] = ACTIONS(3728),
    [aux_sym__expression_token2] = ACTIONS(3728),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3726),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3726),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(3726),
    [anon_sym_GT_EQ] = ACTIONS(3728),
    [anon_sym_LT_EQ] = ACTIONS(3728),
    [anon_sym_GT] = ACTIONS(3726),
    [anon_sym_LT] = ACTIONS(3726),
    [anon_sym_LT_GT] = ACTIONS(3728),
    [anon_sym_and] = ACTIONS(3726),
    [anon_sym_AND] = ACTIONS(3726),
    [anon_sym_And] = ACTIONS(3726),
    [anon_sym_or] = ACTIONS(3726),
    [anon_sym_OR] = ACTIONS(3726),
    [anon_sym_Or] = ACTIONS(3726),
    [anon_sym_xor] = ACTIONS(3726),
    [anon_sym_XOR] = ACTIONS(3726),
    [anon_sym_Xor] = ACTIONS(3726),
    [anon_sym_QMARK] = ACTIONS(3728),
    [sym_datetime_literal] = ACTIONS(3728),
    [sym_date_literal] = ACTIONS(3726),
    [sym_time_literal] = ACTIONS(3726),
    [sym_biginteger_literal] = ACTIONS(3728),
    [anon_sym_else] = ACTIONS(3726),
    [anon_sym_ELSE] = ACTIONS(3726),
    [anon_sym_Else] = ACTIONS(3726),
    [anon_sym_in] = ACTIONS(3726),
    [anon_sym_IN] = ACTIONS(3726),
    [anon_sym_In] = ACTIONS(3726),
    [sym_page_keyword] = ACTIONS(3726),
    [anon_sym_codeunit] = ACTIONS(3726),
    [anon_sym_CODEUNIT] = ACTIONS(3726),
    [anon_sym_Codeunit] = ACTIONS(3726),
    [anon_sym_CodeUnit] = ACTIONS(3726),
    [anon_sym_COdeunit] = ACTIONS(3726),
    [anon_sym_codeUnit] = ACTIONS(3726),
    [sym_report_keyword] = ACTIONS(3726),
    [sym_query_keyword] = ACTIONS(3726),
    [anon_sym_xmlport] = ACTIONS(3726),
    [anon_sym_XMLPORT] = ACTIONS(3726),
    [anon_sym_Xmlport] = ACTIONS(3726),
    [anon_sym_XMLport] = ACTIONS(3726),
    [anon_sym_XMLPort] = ACTIONS(3726),
    [anon_sym_XmlPort] = ACTIONS(3726),
    [anon_sym_enum] = ACTIONS(3726),
    [anon_sym_ENUM] = ACTIONS(3726),
    [anon_sym_Enum] = ACTIONS(3726),
    [anon_sym_eNUM] = ACTIONS(3726),
    [anon_sym_eNum] = ACTIONS(3726),
    [anon_sym_ENum] = ACTIONS(3726),
    [sym_quoted_identifier] = ACTIONS(3728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3728),
    [sym_verbatim_string] = ACTIONS(3728),
    [sym_integer] = ACTIONS(3726),
    [sym_continue_as_identifier] = ACTIONS(3728),
    [sym_preproc_open] = ACTIONS(3728),
  },
  [STATE(3465)] = {
    [sym_argument_list] = STATE(3504),
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(3683),
    [anon_sym_COLON] = ACTIONS(3681),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(7485),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(7487),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
  },
  [STATE(3466)] = {
    [sym_boolean] = STATE(7226),
    [sym_option_member] = STATE(7227),
    [sym_keyword_identifier] = STATE(7226),
    [sym_codeunit_keyword] = STATE(6858),
    [sym_xmlport_keyword] = STATE(6858),
    [sym_enum_keyword] = STATE(6858),
    [sym_keyword_as_identifier] = STATE(7226),
    [sym_identifier] = ACTIONS(3993),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_DOT] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(6693),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [aux_sym_where_condition_token1] = ACTIONS(7225),
    [anon_sym_DOT_DOT] = ACTIONS(611),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(6034),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7225),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7225),
    [aux_sym_separator_action_token1] = ACTIONS(7225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7225),
    [aux_sym_type_declaration_token1] = ACTIONS(7225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(611),
    [aux_sym__expression_token1] = ACTIONS(611),
    [aux_sym__expression_token2] = ACTIONS(611),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1382),
    [anon_sym_SLASH] = ACTIONS(613),
    [anon_sym_div] = ACTIONS(613),
    [anon_sym_DIV] = ACTIONS(613),
    [anon_sym_Div] = ACTIONS(613),
    [anon_sym_mod] = ACTIONS(613),
    [anon_sym_MOD] = ACTIONS(613),
    [anon_sym_Mod] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_GT] = ACTIONS(611),
    [anon_sym_and] = ACTIONS(613),
    [anon_sym_AND] = ACTIONS(613),
    [anon_sym_And] = ACTIONS(613),
    [anon_sym_or] = ACTIONS(613),
    [anon_sym_OR] = ACTIONS(613),
    [anon_sym_Or] = ACTIONS(613),
    [anon_sym_xor] = ACTIONS(613),
    [anon_sym_XOR] = ACTIONS(613),
    [anon_sym_Xor] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [anon_sym_else] = ACTIONS(613),
    [anon_sym_ELSE] = ACTIONS(613),
    [anon_sym_Else] = ACTIONS(613),
    [anon_sym_in] = ACTIONS(613),
    [anon_sym_IN] = ACTIONS(613),
    [anon_sym_In] = ACTIONS(613),
    [sym_table_keyword] = ACTIONS(7225),
    [sym_page_keyword] = ACTIONS(1382),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1382),
    [sym_query_keyword] = ACTIONS(1382),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(7225),
    [sym_dataset_keyword] = ACTIONS(7225),
    [sym_quoted_identifier] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6036),
    [sym_integer] = ACTIONS(6036),
  },
  [STATE(3467)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(3436),
    [sym_identifier] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(7444),
    [anon_sym_EQ] = ACTIONS(3695),
    [anon_sym_COMMA] = ACTIONS(3695),
    [anon_sym_COLON] = ACTIONS(3693),
    [anon_sym_DASH] = ACTIONS(3693),
    [aux_sym_boolean_token1] = ACTIONS(3693),
    [aux_sym_boolean_token2] = ACTIONS(3693),
    [sym_decimal] = ACTIONS(3693),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_DOT_DOT] = ACTIONS(3695),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [aux_sym_record_type_token1] = ACTIONS(3693),
    [aux_sym_basic_type_token21] = ACTIONS(3693),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_basic_type_token48] = ACTIONS(3693),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_not] = ACTIONS(3693),
    [anon_sym_NOT] = ACTIONS(3693),
    [anon_sym_Not] = ACTIONS(3693),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3695),
    [aux_sym__expression_token1] = ACTIONS(3695),
    [aux_sym__expression_token2] = ACTIONS(3695),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3693),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3693),
    [anon_sym_SLASH] = ACTIONS(3693),
    [anon_sym_div] = ACTIONS(3693),
    [anon_sym_DIV] = ACTIONS(3693),
    [anon_sym_Div] = ACTIONS(3693),
    [anon_sym_mod] = ACTIONS(3693),
    [anon_sym_MOD] = ACTIONS(3693),
    [anon_sym_Mod] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(3693),
    [anon_sym_GT_EQ] = ACTIONS(3695),
    [anon_sym_LT_EQ] = ACTIONS(3695),
    [anon_sym_GT] = ACTIONS(3693),
    [anon_sym_LT] = ACTIONS(3693),
    [anon_sym_LT_GT] = ACTIONS(3695),
    [anon_sym_and] = ACTIONS(3693),
    [anon_sym_AND] = ACTIONS(3693),
    [anon_sym_And] = ACTIONS(3693),
    [anon_sym_or] = ACTIONS(3693),
    [anon_sym_OR] = ACTIONS(3693),
    [anon_sym_Or] = ACTIONS(3693),
    [anon_sym_xor] = ACTIONS(3693),
    [anon_sym_XOR] = ACTIONS(3693),
    [anon_sym_Xor] = ACTIONS(3693),
    [anon_sym_QMARK] = ACTIONS(3695),
    [sym_datetime_literal] = ACTIONS(3695),
    [sym_date_literal] = ACTIONS(3693),
    [sym_time_literal] = ACTIONS(3693),
    [sym_biginteger_literal] = ACTIONS(3695),
    [anon_sym_else] = ACTIONS(3693),
    [anon_sym_ELSE] = ACTIONS(3693),
    [anon_sym_Else] = ACTIONS(3693),
    [anon_sym_in] = ACTIONS(3693),
    [anon_sym_IN] = ACTIONS(3693),
    [anon_sym_In] = ACTIONS(3693),
    [sym_page_keyword] = ACTIONS(3693),
    [anon_sym_codeunit] = ACTIONS(3693),
    [anon_sym_CODEUNIT] = ACTIONS(3693),
    [anon_sym_Codeunit] = ACTIONS(3693),
    [anon_sym_CodeUnit] = ACTIONS(3693),
    [anon_sym_COdeunit] = ACTIONS(3693),
    [anon_sym_codeUnit] = ACTIONS(3693),
    [sym_report_keyword] = ACTIONS(3693),
    [sym_query_keyword] = ACTIONS(3693),
    [anon_sym_xmlport] = ACTIONS(3693),
    [anon_sym_XMLPORT] = ACTIONS(3693),
    [anon_sym_Xmlport] = ACTIONS(3693),
    [anon_sym_XMLport] = ACTIONS(3693),
    [anon_sym_XMLPort] = ACTIONS(3693),
    [anon_sym_XmlPort] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_ENUM] = ACTIONS(3693),
    [anon_sym_Enum] = ACTIONS(3693),
    [anon_sym_eNUM] = ACTIONS(3693),
    [anon_sym_eNum] = ACTIONS(3693),
    [anon_sym_ENum] = ACTIONS(3693),
    [sym_temporary_keyword] = ACTIONS(3693),
    [sym_quoted_identifier] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3695),
    [sym_verbatim_string] = ACTIONS(3695),
    [sym_integer] = ACTIONS(3693),
    [sym_continue_as_identifier] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
  },
  [STATE(3468)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3643),
    [anon_sym_SEMI] = ACTIONS(3645),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_COMMA] = ACTIONS(3645),
    [anon_sym_COLON] = ACTIONS(3643),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3643),
    [aux_sym_boolean_token2] = ACTIONS(3643),
    [sym_decimal] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3643),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3643),
    [aux_sym_basic_type_token21] = ACTIONS(3643),
    [aux_sym_basic_type_token22] = ACTIONS(3643),
    [aux_sym_basic_type_token48] = ACTIONS(3643),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3643),
    [anon_sym_POUNDif] = ACTIONS(3645),
    [anon_sym_POUNDIF] = ACTIONS(3645),
    [anon_sym_POUNDIf] = ACTIONS(3645),
    [anon_sym_not] = ACTIONS(3643),
    [anon_sym_NOT] = ACTIONS(3643),
    [anon_sym_Not] = ACTIONS(3643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3645),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3643),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3643),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(3643),
    [anon_sym_AND] = ACTIONS(3643),
    [anon_sym_And] = ACTIONS(3643),
    [anon_sym_or] = ACTIONS(3643),
    [anon_sym_OR] = ACTIONS(3643),
    [anon_sym_Or] = ACTIONS(3643),
    [anon_sym_xor] = ACTIONS(3643),
    [anon_sym_XOR] = ACTIONS(3643),
    [anon_sym_Xor] = ACTIONS(3643),
    [anon_sym_QMARK] = ACTIONS(3645),
    [sym_datetime_literal] = ACTIONS(3645),
    [sym_date_literal] = ACTIONS(3643),
    [sym_time_literal] = ACTIONS(3643),
    [sym_biginteger_literal] = ACTIONS(3645),
    [anon_sym_else] = ACTIONS(3643),
    [anon_sym_ELSE] = ACTIONS(3643),
    [anon_sym_Else] = ACTIONS(3643),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3643),
    [anon_sym_codeunit] = ACTIONS(3643),
    [anon_sym_CODEUNIT] = ACTIONS(3643),
    [anon_sym_Codeunit] = ACTIONS(3643),
    [anon_sym_CodeUnit] = ACTIONS(3643),
    [anon_sym_COdeunit] = ACTIONS(3643),
    [anon_sym_codeUnit] = ACTIONS(3643),
    [sym_report_keyword] = ACTIONS(3643),
    [sym_query_keyword] = ACTIONS(3643),
    [anon_sym_xmlport] = ACTIONS(3643),
    [anon_sym_XMLPORT] = ACTIONS(3643),
    [anon_sym_Xmlport] = ACTIONS(3643),
    [anon_sym_XMLport] = ACTIONS(3643),
    [anon_sym_XMLPort] = ACTIONS(3643),
    [anon_sym_XmlPort] = ACTIONS(3643),
    [anon_sym_enum] = ACTIONS(3643),
    [anon_sym_ENUM] = ACTIONS(3643),
    [anon_sym_Enum] = ACTIONS(3643),
    [anon_sym_eNUM] = ACTIONS(3643),
    [anon_sym_eNum] = ACTIONS(3643),
    [anon_sym_ENum] = ACTIONS(3643),
    [sym_quoted_identifier] = ACTIONS(3645),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3645),
    [sym_verbatim_string] = ACTIONS(3645),
    [sym_integer] = ACTIONS(3643),
    [sym_continue_as_identifier] = ACTIONS(3645),
    [sym_preproc_open] = ACTIONS(3645),
  },
  [STATE(3469)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym_table_relation_expression] = STATE(11351),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3470)] = {
    [sym_identifier] = ACTIONS(3756),
    [anon_sym_SEMI] = ACTIONS(3758),
    [anon_sym_DOT] = ACTIONS(3756),
    [anon_sym_EQ] = ACTIONS(3758),
    [anon_sym_COMMA] = ACTIONS(3758),
    [anon_sym_COLON] = ACTIONS(3756),
    [anon_sym_DASH] = ACTIONS(3756),
    [aux_sym_boolean_token1] = ACTIONS(3756),
    [aux_sym_boolean_token2] = ACTIONS(3756),
    [sym_decimal] = ACTIONS(3756),
    [anon_sym_LPAREN] = ACTIONS(3758),
    [anon_sym_DOT_DOT] = ACTIONS(3758),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3756),
    [anon_sym_LBRACK] = ACTIONS(3758),
    [aux_sym_record_type_token1] = ACTIONS(3756),
    [aux_sym_basic_type_token21] = ACTIONS(3756),
    [aux_sym_basic_type_token22] = ACTIONS(3756),
    [aux_sym_basic_type_token48] = ACTIONS(3756),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3756),
    [anon_sym_COLON_COLON] = ACTIONS(3758),
    [anon_sym_POUNDif] = ACTIONS(3758),
    [anon_sym_POUNDIF] = ACTIONS(3758),
    [anon_sym_POUNDIf] = ACTIONS(3758),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_NOT] = ACTIONS(3756),
    [anon_sym_Not] = ACTIONS(3756),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3758),
    [aux_sym__expression_token1] = ACTIONS(3758),
    [aux_sym__expression_token2] = ACTIONS(3758),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3756),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3756),
    [anon_sym_SLASH] = ACTIONS(3756),
    [anon_sym_div] = ACTIONS(3756),
    [anon_sym_DIV] = ACTIONS(3756),
    [anon_sym_Div] = ACTIONS(3756),
    [anon_sym_mod] = ACTIONS(3756),
    [anon_sym_MOD] = ACTIONS(3756),
    [anon_sym_Mod] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_GT_EQ] = ACTIONS(3758),
    [anon_sym_LT_EQ] = ACTIONS(3758),
    [anon_sym_GT] = ACTIONS(3756),
    [anon_sym_LT] = ACTIONS(3756),
    [anon_sym_LT_GT] = ACTIONS(3758),
    [anon_sym_and] = ACTIONS(3756),
    [anon_sym_AND] = ACTIONS(3756),
    [anon_sym_And] = ACTIONS(3756),
    [anon_sym_or] = ACTIONS(3756),
    [anon_sym_OR] = ACTIONS(3756),
    [anon_sym_Or] = ACTIONS(3756),
    [anon_sym_xor] = ACTIONS(3756),
    [anon_sym_XOR] = ACTIONS(3756),
    [anon_sym_Xor] = ACTIONS(3756),
    [anon_sym_QMARK] = ACTIONS(3758),
    [sym_datetime_literal] = ACTIONS(3758),
    [sym_date_literal] = ACTIONS(3756),
    [sym_time_literal] = ACTIONS(3756),
    [sym_biginteger_literal] = ACTIONS(3758),
    [anon_sym_else] = ACTIONS(3756),
    [anon_sym_ELSE] = ACTIONS(3756),
    [anon_sym_Else] = ACTIONS(3756),
    [anon_sym_in] = ACTIONS(3756),
    [anon_sym_IN] = ACTIONS(3756),
    [anon_sym_In] = ACTIONS(3756),
    [sym_page_keyword] = ACTIONS(3756),
    [anon_sym_codeunit] = ACTIONS(3756),
    [anon_sym_CODEUNIT] = ACTIONS(3756),
    [anon_sym_Codeunit] = ACTIONS(3756),
    [anon_sym_CodeUnit] = ACTIONS(3756),
    [anon_sym_COdeunit] = ACTIONS(3756),
    [anon_sym_codeUnit] = ACTIONS(3756),
    [sym_report_keyword] = ACTIONS(3756),
    [sym_query_keyword] = ACTIONS(3756),
    [anon_sym_xmlport] = ACTIONS(3756),
    [anon_sym_XMLPORT] = ACTIONS(3756),
    [anon_sym_Xmlport] = ACTIONS(3756),
    [anon_sym_XMLport] = ACTIONS(3756),
    [anon_sym_XMLPort] = ACTIONS(3756),
    [anon_sym_XmlPort] = ACTIONS(3756),
    [anon_sym_enum] = ACTIONS(3756),
    [anon_sym_ENUM] = ACTIONS(3756),
    [anon_sym_Enum] = ACTIONS(3756),
    [anon_sym_eNUM] = ACTIONS(3756),
    [anon_sym_eNum] = ACTIONS(3756),
    [anon_sym_ENum] = ACTIONS(3756),
    [sym_quoted_identifier] = ACTIONS(3758),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3758),
    [sym_verbatim_string] = ACTIONS(3758),
    [sym_integer] = ACTIONS(3756),
    [sym_continue_as_identifier] = ACTIONS(3758),
    [sym_preproc_open] = ACTIONS(3758),
  },
  [STATE(3471)] = {
    [sym_identifier] = ACTIONS(3764),
    [anon_sym_SEMI] = ACTIONS(3766),
    [anon_sym_DOT] = ACTIONS(3764),
    [anon_sym_EQ] = ACTIONS(3766),
    [anon_sym_COMMA] = ACTIONS(3766),
    [anon_sym_COLON] = ACTIONS(3764),
    [anon_sym_DASH] = ACTIONS(3764),
    [aux_sym_boolean_token1] = ACTIONS(3764),
    [aux_sym_boolean_token2] = ACTIONS(3764),
    [sym_decimal] = ACTIONS(3764),
    [anon_sym_LPAREN] = ACTIONS(3766),
    [anon_sym_DOT_DOT] = ACTIONS(3766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3764),
    [anon_sym_STAR] = ACTIONS(3764),
    [anon_sym_LBRACK] = ACTIONS(3766),
    [aux_sym_record_type_token1] = ACTIONS(3764),
    [aux_sym_basic_type_token21] = ACTIONS(3764),
    [aux_sym_basic_type_token22] = ACTIONS(3764),
    [aux_sym_basic_type_token48] = ACTIONS(3764),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3764),
    [anon_sym_COLON_COLON] = ACTIONS(3766),
    [anon_sym_POUNDif] = ACTIONS(3766),
    [anon_sym_POUNDIF] = ACTIONS(3766),
    [anon_sym_POUNDIf] = ACTIONS(3766),
    [anon_sym_not] = ACTIONS(3764),
    [anon_sym_NOT] = ACTIONS(3764),
    [anon_sym_Not] = ACTIONS(3764),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3766),
    [aux_sym__expression_token1] = ACTIONS(3766),
    [aux_sym__expression_token2] = ACTIONS(3766),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3764),
    [anon_sym_SLASH] = ACTIONS(3764),
    [anon_sym_div] = ACTIONS(3764),
    [anon_sym_DIV] = ACTIONS(3764),
    [anon_sym_Div] = ACTIONS(3764),
    [anon_sym_mod] = ACTIONS(3764),
    [anon_sym_MOD] = ACTIONS(3764),
    [anon_sym_Mod] = ACTIONS(3764),
    [anon_sym_PLUS] = ACTIONS(3764),
    [anon_sym_GT_EQ] = ACTIONS(3766),
    [anon_sym_LT_EQ] = ACTIONS(3766),
    [anon_sym_GT] = ACTIONS(3764),
    [anon_sym_LT] = ACTIONS(3764),
    [anon_sym_LT_GT] = ACTIONS(3766),
    [anon_sym_and] = ACTIONS(3764),
    [anon_sym_AND] = ACTIONS(3764),
    [anon_sym_And] = ACTIONS(3764),
    [anon_sym_or] = ACTIONS(3764),
    [anon_sym_OR] = ACTIONS(3764),
    [anon_sym_Or] = ACTIONS(3764),
    [anon_sym_xor] = ACTIONS(3764),
    [anon_sym_XOR] = ACTIONS(3764),
    [anon_sym_Xor] = ACTIONS(3764),
    [anon_sym_QMARK] = ACTIONS(3766),
    [sym_datetime_literal] = ACTIONS(3766),
    [sym_date_literal] = ACTIONS(3764),
    [sym_time_literal] = ACTIONS(3764),
    [sym_biginteger_literal] = ACTIONS(3766),
    [anon_sym_else] = ACTIONS(3764),
    [anon_sym_ELSE] = ACTIONS(3764),
    [anon_sym_Else] = ACTIONS(3764),
    [anon_sym_in] = ACTIONS(3764),
    [anon_sym_IN] = ACTIONS(3764),
    [anon_sym_In] = ACTIONS(3764),
    [sym_page_keyword] = ACTIONS(3764),
    [anon_sym_codeunit] = ACTIONS(3764),
    [anon_sym_CODEUNIT] = ACTIONS(3764),
    [anon_sym_Codeunit] = ACTIONS(3764),
    [anon_sym_CodeUnit] = ACTIONS(3764),
    [anon_sym_COdeunit] = ACTIONS(3764),
    [anon_sym_codeUnit] = ACTIONS(3764),
    [sym_report_keyword] = ACTIONS(3764),
    [sym_query_keyword] = ACTIONS(3764),
    [anon_sym_xmlport] = ACTIONS(3764),
    [anon_sym_XMLPORT] = ACTIONS(3764),
    [anon_sym_Xmlport] = ACTIONS(3764),
    [anon_sym_XMLport] = ACTIONS(3764),
    [anon_sym_XMLPort] = ACTIONS(3764),
    [anon_sym_XmlPort] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3764),
    [anon_sym_ENUM] = ACTIONS(3764),
    [anon_sym_Enum] = ACTIONS(3764),
    [anon_sym_eNUM] = ACTIONS(3764),
    [anon_sym_eNum] = ACTIONS(3764),
    [anon_sym_ENum] = ACTIONS(3764),
    [sym_quoted_identifier] = ACTIONS(3766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3766),
    [sym_verbatim_string] = ACTIONS(3766),
    [sym_integer] = ACTIONS(3764),
    [sym_continue_as_identifier] = ACTIONS(3766),
    [sym_preproc_open] = ACTIONS(3766),
  },
  [STATE(3472)] = {
    [aux_sym_option_member_list_repeat1] = STATE(3499),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_SEMI] = ACTIONS(3669),
    [anon_sym_DOT] = ACTIONS(3667),
    [anon_sym_EQ] = ACTIONS(3669),
    [anon_sym_COMMA] = ACTIONS(7489),
    [anon_sym_COLON] = ACTIONS(3667),
    [anon_sym_DASH] = ACTIONS(3667),
    [aux_sym_boolean_token1] = ACTIONS(3667),
    [aux_sym_boolean_token2] = ACTIONS(3667),
    [sym_decimal] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3669),
    [anon_sym_DOT_DOT] = ACTIONS(3669),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3667),
    [anon_sym_STAR] = ACTIONS(3667),
    [anon_sym_LBRACK] = ACTIONS(3669),
    [aux_sym_record_type_token1] = ACTIONS(3667),
    [aux_sym_basic_type_token21] = ACTIONS(3667),
    [aux_sym_basic_type_token22] = ACTIONS(3667),
    [aux_sym_basic_type_token48] = ACTIONS(3667),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3667),
    [anon_sym_POUNDif] = ACTIONS(3669),
    [anon_sym_POUNDIF] = ACTIONS(3669),
    [anon_sym_POUNDIf] = ACTIONS(3669),
    [anon_sym_not] = ACTIONS(3667),
    [anon_sym_NOT] = ACTIONS(3667),
    [anon_sym_Not] = ACTIONS(3667),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3669),
    [aux_sym__expression_token1] = ACTIONS(3669),
    [aux_sym__expression_token2] = ACTIONS(3669),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3667),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3667),
    [anon_sym_SLASH] = ACTIONS(3667),
    [anon_sym_div] = ACTIONS(3667),
    [anon_sym_DIV] = ACTIONS(3667),
    [anon_sym_Div] = ACTIONS(3667),
    [anon_sym_mod] = ACTIONS(3667),
    [anon_sym_MOD] = ACTIONS(3667),
    [anon_sym_Mod] = ACTIONS(3667),
    [anon_sym_PLUS] = ACTIONS(3667),
    [anon_sym_GT_EQ] = ACTIONS(3669),
    [anon_sym_LT_EQ] = ACTIONS(3669),
    [anon_sym_GT] = ACTIONS(3667),
    [anon_sym_LT] = ACTIONS(3667),
    [anon_sym_LT_GT] = ACTIONS(3669),
    [anon_sym_and] = ACTIONS(3667),
    [anon_sym_AND] = ACTIONS(3667),
    [anon_sym_And] = ACTIONS(3667),
    [anon_sym_or] = ACTIONS(3667),
    [anon_sym_OR] = ACTIONS(3667),
    [anon_sym_Or] = ACTIONS(3667),
    [anon_sym_xor] = ACTIONS(3667),
    [anon_sym_XOR] = ACTIONS(3667),
    [anon_sym_Xor] = ACTIONS(3667),
    [anon_sym_QMARK] = ACTIONS(3669),
    [sym_datetime_literal] = ACTIONS(3669),
    [sym_date_literal] = ACTIONS(3667),
    [sym_time_literal] = ACTIONS(3667),
    [sym_biginteger_literal] = ACTIONS(3669),
    [anon_sym_else] = ACTIONS(3667),
    [anon_sym_ELSE] = ACTIONS(3667),
    [anon_sym_Else] = ACTIONS(3667),
    [anon_sym_in] = ACTIONS(3667),
    [anon_sym_IN] = ACTIONS(3667),
    [anon_sym_In] = ACTIONS(3667),
    [sym_page_keyword] = ACTIONS(3667),
    [anon_sym_codeunit] = ACTIONS(3667),
    [anon_sym_CODEUNIT] = ACTIONS(3667),
    [anon_sym_Codeunit] = ACTIONS(3667),
    [anon_sym_CodeUnit] = ACTIONS(3667),
    [anon_sym_COdeunit] = ACTIONS(3667),
    [anon_sym_codeUnit] = ACTIONS(3667),
    [sym_report_keyword] = ACTIONS(3667),
    [sym_query_keyword] = ACTIONS(3667),
    [anon_sym_xmlport] = ACTIONS(3667),
    [anon_sym_XMLPORT] = ACTIONS(3667),
    [anon_sym_Xmlport] = ACTIONS(3667),
    [anon_sym_XMLport] = ACTIONS(3667),
    [anon_sym_XMLPort] = ACTIONS(3667),
    [anon_sym_XmlPort] = ACTIONS(3667),
    [anon_sym_enum] = ACTIONS(3667),
    [anon_sym_ENUM] = ACTIONS(3667),
    [anon_sym_Enum] = ACTIONS(3667),
    [anon_sym_eNUM] = ACTIONS(3667),
    [anon_sym_eNum] = ACTIONS(3667),
    [anon_sym_ENum] = ACTIONS(3667),
    [sym_quoted_identifier] = ACTIONS(3669),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3669),
    [sym_verbatim_string] = ACTIONS(3669),
    [sym_integer] = ACTIONS(3667),
    [sym_continue_as_identifier] = ACTIONS(3669),
    [sym_preproc_open] = ACTIONS(3669),
  },
  [STATE(3473)] = {
    [sym_identifier] = ACTIONS(3768),
    [anon_sym_SEMI] = ACTIONS(3770),
    [anon_sym_DOT] = ACTIONS(3768),
    [anon_sym_EQ] = ACTIONS(3770),
    [anon_sym_COMMA] = ACTIONS(3770),
    [anon_sym_COLON] = ACTIONS(3768),
    [anon_sym_DASH] = ACTIONS(3768),
    [aux_sym_boolean_token1] = ACTIONS(3768),
    [aux_sym_boolean_token2] = ACTIONS(3768),
    [sym_decimal] = ACTIONS(3768),
    [anon_sym_LPAREN] = ACTIONS(3770),
    [anon_sym_DOT_DOT] = ACTIONS(3770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3768),
    [anon_sym_STAR] = ACTIONS(3768),
    [anon_sym_LBRACK] = ACTIONS(3770),
    [aux_sym_record_type_token1] = ACTIONS(3768),
    [aux_sym_basic_type_token21] = ACTIONS(3768),
    [aux_sym_basic_type_token22] = ACTIONS(3768),
    [aux_sym_basic_type_token48] = ACTIONS(3768),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3768),
    [anon_sym_COLON_COLON] = ACTIONS(3770),
    [anon_sym_POUNDif] = ACTIONS(3770),
    [anon_sym_POUNDIF] = ACTIONS(3770),
    [anon_sym_POUNDIf] = ACTIONS(3770),
    [anon_sym_not] = ACTIONS(3768),
    [anon_sym_NOT] = ACTIONS(3768),
    [anon_sym_Not] = ACTIONS(3768),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3770),
    [aux_sym__expression_token1] = ACTIONS(3770),
    [aux_sym__expression_token2] = ACTIONS(3770),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3768),
    [anon_sym_SLASH] = ACTIONS(3768),
    [anon_sym_div] = ACTIONS(3768),
    [anon_sym_DIV] = ACTIONS(3768),
    [anon_sym_Div] = ACTIONS(3768),
    [anon_sym_mod] = ACTIONS(3768),
    [anon_sym_MOD] = ACTIONS(3768),
    [anon_sym_Mod] = ACTIONS(3768),
    [anon_sym_PLUS] = ACTIONS(3768),
    [anon_sym_GT_EQ] = ACTIONS(3770),
    [anon_sym_LT_EQ] = ACTIONS(3770),
    [anon_sym_GT] = ACTIONS(3768),
    [anon_sym_LT] = ACTIONS(3768),
    [anon_sym_LT_GT] = ACTIONS(3770),
    [anon_sym_and] = ACTIONS(3768),
    [anon_sym_AND] = ACTIONS(3768),
    [anon_sym_And] = ACTIONS(3768),
    [anon_sym_or] = ACTIONS(3768),
    [anon_sym_OR] = ACTIONS(3768),
    [anon_sym_Or] = ACTIONS(3768),
    [anon_sym_xor] = ACTIONS(3768),
    [anon_sym_XOR] = ACTIONS(3768),
    [anon_sym_Xor] = ACTIONS(3768),
    [anon_sym_QMARK] = ACTIONS(3770),
    [sym_datetime_literal] = ACTIONS(3770),
    [sym_date_literal] = ACTIONS(3768),
    [sym_time_literal] = ACTIONS(3768),
    [sym_biginteger_literal] = ACTIONS(3770),
    [anon_sym_else] = ACTIONS(3768),
    [anon_sym_ELSE] = ACTIONS(3768),
    [anon_sym_Else] = ACTIONS(3768),
    [anon_sym_in] = ACTIONS(3768),
    [anon_sym_IN] = ACTIONS(3768),
    [anon_sym_In] = ACTIONS(3768),
    [sym_page_keyword] = ACTIONS(3768),
    [anon_sym_codeunit] = ACTIONS(3768),
    [anon_sym_CODEUNIT] = ACTIONS(3768),
    [anon_sym_Codeunit] = ACTIONS(3768),
    [anon_sym_CodeUnit] = ACTIONS(3768),
    [anon_sym_COdeunit] = ACTIONS(3768),
    [anon_sym_codeUnit] = ACTIONS(3768),
    [sym_report_keyword] = ACTIONS(3768),
    [sym_query_keyword] = ACTIONS(3768),
    [anon_sym_xmlport] = ACTIONS(3768),
    [anon_sym_XMLPORT] = ACTIONS(3768),
    [anon_sym_Xmlport] = ACTIONS(3768),
    [anon_sym_XMLport] = ACTIONS(3768),
    [anon_sym_XMLPort] = ACTIONS(3768),
    [anon_sym_XmlPort] = ACTIONS(3768),
    [anon_sym_enum] = ACTIONS(3768),
    [anon_sym_ENUM] = ACTIONS(3768),
    [anon_sym_Enum] = ACTIONS(3768),
    [anon_sym_eNUM] = ACTIONS(3768),
    [anon_sym_eNum] = ACTIONS(3768),
    [anon_sym_ENum] = ACTIONS(3768),
    [sym_quoted_identifier] = ACTIONS(3770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3770),
    [sym_verbatim_string] = ACTIONS(3770),
    [sym_integer] = ACTIONS(3768),
    [sym_continue_as_identifier] = ACTIONS(3770),
    [sym_preproc_open] = ACTIONS(3770),
  },
  [STATE(3474)] = {
    [sym_identifier] = ACTIONS(3772),
    [anon_sym_SEMI] = ACTIONS(3774),
    [anon_sym_DOT] = ACTIONS(3772),
    [anon_sym_EQ] = ACTIONS(3774),
    [anon_sym_COMMA] = ACTIONS(3774),
    [anon_sym_COLON] = ACTIONS(3772),
    [anon_sym_DASH] = ACTIONS(3772),
    [aux_sym_boolean_token1] = ACTIONS(3772),
    [aux_sym_boolean_token2] = ACTIONS(3772),
    [sym_decimal] = ACTIONS(3772),
    [anon_sym_LPAREN] = ACTIONS(3774),
    [anon_sym_DOT_DOT] = ACTIONS(3774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3772),
    [anon_sym_STAR] = ACTIONS(3772),
    [anon_sym_LBRACK] = ACTIONS(3774),
    [aux_sym_record_type_token1] = ACTIONS(3772),
    [aux_sym_basic_type_token21] = ACTIONS(3772),
    [aux_sym_basic_type_token22] = ACTIONS(3772),
    [aux_sym_basic_type_token48] = ACTIONS(3772),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3772),
    [anon_sym_COLON_COLON] = ACTIONS(3774),
    [anon_sym_POUNDif] = ACTIONS(3774),
    [anon_sym_POUNDIF] = ACTIONS(3774),
    [anon_sym_POUNDIf] = ACTIONS(3774),
    [anon_sym_not] = ACTIONS(3772),
    [anon_sym_NOT] = ACTIONS(3772),
    [anon_sym_Not] = ACTIONS(3772),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3774),
    [aux_sym__expression_token1] = ACTIONS(3774),
    [aux_sym__expression_token2] = ACTIONS(3774),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3772),
    [anon_sym_SLASH] = ACTIONS(3772),
    [anon_sym_div] = ACTIONS(3772),
    [anon_sym_DIV] = ACTIONS(3772),
    [anon_sym_Div] = ACTIONS(3772),
    [anon_sym_mod] = ACTIONS(3772),
    [anon_sym_MOD] = ACTIONS(3772),
    [anon_sym_Mod] = ACTIONS(3772),
    [anon_sym_PLUS] = ACTIONS(3772),
    [anon_sym_GT_EQ] = ACTIONS(3774),
    [anon_sym_LT_EQ] = ACTIONS(3774),
    [anon_sym_GT] = ACTIONS(3772),
    [anon_sym_LT] = ACTIONS(3772),
    [anon_sym_LT_GT] = ACTIONS(3774),
    [anon_sym_and] = ACTIONS(3772),
    [anon_sym_AND] = ACTIONS(3772),
    [anon_sym_And] = ACTIONS(3772),
    [anon_sym_or] = ACTIONS(3772),
    [anon_sym_OR] = ACTIONS(3772),
    [anon_sym_Or] = ACTIONS(3772),
    [anon_sym_xor] = ACTIONS(3772),
    [anon_sym_XOR] = ACTIONS(3772),
    [anon_sym_Xor] = ACTIONS(3772),
    [anon_sym_QMARK] = ACTIONS(3774),
    [sym_datetime_literal] = ACTIONS(3774),
    [sym_date_literal] = ACTIONS(3772),
    [sym_time_literal] = ACTIONS(3772),
    [sym_biginteger_literal] = ACTIONS(3774),
    [anon_sym_else] = ACTIONS(3772),
    [anon_sym_ELSE] = ACTIONS(3772),
    [anon_sym_Else] = ACTIONS(3772),
    [anon_sym_in] = ACTIONS(3772),
    [anon_sym_IN] = ACTIONS(3772),
    [anon_sym_In] = ACTIONS(3772),
    [sym_page_keyword] = ACTIONS(3772),
    [anon_sym_codeunit] = ACTIONS(3772),
    [anon_sym_CODEUNIT] = ACTIONS(3772),
    [anon_sym_Codeunit] = ACTIONS(3772),
    [anon_sym_CodeUnit] = ACTIONS(3772),
    [anon_sym_COdeunit] = ACTIONS(3772),
    [anon_sym_codeUnit] = ACTIONS(3772),
    [sym_report_keyword] = ACTIONS(3772),
    [sym_query_keyword] = ACTIONS(3772),
    [anon_sym_xmlport] = ACTIONS(3772),
    [anon_sym_XMLPORT] = ACTIONS(3772),
    [anon_sym_Xmlport] = ACTIONS(3772),
    [anon_sym_XMLport] = ACTIONS(3772),
    [anon_sym_XMLPort] = ACTIONS(3772),
    [anon_sym_XmlPort] = ACTIONS(3772),
    [anon_sym_enum] = ACTIONS(3772),
    [anon_sym_ENUM] = ACTIONS(3772),
    [anon_sym_Enum] = ACTIONS(3772),
    [anon_sym_eNUM] = ACTIONS(3772),
    [anon_sym_eNum] = ACTIONS(3772),
    [anon_sym_ENum] = ACTIONS(3772),
    [sym_quoted_identifier] = ACTIONS(3774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3774),
    [sym_verbatim_string] = ACTIONS(3774),
    [sym_integer] = ACTIONS(3772),
    [sym_continue_as_identifier] = ACTIONS(3774),
    [sym_preproc_open] = ACTIONS(3774),
  },
  [STATE(3475)] = {
    [sym_boolean] = STATE(8846),
    [sym_preproc_conditional_table_relation] = STATE(11301),
    [sym_table_relation_expression] = STATE(11317),
    [sym_if_table_relation] = STATE(11301),
    [sym_simple_table_relation] = STATE(11301),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_preproc_if] = STATE(2113),
    [sym_assignment_expression] = STATE(8846),
    [sym__expression] = STATE(8846),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8846),
    [sym_multiplicative_expression] = STATE(8846),
    [sym_additive_expression] = STATE(8846),
    [sym_comparison_expression] = STATE(8846),
    [sym_logical_expression] = STATE(8846),
    [sym_ternary_expression] = STATE(8846),
    [sym_unary_expression] = STATE(8846),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8846),
    [sym_list_literal] = STATE(8846),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8846),
    [sym__literal_value] = STATE(8846),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10371),
    [sym_keyword_as_identifier] = STATE(10371),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(4365),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_if_table_relation_token1] = ACTIONS(4371),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(4387),
    [sym_date_literal] = ACTIONS(4365),
    [sym_time_literal] = ACTIONS(4365),
    [sym_biginteger_literal] = ACTIONS(4387),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(4387),
    [sym_verbatim_string] = ACTIONS(4387),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(4387),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3476)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_elif] = STATE(3579),
    [sym_preproc_else] = STATE(3832),
    [sym_preproc_endif] = STATE(7148),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(10799),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7501),
    [anon_sym_POUNDELIF] = ACTIONS(7501),
    [anon_sym_POUNDElif] = ACTIONS(7501),
    [anon_sym_POUNDelse] = ACTIONS(7503),
    [anon_sym_POUNDELSE] = ACTIONS(7503),
    [anon_sym_POUNDElse] = ACTIONS(7503),
    [anon_sym_POUNDelse2] = ACTIONS(7503),
    [anon_sym_POUNDELSE2] = ACTIONS(7503),
    [anon_sym_POUNDElse2] = ACTIONS(7503),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3477)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_elif] = STATE(3579),
    [sym_preproc_else] = STATE(3824),
    [sym_preproc_endif] = STATE(3907),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3498),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(10650),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7501),
    [anon_sym_POUNDELIF] = ACTIONS(7501),
    [anon_sym_POUNDElif] = ACTIONS(7501),
    [anon_sym_POUNDelse] = ACTIONS(7503),
    [anon_sym_POUNDELSE] = ACTIONS(7503),
    [anon_sym_POUNDElse] = ACTIONS(7503),
    [anon_sym_POUNDelse2] = ACTIONS(7503),
    [anon_sym_POUNDELSE2] = ACTIONS(7503),
    [anon_sym_POUNDElse2] = ACTIONS(7503),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3478)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_elif] = STATE(3579),
    [sym_preproc_else] = STATE(3850),
    [sym_preproc_endif] = STATE(3908),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(10921),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7501),
    [anon_sym_POUNDELIF] = ACTIONS(7501),
    [anon_sym_POUNDElif] = ACTIONS(7501),
    [anon_sym_POUNDelse] = ACTIONS(7503),
    [anon_sym_POUNDELSE] = ACTIONS(7503),
    [anon_sym_POUNDElse] = ACTIONS(7503),
    [anon_sym_POUNDelse2] = ACTIONS(7503),
    [anon_sym_POUNDELSE2] = ACTIONS(7503),
    [anon_sym_POUNDElse2] = ACTIONS(7503),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3479)] = {
    [sym_boolean] = STATE(8802),
    [sym_preproc_conditional_table_relation] = STATE(7407),
    [sym_table_relation_expression] = STATE(7451),
    [sym_if_table_relation] = STATE(7407),
    [sym_simple_table_relation] = STATE(7407),
    [sym__namespaced_or_simple_ref] = STATE(7175),
    [sym_preproc_if] = STATE(2145),
    [sym_assignment_expression] = STATE(8802),
    [sym__expression] = STATE(8802),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8802),
    [sym_multiplicative_expression] = STATE(8802),
    [sym_additive_expression] = STATE(8802),
    [sym_comparison_expression] = STATE(8802),
    [sym_logical_expression] = STATE(8802),
    [sym_ternary_expression] = STATE(8802),
    [sym_unary_expression] = STATE(8802),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(3559),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8802),
    [sym_list_literal] = STATE(8802),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8802),
    [sym__literal_value] = STATE(8802),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(7118),
    [sym_keyword_as_identifier] = STATE(7118),
    [sym_identifier] = ACTIONS(7513),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7515),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7517),
    [aux_sym_if_table_relation_token1] = ACTIONS(4005),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7519),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7517),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7517),
    [aux_sym_separator_action_token1] = ACTIONS(7517),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7517),
    [aux_sym_type_declaration_token1] = ACTIONS(7517),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7521),
    [sym_date_literal] = ACTIONS(7515),
    [sym_time_literal] = ACTIONS(7515),
    [sym_biginteger_literal] = ACTIONS(7521),
    [sym_table_keyword] = ACTIONS(7517),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7517),
    [sym_dataset_keyword] = ACTIONS(7517),
    [sym_quoted_identifier] = ACTIONS(7523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7521),
    [sym_verbatim_string] = ACTIONS(7521),
    [sym_integer] = ACTIONS(7525),
    [sym_continue_as_identifier] = ACTIONS(7521),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3480)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_elif] = STATE(3579),
    [sym_preproc_else] = STATE(3837),
    [sym_preproc_endif] = STATE(7143),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3476),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(10758),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7501),
    [anon_sym_POUNDELIF] = ACTIONS(7501),
    [anon_sym_POUNDElif] = ACTIONS(7501),
    [anon_sym_POUNDelse] = ACTIONS(7503),
    [anon_sym_POUNDELSE] = ACTIONS(7503),
    [anon_sym_POUNDElse] = ACTIONS(7503),
    [anon_sym_POUNDelse2] = ACTIONS(7503),
    [anon_sym_POUNDELSE2] = ACTIONS(7503),
    [anon_sym_POUNDElse2] = ACTIONS(7503),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3481)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token53] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3562),
    [aux_sym_modify_modification_token1] = ACTIONS(3562),
    [aux_sym_separator_action_token1] = ACTIONS(3562),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [aux_sym_type_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_table_keyword] = ACTIONS(3562),
    [sym_procedure_keyword] = ACTIONS(3562),
    [sym_trigger_keyword] = ACTIONS(3562),
    [sym_var_keyword] = ACTIONS(3562),
    [sym_local_keyword] = ACTIONS(3562),
    [sym_internal_keyword] = ACTIONS(3562),
    [sym_protected_keyword] = ACTIONS(3562),
    [sym_event_keyword] = ACTIONS(3562),
    [sym_fields_keyword] = ACTIONS(3562),
    [sym_keys_keyword] = ACTIONS(3562),
    [sym_key_keyword] = ACTIONS(3562),
    [sym_fieldgroups_keyword] = ACTIONS(3562),
    [sym_actions_keyword] = ACTIONS(3562),
    [sym_layout_keyword] = ACTIONS(3562),
    [sym_dataset_keyword] = ACTIONS(3562),
    [sym_elements_keyword] = ACTIONS(3562),
    [sym_labels_keyword] = ACTIONS(3562),
    [sym_rendering_keyword] = ACTIONS(3562),
    [sym_requestpage_keyword] = ACTIONS(3562),
    [sym_schema_keyword] = ACTIONS(3562),
    [sym_views_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
    [sym_var_attribute_open] = ACTIONS(3564),
  },
  [STATE(3482)] = {
    [sym_boolean] = STATE(8836),
    [sym_preproc_conditional_table_relation] = STATE(17302),
    [sym_table_relation_expression] = STATE(18219),
    [sym_if_table_relation] = STATE(17302),
    [sym_simple_table_relation] = STATE(17302),
    [sym__namespaced_or_simple_ref] = STATE(15111),
    [sym_preproc_if] = STATE(2131),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8317),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(7151),
    [sym_keyword_as_identifier] = STATE(7151),
    [sym_identifier] = ACTIONS(7527),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_if_table_relation_token1] = ACTIONS(4045),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7229),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(7533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7535),
    [sym_continue_as_identifier] = ACTIONS(7531),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3483)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_COLON] = ACTIONS(3663),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(7537),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
  },
  [STATE(3484)] = {
    [sym_identifier] = ACTIONS(6641),
    [anon_sym_SEMI] = ACTIONS(6643),
    [anon_sym_DASH] = ACTIONS(6643),
    [aux_sym_boolean_token1] = ACTIONS(6641),
    [aux_sym_boolean_token2] = ACTIONS(6641),
    [sym_decimal] = ACTIONS(6641),
    [anon_sym_LPAREN] = ACTIONS(6643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6641),
    [anon_sym_LBRACK] = ACTIONS(6643),
    [aux_sym_record_type_token1] = ACTIONS(6641),
    [aux_sym_basic_type_token21] = ACTIONS(6641),
    [aux_sym_basic_type_token22] = ACTIONS(6641),
    [aux_sym_basic_type_token48] = ACTIONS(6641),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(6641),
    [anon_sym_POUNDif] = ACTIONS(6643),
    [anon_sym_POUNDIF] = ACTIONS(6643),
    [anon_sym_POUNDIf] = ACTIONS(6643),
    [anon_sym_not] = ACTIONS(6641),
    [anon_sym_NOT] = ACTIONS(6641),
    [anon_sym_Not] = ACTIONS(6641),
    [anon_sym_POUNDelse] = ACTIONS(6643),
    [anon_sym_POUNDELSE] = ACTIONS(6643),
    [anon_sym_POUNDElse] = ACTIONS(6643),
    [anon_sym_POUNDelse2] = ACTIONS(6643),
    [anon_sym_POUNDELSE2] = ACTIONS(6643),
    [anon_sym_POUNDElse2] = ACTIONS(6643),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6641),
    [anon_sym_PLUS] = ACTIONS(6643),
    [sym_datetime_literal] = ACTIONS(6643),
    [sym_date_literal] = ACTIONS(6641),
    [sym_time_literal] = ACTIONS(6641),
    [sym_biginteger_literal] = ACTIONS(6643),
    [anon_sym_if] = ACTIONS(6641),
    [anon_sym_IF] = ACTIONS(6641),
    [anon_sym_If] = ACTIONS(6641),
    [anon_sym_case] = ACTIONS(6641),
    [anon_sym_CASE] = ACTIONS(6641),
    [anon_sym_Case] = ACTIONS(6641),
    [anon_sym_for] = ACTIONS(6641),
    [anon_sym_FOR] = ACTIONS(6641),
    [anon_sym_For] = ACTIONS(6641),
    [anon_sym_foreach] = ACTIONS(6641),
    [anon_sym_FOREACH] = ACTIONS(6641),
    [anon_sym_Foreach] = ACTIONS(6641),
    [anon_sym_while] = ACTIONS(6641),
    [anon_sym_WHILE] = ACTIONS(6641),
    [anon_sym_While] = ACTIONS(6641),
    [anon_sym_repeat] = ACTIONS(6641),
    [anon_sym_REPEAT] = ACTIONS(6641),
    [anon_sym_Repeat] = ACTIONS(6641),
    [anon_sym_exit] = ACTIONS(6641),
    [anon_sym_EXIT] = ACTIONS(6641),
    [anon_sym_Exit] = ACTIONS(6641),
    [anon_sym_continue] = ACTIONS(6641),
    [anon_sym_CONTINUE] = ACTIONS(6641),
    [anon_sym_Continue] = ACTIONS(6641),
    [anon_sym_break] = ACTIONS(6641),
    [anon_sym_BREAK] = ACTIONS(6641),
    [anon_sym_Break] = ACTIONS(6641),
    [anon_sym_with] = ACTIONS(6641),
    [anon_sym_WITH] = ACTIONS(6641),
    [anon_sym_With] = ACTIONS(6641),
    [sym_asserterror_keyword] = ACTIONS(6643),
    [sym_page_keyword] = ACTIONS(6641),
    [anon_sym_codeunit] = ACTIONS(6641),
    [anon_sym_CODEUNIT] = ACTIONS(6641),
    [anon_sym_Codeunit] = ACTIONS(6641),
    [anon_sym_CodeUnit] = ACTIONS(6641),
    [anon_sym_COdeunit] = ACTIONS(6641),
    [anon_sym_codeUnit] = ACTIONS(6641),
    [sym_report_keyword] = ACTIONS(6641),
    [sym_query_keyword] = ACTIONS(6641),
    [anon_sym_xmlport] = ACTIONS(6641),
    [anon_sym_XMLPORT] = ACTIONS(6641),
    [anon_sym_Xmlport] = ACTIONS(6641),
    [anon_sym_XMLport] = ACTIONS(6641),
    [anon_sym_XMLPort] = ACTIONS(6641),
    [anon_sym_XmlPort] = ACTIONS(6641),
    [anon_sym_enum] = ACTIONS(6641),
    [anon_sym_ENUM] = ACTIONS(6641),
    [anon_sym_Enum] = ACTIONS(6641),
    [anon_sym_eNUM] = ACTIONS(6641),
    [anon_sym_eNum] = ACTIONS(6641),
    [anon_sym_ENum] = ACTIONS(6641),
    [sym_quoted_identifier] = ACTIONS(6643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6643),
    [sym_verbatim_string] = ACTIONS(6643),
    [sym_integer] = ACTIONS(6641),
    [sym_continue_as_identifier] = ACTIONS(6643),
    [sym_preproc_open] = ACTIONS(6643),
    [sym_begin_keyword] = ACTIONS(6643),
  },
  [STATE(3485)] = {
    [sym_boolean] = STATE(8798),
    [sym_preproc_conditional_table_relation] = STATE(9692),
    [sym_table_relation_expression] = STATE(9546),
    [sym_if_table_relation] = STATE(9692),
    [sym_simple_table_relation] = STATE(9692),
    [sym__namespaced_or_simple_ref] = STATE(8712),
    [sym_preproc_if] = STATE(2139),
    [sym_assignment_expression] = STATE(8798),
    [sym__expression] = STATE(8798),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8798),
    [sym_multiplicative_expression] = STATE(8798),
    [sym_additive_expression] = STATE(8798),
    [sym_comparison_expression] = STATE(8798),
    [sym_logical_expression] = STATE(8798),
    [sym_ternary_expression] = STATE(8798),
    [sym_unary_expression] = STATE(8798),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(4060),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8798),
    [sym_list_literal] = STATE(8798),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8798),
    [sym__literal_value] = STATE(8798),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(8690),
    [sym_keyword_as_identifier] = STATE(8690),
    [sym_identifier] = ACTIONS(7539),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7541),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7543),
    [aux_sym_if_table_relation_token1] = ACTIONS(3967),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7545),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7543),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7543),
    [aux_sym_separator_action_token1] = ACTIONS(7543),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7543),
    [aux_sym_type_declaration_token1] = ACTIONS(7543),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7547),
    [sym_date_literal] = ACTIONS(7541),
    [sym_time_literal] = ACTIONS(7541),
    [sym_biginteger_literal] = ACTIONS(7547),
    [sym_table_keyword] = ACTIONS(7543),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7543),
    [sym_dataset_keyword] = ACTIONS(7543),
    [sym_quoted_identifier] = ACTIONS(7549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7547),
    [sym_verbatim_string] = ACTIONS(7547),
    [sym_integer] = ACTIONS(7551),
    [sym_continue_as_identifier] = ACTIONS(7547),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3486)] = {
    [sym_identifier] = ACTIONS(5410),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [aux_sym_where_condition_token1] = ACTIONS(5410),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5410),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_basic_type_token22] = ACTIONS(5410),
    [aux_sym_basic_type_token53] = ACTIONS(5410),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5410),
    [aux_sym_modify_modification_token1] = ACTIONS(5410),
    [aux_sym_separator_action_token1] = ACTIONS(5410),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [aux_sym_type_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [anon_sym_POUNDelif] = ACTIONS(5405),
    [anon_sym_POUNDELIF] = ACTIONS(5405),
    [anon_sym_POUNDElif] = ACTIONS(5405),
    [anon_sym_POUNDelse] = ACTIONS(5405),
    [anon_sym_POUNDELSE] = ACTIONS(5405),
    [anon_sym_POUNDElse] = ACTIONS(5405),
    [anon_sym_POUNDelse2] = ACTIONS(5405),
    [anon_sym_POUNDELSE2] = ACTIONS(5405),
    [anon_sym_POUNDElse2] = ACTIONS(5405),
    [anon_sym_POUNDendif] = ACTIONS(5405),
    [anon_sym_POUNDENDIF] = ACTIONS(5405),
    [anon_sym_POUNDEndif] = ACTIONS(5405),
    [anon_sym_POUNDendif2] = ACTIONS(5405),
    [anon_sym_POUNDENDIF2] = ACTIONS(5405),
    [anon_sym_POUNDEndif2] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_table_keyword] = ACTIONS(5410),
    [sym_procedure_keyword] = ACTIONS(5410),
    [sym_trigger_keyword] = ACTIONS(5410),
    [sym_var_keyword] = ACTIONS(5410),
    [sym_local_keyword] = ACTIONS(5410),
    [sym_internal_keyword] = ACTIONS(5410),
    [sym_protected_keyword] = ACTIONS(5410),
    [sym_event_keyword] = ACTIONS(5410),
    [sym_fields_keyword] = ACTIONS(5410),
    [sym_keys_keyword] = ACTIONS(5410),
    [sym_key_keyword] = ACTIONS(5410),
    [sym_fieldgroups_keyword] = ACTIONS(5410),
    [sym_actions_keyword] = ACTIONS(5410),
    [sym_layout_keyword] = ACTIONS(5410),
    [sym_dataset_keyword] = ACTIONS(5410),
    [sym_elements_keyword] = ACTIONS(5410),
    [sym_labels_keyword] = ACTIONS(5410),
    [sym_rendering_keyword] = ACTIONS(5410),
    [sym_requestpage_keyword] = ACTIONS(5410),
    [sym_schema_keyword] = ACTIONS(5410),
    [sym_views_keyword] = ACTIONS(5410),
    [sym_quoted_identifier] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
    [sym_preproc_close] = ACTIONS(5405),
    [sym_var_attribute_open] = ACTIONS(5405),
  },
  [STATE(3487)] = {
    [sym_identifier] = ACTIONS(3651),
    [anon_sym_SEMI] = ACTIONS(3653),
    [anon_sym_DOT] = ACTIONS(3651),
    [anon_sym_EQ] = ACTIONS(3653),
    [anon_sym_COMMA] = ACTIONS(3653),
    [anon_sym_COLON] = ACTIONS(3651),
    [anon_sym_DASH] = ACTIONS(3651),
    [aux_sym_boolean_token1] = ACTIONS(3651),
    [aux_sym_boolean_token2] = ACTIONS(3651),
    [sym_decimal] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3653),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3651),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_LBRACK] = ACTIONS(3653),
    [aux_sym_record_type_token1] = ACTIONS(3651),
    [aux_sym_basic_type_token21] = ACTIONS(3651),
    [aux_sym_basic_type_token22] = ACTIONS(3651),
    [aux_sym_basic_type_token48] = ACTIONS(3651),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3651),
    [anon_sym_COLON_COLON] = ACTIONS(3653),
    [anon_sym_POUNDif] = ACTIONS(3653),
    [anon_sym_POUNDIF] = ACTIONS(3653),
    [anon_sym_POUNDIf] = ACTIONS(3653),
    [anon_sym_not] = ACTIONS(3651),
    [anon_sym_NOT] = ACTIONS(3651),
    [anon_sym_Not] = ACTIONS(3651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3653),
    [aux_sym__expression_token1] = ACTIONS(3653),
    [aux_sym__expression_token2] = ACTIONS(3653),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3651),
    [anon_sym_SLASH] = ACTIONS(3651),
    [anon_sym_div] = ACTIONS(3651),
    [anon_sym_DIV] = ACTIONS(3651),
    [anon_sym_Div] = ACTIONS(3651),
    [anon_sym_mod] = ACTIONS(3651),
    [anon_sym_MOD] = ACTIONS(3651),
    [anon_sym_Mod] = ACTIONS(3651),
    [anon_sym_PLUS] = ACTIONS(3651),
    [anon_sym_GT_EQ] = ACTIONS(3653),
    [anon_sym_LT_EQ] = ACTIONS(3653),
    [anon_sym_GT] = ACTIONS(3651),
    [anon_sym_LT] = ACTIONS(3651),
    [anon_sym_LT_GT] = ACTIONS(3653),
    [anon_sym_and] = ACTIONS(3651),
    [anon_sym_AND] = ACTIONS(3651),
    [anon_sym_And] = ACTIONS(3651),
    [anon_sym_or] = ACTIONS(3651),
    [anon_sym_OR] = ACTIONS(3651),
    [anon_sym_Or] = ACTIONS(3651),
    [anon_sym_xor] = ACTIONS(3651),
    [anon_sym_XOR] = ACTIONS(3651),
    [anon_sym_Xor] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [sym_datetime_literal] = ACTIONS(3653),
    [sym_date_literal] = ACTIONS(3651),
    [sym_time_literal] = ACTIONS(3651),
    [sym_biginteger_literal] = ACTIONS(3653),
    [anon_sym_else] = ACTIONS(3651),
    [anon_sym_ELSE] = ACTIONS(3651),
    [anon_sym_Else] = ACTIONS(3651),
    [anon_sym_in] = ACTIONS(3651),
    [anon_sym_IN] = ACTIONS(3651),
    [anon_sym_In] = ACTIONS(3651),
    [sym_page_keyword] = ACTIONS(3651),
    [anon_sym_codeunit] = ACTIONS(3651),
    [anon_sym_CODEUNIT] = ACTIONS(3651),
    [anon_sym_Codeunit] = ACTIONS(3651),
    [anon_sym_CodeUnit] = ACTIONS(3651),
    [anon_sym_COdeunit] = ACTIONS(3651),
    [anon_sym_codeUnit] = ACTIONS(3651),
    [sym_report_keyword] = ACTIONS(3651),
    [sym_query_keyword] = ACTIONS(3651),
    [anon_sym_xmlport] = ACTIONS(3651),
    [anon_sym_XMLPORT] = ACTIONS(3651),
    [anon_sym_Xmlport] = ACTIONS(3651),
    [anon_sym_XMLport] = ACTIONS(3651),
    [anon_sym_XMLPort] = ACTIONS(3651),
    [anon_sym_XmlPort] = ACTIONS(3651),
    [anon_sym_enum] = ACTIONS(3651),
    [anon_sym_ENUM] = ACTIONS(3651),
    [anon_sym_Enum] = ACTIONS(3651),
    [anon_sym_eNUM] = ACTIONS(3651),
    [anon_sym_eNum] = ACTIONS(3651),
    [anon_sym_ENum] = ACTIONS(3651),
    [sym_quoted_identifier] = ACTIONS(3653),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3653),
    [sym_verbatim_string] = ACTIONS(3653),
    [sym_integer] = ACTIONS(3651),
    [sym_continue_as_identifier] = ACTIONS(3653),
    [sym_preproc_open] = ACTIONS(3653),
  },
  [STATE(3488)] = {
    [sym_identifier] = ACTIONS(3655),
    [anon_sym_SEMI] = ACTIONS(3657),
    [anon_sym_DOT] = ACTIONS(3655),
    [anon_sym_EQ] = ACTIONS(3657),
    [anon_sym_COMMA] = ACTIONS(3657),
    [anon_sym_COLON] = ACTIONS(3655),
    [anon_sym_DASH] = ACTIONS(3655),
    [aux_sym_boolean_token1] = ACTIONS(3655),
    [aux_sym_boolean_token2] = ACTIONS(3655),
    [sym_decimal] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3657),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3655),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [aux_sym_record_type_token1] = ACTIONS(3655),
    [aux_sym_basic_type_token21] = ACTIONS(3655),
    [aux_sym_basic_type_token22] = ACTIONS(3655),
    [aux_sym_basic_type_token48] = ACTIONS(3655),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3655),
    [anon_sym_COLON_COLON] = ACTIONS(3657),
    [anon_sym_POUNDif] = ACTIONS(3657),
    [anon_sym_POUNDIF] = ACTIONS(3657),
    [anon_sym_POUNDIf] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3655),
    [anon_sym_NOT] = ACTIONS(3655),
    [anon_sym_Not] = ACTIONS(3655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3657),
    [aux_sym__expression_token1] = ACTIONS(3657),
    [aux_sym__expression_token2] = ACTIONS(3657),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3655),
    [anon_sym_SLASH] = ACTIONS(3655),
    [anon_sym_div] = ACTIONS(3655),
    [anon_sym_DIV] = ACTIONS(3655),
    [anon_sym_Div] = ACTIONS(3655),
    [anon_sym_mod] = ACTIONS(3655),
    [anon_sym_MOD] = ACTIONS(3655),
    [anon_sym_Mod] = ACTIONS(3655),
    [anon_sym_PLUS] = ACTIONS(3655),
    [anon_sym_GT_EQ] = ACTIONS(3657),
    [anon_sym_LT_EQ] = ACTIONS(3657),
    [anon_sym_GT] = ACTIONS(3655),
    [anon_sym_LT] = ACTIONS(3655),
    [anon_sym_LT_GT] = ACTIONS(3657),
    [anon_sym_and] = ACTIONS(3655),
    [anon_sym_AND] = ACTIONS(3655),
    [anon_sym_And] = ACTIONS(3655),
    [anon_sym_or] = ACTIONS(3655),
    [anon_sym_OR] = ACTIONS(3655),
    [anon_sym_Or] = ACTIONS(3655),
    [anon_sym_xor] = ACTIONS(3655),
    [anon_sym_XOR] = ACTIONS(3655),
    [anon_sym_Xor] = ACTIONS(3655),
    [anon_sym_QMARK] = ACTIONS(3657),
    [sym_datetime_literal] = ACTIONS(3657),
    [sym_date_literal] = ACTIONS(3655),
    [sym_time_literal] = ACTIONS(3655),
    [sym_biginteger_literal] = ACTIONS(3657),
    [anon_sym_else] = ACTIONS(3655),
    [anon_sym_ELSE] = ACTIONS(3655),
    [anon_sym_Else] = ACTIONS(3655),
    [anon_sym_in] = ACTIONS(3655),
    [anon_sym_IN] = ACTIONS(3655),
    [anon_sym_In] = ACTIONS(3655),
    [sym_page_keyword] = ACTIONS(3655),
    [anon_sym_codeunit] = ACTIONS(3655),
    [anon_sym_CODEUNIT] = ACTIONS(3655),
    [anon_sym_Codeunit] = ACTIONS(3655),
    [anon_sym_CodeUnit] = ACTIONS(3655),
    [anon_sym_COdeunit] = ACTIONS(3655),
    [anon_sym_codeUnit] = ACTIONS(3655),
    [sym_report_keyword] = ACTIONS(3655),
    [sym_query_keyword] = ACTIONS(3655),
    [anon_sym_xmlport] = ACTIONS(3655),
    [anon_sym_XMLPORT] = ACTIONS(3655),
    [anon_sym_Xmlport] = ACTIONS(3655),
    [anon_sym_XMLport] = ACTIONS(3655),
    [anon_sym_XMLPort] = ACTIONS(3655),
    [anon_sym_XmlPort] = ACTIONS(3655),
    [anon_sym_enum] = ACTIONS(3655),
    [anon_sym_ENUM] = ACTIONS(3655),
    [anon_sym_Enum] = ACTIONS(3655),
    [anon_sym_eNUM] = ACTIONS(3655),
    [anon_sym_eNum] = ACTIONS(3655),
    [anon_sym_ENum] = ACTIONS(3655),
    [sym_quoted_identifier] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3657),
    [sym_verbatim_string] = ACTIONS(3657),
    [sym_integer] = ACTIONS(3655),
    [sym_continue_as_identifier] = ACTIONS(3657),
    [sym_preproc_open] = ACTIONS(3657),
  },
  [STATE(3489)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_elif] = STATE(3579),
    [sym_preproc_else] = STATE(3835),
    [sym_preproc_endif] = STATE(3897),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(10706),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7501),
    [anon_sym_POUNDELIF] = ACTIONS(7501),
    [anon_sym_POUNDElif] = ACTIONS(7501),
    [anon_sym_POUNDelse] = ACTIONS(7503),
    [anon_sym_POUNDELSE] = ACTIONS(7503),
    [anon_sym_POUNDElse] = ACTIONS(7503),
    [anon_sym_POUNDelse2] = ACTIONS(7503),
    [anon_sym_POUNDELSE2] = ACTIONS(7503),
    [anon_sym_POUNDElse2] = ACTIONS(7503),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3490)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_COLON] = ACTIONS(3663),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
  },
  [STATE(3491)] = {
    [sym_identifier] = ACTIONS(6698),
    [anon_sym_SEMI] = ACTIONS(6700),
    [anon_sym_DASH] = ACTIONS(6700),
    [aux_sym_boolean_token1] = ACTIONS(6698),
    [aux_sym_boolean_token2] = ACTIONS(6698),
    [sym_decimal] = ACTIONS(6698),
    [anon_sym_LPAREN] = ACTIONS(6700),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6698),
    [anon_sym_LBRACK] = ACTIONS(6700),
    [aux_sym_record_type_token1] = ACTIONS(6698),
    [aux_sym_basic_type_token21] = ACTIONS(6698),
    [aux_sym_basic_type_token22] = ACTIONS(6698),
    [aux_sym_basic_type_token48] = ACTIONS(6698),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6698),
    [anon_sym_POUNDif] = ACTIONS(6700),
    [anon_sym_POUNDIF] = ACTIONS(6700),
    [anon_sym_POUNDIf] = ACTIONS(6700),
    [anon_sym_not] = ACTIONS(6698),
    [anon_sym_NOT] = ACTIONS(6698),
    [anon_sym_Not] = ACTIONS(6698),
    [anon_sym_POUNDelse] = ACTIONS(6700),
    [anon_sym_POUNDELSE] = ACTIONS(6700),
    [anon_sym_POUNDElse] = ACTIONS(6700),
    [anon_sym_POUNDelse2] = ACTIONS(6700),
    [anon_sym_POUNDELSE2] = ACTIONS(6700),
    [anon_sym_POUNDElse2] = ACTIONS(6700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6698),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6698),
    [anon_sym_PLUS] = ACTIONS(6700),
    [sym_datetime_literal] = ACTIONS(6700),
    [sym_date_literal] = ACTIONS(6698),
    [sym_time_literal] = ACTIONS(6698),
    [sym_biginteger_literal] = ACTIONS(6700),
    [anon_sym_if] = ACTIONS(6698),
    [anon_sym_IF] = ACTIONS(6698),
    [anon_sym_If] = ACTIONS(6698),
    [anon_sym_case] = ACTIONS(6698),
    [anon_sym_CASE] = ACTIONS(6698),
    [anon_sym_Case] = ACTIONS(6698),
    [anon_sym_for] = ACTIONS(6698),
    [anon_sym_FOR] = ACTIONS(6698),
    [anon_sym_For] = ACTIONS(6698),
    [anon_sym_foreach] = ACTIONS(6698),
    [anon_sym_FOREACH] = ACTIONS(6698),
    [anon_sym_Foreach] = ACTIONS(6698),
    [anon_sym_while] = ACTIONS(6698),
    [anon_sym_WHILE] = ACTIONS(6698),
    [anon_sym_While] = ACTIONS(6698),
    [anon_sym_repeat] = ACTIONS(6698),
    [anon_sym_REPEAT] = ACTIONS(6698),
    [anon_sym_Repeat] = ACTIONS(6698),
    [anon_sym_exit] = ACTIONS(6698),
    [anon_sym_EXIT] = ACTIONS(6698),
    [anon_sym_Exit] = ACTIONS(6698),
    [anon_sym_continue] = ACTIONS(6698),
    [anon_sym_CONTINUE] = ACTIONS(6698),
    [anon_sym_Continue] = ACTIONS(6698),
    [anon_sym_break] = ACTIONS(6698),
    [anon_sym_BREAK] = ACTIONS(6698),
    [anon_sym_Break] = ACTIONS(6698),
    [anon_sym_with] = ACTIONS(6698),
    [anon_sym_WITH] = ACTIONS(6698),
    [anon_sym_With] = ACTIONS(6698),
    [sym_asserterror_keyword] = ACTIONS(6700),
    [sym_page_keyword] = ACTIONS(6698),
    [anon_sym_codeunit] = ACTIONS(6698),
    [anon_sym_CODEUNIT] = ACTIONS(6698),
    [anon_sym_Codeunit] = ACTIONS(6698),
    [anon_sym_CodeUnit] = ACTIONS(6698),
    [anon_sym_COdeunit] = ACTIONS(6698),
    [anon_sym_codeUnit] = ACTIONS(6698),
    [sym_report_keyword] = ACTIONS(6698),
    [sym_query_keyword] = ACTIONS(6698),
    [anon_sym_xmlport] = ACTIONS(6698),
    [anon_sym_XMLPORT] = ACTIONS(6698),
    [anon_sym_Xmlport] = ACTIONS(6698),
    [anon_sym_XMLport] = ACTIONS(6698),
    [anon_sym_XMLPort] = ACTIONS(6698),
    [anon_sym_XmlPort] = ACTIONS(6698),
    [anon_sym_enum] = ACTIONS(6698),
    [anon_sym_ENUM] = ACTIONS(6698),
    [anon_sym_Enum] = ACTIONS(6698),
    [anon_sym_eNUM] = ACTIONS(6698),
    [anon_sym_eNum] = ACTIONS(6698),
    [anon_sym_ENum] = ACTIONS(6698),
    [sym_quoted_identifier] = ACTIONS(6700),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6700),
    [sym_verbatim_string] = ACTIONS(6700),
    [sym_integer] = ACTIONS(6698),
    [sym_continue_as_identifier] = ACTIONS(6700),
    [sym_preproc_open] = ACTIONS(6700),
    [sym_end_keyword] = ACTIONS(6700),
  },
  [STATE(3492)] = {
    [sym_identifier] = ACTIONS(3776),
    [anon_sym_SEMI] = ACTIONS(3778),
    [anon_sym_DOT] = ACTIONS(3776),
    [anon_sym_EQ] = ACTIONS(3778),
    [anon_sym_COMMA] = ACTIONS(3778),
    [anon_sym_COLON] = ACTIONS(3776),
    [anon_sym_DASH] = ACTIONS(3776),
    [aux_sym_boolean_token1] = ACTIONS(3776),
    [aux_sym_boolean_token2] = ACTIONS(3776),
    [sym_decimal] = ACTIONS(3776),
    [anon_sym_LPAREN] = ACTIONS(3778),
    [anon_sym_DOT_DOT] = ACTIONS(3778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3776),
    [anon_sym_STAR] = ACTIONS(3776),
    [anon_sym_LBRACK] = ACTIONS(3778),
    [aux_sym_record_type_token1] = ACTIONS(3776),
    [aux_sym_basic_type_token21] = ACTIONS(3776),
    [aux_sym_basic_type_token22] = ACTIONS(3776),
    [aux_sym_basic_type_token48] = ACTIONS(3776),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_POUNDif] = ACTIONS(3778),
    [anon_sym_POUNDIF] = ACTIONS(3778),
    [anon_sym_POUNDIf] = ACTIONS(3778),
    [anon_sym_not] = ACTIONS(3776),
    [anon_sym_NOT] = ACTIONS(3776),
    [anon_sym_Not] = ACTIONS(3776),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3778),
    [aux_sym__expression_token1] = ACTIONS(3778),
    [aux_sym__expression_token2] = ACTIONS(3778),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3776),
    [anon_sym_SLASH] = ACTIONS(3776),
    [anon_sym_div] = ACTIONS(3776),
    [anon_sym_DIV] = ACTIONS(3776),
    [anon_sym_Div] = ACTIONS(3776),
    [anon_sym_mod] = ACTIONS(3776),
    [anon_sym_MOD] = ACTIONS(3776),
    [anon_sym_Mod] = ACTIONS(3776),
    [anon_sym_PLUS] = ACTIONS(3776),
    [anon_sym_GT_EQ] = ACTIONS(3778),
    [anon_sym_LT_EQ] = ACTIONS(3778),
    [anon_sym_GT] = ACTIONS(3776),
    [anon_sym_LT] = ACTIONS(3776),
    [anon_sym_LT_GT] = ACTIONS(3778),
    [anon_sym_and] = ACTIONS(3776),
    [anon_sym_AND] = ACTIONS(3776),
    [anon_sym_And] = ACTIONS(3776),
    [anon_sym_or] = ACTIONS(3776),
    [anon_sym_OR] = ACTIONS(3776),
    [anon_sym_Or] = ACTIONS(3776),
    [anon_sym_xor] = ACTIONS(3776),
    [anon_sym_XOR] = ACTIONS(3776),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(3778),
    [sym_date_literal] = ACTIONS(3776),
    [sym_time_literal] = ACTIONS(3776),
    [sym_biginteger_literal] = ACTIONS(3778),
    [anon_sym_else] = ACTIONS(3776),
    [anon_sym_ELSE] = ACTIONS(3776),
    [anon_sym_Else] = ACTIONS(3776),
    [anon_sym_in] = ACTIONS(3776),
    [anon_sym_IN] = ACTIONS(3776),
    [anon_sym_In] = ACTIONS(3776),
    [sym_page_keyword] = ACTIONS(3776),
    [anon_sym_codeunit] = ACTIONS(3776),
    [anon_sym_CODEUNIT] = ACTIONS(3776),
    [anon_sym_Codeunit] = ACTIONS(3776),
    [anon_sym_CodeUnit] = ACTIONS(3776),
    [anon_sym_COdeunit] = ACTIONS(3776),
    [anon_sym_codeUnit] = ACTIONS(3776),
    [sym_report_keyword] = ACTIONS(3776),
    [sym_query_keyword] = ACTIONS(3776),
    [anon_sym_xmlport] = ACTIONS(3776),
    [anon_sym_XMLPORT] = ACTIONS(3776),
    [anon_sym_Xmlport] = ACTIONS(3776),
    [anon_sym_XMLport] = ACTIONS(3776),
    [anon_sym_XMLPort] = ACTIONS(3776),
    [anon_sym_XmlPort] = ACTIONS(3776),
    [anon_sym_enum] = ACTIONS(3776),
    [anon_sym_ENUM] = ACTIONS(3776),
    [anon_sym_Enum] = ACTIONS(3776),
    [anon_sym_eNUM] = ACTIONS(3776),
    [anon_sym_eNum] = ACTIONS(3776),
    [anon_sym_ENum] = ACTIONS(3776),
    [sym_quoted_identifier] = ACTIONS(3778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3778),
    [sym_verbatim_string] = ACTIONS(3778),
    [sym_integer] = ACTIONS(3776),
    [sym_continue_as_identifier] = ACTIONS(3778),
    [sym_preproc_open] = ACTIONS(3778),
  },
  [STATE(3493)] = {
    [sym_identifier] = ACTIONS(3784),
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_COMMA] = ACTIONS(3786),
    [anon_sym_COLON] = ACTIONS(3784),
    [anon_sym_DASH] = ACTIONS(3784),
    [aux_sym_boolean_token1] = ACTIONS(3784),
    [aux_sym_boolean_token2] = ACTIONS(3784),
    [sym_decimal] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3784),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_record_type_token1] = ACTIONS(3784),
    [aux_sym_basic_type_token21] = ACTIONS(3784),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_basic_type_token48] = ACTIONS(3784),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_not] = ACTIONS(3784),
    [anon_sym_NOT] = ACTIONS(3784),
    [anon_sym_Not] = ACTIONS(3784),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3784),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3784),
    [anon_sym_DIV] = ACTIONS(3784),
    [anon_sym_Div] = ACTIONS(3784),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3784),
    [anon_sym_AND] = ACTIONS(3784),
    [anon_sym_And] = ACTIONS(3784),
    [anon_sym_or] = ACTIONS(3784),
    [anon_sym_OR] = ACTIONS(3784),
    [anon_sym_Or] = ACTIONS(3784),
    [anon_sym_xor] = ACTIONS(3784),
    [anon_sym_XOR] = ACTIONS(3784),
    [anon_sym_Xor] = ACTIONS(3784),
    [anon_sym_QMARK] = ACTIONS(3786),
    [sym_datetime_literal] = ACTIONS(3786),
    [sym_date_literal] = ACTIONS(3784),
    [sym_time_literal] = ACTIONS(3784),
    [sym_biginteger_literal] = ACTIONS(3786),
    [anon_sym_else] = ACTIONS(3784),
    [anon_sym_ELSE] = ACTIONS(3784),
    [anon_sym_Else] = ACTIONS(3784),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_page_keyword] = ACTIONS(3784),
    [anon_sym_codeunit] = ACTIONS(3784),
    [anon_sym_CODEUNIT] = ACTIONS(3784),
    [anon_sym_Codeunit] = ACTIONS(3784),
    [anon_sym_CodeUnit] = ACTIONS(3784),
    [anon_sym_COdeunit] = ACTIONS(3784),
    [anon_sym_codeUnit] = ACTIONS(3784),
    [sym_report_keyword] = ACTIONS(3784),
    [sym_query_keyword] = ACTIONS(3784),
    [anon_sym_xmlport] = ACTIONS(3784),
    [anon_sym_XMLPORT] = ACTIONS(3784),
    [anon_sym_Xmlport] = ACTIONS(3784),
    [anon_sym_XMLport] = ACTIONS(3784),
    [anon_sym_XMLPort] = ACTIONS(3784),
    [anon_sym_XmlPort] = ACTIONS(3784),
    [anon_sym_enum] = ACTIONS(3784),
    [anon_sym_ENUM] = ACTIONS(3784),
    [anon_sym_Enum] = ACTIONS(3784),
    [anon_sym_eNUM] = ACTIONS(3784),
    [anon_sym_eNum] = ACTIONS(3784),
    [anon_sym_ENum] = ACTIONS(3784),
    [sym_quoted_identifier] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3786),
    [sym_verbatim_string] = ACTIONS(3786),
    [sym_integer] = ACTIONS(3784),
    [sym_continue_as_identifier] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
  },
  [STATE(3494)] = {
    [sym_boolean] = STATE(8820),
    [sym_preproc_conditional_table_relation] = STATE(6059),
    [sym_table_relation_expression] = STATE(6153),
    [sym_if_table_relation] = STATE(6059),
    [sym_simple_table_relation] = STATE(6059),
    [sym__namespaced_or_simple_ref] = STATE(5577),
    [sym_preproc_if] = STATE(2178),
    [sym_assignment_expression] = STATE(8820),
    [sym__expression] = STATE(8820),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8820),
    [sym_multiplicative_expression] = STATE(8820),
    [sym_additive_expression] = STATE(8820),
    [sym_comparison_expression] = STATE(8820),
    [sym_logical_expression] = STATE(8820),
    [sym_ternary_expression] = STATE(8820),
    [sym_unary_expression] = STATE(8820),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(2813),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8820),
    [sym_list_literal] = STATE(8820),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8820),
    [sym__literal_value] = STATE(8820),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(5439),
    [sym_keyword_as_identifier] = STATE(5439),
    [sym_identifier] = ACTIONS(7553),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7555),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7557),
    [aux_sym_if_table_relation_token1] = ACTIONS(4081),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7559),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7557),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7557),
    [aux_sym_separator_action_token1] = ACTIONS(7557),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7557),
    [aux_sym_type_declaration_token1] = ACTIONS(7557),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7561),
    [sym_date_literal] = ACTIONS(7555),
    [sym_time_literal] = ACTIONS(7555),
    [sym_biginteger_literal] = ACTIONS(7561),
    [sym_table_keyword] = ACTIONS(7557),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7557),
    [sym_dataset_keyword] = ACTIONS(7557),
    [sym_quoted_identifier] = ACTIONS(7563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7561),
    [sym_verbatim_string] = ACTIONS(7561),
    [sym_integer] = ACTIONS(7565),
    [sym_continue_as_identifier] = ACTIONS(7561),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3495)] = {
    [sym_boolean] = STATE(8820),
    [sym_preproc_conditional_table_relation] = STATE(6059),
    [sym_table_relation_expression] = STATE(6153),
    [sym_if_table_relation] = STATE(6059),
    [sym_simple_table_relation] = STATE(6059),
    [sym__namespaced_or_simple_ref] = STATE(5577),
    [sym_preproc_if] = STATE(2135),
    [sym_assignment_expression] = STATE(8820),
    [sym__expression] = STATE(8820),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8820),
    [sym_multiplicative_expression] = STATE(8820),
    [sym_additive_expression] = STATE(8820),
    [sym_comparison_expression] = STATE(8820),
    [sym_logical_expression] = STATE(8820),
    [sym_ternary_expression] = STATE(8820),
    [sym_unary_expression] = STATE(8820),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(2813),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8820),
    [sym_list_literal] = STATE(8820),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8820),
    [sym__literal_value] = STATE(8820),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(5439),
    [sym_keyword_as_identifier] = STATE(5439),
    [sym_identifier] = ACTIONS(7553),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7555),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7557),
    [aux_sym_if_table_relation_token1] = ACTIONS(4091),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7559),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7557),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7557),
    [aux_sym_separator_action_token1] = ACTIONS(7557),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7557),
    [aux_sym_type_declaration_token1] = ACTIONS(7557),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7561),
    [sym_date_literal] = ACTIONS(7555),
    [sym_time_literal] = ACTIONS(7555),
    [sym_biginteger_literal] = ACTIONS(7561),
    [sym_table_keyword] = ACTIONS(7557),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7557),
    [sym_dataset_keyword] = ACTIONS(7557),
    [sym_quoted_identifier] = ACTIONS(7563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7561),
    [sym_verbatim_string] = ACTIONS(7561),
    [sym_integer] = ACTIONS(7565),
    [sym_continue_as_identifier] = ACTIONS(7561),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3496)] = {
    [aux_sym_option_member_list_repeat1] = STATE(3510),
    [sym_identifier] = ACTIONS(602),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_DOT] = ACTIONS(602),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(7489),
    [anon_sym_COLON] = ACTIONS(602),
    [anon_sym_DASH] = ACTIONS(602),
    [aux_sym_boolean_token1] = ACTIONS(602),
    [aux_sym_boolean_token2] = ACTIONS(602),
    [sym_decimal] = ACTIONS(602),
    [anon_sym_LPAREN] = ACTIONS(600),
    [anon_sym_DOT_DOT] = ACTIONS(600),
    [aux_sym_tabledata_permission_token2] = ACTIONS(602),
    [anon_sym_STAR] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(602),
    [aux_sym_basic_type_token21] = ACTIONS(602),
    [aux_sym_basic_type_token22] = ACTIONS(602),
    [aux_sym_basic_type_token48] = ACTIONS(602),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_not] = ACTIONS(602),
    [anon_sym_NOT] = ACTIONS(602),
    [anon_sym_Not] = ACTIONS(602),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(600),
    [aux_sym__expression_token1] = ACTIONS(600),
    [aux_sym__expression_token2] = ACTIONS(600),
    [aux_sym_keyword_identifier_token1] = ACTIONS(602),
    [aux_sym_keyword_identifier_token2] = ACTIONS(602),
    [anon_sym_SLASH] = ACTIONS(602),
    [anon_sym_div] = ACTIONS(602),
    [anon_sym_DIV] = ACTIONS(602),
    [anon_sym_Div] = ACTIONS(602),
    [anon_sym_mod] = ACTIONS(602),
    [anon_sym_MOD] = ACTIONS(602),
    [anon_sym_Mod] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_GT_EQ] = ACTIONS(600),
    [anon_sym_LT_EQ] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(602),
    [anon_sym_LT] = ACTIONS(602),
    [anon_sym_LT_GT] = ACTIONS(600),
    [anon_sym_and] = ACTIONS(602),
    [anon_sym_AND] = ACTIONS(602),
    [anon_sym_And] = ACTIONS(602),
    [anon_sym_or] = ACTIONS(602),
    [anon_sym_OR] = ACTIONS(602),
    [anon_sym_Or] = ACTIONS(602),
    [anon_sym_xor] = ACTIONS(602),
    [anon_sym_XOR] = ACTIONS(602),
    [anon_sym_Xor] = ACTIONS(602),
    [anon_sym_QMARK] = ACTIONS(600),
    [sym_datetime_literal] = ACTIONS(600),
    [sym_date_literal] = ACTIONS(602),
    [sym_time_literal] = ACTIONS(602),
    [sym_biginteger_literal] = ACTIONS(600),
    [anon_sym_else] = ACTIONS(602),
    [anon_sym_ELSE] = ACTIONS(602),
    [anon_sym_Else] = ACTIONS(602),
    [anon_sym_in] = ACTIONS(602),
    [anon_sym_IN] = ACTIONS(602),
    [anon_sym_In] = ACTIONS(602),
    [sym_page_keyword] = ACTIONS(602),
    [anon_sym_codeunit] = ACTIONS(602),
    [anon_sym_CODEUNIT] = ACTIONS(602),
    [anon_sym_Codeunit] = ACTIONS(602),
    [anon_sym_CodeUnit] = ACTIONS(602),
    [anon_sym_COdeunit] = ACTIONS(602),
    [anon_sym_codeUnit] = ACTIONS(602),
    [sym_report_keyword] = ACTIONS(602),
    [sym_query_keyword] = ACTIONS(602),
    [anon_sym_xmlport] = ACTIONS(602),
    [anon_sym_XMLPORT] = ACTIONS(602),
    [anon_sym_Xmlport] = ACTIONS(602),
    [anon_sym_XMLport] = ACTIONS(602),
    [anon_sym_XMLPort] = ACTIONS(602),
    [anon_sym_XmlPort] = ACTIONS(602),
    [anon_sym_enum] = ACTIONS(602),
    [anon_sym_ENUM] = ACTIONS(602),
    [anon_sym_Enum] = ACTIONS(602),
    [anon_sym_eNUM] = ACTIONS(602),
    [anon_sym_eNum] = ACTIONS(602),
    [anon_sym_ENum] = ACTIONS(602),
    [sym_quoted_identifier] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(600),
    [sym_verbatim_string] = ACTIONS(600),
    [sym_integer] = ACTIONS(602),
    [sym_continue_as_identifier] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
  },
  [STATE(3497)] = {
    [sym_identifier] = ACTIONS(3746),
    [anon_sym_SEMI] = ACTIONS(3748),
    [anon_sym_DOT] = ACTIONS(3746),
    [anon_sym_EQ] = ACTIONS(3748),
    [anon_sym_COMMA] = ACTIONS(3748),
    [anon_sym_COLON] = ACTIONS(3746),
    [anon_sym_DASH] = ACTIONS(3746),
    [aux_sym_boolean_token1] = ACTIONS(3746),
    [aux_sym_boolean_token2] = ACTIONS(3746),
    [sym_decimal] = ACTIONS(3746),
    [anon_sym_LPAREN] = ACTIONS(3748),
    [anon_sym_DOT_DOT] = ACTIONS(3748),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3746),
    [anon_sym_STAR] = ACTIONS(3746),
    [anon_sym_LBRACK] = ACTIONS(3748),
    [aux_sym_record_type_token1] = ACTIONS(3746),
    [aux_sym_basic_type_token21] = ACTIONS(3746),
    [aux_sym_basic_type_token22] = ACTIONS(3746),
    [aux_sym_basic_type_token48] = ACTIONS(3746),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3746),
    [anon_sym_POUNDif] = ACTIONS(3748),
    [anon_sym_POUNDIF] = ACTIONS(3748),
    [anon_sym_POUNDIf] = ACTIONS(3748),
    [anon_sym_not] = ACTIONS(3746),
    [anon_sym_NOT] = ACTIONS(3746),
    [anon_sym_Not] = ACTIONS(3746),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3748),
    [aux_sym__expression_token1] = ACTIONS(3748),
    [aux_sym__expression_token2] = ACTIONS(3748),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3746),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3746),
    [anon_sym_SLASH] = ACTIONS(3746),
    [anon_sym_div] = ACTIONS(3746),
    [anon_sym_DIV] = ACTIONS(3746),
    [anon_sym_Div] = ACTIONS(3746),
    [anon_sym_mod] = ACTIONS(3746),
    [anon_sym_MOD] = ACTIONS(3746),
    [anon_sym_Mod] = ACTIONS(3746),
    [anon_sym_PLUS] = ACTIONS(3746),
    [anon_sym_GT_EQ] = ACTIONS(3748),
    [anon_sym_LT_EQ] = ACTIONS(3748),
    [anon_sym_GT] = ACTIONS(3746),
    [anon_sym_LT] = ACTIONS(3746),
    [anon_sym_LT_GT] = ACTIONS(3748),
    [anon_sym_and] = ACTIONS(3746),
    [anon_sym_AND] = ACTIONS(3746),
    [anon_sym_And] = ACTIONS(3746),
    [anon_sym_or] = ACTIONS(3746),
    [anon_sym_OR] = ACTIONS(3746),
    [anon_sym_Or] = ACTIONS(3746),
    [anon_sym_xor] = ACTIONS(3746),
    [anon_sym_XOR] = ACTIONS(3746),
    [anon_sym_Xor] = ACTIONS(3746),
    [anon_sym_QMARK] = ACTIONS(3748),
    [sym_datetime_literal] = ACTIONS(3748),
    [sym_date_literal] = ACTIONS(3746),
    [sym_time_literal] = ACTIONS(3746),
    [sym_biginteger_literal] = ACTIONS(3748),
    [anon_sym_else] = ACTIONS(3746),
    [anon_sym_ELSE] = ACTIONS(3746),
    [anon_sym_Else] = ACTIONS(3746),
    [anon_sym_in] = ACTIONS(3746),
    [anon_sym_IN] = ACTIONS(3746),
    [anon_sym_In] = ACTIONS(3746),
    [sym_page_keyword] = ACTIONS(3746),
    [anon_sym_codeunit] = ACTIONS(3746),
    [anon_sym_CODEUNIT] = ACTIONS(3746),
    [anon_sym_Codeunit] = ACTIONS(3746),
    [anon_sym_CodeUnit] = ACTIONS(3746),
    [anon_sym_COdeunit] = ACTIONS(3746),
    [anon_sym_codeUnit] = ACTIONS(3746),
    [sym_report_keyword] = ACTIONS(3746),
    [sym_query_keyword] = ACTIONS(3746),
    [anon_sym_xmlport] = ACTIONS(3746),
    [anon_sym_XMLPORT] = ACTIONS(3746),
    [anon_sym_Xmlport] = ACTIONS(3746),
    [anon_sym_XMLport] = ACTIONS(3746),
    [anon_sym_XMLPort] = ACTIONS(3746),
    [anon_sym_XmlPort] = ACTIONS(3746),
    [anon_sym_enum] = ACTIONS(3746),
    [anon_sym_ENUM] = ACTIONS(3746),
    [anon_sym_Enum] = ACTIONS(3746),
    [anon_sym_eNUM] = ACTIONS(3746),
    [anon_sym_eNum] = ACTIONS(3746),
    [anon_sym_ENum] = ACTIONS(3746),
    [sym_temporary_keyword] = ACTIONS(7567),
    [sym_quoted_identifier] = ACTIONS(3748),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3748),
    [sym_verbatim_string] = ACTIONS(3748),
    [sym_integer] = ACTIONS(3746),
    [sym_continue_as_identifier] = ACTIONS(3748),
    [sym_preproc_open] = ACTIONS(3748),
  },
  [STATE(3498)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_elif] = STATE(3579),
    [sym_preproc_else] = STATE(3857),
    [sym_preproc_endif] = STATE(3936),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(11008),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7501),
    [anon_sym_POUNDELIF] = ACTIONS(7501),
    [anon_sym_POUNDElif] = ACTIONS(7501),
    [anon_sym_POUNDelse] = ACTIONS(7503),
    [anon_sym_POUNDELSE] = ACTIONS(7503),
    [anon_sym_POUNDElse] = ACTIONS(7503),
    [anon_sym_POUNDelse2] = ACTIONS(7503),
    [anon_sym_POUNDELSE2] = ACTIONS(7503),
    [anon_sym_POUNDElse2] = ACTIONS(7503),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3499)] = {
    [aux_sym_option_member_list_repeat1] = STATE(3499),
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(7569),
    [anon_sym_COLON] = ACTIONS(3632),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3634),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
  },
  [STATE(3500)] = {
    [sym_identifier] = ACTIONS(3784),
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [aux_sym_where_clause_token1] = ACTIONS(3786),
    [aux_sym_where_condition_token1] = ACTIONS(3784),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_basic_type_token22] = ACTIONS(3784),
    [aux_sym_basic_type_token53] = ACTIONS(3784),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3784),
    [aux_sym_modify_modification_token1] = ACTIONS(3784),
    [aux_sym_separator_action_token1] = ACTIONS(3784),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3784),
    [aux_sym_type_declaration_token1] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_POUNDelif] = ACTIONS(3786),
    [anon_sym_POUNDELIF] = ACTIONS(3786),
    [anon_sym_POUNDElif] = ACTIONS(3786),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [anon_sym_POUNDendif] = ACTIONS(3786),
    [anon_sym_POUNDENDIF] = ACTIONS(3786),
    [anon_sym_POUNDEndif] = ACTIONS(3786),
    [anon_sym_POUNDendif2] = ACTIONS(3786),
    [anon_sym_POUNDENDIF2] = ACTIONS(3786),
    [anon_sym_POUNDEndif2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3784),
    [anon_sym_DIV] = ACTIONS(3784),
    [anon_sym_Div] = ACTIONS(3784),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3784),
    [anon_sym_AND] = ACTIONS(3784),
    [anon_sym_And] = ACTIONS(3784),
    [anon_sym_or] = ACTIONS(3784),
    [anon_sym_OR] = ACTIONS(3784),
    [anon_sym_Or] = ACTIONS(3784),
    [anon_sym_xor] = ACTIONS(3784),
    [anon_sym_XOR] = ACTIONS(3784),
    [anon_sym_Xor] = ACTIONS(3784),
    [anon_sym_QMARK] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_table_keyword] = ACTIONS(3784),
    [sym_procedure_keyword] = ACTIONS(3784),
    [sym_trigger_keyword] = ACTIONS(3784),
    [sym_var_keyword] = ACTIONS(3784),
    [sym_local_keyword] = ACTIONS(3784),
    [sym_internal_keyword] = ACTIONS(3784),
    [sym_protected_keyword] = ACTIONS(3784),
    [sym_event_keyword] = ACTIONS(3784),
    [sym_fields_keyword] = ACTIONS(3784),
    [sym_keys_keyword] = ACTIONS(3784),
    [sym_key_keyword] = ACTIONS(3784),
    [sym_fieldgroups_keyword] = ACTIONS(3784),
    [sym_actions_keyword] = ACTIONS(3784),
    [sym_layout_keyword] = ACTIONS(3784),
    [sym_dataset_keyword] = ACTIONS(3784),
    [sym_elements_keyword] = ACTIONS(3784),
    [sym_labels_keyword] = ACTIONS(3784),
    [sym_rendering_keyword] = ACTIONS(3784),
    [sym_requestpage_keyword] = ACTIONS(3784),
    [sym_schema_keyword] = ACTIONS(3784),
    [sym_views_keyword] = ACTIONS(3784),
    [sym_quoted_identifier] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
    [sym_preproc_close] = ACTIONS(3786),
    [sym_var_attribute_open] = ACTIONS(3786),
  },
  [STATE(3501)] = {
    [sym_identifier] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(3683),
    [anon_sym_COLON] = ACTIONS(3681),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_boolean_token1] = ACTIONS(3681),
    [aux_sym_boolean_token2] = ACTIONS(3681),
    [sym_decimal] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [aux_sym_record_type_token1] = ACTIONS(3681),
    [aux_sym_basic_type_token21] = ACTIONS(3681),
    [aux_sym_basic_type_token22] = ACTIONS(3681),
    [aux_sym_basic_type_token48] = ACTIONS(3681),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3681),
    [anon_sym_COLON_COLON] = ACTIONS(7487),
    [anon_sym_POUNDif] = ACTIONS(3683),
    [anon_sym_POUNDIF] = ACTIONS(3683),
    [anon_sym_POUNDIf] = ACTIONS(3683),
    [anon_sym_not] = ACTIONS(3681),
    [anon_sym_NOT] = ACTIONS(3681),
    [anon_sym_Not] = ACTIONS(3681),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3681),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(3683),
    [sym_date_literal] = ACTIONS(3681),
    [sym_time_literal] = ACTIONS(3681),
    [sym_biginteger_literal] = ACTIONS(3683),
    [anon_sym_else] = ACTIONS(3681),
    [anon_sym_ELSE] = ACTIONS(3681),
    [anon_sym_Else] = ACTIONS(3681),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(3681),
    [anon_sym_codeunit] = ACTIONS(3681),
    [anon_sym_CODEUNIT] = ACTIONS(3681),
    [anon_sym_Codeunit] = ACTIONS(3681),
    [anon_sym_CodeUnit] = ACTIONS(3681),
    [anon_sym_COdeunit] = ACTIONS(3681),
    [anon_sym_codeUnit] = ACTIONS(3681),
    [sym_report_keyword] = ACTIONS(3681),
    [sym_query_keyword] = ACTIONS(3681),
    [anon_sym_xmlport] = ACTIONS(3681),
    [anon_sym_XMLPORT] = ACTIONS(3681),
    [anon_sym_Xmlport] = ACTIONS(3681),
    [anon_sym_XMLport] = ACTIONS(3681),
    [anon_sym_XMLPort] = ACTIONS(3681),
    [anon_sym_XmlPort] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_ENUM] = ACTIONS(3681),
    [anon_sym_Enum] = ACTIONS(3681),
    [anon_sym_eNUM] = ACTIONS(3681),
    [anon_sym_eNum] = ACTIONS(3681),
    [anon_sym_ENum] = ACTIONS(3681),
    [sym_quoted_identifier] = ACTIONS(3683),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3683),
    [sym_verbatim_string] = ACTIONS(3683),
    [sym_integer] = ACTIONS(3681),
    [sym_continue_as_identifier] = ACTIONS(3683),
    [sym_preproc_open] = ACTIONS(3683),
  },
  [STATE(3502)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token53] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3562),
    [aux_sym_modify_modification_token1] = ACTIONS(3562),
    [aux_sym_separator_action_token1] = ACTIONS(3562),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [aux_sym_type_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_table_keyword] = ACTIONS(3562),
    [sym_procedure_keyword] = ACTIONS(3562),
    [sym_trigger_keyword] = ACTIONS(3562),
    [sym_var_keyword] = ACTIONS(3562),
    [sym_local_keyword] = ACTIONS(3562),
    [sym_internal_keyword] = ACTIONS(3562),
    [sym_protected_keyword] = ACTIONS(3562),
    [sym_event_keyword] = ACTIONS(3562),
    [sym_fields_keyword] = ACTIONS(3562),
    [sym_keys_keyword] = ACTIONS(3562),
    [sym_key_keyword] = ACTIONS(3562),
    [sym_fieldgroups_keyword] = ACTIONS(3562),
    [sym_actions_keyword] = ACTIONS(3562),
    [sym_layout_keyword] = ACTIONS(3562),
    [sym_dataset_keyword] = ACTIONS(3562),
    [sym_elements_keyword] = ACTIONS(3562),
    [sym_labels_keyword] = ACTIONS(3562),
    [sym_rendering_keyword] = ACTIONS(3562),
    [sym_requestpage_keyword] = ACTIONS(3562),
    [sym_schema_keyword] = ACTIONS(3562),
    [sym_views_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
    [sym_var_attribute_open] = ACTIONS(3564),
  },
  [STATE(3503)] = {
    [sym_identifier] = ACTIONS(3760),
    [anon_sym_SEMI] = ACTIONS(3762),
    [anon_sym_DOT] = ACTIONS(3760),
    [anon_sym_EQ] = ACTIONS(3762),
    [anon_sym_COMMA] = ACTIONS(3762),
    [anon_sym_COLON] = ACTIONS(3760),
    [anon_sym_DASH] = ACTIONS(3760),
    [aux_sym_boolean_token1] = ACTIONS(3760),
    [aux_sym_boolean_token2] = ACTIONS(3760),
    [sym_decimal] = ACTIONS(3760),
    [anon_sym_LPAREN] = ACTIONS(3762),
    [anon_sym_DOT_DOT] = ACTIONS(3762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3760),
    [anon_sym_STAR] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3762),
    [aux_sym_record_type_token1] = ACTIONS(3760),
    [aux_sym_basic_type_token21] = ACTIONS(3760),
    [aux_sym_basic_type_token22] = ACTIONS(3760),
    [aux_sym_basic_type_token48] = ACTIONS(3760),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3760),
    [anon_sym_COLON_COLON] = ACTIONS(3762),
    [anon_sym_POUNDif] = ACTIONS(3762),
    [anon_sym_POUNDIF] = ACTIONS(3762),
    [anon_sym_POUNDIf] = ACTIONS(3762),
    [anon_sym_not] = ACTIONS(3760),
    [anon_sym_NOT] = ACTIONS(3760),
    [anon_sym_Not] = ACTIONS(3760),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3762),
    [aux_sym__expression_token1] = ACTIONS(3762),
    [aux_sym__expression_token2] = ACTIONS(3762),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3760),
    [anon_sym_SLASH] = ACTIONS(3760),
    [anon_sym_div] = ACTIONS(3760),
    [anon_sym_DIV] = ACTIONS(3760),
    [anon_sym_Div] = ACTIONS(3760),
    [anon_sym_mod] = ACTIONS(3760),
    [anon_sym_MOD] = ACTIONS(3760),
    [anon_sym_Mod] = ACTIONS(3760),
    [anon_sym_PLUS] = ACTIONS(3760),
    [anon_sym_GT_EQ] = ACTIONS(3762),
    [anon_sym_LT_EQ] = ACTIONS(3762),
    [anon_sym_GT] = ACTIONS(3760),
    [anon_sym_LT] = ACTIONS(3760),
    [anon_sym_LT_GT] = ACTIONS(3762),
    [anon_sym_and] = ACTIONS(3760),
    [anon_sym_AND] = ACTIONS(3760),
    [anon_sym_And] = ACTIONS(3760),
    [anon_sym_or] = ACTIONS(3760),
    [anon_sym_OR] = ACTIONS(3760),
    [anon_sym_Or] = ACTIONS(3760),
    [anon_sym_xor] = ACTIONS(3760),
    [anon_sym_XOR] = ACTIONS(3760),
    [anon_sym_Xor] = ACTIONS(3760),
    [anon_sym_QMARK] = ACTIONS(3762),
    [sym_datetime_literal] = ACTIONS(3762),
    [sym_date_literal] = ACTIONS(3760),
    [sym_time_literal] = ACTIONS(3760),
    [sym_biginteger_literal] = ACTIONS(3762),
    [anon_sym_else] = ACTIONS(3760),
    [anon_sym_ELSE] = ACTIONS(3760),
    [anon_sym_Else] = ACTIONS(3760),
    [anon_sym_in] = ACTIONS(3760),
    [anon_sym_IN] = ACTIONS(3760),
    [anon_sym_In] = ACTIONS(3760),
    [sym_page_keyword] = ACTIONS(3760),
    [anon_sym_codeunit] = ACTIONS(3760),
    [anon_sym_CODEUNIT] = ACTIONS(3760),
    [anon_sym_Codeunit] = ACTIONS(3760),
    [anon_sym_CodeUnit] = ACTIONS(3760),
    [anon_sym_COdeunit] = ACTIONS(3760),
    [anon_sym_codeUnit] = ACTIONS(3760),
    [sym_report_keyword] = ACTIONS(3760),
    [sym_query_keyword] = ACTIONS(3760),
    [anon_sym_xmlport] = ACTIONS(3760),
    [anon_sym_XMLPORT] = ACTIONS(3760),
    [anon_sym_Xmlport] = ACTIONS(3760),
    [anon_sym_XMLport] = ACTIONS(3760),
    [anon_sym_XMLPort] = ACTIONS(3760),
    [anon_sym_XmlPort] = ACTIONS(3760),
    [anon_sym_enum] = ACTIONS(3760),
    [anon_sym_ENUM] = ACTIONS(3760),
    [anon_sym_Enum] = ACTIONS(3760),
    [anon_sym_eNUM] = ACTIONS(3760),
    [anon_sym_eNum] = ACTIONS(3760),
    [anon_sym_ENum] = ACTIONS(3760),
    [sym_quoted_identifier] = ACTIONS(3762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3762),
    [sym_verbatim_string] = ACTIONS(3762),
    [sym_integer] = ACTIONS(3760),
    [sym_continue_as_identifier] = ACTIONS(3762),
    [sym_preproc_open] = ACTIONS(3762),
  },
  [STATE(3504)] = {
    [sym_identifier] = ACTIONS(3790),
    [anon_sym_SEMI] = ACTIONS(3792),
    [anon_sym_DOT] = ACTIONS(3790),
    [anon_sym_EQ] = ACTIONS(3792),
    [anon_sym_COMMA] = ACTIONS(3792),
    [anon_sym_COLON] = ACTIONS(3790),
    [anon_sym_DASH] = ACTIONS(3790),
    [aux_sym_boolean_token1] = ACTIONS(3790),
    [aux_sym_boolean_token2] = ACTIONS(3790),
    [sym_decimal] = ACTIONS(3790),
    [anon_sym_LPAREN] = ACTIONS(3792),
    [anon_sym_DOT_DOT] = ACTIONS(3792),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3790),
    [anon_sym_STAR] = ACTIONS(3790),
    [anon_sym_LBRACK] = ACTIONS(3792),
    [aux_sym_record_type_token1] = ACTIONS(3790),
    [aux_sym_basic_type_token21] = ACTIONS(3790),
    [aux_sym_basic_type_token22] = ACTIONS(3790),
    [aux_sym_basic_type_token48] = ACTIONS(3790),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3790),
    [anon_sym_COLON_COLON] = ACTIONS(3792),
    [anon_sym_POUNDif] = ACTIONS(3792),
    [anon_sym_POUNDIF] = ACTIONS(3792),
    [anon_sym_POUNDIf] = ACTIONS(3792),
    [anon_sym_not] = ACTIONS(3790),
    [anon_sym_NOT] = ACTIONS(3790),
    [anon_sym_Not] = ACTIONS(3790),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3792),
    [aux_sym__expression_token1] = ACTIONS(3792),
    [aux_sym__expression_token2] = ACTIONS(3792),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3790),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3790),
    [anon_sym_SLASH] = ACTIONS(3790),
    [anon_sym_div] = ACTIONS(3790),
    [anon_sym_DIV] = ACTIONS(3790),
    [anon_sym_Div] = ACTIONS(3790),
    [anon_sym_mod] = ACTIONS(3790),
    [anon_sym_MOD] = ACTIONS(3790),
    [anon_sym_Mod] = ACTIONS(3790),
    [anon_sym_PLUS] = ACTIONS(3790),
    [anon_sym_GT_EQ] = ACTIONS(3792),
    [anon_sym_LT_EQ] = ACTIONS(3792),
    [anon_sym_GT] = ACTIONS(3790),
    [anon_sym_LT] = ACTIONS(3790),
    [anon_sym_LT_GT] = ACTIONS(3792),
    [anon_sym_and] = ACTIONS(3790),
    [anon_sym_AND] = ACTIONS(3790),
    [anon_sym_And] = ACTIONS(3790),
    [anon_sym_or] = ACTIONS(3790),
    [anon_sym_OR] = ACTIONS(3790),
    [anon_sym_Or] = ACTIONS(3790),
    [anon_sym_xor] = ACTIONS(3790),
    [anon_sym_XOR] = ACTIONS(3790),
    [anon_sym_Xor] = ACTIONS(3790),
    [anon_sym_QMARK] = ACTIONS(3792),
    [sym_datetime_literal] = ACTIONS(3792),
    [sym_date_literal] = ACTIONS(3790),
    [sym_time_literal] = ACTIONS(3790),
    [sym_biginteger_literal] = ACTIONS(3792),
    [anon_sym_else] = ACTIONS(3790),
    [anon_sym_ELSE] = ACTIONS(3790),
    [anon_sym_Else] = ACTIONS(3790),
    [anon_sym_in] = ACTIONS(3790),
    [anon_sym_IN] = ACTIONS(3790),
    [anon_sym_In] = ACTIONS(3790),
    [sym_page_keyword] = ACTIONS(3790),
    [anon_sym_codeunit] = ACTIONS(3790),
    [anon_sym_CODEUNIT] = ACTIONS(3790),
    [anon_sym_Codeunit] = ACTIONS(3790),
    [anon_sym_CodeUnit] = ACTIONS(3790),
    [anon_sym_COdeunit] = ACTIONS(3790),
    [anon_sym_codeUnit] = ACTIONS(3790),
    [sym_report_keyword] = ACTIONS(3790),
    [sym_query_keyword] = ACTIONS(3790),
    [anon_sym_xmlport] = ACTIONS(3790),
    [anon_sym_XMLPORT] = ACTIONS(3790),
    [anon_sym_Xmlport] = ACTIONS(3790),
    [anon_sym_XMLport] = ACTIONS(3790),
    [anon_sym_XMLPort] = ACTIONS(3790),
    [anon_sym_XmlPort] = ACTIONS(3790),
    [anon_sym_enum] = ACTIONS(3790),
    [anon_sym_ENUM] = ACTIONS(3790),
    [anon_sym_Enum] = ACTIONS(3790),
    [anon_sym_eNUM] = ACTIONS(3790),
    [anon_sym_eNum] = ACTIONS(3790),
    [anon_sym_ENum] = ACTIONS(3790),
    [sym_quoted_identifier] = ACTIONS(3792),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3792),
    [sym_verbatim_string] = ACTIONS(3792),
    [sym_integer] = ACTIONS(3790),
    [sym_continue_as_identifier] = ACTIONS(3792),
    [sym_preproc_open] = ACTIONS(3792),
  },
  [STATE(3505)] = {
    [sym_boolean] = STATE(8824),
    [sym_preproc_conditional_table_relation] = STATE(5009),
    [sym_table_relation_expression] = STATE(5261),
    [sym_if_table_relation] = STATE(5009),
    [sym_simple_table_relation] = STATE(5009),
    [sym__namespaced_or_simple_ref] = STATE(4477),
    [sym_preproc_if] = STATE(2142),
    [sym_assignment_expression] = STATE(8824),
    [sym__expression] = STATE(8824),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8824),
    [sym_multiplicative_expression] = STATE(8824),
    [sym_additive_expression] = STATE(8824),
    [sym_comparison_expression] = STATE(8824),
    [sym_logical_expression] = STATE(8824),
    [sym_ternary_expression] = STATE(8824),
    [sym_unary_expression] = STATE(8824),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(2302),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8824),
    [sym_list_literal] = STATE(8824),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8824),
    [sym__literal_value] = STATE(8824),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(4330),
    [sym_keyword_as_identifier] = STATE(4330),
    [sym_identifier] = ACTIONS(7572),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7574),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7576),
    [aux_sym_if_table_relation_token1] = ACTIONS(4029),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7578),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7576),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7576),
    [aux_sym_separator_action_token1] = ACTIONS(7576),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7576),
    [aux_sym_type_declaration_token1] = ACTIONS(7576),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7580),
    [sym_date_literal] = ACTIONS(7574),
    [sym_time_literal] = ACTIONS(7574),
    [sym_biginteger_literal] = ACTIONS(7580),
    [sym_table_keyword] = ACTIONS(7576),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7576),
    [sym_dataset_keyword] = ACTIONS(7576),
    [sym_quoted_identifier] = ACTIONS(7582),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7580),
    [sym_verbatim_string] = ACTIONS(7580),
    [sym_integer] = ACTIONS(7584),
    [sym_continue_as_identifier] = ACTIONS(7580),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3506)] = {
    [sym_boolean] = STATE(8824),
    [sym_preproc_conditional_table_relation] = STATE(5009),
    [sym_table_relation_expression] = STATE(5261),
    [sym_if_table_relation] = STATE(5009),
    [sym_simple_table_relation] = STATE(5009),
    [sym__namespaced_or_simple_ref] = STATE(4477),
    [sym_preproc_if] = STATE(2117),
    [sym_assignment_expression] = STATE(8824),
    [sym__expression] = STATE(8824),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8824),
    [sym_multiplicative_expression] = STATE(8824),
    [sym_additive_expression] = STATE(8824),
    [sym_comparison_expression] = STATE(8824),
    [sym_logical_expression] = STATE(8824),
    [sym_ternary_expression] = STATE(8824),
    [sym_unary_expression] = STATE(8824),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(2302),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8824),
    [sym_list_literal] = STATE(8824),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8824),
    [sym__literal_value] = STATE(8824),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(4330),
    [sym_keyword_as_identifier] = STATE(4330),
    [sym_identifier] = ACTIONS(7572),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7574),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7576),
    [aux_sym_if_table_relation_token1] = ACTIONS(4063),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7578),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7576),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7576),
    [aux_sym_separator_action_token1] = ACTIONS(7576),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7576),
    [aux_sym_type_declaration_token1] = ACTIONS(7576),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7580),
    [sym_date_literal] = ACTIONS(7574),
    [sym_time_literal] = ACTIONS(7574),
    [sym_biginteger_literal] = ACTIONS(7580),
    [sym_table_keyword] = ACTIONS(7576),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7576),
    [sym_dataset_keyword] = ACTIONS(7576),
    [sym_quoted_identifier] = ACTIONS(7582),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7580),
    [sym_verbatim_string] = ACTIONS(7580),
    [sym_integer] = ACTIONS(7584),
    [sym_continue_as_identifier] = ACTIONS(7580),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3507)] = {
    [sym_identifier] = ACTIONS(3703),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(3703),
    [anon_sym_EQ] = ACTIONS(3705),
    [anon_sym_COMMA] = ACTIONS(3705),
    [anon_sym_COLON] = ACTIONS(3703),
    [anon_sym_DASH] = ACTIONS(3703),
    [aux_sym_boolean_token1] = ACTIONS(3703),
    [aux_sym_boolean_token2] = ACTIONS(3703),
    [sym_decimal] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3705),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3703),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_record_type_token1] = ACTIONS(3703),
    [aux_sym_basic_type_token21] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_basic_type_token48] = ACTIONS(3703),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3703),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_not] = ACTIONS(3703),
    [anon_sym_NOT] = ACTIONS(3703),
    [anon_sym_Not] = ACTIONS(3703),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3705),
    [aux_sym__expression_token1] = ACTIONS(3705),
    [aux_sym__expression_token2] = ACTIONS(3705),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3703),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3703),
    [anon_sym_SLASH] = ACTIONS(3703),
    [anon_sym_div] = ACTIONS(3703),
    [anon_sym_DIV] = ACTIONS(3703),
    [anon_sym_Div] = ACTIONS(3703),
    [anon_sym_mod] = ACTIONS(3703),
    [anon_sym_MOD] = ACTIONS(3703),
    [anon_sym_Mod] = ACTIONS(3703),
    [anon_sym_PLUS] = ACTIONS(3703),
    [anon_sym_GT_EQ] = ACTIONS(3705),
    [anon_sym_LT_EQ] = ACTIONS(3705),
    [anon_sym_GT] = ACTIONS(3703),
    [anon_sym_LT] = ACTIONS(3703),
    [anon_sym_LT_GT] = ACTIONS(3705),
    [anon_sym_and] = ACTIONS(3703),
    [anon_sym_AND] = ACTIONS(3703),
    [anon_sym_And] = ACTIONS(3703),
    [anon_sym_or] = ACTIONS(3703),
    [anon_sym_OR] = ACTIONS(3703),
    [anon_sym_Or] = ACTIONS(3703),
    [anon_sym_xor] = ACTIONS(3703),
    [anon_sym_XOR] = ACTIONS(3703),
    [anon_sym_Xor] = ACTIONS(3703),
    [anon_sym_QMARK] = ACTIONS(3705),
    [sym_datetime_literal] = ACTIONS(3705),
    [sym_date_literal] = ACTIONS(3703),
    [sym_time_literal] = ACTIONS(3703),
    [sym_biginteger_literal] = ACTIONS(3705),
    [anon_sym_else] = ACTIONS(3703),
    [anon_sym_ELSE] = ACTIONS(3703),
    [anon_sym_Else] = ACTIONS(3703),
    [anon_sym_in] = ACTIONS(3703),
    [anon_sym_IN] = ACTIONS(3703),
    [anon_sym_In] = ACTIONS(3703),
    [sym_page_keyword] = ACTIONS(3703),
    [anon_sym_codeunit] = ACTIONS(3703),
    [anon_sym_CODEUNIT] = ACTIONS(3703),
    [anon_sym_Codeunit] = ACTIONS(3703),
    [anon_sym_CodeUnit] = ACTIONS(3703),
    [anon_sym_COdeunit] = ACTIONS(3703),
    [anon_sym_codeUnit] = ACTIONS(3703),
    [sym_report_keyword] = ACTIONS(3703),
    [sym_query_keyword] = ACTIONS(3703),
    [anon_sym_xmlport] = ACTIONS(3703),
    [anon_sym_XMLPORT] = ACTIONS(3703),
    [anon_sym_Xmlport] = ACTIONS(3703),
    [anon_sym_XMLport] = ACTIONS(3703),
    [anon_sym_XMLPort] = ACTIONS(3703),
    [anon_sym_XmlPort] = ACTIONS(3703),
    [anon_sym_enum] = ACTIONS(3703),
    [anon_sym_ENUM] = ACTIONS(3703),
    [anon_sym_Enum] = ACTIONS(3703),
    [anon_sym_eNUM] = ACTIONS(3703),
    [anon_sym_eNum] = ACTIONS(3703),
    [anon_sym_ENum] = ACTIONS(3703),
    [sym_temporary_keyword] = ACTIONS(3703),
    [sym_quoted_identifier] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3705),
    [sym_verbatim_string] = ACTIONS(3705),
    [sym_integer] = ACTIONS(3703),
    [sym_continue_as_identifier] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
  },
  [STATE(3508)] = {
    [sym_boolean] = STATE(8795),
    [sym_preproc_conditional_table_relation] = STATE(6870),
    [sym_table_relation_expression] = STATE(6778),
    [sym_if_table_relation] = STATE(6870),
    [sym_simple_table_relation] = STATE(6870),
    [sym__namespaced_or_simple_ref] = STATE(6492),
    [sym_preproc_if] = STATE(2125),
    [sym_assignment_expression] = STATE(8795),
    [sym__expression] = STATE(8795),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8795),
    [sym_multiplicative_expression] = STATE(8795),
    [sym_additive_expression] = STATE(8795),
    [sym_comparison_expression] = STATE(8795),
    [sym_logical_expression] = STATE(8795),
    [sym_ternary_expression] = STATE(8795),
    [sym_unary_expression] = STATE(8795),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(3414),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8795),
    [sym_list_literal] = STATE(8795),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8795),
    [sym__literal_value] = STATE(8795),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(5991),
    [sym_keyword_as_identifier] = STATE(5991),
    [sym_identifier] = ACTIONS(7586),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7588),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7590),
    [aux_sym_if_table_relation_token1] = ACTIONS(4017),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7592),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7590),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7590),
    [aux_sym_separator_action_token1] = ACTIONS(7590),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7590),
    [aux_sym_type_declaration_token1] = ACTIONS(7590),
    [anon_sym_POUNDif] = ACTIONS(4889),
    [anon_sym_POUNDIF] = ACTIONS(4889),
    [anon_sym_POUNDIf] = ACTIONS(4889),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7594),
    [sym_date_literal] = ACTIONS(7588),
    [sym_time_literal] = ACTIONS(7588),
    [sym_biginteger_literal] = ACTIONS(7594),
    [sym_table_keyword] = ACTIONS(7590),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7590),
    [sym_dataset_keyword] = ACTIONS(7590),
    [sym_quoted_identifier] = ACTIONS(7596),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7594),
    [sym_verbatim_string] = ACTIONS(7594),
    [sym_integer] = ACTIONS(7598),
    [sym_continue_as_identifier] = ACTIONS(7594),
    [sym_preproc_open] = ACTIONS(4889),
  },
  [STATE(3509)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_elif] = STATE(3579),
    [sym_preproc_else] = STATE(3827),
    [sym_preproc_endif] = STATE(3883),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3478),
    [aux_sym_preproc_split_case_branch_repeat2] = STATE(10919),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7501),
    [anon_sym_POUNDELIF] = ACTIONS(7501),
    [anon_sym_POUNDElif] = ACTIONS(7501),
    [anon_sym_POUNDelse] = ACTIONS(7503),
    [anon_sym_POUNDELSE] = ACTIONS(7503),
    [anon_sym_POUNDElse] = ACTIONS(7503),
    [anon_sym_POUNDelse2] = ACTIONS(7503),
    [anon_sym_POUNDELSE2] = ACTIONS(7503),
    [anon_sym_POUNDElse2] = ACTIONS(7503),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3510)] = {
    [aux_sym_option_member_list_repeat1] = STATE(3499),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(7489),
    [anon_sym_COLON] = ACTIONS(3689),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3691),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
  },
  [STATE(3511)] = {
    [aux_sym_option_member_list_repeat1] = STATE(3472),
    [sym_identifier] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_DOT] = ACTIONS(3689),
    [anon_sym_EQ] = ACTIONS(3691),
    [anon_sym_COMMA] = ACTIONS(7489),
    [anon_sym_COLON] = ACTIONS(3689),
    [anon_sym_DASH] = ACTIONS(3689),
    [aux_sym_boolean_token1] = ACTIONS(3689),
    [aux_sym_boolean_token2] = ACTIONS(3689),
    [sym_decimal] = ACTIONS(3689),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [aux_sym_record_type_token1] = ACTIONS(3689),
    [aux_sym_basic_type_token21] = ACTIONS(3689),
    [aux_sym_basic_type_token22] = ACTIONS(3689),
    [aux_sym_basic_type_token48] = ACTIONS(3689),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3689),
    [anon_sym_POUNDif] = ACTIONS(3691),
    [anon_sym_POUNDIF] = ACTIONS(3691),
    [anon_sym_POUNDIf] = ACTIONS(3691),
    [anon_sym_not] = ACTIONS(3689),
    [anon_sym_NOT] = ACTIONS(3689),
    [anon_sym_Not] = ACTIONS(3689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3691),
    [aux_sym__expression_token1] = ACTIONS(3691),
    [aux_sym__expression_token2] = ACTIONS(3691),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3689),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3689),
    [anon_sym_SLASH] = ACTIONS(3689),
    [anon_sym_div] = ACTIONS(3689),
    [anon_sym_DIV] = ACTIONS(3689),
    [anon_sym_Div] = ACTIONS(3689),
    [anon_sym_mod] = ACTIONS(3689),
    [anon_sym_MOD] = ACTIONS(3689),
    [anon_sym_Mod] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_GT_EQ] = ACTIONS(3691),
    [anon_sym_LT_EQ] = ACTIONS(3691),
    [anon_sym_GT] = ACTIONS(3689),
    [anon_sym_LT] = ACTIONS(3689),
    [anon_sym_LT_GT] = ACTIONS(3691),
    [anon_sym_and] = ACTIONS(3689),
    [anon_sym_AND] = ACTIONS(3689),
    [anon_sym_And] = ACTIONS(3689),
    [anon_sym_or] = ACTIONS(3689),
    [anon_sym_OR] = ACTIONS(3689),
    [anon_sym_Or] = ACTIONS(3689),
    [anon_sym_xor] = ACTIONS(3689),
    [anon_sym_XOR] = ACTIONS(3689),
    [anon_sym_Xor] = ACTIONS(3689),
    [anon_sym_QMARK] = ACTIONS(3691),
    [sym_datetime_literal] = ACTIONS(3691),
    [sym_date_literal] = ACTIONS(3689),
    [sym_time_literal] = ACTIONS(3689),
    [sym_biginteger_literal] = ACTIONS(3691),
    [anon_sym_else] = ACTIONS(3689),
    [anon_sym_ELSE] = ACTIONS(3689),
    [anon_sym_Else] = ACTIONS(3689),
    [anon_sym_in] = ACTIONS(3689),
    [anon_sym_IN] = ACTIONS(3689),
    [anon_sym_In] = ACTIONS(3689),
    [sym_page_keyword] = ACTIONS(3689),
    [anon_sym_codeunit] = ACTIONS(3689),
    [anon_sym_CODEUNIT] = ACTIONS(3689),
    [anon_sym_Codeunit] = ACTIONS(3689),
    [anon_sym_CodeUnit] = ACTIONS(3689),
    [anon_sym_COdeunit] = ACTIONS(3689),
    [anon_sym_codeUnit] = ACTIONS(3689),
    [sym_report_keyword] = ACTIONS(3689),
    [sym_query_keyword] = ACTIONS(3689),
    [anon_sym_xmlport] = ACTIONS(3689),
    [anon_sym_XMLPORT] = ACTIONS(3689),
    [anon_sym_Xmlport] = ACTIONS(3689),
    [anon_sym_XMLport] = ACTIONS(3689),
    [anon_sym_XMLPort] = ACTIONS(3689),
    [anon_sym_XmlPort] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_ENUM] = ACTIONS(3689),
    [anon_sym_Enum] = ACTIONS(3689),
    [anon_sym_eNUM] = ACTIONS(3689),
    [anon_sym_eNum] = ACTIONS(3689),
    [anon_sym_ENum] = ACTIONS(3689),
    [sym_quoted_identifier] = ACTIONS(3691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3691),
    [sym_verbatim_string] = ACTIONS(3691),
    [sym_integer] = ACTIONS(3689),
    [sym_continue_as_identifier] = ACTIONS(3691),
    [sym_preproc_open] = ACTIONS(3691),
  },
  [STATE(3512)] = {
    [sym_identifier] = ACTIONS(3659),
    [anon_sym_SEMI] = ACTIONS(3661),
    [anon_sym_DOT] = ACTIONS(3659),
    [anon_sym_EQ] = ACTIONS(3661),
    [anon_sym_COMMA] = ACTIONS(3661),
    [anon_sym_COLON] = ACTIONS(3659),
    [anon_sym_DASH] = ACTIONS(3659),
    [aux_sym_boolean_token1] = ACTIONS(3659),
    [aux_sym_boolean_token2] = ACTIONS(3659),
    [sym_decimal] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3661),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3661),
    [aux_sym_record_type_token1] = ACTIONS(3659),
    [aux_sym_basic_type_token21] = ACTIONS(3659),
    [aux_sym_basic_type_token22] = ACTIONS(3659),
    [aux_sym_basic_type_token48] = ACTIONS(3659),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3659),
    [anon_sym_COLON_COLON] = ACTIONS(3661),
    [anon_sym_POUNDif] = ACTIONS(3661),
    [anon_sym_POUNDIF] = ACTIONS(3661),
    [anon_sym_POUNDIf] = ACTIONS(3661),
    [anon_sym_not] = ACTIONS(3659),
    [anon_sym_NOT] = ACTIONS(3659),
    [anon_sym_Not] = ACTIONS(3659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3661),
    [aux_sym__expression_token1] = ACTIONS(3661),
    [aux_sym__expression_token2] = ACTIONS(3661),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3659),
    [anon_sym_SLASH] = ACTIONS(3659),
    [anon_sym_div] = ACTIONS(3659),
    [anon_sym_DIV] = ACTIONS(3659),
    [anon_sym_Div] = ACTIONS(3659),
    [anon_sym_mod] = ACTIONS(3659),
    [anon_sym_MOD] = ACTIONS(3659),
    [anon_sym_Mod] = ACTIONS(3659),
    [anon_sym_PLUS] = ACTIONS(3659),
    [anon_sym_GT_EQ] = ACTIONS(3661),
    [anon_sym_LT_EQ] = ACTIONS(3661),
    [anon_sym_GT] = ACTIONS(3659),
    [anon_sym_LT] = ACTIONS(3659),
    [anon_sym_LT_GT] = ACTIONS(3661),
    [anon_sym_and] = ACTIONS(3659),
    [anon_sym_AND] = ACTIONS(3659),
    [anon_sym_And] = ACTIONS(3659),
    [anon_sym_or] = ACTIONS(3659),
    [anon_sym_OR] = ACTIONS(3659),
    [anon_sym_Or] = ACTIONS(3659),
    [anon_sym_xor] = ACTIONS(3659),
    [anon_sym_XOR] = ACTIONS(3659),
    [anon_sym_Xor] = ACTIONS(3659),
    [anon_sym_QMARK] = ACTIONS(3661),
    [sym_datetime_literal] = ACTIONS(3661),
    [sym_date_literal] = ACTIONS(3659),
    [sym_time_literal] = ACTIONS(3659),
    [sym_biginteger_literal] = ACTIONS(3661),
    [anon_sym_else] = ACTIONS(3659),
    [anon_sym_ELSE] = ACTIONS(3659),
    [anon_sym_Else] = ACTIONS(3659),
    [anon_sym_in] = ACTIONS(3659),
    [anon_sym_IN] = ACTIONS(3659),
    [anon_sym_In] = ACTIONS(3659),
    [sym_page_keyword] = ACTIONS(3659),
    [anon_sym_codeunit] = ACTIONS(3659),
    [anon_sym_CODEUNIT] = ACTIONS(3659),
    [anon_sym_Codeunit] = ACTIONS(3659),
    [anon_sym_CodeUnit] = ACTIONS(3659),
    [anon_sym_COdeunit] = ACTIONS(3659),
    [anon_sym_codeUnit] = ACTIONS(3659),
    [sym_report_keyword] = ACTIONS(3659),
    [sym_query_keyword] = ACTIONS(3659),
    [anon_sym_xmlport] = ACTIONS(3659),
    [anon_sym_XMLPORT] = ACTIONS(3659),
    [anon_sym_Xmlport] = ACTIONS(3659),
    [anon_sym_XMLport] = ACTIONS(3659),
    [anon_sym_XMLPort] = ACTIONS(3659),
    [anon_sym_XmlPort] = ACTIONS(3659),
    [anon_sym_enum] = ACTIONS(3659),
    [anon_sym_ENUM] = ACTIONS(3659),
    [anon_sym_Enum] = ACTIONS(3659),
    [anon_sym_eNUM] = ACTIONS(3659),
    [anon_sym_eNum] = ACTIONS(3659),
    [anon_sym_ENum] = ACTIONS(3659),
    [sym_quoted_identifier] = ACTIONS(3661),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3661),
    [sym_verbatim_string] = ACTIONS(3661),
    [sym_integer] = ACTIONS(3659),
    [sym_continue_as_identifier] = ACTIONS(3661),
    [sym_preproc_open] = ACTIONS(3661),
  },
  [STATE(3513)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_COLON] = ACTIONS(3865),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
  },
  [STATE(3514)] = {
    [sym_identifier] = ACTIONS(3925),
    [anon_sym_SEMI] = ACTIONS(3927),
    [anon_sym_DOT] = ACTIONS(3925),
    [anon_sym_EQ] = ACTIONS(3927),
    [anon_sym_COMMA] = ACTIONS(3927),
    [anon_sym_COLON] = ACTIONS(3925),
    [anon_sym_DASH] = ACTIONS(3925),
    [aux_sym_boolean_token1] = ACTIONS(3925),
    [aux_sym_boolean_token2] = ACTIONS(3925),
    [sym_decimal] = ACTIONS(3925),
    [anon_sym_LPAREN] = ACTIONS(3927),
    [anon_sym_DOT_DOT] = ACTIONS(3927),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3925),
    [anon_sym_STAR] = ACTIONS(3925),
    [anon_sym_LBRACK] = ACTIONS(7600),
    [aux_sym_record_type_token1] = ACTIONS(3925),
    [aux_sym_basic_type_token21] = ACTIONS(3925),
    [aux_sym_basic_type_token22] = ACTIONS(3925),
    [aux_sym_basic_type_token48] = ACTIONS(3925),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3925),
    [anon_sym_POUNDif] = ACTIONS(3927),
    [anon_sym_POUNDIF] = ACTIONS(3927),
    [anon_sym_POUNDIf] = ACTIONS(3927),
    [anon_sym_not] = ACTIONS(3925),
    [anon_sym_NOT] = ACTIONS(3925),
    [anon_sym_Not] = ACTIONS(3925),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3927),
    [aux_sym__expression_token1] = ACTIONS(3927),
    [aux_sym__expression_token2] = ACTIONS(3927),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3925),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3925),
    [anon_sym_SLASH] = ACTIONS(3925),
    [anon_sym_div] = ACTIONS(3925),
    [anon_sym_DIV] = ACTIONS(3925),
    [anon_sym_Div] = ACTIONS(3925),
    [anon_sym_mod] = ACTIONS(3925),
    [anon_sym_MOD] = ACTIONS(3925),
    [anon_sym_Mod] = ACTIONS(3925),
    [anon_sym_PLUS] = ACTIONS(3925),
    [anon_sym_GT_EQ] = ACTIONS(3927),
    [anon_sym_LT_EQ] = ACTIONS(3927),
    [anon_sym_GT] = ACTIONS(3925),
    [anon_sym_LT] = ACTIONS(3925),
    [anon_sym_LT_GT] = ACTIONS(3927),
    [anon_sym_and] = ACTIONS(3925),
    [anon_sym_AND] = ACTIONS(3925),
    [anon_sym_And] = ACTIONS(3925),
    [anon_sym_or] = ACTIONS(3925),
    [anon_sym_OR] = ACTIONS(3925),
    [anon_sym_Or] = ACTIONS(3925),
    [anon_sym_xor] = ACTIONS(3925),
    [anon_sym_XOR] = ACTIONS(3925),
    [anon_sym_Xor] = ACTIONS(3925),
    [anon_sym_QMARK] = ACTIONS(3927),
    [sym_datetime_literal] = ACTIONS(3927),
    [sym_date_literal] = ACTIONS(3925),
    [sym_time_literal] = ACTIONS(3925),
    [sym_biginteger_literal] = ACTIONS(3927),
    [anon_sym_else] = ACTIONS(3925),
    [anon_sym_ELSE] = ACTIONS(3925),
    [anon_sym_Else] = ACTIONS(3925),
    [anon_sym_in] = ACTIONS(3925),
    [anon_sym_IN] = ACTIONS(3925),
    [anon_sym_In] = ACTIONS(3925),
    [sym_page_keyword] = ACTIONS(3925),
    [anon_sym_codeunit] = ACTIONS(3925),
    [anon_sym_CODEUNIT] = ACTIONS(3925),
    [anon_sym_Codeunit] = ACTIONS(3925),
    [anon_sym_CodeUnit] = ACTIONS(3925),
    [anon_sym_COdeunit] = ACTIONS(3925),
    [anon_sym_codeUnit] = ACTIONS(3925),
    [sym_report_keyword] = ACTIONS(3925),
    [sym_query_keyword] = ACTIONS(3925),
    [anon_sym_xmlport] = ACTIONS(3925),
    [anon_sym_XMLPORT] = ACTIONS(3925),
    [anon_sym_Xmlport] = ACTIONS(3925),
    [anon_sym_XMLport] = ACTIONS(3925),
    [anon_sym_XMLPort] = ACTIONS(3925),
    [anon_sym_XmlPort] = ACTIONS(3925),
    [anon_sym_enum] = ACTIONS(3925),
    [anon_sym_ENUM] = ACTIONS(3925),
    [anon_sym_Enum] = ACTIONS(3925),
    [anon_sym_eNUM] = ACTIONS(3925),
    [anon_sym_eNum] = ACTIONS(3925),
    [anon_sym_ENum] = ACTIONS(3925),
    [sym_quoted_identifier] = ACTIONS(3927),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3927),
    [sym_verbatim_string] = ACTIONS(3927),
    [sym_integer] = ACTIONS(3925),
    [sym_continue_as_identifier] = ACTIONS(3927),
    [sym_preproc_open] = ACTIONS(3927),
  },
  [STATE(3515)] = {
    [sym_identifier] = ACTIONS(3931),
    [anon_sym_SEMI] = ACTIONS(3933),
    [anon_sym_DOT] = ACTIONS(3931),
    [anon_sym_EQ] = ACTIONS(3933),
    [anon_sym_COMMA] = ACTIONS(3933),
    [anon_sym_COLON] = ACTIONS(3931),
    [anon_sym_DASH] = ACTIONS(3931),
    [aux_sym_boolean_token1] = ACTIONS(3931),
    [aux_sym_boolean_token2] = ACTIONS(3931),
    [sym_decimal] = ACTIONS(3931),
    [anon_sym_LPAREN] = ACTIONS(3933),
    [anon_sym_DOT_DOT] = ACTIONS(3933),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3931),
    [anon_sym_STAR] = ACTIONS(3931),
    [anon_sym_LBRACK] = ACTIONS(7602),
    [aux_sym_record_type_token1] = ACTIONS(3931),
    [aux_sym_basic_type_token21] = ACTIONS(3931),
    [aux_sym_basic_type_token22] = ACTIONS(3931),
    [aux_sym_basic_type_token48] = ACTIONS(3931),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3931),
    [anon_sym_POUNDif] = ACTIONS(3933),
    [anon_sym_POUNDIF] = ACTIONS(3933),
    [anon_sym_POUNDIf] = ACTIONS(3933),
    [anon_sym_not] = ACTIONS(3931),
    [anon_sym_NOT] = ACTIONS(3931),
    [anon_sym_Not] = ACTIONS(3931),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3933),
    [aux_sym__expression_token1] = ACTIONS(3933),
    [aux_sym__expression_token2] = ACTIONS(3933),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3931),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3931),
    [anon_sym_SLASH] = ACTIONS(3931),
    [anon_sym_div] = ACTIONS(3931),
    [anon_sym_DIV] = ACTIONS(3931),
    [anon_sym_Div] = ACTIONS(3931),
    [anon_sym_mod] = ACTIONS(3931),
    [anon_sym_MOD] = ACTIONS(3931),
    [anon_sym_Mod] = ACTIONS(3931),
    [anon_sym_PLUS] = ACTIONS(3931),
    [anon_sym_GT_EQ] = ACTIONS(3933),
    [anon_sym_LT_EQ] = ACTIONS(3933),
    [anon_sym_GT] = ACTIONS(3931),
    [anon_sym_LT] = ACTIONS(3931),
    [anon_sym_LT_GT] = ACTIONS(3933),
    [anon_sym_and] = ACTIONS(3931),
    [anon_sym_AND] = ACTIONS(3931),
    [anon_sym_And] = ACTIONS(3931),
    [anon_sym_or] = ACTIONS(3931),
    [anon_sym_OR] = ACTIONS(3931),
    [anon_sym_Or] = ACTIONS(3931),
    [anon_sym_xor] = ACTIONS(3931),
    [anon_sym_XOR] = ACTIONS(3931),
    [anon_sym_Xor] = ACTIONS(3931),
    [anon_sym_QMARK] = ACTIONS(3933),
    [sym_datetime_literal] = ACTIONS(3933),
    [sym_date_literal] = ACTIONS(3931),
    [sym_time_literal] = ACTIONS(3931),
    [sym_biginteger_literal] = ACTIONS(3933),
    [anon_sym_else] = ACTIONS(3931),
    [anon_sym_ELSE] = ACTIONS(3931),
    [anon_sym_Else] = ACTIONS(3931),
    [anon_sym_in] = ACTIONS(3931),
    [anon_sym_IN] = ACTIONS(3931),
    [anon_sym_In] = ACTIONS(3931),
    [sym_page_keyword] = ACTIONS(3931),
    [anon_sym_codeunit] = ACTIONS(3931),
    [anon_sym_CODEUNIT] = ACTIONS(3931),
    [anon_sym_Codeunit] = ACTIONS(3931),
    [anon_sym_CodeUnit] = ACTIONS(3931),
    [anon_sym_COdeunit] = ACTIONS(3931),
    [anon_sym_codeUnit] = ACTIONS(3931),
    [sym_report_keyword] = ACTIONS(3931),
    [sym_query_keyword] = ACTIONS(3931),
    [anon_sym_xmlport] = ACTIONS(3931),
    [anon_sym_XMLPORT] = ACTIONS(3931),
    [anon_sym_Xmlport] = ACTIONS(3931),
    [anon_sym_XMLport] = ACTIONS(3931),
    [anon_sym_XMLPort] = ACTIONS(3931),
    [anon_sym_XmlPort] = ACTIONS(3931),
    [anon_sym_enum] = ACTIONS(3931),
    [anon_sym_ENUM] = ACTIONS(3931),
    [anon_sym_Enum] = ACTIONS(3931),
    [anon_sym_eNUM] = ACTIONS(3931),
    [anon_sym_eNum] = ACTIONS(3931),
    [anon_sym_ENum] = ACTIONS(3931),
    [sym_quoted_identifier] = ACTIONS(3933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3933),
    [sym_verbatim_string] = ACTIONS(3933),
    [sym_integer] = ACTIONS(3931),
    [sym_continue_as_identifier] = ACTIONS(3933),
    [sym_preproc_open] = ACTIONS(3933),
  },
  [STATE(3516)] = {
    [sym_identifier] = ACTIONS(3945),
    [anon_sym_SEMI] = ACTIONS(3947),
    [anon_sym_DOT] = ACTIONS(3945),
    [anon_sym_EQ] = ACTIONS(3947),
    [anon_sym_COMMA] = ACTIONS(3947),
    [anon_sym_COLON] = ACTIONS(3945),
    [anon_sym_DASH] = ACTIONS(3945),
    [aux_sym_boolean_token1] = ACTIONS(3945),
    [aux_sym_boolean_token2] = ACTIONS(3945),
    [sym_decimal] = ACTIONS(3945),
    [anon_sym_LPAREN] = ACTIONS(3947),
    [anon_sym_DOT_DOT] = ACTIONS(3947),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3945),
    [anon_sym_STAR] = ACTIONS(3945),
    [anon_sym_LBRACK] = ACTIONS(3947),
    [aux_sym_record_type_token1] = ACTIONS(3945),
    [aux_sym_basic_type_token21] = ACTIONS(3945),
    [aux_sym_basic_type_token22] = ACTIONS(3945),
    [aux_sym_basic_type_token48] = ACTIONS(3945),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3945),
    [anon_sym_POUNDif] = ACTIONS(3947),
    [anon_sym_POUNDIF] = ACTIONS(3947),
    [anon_sym_POUNDIf] = ACTIONS(3947),
    [anon_sym_not] = ACTIONS(3945),
    [anon_sym_NOT] = ACTIONS(3945),
    [anon_sym_Not] = ACTIONS(3945),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3947),
    [aux_sym__expression_token1] = ACTIONS(3947),
    [aux_sym__expression_token2] = ACTIONS(3947),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3945),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3945),
    [anon_sym_SLASH] = ACTIONS(3945),
    [anon_sym_div] = ACTIONS(3945),
    [anon_sym_DIV] = ACTIONS(3945),
    [anon_sym_Div] = ACTIONS(3945),
    [anon_sym_mod] = ACTIONS(3945),
    [anon_sym_MOD] = ACTIONS(3945),
    [anon_sym_Mod] = ACTIONS(3945),
    [anon_sym_PLUS] = ACTIONS(3945),
    [anon_sym_GT_EQ] = ACTIONS(3947),
    [anon_sym_LT_EQ] = ACTIONS(3947),
    [anon_sym_GT] = ACTIONS(3945),
    [anon_sym_LT] = ACTIONS(3945),
    [anon_sym_LT_GT] = ACTIONS(3947),
    [anon_sym_and] = ACTIONS(3945),
    [anon_sym_AND] = ACTIONS(3945),
    [anon_sym_And] = ACTIONS(3945),
    [anon_sym_or] = ACTIONS(3945),
    [anon_sym_OR] = ACTIONS(3945),
    [anon_sym_Or] = ACTIONS(3945),
    [anon_sym_xor] = ACTIONS(3945),
    [anon_sym_XOR] = ACTIONS(3945),
    [anon_sym_Xor] = ACTIONS(3945),
    [anon_sym_QMARK] = ACTIONS(3947),
    [sym_datetime_literal] = ACTIONS(3947),
    [sym_date_literal] = ACTIONS(3945),
    [sym_time_literal] = ACTIONS(3945),
    [sym_biginteger_literal] = ACTIONS(3947),
    [anon_sym_else] = ACTIONS(3945),
    [anon_sym_ELSE] = ACTIONS(3945),
    [anon_sym_Else] = ACTIONS(3945),
    [anon_sym_in] = ACTIONS(3945),
    [anon_sym_IN] = ACTIONS(3945),
    [anon_sym_In] = ACTIONS(3945),
    [sym_page_keyword] = ACTIONS(3945),
    [anon_sym_codeunit] = ACTIONS(3945),
    [anon_sym_CODEUNIT] = ACTIONS(3945),
    [anon_sym_Codeunit] = ACTIONS(3945),
    [anon_sym_CodeUnit] = ACTIONS(3945),
    [anon_sym_COdeunit] = ACTIONS(3945),
    [anon_sym_codeUnit] = ACTIONS(3945),
    [sym_report_keyword] = ACTIONS(3945),
    [sym_query_keyword] = ACTIONS(3945),
    [anon_sym_xmlport] = ACTIONS(3945),
    [anon_sym_XMLPORT] = ACTIONS(3945),
    [anon_sym_Xmlport] = ACTIONS(3945),
    [anon_sym_XMLport] = ACTIONS(3945),
    [anon_sym_XMLPort] = ACTIONS(3945),
    [anon_sym_XmlPort] = ACTIONS(3945),
    [anon_sym_enum] = ACTIONS(3945),
    [anon_sym_ENUM] = ACTIONS(3945),
    [anon_sym_Enum] = ACTIONS(3945),
    [anon_sym_eNUM] = ACTIONS(3945),
    [anon_sym_eNum] = ACTIONS(3945),
    [anon_sym_ENum] = ACTIONS(3945),
    [sym_quoted_identifier] = ACTIONS(3947),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3947),
    [sym_verbatim_string] = ACTIONS(3947),
    [sym_integer] = ACTIONS(3945),
    [sym_continue_as_identifier] = ACTIONS(3947),
    [sym_preproc_open] = ACTIONS(3947),
  },
  [STATE(3517)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_COLON] = ACTIONS(3865),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
  },
  [STATE(3518)] = {
    [sym_identifier] = ACTIONS(3865),
    [anon_sym_SEMI] = ACTIONS(3867),
    [anon_sym_DOT] = ACTIONS(3865),
    [anon_sym_EQ] = ACTIONS(3867),
    [anon_sym_COMMA] = ACTIONS(3867),
    [anon_sym_COLON] = ACTIONS(3865),
    [anon_sym_DASH] = ACTIONS(3865),
    [aux_sym_boolean_token1] = ACTIONS(3865),
    [aux_sym_boolean_token2] = ACTIONS(3865),
    [sym_decimal] = ACTIONS(3865),
    [anon_sym_LPAREN] = ACTIONS(3867),
    [anon_sym_DOT_DOT] = ACTIONS(3867),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3865),
    [anon_sym_STAR] = ACTIONS(3865),
    [anon_sym_LBRACK] = ACTIONS(3867),
    [aux_sym_record_type_token1] = ACTIONS(3865),
    [aux_sym_basic_type_token21] = ACTIONS(3865),
    [aux_sym_basic_type_token22] = ACTIONS(3865),
    [aux_sym_basic_type_token48] = ACTIONS(3865),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3865),
    [anon_sym_POUNDif] = ACTIONS(3867),
    [anon_sym_POUNDIF] = ACTIONS(3867),
    [anon_sym_POUNDIf] = ACTIONS(3867),
    [anon_sym_not] = ACTIONS(3865),
    [anon_sym_NOT] = ACTIONS(3865),
    [anon_sym_Not] = ACTIONS(3865),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3867),
    [aux_sym__expression_token1] = ACTIONS(3867),
    [aux_sym__expression_token2] = ACTIONS(3867),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3865),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3865),
    [anon_sym_SLASH] = ACTIONS(3865),
    [anon_sym_div] = ACTIONS(3865),
    [anon_sym_DIV] = ACTIONS(3865),
    [anon_sym_Div] = ACTIONS(3865),
    [anon_sym_mod] = ACTIONS(3865),
    [anon_sym_MOD] = ACTIONS(3865),
    [anon_sym_Mod] = ACTIONS(3865),
    [anon_sym_PLUS] = ACTIONS(3865),
    [anon_sym_GT_EQ] = ACTIONS(3867),
    [anon_sym_LT_EQ] = ACTIONS(3867),
    [anon_sym_GT] = ACTIONS(3865),
    [anon_sym_LT] = ACTIONS(3865),
    [anon_sym_LT_GT] = ACTIONS(3867),
    [anon_sym_and] = ACTIONS(3865),
    [anon_sym_AND] = ACTIONS(3865),
    [anon_sym_And] = ACTIONS(3865),
    [anon_sym_or] = ACTIONS(3865),
    [anon_sym_OR] = ACTIONS(3865),
    [anon_sym_Or] = ACTIONS(3865),
    [anon_sym_xor] = ACTIONS(3865),
    [anon_sym_XOR] = ACTIONS(3865),
    [anon_sym_Xor] = ACTIONS(3865),
    [anon_sym_QMARK] = ACTIONS(3867),
    [sym_datetime_literal] = ACTIONS(3867),
    [sym_date_literal] = ACTIONS(3865),
    [sym_time_literal] = ACTIONS(3865),
    [sym_biginteger_literal] = ACTIONS(3867),
    [anon_sym_else] = ACTIONS(3865),
    [anon_sym_ELSE] = ACTIONS(3865),
    [anon_sym_Else] = ACTIONS(3865),
    [anon_sym_in] = ACTIONS(3865),
    [anon_sym_IN] = ACTIONS(3865),
    [anon_sym_In] = ACTIONS(3865),
    [sym_page_keyword] = ACTIONS(3865),
    [anon_sym_codeunit] = ACTIONS(3865),
    [anon_sym_CODEUNIT] = ACTIONS(3865),
    [anon_sym_Codeunit] = ACTIONS(3865),
    [anon_sym_CodeUnit] = ACTIONS(3865),
    [anon_sym_COdeunit] = ACTIONS(3865),
    [anon_sym_codeUnit] = ACTIONS(3865),
    [sym_report_keyword] = ACTIONS(3865),
    [sym_query_keyword] = ACTIONS(3865),
    [anon_sym_xmlport] = ACTIONS(3865),
    [anon_sym_XMLPORT] = ACTIONS(3865),
    [anon_sym_Xmlport] = ACTIONS(3865),
    [anon_sym_XMLport] = ACTIONS(3865),
    [anon_sym_XMLPort] = ACTIONS(3865),
    [anon_sym_XmlPort] = ACTIONS(3865),
    [anon_sym_enum] = ACTIONS(3865),
    [anon_sym_ENUM] = ACTIONS(3865),
    [anon_sym_Enum] = ACTIONS(3865),
    [anon_sym_eNUM] = ACTIONS(3865),
    [anon_sym_eNum] = ACTIONS(3865),
    [anon_sym_ENum] = ACTIONS(3865),
    [sym_quoted_identifier] = ACTIONS(3867),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3867),
    [sym_verbatim_string] = ACTIONS(3867),
    [sym_integer] = ACTIONS(3865),
    [sym_continue_as_identifier] = ACTIONS(3867),
    [sym_preproc_open] = ACTIONS(3867),
  },
  [STATE(3519)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_COLON] = ACTIONS(3869),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
  },
  [STATE(3520)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_COLON] = ACTIONS(3869),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
  },
  [STATE(3521)] = {
    [sym_identifier] = ACTIONS(3869),
    [anon_sym_SEMI] = ACTIONS(3871),
    [anon_sym_DOT] = ACTIONS(3869),
    [anon_sym_EQ] = ACTIONS(3871),
    [anon_sym_COMMA] = ACTIONS(3871),
    [anon_sym_COLON] = ACTIONS(3869),
    [anon_sym_DASH] = ACTIONS(3869),
    [aux_sym_boolean_token1] = ACTIONS(3869),
    [aux_sym_boolean_token2] = ACTIONS(3869),
    [sym_decimal] = ACTIONS(3869),
    [anon_sym_LPAREN] = ACTIONS(3871),
    [anon_sym_DOT_DOT] = ACTIONS(3871),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3869),
    [anon_sym_STAR] = ACTIONS(3869),
    [anon_sym_LBRACK] = ACTIONS(3871),
    [aux_sym_record_type_token1] = ACTIONS(3869),
    [aux_sym_basic_type_token21] = ACTIONS(3869),
    [aux_sym_basic_type_token22] = ACTIONS(3869),
    [aux_sym_basic_type_token48] = ACTIONS(3869),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3869),
    [anon_sym_POUNDif] = ACTIONS(3871),
    [anon_sym_POUNDIF] = ACTIONS(3871),
    [anon_sym_POUNDIf] = ACTIONS(3871),
    [anon_sym_not] = ACTIONS(3869),
    [anon_sym_NOT] = ACTIONS(3869),
    [anon_sym_Not] = ACTIONS(3869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3871),
    [aux_sym__expression_token1] = ACTIONS(3871),
    [aux_sym__expression_token2] = ACTIONS(3871),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3869),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3869),
    [anon_sym_SLASH] = ACTIONS(3869),
    [anon_sym_div] = ACTIONS(3869),
    [anon_sym_DIV] = ACTIONS(3869),
    [anon_sym_Div] = ACTIONS(3869),
    [anon_sym_mod] = ACTIONS(3869),
    [anon_sym_MOD] = ACTIONS(3869),
    [anon_sym_Mod] = ACTIONS(3869),
    [anon_sym_PLUS] = ACTIONS(3869),
    [anon_sym_GT_EQ] = ACTIONS(3871),
    [anon_sym_LT_EQ] = ACTIONS(3871),
    [anon_sym_GT] = ACTIONS(3869),
    [anon_sym_LT] = ACTIONS(3869),
    [anon_sym_LT_GT] = ACTIONS(3871),
    [anon_sym_and] = ACTIONS(3869),
    [anon_sym_AND] = ACTIONS(3869),
    [anon_sym_And] = ACTIONS(3869),
    [anon_sym_or] = ACTIONS(3869),
    [anon_sym_OR] = ACTIONS(3869),
    [anon_sym_Or] = ACTIONS(3869),
    [anon_sym_xor] = ACTIONS(3869),
    [anon_sym_XOR] = ACTIONS(3869),
    [anon_sym_Xor] = ACTIONS(3869),
    [anon_sym_QMARK] = ACTIONS(3871),
    [sym_datetime_literal] = ACTIONS(3871),
    [sym_date_literal] = ACTIONS(3869),
    [sym_time_literal] = ACTIONS(3869),
    [sym_biginteger_literal] = ACTIONS(3871),
    [anon_sym_else] = ACTIONS(3869),
    [anon_sym_ELSE] = ACTIONS(3869),
    [anon_sym_Else] = ACTIONS(3869),
    [anon_sym_in] = ACTIONS(3869),
    [anon_sym_IN] = ACTIONS(3869),
    [anon_sym_In] = ACTIONS(3869),
    [sym_page_keyword] = ACTIONS(3869),
    [anon_sym_codeunit] = ACTIONS(3869),
    [anon_sym_CODEUNIT] = ACTIONS(3869),
    [anon_sym_Codeunit] = ACTIONS(3869),
    [anon_sym_CodeUnit] = ACTIONS(3869),
    [anon_sym_COdeunit] = ACTIONS(3869),
    [anon_sym_codeUnit] = ACTIONS(3869),
    [sym_report_keyword] = ACTIONS(3869),
    [sym_query_keyword] = ACTIONS(3869),
    [anon_sym_xmlport] = ACTIONS(3869),
    [anon_sym_XMLPORT] = ACTIONS(3869),
    [anon_sym_Xmlport] = ACTIONS(3869),
    [anon_sym_XMLport] = ACTIONS(3869),
    [anon_sym_XMLPort] = ACTIONS(3869),
    [anon_sym_XmlPort] = ACTIONS(3869),
    [anon_sym_enum] = ACTIONS(3869),
    [anon_sym_ENUM] = ACTIONS(3869),
    [anon_sym_Enum] = ACTIONS(3869),
    [anon_sym_eNUM] = ACTIONS(3869),
    [anon_sym_eNum] = ACTIONS(3869),
    [anon_sym_ENum] = ACTIONS(3869),
    [sym_quoted_identifier] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3871),
    [sym_verbatim_string] = ACTIONS(3871),
    [sym_integer] = ACTIONS(3869),
    [sym_continue_as_identifier] = ACTIONS(3871),
    [sym_preproc_open] = ACTIONS(3871),
  },
  [STATE(3522)] = {
    [sym_identifier] = ACTIONS(3632),
    [anon_sym_SEMI] = ACTIONS(3634),
    [anon_sym_DOT] = ACTIONS(3632),
    [anon_sym_EQ] = ACTIONS(3634),
    [anon_sym_COMMA] = ACTIONS(3634),
    [anon_sym_COLON] = ACTIONS(3632),
    [anon_sym_DASH] = ACTIONS(3632),
    [aux_sym_boolean_token1] = ACTIONS(3632),
    [aux_sym_boolean_token2] = ACTIONS(3632),
    [sym_decimal] = ACTIONS(3632),
    [anon_sym_LPAREN] = ACTIONS(3634),
    [anon_sym_DOT_DOT] = ACTIONS(3634),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3632),
    [anon_sym_STAR] = ACTIONS(3632),
    [anon_sym_LBRACK] = ACTIONS(3634),
    [aux_sym_record_type_token1] = ACTIONS(3632),
    [aux_sym_basic_type_token21] = ACTIONS(3632),
    [aux_sym_basic_type_token22] = ACTIONS(3632),
    [aux_sym_basic_type_token48] = ACTIONS(3632),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3632),
    [anon_sym_POUNDif] = ACTIONS(3634),
    [anon_sym_POUNDIF] = ACTIONS(3634),
    [anon_sym_POUNDIf] = ACTIONS(3634),
    [anon_sym_not] = ACTIONS(3632),
    [anon_sym_NOT] = ACTIONS(3632),
    [anon_sym_Not] = ACTIONS(3632),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3634),
    [aux_sym__expression_token1] = ACTIONS(3634),
    [aux_sym__expression_token2] = ACTIONS(3634),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3632),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3632),
    [anon_sym_SLASH] = ACTIONS(3632),
    [anon_sym_div] = ACTIONS(3632),
    [anon_sym_DIV] = ACTIONS(3632),
    [anon_sym_Div] = ACTIONS(3632),
    [anon_sym_mod] = ACTIONS(3632),
    [anon_sym_MOD] = ACTIONS(3632),
    [anon_sym_Mod] = ACTIONS(3632),
    [anon_sym_PLUS] = ACTIONS(3632),
    [anon_sym_GT_EQ] = ACTIONS(3634),
    [anon_sym_LT_EQ] = ACTIONS(3634),
    [anon_sym_GT] = ACTIONS(3632),
    [anon_sym_LT] = ACTIONS(3632),
    [anon_sym_LT_GT] = ACTIONS(3634),
    [anon_sym_and] = ACTIONS(3632),
    [anon_sym_AND] = ACTIONS(3632),
    [anon_sym_And] = ACTIONS(3632),
    [anon_sym_or] = ACTIONS(3632),
    [anon_sym_OR] = ACTIONS(3632),
    [anon_sym_Or] = ACTIONS(3632),
    [anon_sym_xor] = ACTIONS(3632),
    [anon_sym_XOR] = ACTIONS(3632),
    [anon_sym_Xor] = ACTIONS(3632),
    [anon_sym_QMARK] = ACTIONS(3634),
    [sym_datetime_literal] = ACTIONS(3634),
    [sym_date_literal] = ACTIONS(3632),
    [sym_time_literal] = ACTIONS(3632),
    [sym_biginteger_literal] = ACTIONS(3634),
    [anon_sym_else] = ACTIONS(3632),
    [anon_sym_ELSE] = ACTIONS(3632),
    [anon_sym_Else] = ACTIONS(3632),
    [anon_sym_in] = ACTIONS(3632),
    [anon_sym_IN] = ACTIONS(3632),
    [anon_sym_In] = ACTIONS(3632),
    [sym_page_keyword] = ACTIONS(3632),
    [anon_sym_codeunit] = ACTIONS(3632),
    [anon_sym_CODEUNIT] = ACTIONS(3632),
    [anon_sym_Codeunit] = ACTIONS(3632),
    [anon_sym_CodeUnit] = ACTIONS(3632),
    [anon_sym_COdeunit] = ACTIONS(3632),
    [anon_sym_codeUnit] = ACTIONS(3632),
    [sym_report_keyword] = ACTIONS(3632),
    [sym_query_keyword] = ACTIONS(3632),
    [anon_sym_xmlport] = ACTIONS(3632),
    [anon_sym_XMLPORT] = ACTIONS(3632),
    [anon_sym_Xmlport] = ACTIONS(3632),
    [anon_sym_XMLport] = ACTIONS(3632),
    [anon_sym_XMLPort] = ACTIONS(3632),
    [anon_sym_XmlPort] = ACTIONS(3632),
    [anon_sym_enum] = ACTIONS(3632),
    [anon_sym_ENUM] = ACTIONS(3632),
    [anon_sym_Enum] = ACTIONS(3632),
    [anon_sym_eNUM] = ACTIONS(3632),
    [anon_sym_eNum] = ACTIONS(3632),
    [anon_sym_ENum] = ACTIONS(3632),
    [sym_quoted_identifier] = ACTIONS(3634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3634),
    [sym_verbatim_string] = ACTIONS(3634),
    [sym_integer] = ACTIONS(3632),
    [sym_continue_as_identifier] = ACTIONS(3634),
    [sym_preproc_open] = ACTIONS(3634),
  },
  [STATE(3523)] = {
    [sym_identifier] = ACTIONS(3742),
    [anon_sym_SEMI] = ACTIONS(3744),
    [anon_sym_DOT] = ACTIONS(3742),
    [anon_sym_EQ] = ACTIONS(3744),
    [anon_sym_COMMA] = ACTIONS(3744),
    [anon_sym_COLON] = ACTIONS(3742),
    [anon_sym_DASH] = ACTIONS(3742),
    [aux_sym_boolean_token1] = ACTIONS(3742),
    [aux_sym_boolean_token2] = ACTIONS(3742),
    [sym_decimal] = ACTIONS(3742),
    [anon_sym_LPAREN] = ACTIONS(3744),
    [anon_sym_DOT_DOT] = ACTIONS(3744),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3742),
    [anon_sym_STAR] = ACTIONS(3742),
    [anon_sym_LBRACK] = ACTIONS(3744),
    [aux_sym_record_type_token1] = ACTIONS(3742),
    [aux_sym_basic_type_token21] = ACTIONS(3742),
    [aux_sym_basic_type_token22] = ACTIONS(3742),
    [aux_sym_basic_type_token48] = ACTIONS(3742),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3742),
    [anon_sym_POUNDif] = ACTIONS(3744),
    [anon_sym_POUNDIF] = ACTIONS(3744),
    [anon_sym_POUNDIf] = ACTIONS(3744),
    [anon_sym_not] = ACTIONS(3742),
    [anon_sym_NOT] = ACTIONS(3742),
    [anon_sym_Not] = ACTIONS(3742),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3744),
    [aux_sym__expression_token1] = ACTIONS(3744),
    [aux_sym__expression_token2] = ACTIONS(3744),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3742),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3742),
    [anon_sym_SLASH] = ACTIONS(3742),
    [anon_sym_div] = ACTIONS(3742),
    [anon_sym_DIV] = ACTIONS(3742),
    [anon_sym_Div] = ACTIONS(3742),
    [anon_sym_mod] = ACTIONS(3742),
    [anon_sym_MOD] = ACTIONS(3742),
    [anon_sym_Mod] = ACTIONS(3742),
    [anon_sym_PLUS] = ACTIONS(3742),
    [anon_sym_GT_EQ] = ACTIONS(3744),
    [anon_sym_LT_EQ] = ACTIONS(3744),
    [anon_sym_GT] = ACTIONS(3742),
    [anon_sym_LT] = ACTIONS(3742),
    [anon_sym_LT_GT] = ACTIONS(3744),
    [anon_sym_and] = ACTIONS(3742),
    [anon_sym_AND] = ACTIONS(3742),
    [anon_sym_And] = ACTIONS(3742),
    [anon_sym_or] = ACTIONS(3742),
    [anon_sym_OR] = ACTIONS(3742),
    [anon_sym_Or] = ACTIONS(3742),
    [anon_sym_xor] = ACTIONS(3742),
    [anon_sym_XOR] = ACTIONS(3742),
    [anon_sym_Xor] = ACTIONS(3742),
    [anon_sym_QMARK] = ACTIONS(3744),
    [sym_datetime_literal] = ACTIONS(3744),
    [sym_date_literal] = ACTIONS(3742),
    [sym_time_literal] = ACTIONS(3742),
    [sym_biginteger_literal] = ACTIONS(3744),
    [anon_sym_else] = ACTIONS(3742),
    [anon_sym_ELSE] = ACTIONS(3742),
    [anon_sym_Else] = ACTIONS(3742),
    [anon_sym_in] = ACTIONS(3742),
    [anon_sym_IN] = ACTIONS(3742),
    [anon_sym_In] = ACTIONS(3742),
    [sym_page_keyword] = ACTIONS(3742),
    [anon_sym_codeunit] = ACTIONS(3742),
    [anon_sym_CODEUNIT] = ACTIONS(3742),
    [anon_sym_Codeunit] = ACTIONS(3742),
    [anon_sym_CodeUnit] = ACTIONS(3742),
    [anon_sym_COdeunit] = ACTIONS(3742),
    [anon_sym_codeUnit] = ACTIONS(3742),
    [sym_report_keyword] = ACTIONS(3742),
    [sym_query_keyword] = ACTIONS(3742),
    [anon_sym_xmlport] = ACTIONS(3742),
    [anon_sym_XMLPORT] = ACTIONS(3742),
    [anon_sym_Xmlport] = ACTIONS(3742),
    [anon_sym_XMLport] = ACTIONS(3742),
    [anon_sym_XMLPort] = ACTIONS(3742),
    [anon_sym_XmlPort] = ACTIONS(3742),
    [anon_sym_enum] = ACTIONS(3742),
    [anon_sym_ENUM] = ACTIONS(3742),
    [anon_sym_Enum] = ACTIONS(3742),
    [anon_sym_eNUM] = ACTIONS(3742),
    [anon_sym_eNum] = ACTIONS(3742),
    [anon_sym_ENum] = ACTIONS(3742),
    [sym_quoted_identifier] = ACTIONS(3744),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3744),
    [sym_verbatim_string] = ACTIONS(3744),
    [sym_integer] = ACTIONS(3742),
    [sym_continue_as_identifier] = ACTIONS(3744),
    [sym_preproc_open] = ACTIONS(3744),
  },
  [STATE(3524)] = {
    [sym_identifier] = ACTIONS(3921),
    [anon_sym_SEMI] = ACTIONS(3923),
    [anon_sym_DOT] = ACTIONS(3921),
    [anon_sym_EQ] = ACTIONS(3923),
    [anon_sym_COMMA] = ACTIONS(3923),
    [anon_sym_COLON] = ACTIONS(3921),
    [anon_sym_DASH] = ACTIONS(3921),
    [aux_sym_boolean_token1] = ACTIONS(3921),
    [aux_sym_boolean_token2] = ACTIONS(3921),
    [sym_decimal] = ACTIONS(3921),
    [anon_sym_LPAREN] = ACTIONS(3923),
    [anon_sym_DOT_DOT] = ACTIONS(3923),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3921),
    [anon_sym_STAR] = ACTIONS(3921),
    [anon_sym_LBRACK] = ACTIONS(3923),
    [aux_sym_record_type_token1] = ACTIONS(3921),
    [aux_sym_basic_type_token21] = ACTIONS(3921),
    [aux_sym_basic_type_token22] = ACTIONS(3921),
    [aux_sym_basic_type_token48] = ACTIONS(3921),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3921),
    [anon_sym_POUNDif] = ACTIONS(3923),
    [anon_sym_POUNDIF] = ACTIONS(3923),
    [anon_sym_POUNDIf] = ACTIONS(3923),
    [anon_sym_not] = ACTIONS(3921),
    [anon_sym_NOT] = ACTIONS(3921),
    [anon_sym_Not] = ACTIONS(3921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3923),
    [aux_sym__expression_token1] = ACTIONS(3923),
    [aux_sym__expression_token2] = ACTIONS(3923),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3921),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3921),
    [anon_sym_SLASH] = ACTIONS(3921),
    [anon_sym_div] = ACTIONS(3921),
    [anon_sym_DIV] = ACTIONS(3921),
    [anon_sym_Div] = ACTIONS(3921),
    [anon_sym_mod] = ACTIONS(3921),
    [anon_sym_MOD] = ACTIONS(3921),
    [anon_sym_Mod] = ACTIONS(3921),
    [anon_sym_PLUS] = ACTIONS(3921),
    [anon_sym_GT_EQ] = ACTIONS(3923),
    [anon_sym_LT_EQ] = ACTIONS(3923),
    [anon_sym_GT] = ACTIONS(3921),
    [anon_sym_LT] = ACTIONS(3921),
    [anon_sym_LT_GT] = ACTIONS(3923),
    [anon_sym_and] = ACTIONS(3921),
    [anon_sym_AND] = ACTIONS(3921),
    [anon_sym_And] = ACTIONS(3921),
    [anon_sym_or] = ACTIONS(3921),
    [anon_sym_OR] = ACTIONS(3921),
    [anon_sym_Or] = ACTIONS(3921),
    [anon_sym_xor] = ACTIONS(3921),
    [anon_sym_XOR] = ACTIONS(3921),
    [anon_sym_Xor] = ACTIONS(3921),
    [anon_sym_QMARK] = ACTIONS(3923),
    [sym_datetime_literal] = ACTIONS(3923),
    [sym_date_literal] = ACTIONS(3921),
    [sym_time_literal] = ACTIONS(3921),
    [sym_biginteger_literal] = ACTIONS(3923),
    [anon_sym_else] = ACTIONS(3921),
    [anon_sym_ELSE] = ACTIONS(3921),
    [anon_sym_Else] = ACTIONS(3921),
    [anon_sym_in] = ACTIONS(3921),
    [anon_sym_IN] = ACTIONS(3921),
    [anon_sym_In] = ACTIONS(3921),
    [sym_page_keyword] = ACTIONS(3921),
    [anon_sym_codeunit] = ACTIONS(3921),
    [anon_sym_CODEUNIT] = ACTIONS(3921),
    [anon_sym_Codeunit] = ACTIONS(3921),
    [anon_sym_CodeUnit] = ACTIONS(3921),
    [anon_sym_COdeunit] = ACTIONS(3921),
    [anon_sym_codeUnit] = ACTIONS(3921),
    [sym_report_keyword] = ACTIONS(3921),
    [sym_query_keyword] = ACTIONS(3921),
    [anon_sym_xmlport] = ACTIONS(3921),
    [anon_sym_XMLPORT] = ACTIONS(3921),
    [anon_sym_Xmlport] = ACTIONS(3921),
    [anon_sym_XMLport] = ACTIONS(3921),
    [anon_sym_XMLPort] = ACTIONS(3921),
    [anon_sym_XmlPort] = ACTIONS(3921),
    [anon_sym_enum] = ACTIONS(3921),
    [anon_sym_ENUM] = ACTIONS(3921),
    [anon_sym_Enum] = ACTIONS(3921),
    [anon_sym_eNUM] = ACTIONS(3921),
    [anon_sym_eNum] = ACTIONS(3921),
    [anon_sym_ENum] = ACTIONS(3921),
    [sym_quoted_identifier] = ACTIONS(3923),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3923),
    [sym_verbatim_string] = ACTIONS(3923),
    [sym_integer] = ACTIONS(3921),
    [sym_continue_as_identifier] = ACTIONS(3923),
    [sym_preproc_open] = ACTIONS(3923),
  },
  [STATE(3525)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3716),
    [anon_sym_SEMI] = ACTIONS(3718),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(3716),
    [aux_sym_boolean_token1] = ACTIONS(3716),
    [aux_sym_boolean_token2] = ACTIONS(3716),
    [sym_decimal] = ACTIONS(3716),
    [anon_sym_LPAREN] = ACTIONS(3718),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3716),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(3718),
    [aux_sym_record_type_token1] = ACTIONS(3716),
    [aux_sym_basic_type_token21] = ACTIONS(3716),
    [aux_sym_basic_type_token22] = ACTIONS(3716),
    [aux_sym_basic_type_token48] = ACTIONS(3716),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3716),
    [anon_sym_POUNDif] = ACTIONS(3718),
    [anon_sym_POUNDIF] = ACTIONS(3718),
    [anon_sym_POUNDIf] = ACTIONS(3718),
    [anon_sym_not] = ACTIONS(3716),
    [anon_sym_NOT] = ACTIONS(3716),
    [anon_sym_Not] = ACTIONS(3716),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(7469),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3716),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3716),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(3716),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(7471),
    [anon_sym_OR] = ACTIONS(7473),
    [anon_sym_Or] = ACTIONS(7475),
    [anon_sym_xor] = ACTIONS(7477),
    [anon_sym_XOR] = ACTIONS(7479),
    [anon_sym_Xor] = ACTIONS(7481),
    [anon_sym_QMARK] = ACTIONS(7483),
    [sym_datetime_literal] = ACTIONS(3718),
    [sym_date_literal] = ACTIONS(3716),
    [sym_time_literal] = ACTIONS(3716),
    [sym_biginteger_literal] = ACTIONS(3718),
    [anon_sym_else] = ACTIONS(3716),
    [anon_sym_ELSE] = ACTIONS(3716),
    [anon_sym_Else] = ACTIONS(3716),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3716),
    [anon_sym_codeunit] = ACTIONS(3716),
    [anon_sym_CODEUNIT] = ACTIONS(3716),
    [anon_sym_Codeunit] = ACTIONS(3716),
    [anon_sym_CodeUnit] = ACTIONS(3716),
    [anon_sym_COdeunit] = ACTIONS(3716),
    [anon_sym_codeUnit] = ACTIONS(3716),
    [sym_report_keyword] = ACTIONS(3716),
    [sym_query_keyword] = ACTIONS(3716),
    [anon_sym_xmlport] = ACTIONS(3716),
    [anon_sym_XMLPORT] = ACTIONS(3716),
    [anon_sym_Xmlport] = ACTIONS(3716),
    [anon_sym_XMLport] = ACTIONS(3716),
    [anon_sym_XMLPort] = ACTIONS(3716),
    [anon_sym_XmlPort] = ACTIONS(3716),
    [anon_sym_enum] = ACTIONS(3716),
    [anon_sym_ENUM] = ACTIONS(3716),
    [anon_sym_Enum] = ACTIONS(3716),
    [anon_sym_eNUM] = ACTIONS(3716),
    [anon_sym_eNum] = ACTIONS(3716),
    [anon_sym_ENum] = ACTIONS(3716),
    [sym_quoted_identifier] = ACTIONS(3718),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3718),
    [sym_verbatim_string] = ACTIONS(3718),
    [sym_integer] = ACTIONS(3716),
    [sym_continue_as_identifier] = ACTIONS(3718),
    [sym_preproc_open] = ACTIONS(3718),
  },
  [STATE(3526)] = {
    [sym_identifier] = ACTIONS(3881),
    [anon_sym_SEMI] = ACTIONS(3883),
    [anon_sym_DOT] = ACTIONS(3881),
    [anon_sym_EQ] = ACTIONS(3883),
    [anon_sym_COMMA] = ACTIONS(3883),
    [anon_sym_COLON] = ACTIONS(3881),
    [anon_sym_DASH] = ACTIONS(3881),
    [aux_sym_boolean_token1] = ACTIONS(3881),
    [aux_sym_boolean_token2] = ACTIONS(3881),
    [sym_decimal] = ACTIONS(3881),
    [anon_sym_LPAREN] = ACTIONS(3883),
    [anon_sym_DOT_DOT] = ACTIONS(3883),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3881),
    [anon_sym_STAR] = ACTIONS(3881),
    [anon_sym_LBRACK] = ACTIONS(3883),
    [aux_sym_record_type_token1] = ACTIONS(3881),
    [aux_sym_basic_type_token21] = ACTIONS(3881),
    [aux_sym_basic_type_token22] = ACTIONS(3881),
    [aux_sym_basic_type_token48] = ACTIONS(3881),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3881),
    [anon_sym_POUNDif] = ACTIONS(3883),
    [anon_sym_POUNDIF] = ACTIONS(3883),
    [anon_sym_POUNDIf] = ACTIONS(3883),
    [anon_sym_not] = ACTIONS(3881),
    [anon_sym_NOT] = ACTIONS(3881),
    [anon_sym_Not] = ACTIONS(3881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3883),
    [aux_sym__expression_token1] = ACTIONS(3883),
    [aux_sym__expression_token2] = ACTIONS(3883),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3881),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3881),
    [anon_sym_SLASH] = ACTIONS(3881),
    [anon_sym_div] = ACTIONS(3881),
    [anon_sym_DIV] = ACTIONS(3881),
    [anon_sym_Div] = ACTIONS(3881),
    [anon_sym_mod] = ACTIONS(3881),
    [anon_sym_MOD] = ACTIONS(3881),
    [anon_sym_Mod] = ACTIONS(3881),
    [anon_sym_PLUS] = ACTIONS(3881),
    [anon_sym_GT_EQ] = ACTIONS(3883),
    [anon_sym_LT_EQ] = ACTIONS(3883),
    [anon_sym_GT] = ACTIONS(3881),
    [anon_sym_LT] = ACTIONS(3881),
    [anon_sym_LT_GT] = ACTIONS(3883),
    [anon_sym_and] = ACTIONS(3881),
    [anon_sym_AND] = ACTIONS(3881),
    [anon_sym_And] = ACTIONS(3881),
    [anon_sym_or] = ACTIONS(3881),
    [anon_sym_OR] = ACTIONS(3881),
    [anon_sym_Or] = ACTIONS(3881),
    [anon_sym_xor] = ACTIONS(3881),
    [anon_sym_XOR] = ACTIONS(3881),
    [anon_sym_Xor] = ACTIONS(3881),
    [anon_sym_QMARK] = ACTIONS(3883),
    [sym_datetime_literal] = ACTIONS(3883),
    [sym_date_literal] = ACTIONS(3881),
    [sym_time_literal] = ACTIONS(3881),
    [sym_biginteger_literal] = ACTIONS(3883),
    [anon_sym_else] = ACTIONS(3881),
    [anon_sym_ELSE] = ACTIONS(3881),
    [anon_sym_Else] = ACTIONS(3881),
    [anon_sym_in] = ACTIONS(3881),
    [anon_sym_IN] = ACTIONS(3881),
    [anon_sym_In] = ACTIONS(3881),
    [sym_page_keyword] = ACTIONS(3881),
    [anon_sym_codeunit] = ACTIONS(3881),
    [anon_sym_CODEUNIT] = ACTIONS(3881),
    [anon_sym_Codeunit] = ACTIONS(3881),
    [anon_sym_CodeUnit] = ACTIONS(3881),
    [anon_sym_COdeunit] = ACTIONS(3881),
    [anon_sym_codeUnit] = ACTIONS(3881),
    [sym_report_keyword] = ACTIONS(3881),
    [sym_query_keyword] = ACTIONS(3881),
    [anon_sym_xmlport] = ACTIONS(3881),
    [anon_sym_XMLPORT] = ACTIONS(3881),
    [anon_sym_Xmlport] = ACTIONS(3881),
    [anon_sym_XMLport] = ACTIONS(3881),
    [anon_sym_XMLPort] = ACTIONS(3881),
    [anon_sym_XmlPort] = ACTIONS(3881),
    [anon_sym_enum] = ACTIONS(3881),
    [anon_sym_ENUM] = ACTIONS(3881),
    [anon_sym_Enum] = ACTIONS(3881),
    [anon_sym_eNUM] = ACTIONS(3881),
    [anon_sym_eNum] = ACTIONS(3881),
    [anon_sym_ENum] = ACTIONS(3881),
    [sym_quoted_identifier] = ACTIONS(3883),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3883),
    [sym_verbatim_string] = ACTIONS(3883),
    [sym_integer] = ACTIONS(3881),
    [sym_continue_as_identifier] = ACTIONS(3883),
    [sym_preproc_open] = ACTIONS(3883),
  },
  [STATE(3527)] = {
    [sym_identifier] = ACTIONS(3889),
    [anon_sym_SEMI] = ACTIONS(3891),
    [anon_sym_DOT] = ACTIONS(3889),
    [anon_sym_EQ] = ACTIONS(3891),
    [anon_sym_COMMA] = ACTIONS(3891),
    [anon_sym_COLON] = ACTIONS(3889),
    [anon_sym_DASH] = ACTIONS(3889),
    [aux_sym_boolean_token1] = ACTIONS(3889),
    [aux_sym_boolean_token2] = ACTIONS(3889),
    [sym_decimal] = ACTIONS(3889),
    [anon_sym_LPAREN] = ACTIONS(3891),
    [anon_sym_DOT_DOT] = ACTIONS(3891),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3889),
    [anon_sym_STAR] = ACTIONS(3889),
    [anon_sym_LBRACK] = ACTIONS(3891),
    [aux_sym_record_type_token1] = ACTIONS(3889),
    [aux_sym_basic_type_token21] = ACTIONS(3889),
    [aux_sym_basic_type_token22] = ACTIONS(3889),
    [aux_sym_basic_type_token48] = ACTIONS(3889),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3889),
    [anon_sym_POUNDif] = ACTIONS(3891),
    [anon_sym_POUNDIF] = ACTIONS(3891),
    [anon_sym_POUNDIf] = ACTIONS(3891),
    [anon_sym_not] = ACTIONS(3889),
    [anon_sym_NOT] = ACTIONS(3889),
    [anon_sym_Not] = ACTIONS(3889),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3891),
    [aux_sym__expression_token1] = ACTIONS(3891),
    [aux_sym__expression_token2] = ACTIONS(3891),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3889),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3889),
    [anon_sym_SLASH] = ACTIONS(3889),
    [anon_sym_div] = ACTIONS(3889),
    [anon_sym_DIV] = ACTIONS(3889),
    [anon_sym_Div] = ACTIONS(3889),
    [anon_sym_mod] = ACTIONS(3889),
    [anon_sym_MOD] = ACTIONS(3889),
    [anon_sym_Mod] = ACTIONS(3889),
    [anon_sym_PLUS] = ACTIONS(3889),
    [anon_sym_GT_EQ] = ACTIONS(3891),
    [anon_sym_LT_EQ] = ACTIONS(3891),
    [anon_sym_GT] = ACTIONS(3889),
    [anon_sym_LT] = ACTIONS(3889),
    [anon_sym_LT_GT] = ACTIONS(3891),
    [anon_sym_and] = ACTIONS(3889),
    [anon_sym_AND] = ACTIONS(3889),
    [anon_sym_And] = ACTIONS(3889),
    [anon_sym_or] = ACTIONS(3889),
    [anon_sym_OR] = ACTIONS(3889),
    [anon_sym_Or] = ACTIONS(3889),
    [anon_sym_xor] = ACTIONS(3889),
    [anon_sym_XOR] = ACTIONS(3889),
    [anon_sym_Xor] = ACTIONS(3889),
    [anon_sym_QMARK] = ACTIONS(3891),
    [sym_datetime_literal] = ACTIONS(3891),
    [sym_date_literal] = ACTIONS(3889),
    [sym_time_literal] = ACTIONS(3889),
    [sym_biginteger_literal] = ACTIONS(3891),
    [anon_sym_else] = ACTIONS(3889),
    [anon_sym_ELSE] = ACTIONS(3889),
    [anon_sym_Else] = ACTIONS(3889),
    [anon_sym_in] = ACTIONS(3889),
    [anon_sym_IN] = ACTIONS(3889),
    [anon_sym_In] = ACTIONS(3889),
    [sym_page_keyword] = ACTIONS(3889),
    [anon_sym_codeunit] = ACTIONS(3889),
    [anon_sym_CODEUNIT] = ACTIONS(3889),
    [anon_sym_Codeunit] = ACTIONS(3889),
    [anon_sym_CodeUnit] = ACTIONS(3889),
    [anon_sym_COdeunit] = ACTIONS(3889),
    [anon_sym_codeUnit] = ACTIONS(3889),
    [sym_report_keyword] = ACTIONS(3889),
    [sym_query_keyword] = ACTIONS(3889),
    [anon_sym_xmlport] = ACTIONS(3889),
    [anon_sym_XMLPORT] = ACTIONS(3889),
    [anon_sym_Xmlport] = ACTIONS(3889),
    [anon_sym_XMLport] = ACTIONS(3889),
    [anon_sym_XMLPort] = ACTIONS(3889),
    [anon_sym_XmlPort] = ACTIONS(3889),
    [anon_sym_enum] = ACTIONS(3889),
    [anon_sym_ENUM] = ACTIONS(3889),
    [anon_sym_Enum] = ACTIONS(3889),
    [anon_sym_eNUM] = ACTIONS(3889),
    [anon_sym_eNum] = ACTIONS(3889),
    [anon_sym_ENum] = ACTIONS(3889),
    [sym_quoted_identifier] = ACTIONS(3891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3891),
    [sym_verbatim_string] = ACTIONS(3891),
    [sym_integer] = ACTIONS(3889),
    [sym_continue_as_identifier] = ACTIONS(3891),
    [sym_preproc_open] = ACTIONS(3891),
  },
  [STATE(3528)] = {
    [sym_identifier] = ACTIONS(3893),
    [anon_sym_SEMI] = ACTIONS(3895),
    [anon_sym_DOT] = ACTIONS(3893),
    [anon_sym_EQ] = ACTIONS(3895),
    [anon_sym_COMMA] = ACTIONS(3895),
    [anon_sym_COLON] = ACTIONS(3893),
    [anon_sym_DASH] = ACTIONS(3893),
    [aux_sym_boolean_token1] = ACTIONS(3893),
    [aux_sym_boolean_token2] = ACTIONS(3893),
    [sym_decimal] = ACTIONS(3893),
    [anon_sym_LPAREN] = ACTIONS(3895),
    [anon_sym_DOT_DOT] = ACTIONS(3895),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3893),
    [anon_sym_STAR] = ACTIONS(3893),
    [anon_sym_LBRACK] = ACTIONS(3895),
    [aux_sym_record_type_token1] = ACTIONS(3893),
    [aux_sym_basic_type_token21] = ACTIONS(3893),
    [aux_sym_basic_type_token22] = ACTIONS(3893),
    [aux_sym_basic_type_token48] = ACTIONS(3893),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3893),
    [anon_sym_POUNDif] = ACTIONS(3895),
    [anon_sym_POUNDIF] = ACTIONS(3895),
    [anon_sym_POUNDIf] = ACTIONS(3895),
    [anon_sym_not] = ACTIONS(3893),
    [anon_sym_NOT] = ACTIONS(3893),
    [anon_sym_Not] = ACTIONS(3893),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3895),
    [aux_sym__expression_token1] = ACTIONS(3895),
    [aux_sym__expression_token2] = ACTIONS(3895),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3893),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3893),
    [anon_sym_SLASH] = ACTIONS(3893),
    [anon_sym_div] = ACTIONS(3893),
    [anon_sym_DIV] = ACTIONS(3893),
    [anon_sym_Div] = ACTIONS(3893),
    [anon_sym_mod] = ACTIONS(3893),
    [anon_sym_MOD] = ACTIONS(3893),
    [anon_sym_Mod] = ACTIONS(3893),
    [anon_sym_PLUS] = ACTIONS(3893),
    [anon_sym_GT_EQ] = ACTIONS(3895),
    [anon_sym_LT_EQ] = ACTIONS(3895),
    [anon_sym_GT] = ACTIONS(3893),
    [anon_sym_LT] = ACTIONS(3893),
    [anon_sym_LT_GT] = ACTIONS(3895),
    [anon_sym_and] = ACTIONS(3893),
    [anon_sym_AND] = ACTIONS(3893),
    [anon_sym_And] = ACTIONS(3893),
    [anon_sym_or] = ACTIONS(3893),
    [anon_sym_OR] = ACTIONS(3893),
    [anon_sym_Or] = ACTIONS(3893),
    [anon_sym_xor] = ACTIONS(3893),
    [anon_sym_XOR] = ACTIONS(3893),
    [anon_sym_Xor] = ACTIONS(3893),
    [anon_sym_QMARK] = ACTIONS(3895),
    [sym_datetime_literal] = ACTIONS(3895),
    [sym_date_literal] = ACTIONS(3893),
    [sym_time_literal] = ACTIONS(3893),
    [sym_biginteger_literal] = ACTIONS(3895),
    [anon_sym_else] = ACTIONS(3893),
    [anon_sym_ELSE] = ACTIONS(3893),
    [anon_sym_Else] = ACTIONS(3893),
    [anon_sym_in] = ACTIONS(3893),
    [anon_sym_IN] = ACTIONS(3893),
    [anon_sym_In] = ACTIONS(3893),
    [sym_page_keyword] = ACTIONS(3893),
    [anon_sym_codeunit] = ACTIONS(3893),
    [anon_sym_CODEUNIT] = ACTIONS(3893),
    [anon_sym_Codeunit] = ACTIONS(3893),
    [anon_sym_CodeUnit] = ACTIONS(3893),
    [anon_sym_COdeunit] = ACTIONS(3893),
    [anon_sym_codeUnit] = ACTIONS(3893),
    [sym_report_keyword] = ACTIONS(3893),
    [sym_query_keyword] = ACTIONS(3893),
    [anon_sym_xmlport] = ACTIONS(3893),
    [anon_sym_XMLPORT] = ACTIONS(3893),
    [anon_sym_Xmlport] = ACTIONS(3893),
    [anon_sym_XMLport] = ACTIONS(3893),
    [anon_sym_XMLPort] = ACTIONS(3893),
    [anon_sym_XmlPort] = ACTIONS(3893),
    [anon_sym_enum] = ACTIONS(3893),
    [anon_sym_ENUM] = ACTIONS(3893),
    [anon_sym_Enum] = ACTIONS(3893),
    [anon_sym_eNUM] = ACTIONS(3893),
    [anon_sym_eNum] = ACTIONS(3893),
    [anon_sym_ENum] = ACTIONS(3893),
    [sym_quoted_identifier] = ACTIONS(3895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3895),
    [sym_verbatim_string] = ACTIONS(3895),
    [sym_integer] = ACTIONS(3893),
    [sym_continue_as_identifier] = ACTIONS(3895),
    [sym_preproc_open] = ACTIONS(3895),
  },
  [STATE(3529)] = {
    [sym_identifier] = ACTIONS(3897),
    [anon_sym_SEMI] = ACTIONS(3899),
    [anon_sym_DOT] = ACTIONS(3897),
    [anon_sym_EQ] = ACTIONS(3899),
    [anon_sym_COMMA] = ACTIONS(3899),
    [anon_sym_COLON] = ACTIONS(3897),
    [anon_sym_DASH] = ACTIONS(3897),
    [aux_sym_boolean_token1] = ACTIONS(3897),
    [aux_sym_boolean_token2] = ACTIONS(3897),
    [sym_decimal] = ACTIONS(3897),
    [anon_sym_LPAREN] = ACTIONS(3899),
    [anon_sym_DOT_DOT] = ACTIONS(3899),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3897),
    [anon_sym_STAR] = ACTIONS(3897),
    [anon_sym_LBRACK] = ACTIONS(3899),
    [aux_sym_record_type_token1] = ACTIONS(3897),
    [aux_sym_basic_type_token21] = ACTIONS(3897),
    [aux_sym_basic_type_token22] = ACTIONS(3897),
    [aux_sym_basic_type_token48] = ACTIONS(3897),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3897),
    [anon_sym_POUNDif] = ACTIONS(3899),
    [anon_sym_POUNDIF] = ACTIONS(3899),
    [anon_sym_POUNDIf] = ACTIONS(3899),
    [anon_sym_not] = ACTIONS(3897),
    [anon_sym_NOT] = ACTIONS(3897),
    [anon_sym_Not] = ACTIONS(3897),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3899),
    [aux_sym__expression_token1] = ACTIONS(3899),
    [aux_sym__expression_token2] = ACTIONS(3899),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3897),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3897),
    [anon_sym_SLASH] = ACTIONS(3897),
    [anon_sym_div] = ACTIONS(3897),
    [anon_sym_DIV] = ACTIONS(3897),
    [anon_sym_Div] = ACTIONS(3897),
    [anon_sym_mod] = ACTIONS(3897),
    [anon_sym_MOD] = ACTIONS(3897),
    [anon_sym_Mod] = ACTIONS(3897),
    [anon_sym_PLUS] = ACTIONS(3897),
    [anon_sym_GT_EQ] = ACTIONS(3899),
    [anon_sym_LT_EQ] = ACTIONS(3899),
    [anon_sym_GT] = ACTIONS(3897),
    [anon_sym_LT] = ACTIONS(3897),
    [anon_sym_LT_GT] = ACTIONS(3899),
    [anon_sym_and] = ACTIONS(3897),
    [anon_sym_AND] = ACTIONS(3897),
    [anon_sym_And] = ACTIONS(3897),
    [anon_sym_or] = ACTIONS(3897),
    [anon_sym_OR] = ACTIONS(3897),
    [anon_sym_Or] = ACTIONS(3897),
    [anon_sym_xor] = ACTIONS(3897),
    [anon_sym_XOR] = ACTIONS(3897),
    [anon_sym_Xor] = ACTIONS(3897),
    [anon_sym_QMARK] = ACTIONS(3899),
    [sym_datetime_literal] = ACTIONS(3899),
    [sym_date_literal] = ACTIONS(3897),
    [sym_time_literal] = ACTIONS(3897),
    [sym_biginteger_literal] = ACTIONS(3899),
    [anon_sym_else] = ACTIONS(3897),
    [anon_sym_ELSE] = ACTIONS(3897),
    [anon_sym_Else] = ACTIONS(3897),
    [anon_sym_in] = ACTIONS(3897),
    [anon_sym_IN] = ACTIONS(3897),
    [anon_sym_In] = ACTIONS(3897),
    [sym_page_keyword] = ACTIONS(3897),
    [anon_sym_codeunit] = ACTIONS(3897),
    [anon_sym_CODEUNIT] = ACTIONS(3897),
    [anon_sym_Codeunit] = ACTIONS(3897),
    [anon_sym_CodeUnit] = ACTIONS(3897),
    [anon_sym_COdeunit] = ACTIONS(3897),
    [anon_sym_codeUnit] = ACTIONS(3897),
    [sym_report_keyword] = ACTIONS(3897),
    [sym_query_keyword] = ACTIONS(3897),
    [anon_sym_xmlport] = ACTIONS(3897),
    [anon_sym_XMLPORT] = ACTIONS(3897),
    [anon_sym_Xmlport] = ACTIONS(3897),
    [anon_sym_XMLport] = ACTIONS(3897),
    [anon_sym_XMLPort] = ACTIONS(3897),
    [anon_sym_XmlPort] = ACTIONS(3897),
    [anon_sym_enum] = ACTIONS(3897),
    [anon_sym_ENUM] = ACTIONS(3897),
    [anon_sym_Enum] = ACTIONS(3897),
    [anon_sym_eNUM] = ACTIONS(3897),
    [anon_sym_eNum] = ACTIONS(3897),
    [anon_sym_ENum] = ACTIONS(3897),
    [sym_quoted_identifier] = ACTIONS(3899),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3899),
    [sym_verbatim_string] = ACTIONS(3899),
    [sym_integer] = ACTIONS(3897),
    [sym_continue_as_identifier] = ACTIONS(3899),
    [sym_preproc_open] = ACTIONS(3899),
  },
  [STATE(3530)] = {
    [sym_identifier] = ACTIONS(3901),
    [anon_sym_SEMI] = ACTIONS(3903),
    [anon_sym_DOT] = ACTIONS(3901),
    [anon_sym_EQ] = ACTIONS(3903),
    [anon_sym_COMMA] = ACTIONS(3903),
    [anon_sym_COLON] = ACTIONS(3901),
    [anon_sym_DASH] = ACTIONS(3901),
    [aux_sym_boolean_token1] = ACTIONS(3901),
    [aux_sym_boolean_token2] = ACTIONS(3901),
    [sym_decimal] = ACTIONS(3901),
    [anon_sym_LPAREN] = ACTIONS(3903),
    [anon_sym_DOT_DOT] = ACTIONS(3903),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3901),
    [anon_sym_STAR] = ACTIONS(3901),
    [anon_sym_LBRACK] = ACTIONS(3903),
    [aux_sym_record_type_token1] = ACTIONS(3901),
    [aux_sym_basic_type_token21] = ACTIONS(3901),
    [aux_sym_basic_type_token22] = ACTIONS(3901),
    [aux_sym_basic_type_token48] = ACTIONS(3901),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3901),
    [anon_sym_POUNDif] = ACTIONS(3903),
    [anon_sym_POUNDIF] = ACTIONS(3903),
    [anon_sym_POUNDIf] = ACTIONS(3903),
    [anon_sym_not] = ACTIONS(3901),
    [anon_sym_NOT] = ACTIONS(3901),
    [anon_sym_Not] = ACTIONS(3901),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3903),
    [aux_sym__expression_token1] = ACTIONS(3903),
    [aux_sym__expression_token2] = ACTIONS(3903),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3901),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3901),
    [anon_sym_SLASH] = ACTIONS(3901),
    [anon_sym_div] = ACTIONS(3901),
    [anon_sym_DIV] = ACTIONS(3901),
    [anon_sym_Div] = ACTIONS(3901),
    [anon_sym_mod] = ACTIONS(3901),
    [anon_sym_MOD] = ACTIONS(3901),
    [anon_sym_Mod] = ACTIONS(3901),
    [anon_sym_PLUS] = ACTIONS(3901),
    [anon_sym_GT_EQ] = ACTIONS(3903),
    [anon_sym_LT_EQ] = ACTIONS(3903),
    [anon_sym_GT] = ACTIONS(3901),
    [anon_sym_LT] = ACTIONS(3901),
    [anon_sym_LT_GT] = ACTIONS(3903),
    [anon_sym_and] = ACTIONS(3901),
    [anon_sym_AND] = ACTIONS(3901),
    [anon_sym_And] = ACTIONS(3901),
    [anon_sym_or] = ACTIONS(3901),
    [anon_sym_OR] = ACTIONS(3901),
    [anon_sym_Or] = ACTIONS(3901),
    [anon_sym_xor] = ACTIONS(3901),
    [anon_sym_XOR] = ACTIONS(3901),
    [anon_sym_Xor] = ACTIONS(3901),
    [anon_sym_QMARK] = ACTIONS(3903),
    [sym_datetime_literal] = ACTIONS(3903),
    [sym_date_literal] = ACTIONS(3901),
    [sym_time_literal] = ACTIONS(3901),
    [sym_biginteger_literal] = ACTIONS(3903),
    [anon_sym_else] = ACTIONS(3901),
    [anon_sym_ELSE] = ACTIONS(3901),
    [anon_sym_Else] = ACTIONS(3901),
    [anon_sym_in] = ACTIONS(3901),
    [anon_sym_IN] = ACTIONS(3901),
    [anon_sym_In] = ACTIONS(3901),
    [sym_page_keyword] = ACTIONS(3901),
    [anon_sym_codeunit] = ACTIONS(3901),
    [anon_sym_CODEUNIT] = ACTIONS(3901),
    [anon_sym_Codeunit] = ACTIONS(3901),
    [anon_sym_CodeUnit] = ACTIONS(3901),
    [anon_sym_COdeunit] = ACTIONS(3901),
    [anon_sym_codeUnit] = ACTIONS(3901),
    [sym_report_keyword] = ACTIONS(3901),
    [sym_query_keyword] = ACTIONS(3901),
    [anon_sym_xmlport] = ACTIONS(3901),
    [anon_sym_XMLPORT] = ACTIONS(3901),
    [anon_sym_Xmlport] = ACTIONS(3901),
    [anon_sym_XMLport] = ACTIONS(3901),
    [anon_sym_XMLPort] = ACTIONS(3901),
    [anon_sym_XmlPort] = ACTIONS(3901),
    [anon_sym_enum] = ACTIONS(3901),
    [anon_sym_ENUM] = ACTIONS(3901),
    [anon_sym_Enum] = ACTIONS(3901),
    [anon_sym_eNUM] = ACTIONS(3901),
    [anon_sym_eNum] = ACTIONS(3901),
    [anon_sym_ENum] = ACTIONS(3901),
    [sym_quoted_identifier] = ACTIONS(3903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3903),
    [sym_verbatim_string] = ACTIONS(3903),
    [sym_integer] = ACTIONS(3901),
    [sym_continue_as_identifier] = ACTIONS(3903),
    [sym_preproc_open] = ACTIONS(3903),
  },
  [STATE(3531)] = {
    [sym_identifier] = ACTIONS(3905),
    [anon_sym_SEMI] = ACTIONS(3907),
    [anon_sym_DOT] = ACTIONS(3905),
    [anon_sym_EQ] = ACTIONS(3907),
    [anon_sym_COMMA] = ACTIONS(3907),
    [anon_sym_COLON] = ACTIONS(3905),
    [anon_sym_DASH] = ACTIONS(3905),
    [aux_sym_boolean_token1] = ACTIONS(3905),
    [aux_sym_boolean_token2] = ACTIONS(3905),
    [sym_decimal] = ACTIONS(3905),
    [anon_sym_LPAREN] = ACTIONS(3907),
    [anon_sym_DOT_DOT] = ACTIONS(3907),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3905),
    [anon_sym_STAR] = ACTIONS(3905),
    [anon_sym_LBRACK] = ACTIONS(3907),
    [aux_sym_record_type_token1] = ACTIONS(3905),
    [aux_sym_basic_type_token21] = ACTIONS(3905),
    [aux_sym_basic_type_token22] = ACTIONS(3905),
    [aux_sym_basic_type_token48] = ACTIONS(3905),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3905),
    [anon_sym_POUNDif] = ACTIONS(3907),
    [anon_sym_POUNDIF] = ACTIONS(3907),
    [anon_sym_POUNDIf] = ACTIONS(3907),
    [anon_sym_not] = ACTIONS(3905),
    [anon_sym_NOT] = ACTIONS(3905),
    [anon_sym_Not] = ACTIONS(3905),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3907),
    [aux_sym__expression_token1] = ACTIONS(3907),
    [aux_sym__expression_token2] = ACTIONS(3907),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3905),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3905),
    [anon_sym_SLASH] = ACTIONS(3905),
    [anon_sym_div] = ACTIONS(3905),
    [anon_sym_DIV] = ACTIONS(3905),
    [anon_sym_Div] = ACTIONS(3905),
    [anon_sym_mod] = ACTIONS(3905),
    [anon_sym_MOD] = ACTIONS(3905),
    [anon_sym_Mod] = ACTIONS(3905),
    [anon_sym_PLUS] = ACTIONS(3905),
    [anon_sym_GT_EQ] = ACTIONS(3907),
    [anon_sym_LT_EQ] = ACTIONS(3907),
    [anon_sym_GT] = ACTIONS(3905),
    [anon_sym_LT] = ACTIONS(3905),
    [anon_sym_LT_GT] = ACTIONS(3907),
    [anon_sym_and] = ACTIONS(3905),
    [anon_sym_AND] = ACTIONS(3905),
    [anon_sym_And] = ACTIONS(3905),
    [anon_sym_or] = ACTIONS(3905),
    [anon_sym_OR] = ACTIONS(3905),
    [anon_sym_Or] = ACTIONS(3905),
    [anon_sym_xor] = ACTIONS(3905),
    [anon_sym_XOR] = ACTIONS(3905),
    [anon_sym_Xor] = ACTIONS(3905),
    [anon_sym_QMARK] = ACTIONS(3907),
    [sym_datetime_literal] = ACTIONS(3907),
    [sym_date_literal] = ACTIONS(3905),
    [sym_time_literal] = ACTIONS(3905),
    [sym_biginteger_literal] = ACTIONS(3907),
    [anon_sym_else] = ACTIONS(3905),
    [anon_sym_ELSE] = ACTIONS(3905),
    [anon_sym_Else] = ACTIONS(3905),
    [anon_sym_in] = ACTIONS(3905),
    [anon_sym_IN] = ACTIONS(3905),
    [anon_sym_In] = ACTIONS(3905),
    [sym_page_keyword] = ACTIONS(3905),
    [anon_sym_codeunit] = ACTIONS(3905),
    [anon_sym_CODEUNIT] = ACTIONS(3905),
    [anon_sym_Codeunit] = ACTIONS(3905),
    [anon_sym_CodeUnit] = ACTIONS(3905),
    [anon_sym_COdeunit] = ACTIONS(3905),
    [anon_sym_codeUnit] = ACTIONS(3905),
    [sym_report_keyword] = ACTIONS(3905),
    [sym_query_keyword] = ACTIONS(3905),
    [anon_sym_xmlport] = ACTIONS(3905),
    [anon_sym_XMLPORT] = ACTIONS(3905),
    [anon_sym_Xmlport] = ACTIONS(3905),
    [anon_sym_XMLport] = ACTIONS(3905),
    [anon_sym_XMLPort] = ACTIONS(3905),
    [anon_sym_XmlPort] = ACTIONS(3905),
    [anon_sym_enum] = ACTIONS(3905),
    [anon_sym_ENUM] = ACTIONS(3905),
    [anon_sym_Enum] = ACTIONS(3905),
    [anon_sym_eNUM] = ACTIONS(3905),
    [anon_sym_eNum] = ACTIONS(3905),
    [anon_sym_ENum] = ACTIONS(3905),
    [sym_quoted_identifier] = ACTIONS(3907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3907),
    [sym_verbatim_string] = ACTIONS(3907),
    [sym_integer] = ACTIONS(3905),
    [sym_continue_as_identifier] = ACTIONS(3907),
    [sym_preproc_open] = ACTIONS(3907),
  },
  [STATE(3532)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3730),
    [anon_sym_SEMI] = ACTIONS(3732),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3730),
    [aux_sym_boolean_token2] = ACTIONS(3730),
    [sym_decimal] = ACTIONS(3730),
    [anon_sym_LPAREN] = ACTIONS(3732),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3730),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3730),
    [aux_sym_basic_type_token21] = ACTIONS(3730),
    [aux_sym_basic_type_token22] = ACTIONS(3730),
    [aux_sym_basic_type_token48] = ACTIONS(3730),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3730),
    [anon_sym_POUNDif] = ACTIONS(3732),
    [anon_sym_POUNDIF] = ACTIONS(3732),
    [anon_sym_POUNDIf] = ACTIONS(3732),
    [anon_sym_not] = ACTIONS(3730),
    [anon_sym_NOT] = ACTIONS(3730),
    [anon_sym_Not] = ACTIONS(3730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(7469),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3730),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3730),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(7471),
    [anon_sym_OR] = ACTIONS(7473),
    [anon_sym_Or] = ACTIONS(7475),
    [anon_sym_xor] = ACTIONS(7477),
    [anon_sym_XOR] = ACTIONS(7479),
    [anon_sym_Xor] = ACTIONS(7481),
    [anon_sym_QMARK] = ACTIONS(7483),
    [sym_datetime_literal] = ACTIONS(3732),
    [sym_date_literal] = ACTIONS(3730),
    [sym_time_literal] = ACTIONS(3730),
    [sym_biginteger_literal] = ACTIONS(3732),
    [anon_sym_else] = ACTIONS(3730),
    [anon_sym_ELSE] = ACTIONS(3730),
    [anon_sym_Else] = ACTIONS(3730),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3730),
    [anon_sym_codeunit] = ACTIONS(3730),
    [anon_sym_CODEUNIT] = ACTIONS(3730),
    [anon_sym_Codeunit] = ACTIONS(3730),
    [anon_sym_CodeUnit] = ACTIONS(3730),
    [anon_sym_COdeunit] = ACTIONS(3730),
    [anon_sym_codeUnit] = ACTIONS(3730),
    [sym_report_keyword] = ACTIONS(3730),
    [sym_query_keyword] = ACTIONS(3730),
    [anon_sym_xmlport] = ACTIONS(3730),
    [anon_sym_XMLPORT] = ACTIONS(3730),
    [anon_sym_Xmlport] = ACTIONS(3730),
    [anon_sym_XMLport] = ACTIONS(3730),
    [anon_sym_XMLPort] = ACTIONS(3730),
    [anon_sym_XmlPort] = ACTIONS(3730),
    [anon_sym_enum] = ACTIONS(3730),
    [anon_sym_ENUM] = ACTIONS(3730),
    [anon_sym_Enum] = ACTIONS(3730),
    [anon_sym_eNUM] = ACTIONS(3730),
    [anon_sym_eNum] = ACTIONS(3730),
    [anon_sym_ENum] = ACTIONS(3730),
    [sym_quoted_identifier] = ACTIONS(3732),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3732),
    [sym_verbatim_string] = ACTIONS(3732),
    [sym_integer] = ACTIONS(3730),
    [sym_continue_as_identifier] = ACTIONS(3732),
    [sym_preproc_open] = ACTIONS(3732),
  },
  [STATE(3533)] = {
    [anon_sym_POUNDif] = ACTIONS(7420),
    [anon_sym_POUNDIF] = ACTIONS(7420),
    [anon_sym_POUNDIf] = ACTIONS(7420),
    [anon_sym_POUNDendif] = ACTIONS(7420),
    [anon_sym_POUNDENDIF] = ACTIONS(7420),
    [anon_sym_POUNDEndif] = ACTIONS(7420),
    [anon_sym_POUNDendif2] = ACTIONS(7420),
    [anon_sym_POUNDENDIF2] = ACTIONS(7420),
    [anon_sym_POUNDEndif2] = ACTIONS(7420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7418),
    [anon_sym_tableextension] = ACTIONS(7420),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7420),
    [anon_sym_Tableextension] = ACTIONS(7420),
    [anon_sym_TableExtension] = ACTIONS(7420),
    [anon_sym_tableExtension] = ACTIONS(7420),
    [sym_page_keyword] = ACTIONS(7418),
    [anon_sym_pageextension] = ACTIONS(7420),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7420),
    [anon_sym_Pageextension] = ACTIONS(7420),
    [anon_sym_PageExtension] = ACTIONS(7420),
    [anon_sym_pageExtension] = ACTIONS(7420),
    [anon_sym_codeunit] = ACTIONS(7420),
    [anon_sym_CODEUNIT] = ACTIONS(7420),
    [anon_sym_Codeunit] = ACTIONS(7420),
    [anon_sym_CodeUnit] = ACTIONS(7420),
    [anon_sym_COdeunit] = ACTIONS(7420),
    [anon_sym_codeUnit] = ACTIONS(7420),
    [sym_report_keyword] = ACTIONS(7418),
    [anon_sym_reportextension] = ACTIONS(7420),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7420),
    [anon_sym_Reportextension] = ACTIONS(7420),
    [anon_sym_ReportExtension] = ACTIONS(7420),
    [anon_sym_reportExtension] = ACTIONS(7420),
    [sym_query_keyword] = ACTIONS(7420),
    [anon_sym_xmlport] = ACTIONS(7420),
    [anon_sym_XMLPORT] = ACTIONS(7420),
    [anon_sym_Xmlport] = ACTIONS(7420),
    [anon_sym_XMLport] = ACTIONS(7420),
    [anon_sym_XMLPort] = ACTIONS(7420),
    [anon_sym_XmlPort] = ACTIONS(7420),
    [anon_sym_enum] = ACTIONS(7418),
    [anon_sym_ENUM] = ACTIONS(7418),
    [anon_sym_Enum] = ACTIONS(7418),
    [anon_sym_eNUM] = ACTIONS(7420),
    [anon_sym_eNum] = ACTIONS(7420),
    [anon_sym_ENum] = ACTIONS(7420),
    [anon_sym_enumextension] = ACTIONS(7420),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7420),
    [anon_sym_Enumextension] = ACTIONS(7420),
    [anon_sym_EnumExtension] = ACTIONS(7420),
    [anon_sym_enumExtension] = ACTIONS(7420),
    [sym_interface_keyword] = ACTIONS(7420),
    [anon_sym_controladdin] = ACTIONS(7420),
    [anon_sym_CONTROLADDIN] = ACTIONS(7420),
    [anon_sym_Controladdin] = ACTIONS(7420),
    [anon_sym_ControlAddIn] = ACTIONS(7420),
    [anon_sym_ControlAddin] = ACTIONS(7420),
    [anon_sym_controlAddIn] = ACTIONS(7420),
    [anon_sym_controlAddin] = ACTIONS(7420),
    [anon_sym_dotnet] = ACTIONS(7420),
    [anon_sym_DOTNET] = ACTIONS(7420),
    [anon_sym_Dotnet] = ACTIONS(7420),
    [anon_sym_DotNet] = ACTIONS(7420),
    [anon_sym_dotNet] = ACTIONS(7420),
    [sym_profile_keyword] = ACTIONS(7418),
    [anon_sym_profileextension] = ACTIONS(7420),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7420),
    [anon_sym_Profileextension] = ACTIONS(7420),
    [anon_sym_ProfileExtension] = ACTIONS(7420),
    [anon_sym_profileExtension] = ACTIONS(7420),
    [anon_sym_permissionset] = ACTIONS(7418),
    [anon_sym_PERMISSIONSET] = ACTIONS(7418),
    [anon_sym_Permissionset] = ACTIONS(7418),
    [anon_sym_PermissionSet] = ACTIONS(7418),
    [anon_sym_permissionSet] = ACTIONS(7418),
    [anon_sym_permissionsetextension] = ACTIONS(7420),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7420),
    [anon_sym_Permissionsetextension] = ACTIONS(7420),
    [anon_sym_PermissionSetExtension] = ACTIONS(7420),
    [anon_sym_permissionSetExtension] = ACTIONS(7420),
    [sym_entitlement_keyword] = ACTIONS(7420),
    [anon_sym_pagecustomization] = ACTIONS(7420),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7420),
    [anon_sym_Pagecustomization] = ACTIONS(7420),
    [anon_sym_PageCustomization] = ACTIONS(7420),
    [anon_sym_pageCustomization] = ACTIONS(7420),
    [sym_namespace_keyword] = ACTIONS(7420),
    [sym_using_keyword] = ACTIONS(7420),
    [sym_fieldgroup_keyword] = ACTIONS(7420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7420),
    [sym_preproc_close] = ACTIONS(7420),
  },
  [STATE(3534)] = {
    [sym_identifier] = ACTIONS(3913),
    [anon_sym_SEMI] = ACTIONS(3915),
    [anon_sym_DOT] = ACTIONS(3913),
    [anon_sym_EQ] = ACTIONS(3915),
    [anon_sym_COMMA] = ACTIONS(3915),
    [anon_sym_COLON] = ACTIONS(3913),
    [anon_sym_DASH] = ACTIONS(3913),
    [aux_sym_boolean_token1] = ACTIONS(3913),
    [aux_sym_boolean_token2] = ACTIONS(3913),
    [sym_decimal] = ACTIONS(3913),
    [anon_sym_LPAREN] = ACTIONS(3915),
    [anon_sym_DOT_DOT] = ACTIONS(3915),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3913),
    [anon_sym_STAR] = ACTIONS(3913),
    [anon_sym_LBRACK] = ACTIONS(3915),
    [aux_sym_record_type_token1] = ACTIONS(3913),
    [aux_sym_basic_type_token21] = ACTIONS(3913),
    [aux_sym_basic_type_token22] = ACTIONS(3913),
    [aux_sym_basic_type_token48] = ACTIONS(3913),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3913),
    [anon_sym_POUNDif] = ACTIONS(3915),
    [anon_sym_POUNDIF] = ACTIONS(3915),
    [anon_sym_POUNDIf] = ACTIONS(3915),
    [anon_sym_not] = ACTIONS(3913),
    [anon_sym_NOT] = ACTIONS(3913),
    [anon_sym_Not] = ACTIONS(3913),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3915),
    [aux_sym__expression_token1] = ACTIONS(3915),
    [aux_sym__expression_token2] = ACTIONS(3915),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3913),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3913),
    [anon_sym_SLASH] = ACTIONS(3913),
    [anon_sym_div] = ACTIONS(3913),
    [anon_sym_DIV] = ACTIONS(3913),
    [anon_sym_Div] = ACTIONS(3913),
    [anon_sym_mod] = ACTIONS(3913),
    [anon_sym_MOD] = ACTIONS(3913),
    [anon_sym_Mod] = ACTIONS(3913),
    [anon_sym_PLUS] = ACTIONS(3913),
    [anon_sym_GT_EQ] = ACTIONS(3915),
    [anon_sym_LT_EQ] = ACTIONS(3915),
    [anon_sym_GT] = ACTIONS(3913),
    [anon_sym_LT] = ACTIONS(3913),
    [anon_sym_LT_GT] = ACTIONS(3915),
    [anon_sym_and] = ACTIONS(3913),
    [anon_sym_AND] = ACTIONS(3913),
    [anon_sym_And] = ACTIONS(3913),
    [anon_sym_or] = ACTIONS(3913),
    [anon_sym_OR] = ACTIONS(3913),
    [anon_sym_Or] = ACTIONS(3913),
    [anon_sym_xor] = ACTIONS(3913),
    [anon_sym_XOR] = ACTIONS(3913),
    [anon_sym_Xor] = ACTIONS(3913),
    [anon_sym_QMARK] = ACTIONS(3915),
    [sym_datetime_literal] = ACTIONS(3915),
    [sym_date_literal] = ACTIONS(3913),
    [sym_time_literal] = ACTIONS(3913),
    [sym_biginteger_literal] = ACTIONS(3915),
    [anon_sym_else] = ACTIONS(3913),
    [anon_sym_ELSE] = ACTIONS(3913),
    [anon_sym_Else] = ACTIONS(3913),
    [anon_sym_in] = ACTIONS(3913),
    [anon_sym_IN] = ACTIONS(3913),
    [anon_sym_In] = ACTIONS(3913),
    [sym_page_keyword] = ACTIONS(3913),
    [anon_sym_codeunit] = ACTIONS(3913),
    [anon_sym_CODEUNIT] = ACTIONS(3913),
    [anon_sym_Codeunit] = ACTIONS(3913),
    [anon_sym_CodeUnit] = ACTIONS(3913),
    [anon_sym_COdeunit] = ACTIONS(3913),
    [anon_sym_codeUnit] = ACTIONS(3913),
    [sym_report_keyword] = ACTIONS(3913),
    [sym_query_keyword] = ACTIONS(3913),
    [anon_sym_xmlport] = ACTIONS(3913),
    [anon_sym_XMLPORT] = ACTIONS(3913),
    [anon_sym_Xmlport] = ACTIONS(3913),
    [anon_sym_XMLport] = ACTIONS(3913),
    [anon_sym_XMLPort] = ACTIONS(3913),
    [anon_sym_XmlPort] = ACTIONS(3913),
    [anon_sym_enum] = ACTIONS(3913),
    [anon_sym_ENUM] = ACTIONS(3913),
    [anon_sym_Enum] = ACTIONS(3913),
    [anon_sym_eNUM] = ACTIONS(3913),
    [anon_sym_eNum] = ACTIONS(3913),
    [anon_sym_ENum] = ACTIONS(3913),
    [sym_quoted_identifier] = ACTIONS(3915),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3915),
    [sym_verbatim_string] = ACTIONS(3915),
    [sym_integer] = ACTIONS(3913),
    [sym_continue_as_identifier] = ACTIONS(3915),
    [sym_preproc_open] = ACTIONS(3915),
  },
  [STATE(3535)] = {
    [sym_identifier] = ACTIONS(3917),
    [anon_sym_SEMI] = ACTIONS(3919),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_EQ] = ACTIONS(3919),
    [anon_sym_COMMA] = ACTIONS(3919),
    [anon_sym_COLON] = ACTIONS(3917),
    [anon_sym_DASH] = ACTIONS(3917),
    [aux_sym_boolean_token1] = ACTIONS(3917),
    [aux_sym_boolean_token2] = ACTIONS(3917),
    [sym_decimal] = ACTIONS(3917),
    [anon_sym_LPAREN] = ACTIONS(3919),
    [anon_sym_DOT_DOT] = ACTIONS(3919),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3919),
    [aux_sym_record_type_token1] = ACTIONS(3917),
    [aux_sym_basic_type_token21] = ACTIONS(3917),
    [aux_sym_basic_type_token22] = ACTIONS(3917),
    [aux_sym_basic_type_token48] = ACTIONS(3917),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3917),
    [anon_sym_POUNDif] = ACTIONS(3919),
    [anon_sym_POUNDIF] = ACTIONS(3919),
    [anon_sym_POUNDIf] = ACTIONS(3919),
    [anon_sym_not] = ACTIONS(3917),
    [anon_sym_NOT] = ACTIONS(3917),
    [anon_sym_Not] = ACTIONS(3917),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3919),
    [aux_sym__expression_token1] = ACTIONS(3919),
    [aux_sym__expression_token2] = ACTIONS(3919),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3917),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_div] = ACTIONS(3917),
    [anon_sym_DIV] = ACTIONS(3917),
    [anon_sym_Div] = ACTIONS(3917),
    [anon_sym_mod] = ACTIONS(3917),
    [anon_sym_MOD] = ACTIONS(3917),
    [anon_sym_Mod] = ACTIONS(3917),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3919),
    [anon_sym_LT_EQ] = ACTIONS(3919),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_LT_GT] = ACTIONS(3919),
    [anon_sym_and] = ACTIONS(3917),
    [anon_sym_AND] = ACTIONS(3917),
    [anon_sym_And] = ACTIONS(3917),
    [anon_sym_or] = ACTIONS(3917),
    [anon_sym_OR] = ACTIONS(3917),
    [anon_sym_Or] = ACTIONS(3917),
    [anon_sym_xor] = ACTIONS(3917),
    [anon_sym_XOR] = ACTIONS(3917),
    [anon_sym_Xor] = ACTIONS(3917),
    [anon_sym_QMARK] = ACTIONS(3919),
    [sym_datetime_literal] = ACTIONS(3919),
    [sym_date_literal] = ACTIONS(3917),
    [sym_time_literal] = ACTIONS(3917),
    [sym_biginteger_literal] = ACTIONS(3919),
    [anon_sym_else] = ACTIONS(3917),
    [anon_sym_ELSE] = ACTIONS(3917),
    [anon_sym_Else] = ACTIONS(3917),
    [anon_sym_in] = ACTIONS(3917),
    [anon_sym_IN] = ACTIONS(3917),
    [anon_sym_In] = ACTIONS(3917),
    [sym_page_keyword] = ACTIONS(3917),
    [anon_sym_codeunit] = ACTIONS(3917),
    [anon_sym_CODEUNIT] = ACTIONS(3917),
    [anon_sym_Codeunit] = ACTIONS(3917),
    [anon_sym_CodeUnit] = ACTIONS(3917),
    [anon_sym_COdeunit] = ACTIONS(3917),
    [anon_sym_codeUnit] = ACTIONS(3917),
    [sym_report_keyword] = ACTIONS(3917),
    [sym_query_keyword] = ACTIONS(3917),
    [anon_sym_xmlport] = ACTIONS(3917),
    [anon_sym_XMLPORT] = ACTIONS(3917),
    [anon_sym_Xmlport] = ACTIONS(3917),
    [anon_sym_XMLport] = ACTIONS(3917),
    [anon_sym_XMLPort] = ACTIONS(3917),
    [anon_sym_XmlPort] = ACTIONS(3917),
    [anon_sym_enum] = ACTIONS(3917),
    [anon_sym_ENUM] = ACTIONS(3917),
    [anon_sym_Enum] = ACTIONS(3917),
    [anon_sym_eNUM] = ACTIONS(3917),
    [anon_sym_eNum] = ACTIONS(3917),
    [anon_sym_ENum] = ACTIONS(3917),
    [sym_quoted_identifier] = ACTIONS(3919),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3919),
    [sym_verbatim_string] = ACTIONS(3919),
    [sym_integer] = ACTIONS(3917),
    [sym_continue_as_identifier] = ACTIONS(3919),
    [sym_preproc_open] = ACTIONS(3919),
  },
  [STATE(3536)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_COLON] = ACTIONS(3873),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
  },
  [STATE(3537)] = {
    [sym_identifier] = ACTIONS(3877),
    [anon_sym_SEMI] = ACTIONS(3879),
    [anon_sym_DOT] = ACTIONS(3877),
    [anon_sym_EQ] = ACTIONS(3879),
    [anon_sym_COMMA] = ACTIONS(3879),
    [anon_sym_COLON] = ACTIONS(3877),
    [anon_sym_DASH] = ACTIONS(3877),
    [aux_sym_boolean_token1] = ACTIONS(3877),
    [aux_sym_boolean_token2] = ACTIONS(3877),
    [sym_decimal] = ACTIONS(3877),
    [anon_sym_LPAREN] = ACTIONS(3879),
    [anon_sym_DOT_DOT] = ACTIONS(3879),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3877),
    [anon_sym_STAR] = ACTIONS(3877),
    [anon_sym_LBRACK] = ACTIONS(3879),
    [aux_sym_record_type_token1] = ACTIONS(3877),
    [aux_sym_basic_type_token21] = ACTIONS(3877),
    [aux_sym_basic_type_token22] = ACTIONS(3877),
    [aux_sym_basic_type_token48] = ACTIONS(3877),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3877),
    [anon_sym_POUNDif] = ACTIONS(3879),
    [anon_sym_POUNDIF] = ACTIONS(3879),
    [anon_sym_POUNDIf] = ACTIONS(3879),
    [anon_sym_not] = ACTIONS(3877),
    [anon_sym_NOT] = ACTIONS(3877),
    [anon_sym_Not] = ACTIONS(3877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3879),
    [aux_sym__expression_token1] = ACTIONS(3879),
    [aux_sym__expression_token2] = ACTIONS(3879),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3877),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3877),
    [anon_sym_SLASH] = ACTIONS(3877),
    [anon_sym_div] = ACTIONS(3877),
    [anon_sym_DIV] = ACTIONS(3877),
    [anon_sym_Div] = ACTIONS(3877),
    [anon_sym_mod] = ACTIONS(3877),
    [anon_sym_MOD] = ACTIONS(3877),
    [anon_sym_Mod] = ACTIONS(3877),
    [anon_sym_PLUS] = ACTIONS(3877),
    [anon_sym_GT_EQ] = ACTIONS(3879),
    [anon_sym_LT_EQ] = ACTIONS(3879),
    [anon_sym_GT] = ACTIONS(3877),
    [anon_sym_LT] = ACTIONS(3877),
    [anon_sym_LT_GT] = ACTIONS(3879),
    [anon_sym_and] = ACTIONS(3877),
    [anon_sym_AND] = ACTIONS(3877),
    [anon_sym_And] = ACTIONS(3877),
    [anon_sym_or] = ACTIONS(3877),
    [anon_sym_OR] = ACTIONS(3877),
    [anon_sym_Or] = ACTIONS(3877),
    [anon_sym_xor] = ACTIONS(3877),
    [anon_sym_XOR] = ACTIONS(3877),
    [anon_sym_Xor] = ACTIONS(3877),
    [anon_sym_QMARK] = ACTIONS(3879),
    [sym_datetime_literal] = ACTIONS(3879),
    [sym_date_literal] = ACTIONS(3877),
    [sym_time_literal] = ACTIONS(3877),
    [sym_biginteger_literal] = ACTIONS(3879),
    [anon_sym_else] = ACTIONS(3877),
    [anon_sym_ELSE] = ACTIONS(3877),
    [anon_sym_Else] = ACTIONS(3877),
    [anon_sym_in] = ACTIONS(3877),
    [anon_sym_IN] = ACTIONS(3877),
    [anon_sym_In] = ACTIONS(3877),
    [sym_page_keyword] = ACTIONS(3877),
    [anon_sym_codeunit] = ACTIONS(3877),
    [anon_sym_CODEUNIT] = ACTIONS(3877),
    [anon_sym_Codeunit] = ACTIONS(3877),
    [anon_sym_CodeUnit] = ACTIONS(3877),
    [anon_sym_COdeunit] = ACTIONS(3877),
    [anon_sym_codeUnit] = ACTIONS(3877),
    [sym_report_keyword] = ACTIONS(3877),
    [sym_query_keyword] = ACTIONS(3877),
    [anon_sym_xmlport] = ACTIONS(3877),
    [anon_sym_XMLPORT] = ACTIONS(3877),
    [anon_sym_Xmlport] = ACTIONS(3877),
    [anon_sym_XMLport] = ACTIONS(3877),
    [anon_sym_XMLPort] = ACTIONS(3877),
    [anon_sym_XmlPort] = ACTIONS(3877),
    [anon_sym_enum] = ACTIONS(3877),
    [anon_sym_ENUM] = ACTIONS(3877),
    [anon_sym_Enum] = ACTIONS(3877),
    [anon_sym_eNUM] = ACTIONS(3877),
    [anon_sym_eNum] = ACTIONS(3877),
    [anon_sym_ENum] = ACTIONS(3877),
    [sym_quoted_identifier] = ACTIONS(3879),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3879),
    [sym_verbatim_string] = ACTIONS(3879),
    [sym_integer] = ACTIONS(3877),
    [sym_continue_as_identifier] = ACTIONS(3879),
    [sym_preproc_open] = ACTIONS(3879),
  },
  [STATE(3538)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_SEMI] = ACTIONS(3665),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_COMMA] = ACTIONS(3665),
    [anon_sym_COLON] = ACTIONS(3663),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3663),
    [anon_sym_POUNDif] = ACTIONS(3665),
    [anon_sym_POUNDIF] = ACTIONS(3665),
    [anon_sym_POUNDIf] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_else] = ACTIONS(3663),
    [anon_sym_ELSE] = ACTIONS(3663),
    [anon_sym_Else] = ACTIONS(3663),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
    [sym_preproc_open] = ACTIONS(3665),
  },
  [STATE(3539)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_COLON] = ACTIONS(3873),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
  },
  [STATE(3540)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3710),
    [anon_sym_SEMI] = ACTIONS(3712),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3710),
    [aux_sym_boolean_token2] = ACTIONS(3710),
    [sym_decimal] = ACTIONS(3710),
    [anon_sym_LPAREN] = ACTIONS(3712),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3710),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3710),
    [aux_sym_basic_type_token21] = ACTIONS(3710),
    [aux_sym_basic_type_token22] = ACTIONS(3710),
    [aux_sym_basic_type_token48] = ACTIONS(3710),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3710),
    [anon_sym_POUNDif] = ACTIONS(3712),
    [anon_sym_POUNDIF] = ACTIONS(3712),
    [anon_sym_POUNDIf] = ACTIONS(3712),
    [anon_sym_not] = ACTIONS(3710),
    [anon_sym_NOT] = ACTIONS(3710),
    [anon_sym_Not] = ACTIONS(3710),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(7604),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3710),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3710),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(7471),
    [anon_sym_OR] = ACTIONS(7473),
    [anon_sym_Or] = ACTIONS(7475),
    [anon_sym_xor] = ACTIONS(7477),
    [anon_sym_XOR] = ACTIONS(7479),
    [anon_sym_Xor] = ACTIONS(7481),
    [anon_sym_QMARK] = ACTIONS(7483),
    [sym_datetime_literal] = ACTIONS(3712),
    [sym_date_literal] = ACTIONS(3710),
    [sym_time_literal] = ACTIONS(3710),
    [sym_biginteger_literal] = ACTIONS(3712),
    [anon_sym_else] = ACTIONS(3710),
    [anon_sym_ELSE] = ACTIONS(3710),
    [anon_sym_Else] = ACTIONS(3710),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3710),
    [anon_sym_codeunit] = ACTIONS(3710),
    [anon_sym_CODEUNIT] = ACTIONS(3710),
    [anon_sym_Codeunit] = ACTIONS(3710),
    [anon_sym_CodeUnit] = ACTIONS(3710),
    [anon_sym_COdeunit] = ACTIONS(3710),
    [anon_sym_codeUnit] = ACTIONS(3710),
    [sym_report_keyword] = ACTIONS(3710),
    [sym_query_keyword] = ACTIONS(3710),
    [anon_sym_xmlport] = ACTIONS(3710),
    [anon_sym_XMLPORT] = ACTIONS(3710),
    [anon_sym_Xmlport] = ACTIONS(3710),
    [anon_sym_XMLport] = ACTIONS(3710),
    [anon_sym_XMLPort] = ACTIONS(3710),
    [anon_sym_XmlPort] = ACTIONS(3710),
    [anon_sym_enum] = ACTIONS(3710),
    [anon_sym_ENUM] = ACTIONS(3710),
    [anon_sym_Enum] = ACTIONS(3710),
    [anon_sym_eNUM] = ACTIONS(3710),
    [anon_sym_eNum] = ACTIONS(3710),
    [anon_sym_ENum] = ACTIONS(3710),
    [sym_quoted_identifier] = ACTIONS(3712),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3712),
    [sym_verbatim_string] = ACTIONS(3712),
    [sym_integer] = ACTIONS(3710),
    [sym_continue_as_identifier] = ACTIONS(3712),
    [sym_preproc_open] = ACTIONS(3712),
  },
  [STATE(3541)] = {
    [sym_identifier] = ACTIONS(3873),
    [anon_sym_SEMI] = ACTIONS(3875),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(3875),
    [anon_sym_COLON] = ACTIONS(3873),
    [anon_sym_DASH] = ACTIONS(3873),
    [aux_sym_boolean_token1] = ACTIONS(3873),
    [aux_sym_boolean_token2] = ACTIONS(3873),
    [sym_decimal] = ACTIONS(3873),
    [anon_sym_LPAREN] = ACTIONS(3875),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3873),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(3875),
    [aux_sym_record_type_token1] = ACTIONS(3873),
    [aux_sym_basic_type_token21] = ACTIONS(3873),
    [aux_sym_basic_type_token22] = ACTIONS(3873),
    [aux_sym_basic_type_token48] = ACTIONS(3873),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3873),
    [anon_sym_POUNDif] = ACTIONS(3875),
    [anon_sym_POUNDIF] = ACTIONS(3875),
    [anon_sym_POUNDIf] = ACTIONS(3875),
    [anon_sym_not] = ACTIONS(3873),
    [anon_sym_NOT] = ACTIONS(3873),
    [anon_sym_Not] = ACTIONS(3873),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3873),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3873),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(3873),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(3875),
    [sym_date_literal] = ACTIONS(3873),
    [sym_time_literal] = ACTIONS(3873),
    [sym_biginteger_literal] = ACTIONS(3875),
    [anon_sym_else] = ACTIONS(3873),
    [anon_sym_ELSE] = ACTIONS(3873),
    [anon_sym_Else] = ACTIONS(3873),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(3873),
    [anon_sym_codeunit] = ACTIONS(3873),
    [anon_sym_CODEUNIT] = ACTIONS(3873),
    [anon_sym_Codeunit] = ACTIONS(3873),
    [anon_sym_CodeUnit] = ACTIONS(3873),
    [anon_sym_COdeunit] = ACTIONS(3873),
    [anon_sym_codeUnit] = ACTIONS(3873),
    [sym_report_keyword] = ACTIONS(3873),
    [sym_query_keyword] = ACTIONS(3873),
    [anon_sym_xmlport] = ACTIONS(3873),
    [anon_sym_XMLPORT] = ACTIONS(3873),
    [anon_sym_Xmlport] = ACTIONS(3873),
    [anon_sym_XMLport] = ACTIONS(3873),
    [anon_sym_XMLPort] = ACTIONS(3873),
    [anon_sym_XmlPort] = ACTIONS(3873),
    [anon_sym_enum] = ACTIONS(3873),
    [anon_sym_ENUM] = ACTIONS(3873),
    [anon_sym_Enum] = ACTIONS(3873),
    [anon_sym_eNUM] = ACTIONS(3873),
    [anon_sym_eNum] = ACTIONS(3873),
    [anon_sym_ENum] = ACTIONS(3873),
    [sym_quoted_identifier] = ACTIONS(3875),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3875),
    [sym_verbatim_string] = ACTIONS(3875),
    [sym_integer] = ACTIONS(3873),
    [sym_continue_as_identifier] = ACTIONS(3875),
    [sym_preproc_open] = ACTIONS(3875),
  },
  [STATE(3542)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3734),
    [anon_sym_SEMI] = ACTIONS(3736),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3734),
    [aux_sym_boolean_token2] = ACTIONS(3734),
    [sym_decimal] = ACTIONS(3734),
    [anon_sym_LPAREN] = ACTIONS(3736),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3734),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3734),
    [aux_sym_basic_type_token21] = ACTIONS(3734),
    [aux_sym_basic_type_token22] = ACTIONS(3734),
    [aux_sym_basic_type_token48] = ACTIONS(3734),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3734),
    [anon_sym_POUNDif] = ACTIONS(3736),
    [anon_sym_POUNDIF] = ACTIONS(3736),
    [anon_sym_POUNDIf] = ACTIONS(3736),
    [anon_sym_not] = ACTIONS(3734),
    [anon_sym_NOT] = ACTIONS(3734),
    [anon_sym_Not] = ACTIONS(3734),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(7469),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3734),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3734),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(7471),
    [anon_sym_OR] = ACTIONS(7473),
    [anon_sym_Or] = ACTIONS(7475),
    [anon_sym_xor] = ACTIONS(7477),
    [anon_sym_XOR] = ACTIONS(7479),
    [anon_sym_Xor] = ACTIONS(7481),
    [anon_sym_QMARK] = ACTIONS(7483),
    [sym_datetime_literal] = ACTIONS(3736),
    [sym_date_literal] = ACTIONS(3734),
    [sym_time_literal] = ACTIONS(3734),
    [sym_biginteger_literal] = ACTIONS(3736),
    [anon_sym_else] = ACTIONS(3734),
    [anon_sym_ELSE] = ACTIONS(3734),
    [anon_sym_Else] = ACTIONS(3734),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3734),
    [anon_sym_codeunit] = ACTIONS(3734),
    [anon_sym_CODEUNIT] = ACTIONS(3734),
    [anon_sym_Codeunit] = ACTIONS(3734),
    [anon_sym_CodeUnit] = ACTIONS(3734),
    [anon_sym_COdeunit] = ACTIONS(3734),
    [anon_sym_codeUnit] = ACTIONS(3734),
    [sym_report_keyword] = ACTIONS(3734),
    [sym_query_keyword] = ACTIONS(3734),
    [anon_sym_xmlport] = ACTIONS(3734),
    [anon_sym_XMLPORT] = ACTIONS(3734),
    [anon_sym_Xmlport] = ACTIONS(3734),
    [anon_sym_XMLport] = ACTIONS(3734),
    [anon_sym_XMLPort] = ACTIONS(3734),
    [anon_sym_XmlPort] = ACTIONS(3734),
    [anon_sym_enum] = ACTIONS(3734),
    [anon_sym_ENUM] = ACTIONS(3734),
    [anon_sym_Enum] = ACTIONS(3734),
    [anon_sym_eNUM] = ACTIONS(3734),
    [anon_sym_eNum] = ACTIONS(3734),
    [anon_sym_ENum] = ACTIONS(3734),
    [sym_quoted_identifier] = ACTIONS(3736),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3736),
    [sym_verbatim_string] = ACTIONS(3736),
    [sym_integer] = ACTIONS(3734),
    [sym_continue_as_identifier] = ACTIONS(3736),
    [sym_preproc_open] = ACTIONS(3736),
  },
  [STATE(3543)] = {
    [sym_identifier] = ACTIONS(3937),
    [anon_sym_SEMI] = ACTIONS(3939),
    [anon_sym_DOT] = ACTIONS(3937),
    [anon_sym_EQ] = ACTIONS(3939),
    [anon_sym_COMMA] = ACTIONS(3939),
    [anon_sym_COLON] = ACTIONS(3937),
    [anon_sym_DASH] = ACTIONS(3937),
    [aux_sym_boolean_token1] = ACTIONS(3937),
    [aux_sym_boolean_token2] = ACTIONS(3937),
    [sym_decimal] = ACTIONS(3937),
    [anon_sym_LPAREN] = ACTIONS(3939),
    [anon_sym_DOT_DOT] = ACTIONS(3939),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3937),
    [anon_sym_STAR] = ACTIONS(3937),
    [anon_sym_LBRACK] = ACTIONS(3939),
    [aux_sym_record_type_token1] = ACTIONS(3937),
    [aux_sym_basic_type_token21] = ACTIONS(3937),
    [aux_sym_basic_type_token22] = ACTIONS(3937),
    [aux_sym_basic_type_token48] = ACTIONS(3937),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3937),
    [anon_sym_POUNDif] = ACTIONS(3939),
    [anon_sym_POUNDIF] = ACTIONS(3939),
    [anon_sym_POUNDIf] = ACTIONS(3939),
    [anon_sym_not] = ACTIONS(3937),
    [anon_sym_NOT] = ACTIONS(3937),
    [anon_sym_Not] = ACTIONS(3937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3939),
    [aux_sym__expression_token1] = ACTIONS(3939),
    [aux_sym__expression_token2] = ACTIONS(3939),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3937),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3937),
    [anon_sym_SLASH] = ACTIONS(3937),
    [anon_sym_div] = ACTIONS(3937),
    [anon_sym_DIV] = ACTIONS(3937),
    [anon_sym_Div] = ACTIONS(3937),
    [anon_sym_mod] = ACTIONS(3937),
    [anon_sym_MOD] = ACTIONS(3937),
    [anon_sym_Mod] = ACTIONS(3937),
    [anon_sym_PLUS] = ACTIONS(3937),
    [anon_sym_GT_EQ] = ACTIONS(3939),
    [anon_sym_LT_EQ] = ACTIONS(3939),
    [anon_sym_GT] = ACTIONS(3937),
    [anon_sym_LT] = ACTIONS(3937),
    [anon_sym_LT_GT] = ACTIONS(3939),
    [anon_sym_and] = ACTIONS(3937),
    [anon_sym_AND] = ACTIONS(3937),
    [anon_sym_And] = ACTIONS(3937),
    [anon_sym_or] = ACTIONS(3937),
    [anon_sym_OR] = ACTIONS(3937),
    [anon_sym_Or] = ACTIONS(3937),
    [anon_sym_xor] = ACTIONS(3937),
    [anon_sym_XOR] = ACTIONS(3937),
    [anon_sym_Xor] = ACTIONS(3937),
    [anon_sym_QMARK] = ACTIONS(3939),
    [sym_datetime_literal] = ACTIONS(3939),
    [sym_date_literal] = ACTIONS(3937),
    [sym_time_literal] = ACTIONS(3937),
    [sym_biginteger_literal] = ACTIONS(3939),
    [anon_sym_else] = ACTIONS(3937),
    [anon_sym_ELSE] = ACTIONS(3937),
    [anon_sym_Else] = ACTIONS(3937),
    [anon_sym_in] = ACTIONS(3937),
    [anon_sym_IN] = ACTIONS(3937),
    [anon_sym_In] = ACTIONS(3937),
    [sym_page_keyword] = ACTIONS(3937),
    [anon_sym_codeunit] = ACTIONS(3937),
    [anon_sym_CODEUNIT] = ACTIONS(3937),
    [anon_sym_Codeunit] = ACTIONS(3937),
    [anon_sym_CodeUnit] = ACTIONS(3937),
    [anon_sym_COdeunit] = ACTIONS(3937),
    [anon_sym_codeUnit] = ACTIONS(3937),
    [sym_report_keyword] = ACTIONS(3937),
    [sym_query_keyword] = ACTIONS(3937),
    [anon_sym_xmlport] = ACTIONS(3937),
    [anon_sym_XMLPORT] = ACTIONS(3937),
    [anon_sym_Xmlport] = ACTIONS(3937),
    [anon_sym_XMLport] = ACTIONS(3937),
    [anon_sym_XMLPort] = ACTIONS(3937),
    [anon_sym_XmlPort] = ACTIONS(3937),
    [anon_sym_enum] = ACTIONS(3937),
    [anon_sym_ENUM] = ACTIONS(3937),
    [anon_sym_Enum] = ACTIONS(3937),
    [anon_sym_eNUM] = ACTIONS(3937),
    [anon_sym_eNum] = ACTIONS(3937),
    [anon_sym_ENum] = ACTIONS(3937),
    [sym_quoted_identifier] = ACTIONS(3939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3939),
    [sym_verbatim_string] = ACTIONS(3939),
    [sym_integer] = ACTIONS(3937),
    [sym_continue_as_identifier] = ACTIONS(3939),
    [sym_preproc_open] = ACTIONS(3939),
  },
  [STATE(3544)] = {
    [sym_identifier] = ACTIONS(3738),
    [anon_sym_SEMI] = ACTIONS(3740),
    [anon_sym_DOT] = ACTIONS(3738),
    [anon_sym_EQ] = ACTIONS(3740),
    [anon_sym_COMMA] = ACTIONS(3740),
    [anon_sym_COLON] = ACTIONS(3738),
    [anon_sym_DASH] = ACTIONS(3738),
    [aux_sym_boolean_token1] = ACTIONS(3738),
    [aux_sym_boolean_token2] = ACTIONS(3738),
    [sym_decimal] = ACTIONS(3738),
    [anon_sym_LPAREN] = ACTIONS(3740),
    [anon_sym_DOT_DOT] = ACTIONS(3740),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3738),
    [anon_sym_STAR] = ACTIONS(3738),
    [anon_sym_LBRACK] = ACTIONS(3740),
    [aux_sym_record_type_token1] = ACTIONS(3738),
    [aux_sym_basic_type_token21] = ACTIONS(3738),
    [aux_sym_basic_type_token22] = ACTIONS(3738),
    [aux_sym_basic_type_token48] = ACTIONS(3738),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3738),
    [anon_sym_POUNDif] = ACTIONS(3740),
    [anon_sym_POUNDIF] = ACTIONS(3740),
    [anon_sym_POUNDIf] = ACTIONS(3740),
    [anon_sym_not] = ACTIONS(3738),
    [anon_sym_NOT] = ACTIONS(3738),
    [anon_sym_Not] = ACTIONS(3738),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3740),
    [aux_sym__expression_token1] = ACTIONS(3740),
    [aux_sym__expression_token2] = ACTIONS(3740),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3738),
    [anon_sym_SLASH] = ACTIONS(3738),
    [anon_sym_div] = ACTIONS(3738),
    [anon_sym_DIV] = ACTIONS(3738),
    [anon_sym_Div] = ACTIONS(3738),
    [anon_sym_mod] = ACTIONS(3738),
    [anon_sym_MOD] = ACTIONS(3738),
    [anon_sym_Mod] = ACTIONS(3738),
    [anon_sym_PLUS] = ACTIONS(3738),
    [anon_sym_GT_EQ] = ACTIONS(3740),
    [anon_sym_LT_EQ] = ACTIONS(3740),
    [anon_sym_GT] = ACTIONS(3738),
    [anon_sym_LT] = ACTIONS(3738),
    [anon_sym_LT_GT] = ACTIONS(3740),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3738),
    [anon_sym_And] = ACTIONS(3738),
    [anon_sym_or] = ACTIONS(3738),
    [anon_sym_OR] = ACTIONS(3738),
    [anon_sym_Or] = ACTIONS(3738),
    [anon_sym_xor] = ACTIONS(3738),
    [anon_sym_XOR] = ACTIONS(3738),
    [anon_sym_Xor] = ACTIONS(3738),
    [anon_sym_QMARK] = ACTIONS(3740),
    [sym_datetime_literal] = ACTIONS(3740),
    [sym_date_literal] = ACTIONS(3738),
    [sym_time_literal] = ACTIONS(3738),
    [sym_biginteger_literal] = ACTIONS(3740),
    [anon_sym_else] = ACTIONS(3738),
    [anon_sym_ELSE] = ACTIONS(3738),
    [anon_sym_Else] = ACTIONS(3738),
    [anon_sym_in] = ACTIONS(3738),
    [anon_sym_IN] = ACTIONS(3738),
    [anon_sym_In] = ACTIONS(3738),
    [sym_page_keyword] = ACTIONS(3738),
    [anon_sym_codeunit] = ACTIONS(3738),
    [anon_sym_CODEUNIT] = ACTIONS(3738),
    [anon_sym_Codeunit] = ACTIONS(3738),
    [anon_sym_CodeUnit] = ACTIONS(3738),
    [anon_sym_COdeunit] = ACTIONS(3738),
    [anon_sym_codeUnit] = ACTIONS(3738),
    [sym_report_keyword] = ACTIONS(3738),
    [sym_query_keyword] = ACTIONS(3738),
    [anon_sym_xmlport] = ACTIONS(3738),
    [anon_sym_XMLPORT] = ACTIONS(3738),
    [anon_sym_Xmlport] = ACTIONS(3738),
    [anon_sym_XMLport] = ACTIONS(3738),
    [anon_sym_XMLPort] = ACTIONS(3738),
    [anon_sym_XmlPort] = ACTIONS(3738),
    [anon_sym_enum] = ACTIONS(3738),
    [anon_sym_ENUM] = ACTIONS(3738),
    [anon_sym_Enum] = ACTIONS(3738),
    [anon_sym_eNUM] = ACTIONS(3738),
    [anon_sym_eNum] = ACTIONS(3738),
    [anon_sym_ENum] = ACTIONS(3738),
    [sym_quoted_identifier] = ACTIONS(3740),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3740),
    [sym_verbatim_string] = ACTIONS(3740),
    [sym_integer] = ACTIONS(3738),
    [sym_continue_as_identifier] = ACTIONS(3740),
    [sym_preproc_open] = ACTIONS(3740),
  },
  [STATE(3545)] = {
    [sym_identifier] = ACTIONS(3885),
    [anon_sym_SEMI] = ACTIONS(3887),
    [anon_sym_DOT] = ACTIONS(3885),
    [anon_sym_EQ] = ACTIONS(3887),
    [anon_sym_COMMA] = ACTIONS(3887),
    [anon_sym_COLON] = ACTIONS(3885),
    [anon_sym_DASH] = ACTIONS(3885),
    [aux_sym_boolean_token1] = ACTIONS(3885),
    [aux_sym_boolean_token2] = ACTIONS(3885),
    [sym_decimal] = ACTIONS(3885),
    [anon_sym_LPAREN] = ACTIONS(3887),
    [anon_sym_DOT_DOT] = ACTIONS(3887),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3885),
    [anon_sym_STAR] = ACTIONS(3885),
    [anon_sym_LBRACK] = ACTIONS(3887),
    [aux_sym_record_type_token1] = ACTIONS(3885),
    [aux_sym_basic_type_token21] = ACTIONS(3885),
    [aux_sym_basic_type_token22] = ACTIONS(3885),
    [aux_sym_basic_type_token48] = ACTIONS(3885),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3885),
    [anon_sym_POUNDif] = ACTIONS(3887),
    [anon_sym_POUNDIF] = ACTIONS(3887),
    [anon_sym_POUNDIf] = ACTIONS(3887),
    [anon_sym_not] = ACTIONS(3885),
    [anon_sym_NOT] = ACTIONS(3885),
    [anon_sym_Not] = ACTIONS(3885),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3887),
    [aux_sym__expression_token1] = ACTIONS(3887),
    [aux_sym__expression_token2] = ACTIONS(3887),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3885),
    [anon_sym_SLASH] = ACTIONS(3885),
    [anon_sym_div] = ACTIONS(3885),
    [anon_sym_DIV] = ACTIONS(3885),
    [anon_sym_Div] = ACTIONS(3885),
    [anon_sym_mod] = ACTIONS(3885),
    [anon_sym_MOD] = ACTIONS(3885),
    [anon_sym_Mod] = ACTIONS(3885),
    [anon_sym_PLUS] = ACTIONS(3885),
    [anon_sym_GT_EQ] = ACTIONS(3887),
    [anon_sym_LT_EQ] = ACTIONS(3887),
    [anon_sym_GT] = ACTIONS(3885),
    [anon_sym_LT] = ACTIONS(3885),
    [anon_sym_LT_GT] = ACTIONS(3887),
    [anon_sym_and] = ACTIONS(3885),
    [anon_sym_AND] = ACTIONS(3885),
    [anon_sym_And] = ACTIONS(3885),
    [anon_sym_or] = ACTIONS(3885),
    [anon_sym_OR] = ACTIONS(3885),
    [anon_sym_Or] = ACTIONS(3885),
    [anon_sym_xor] = ACTIONS(3885),
    [anon_sym_XOR] = ACTIONS(3885),
    [anon_sym_Xor] = ACTIONS(3885),
    [anon_sym_QMARK] = ACTIONS(3887),
    [sym_datetime_literal] = ACTIONS(3887),
    [sym_date_literal] = ACTIONS(3885),
    [sym_time_literal] = ACTIONS(3885),
    [sym_biginteger_literal] = ACTIONS(3887),
    [anon_sym_else] = ACTIONS(3885),
    [anon_sym_ELSE] = ACTIONS(3885),
    [anon_sym_Else] = ACTIONS(3885),
    [anon_sym_in] = ACTIONS(3885),
    [anon_sym_IN] = ACTIONS(3885),
    [anon_sym_In] = ACTIONS(3885),
    [sym_page_keyword] = ACTIONS(3885),
    [anon_sym_codeunit] = ACTIONS(3885),
    [anon_sym_CODEUNIT] = ACTIONS(3885),
    [anon_sym_Codeunit] = ACTIONS(3885),
    [anon_sym_CodeUnit] = ACTIONS(3885),
    [anon_sym_COdeunit] = ACTIONS(3885),
    [anon_sym_codeUnit] = ACTIONS(3885),
    [sym_report_keyword] = ACTIONS(3885),
    [sym_query_keyword] = ACTIONS(3885),
    [anon_sym_xmlport] = ACTIONS(3885),
    [anon_sym_XMLPORT] = ACTIONS(3885),
    [anon_sym_Xmlport] = ACTIONS(3885),
    [anon_sym_XMLport] = ACTIONS(3885),
    [anon_sym_XMLPort] = ACTIONS(3885),
    [anon_sym_XmlPort] = ACTIONS(3885),
    [anon_sym_enum] = ACTIONS(3885),
    [anon_sym_ENUM] = ACTIONS(3885),
    [anon_sym_Enum] = ACTIONS(3885),
    [anon_sym_eNUM] = ACTIONS(3885),
    [anon_sym_eNum] = ACTIONS(3885),
    [anon_sym_ENum] = ACTIONS(3885),
    [sym_quoted_identifier] = ACTIONS(3887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3887),
    [sym_verbatim_string] = ACTIONS(3887),
    [sym_integer] = ACTIONS(3885),
    [sym_continue_as_identifier] = ACTIONS(3887),
    [sym_preproc_open] = ACTIONS(3887),
  },
  [STATE(3546)] = {
    [sym__body_element] = STATE(8121),
    [sym_empty_statement] = STATE(8121),
    [sym_property] = STATE(8121),
    [sym_permissions_property] = STATE(8121),
    [sym_table_relation_property] = STATE(8121),
    [sym_fields_section] = STATE(8121),
    [sym_keys_section] = STATE(8121),
    [sym_fieldgroups_section] = STATE(8121),
    [sym_enum_value_declaration] = STATE(8121),
    [sym_labels_section] = STATE(8121),
    [sym_layout_section] = STATE(8121),
    [sym_modify_modification] = STATE(8121),
    [sym_actions_section] = STATE(8121),
    [sym_views_section] = STATE(8121),
    [sym_dataset_section] = STATE(8121),
    [sym_report_dataitem] = STATE(3605),
    [sym__report_body_element] = STATE(3605),
    [sym_preproc_conditional_report] = STATE(3605),
    [sym_report_column] = STATE(3605),
    [sym_requestpage_section] = STATE(8121),
    [sym_rendering_section] = STATE(8121),
    [sym_elements_section] = STATE(8121),
    [sym_schema_section] = STATE(8121),
    [sym_assembly_declaration] = STATE(8121),
    [sym_event_declaration] = STATE(8121),
    [sym_procedure] = STATE(8121),
    [sym_preproc_split_procedure] = STATE(8121),
    [sym__procedure_preamble] = STATE(10810),
    [sym_preproc_split_procedure_preamble] = STATE(8121),
    [sym__procedure_header] = STATE(9981),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(8121),
    [sym_var_section] = STATE(8121),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(8121),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_elif] = STATE(3730),
    [sym_preproc_else] = STATE(4059),
    [sym_preproc_endif] = STATE(9871),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3826),
    [aux_sym_report_dataitem_repeat1] = STATE(3605),
    [aux_sym_preproc_conditional_report_repeat1] = STATE(10923),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10844),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3547)] = {
    [sym_identifier] = ACTIONS(5410),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [aux_sym_where_condition_token1] = ACTIONS(5410),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_basic_type_token22] = ACTIONS(5410),
    [aux_sym_basic_type_token53] = ACTIONS(5410),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5410),
    [aux_sym_modify_modification_token1] = ACTIONS(5410),
    [aux_sym_separator_action_token1] = ACTIONS(5410),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [aux_sym_type_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [anon_sym_POUNDelif] = ACTIONS(5405),
    [anon_sym_POUNDELIF] = ACTIONS(5405),
    [anon_sym_POUNDElif] = ACTIONS(5405),
    [anon_sym_POUNDelse] = ACTIONS(5405),
    [anon_sym_POUNDELSE] = ACTIONS(5405),
    [anon_sym_POUNDElse] = ACTIONS(5405),
    [anon_sym_POUNDelse2] = ACTIONS(5405),
    [anon_sym_POUNDELSE2] = ACTIONS(5405),
    [anon_sym_POUNDElse2] = ACTIONS(5405),
    [anon_sym_POUNDendif] = ACTIONS(5405),
    [anon_sym_POUNDENDIF] = ACTIONS(5405),
    [anon_sym_POUNDEndif] = ACTIONS(5405),
    [anon_sym_POUNDendif2] = ACTIONS(5405),
    [anon_sym_POUNDENDIF2] = ACTIONS(5405),
    [anon_sym_POUNDEndif2] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_table_keyword] = ACTIONS(5410),
    [sym_procedure_keyword] = ACTIONS(5410),
    [sym_trigger_keyword] = ACTIONS(5410),
    [sym_var_keyword] = ACTIONS(5410),
    [sym_local_keyword] = ACTIONS(5410),
    [sym_internal_keyword] = ACTIONS(5410),
    [sym_protected_keyword] = ACTIONS(5410),
    [sym_event_keyword] = ACTIONS(5410),
    [sym_fields_keyword] = ACTIONS(5410),
    [sym_keys_keyword] = ACTIONS(5410),
    [sym_key_keyword] = ACTIONS(5410),
    [sym_fieldgroups_keyword] = ACTIONS(5410),
    [sym_actions_keyword] = ACTIONS(5410),
    [sym_layout_keyword] = ACTIONS(5410),
    [sym_dataset_keyword] = ACTIONS(5410),
    [sym_elements_keyword] = ACTIONS(5410),
    [sym_labels_keyword] = ACTIONS(5410),
    [sym_rendering_keyword] = ACTIONS(5410),
    [sym_requestpage_keyword] = ACTIONS(5410),
    [sym_schema_keyword] = ACTIONS(5410),
    [sym_views_keyword] = ACTIONS(5410),
    [sym_quoted_identifier] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
    [sym_preproc_close] = ACTIONS(5405),
    [sym_var_attribute_open] = ACTIONS(5405),
  },
  [STATE(3548)] = {
    [sym__body_element] = STATE(8121),
    [sym_empty_statement] = STATE(8121),
    [sym_property] = STATE(8121),
    [sym_permissions_property] = STATE(8121),
    [sym_table_relation_property] = STATE(8121),
    [sym_fields_section] = STATE(8121),
    [sym_keys_section] = STATE(8121),
    [sym_fieldgroups_section] = STATE(8121),
    [sym_enum_value_declaration] = STATE(8121),
    [sym_labels_section] = STATE(8121),
    [sym_layout_section] = STATE(8121),
    [sym_modify_modification] = STATE(8121),
    [sym_actions_section] = STATE(8121),
    [sym_views_section] = STATE(8121),
    [sym_dataset_section] = STATE(8121),
    [sym_report_dataitem] = STATE(3601),
    [sym__report_body_element] = STATE(3601),
    [sym_preproc_conditional_report] = STATE(3601),
    [sym_report_column] = STATE(3601),
    [sym_requestpage_section] = STATE(8121),
    [sym_rendering_section] = STATE(8121),
    [sym_elements_section] = STATE(8121),
    [sym_schema_section] = STATE(8121),
    [sym_assembly_declaration] = STATE(8121),
    [sym_event_declaration] = STATE(8121),
    [sym_procedure] = STATE(8121),
    [sym_preproc_split_procedure] = STATE(8121),
    [sym__procedure_preamble] = STATE(10930),
    [sym_preproc_split_procedure_preamble] = STATE(8121),
    [sym__procedure_header] = STATE(9970),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(8121),
    [sym_var_section] = STATE(8121),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(8121),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_elif] = STATE(3730),
    [sym_preproc_else] = STATE(4062),
    [sym_preproc_endif] = STATE(8126),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3834),
    [aux_sym_report_dataitem_repeat1] = STATE(3601),
    [aux_sym_preproc_conditional_report_repeat1] = STATE(10820),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10978),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3549)] = {
    [sym_identifier] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(6589),
    [anon_sym_EQ] = ACTIONS(6591),
    [anon_sym_DASH] = ACTIONS(6589),
    [aux_sym_where_clause_token1] = ACTIONS(3695),
    [aux_sym_where_condition_token1] = ACTIONS(3693),
    [anon_sym_DOT_DOT] = ACTIONS(6591),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(6593),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_basic_type_token53] = ACTIONS(3693),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3693),
    [aux_sym_modify_modification_token1] = ACTIONS(3693),
    [aux_sym_separator_action_token1] = ACTIONS(3693),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3693),
    [aux_sym_type_declaration_token1] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_POUNDelif] = ACTIONS(3695),
    [anon_sym_POUNDELIF] = ACTIONS(3695),
    [anon_sym_POUNDElif] = ACTIONS(3695),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [anon_sym_POUNDendif] = ACTIONS(3695),
    [anon_sym_POUNDENDIF] = ACTIONS(3695),
    [anon_sym_POUNDEndif] = ACTIONS(3695),
    [anon_sym_POUNDendif2] = ACTIONS(3695),
    [anon_sym_POUNDENDIF2] = ACTIONS(3695),
    [anon_sym_POUNDEndif2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6591),
    [aux_sym__expression_token1] = ACTIONS(6591),
    [aux_sym__expression_token2] = ACTIONS(6591),
    [anon_sym_SLASH] = ACTIONS(6589),
    [anon_sym_div] = ACTIONS(6589),
    [anon_sym_DIV] = ACTIONS(6589),
    [anon_sym_Div] = ACTIONS(6589),
    [anon_sym_mod] = ACTIONS(6589),
    [anon_sym_MOD] = ACTIONS(6589),
    [anon_sym_Mod] = ACTIONS(6589),
    [anon_sym_PLUS] = ACTIONS(6589),
    [anon_sym_GT_EQ] = ACTIONS(6591),
    [anon_sym_LT_EQ] = ACTIONS(6591),
    [anon_sym_GT] = ACTIONS(6589),
    [anon_sym_LT] = ACTIONS(6589),
    [anon_sym_LT_GT] = ACTIONS(6591),
    [anon_sym_and] = ACTIONS(6589),
    [anon_sym_AND] = ACTIONS(6589),
    [anon_sym_And] = ACTIONS(6589),
    [anon_sym_or] = ACTIONS(6589),
    [anon_sym_OR] = ACTIONS(6589),
    [anon_sym_Or] = ACTIONS(6589),
    [anon_sym_xor] = ACTIONS(6589),
    [anon_sym_XOR] = ACTIONS(6589),
    [anon_sym_Xor] = ACTIONS(6589),
    [anon_sym_QMARK] = ACTIONS(6591),
    [anon_sym_in] = ACTIONS(6589),
    [anon_sym_IN] = ACTIONS(6589),
    [anon_sym_In] = ACTIONS(6589),
    [sym_table_keyword] = ACTIONS(3693),
    [sym_procedure_keyword] = ACTIONS(3693),
    [sym_trigger_keyword] = ACTIONS(3693),
    [sym_var_keyword] = ACTIONS(3693),
    [sym_local_keyword] = ACTIONS(3693),
    [sym_internal_keyword] = ACTIONS(3693),
    [sym_protected_keyword] = ACTIONS(3693),
    [sym_event_keyword] = ACTIONS(3693),
    [sym_fields_keyword] = ACTIONS(3693),
    [sym_keys_keyword] = ACTIONS(3693),
    [sym_key_keyword] = ACTIONS(3693),
    [sym_fieldgroups_keyword] = ACTIONS(3693),
    [sym_actions_keyword] = ACTIONS(3693),
    [sym_layout_keyword] = ACTIONS(3693),
    [sym_dataset_keyword] = ACTIONS(3693),
    [sym_elements_keyword] = ACTIONS(3693),
    [sym_labels_keyword] = ACTIONS(3693),
    [sym_rendering_keyword] = ACTIONS(3693),
    [sym_requestpage_keyword] = ACTIONS(3693),
    [sym_schema_keyword] = ACTIONS(3693),
    [sym_views_keyword] = ACTIONS(3693),
    [sym_quoted_identifier] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
    [sym_preproc_close] = ACTIONS(3695),
    [sym_var_attribute_open] = ACTIONS(3695),
  },
  [STATE(3550)] = {
    [sym_comparison_operator] = STATE(4506),
    [sym_in_keyword] = STATE(16440),
    [sym_identifier] = ACTIONS(3720),
    [anon_sym_SEMI] = ACTIONS(3723),
    [anon_sym_DOT] = ACTIONS(7422),
    [anon_sym_EQ] = ACTIONS(3580),
    [anon_sym_DASH] = ACTIONS(7449),
    [aux_sym_boolean_token1] = ACTIONS(3720),
    [aux_sym_boolean_token2] = ACTIONS(3720),
    [sym_decimal] = ACTIONS(3720),
    [anon_sym_LPAREN] = ACTIONS(3723),
    [anon_sym_DOT_DOT] = ACTIONS(7424),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3720),
    [anon_sym_STAR] = ACTIONS(7426),
    [anon_sym_LBRACK] = ACTIONS(7428),
    [aux_sym_record_type_token1] = ACTIONS(3720),
    [aux_sym_basic_type_token21] = ACTIONS(3720),
    [aux_sym_basic_type_token22] = ACTIONS(3720),
    [aux_sym_basic_type_token48] = ACTIONS(3720),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3720),
    [anon_sym_POUNDif] = ACTIONS(3723),
    [anon_sym_POUNDIF] = ACTIONS(3723),
    [anon_sym_POUNDIf] = ACTIONS(3723),
    [anon_sym_not] = ACTIONS(3720),
    [anon_sym_NOT] = ACTIONS(3720),
    [anon_sym_Not] = ACTIONS(3720),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(7469),
    [aux_sym__expression_token1] = ACTIONS(7451),
    [aux_sym__expression_token2] = ACTIONS(7453),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3720),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3720),
    [anon_sym_SLASH] = ACTIONS(7430),
    [anon_sym_div] = ACTIONS(7432),
    [anon_sym_DIV] = ACTIONS(7434),
    [anon_sym_Div] = ACTIONS(7436),
    [anon_sym_mod] = ACTIONS(7438),
    [anon_sym_MOD] = ACTIONS(7440),
    [anon_sym_Mod] = ACTIONS(7442),
    [anon_sym_PLUS] = ACTIONS(7455),
    [anon_sym_GT_EQ] = ACTIONS(3580),
    [anon_sym_LT_EQ] = ACTIONS(3580),
    [anon_sym_GT] = ACTIONS(3608),
    [anon_sym_LT] = ACTIONS(3608),
    [anon_sym_LT_GT] = ACTIONS(3580),
    [anon_sym_and] = ACTIONS(7457),
    [anon_sym_AND] = ACTIONS(7459),
    [anon_sym_And] = ACTIONS(7461),
    [anon_sym_or] = ACTIONS(7471),
    [anon_sym_OR] = ACTIONS(7473),
    [anon_sym_Or] = ACTIONS(7475),
    [anon_sym_xor] = ACTIONS(7477),
    [anon_sym_XOR] = ACTIONS(7479),
    [anon_sym_Xor] = ACTIONS(7481),
    [anon_sym_QMARK] = ACTIONS(7483),
    [sym_datetime_literal] = ACTIONS(3723),
    [sym_date_literal] = ACTIONS(3720),
    [sym_time_literal] = ACTIONS(3720),
    [sym_biginteger_literal] = ACTIONS(3723),
    [anon_sym_else] = ACTIONS(3720),
    [anon_sym_ELSE] = ACTIONS(3720),
    [anon_sym_Else] = ACTIONS(3720),
    [anon_sym_in] = ACTIONS(3630),
    [anon_sym_IN] = ACTIONS(3630),
    [anon_sym_In] = ACTIONS(3630),
    [sym_page_keyword] = ACTIONS(3720),
    [anon_sym_codeunit] = ACTIONS(3720),
    [anon_sym_CODEUNIT] = ACTIONS(3720),
    [anon_sym_Codeunit] = ACTIONS(3720),
    [anon_sym_CodeUnit] = ACTIONS(3720),
    [anon_sym_COdeunit] = ACTIONS(3720),
    [anon_sym_codeUnit] = ACTIONS(3720),
    [sym_report_keyword] = ACTIONS(3720),
    [sym_query_keyword] = ACTIONS(3720),
    [anon_sym_xmlport] = ACTIONS(3720),
    [anon_sym_XMLPORT] = ACTIONS(3720),
    [anon_sym_Xmlport] = ACTIONS(3720),
    [anon_sym_XMLport] = ACTIONS(3720),
    [anon_sym_XMLPort] = ACTIONS(3720),
    [anon_sym_XmlPort] = ACTIONS(3720),
    [anon_sym_enum] = ACTIONS(3720),
    [anon_sym_ENUM] = ACTIONS(3720),
    [anon_sym_Enum] = ACTIONS(3720),
    [anon_sym_eNUM] = ACTIONS(3720),
    [anon_sym_eNum] = ACTIONS(3720),
    [anon_sym_ENum] = ACTIONS(3720),
    [sym_quoted_identifier] = ACTIONS(3723),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3723),
    [sym_verbatim_string] = ACTIONS(3723),
    [sym_integer] = ACTIONS(3720),
    [sym_continue_as_identifier] = ACTIONS(3723),
    [sym_preproc_open] = ACTIONS(3723),
  },
  [STATE(3551)] = {
    [sym_identifier] = ACTIONS(3752),
    [anon_sym_SEMI] = ACTIONS(3754),
    [anon_sym_DOT] = ACTIONS(3752),
    [anon_sym_EQ] = ACTIONS(3754),
    [anon_sym_COMMA] = ACTIONS(3754),
    [anon_sym_COLON] = ACTIONS(3752),
    [anon_sym_DASH] = ACTIONS(3752),
    [aux_sym_boolean_token1] = ACTIONS(3752),
    [aux_sym_boolean_token2] = ACTIONS(3752),
    [sym_decimal] = ACTIONS(3752),
    [anon_sym_LPAREN] = ACTIONS(3754),
    [anon_sym_DOT_DOT] = ACTIONS(3754),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3752),
    [anon_sym_STAR] = ACTIONS(3752),
    [anon_sym_LBRACK] = ACTIONS(3754),
    [aux_sym_record_type_token1] = ACTIONS(3752),
    [aux_sym_basic_type_token21] = ACTIONS(3752),
    [aux_sym_basic_type_token22] = ACTIONS(3752),
    [aux_sym_basic_type_token48] = ACTIONS(3752),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3752),
    [anon_sym_POUNDif] = ACTIONS(3754),
    [anon_sym_POUNDIF] = ACTIONS(3754),
    [anon_sym_POUNDIf] = ACTIONS(3754),
    [anon_sym_not] = ACTIONS(3752),
    [anon_sym_NOT] = ACTIONS(3752),
    [anon_sym_Not] = ACTIONS(3752),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3754),
    [aux_sym__expression_token1] = ACTIONS(3754),
    [aux_sym__expression_token2] = ACTIONS(3754),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3752),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3752),
    [anon_sym_SLASH] = ACTIONS(3752),
    [anon_sym_div] = ACTIONS(3752),
    [anon_sym_DIV] = ACTIONS(3752),
    [anon_sym_Div] = ACTIONS(3752),
    [anon_sym_mod] = ACTIONS(3752),
    [anon_sym_MOD] = ACTIONS(3752),
    [anon_sym_Mod] = ACTIONS(3752),
    [anon_sym_PLUS] = ACTIONS(3752),
    [anon_sym_GT_EQ] = ACTIONS(3754),
    [anon_sym_LT_EQ] = ACTIONS(3754),
    [anon_sym_GT] = ACTIONS(3752),
    [anon_sym_LT] = ACTIONS(3752),
    [anon_sym_LT_GT] = ACTIONS(3754),
    [anon_sym_and] = ACTIONS(3752),
    [anon_sym_AND] = ACTIONS(3752),
    [anon_sym_And] = ACTIONS(3752),
    [anon_sym_or] = ACTIONS(3752),
    [anon_sym_OR] = ACTIONS(3752),
    [anon_sym_Or] = ACTIONS(3752),
    [anon_sym_xor] = ACTIONS(3752),
    [anon_sym_XOR] = ACTIONS(3752),
    [anon_sym_Xor] = ACTIONS(3752),
    [anon_sym_QMARK] = ACTIONS(3754),
    [sym_datetime_literal] = ACTIONS(3754),
    [sym_date_literal] = ACTIONS(3752),
    [sym_time_literal] = ACTIONS(3752),
    [sym_biginteger_literal] = ACTIONS(3754),
    [anon_sym_else] = ACTIONS(3752),
    [anon_sym_ELSE] = ACTIONS(3752),
    [anon_sym_Else] = ACTIONS(3752),
    [anon_sym_in] = ACTIONS(3752),
    [anon_sym_IN] = ACTIONS(3752),
    [anon_sym_In] = ACTIONS(3752),
    [sym_page_keyword] = ACTIONS(3752),
    [anon_sym_codeunit] = ACTIONS(3752),
    [anon_sym_CODEUNIT] = ACTIONS(3752),
    [anon_sym_Codeunit] = ACTIONS(3752),
    [anon_sym_CodeUnit] = ACTIONS(3752),
    [anon_sym_COdeunit] = ACTIONS(3752),
    [anon_sym_codeUnit] = ACTIONS(3752),
    [sym_report_keyword] = ACTIONS(3752),
    [sym_query_keyword] = ACTIONS(3752),
    [anon_sym_xmlport] = ACTIONS(3752),
    [anon_sym_XMLPORT] = ACTIONS(3752),
    [anon_sym_Xmlport] = ACTIONS(3752),
    [anon_sym_XMLport] = ACTIONS(3752),
    [anon_sym_XMLPort] = ACTIONS(3752),
    [anon_sym_XmlPort] = ACTIONS(3752),
    [anon_sym_enum] = ACTIONS(3752),
    [anon_sym_ENUM] = ACTIONS(3752),
    [anon_sym_Enum] = ACTIONS(3752),
    [anon_sym_eNUM] = ACTIONS(3752),
    [anon_sym_eNum] = ACTIONS(3752),
    [anon_sym_ENum] = ACTIONS(3752),
    [sym_quoted_identifier] = ACTIONS(3754),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3754),
    [sym_verbatim_string] = ACTIONS(3754),
    [sym_integer] = ACTIONS(3752),
    [sym_continue_as_identifier] = ACTIONS(3754),
    [sym_preproc_open] = ACTIONS(3754),
  },
  [STATE(3552)] = {
    [sym_identifier] = ACTIONS(3941),
    [anon_sym_SEMI] = ACTIONS(3943),
    [anon_sym_DOT] = ACTIONS(3941),
    [anon_sym_EQ] = ACTIONS(3943),
    [anon_sym_COMMA] = ACTIONS(3943),
    [anon_sym_COLON] = ACTIONS(3941),
    [anon_sym_DASH] = ACTIONS(3941),
    [aux_sym_boolean_token1] = ACTIONS(3941),
    [aux_sym_boolean_token2] = ACTIONS(3941),
    [sym_decimal] = ACTIONS(3941),
    [anon_sym_LPAREN] = ACTIONS(3943),
    [anon_sym_DOT_DOT] = ACTIONS(3943),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3941),
    [anon_sym_STAR] = ACTIONS(3941),
    [anon_sym_LBRACK] = ACTIONS(3943),
    [aux_sym_record_type_token1] = ACTIONS(3941),
    [aux_sym_basic_type_token21] = ACTIONS(3941),
    [aux_sym_basic_type_token22] = ACTIONS(3941),
    [aux_sym_basic_type_token48] = ACTIONS(3941),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3941),
    [anon_sym_POUNDif] = ACTIONS(3943),
    [anon_sym_POUNDIF] = ACTIONS(3943),
    [anon_sym_POUNDIf] = ACTIONS(3943),
    [anon_sym_not] = ACTIONS(3941),
    [anon_sym_NOT] = ACTIONS(3941),
    [anon_sym_Not] = ACTIONS(3941),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3943),
    [aux_sym__expression_token1] = ACTIONS(3943),
    [aux_sym__expression_token2] = ACTIONS(3943),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3941),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3941),
    [anon_sym_SLASH] = ACTIONS(3941),
    [anon_sym_div] = ACTIONS(3941),
    [anon_sym_DIV] = ACTIONS(3941),
    [anon_sym_Div] = ACTIONS(3941),
    [anon_sym_mod] = ACTIONS(3941),
    [anon_sym_MOD] = ACTIONS(3941),
    [anon_sym_Mod] = ACTIONS(3941),
    [anon_sym_PLUS] = ACTIONS(3941),
    [anon_sym_GT_EQ] = ACTIONS(3943),
    [anon_sym_LT_EQ] = ACTIONS(3943),
    [anon_sym_GT] = ACTIONS(3941),
    [anon_sym_LT] = ACTIONS(3941),
    [anon_sym_LT_GT] = ACTIONS(3943),
    [anon_sym_and] = ACTIONS(3941),
    [anon_sym_AND] = ACTIONS(3941),
    [anon_sym_And] = ACTIONS(3941),
    [anon_sym_or] = ACTIONS(3941),
    [anon_sym_OR] = ACTIONS(3941),
    [anon_sym_Or] = ACTIONS(3941),
    [anon_sym_xor] = ACTIONS(3941),
    [anon_sym_XOR] = ACTIONS(3941),
    [anon_sym_Xor] = ACTIONS(3941),
    [anon_sym_QMARK] = ACTIONS(3943),
    [sym_datetime_literal] = ACTIONS(3943),
    [sym_date_literal] = ACTIONS(3941),
    [sym_time_literal] = ACTIONS(3941),
    [sym_biginteger_literal] = ACTIONS(3943),
    [anon_sym_else] = ACTIONS(3941),
    [anon_sym_ELSE] = ACTIONS(3941),
    [anon_sym_Else] = ACTIONS(3941),
    [anon_sym_in] = ACTIONS(3941),
    [anon_sym_IN] = ACTIONS(3941),
    [anon_sym_In] = ACTIONS(3941),
    [sym_page_keyword] = ACTIONS(3941),
    [anon_sym_codeunit] = ACTIONS(3941),
    [anon_sym_CODEUNIT] = ACTIONS(3941),
    [anon_sym_Codeunit] = ACTIONS(3941),
    [anon_sym_CodeUnit] = ACTIONS(3941),
    [anon_sym_COdeunit] = ACTIONS(3941),
    [anon_sym_codeUnit] = ACTIONS(3941),
    [sym_report_keyword] = ACTIONS(3941),
    [sym_query_keyword] = ACTIONS(3941),
    [anon_sym_xmlport] = ACTIONS(3941),
    [anon_sym_XMLPORT] = ACTIONS(3941),
    [anon_sym_Xmlport] = ACTIONS(3941),
    [anon_sym_XMLport] = ACTIONS(3941),
    [anon_sym_XMLPort] = ACTIONS(3941),
    [anon_sym_XmlPort] = ACTIONS(3941),
    [anon_sym_enum] = ACTIONS(3941),
    [anon_sym_ENUM] = ACTIONS(3941),
    [anon_sym_Enum] = ACTIONS(3941),
    [anon_sym_eNUM] = ACTIONS(3941),
    [anon_sym_eNum] = ACTIONS(3941),
    [anon_sym_ENum] = ACTIONS(3941),
    [sym_quoted_identifier] = ACTIONS(3943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3943),
    [sym_verbatim_string] = ACTIONS(3943),
    [sym_integer] = ACTIONS(3941),
    [sym_continue_as_identifier] = ACTIONS(3943),
    [sym_preproc_open] = ACTIONS(3943),
  },
  [STATE(3553)] = {
    [sym_identifier] = ACTIONS(3909),
    [anon_sym_SEMI] = ACTIONS(3911),
    [anon_sym_DOT] = ACTIONS(3909),
    [anon_sym_EQ] = ACTIONS(3911),
    [anon_sym_COMMA] = ACTIONS(3911),
    [anon_sym_COLON] = ACTIONS(3909),
    [anon_sym_DASH] = ACTIONS(3909),
    [aux_sym_boolean_token1] = ACTIONS(3909),
    [aux_sym_boolean_token2] = ACTIONS(3909),
    [sym_decimal] = ACTIONS(3909),
    [anon_sym_LPAREN] = ACTIONS(3911),
    [anon_sym_DOT_DOT] = ACTIONS(3911),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3909),
    [anon_sym_STAR] = ACTIONS(3909),
    [anon_sym_LBRACK] = ACTIONS(3911),
    [aux_sym_record_type_token1] = ACTIONS(3909),
    [aux_sym_basic_type_token21] = ACTIONS(3909),
    [aux_sym_basic_type_token22] = ACTIONS(3909),
    [aux_sym_basic_type_token48] = ACTIONS(3909),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(3909),
    [anon_sym_POUNDif] = ACTIONS(3911),
    [anon_sym_POUNDIF] = ACTIONS(3911),
    [anon_sym_POUNDIf] = ACTIONS(3911),
    [anon_sym_not] = ACTIONS(3909),
    [anon_sym_NOT] = ACTIONS(3909),
    [anon_sym_Not] = ACTIONS(3909),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3911),
    [aux_sym__expression_token1] = ACTIONS(3911),
    [aux_sym__expression_token2] = ACTIONS(3911),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3909),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3909),
    [anon_sym_SLASH] = ACTIONS(3909),
    [anon_sym_div] = ACTIONS(3909),
    [anon_sym_DIV] = ACTIONS(3909),
    [anon_sym_Div] = ACTIONS(3909),
    [anon_sym_mod] = ACTIONS(3909),
    [anon_sym_MOD] = ACTIONS(3909),
    [anon_sym_Mod] = ACTIONS(3909),
    [anon_sym_PLUS] = ACTIONS(3909),
    [anon_sym_GT_EQ] = ACTIONS(3911),
    [anon_sym_LT_EQ] = ACTIONS(3911),
    [anon_sym_GT] = ACTIONS(3909),
    [anon_sym_LT] = ACTIONS(3909),
    [anon_sym_LT_GT] = ACTIONS(3911),
    [anon_sym_and] = ACTIONS(3909),
    [anon_sym_AND] = ACTIONS(3909),
    [anon_sym_And] = ACTIONS(3909),
    [anon_sym_or] = ACTIONS(3909),
    [anon_sym_OR] = ACTIONS(3909),
    [anon_sym_Or] = ACTIONS(3909),
    [anon_sym_xor] = ACTIONS(3909),
    [anon_sym_XOR] = ACTIONS(3909),
    [anon_sym_Xor] = ACTIONS(3909),
    [anon_sym_QMARK] = ACTIONS(3911),
    [sym_datetime_literal] = ACTIONS(3911),
    [sym_date_literal] = ACTIONS(3909),
    [sym_time_literal] = ACTIONS(3909),
    [sym_biginteger_literal] = ACTIONS(3911),
    [anon_sym_else] = ACTIONS(3909),
    [anon_sym_ELSE] = ACTIONS(3909),
    [anon_sym_Else] = ACTIONS(3909),
    [anon_sym_in] = ACTIONS(3909),
    [anon_sym_IN] = ACTIONS(3909),
    [anon_sym_In] = ACTIONS(3909),
    [sym_page_keyword] = ACTIONS(3909),
    [anon_sym_codeunit] = ACTIONS(3909),
    [anon_sym_CODEUNIT] = ACTIONS(3909),
    [anon_sym_Codeunit] = ACTIONS(3909),
    [anon_sym_CodeUnit] = ACTIONS(3909),
    [anon_sym_COdeunit] = ACTIONS(3909),
    [anon_sym_codeUnit] = ACTIONS(3909),
    [sym_report_keyword] = ACTIONS(3909),
    [sym_query_keyword] = ACTIONS(3909),
    [anon_sym_xmlport] = ACTIONS(3909),
    [anon_sym_XMLPORT] = ACTIONS(3909),
    [anon_sym_Xmlport] = ACTIONS(3909),
    [anon_sym_XMLport] = ACTIONS(3909),
    [anon_sym_XMLPort] = ACTIONS(3909),
    [anon_sym_XmlPort] = ACTIONS(3909),
    [anon_sym_enum] = ACTIONS(3909),
    [anon_sym_ENUM] = ACTIONS(3909),
    [anon_sym_Enum] = ACTIONS(3909),
    [anon_sym_eNUM] = ACTIONS(3909),
    [anon_sym_eNum] = ACTIONS(3909),
    [anon_sym_ENum] = ACTIONS(3909),
    [sym_quoted_identifier] = ACTIONS(3911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3911),
    [sym_verbatim_string] = ACTIONS(3911),
    [sym_integer] = ACTIONS(3909),
    [sym_continue_as_identifier] = ACTIONS(3911),
    [sym_preproc_open] = ACTIONS(3911),
  },
  [STATE(3554)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7610),
    [anon_sym_SEMI] = ACTIONS(7613),
    [aux_sym_where_condition_token1] = ACTIONS(7616),
    [anon_sym_LBRACK] = ACTIONS(7619),
    [aux_sym_basic_type_token22] = ACTIONS(7616),
    [aux_sym_basic_type_token53] = ACTIONS(7616),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7622),
    [aux_sym_modify_modification_token1] = ACTIONS(7625),
    [aux_sym_separator_action_token1] = ACTIONS(7616),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7628),
    [aux_sym_type_declaration_token1] = ACTIONS(7616),
    [anon_sym_POUNDif] = ACTIONS(7631),
    [anon_sym_POUNDIF] = ACTIONS(7631),
    [anon_sym_POUNDIf] = ACTIONS(7631),
    [anon_sym_POUNDelif] = ACTIONS(7634),
    [anon_sym_POUNDELIF] = ACTIONS(7634),
    [anon_sym_POUNDElif] = ACTIONS(7634),
    [anon_sym_POUNDelse] = ACTIONS(7634),
    [anon_sym_POUNDELSE] = ACTIONS(7634),
    [anon_sym_POUNDElse] = ACTIONS(7634),
    [anon_sym_POUNDelse2] = ACTIONS(7634),
    [anon_sym_POUNDELSE2] = ACTIONS(7634),
    [anon_sym_POUNDElse2] = ACTIONS(7634),
    [anon_sym_POUNDendif] = ACTIONS(7634),
    [anon_sym_POUNDENDIF] = ACTIONS(7634),
    [anon_sym_POUNDEndif] = ACTIONS(7634),
    [anon_sym_POUNDendif2] = ACTIONS(7634),
    [anon_sym_POUNDENDIF2] = ACTIONS(7634),
    [anon_sym_POUNDEndif2] = ACTIONS(7634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7616),
    [sym_procedure_keyword] = ACTIONS(7636),
    [sym_trigger_keyword] = ACTIONS(7639),
    [sym_var_keyword] = ACTIONS(7642),
    [sym_local_keyword] = ACTIONS(7645),
    [sym_internal_keyword] = ACTIONS(7648),
    [sym_protected_keyword] = ACTIONS(7645),
    [sym_event_keyword] = ACTIONS(7651),
    [sym_fields_keyword] = ACTIONS(7654),
    [sym_keys_keyword] = ACTIONS(7657),
    [sym_key_keyword] = ACTIONS(7616),
    [sym_fieldgroups_keyword] = ACTIONS(7660),
    [sym_actions_keyword] = ACTIONS(7663),
    [sym_layout_keyword] = ACTIONS(7666),
    [sym_dataset_keyword] = ACTIONS(7669),
    [sym_elements_keyword] = ACTIONS(7672),
    [sym_labels_keyword] = ACTIONS(7675),
    [sym_rendering_keyword] = ACTIONS(7678),
    [sym_requestpage_keyword] = ACTIONS(7681),
    [sym_schema_keyword] = ACTIONS(7684),
    [sym_views_keyword] = ACTIONS(7687),
    [sym_quoted_identifier] = ACTIONS(7690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7693),
    [sym_preproc_open] = ACTIONS(7631),
    [sym_preproc_close] = ACTIONS(7634),
    [sym_var_attribute_open] = ACTIONS(7696),
  },
  [STATE(3555)] = {
    [sym_identifier] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(6589),
    [anon_sym_EQ] = ACTIONS(6591),
    [anon_sym_DASH] = ACTIONS(6589),
    [aux_sym_where_clause_token1] = ACTIONS(3695),
    [aux_sym_where_condition_token1] = ACTIONS(3693),
    [anon_sym_DOT_DOT] = ACTIONS(6591),
    [anon_sym_STAR] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(6593),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_basic_type_token53] = ACTIONS(3693),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3693),
    [aux_sym_modify_modification_token1] = ACTIONS(3693),
    [aux_sym_separator_action_token1] = ACTIONS(3693),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3693),
    [aux_sym_type_declaration_token1] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_POUNDelif] = ACTIONS(3695),
    [anon_sym_POUNDELIF] = ACTIONS(3695),
    [anon_sym_POUNDElif] = ACTIONS(3695),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [anon_sym_POUNDendif] = ACTIONS(3695),
    [anon_sym_POUNDENDIF] = ACTIONS(3695),
    [anon_sym_POUNDEndif] = ACTIONS(3695),
    [anon_sym_POUNDendif2] = ACTIONS(3695),
    [anon_sym_POUNDENDIF2] = ACTIONS(3695),
    [anon_sym_POUNDEndif2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6591),
    [aux_sym__expression_token1] = ACTIONS(6591),
    [aux_sym__expression_token2] = ACTIONS(6591),
    [anon_sym_SLASH] = ACTIONS(6589),
    [anon_sym_div] = ACTIONS(6589),
    [anon_sym_DIV] = ACTIONS(6589),
    [anon_sym_Div] = ACTIONS(6589),
    [anon_sym_mod] = ACTIONS(6589),
    [anon_sym_MOD] = ACTIONS(6589),
    [anon_sym_Mod] = ACTIONS(6589),
    [anon_sym_PLUS] = ACTIONS(6589),
    [anon_sym_GT_EQ] = ACTIONS(6591),
    [anon_sym_LT_EQ] = ACTIONS(6591),
    [anon_sym_GT] = ACTIONS(6589),
    [anon_sym_LT] = ACTIONS(6589),
    [anon_sym_LT_GT] = ACTIONS(6591),
    [anon_sym_and] = ACTIONS(6589),
    [anon_sym_AND] = ACTIONS(6589),
    [anon_sym_And] = ACTIONS(6589),
    [anon_sym_or] = ACTIONS(6589),
    [anon_sym_OR] = ACTIONS(6589),
    [anon_sym_Or] = ACTIONS(6589),
    [anon_sym_xor] = ACTIONS(6589),
    [anon_sym_XOR] = ACTIONS(6589),
    [anon_sym_Xor] = ACTIONS(6589),
    [anon_sym_QMARK] = ACTIONS(6591),
    [anon_sym_in] = ACTIONS(6589),
    [anon_sym_IN] = ACTIONS(6589),
    [anon_sym_In] = ACTIONS(6589),
    [sym_table_keyword] = ACTIONS(3693),
    [sym_procedure_keyword] = ACTIONS(3693),
    [sym_trigger_keyword] = ACTIONS(3693),
    [sym_var_keyword] = ACTIONS(3693),
    [sym_local_keyword] = ACTIONS(3693),
    [sym_internal_keyword] = ACTIONS(3693),
    [sym_protected_keyword] = ACTIONS(3693),
    [sym_event_keyword] = ACTIONS(3693),
    [sym_fields_keyword] = ACTIONS(3693),
    [sym_keys_keyword] = ACTIONS(3693),
    [sym_key_keyword] = ACTIONS(3693),
    [sym_fieldgroups_keyword] = ACTIONS(3693),
    [sym_actions_keyword] = ACTIONS(3693),
    [sym_layout_keyword] = ACTIONS(3693),
    [sym_dataset_keyword] = ACTIONS(3693),
    [sym_elements_keyword] = ACTIONS(3693),
    [sym_labels_keyword] = ACTIONS(3693),
    [sym_rendering_keyword] = ACTIONS(3693),
    [sym_requestpage_keyword] = ACTIONS(3693),
    [sym_schema_keyword] = ACTIONS(3693),
    [sym_views_keyword] = ACTIONS(3693),
    [sym_quoted_identifier] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
    [sym_preproc_close] = ACTIONS(3695),
    [sym_var_attribute_open] = ACTIONS(3695),
  },
  [STATE(3556)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7699),
    [anon_sym_POUNDELIF] = ACTIONS(7699),
    [anon_sym_POUNDElif] = ACTIONS(7699),
    [anon_sym_POUNDelse] = ACTIONS(7699),
    [anon_sym_POUNDELSE] = ACTIONS(7699),
    [anon_sym_POUNDElse] = ACTIONS(7699),
    [anon_sym_POUNDelse2] = ACTIONS(7699),
    [anon_sym_POUNDELSE2] = ACTIONS(7699),
    [anon_sym_POUNDElse2] = ACTIONS(7699),
    [anon_sym_POUNDendif] = ACTIONS(7699),
    [anon_sym_POUNDENDIF] = ACTIONS(7699),
    [anon_sym_POUNDEndif] = ACTIONS(7699),
    [anon_sym_POUNDendif2] = ACTIONS(7699),
    [anon_sym_POUNDENDIF2] = ACTIONS(7699),
    [anon_sym_POUNDEndif2] = ACTIONS(7699),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7699),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3557)] = {
    [sym__body_element] = STATE(3556),
    [sym_empty_statement] = STATE(3556),
    [sym_property] = STATE(3556),
    [sym_permissions_property] = STATE(3556),
    [sym_table_relation_property] = STATE(3556),
    [sym_fields_section] = STATE(3556),
    [sym_keys_section] = STATE(3556),
    [sym_fieldgroups_section] = STATE(3556),
    [sym_enum_value_declaration] = STATE(3556),
    [sym_labels_section] = STATE(3556),
    [sym_layout_section] = STATE(3556),
    [sym_modify_modification] = STATE(3556),
    [sym_actions_section] = STATE(3556),
    [sym_views_section] = STATE(3556),
    [sym_dataset_section] = STATE(3556),
    [sym_requestpage_section] = STATE(3556),
    [sym_rendering_section] = STATE(3556),
    [sym_elements_section] = STATE(3556),
    [sym_schema_section] = STATE(3556),
    [sym_assembly_declaration] = STATE(3556),
    [sym_event_declaration] = STATE(3556),
    [sym_procedure] = STATE(3556),
    [sym_preproc_split_procedure] = STATE(3556),
    [sym_preproc_split_procedure_preamble] = STATE(3556),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3556),
    [sym_var_section] = STATE(3556),
    [sym_var_attribute_item] = STATE(3556),
    [sym_variable_declaration] = STATE(3556),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3556),
    [sym_preproc_if] = STATE(3656),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3556),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(7701),
    [anon_sym_POUNDELIF] = ACTIONS(7701),
    [anon_sym_POUNDElif] = ACTIONS(7701),
    [anon_sym_POUNDelse] = ACTIONS(7701),
    [anon_sym_POUNDELSE] = ACTIONS(7701),
    [anon_sym_POUNDElse] = ACTIONS(7701),
    [anon_sym_POUNDelse2] = ACTIONS(7701),
    [anon_sym_POUNDELSE2] = ACTIONS(7701),
    [anon_sym_POUNDElse2] = ACTIONS(7701),
    [anon_sym_POUNDendif] = ACTIONS(7701),
    [anon_sym_POUNDENDIF] = ACTIONS(7701),
    [anon_sym_POUNDEndif] = ACTIONS(7701),
    [anon_sym_POUNDendif2] = ACTIONS(7701),
    [anon_sym_POUNDENDIF2] = ACTIONS(7701),
    [anon_sym_POUNDEndif2] = ACTIONS(7701),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7701),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3558)] = {
    [aux_sym_option_member_list_repeat2] = STATE(3558),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(7703),
    [anon_sym_DASH] = ACTIONS(838),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_modify_modification_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [anon_sym_POUNDelif] = ACTIONS(838),
    [anon_sym_POUNDELIF] = ACTIONS(838),
    [anon_sym_POUNDElif] = ACTIONS(838),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [anon_sym_POUNDendif] = ACTIONS(838),
    [anon_sym_POUNDENDIF] = ACTIONS(838),
    [anon_sym_POUNDEndif] = ACTIONS(838),
    [anon_sym_POUNDendif2] = ACTIONS(838),
    [anon_sym_POUNDENDIF2] = ACTIONS(838),
    [anon_sym_POUNDEndif2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_procedure_keyword] = ACTIONS(836),
    [sym_trigger_keyword] = ACTIONS(836),
    [sym_var_keyword] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_event_keyword] = ACTIONS(836),
    [sym_fields_keyword] = ACTIONS(836),
    [sym_keys_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_fieldgroups_keyword] = ACTIONS(836),
    [sym_actions_keyword] = ACTIONS(836),
    [sym_layout_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_elements_keyword] = ACTIONS(836),
    [sym_labels_keyword] = ACTIONS(836),
    [sym_rendering_keyword] = ACTIONS(836),
    [sym_requestpage_keyword] = ACTIONS(836),
    [sym_schema_keyword] = ACTIONS(836),
    [sym_views_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(838),
    [sym_property_name] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
    [sym_preproc_close] = ACTIONS(838),
    [sym_begin_keyword] = ACTIONS(838),
  },
  [STATE(3559)] = {
    [sym_where_clause] = STATE(7273),
    [sym_argument_list] = STATE(7165),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(7706),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5386),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5386),
    [aux_sym_modify_modification_token1] = ACTIONS(5386),
    [aux_sym_xmlport_element_token1] = ACTIONS(5386),
    [aux_sym_xmlport_element_token2] = ACTIONS(5386),
    [aux_sym_xmlport_element_token3] = ACTIONS(5386),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5386),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5386),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5392),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5386),
    [anon_sym_POUNDIF] = ACTIONS(5386),
    [anon_sym_POUNDIf] = ACTIONS(5386),
    [anon_sym_POUNDelif] = ACTIONS(5386),
    [anon_sym_POUNDELIF] = ACTIONS(5386),
    [anon_sym_POUNDElif] = ACTIONS(5386),
    [anon_sym_POUNDelse] = ACTIONS(5386),
    [anon_sym_POUNDELSE] = ACTIONS(5386),
    [anon_sym_POUNDElse] = ACTIONS(5386),
    [anon_sym_POUNDelse2] = ACTIONS(5386),
    [anon_sym_POUNDELSE2] = ACTIONS(5386),
    [anon_sym_POUNDElse2] = ACTIONS(5386),
    [anon_sym_POUNDendif] = ACTIONS(5386),
    [anon_sym_POUNDENDIF] = ACTIONS(5386),
    [anon_sym_POUNDEndif] = ACTIONS(5386),
    [anon_sym_POUNDendif2] = ACTIONS(5386),
    [anon_sym_POUNDENDIF2] = ACTIONS(5386),
    [anon_sym_POUNDEndif2] = ACTIONS(5386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5386),
    [sym_trigger_keyword] = ACTIONS(5386),
    [sym_var_keyword] = ACTIONS(5386),
    [sym_local_keyword] = ACTIONS(5386),
    [sym_internal_keyword] = ACTIONS(5386),
    [sym_protected_keyword] = ACTIONS(5386),
    [sym_event_keyword] = ACTIONS(5386),
    [sym_fields_keyword] = ACTIONS(5386),
    [sym_keys_keyword] = ACTIONS(5386),
    [sym_fieldgroups_keyword] = ACTIONS(5386),
    [sym_actions_keyword] = ACTIONS(5386),
    [sym_layout_keyword] = ACTIONS(5386),
    [sym_dataset_keyword] = ACTIONS(5386),
    [sym_elements_keyword] = ACTIONS(5386),
    [sym_labels_keyword] = ACTIONS(5386),
    [sym_rendering_keyword] = ACTIONS(5386),
    [sym_requestpage_keyword] = ACTIONS(5386),
    [sym_schema_keyword] = ACTIONS(5386),
    [sym_views_keyword] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5386),
    [sym_preproc_open] = ACTIONS(5386),
    [sym_preproc_close] = ACTIONS(5386),
  },
  [STATE(3560)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3566),
    [sym_case_branch] = STATE(3566),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3566),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(17875),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(297),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3566),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7708),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(3561)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3600),
    [sym_case_branch] = STATE(3600),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3600),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(17439),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(297),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3600),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7710),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(3562)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5279),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token6] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_addafter_modification_token1] = ACTIONS(5279),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5279),
    [aux_sym_movelast_modification_token1] = ACTIONS(5279),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5279),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_area_keyword] = ACTIONS(5279),
    [sym_group_keyword] = ACTIONS(5279),
    [sym_repeater_keyword] = ACTIONS(5279),
    [sym_cuegroup_keyword] = ACTIONS(5279),
    [sym_fixed_keyword] = ACTIONS(5279),
    [sym_grid_keyword] = ACTIONS(5279),
    [sym_part_keyword] = ACTIONS(5279),
    [sym_systempart_keyword] = ACTIONS(5279),
    [sym_usercontrol_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
  },
  [STATE(3563)] = {
    [sym_argument_list] = STATE(7165),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5405),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5405),
    [aux_sym_modify_modification_token1] = ACTIONS(5405),
    [aux_sym_xmlport_element_token1] = ACTIONS(5405),
    [aux_sym_xmlport_element_token2] = ACTIONS(5405),
    [aux_sym_xmlport_element_token3] = ACTIONS(5405),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5405),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [anon_sym_POUNDelif] = ACTIONS(5405),
    [anon_sym_POUNDELIF] = ACTIONS(5405),
    [anon_sym_POUNDElif] = ACTIONS(5405),
    [anon_sym_POUNDelse] = ACTIONS(5405),
    [anon_sym_POUNDELSE] = ACTIONS(5405),
    [anon_sym_POUNDElse] = ACTIONS(5405),
    [anon_sym_POUNDelse2] = ACTIONS(5405),
    [anon_sym_POUNDELSE2] = ACTIONS(5405),
    [anon_sym_POUNDElse2] = ACTIONS(5405),
    [anon_sym_POUNDendif] = ACTIONS(5405),
    [anon_sym_POUNDENDIF] = ACTIONS(5405),
    [anon_sym_POUNDEndif] = ACTIONS(5405),
    [anon_sym_POUNDendif2] = ACTIONS(5405),
    [anon_sym_POUNDENDIF2] = ACTIONS(5405),
    [anon_sym_POUNDEndif2] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5405),
    [sym_trigger_keyword] = ACTIONS(5405),
    [sym_var_keyword] = ACTIONS(5405),
    [sym_local_keyword] = ACTIONS(5405),
    [sym_internal_keyword] = ACTIONS(5405),
    [sym_protected_keyword] = ACTIONS(5405),
    [sym_event_keyword] = ACTIONS(5405),
    [sym_fields_keyword] = ACTIONS(5405),
    [sym_keys_keyword] = ACTIONS(5405),
    [sym_fieldgroups_keyword] = ACTIONS(5405),
    [sym_actions_keyword] = ACTIONS(5405),
    [sym_layout_keyword] = ACTIONS(5405),
    [sym_dataset_keyword] = ACTIONS(5405),
    [sym_elements_keyword] = ACTIONS(5405),
    [sym_labels_keyword] = ACTIONS(5405),
    [sym_rendering_keyword] = ACTIONS(5405),
    [sym_requestpage_keyword] = ACTIONS(5405),
    [sym_schema_keyword] = ACTIONS(5405),
    [sym_views_keyword] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
    [sym_preproc_close] = ACTIONS(5405),
  },
  [STATE(3564)] = {
    [sym_identifier] = ACTIONS(7712),
    [anon_sym_SEMI] = ACTIONS(7715),
    [aux_sym_where_condition_token1] = ACTIONS(7720),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7727),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7727),
    [anon_sym_LBRACK] = ACTIONS(7730),
    [aux_sym_basic_type_token6] = ACTIONS(7727),
    [aux_sym_basic_type_token22] = ACTIONS(7712),
    [aux_sym_basic_type_token53] = ACTIONS(7712),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7720),
    [aux_sym_addafter_modification_token1] = ACTIONS(7727),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7727),
    [aux_sym_modify_modification_token1] = ACTIONS(7727),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7727),
    [aux_sym_movelast_modification_token1] = ACTIONS(7727),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7727),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7727),
    [aux_sym_separator_action_token1] = ACTIONS(7712),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7720),
    [aux_sym_type_declaration_token1] = ACTIONS(7712),
    [anon_sym_POUNDif] = ACTIONS(7715),
    [anon_sym_POUNDIF] = ACTIONS(7715),
    [anon_sym_POUNDIf] = ACTIONS(7715),
    [anon_sym_POUNDelif] = ACTIONS(7730),
    [anon_sym_POUNDELIF] = ACTIONS(7730),
    [anon_sym_POUNDElif] = ACTIONS(7730),
    [anon_sym_POUNDelse] = ACTIONS(7730),
    [anon_sym_POUNDELSE] = ACTIONS(7730),
    [anon_sym_POUNDElse] = ACTIONS(7730),
    [anon_sym_POUNDelse2] = ACTIONS(7730),
    [anon_sym_POUNDELSE2] = ACTIONS(7730),
    [anon_sym_POUNDElse2] = ACTIONS(7730),
    [anon_sym_POUNDendif] = ACTIONS(7730),
    [anon_sym_POUNDENDIF] = ACTIONS(7730),
    [anon_sym_POUNDEndif] = ACTIONS(7730),
    [anon_sym_POUNDendif2] = ACTIONS(7730),
    [anon_sym_POUNDENDIF2] = ACTIONS(7730),
    [anon_sym_POUNDEndif2] = ACTIONS(7730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7733),
    [sym_page_keyword] = ACTIONS(7725),
    [anon_sym_codeunit] = ACTIONS(7725),
    [anon_sym_CODEUNIT] = ACTIONS(7725),
    [anon_sym_Codeunit] = ACTIONS(7725),
    [anon_sym_CodeUnit] = ACTIONS(7725),
    [anon_sym_COdeunit] = ACTIONS(7725),
    [anon_sym_codeUnit] = ACTIONS(7725),
    [sym_report_keyword] = ACTIONS(7725),
    [sym_query_keyword] = ACTIONS(7725),
    [anon_sym_xmlport] = ACTIONS(7725),
    [anon_sym_XMLPORT] = ACTIONS(7725),
    [anon_sym_Xmlport] = ACTIONS(7725),
    [anon_sym_XMLport] = ACTIONS(7725),
    [anon_sym_XMLPort] = ACTIONS(7725),
    [anon_sym_XmlPort] = ACTIONS(7725),
    [sym_procedure_keyword] = ACTIONS(7727),
    [sym_trigger_keyword] = ACTIONS(7727),
    [sym_var_keyword] = ACTIONS(7727),
    [sym_local_keyword] = ACTIONS(7727),
    [sym_internal_keyword] = ACTIONS(7727),
    [sym_protected_keyword] = ACTIONS(7727),
    [sym_event_keyword] = ACTIONS(7727),
    [sym_fields_keyword] = ACTIONS(7727),
    [sym_keys_keyword] = ACTIONS(7727),
    [sym_key_keyword] = ACTIONS(7712),
    [sym_fieldgroups_keyword] = ACTIONS(7727),
    [sym_actions_keyword] = ACTIONS(7727),
    [sym_layout_keyword] = ACTIONS(7727),
    [sym_area_keyword] = ACTIONS(7727),
    [sym_group_keyword] = ACTIONS(7727),
    [sym_repeater_keyword] = ACTIONS(7727),
    [sym_cuegroup_keyword] = ACTIONS(7727),
    [sym_fixed_keyword] = ACTIONS(7727),
    [sym_grid_keyword] = ACTIONS(7727),
    [sym_part_keyword] = ACTIONS(7727),
    [sym_systempart_keyword] = ACTIONS(7727),
    [sym_usercontrol_keyword] = ACTIONS(7727),
    [sym_dataset_keyword] = ACTIONS(7720),
    [sym_elements_keyword] = ACTIONS(7727),
    [sym_labels_keyword] = ACTIONS(7727),
    [sym_rendering_keyword] = ACTIONS(7727),
    [sym_requestpage_keyword] = ACTIONS(7727),
    [sym_schema_keyword] = ACTIONS(7727),
    [sym_views_keyword] = ACTIONS(7727),
    [sym_quoted_identifier] = ACTIONS(7737),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7730),
    [sym_preproc_open] = ACTIONS(7715),
    [sym_preproc_close] = ACTIONS(7730),
  },
  [STATE(3565)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3570),
    [sym_case_branch] = STATE(3570),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3570),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(17192),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(297),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3570),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7740),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(3566)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3600),
    [sym_case_branch] = STATE(3600),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3600),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(17996),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(297),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3600),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7742),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(3567)] = {
    [aux_sym_option_member_list_repeat2] = STATE(3567),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_EQ] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(7744),
    [anon_sym_DASH] = ACTIONS(836),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(838),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(838),
    [aux_sym__expression_token1] = ACTIONS(838),
    [aux_sym__expression_token2] = ACTIONS(838),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_div] = ACTIONS(836),
    [anon_sym_DIV] = ACTIONS(836),
    [anon_sym_Div] = ACTIONS(836),
    [anon_sym_mod] = ACTIONS(836),
    [anon_sym_MOD] = ACTIONS(836),
    [anon_sym_Mod] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_LT_GT] = ACTIONS(838),
    [anon_sym_and] = ACTIONS(836),
    [anon_sym_AND] = ACTIONS(836),
    [anon_sym_And] = ACTIONS(836),
    [anon_sym_or] = ACTIONS(836),
    [anon_sym_OR] = ACTIONS(836),
    [anon_sym_Or] = ACTIONS(836),
    [anon_sym_xor] = ACTIONS(836),
    [anon_sym_XOR] = ACTIONS(836),
    [anon_sym_Xor] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(838),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_IN] = ACTIONS(836),
    [anon_sym_In] = ACTIONS(836),
    [anon_sym_to] = ACTIONS(836),
    [anon_sym_TO] = ACTIONS(836),
    [anon_sym_To] = ACTIONS(836),
    [anon_sym_downto] = ACTIONS(836),
    [anon_sym_DOWNTO] = ACTIONS(836),
    [anon_sym_Downto] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(838),
  },
  [STATE(3568)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_elif] = STATE(3620),
    [sym_preproc_else] = STATE(3965),
    [sym_preproc_endif] = STATE(7528),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [aux_sym_preproc_conditional_xmlport_repeat1] = STATE(10794),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDelif] = ACTIONS(7378),
    [anon_sym_POUNDELIF] = ACTIONS(7378),
    [anon_sym_POUNDElif] = ACTIONS(7378),
    [anon_sym_POUNDelse] = ACTIONS(7380),
    [anon_sym_POUNDELSE] = ACTIONS(7380),
    [anon_sym_POUNDElse] = ACTIONS(7380),
    [anon_sym_POUNDelse2] = ACTIONS(7380),
    [anon_sym_POUNDELSE2] = ACTIONS(7380),
    [anon_sym_POUNDElse2] = ACTIONS(7380),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3569)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_elif] = STATE(3620),
    [sym_preproc_else] = STATE(3974),
    [sym_preproc_endif] = STATE(9184),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [aux_sym_preproc_conditional_xmlport_repeat1] = STATE(10860),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDelif] = ACTIONS(7378),
    [anon_sym_POUNDELIF] = ACTIONS(7378),
    [anon_sym_POUNDElif] = ACTIONS(7378),
    [anon_sym_POUNDelse] = ACTIONS(7380),
    [anon_sym_POUNDELSE] = ACTIONS(7380),
    [anon_sym_POUNDElse] = ACTIONS(7380),
    [anon_sym_POUNDelse2] = ACTIONS(7380),
    [anon_sym_POUNDELSE2] = ACTIONS(7380),
    [anon_sym_POUNDElse2] = ACTIONS(7380),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3570)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3600),
    [sym_case_branch] = STATE(3600),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3600),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(17426),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(297),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3600),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7749),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(3571)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3561),
    [sym_case_branch] = STATE(3561),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3561),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(18275),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(297),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3561),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7751),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(3572)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3573),
    [sym_case_branch] = STATE(3573),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3573),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(18105),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(297),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3573),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7753),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(3573)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3600),
    [sym_case_branch] = STATE(3600),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3600),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym_case_else_branch] = STATE(18205),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_else_keyword] = STATE(297),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3600),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7755),
    [anon_sym_POUNDif] = ACTIONS(73),
    [anon_sym_POUNDIF] = ACTIONS(73),
    [anon_sym_POUNDIf] = ACTIONS(73),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(73),
  },
  [STATE(3574)] = {
    [sym_identifier] = ACTIONS(7757),
    [anon_sym_SEMI] = ACTIONS(7760),
    [aux_sym_where_condition_token1] = ACTIONS(7765),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7772),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7772),
    [anon_sym_LBRACK] = ACTIONS(7775),
    [aux_sym_basic_type_token6] = ACTIONS(7772),
    [aux_sym_basic_type_token22] = ACTIONS(7757),
    [aux_sym_basic_type_token53] = ACTIONS(7757),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7765),
    [aux_sym_addafter_modification_token1] = ACTIONS(7772),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7772),
    [aux_sym_modify_modification_token1] = ACTIONS(7772),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7772),
    [aux_sym_movelast_modification_token1] = ACTIONS(7772),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7772),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7772),
    [aux_sym_separator_action_token1] = ACTIONS(7757),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7765),
    [aux_sym_type_declaration_token1] = ACTIONS(7757),
    [anon_sym_POUNDif] = ACTIONS(7760),
    [anon_sym_POUNDIF] = ACTIONS(7760),
    [anon_sym_POUNDIf] = ACTIONS(7760),
    [anon_sym_POUNDelif] = ACTIONS(7775),
    [anon_sym_POUNDELIF] = ACTIONS(7775),
    [anon_sym_POUNDElif] = ACTIONS(7775),
    [anon_sym_POUNDelse] = ACTIONS(7775),
    [anon_sym_POUNDELSE] = ACTIONS(7775),
    [anon_sym_POUNDElse] = ACTIONS(7775),
    [anon_sym_POUNDelse2] = ACTIONS(7775),
    [anon_sym_POUNDELSE2] = ACTIONS(7775),
    [anon_sym_POUNDElse2] = ACTIONS(7775),
    [anon_sym_POUNDendif] = ACTIONS(7775),
    [anon_sym_POUNDENDIF] = ACTIONS(7775),
    [anon_sym_POUNDEndif] = ACTIONS(7775),
    [anon_sym_POUNDendif2] = ACTIONS(7775),
    [anon_sym_POUNDENDIF2] = ACTIONS(7775),
    [anon_sym_POUNDEndif2] = ACTIONS(7775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7778),
    [sym_page_keyword] = ACTIONS(7770),
    [anon_sym_codeunit] = ACTIONS(7770),
    [anon_sym_CODEUNIT] = ACTIONS(7770),
    [anon_sym_Codeunit] = ACTIONS(7770),
    [anon_sym_CodeUnit] = ACTIONS(7770),
    [anon_sym_COdeunit] = ACTIONS(7770),
    [anon_sym_codeUnit] = ACTIONS(7770),
    [sym_report_keyword] = ACTIONS(7770),
    [sym_query_keyword] = ACTIONS(7770),
    [anon_sym_xmlport] = ACTIONS(7770),
    [anon_sym_XMLPORT] = ACTIONS(7770),
    [anon_sym_Xmlport] = ACTIONS(7770),
    [anon_sym_XMLport] = ACTIONS(7770),
    [anon_sym_XMLPort] = ACTIONS(7770),
    [anon_sym_XmlPort] = ACTIONS(7770),
    [sym_procedure_keyword] = ACTIONS(7772),
    [sym_trigger_keyword] = ACTIONS(7772),
    [sym_var_keyword] = ACTIONS(7772),
    [sym_local_keyword] = ACTIONS(7772),
    [sym_internal_keyword] = ACTIONS(7772),
    [sym_protected_keyword] = ACTIONS(7772),
    [sym_event_keyword] = ACTIONS(7772),
    [sym_fields_keyword] = ACTIONS(7772),
    [sym_keys_keyword] = ACTIONS(7772),
    [sym_key_keyword] = ACTIONS(7757),
    [sym_fieldgroups_keyword] = ACTIONS(7772),
    [sym_actions_keyword] = ACTIONS(7772),
    [sym_layout_keyword] = ACTIONS(7772),
    [sym_area_keyword] = ACTIONS(7772),
    [sym_group_keyword] = ACTIONS(7772),
    [sym_repeater_keyword] = ACTIONS(7772),
    [sym_cuegroup_keyword] = ACTIONS(7772),
    [sym_fixed_keyword] = ACTIONS(7772),
    [sym_grid_keyword] = ACTIONS(7772),
    [sym_part_keyword] = ACTIONS(7772),
    [sym_systempart_keyword] = ACTIONS(7772),
    [sym_usercontrol_keyword] = ACTIONS(7772),
    [sym_dataset_keyword] = ACTIONS(7765),
    [sym_elements_keyword] = ACTIONS(7772),
    [sym_labels_keyword] = ACTIONS(7772),
    [sym_rendering_keyword] = ACTIONS(7772),
    [sym_requestpage_keyword] = ACTIONS(7772),
    [sym_schema_keyword] = ACTIONS(7772),
    [sym_views_keyword] = ACTIONS(7772),
    [sym_quoted_identifier] = ACTIONS(7782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7775),
    [sym_preproc_open] = ACTIONS(7760),
    [sym_preproc_close] = ACTIONS(7775),
  },
  [STATE(3575)] = {
    [sym_preproc_conditional_permissions] = STATE(3575),
    [sym_tabledata_permission] = STATE(3688),
    [sym_preproc_if] = STATE(7981),
    [sym_codeunit_keyword] = STATE(11365),
    [sym_xmlport_keyword] = STATE(11365),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(3575),
    [anon_sym_SEMI] = ACTIONS(7785),
    [aux_sym_where_condition_token1] = ACTIONS(7787),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7789),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7792),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7785),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7785),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_basic_type_token6] = ACTIONS(7787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_addafter_modification_token1] = ACTIONS(7785),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7785),
    [aux_sym_movelast_modification_token1] = ACTIONS(7785),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7785),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7795),
    [anon_sym_POUNDIF] = ACTIONS(7795),
    [anon_sym_POUNDIf] = ACTIONS(7795),
    [anon_sym_POUNDelif] = ACTIONS(7785),
    [anon_sym_POUNDELIF] = ACTIONS(7785),
    [anon_sym_POUNDElif] = ACTIONS(7785),
    [anon_sym_POUNDelse] = ACTIONS(7785),
    [anon_sym_POUNDELSE] = ACTIONS(7785),
    [anon_sym_POUNDElse] = ACTIONS(7785),
    [anon_sym_POUNDelse2] = ACTIONS(7785),
    [anon_sym_POUNDELSE2] = ACTIONS(7785),
    [anon_sym_POUNDElse2] = ACTIONS(7785),
    [anon_sym_POUNDendif] = ACTIONS(7785),
    [anon_sym_POUNDENDIF] = ACTIONS(7785),
    [anon_sym_POUNDEndif] = ACTIONS(7785),
    [anon_sym_POUNDendif2] = ACTIONS(7785),
    [anon_sym_POUNDENDIF2] = ACTIONS(7785),
    [anon_sym_POUNDEndif2] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7792),
    [sym_page_keyword] = ACTIONS(7789),
    [anon_sym_codeunit] = ACTIONS(7798),
    [anon_sym_CODEUNIT] = ACTIONS(7798),
    [anon_sym_Codeunit] = ACTIONS(7798),
    [anon_sym_CodeUnit] = ACTIONS(7798),
    [anon_sym_COdeunit] = ACTIONS(7798),
    [anon_sym_codeUnit] = ACTIONS(7798),
    [sym_report_keyword] = ACTIONS(7789),
    [sym_query_keyword] = ACTIONS(7789),
    [anon_sym_xmlport] = ACTIONS(7801),
    [anon_sym_XMLPORT] = ACTIONS(7801),
    [anon_sym_Xmlport] = ACTIONS(7801),
    [anon_sym_XMLport] = ACTIONS(7801),
    [anon_sym_XMLPort] = ACTIONS(7801),
    [anon_sym_XmlPort] = ACTIONS(7801),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_area_keyword] = ACTIONS(7785),
    [sym_group_keyword] = ACTIONS(7785),
    [sym_repeater_keyword] = ACTIONS(7785),
    [sym_cuegroup_keyword] = ACTIONS(7785),
    [sym_fixed_keyword] = ACTIONS(7785),
    [sym_grid_keyword] = ACTIONS(7785),
    [sym_part_keyword] = ACTIONS(7785),
    [sym_systempart_keyword] = ACTIONS(7785),
    [sym_usercontrol_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7795),
    [sym_preproc_close] = ACTIONS(7785),
  },
  [STATE(3576)] = {
    [sym__body_element] = STATE(3590),
    [sym_empty_statement] = STATE(3590),
    [sym_property] = STATE(8316),
    [sym_permissions_property] = STATE(3590),
    [sym_table_relation_property] = STATE(3590),
    [sym_fields_section] = STATE(3590),
    [sym_keys_section] = STATE(3590),
    [sym_fieldgroups_section] = STATE(3590),
    [sym_enum_value_declaration] = STATE(3590),
    [sym_labels_section] = STATE(3590),
    [sym_layout_section] = STATE(3590),
    [sym_modify_modification] = STATE(3590),
    [sym_actions_section] = STATE(3590),
    [sym__action_element] = STATE(3590),
    [sym_action_area_section] = STATE(3590),
    [sym_action_group_section] = STATE(3590),
    [sym_action_declaration] = STATE(3590),
    [sym_separator_action] = STATE(3590),
    [sym_actionref_declaration] = STATE(3590),
    [sym_systemaction_declaration] = STATE(3590),
    [sym_fileuploadaction_declaration] = STATE(3590),
    [sym_customaction_declaration] = STATE(3590),
    [sym_addfirst_action_modification] = STATE(3590),
    [sym_addlast_action_modification] = STATE(3590),
    [sym_addafter_action_modification] = STATE(3590),
    [sym_addbefore_action_modification] = STATE(3590),
    [sym_modify_action_modification] = STATE(3590),
    [sym_views_section] = STATE(3590),
    [sym_dataset_section] = STATE(3590),
    [sym_requestpage_section] = STATE(3590),
    [sym_rendering_section] = STATE(3590),
    [sym_elements_section] = STATE(3590),
    [sym_schema_section] = STATE(3590),
    [sym_assembly_declaration] = STATE(3590),
    [sym_event_declaration] = STATE(3590),
    [sym_procedure] = STATE(3590),
    [sym_preproc_split_procedure] = STATE(3590),
    [sym_preproc_split_procedure_preamble] = STATE(3590),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(8316),
    [sym_var_section] = STATE(3590),
    [sym_attribute_item] = STATE(8316),
    [sym_preproc_conditional] = STATE(3590),
    [sym_preproc_if] = STATE(2237),
    [sym_preproc_conditional_actions] = STATE(3590),
    [aux_sym_action_group_section_repeat1] = STATE(3590),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(7804),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7806),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7808),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token22] = ACTIONS(7810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(7812),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7814),
    [aux_sym_modify_modification_token1] = ACTIONS(7816),
    [aux_sym_separator_action_token1] = ACTIONS(7818),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7820),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7822),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7824),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7826),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(7828),
    [sym_local_keyword] = ACTIONS(7830),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7830),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(7832),
    [sym_group_keyword] = ACTIONS(7834),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7836),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(3577)] = {
    [sym__body_element] = STATE(3586),
    [sym_empty_statement] = STATE(3586),
    [sym_property] = STATE(8316),
    [sym_permissions_property] = STATE(3586),
    [sym_table_relation_property] = STATE(3586),
    [sym_fields_section] = STATE(3586),
    [sym_keys_section] = STATE(3586),
    [sym_fieldgroups_section] = STATE(3586),
    [sym_enum_value_declaration] = STATE(3586),
    [sym_labels_section] = STATE(3586),
    [sym_layout_section] = STATE(3586),
    [sym_modify_modification] = STATE(3586),
    [sym_actions_section] = STATE(3586),
    [sym__action_element] = STATE(3586),
    [sym_action_area_section] = STATE(3586),
    [sym_action_group_section] = STATE(3586),
    [sym_action_declaration] = STATE(3586),
    [sym_separator_action] = STATE(3586),
    [sym_actionref_declaration] = STATE(3586),
    [sym_systemaction_declaration] = STATE(3586),
    [sym_fileuploadaction_declaration] = STATE(3586),
    [sym_customaction_declaration] = STATE(3586),
    [sym_addfirst_action_modification] = STATE(3586),
    [sym_addlast_action_modification] = STATE(3586),
    [sym_addafter_action_modification] = STATE(3586),
    [sym_addbefore_action_modification] = STATE(3586),
    [sym_modify_action_modification] = STATE(3586),
    [sym_views_section] = STATE(3586),
    [sym_dataset_section] = STATE(3586),
    [sym_requestpage_section] = STATE(3586),
    [sym_rendering_section] = STATE(3586),
    [sym_elements_section] = STATE(3586),
    [sym_schema_section] = STATE(3586),
    [sym_assembly_declaration] = STATE(3586),
    [sym_event_declaration] = STATE(3586),
    [sym_procedure] = STATE(3586),
    [sym_preproc_split_procedure] = STATE(3586),
    [sym_preproc_split_procedure_preamble] = STATE(3586),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(8316),
    [sym_var_section] = STATE(3586),
    [sym_attribute_item] = STATE(8316),
    [sym_preproc_conditional] = STATE(3586),
    [sym_preproc_if] = STATE(2237),
    [sym_preproc_conditional_actions] = STATE(3586),
    [aux_sym_action_group_section_repeat1] = STATE(3586),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(7838),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7806),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7808),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token22] = ACTIONS(7810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(7812),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7814),
    [aux_sym_modify_modification_token1] = ACTIONS(7816),
    [aux_sym_separator_action_token1] = ACTIONS(7818),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7820),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7822),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7824),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7826),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(7828),
    [sym_local_keyword] = ACTIONS(7830),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7830),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(7832),
    [sym_group_keyword] = ACTIONS(7834),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7836),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(3578)] = {
    [sym__body_element] = STATE(3587),
    [sym_empty_statement] = STATE(3587),
    [sym_property] = STATE(8316),
    [sym_permissions_property] = STATE(3587),
    [sym_table_relation_property] = STATE(3587),
    [sym_fields_section] = STATE(3587),
    [sym_keys_section] = STATE(3587),
    [sym_fieldgroups_section] = STATE(3587),
    [sym_enum_value_declaration] = STATE(3587),
    [sym_labels_section] = STATE(3587),
    [sym_layout_section] = STATE(3587),
    [sym_modify_modification] = STATE(3587),
    [sym_actions_section] = STATE(3587),
    [sym__action_element] = STATE(3587),
    [sym_action_area_section] = STATE(3587),
    [sym_action_group_section] = STATE(3587),
    [sym_action_declaration] = STATE(3587),
    [sym_separator_action] = STATE(3587),
    [sym_actionref_declaration] = STATE(3587),
    [sym_systemaction_declaration] = STATE(3587),
    [sym_fileuploadaction_declaration] = STATE(3587),
    [sym_customaction_declaration] = STATE(3587),
    [sym_addfirst_action_modification] = STATE(3587),
    [sym_addlast_action_modification] = STATE(3587),
    [sym_addafter_action_modification] = STATE(3587),
    [sym_addbefore_action_modification] = STATE(3587),
    [sym_modify_action_modification] = STATE(3587),
    [sym_views_section] = STATE(3587),
    [sym_dataset_section] = STATE(3587),
    [sym_requestpage_section] = STATE(3587),
    [sym_rendering_section] = STATE(3587),
    [sym_elements_section] = STATE(3587),
    [sym_schema_section] = STATE(3587),
    [sym_assembly_declaration] = STATE(3587),
    [sym_event_declaration] = STATE(3587),
    [sym_procedure] = STATE(3587),
    [sym_preproc_split_procedure] = STATE(3587),
    [sym_preproc_split_procedure_preamble] = STATE(3587),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(8316),
    [sym_var_section] = STATE(3587),
    [sym_attribute_item] = STATE(8316),
    [sym_preproc_conditional] = STATE(3587),
    [sym_preproc_if] = STATE(2237),
    [sym_preproc_conditional_actions] = STATE(3587),
    [aux_sym_action_group_section_repeat1] = STATE(3587),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(7840),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7806),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7808),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token22] = ACTIONS(7810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(7812),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7814),
    [aux_sym_modify_modification_token1] = ACTIONS(7816),
    [aux_sym_separator_action_token1] = ACTIONS(7818),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7820),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7822),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7824),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7826),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(7828),
    [sym_local_keyword] = ACTIONS(7830),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7830),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(7832),
    [sym_group_keyword] = ACTIONS(7834),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7836),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(3579)] = {
    [sym_boolean] = STATE(3032),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3585),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7842),
    [anon_sym_POUNDELIF] = ACTIONS(7842),
    [anon_sym_POUNDElif] = ACTIONS(7842),
    [anon_sym_POUNDelse] = ACTIONS(7842),
    [anon_sym_POUNDELSE] = ACTIONS(7842),
    [anon_sym_POUNDElse] = ACTIONS(7842),
    [anon_sym_POUNDelse2] = ACTIONS(7842),
    [anon_sym_POUNDELSE2] = ACTIONS(7842),
    [anon_sym_POUNDElse2] = ACTIONS(7842),
    [anon_sym_POUNDendif] = ACTIONS(7842),
    [anon_sym_POUNDENDIF] = ACTIONS(7842),
    [anon_sym_POUNDEndif] = ACTIONS(7842),
    [anon_sym_POUNDendif2] = ACTIONS(7842),
    [anon_sym_POUNDENDIF2] = ACTIONS(7842),
    [anon_sym_POUNDEndif2] = ACTIONS(7842),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(7842),
  },
  [STATE(3580)] = {
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3564),
    [aux_sym_modify_modification_token1] = ACTIONS(3564),
    [aux_sym_xmlport_element_token1] = ACTIONS(3564),
    [aux_sym_xmlport_element_token2] = ACTIONS(3564),
    [aux_sym_xmlport_element_token3] = ACTIONS(3564),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(3564),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(3564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3665),
    [anon_sym_DIV] = ACTIONS(3665),
    [anon_sym_Div] = ACTIONS(3665),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3665),
    [anon_sym_AND] = ACTIONS(3665),
    [anon_sym_And] = ACTIONS(3665),
    [anon_sym_or] = ACTIONS(3665),
    [anon_sym_OR] = ACTIONS(3665),
    [anon_sym_Or] = ACTIONS(3665),
    [anon_sym_xor] = ACTIONS(3665),
    [anon_sym_XOR] = ACTIONS(3665),
    [anon_sym_Xor] = ACTIONS(3665),
    [anon_sym_QMARK] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_procedure_keyword] = ACTIONS(3564),
    [sym_trigger_keyword] = ACTIONS(3564),
    [sym_var_keyword] = ACTIONS(3564),
    [sym_local_keyword] = ACTIONS(3564),
    [sym_internal_keyword] = ACTIONS(3564),
    [sym_protected_keyword] = ACTIONS(3564),
    [sym_event_keyword] = ACTIONS(3564),
    [sym_fields_keyword] = ACTIONS(3564),
    [sym_keys_keyword] = ACTIONS(3564),
    [sym_fieldgroups_keyword] = ACTIONS(3564),
    [sym_actions_keyword] = ACTIONS(3564),
    [sym_layout_keyword] = ACTIONS(3564),
    [sym_dataset_keyword] = ACTIONS(3564),
    [sym_elements_keyword] = ACTIONS(3564),
    [sym_labels_keyword] = ACTIONS(3564),
    [sym_rendering_keyword] = ACTIONS(3564),
    [sym_requestpage_keyword] = ACTIONS(3564),
    [sym_schema_keyword] = ACTIONS(3564),
    [sym_views_keyword] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
  },
  [STATE(3581)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_elif] = STATE(3624),
    [sym_preproc_else] = STATE(4031),
    [sym_preproc_endif] = STATE(9822),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [aux_sym_preproc_conditional_query_repeat1] = STATE(10994),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3582)] = {
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [aux_sym_where_clause_token1] = ACTIONS(3786),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3786),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3786),
    [aux_sym_modify_modification_token1] = ACTIONS(3786),
    [aux_sym_xmlport_element_token1] = ACTIONS(3786),
    [aux_sym_xmlport_element_token2] = ACTIONS(3786),
    [aux_sym_xmlport_element_token3] = ACTIONS(3786),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(3786),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(3786),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [anon_sym_POUNDelif] = ACTIONS(3786),
    [anon_sym_POUNDELIF] = ACTIONS(3786),
    [anon_sym_POUNDElif] = ACTIONS(3786),
    [anon_sym_POUNDelse] = ACTIONS(3786),
    [anon_sym_POUNDELSE] = ACTIONS(3786),
    [anon_sym_POUNDElse] = ACTIONS(3786),
    [anon_sym_POUNDelse2] = ACTIONS(3786),
    [anon_sym_POUNDELSE2] = ACTIONS(3786),
    [anon_sym_POUNDElse2] = ACTIONS(3786),
    [anon_sym_POUNDendif] = ACTIONS(3786),
    [anon_sym_POUNDENDIF] = ACTIONS(3786),
    [anon_sym_POUNDEndif] = ACTIONS(3786),
    [anon_sym_POUNDendif2] = ACTIONS(3786),
    [anon_sym_POUNDENDIF2] = ACTIONS(3786),
    [anon_sym_POUNDEndif2] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3786),
    [anon_sym_DIV] = ACTIONS(3786),
    [anon_sym_Div] = ACTIONS(3786),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3786),
    [anon_sym_AND] = ACTIONS(3786),
    [anon_sym_And] = ACTIONS(3786),
    [anon_sym_or] = ACTIONS(3786),
    [anon_sym_OR] = ACTIONS(3786),
    [anon_sym_Or] = ACTIONS(3786),
    [anon_sym_xor] = ACTIONS(3786),
    [anon_sym_XOR] = ACTIONS(3786),
    [anon_sym_Xor] = ACTIONS(3786),
    [anon_sym_QMARK] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_procedure_keyword] = ACTIONS(3786),
    [sym_trigger_keyword] = ACTIONS(3786),
    [sym_var_keyword] = ACTIONS(3786),
    [sym_local_keyword] = ACTIONS(3786),
    [sym_internal_keyword] = ACTIONS(3786),
    [sym_protected_keyword] = ACTIONS(3786),
    [sym_event_keyword] = ACTIONS(3786),
    [sym_fields_keyword] = ACTIONS(3786),
    [sym_keys_keyword] = ACTIONS(3786),
    [sym_fieldgroups_keyword] = ACTIONS(3786),
    [sym_actions_keyword] = ACTIONS(3786),
    [sym_layout_keyword] = ACTIONS(3786),
    [sym_dataset_keyword] = ACTIONS(3786),
    [sym_elements_keyword] = ACTIONS(3786),
    [sym_labels_keyword] = ACTIONS(3786),
    [sym_rendering_keyword] = ACTIONS(3786),
    [sym_requestpage_keyword] = ACTIONS(3786),
    [sym_schema_keyword] = ACTIONS(3786),
    [sym_views_keyword] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
    [sym_preproc_close] = ACTIONS(3786),
  },
  [STATE(3583)] = {
    [sym__body_element] = STATE(3578),
    [sym_empty_statement] = STATE(3578),
    [sym_property] = STATE(8316),
    [sym_permissions_property] = STATE(3578),
    [sym_table_relation_property] = STATE(3578),
    [sym_fields_section] = STATE(3578),
    [sym_keys_section] = STATE(3578),
    [sym_fieldgroups_section] = STATE(3578),
    [sym_enum_value_declaration] = STATE(3578),
    [sym_labels_section] = STATE(3578),
    [sym_layout_section] = STATE(3578),
    [sym_modify_modification] = STATE(3578),
    [sym_actions_section] = STATE(3578),
    [sym__action_element] = STATE(3578),
    [sym_action_area_section] = STATE(3578),
    [sym_action_group_section] = STATE(3578),
    [sym_action_declaration] = STATE(3578),
    [sym_separator_action] = STATE(3578),
    [sym_actionref_declaration] = STATE(3578),
    [sym_systemaction_declaration] = STATE(3578),
    [sym_fileuploadaction_declaration] = STATE(3578),
    [sym_customaction_declaration] = STATE(3578),
    [sym_addfirst_action_modification] = STATE(3578),
    [sym_addlast_action_modification] = STATE(3578),
    [sym_addafter_action_modification] = STATE(3578),
    [sym_addbefore_action_modification] = STATE(3578),
    [sym_modify_action_modification] = STATE(3578),
    [sym_views_section] = STATE(3578),
    [sym_dataset_section] = STATE(3578),
    [sym_requestpage_section] = STATE(3578),
    [sym_rendering_section] = STATE(3578),
    [sym_elements_section] = STATE(3578),
    [sym_schema_section] = STATE(3578),
    [sym_assembly_declaration] = STATE(3578),
    [sym_event_declaration] = STATE(3578),
    [sym_procedure] = STATE(3578),
    [sym_preproc_split_procedure] = STATE(3578),
    [sym_preproc_split_procedure_preamble] = STATE(3578),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(8316),
    [sym_var_section] = STATE(3578),
    [sym_attribute_item] = STATE(8316),
    [sym_preproc_conditional] = STATE(3578),
    [sym_preproc_if] = STATE(2237),
    [sym_preproc_conditional_actions] = STATE(3578),
    [aux_sym_action_group_section_repeat1] = STATE(3578),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(7844),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7806),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7808),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token22] = ACTIONS(7810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(7812),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7814),
    [aux_sym_modify_modification_token1] = ACTIONS(7816),
    [aux_sym_separator_action_token1] = ACTIONS(7818),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7820),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7822),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7824),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7826),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(7828),
    [sym_local_keyword] = ACTIONS(7830),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7830),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(7832),
    [sym_group_keyword] = ACTIONS(7834),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7836),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(3584)] = {
    [sym_preproc_conditional_permissions] = STATE(3575),
    [sym_tabledata_permission] = STATE(3688),
    [sym_preproc_if] = STATE(7981),
    [sym_codeunit_keyword] = STATE(11365),
    [sym_xmlport_keyword] = STATE(11365),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(3575),
    [anon_sym_SEMI] = ACTIONS(7846),
    [aux_sym_where_condition_token1] = ACTIONS(7848),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7850),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4031),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7846),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7846),
    [anon_sym_LBRACK] = ACTIONS(7846),
    [aux_sym_basic_type_token6] = ACTIONS(7848),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7846),
    [aux_sym_addafter_modification_token1] = ACTIONS(7846),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7846),
    [aux_sym_modify_modification_token1] = ACTIONS(7846),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7846),
    [aux_sym_movelast_modification_token1] = ACTIONS(7846),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7846),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7846),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7846),
    [anon_sym_POUNDif] = ACTIONS(7852),
    [anon_sym_POUNDIF] = ACTIONS(7852),
    [anon_sym_POUNDIf] = ACTIONS(7852),
    [anon_sym_POUNDelif] = ACTIONS(7846),
    [anon_sym_POUNDELIF] = ACTIONS(7846),
    [anon_sym_POUNDElif] = ACTIONS(7846),
    [anon_sym_POUNDelse] = ACTIONS(7846),
    [anon_sym_POUNDELSE] = ACTIONS(7846),
    [anon_sym_POUNDElse] = ACTIONS(7846),
    [anon_sym_POUNDelse2] = ACTIONS(7846),
    [anon_sym_POUNDELSE2] = ACTIONS(7846),
    [anon_sym_POUNDElse2] = ACTIONS(7846),
    [anon_sym_POUNDendif] = ACTIONS(7846),
    [anon_sym_POUNDENDIF] = ACTIONS(7846),
    [anon_sym_POUNDEndif] = ACTIONS(7846),
    [anon_sym_POUNDendif2] = ACTIONS(7846),
    [anon_sym_POUNDENDIF2] = ACTIONS(7846),
    [anon_sym_POUNDEndif2] = ACTIONS(7846),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4031),
    [sym_page_keyword] = ACTIONS(7850),
    [anon_sym_codeunit] = ACTIONS(7855),
    [anon_sym_CODEUNIT] = ACTIONS(7855),
    [anon_sym_Codeunit] = ACTIONS(7855),
    [anon_sym_CodeUnit] = ACTIONS(7855),
    [anon_sym_COdeunit] = ACTIONS(7855),
    [anon_sym_codeUnit] = ACTIONS(7855),
    [sym_report_keyword] = ACTIONS(7850),
    [sym_query_keyword] = ACTIONS(7850),
    [anon_sym_xmlport] = ACTIONS(7857),
    [anon_sym_XMLPORT] = ACTIONS(7857),
    [anon_sym_Xmlport] = ACTIONS(7857),
    [anon_sym_XMLport] = ACTIONS(7857),
    [anon_sym_XMLPort] = ACTIONS(7857),
    [anon_sym_XmlPort] = ACTIONS(7857),
    [sym_procedure_keyword] = ACTIONS(7846),
    [sym_trigger_keyword] = ACTIONS(7846),
    [sym_var_keyword] = ACTIONS(7846),
    [sym_local_keyword] = ACTIONS(7846),
    [sym_internal_keyword] = ACTIONS(7846),
    [sym_protected_keyword] = ACTIONS(7846),
    [sym_event_keyword] = ACTIONS(7846),
    [sym_fields_keyword] = ACTIONS(7846),
    [sym_keys_keyword] = ACTIONS(7846),
    [sym_fieldgroups_keyword] = ACTIONS(7846),
    [sym_actions_keyword] = ACTIONS(7846),
    [sym_layout_keyword] = ACTIONS(7846),
    [sym_area_keyword] = ACTIONS(7846),
    [sym_group_keyword] = ACTIONS(7846),
    [sym_repeater_keyword] = ACTIONS(7846),
    [sym_cuegroup_keyword] = ACTIONS(7846),
    [sym_fixed_keyword] = ACTIONS(7846),
    [sym_grid_keyword] = ACTIONS(7846),
    [sym_part_keyword] = ACTIONS(7846),
    [sym_systempart_keyword] = ACTIONS(7846),
    [sym_usercontrol_keyword] = ACTIONS(7846),
    [sym_dataset_keyword] = ACTIONS(7846),
    [sym_elements_keyword] = ACTIONS(7846),
    [sym_labels_keyword] = ACTIONS(7846),
    [sym_rendering_keyword] = ACTIONS(7846),
    [sym_requestpage_keyword] = ACTIONS(7846),
    [sym_schema_keyword] = ACTIONS(7846),
    [sym_views_keyword] = ACTIONS(7846),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7846),
    [sym_preproc_open] = ACTIONS(7852),
    [sym_preproc_close] = ACTIONS(7846),
  },
  [STATE(3585)] = {
    [sym_boolean] = STATE(3032),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDelif] = ACTIONS(7859),
    [anon_sym_POUNDELIF] = ACTIONS(7859),
    [anon_sym_POUNDElif] = ACTIONS(7859),
    [anon_sym_POUNDelse] = ACTIONS(7859),
    [anon_sym_POUNDELSE] = ACTIONS(7859),
    [anon_sym_POUNDElse] = ACTIONS(7859),
    [anon_sym_POUNDelse2] = ACTIONS(7859),
    [anon_sym_POUNDELSE2] = ACTIONS(7859),
    [anon_sym_POUNDElse2] = ACTIONS(7859),
    [anon_sym_POUNDendif] = ACTIONS(7859),
    [anon_sym_POUNDENDIF] = ACTIONS(7859),
    [anon_sym_POUNDEndif] = ACTIONS(7859),
    [anon_sym_POUNDendif2] = ACTIONS(7859),
    [anon_sym_POUNDENDIF2] = ACTIONS(7859),
    [anon_sym_POUNDEndif2] = ACTIONS(7859),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(7859),
  },
  [STATE(3586)] = {
    [sym__body_element] = STATE(3587),
    [sym_empty_statement] = STATE(3587),
    [sym_property] = STATE(8316),
    [sym_permissions_property] = STATE(3587),
    [sym_table_relation_property] = STATE(3587),
    [sym_fields_section] = STATE(3587),
    [sym_keys_section] = STATE(3587),
    [sym_fieldgroups_section] = STATE(3587),
    [sym_enum_value_declaration] = STATE(3587),
    [sym_labels_section] = STATE(3587),
    [sym_layout_section] = STATE(3587),
    [sym_modify_modification] = STATE(3587),
    [sym_actions_section] = STATE(3587),
    [sym__action_element] = STATE(3587),
    [sym_action_area_section] = STATE(3587),
    [sym_action_group_section] = STATE(3587),
    [sym_action_declaration] = STATE(3587),
    [sym_separator_action] = STATE(3587),
    [sym_actionref_declaration] = STATE(3587),
    [sym_systemaction_declaration] = STATE(3587),
    [sym_fileuploadaction_declaration] = STATE(3587),
    [sym_customaction_declaration] = STATE(3587),
    [sym_addfirst_action_modification] = STATE(3587),
    [sym_addlast_action_modification] = STATE(3587),
    [sym_addafter_action_modification] = STATE(3587),
    [sym_addbefore_action_modification] = STATE(3587),
    [sym_modify_action_modification] = STATE(3587),
    [sym_views_section] = STATE(3587),
    [sym_dataset_section] = STATE(3587),
    [sym_requestpage_section] = STATE(3587),
    [sym_rendering_section] = STATE(3587),
    [sym_elements_section] = STATE(3587),
    [sym_schema_section] = STATE(3587),
    [sym_assembly_declaration] = STATE(3587),
    [sym_event_declaration] = STATE(3587),
    [sym_procedure] = STATE(3587),
    [sym_preproc_split_procedure] = STATE(3587),
    [sym_preproc_split_procedure_preamble] = STATE(3587),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(8316),
    [sym_var_section] = STATE(3587),
    [sym_attribute_item] = STATE(8316),
    [sym_preproc_conditional] = STATE(3587),
    [sym_preproc_if] = STATE(2237),
    [sym_preproc_conditional_actions] = STATE(3587),
    [aux_sym_action_group_section_repeat1] = STATE(3587),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(7861),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7806),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7808),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token22] = ACTIONS(7810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(7812),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7814),
    [aux_sym_modify_modification_token1] = ACTIONS(7816),
    [aux_sym_separator_action_token1] = ACTIONS(7818),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7820),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7822),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7824),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7826),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(7828),
    [sym_local_keyword] = ACTIONS(7830),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7830),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(7832),
    [sym_group_keyword] = ACTIONS(7834),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7836),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(3587)] = {
    [sym__body_element] = STATE(3587),
    [sym_empty_statement] = STATE(3587),
    [sym_property] = STATE(8316),
    [sym_permissions_property] = STATE(3587),
    [sym_table_relation_property] = STATE(3587),
    [sym_fields_section] = STATE(3587),
    [sym_keys_section] = STATE(3587),
    [sym_fieldgroups_section] = STATE(3587),
    [sym_enum_value_declaration] = STATE(3587),
    [sym_labels_section] = STATE(3587),
    [sym_layout_section] = STATE(3587),
    [sym_modify_modification] = STATE(3587),
    [sym_actions_section] = STATE(3587),
    [sym__action_element] = STATE(3587),
    [sym_action_area_section] = STATE(3587),
    [sym_action_group_section] = STATE(3587),
    [sym_action_declaration] = STATE(3587),
    [sym_separator_action] = STATE(3587),
    [sym_actionref_declaration] = STATE(3587),
    [sym_systemaction_declaration] = STATE(3587),
    [sym_fileuploadaction_declaration] = STATE(3587),
    [sym_customaction_declaration] = STATE(3587),
    [sym_addfirst_action_modification] = STATE(3587),
    [sym_addlast_action_modification] = STATE(3587),
    [sym_addafter_action_modification] = STATE(3587),
    [sym_addbefore_action_modification] = STATE(3587),
    [sym_modify_action_modification] = STATE(3587),
    [sym_views_section] = STATE(3587),
    [sym_dataset_section] = STATE(3587),
    [sym_requestpage_section] = STATE(3587),
    [sym_rendering_section] = STATE(3587),
    [sym_elements_section] = STATE(3587),
    [sym_schema_section] = STATE(3587),
    [sym_assembly_declaration] = STATE(3587),
    [sym_event_declaration] = STATE(3587),
    [sym_procedure] = STATE(3587),
    [sym_preproc_split_procedure] = STATE(3587),
    [sym_preproc_split_procedure_preamble] = STATE(3587),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(8316),
    [sym_var_section] = STATE(3587),
    [sym_attribute_item] = STATE(8316),
    [sym_preproc_conditional] = STATE(3587),
    [sym_preproc_if] = STATE(2237),
    [sym_preproc_conditional_actions] = STATE(3587),
    [aux_sym_action_group_section_repeat1] = STATE(3587),
    [anon_sym_SEMI] = ACTIONS(7863),
    [anon_sym_RBRACE] = ACTIONS(7866),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7868),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(7874),
    [aux_sym_basic_type_token22] = ACTIONS(7877),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7880),
    [aux_sym_addafter_modification_token1] = ACTIONS(7883),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7886),
    [aux_sym_modify_modification_token1] = ACTIONS(7889),
    [aux_sym_separator_action_token1] = ACTIONS(7892),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7895),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7898),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7901),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7904),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7907),
    [anon_sym_POUNDif] = ACTIONS(7910),
    [anon_sym_POUNDIF] = ACTIONS(7910),
    [anon_sym_POUNDIf] = ACTIONS(7910),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7913),
    [sym_trigger_keyword] = ACTIONS(7916),
    [sym_var_keyword] = ACTIONS(7919),
    [sym_local_keyword] = ACTIONS(7922),
    [sym_internal_keyword] = ACTIONS(7925),
    [sym_protected_keyword] = ACTIONS(7922),
    [sym_event_keyword] = ACTIONS(7928),
    [sym_fields_keyword] = ACTIONS(7931),
    [sym_keys_keyword] = ACTIONS(7934),
    [sym_fieldgroups_keyword] = ACTIONS(7937),
    [sym_actions_keyword] = ACTIONS(7940),
    [sym_layout_keyword] = ACTIONS(7943),
    [sym_area_keyword] = ACTIONS(7946),
    [sym_group_keyword] = ACTIONS(7949),
    [sym_dataset_keyword] = ACTIONS(7952),
    [sym_elements_keyword] = ACTIONS(7955),
    [sym_labels_keyword] = ACTIONS(7958),
    [sym_rendering_keyword] = ACTIONS(7961),
    [sym_requestpage_keyword] = ACTIONS(7964),
    [sym_schema_keyword] = ACTIONS(7967),
    [sym_views_keyword] = ACTIONS(7970),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7973),
    [sym_preproc_open] = ACTIONS(7910),
  },
  [STATE(3588)] = {
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3564),
    [aux_sym_modify_modification_token1] = ACTIONS(3564),
    [aux_sym_xmlport_element_token1] = ACTIONS(3564),
    [aux_sym_xmlport_element_token2] = ACTIONS(3564),
    [aux_sym_xmlport_element_token3] = ACTIONS(3564),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(3564),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(3564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3564),
    [anon_sym_DIV] = ACTIONS(3564),
    [anon_sym_Div] = ACTIONS(3564),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3564),
    [anon_sym_AND] = ACTIONS(3564),
    [anon_sym_And] = ACTIONS(3564),
    [anon_sym_or] = ACTIONS(3564),
    [anon_sym_OR] = ACTIONS(3564),
    [anon_sym_Or] = ACTIONS(3564),
    [anon_sym_xor] = ACTIONS(3564),
    [anon_sym_XOR] = ACTIONS(3564),
    [anon_sym_Xor] = ACTIONS(3564),
    [anon_sym_QMARK] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_procedure_keyword] = ACTIONS(3564),
    [sym_trigger_keyword] = ACTIONS(3564),
    [sym_var_keyword] = ACTIONS(3564),
    [sym_local_keyword] = ACTIONS(3564),
    [sym_internal_keyword] = ACTIONS(3564),
    [sym_protected_keyword] = ACTIONS(3564),
    [sym_event_keyword] = ACTIONS(3564),
    [sym_fields_keyword] = ACTIONS(3564),
    [sym_keys_keyword] = ACTIONS(3564),
    [sym_fieldgroups_keyword] = ACTIONS(3564),
    [sym_actions_keyword] = ACTIONS(3564),
    [sym_layout_keyword] = ACTIONS(3564),
    [sym_dataset_keyword] = ACTIONS(3564),
    [sym_elements_keyword] = ACTIONS(3564),
    [sym_labels_keyword] = ACTIONS(3564),
    [sym_rendering_keyword] = ACTIONS(3564),
    [sym_requestpage_keyword] = ACTIONS(3564),
    [sym_schema_keyword] = ACTIONS(3564),
    [sym_views_keyword] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
    [sym_preproc_close] = ACTIONS(3564),
  },
  [STATE(3589)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_elif] = STATE(3624),
    [sym_preproc_else] = STATE(4054),
    [sym_preproc_endif] = STATE(8073),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [aux_sym_preproc_conditional_query_repeat1] = STATE(10842),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3590)] = {
    [sym__body_element] = STATE(3587),
    [sym_empty_statement] = STATE(3587),
    [sym_property] = STATE(8316),
    [sym_permissions_property] = STATE(3587),
    [sym_table_relation_property] = STATE(3587),
    [sym_fields_section] = STATE(3587),
    [sym_keys_section] = STATE(3587),
    [sym_fieldgroups_section] = STATE(3587),
    [sym_enum_value_declaration] = STATE(3587),
    [sym_labels_section] = STATE(3587),
    [sym_layout_section] = STATE(3587),
    [sym_modify_modification] = STATE(3587),
    [sym_actions_section] = STATE(3587),
    [sym__action_element] = STATE(3587),
    [sym_action_area_section] = STATE(3587),
    [sym_action_group_section] = STATE(3587),
    [sym_action_declaration] = STATE(3587),
    [sym_separator_action] = STATE(3587),
    [sym_actionref_declaration] = STATE(3587),
    [sym_systemaction_declaration] = STATE(3587),
    [sym_fileuploadaction_declaration] = STATE(3587),
    [sym_customaction_declaration] = STATE(3587),
    [sym_addfirst_action_modification] = STATE(3587),
    [sym_addlast_action_modification] = STATE(3587),
    [sym_addafter_action_modification] = STATE(3587),
    [sym_addbefore_action_modification] = STATE(3587),
    [sym_modify_action_modification] = STATE(3587),
    [sym_views_section] = STATE(3587),
    [sym_dataset_section] = STATE(3587),
    [sym_requestpage_section] = STATE(3587),
    [sym_rendering_section] = STATE(3587),
    [sym_elements_section] = STATE(3587),
    [sym_schema_section] = STATE(3587),
    [sym_assembly_declaration] = STATE(3587),
    [sym_event_declaration] = STATE(3587),
    [sym_procedure] = STATE(3587),
    [sym_preproc_split_procedure] = STATE(3587),
    [sym_preproc_split_procedure_preamble] = STATE(3587),
    [sym_procedure_modifier] = STATE(17977),
    [sym_trigger_declaration] = STATE(8316),
    [sym_var_section] = STATE(3587),
    [sym_attribute_item] = STATE(8316),
    [sym_preproc_conditional] = STATE(3587),
    [sym_preproc_if] = STATE(2237),
    [sym_preproc_conditional_actions] = STATE(3587),
    [aux_sym_action_group_section_repeat1] = STATE(3587),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(7976),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7806),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7808),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_basic_type_token22] = ACTIONS(7810),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_addafter_modification_token1] = ACTIONS(7812),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7814),
    [aux_sym_modify_modification_token1] = ACTIONS(7816),
    [aux_sym_separator_action_token1] = ACTIONS(7818),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7820),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7822),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7824),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7826),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6395),
    [sym_trigger_keyword] = ACTIONS(6397),
    [sym_var_keyword] = ACTIONS(7828),
    [sym_local_keyword] = ACTIONS(7830),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7830),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_area_keyword] = ACTIONS(7832),
    [sym_group_keyword] = ACTIONS(7834),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7836),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(3591)] = {
    [sym_argument_list] = STATE(3504),
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_COLON] = ACTIONS(6000),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(7485),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_COLON_COLON] = ACTIONS(7487),
    [anon_sym_POUNDif] = ACTIONS(6002),
    [anon_sym_POUNDIF] = ACTIONS(6002),
    [anon_sym_POUNDIf] = ACTIONS(6002),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_open] = ACTIONS(6002),
  },
  [STATE(3592)] = {
    [sym_boolean] = STATE(3032),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7978),
    [anon_sym_DASH] = ACTIONS(7981),
    [aux_sym_boolean_token1] = ACTIONS(7984),
    [aux_sym_boolean_token2] = ACTIONS(7984),
    [sym_decimal] = ACTIONS(7987),
    [anon_sym_LPAREN] = ACTIONS(7990),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7993),
    [anon_sym_LBRACK] = ACTIONS(7996),
    [aux_sym_record_type_token1] = ACTIONS(7993),
    [aux_sym_basic_type_token21] = ACTIONS(7993),
    [aux_sym_basic_type_token22] = ACTIONS(7993),
    [aux_sym_basic_type_token48] = ACTIONS(7993),
    [anon_sym_not] = ACTIONS(7999),
    [anon_sym_NOT] = ACTIONS(7999),
    [anon_sym_Not] = ACTIONS(7999),
    [anon_sym_POUNDelif] = ACTIONS(8002),
    [anon_sym_POUNDELIF] = ACTIONS(8002),
    [anon_sym_POUNDElif] = ACTIONS(8002),
    [anon_sym_POUNDelse] = ACTIONS(8002),
    [anon_sym_POUNDELSE] = ACTIONS(8002),
    [anon_sym_POUNDElse] = ACTIONS(8002),
    [anon_sym_POUNDelse2] = ACTIONS(8002),
    [anon_sym_POUNDELSE2] = ACTIONS(8002),
    [anon_sym_POUNDElse2] = ACTIONS(8002),
    [anon_sym_POUNDendif] = ACTIONS(8002),
    [anon_sym_POUNDENDIF] = ACTIONS(8002),
    [anon_sym_POUNDEndif] = ACTIONS(8002),
    [anon_sym_POUNDendif2] = ACTIONS(8002),
    [anon_sym_POUNDENDIF2] = ACTIONS(8002),
    [anon_sym_POUNDEndif2] = ACTIONS(8002),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7993),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8004),
    [anon_sym_PLUS] = ACTIONS(7981),
    [sym_datetime_literal] = ACTIONS(8007),
    [sym_date_literal] = ACTIONS(7987),
    [sym_time_literal] = ACTIONS(7987),
    [sym_biginteger_literal] = ACTIONS(8007),
    [sym_page_keyword] = ACTIONS(8004),
    [anon_sym_codeunit] = ACTIONS(8010),
    [anon_sym_CODEUNIT] = ACTIONS(8010),
    [anon_sym_Codeunit] = ACTIONS(8010),
    [anon_sym_CodeUnit] = ACTIONS(8010),
    [anon_sym_COdeunit] = ACTIONS(8010),
    [anon_sym_codeUnit] = ACTIONS(8010),
    [sym_report_keyword] = ACTIONS(8004),
    [sym_query_keyword] = ACTIONS(8004),
    [anon_sym_xmlport] = ACTIONS(8013),
    [anon_sym_XMLPORT] = ACTIONS(8013),
    [anon_sym_Xmlport] = ACTIONS(8013),
    [anon_sym_XMLport] = ACTIONS(8013),
    [anon_sym_XMLPort] = ACTIONS(8013),
    [anon_sym_XmlPort] = ACTIONS(8013),
    [anon_sym_enum] = ACTIONS(8016),
    [anon_sym_ENUM] = ACTIONS(8016),
    [anon_sym_Enum] = ACTIONS(8016),
    [anon_sym_eNUM] = ACTIONS(8016),
    [anon_sym_eNum] = ACTIONS(8016),
    [anon_sym_ENum] = ACTIONS(8016),
    [sym_quoted_identifier] = ACTIONS(8019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8007),
    [sym_verbatim_string] = ACTIONS(8007),
    [sym_integer] = ACTIONS(7987),
    [sym_continue_as_identifier] = ACTIONS(8022),
    [sym_preproc_close] = ACTIONS(8002),
  },
  [STATE(3593)] = {
    [sym_preproc_conditional_controladdin] = STATE(3758),
    [sym__body_element] = STATE(8196),
    [sym_empty_statement] = STATE(8196),
    [sym_property] = STATE(8196),
    [sym_permissions_property] = STATE(8196),
    [sym_table_relation_property] = STATE(8196),
    [sym_fields_section] = STATE(8196),
    [sym_keys_section] = STATE(8196),
    [sym_fieldgroups_section] = STATE(8196),
    [sym_enum_value_declaration] = STATE(8196),
    [sym_labels_section] = STATE(8196),
    [sym_layout_section] = STATE(8196),
    [sym_modify_modification] = STATE(8196),
    [sym_actions_section] = STATE(8196),
    [sym_views_section] = STATE(8196),
    [sym_dataset_section] = STATE(8196),
    [sym_requestpage_section] = STATE(8196),
    [sym_rendering_section] = STATE(8196),
    [sym_elements_section] = STATE(8196),
    [sym_schema_section] = STATE(8196),
    [sym_assembly_declaration] = STATE(8196),
    [sym_event_declaration] = STATE(8196),
    [sym_procedure] = STATE(8196),
    [sym_preproc_split_procedure] = STATE(8196),
    [sym__procedure_preamble] = STATE(10930),
    [sym_preproc_split_procedure_preamble] = STATE(8196),
    [sym__procedure_header] = STATE(9970),
    [sym_interface_procedure] = STATE(3758),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(8196),
    [sym_var_section] = STATE(8196),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(8196),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_elif] = STATE(3894),
    [sym_preproc_else] = STATE(4344),
    [sym_preproc_endif] = STATE(8234),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3834),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3758),
    [aux_sym_preproc_conditional_controladdin_repeat1] = STATE(10653),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10978),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8025),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3594)] = {
    [sym_identifier] = ACTIONS(6673),
    [anon_sym_SEMI] = ACTIONS(6675),
    [anon_sym_DASH] = ACTIONS(6675),
    [aux_sym_boolean_token1] = ACTIONS(6673),
    [aux_sym_boolean_token2] = ACTIONS(6673),
    [sym_decimal] = ACTIONS(6673),
    [anon_sym_LPAREN] = ACTIONS(6675),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6673),
    [anon_sym_LBRACK] = ACTIONS(6675),
    [aux_sym_record_type_token1] = ACTIONS(6673),
    [aux_sym_basic_type_token21] = ACTIONS(6673),
    [aux_sym_basic_type_token22] = ACTIONS(6673),
    [aux_sym_basic_type_token48] = ACTIONS(6673),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(6673),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(6673),
    [anon_sym_POUNDif] = ACTIONS(6675),
    [anon_sym_POUNDIF] = ACTIONS(6675),
    [anon_sym_POUNDIf] = ACTIONS(6675),
    [anon_sym_not] = ACTIONS(6673),
    [anon_sym_NOT] = ACTIONS(6673),
    [anon_sym_Not] = ACTIONS(6673),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6673),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6673),
    [anon_sym_PLUS] = ACTIONS(6675),
    [sym_datetime_literal] = ACTIONS(6675),
    [sym_date_literal] = ACTIONS(6673),
    [sym_time_literal] = ACTIONS(6673),
    [sym_biginteger_literal] = ACTIONS(6675),
    [anon_sym_if] = ACTIONS(6673),
    [anon_sym_IF] = ACTIONS(6673),
    [anon_sym_If] = ACTIONS(6673),
    [anon_sym_case] = ACTIONS(6673),
    [anon_sym_CASE] = ACTIONS(6673),
    [anon_sym_Case] = ACTIONS(6673),
    [anon_sym_for] = ACTIONS(6673),
    [anon_sym_FOR] = ACTIONS(6673),
    [anon_sym_For] = ACTIONS(6673),
    [anon_sym_foreach] = ACTIONS(6673),
    [anon_sym_FOREACH] = ACTIONS(6673),
    [anon_sym_Foreach] = ACTIONS(6673),
    [anon_sym_while] = ACTIONS(6673),
    [anon_sym_WHILE] = ACTIONS(6673),
    [anon_sym_While] = ACTIONS(6673),
    [anon_sym_repeat] = ACTIONS(6673),
    [anon_sym_REPEAT] = ACTIONS(6673),
    [anon_sym_Repeat] = ACTIONS(6673),
    [anon_sym_exit] = ACTIONS(6673),
    [anon_sym_EXIT] = ACTIONS(6673),
    [anon_sym_Exit] = ACTIONS(6673),
    [anon_sym_continue] = ACTIONS(6673),
    [anon_sym_CONTINUE] = ACTIONS(6673),
    [anon_sym_Continue] = ACTIONS(6673),
    [anon_sym_break] = ACTIONS(6673),
    [anon_sym_BREAK] = ACTIONS(6673),
    [anon_sym_Break] = ACTIONS(6673),
    [anon_sym_with] = ACTIONS(6673),
    [anon_sym_WITH] = ACTIONS(6673),
    [anon_sym_With] = ACTIONS(6673),
    [sym_asserterror_keyword] = ACTIONS(6675),
    [sym_page_keyword] = ACTIONS(6673),
    [anon_sym_codeunit] = ACTIONS(6673),
    [anon_sym_CODEUNIT] = ACTIONS(6673),
    [anon_sym_Codeunit] = ACTIONS(6673),
    [anon_sym_CodeUnit] = ACTIONS(6673),
    [anon_sym_COdeunit] = ACTIONS(6673),
    [anon_sym_codeUnit] = ACTIONS(6673),
    [sym_report_keyword] = ACTIONS(6673),
    [sym_query_keyword] = ACTIONS(6673),
    [anon_sym_xmlport] = ACTIONS(6673),
    [anon_sym_XMLPORT] = ACTIONS(6673),
    [anon_sym_Xmlport] = ACTIONS(6673),
    [anon_sym_XMLport] = ACTIONS(6673),
    [anon_sym_XMLPort] = ACTIONS(6673),
    [anon_sym_XmlPort] = ACTIONS(6673),
    [anon_sym_enum] = ACTIONS(6673),
    [anon_sym_ENUM] = ACTIONS(6673),
    [anon_sym_Enum] = ACTIONS(6673),
    [anon_sym_eNUM] = ACTIONS(6673),
    [anon_sym_eNum] = ACTIONS(6673),
    [anon_sym_ENum] = ACTIONS(6673),
    [sym_quoted_identifier] = ACTIONS(6675),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6675),
    [sym_verbatim_string] = ACTIONS(6675),
    [sym_integer] = ACTIONS(6673),
    [sym_continue_as_identifier] = ACTIONS(6675),
    [sym_preproc_open] = ACTIONS(6675),
    [sym_begin_keyword] = ACTIONS(6675),
  },
  [STATE(3595)] = {
    [sym_identifier] = ACTIONS(8027),
    [anon_sym_SEMI] = ACTIONS(8029),
    [anon_sym_DASH] = ACTIONS(8029),
    [aux_sym_boolean_token1] = ACTIONS(8027),
    [aux_sym_boolean_token2] = ACTIONS(8027),
    [sym_decimal] = ACTIONS(8027),
    [anon_sym_LPAREN] = ACTIONS(8029),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8027),
    [anon_sym_LBRACK] = ACTIONS(8029),
    [aux_sym_record_type_token1] = ACTIONS(8027),
    [aux_sym_basic_type_token21] = ACTIONS(8027),
    [aux_sym_basic_type_token22] = ACTIONS(8027),
    [aux_sym_basic_type_token48] = ACTIONS(8027),
    [anon_sym_POUNDif] = ACTIONS(8029),
    [anon_sym_POUNDIF] = ACTIONS(8029),
    [anon_sym_POUNDIf] = ACTIONS(8029),
    [anon_sym_not] = ACTIONS(8027),
    [anon_sym_NOT] = ACTIONS(8027),
    [anon_sym_Not] = ACTIONS(8027),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8027),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8027),
    [anon_sym_PLUS] = ACTIONS(8029),
    [sym_datetime_literal] = ACTIONS(8029),
    [sym_date_literal] = ACTIONS(8027),
    [sym_time_literal] = ACTIONS(8027),
    [sym_biginteger_literal] = ACTIONS(8029),
    [anon_sym_if] = ACTIONS(8027),
    [anon_sym_IF] = ACTIONS(8027),
    [anon_sym_If] = ACTIONS(8027),
    [anon_sym_case] = ACTIONS(8027),
    [anon_sym_CASE] = ACTIONS(8027),
    [anon_sym_Case] = ACTIONS(8027),
    [anon_sym_for] = ACTIONS(8027),
    [anon_sym_FOR] = ACTIONS(8027),
    [anon_sym_For] = ACTIONS(8027),
    [anon_sym_foreach] = ACTIONS(8027),
    [anon_sym_FOREACH] = ACTIONS(8027),
    [anon_sym_Foreach] = ACTIONS(8027),
    [anon_sym_while] = ACTIONS(8027),
    [anon_sym_WHILE] = ACTIONS(8027),
    [anon_sym_While] = ACTIONS(8027),
    [anon_sym_repeat] = ACTIONS(8027),
    [anon_sym_REPEAT] = ACTIONS(8027),
    [anon_sym_Repeat] = ACTIONS(8027),
    [anon_sym_until] = ACTIONS(8027),
    [anon_sym_UNTIL] = ACTIONS(8027),
    [anon_sym_Until] = ACTIONS(8027),
    [anon_sym_exit] = ACTIONS(8027),
    [anon_sym_EXIT] = ACTIONS(8027),
    [anon_sym_Exit] = ACTIONS(8027),
    [anon_sym_continue] = ACTIONS(8027),
    [anon_sym_CONTINUE] = ACTIONS(8027),
    [anon_sym_Continue] = ACTIONS(8027),
    [anon_sym_break] = ACTIONS(8027),
    [anon_sym_BREAK] = ACTIONS(8027),
    [anon_sym_Break] = ACTIONS(8027),
    [anon_sym_with] = ACTIONS(8027),
    [anon_sym_WITH] = ACTIONS(8027),
    [anon_sym_With] = ACTIONS(8027),
    [sym_asserterror_keyword] = ACTIONS(8029),
    [sym_page_keyword] = ACTIONS(8027),
    [anon_sym_codeunit] = ACTIONS(8027),
    [anon_sym_CODEUNIT] = ACTIONS(8027),
    [anon_sym_Codeunit] = ACTIONS(8027),
    [anon_sym_CodeUnit] = ACTIONS(8027),
    [anon_sym_COdeunit] = ACTIONS(8027),
    [anon_sym_codeUnit] = ACTIONS(8027),
    [sym_report_keyword] = ACTIONS(8027),
    [sym_query_keyword] = ACTIONS(8027),
    [anon_sym_xmlport] = ACTIONS(8027),
    [anon_sym_XMLPORT] = ACTIONS(8027),
    [anon_sym_Xmlport] = ACTIONS(8027),
    [anon_sym_XMLport] = ACTIONS(8027),
    [anon_sym_XMLPort] = ACTIONS(8027),
    [anon_sym_XmlPort] = ACTIONS(8027),
    [anon_sym_enum] = ACTIONS(8027),
    [anon_sym_ENUM] = ACTIONS(8027),
    [anon_sym_Enum] = ACTIONS(8027),
    [anon_sym_eNUM] = ACTIONS(8027),
    [anon_sym_eNum] = ACTIONS(8027),
    [anon_sym_ENum] = ACTIONS(8027),
    [sym_quoted_identifier] = ACTIONS(8029),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8029),
    [sym_verbatim_string] = ACTIONS(8029),
    [sym_integer] = ACTIONS(8027),
    [sym_continue_as_identifier] = ACTIONS(8029),
    [sym_preproc_open] = ACTIONS(8029),
  },
  [STATE(3596)] = {
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5405),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5405),
    [aux_sym_modify_modification_token1] = ACTIONS(5405),
    [aux_sym_xmlport_element_token1] = ACTIONS(5405),
    [aux_sym_xmlport_element_token2] = ACTIONS(5405),
    [aux_sym_xmlport_element_token3] = ACTIONS(5405),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5405),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [anon_sym_POUNDelif] = ACTIONS(5405),
    [anon_sym_POUNDELIF] = ACTIONS(5405),
    [anon_sym_POUNDElif] = ACTIONS(5405),
    [anon_sym_POUNDelse] = ACTIONS(5405),
    [anon_sym_POUNDELSE] = ACTIONS(5405),
    [anon_sym_POUNDElse] = ACTIONS(5405),
    [anon_sym_POUNDelse2] = ACTIONS(5405),
    [anon_sym_POUNDELSE2] = ACTIONS(5405),
    [anon_sym_POUNDElse2] = ACTIONS(5405),
    [anon_sym_POUNDendif] = ACTIONS(5405),
    [anon_sym_POUNDENDIF] = ACTIONS(5405),
    [anon_sym_POUNDEndif] = ACTIONS(5405),
    [anon_sym_POUNDendif2] = ACTIONS(5405),
    [anon_sym_POUNDENDIF2] = ACTIONS(5405),
    [anon_sym_POUNDEndif2] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5405),
    [sym_trigger_keyword] = ACTIONS(5405),
    [sym_var_keyword] = ACTIONS(5405),
    [sym_local_keyword] = ACTIONS(5405),
    [sym_internal_keyword] = ACTIONS(5405),
    [sym_protected_keyword] = ACTIONS(5405),
    [sym_event_keyword] = ACTIONS(5405),
    [sym_fields_keyword] = ACTIONS(5405),
    [sym_keys_keyword] = ACTIONS(5405),
    [sym_fieldgroups_keyword] = ACTIONS(5405),
    [sym_actions_keyword] = ACTIONS(5405),
    [sym_layout_keyword] = ACTIONS(5405),
    [sym_dataset_keyword] = ACTIONS(5405),
    [sym_elements_keyword] = ACTIONS(5405),
    [sym_labels_keyword] = ACTIONS(5405),
    [sym_rendering_keyword] = ACTIONS(5405),
    [sym_requestpage_keyword] = ACTIONS(5405),
    [sym_schema_keyword] = ACTIONS(5405),
    [sym_views_keyword] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
    [sym_preproc_close] = ACTIONS(5405),
  },
  [STATE(3597)] = {
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_COLON] = ACTIONS(6000),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(6002),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_COLON_COLON] = ACTIONS(7487),
    [anon_sym_POUNDif] = ACTIONS(6002),
    [anon_sym_POUNDIF] = ACTIONS(6002),
    [anon_sym_POUNDIf] = ACTIONS(6002),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_open] = ACTIONS(6002),
  },
  [STATE(3598)] = {
    [sym_identifier] = ACTIONS(6641),
    [anon_sym_SEMI] = ACTIONS(6643),
    [anon_sym_DASH] = ACTIONS(6643),
    [aux_sym_boolean_token1] = ACTIONS(6641),
    [aux_sym_boolean_token2] = ACTIONS(6641),
    [sym_decimal] = ACTIONS(6641),
    [anon_sym_LPAREN] = ACTIONS(6643),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6641),
    [anon_sym_LBRACK] = ACTIONS(6643),
    [aux_sym_record_type_token1] = ACTIONS(6641),
    [aux_sym_basic_type_token21] = ACTIONS(6641),
    [aux_sym_basic_type_token22] = ACTIONS(6641),
    [aux_sym_basic_type_token48] = ACTIONS(6641),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(6641),
    [anon_sym_POUNDif] = ACTIONS(6643),
    [anon_sym_POUNDIF] = ACTIONS(6643),
    [anon_sym_POUNDIf] = ACTIONS(6643),
    [anon_sym_not] = ACTIONS(6641),
    [anon_sym_NOT] = ACTIONS(6641),
    [anon_sym_Not] = ACTIONS(6641),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6641),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6641),
    [anon_sym_PLUS] = ACTIONS(6643),
    [sym_datetime_literal] = ACTIONS(6643),
    [sym_date_literal] = ACTIONS(6641),
    [sym_time_literal] = ACTIONS(6641),
    [sym_biginteger_literal] = ACTIONS(6643),
    [anon_sym_if] = ACTIONS(6641),
    [anon_sym_IF] = ACTIONS(6641),
    [anon_sym_If] = ACTIONS(6641),
    [anon_sym_case] = ACTIONS(6641),
    [anon_sym_CASE] = ACTIONS(6641),
    [anon_sym_Case] = ACTIONS(6641),
    [anon_sym_for] = ACTIONS(6641),
    [anon_sym_FOR] = ACTIONS(6641),
    [anon_sym_For] = ACTIONS(6641),
    [anon_sym_foreach] = ACTIONS(6641),
    [anon_sym_FOREACH] = ACTIONS(6641),
    [anon_sym_Foreach] = ACTIONS(6641),
    [anon_sym_while] = ACTIONS(6641),
    [anon_sym_WHILE] = ACTIONS(6641),
    [anon_sym_While] = ACTIONS(6641),
    [anon_sym_repeat] = ACTIONS(6641),
    [anon_sym_REPEAT] = ACTIONS(6641),
    [anon_sym_Repeat] = ACTIONS(6641),
    [anon_sym_exit] = ACTIONS(6641),
    [anon_sym_EXIT] = ACTIONS(6641),
    [anon_sym_Exit] = ACTIONS(6641),
    [anon_sym_continue] = ACTIONS(6641),
    [anon_sym_CONTINUE] = ACTIONS(6641),
    [anon_sym_Continue] = ACTIONS(6641),
    [anon_sym_break] = ACTIONS(6641),
    [anon_sym_BREAK] = ACTIONS(6641),
    [anon_sym_Break] = ACTIONS(6641),
    [anon_sym_with] = ACTIONS(6641),
    [anon_sym_WITH] = ACTIONS(6641),
    [anon_sym_With] = ACTIONS(6641),
    [sym_asserterror_keyword] = ACTIONS(6643),
    [sym_page_keyword] = ACTIONS(6641),
    [anon_sym_codeunit] = ACTIONS(6641),
    [anon_sym_CODEUNIT] = ACTIONS(6641),
    [anon_sym_Codeunit] = ACTIONS(6641),
    [anon_sym_CodeUnit] = ACTIONS(6641),
    [anon_sym_COdeunit] = ACTIONS(6641),
    [anon_sym_codeUnit] = ACTIONS(6641),
    [sym_report_keyword] = ACTIONS(6641),
    [sym_query_keyword] = ACTIONS(6641),
    [anon_sym_xmlport] = ACTIONS(6641),
    [anon_sym_XMLPORT] = ACTIONS(6641),
    [anon_sym_Xmlport] = ACTIONS(6641),
    [anon_sym_XMLport] = ACTIONS(6641),
    [anon_sym_XMLPort] = ACTIONS(6641),
    [anon_sym_XmlPort] = ACTIONS(6641),
    [anon_sym_enum] = ACTIONS(6641),
    [anon_sym_ENUM] = ACTIONS(6641),
    [anon_sym_Enum] = ACTIONS(6641),
    [anon_sym_eNUM] = ACTIONS(6641),
    [anon_sym_eNum] = ACTIONS(6641),
    [anon_sym_ENum] = ACTIONS(6641),
    [sym_quoted_identifier] = ACTIONS(6643),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6643),
    [sym_verbatim_string] = ACTIONS(6643),
    [sym_integer] = ACTIONS(6641),
    [sym_continue_as_identifier] = ACTIONS(6643),
    [sym_preproc_open] = ACTIONS(6643),
    [sym_begin_keyword] = ACTIONS(6643),
    [sym_preproc_split_begin] = ACTIONS(6643),
  },
  [STATE(3599)] = {
    [sym_preproc_conditional_controladdin] = STATE(3765),
    [sym__body_element] = STATE(8196),
    [sym_empty_statement] = STATE(8196),
    [sym_property] = STATE(8196),
    [sym_permissions_property] = STATE(8196),
    [sym_table_relation_property] = STATE(8196),
    [sym_fields_section] = STATE(8196),
    [sym_keys_section] = STATE(8196),
    [sym_fieldgroups_section] = STATE(8196),
    [sym_enum_value_declaration] = STATE(8196),
    [sym_labels_section] = STATE(8196),
    [sym_layout_section] = STATE(8196),
    [sym_modify_modification] = STATE(8196),
    [sym_actions_section] = STATE(8196),
    [sym_views_section] = STATE(8196),
    [sym_dataset_section] = STATE(8196),
    [sym_requestpage_section] = STATE(8196),
    [sym_rendering_section] = STATE(8196),
    [sym_elements_section] = STATE(8196),
    [sym_schema_section] = STATE(8196),
    [sym_assembly_declaration] = STATE(8196),
    [sym_event_declaration] = STATE(8196),
    [sym_procedure] = STATE(8196),
    [sym_preproc_split_procedure] = STATE(8196),
    [sym__procedure_preamble] = STATE(10810),
    [sym_preproc_split_procedure_preamble] = STATE(8196),
    [sym__procedure_header] = STATE(9981),
    [sym_interface_procedure] = STATE(3765),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(8196),
    [sym_var_section] = STATE(8196),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(8196),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_elif] = STATE(3894),
    [sym_preproc_else] = STATE(4392),
    [sym_preproc_endif] = STATE(9974),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3826),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3765),
    [aux_sym_preproc_conditional_controladdin_repeat1] = STATE(10678),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10844),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8025),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3600)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(2288),
    [sym_assignment_expression] = STATE(8793),
    [sym_preproc_conditional_case] = STATE(3600),
    [sym_case_branch] = STATE(3600),
    [sym_preproc_split_case_branch] = STATE(6559),
    [sym_preproc_split_case_extended] = STATE(3600),
    [aux_sym__case_pattern] = STATE(3892),
    [sym_preproc_conditional_case_patterns] = STATE(3892),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_case_statement_repeat1] = STATE(3600),
    [sym_identifier] = ACTIONS(8031),
    [anon_sym_DASH] = ACTIONS(8034),
    [aux_sym_boolean_token1] = ACTIONS(8037),
    [aux_sym_boolean_token2] = ACTIONS(8037),
    [sym_decimal] = ACTIONS(8040),
    [anon_sym_LPAREN] = ACTIONS(8043),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8046),
    [anon_sym_LBRACK] = ACTIONS(8049),
    [aux_sym_record_type_token1] = ACTIONS(8046),
    [aux_sym_basic_type_token21] = ACTIONS(8046),
    [aux_sym_basic_type_token22] = ACTIONS(8046),
    [aux_sym_basic_type_token48] = ACTIONS(8046),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(8052),
    [anon_sym_POUNDif] = ACTIONS(8054),
    [anon_sym_POUNDIF] = ACTIONS(8054),
    [anon_sym_POUNDIf] = ACTIONS(8054),
    [anon_sym_not] = ACTIONS(8057),
    [anon_sym_NOT] = ACTIONS(8057),
    [anon_sym_Not] = ACTIONS(8057),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8046),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8060),
    [anon_sym_PLUS] = ACTIONS(8034),
    [sym_datetime_literal] = ACTIONS(8063),
    [sym_date_literal] = ACTIONS(8040),
    [sym_time_literal] = ACTIONS(8040),
    [sym_biginteger_literal] = ACTIONS(8063),
    [anon_sym_else] = ACTIONS(8052),
    [anon_sym_ELSE] = ACTIONS(8052),
    [anon_sym_Else] = ACTIONS(8052),
    [sym_page_keyword] = ACTIONS(8060),
    [anon_sym_codeunit] = ACTIONS(8066),
    [anon_sym_CODEUNIT] = ACTIONS(8066),
    [anon_sym_Codeunit] = ACTIONS(8066),
    [anon_sym_CodeUnit] = ACTIONS(8066),
    [anon_sym_COdeunit] = ACTIONS(8066),
    [anon_sym_codeUnit] = ACTIONS(8066),
    [sym_report_keyword] = ACTIONS(8060),
    [sym_query_keyword] = ACTIONS(8060),
    [anon_sym_xmlport] = ACTIONS(8069),
    [anon_sym_XMLPORT] = ACTIONS(8069),
    [anon_sym_Xmlport] = ACTIONS(8069),
    [anon_sym_XMLport] = ACTIONS(8069),
    [anon_sym_XMLPort] = ACTIONS(8069),
    [anon_sym_XmlPort] = ACTIONS(8069),
    [anon_sym_enum] = ACTIONS(8072),
    [anon_sym_ENUM] = ACTIONS(8072),
    [anon_sym_Enum] = ACTIONS(8072),
    [anon_sym_eNUM] = ACTIONS(8072),
    [anon_sym_eNum] = ACTIONS(8072),
    [anon_sym_ENum] = ACTIONS(8072),
    [sym_quoted_identifier] = ACTIONS(8075),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8063),
    [sym_verbatim_string] = ACTIONS(8063),
    [sym_integer] = ACTIONS(8040),
    [sym_continue_as_identifier] = ACTIONS(8078),
    [sym_preproc_open] = ACTIONS(8054),
  },
  [STATE(3601)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_elif] = STATE(3808),
    [sym_preproc_else] = STATE(4081),
    [sym_preproc_endif] = STATE(8139),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [aux_sym_preproc_conditional_report_repeat1] = STATE(10841),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3602)] = {
    [sym_boolean] = STATE(8663),
    [sym_assignment_expression] = STATE(8663),
    [sym__expression] = STATE(8663),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8663),
    [sym_multiplicative_expression] = STATE(8663),
    [sym_additive_expression] = STATE(8663),
    [sym_comparison_expression] = STATE(8663),
    [sym_logical_expression] = STATE(8663),
    [sym_ternary_expression] = STATE(8663),
    [sym_unary_expression] = STATE(8663),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8663),
    [sym_list_literal] = STATE(8663),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8663),
    [sym__literal_value] = STATE(8663),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8083),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(8085),
    [anon_sym_POUNDELIF] = ACTIONS(8085),
    [anon_sym_POUNDElif] = ACTIONS(8085),
    [anon_sym_POUNDelse] = ACTIONS(8085),
    [anon_sym_POUNDELSE] = ACTIONS(8085),
    [anon_sym_POUNDElse] = ACTIONS(8085),
    [anon_sym_POUNDelse2] = ACTIONS(8085),
    [anon_sym_POUNDELSE2] = ACTIONS(8085),
    [anon_sym_POUNDElse2] = ACTIONS(8085),
    [anon_sym_POUNDendif] = ACTIONS(8085),
    [anon_sym_POUNDENDIF] = ACTIONS(8085),
    [anon_sym_POUNDEndif] = ACTIONS(8085),
    [anon_sym_POUNDendif2] = ACTIONS(8085),
    [anon_sym_POUNDENDIF2] = ACTIONS(8085),
    [anon_sym_POUNDEndif2] = ACTIONS(8085),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(8087),
    [sym_date_literal] = ACTIONS(8083),
    [sym_time_literal] = ACTIONS(8083),
    [sym_biginteger_literal] = ACTIONS(8087),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8087),
    [sym_verbatim_string] = ACTIONS(8087),
    [sym_integer] = ACTIONS(8083),
    [sym_continue_as_identifier] = ACTIONS(8087),
    [sym_preproc_close] = ACTIONS(8085),
  },
  [STATE(3603)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_DASH] = ACTIONS(5277),
    [aux_sym_boolean_token1] = ACTIONS(5279),
    [aux_sym_boolean_token2] = ACTIONS(5279),
    [sym_decimal] = ACTIONS(5279),
    [anon_sym_LPAREN] = ACTIONS(5277),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_record_type_token1] = ACTIONS(5279),
    [aux_sym_basic_type_token21] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token48] = ACTIONS(5279),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_not] = ACTIONS(5279),
    [anon_sym_NOT] = ACTIONS(5279),
    [anon_sym_Not] = ACTIONS(5279),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5279),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5279),
    [anon_sym_PLUS] = ACTIONS(5277),
    [sym_datetime_literal] = ACTIONS(5277),
    [sym_date_literal] = ACTIONS(5279),
    [sym_time_literal] = ACTIONS(5279),
    [sym_biginteger_literal] = ACTIONS(5277),
    [anon_sym_if] = ACTIONS(5279),
    [anon_sym_IF] = ACTIONS(5279),
    [anon_sym_If] = ACTIONS(5279),
    [anon_sym_case] = ACTIONS(5279),
    [anon_sym_CASE] = ACTIONS(5279),
    [anon_sym_Case] = ACTIONS(5279),
    [anon_sym_for] = ACTIONS(5279),
    [anon_sym_FOR] = ACTIONS(5279),
    [anon_sym_For] = ACTIONS(5279),
    [anon_sym_foreach] = ACTIONS(5279),
    [anon_sym_FOREACH] = ACTIONS(5279),
    [anon_sym_Foreach] = ACTIONS(5279),
    [anon_sym_while] = ACTIONS(5279),
    [anon_sym_WHILE] = ACTIONS(5279),
    [anon_sym_While] = ACTIONS(5279),
    [anon_sym_repeat] = ACTIONS(5279),
    [anon_sym_REPEAT] = ACTIONS(5279),
    [anon_sym_Repeat] = ACTIONS(5279),
    [anon_sym_exit] = ACTIONS(5279),
    [anon_sym_EXIT] = ACTIONS(5279),
    [anon_sym_Exit] = ACTIONS(5279),
    [anon_sym_continue] = ACTIONS(5279),
    [anon_sym_CONTINUE] = ACTIONS(5279),
    [anon_sym_Continue] = ACTIONS(5279),
    [anon_sym_break] = ACTIONS(5279),
    [anon_sym_BREAK] = ACTIONS(5279),
    [anon_sym_Break] = ACTIONS(5279),
    [anon_sym_with] = ACTIONS(5279),
    [anon_sym_WITH] = ACTIONS(5279),
    [anon_sym_With] = ACTIONS(5279),
    [sym_asserterror_keyword] = ACTIONS(5277),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [anon_sym_enum] = ACTIONS(5279),
    [anon_sym_ENUM] = ACTIONS(5279),
    [anon_sym_Enum] = ACTIONS(5279),
    [anon_sym_eNUM] = ACTIONS(5279),
    [anon_sym_eNum] = ACTIONS(5279),
    [anon_sym_ENum] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5277),
    [sym_verbatim_string] = ACTIONS(5277),
    [sym_integer] = ACTIONS(5279),
    [sym_continue_as_identifier] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_begin_keyword] = ACTIONS(5277),
  },
  [STATE(3604)] = {
    [sym_identifier] = ACTIONS(8091),
    [anon_sym_SEMI] = ACTIONS(8093),
    [anon_sym_DASH] = ACTIONS(8093),
    [aux_sym_boolean_token1] = ACTIONS(8091),
    [aux_sym_boolean_token2] = ACTIONS(8091),
    [sym_decimal] = ACTIONS(8091),
    [anon_sym_LPAREN] = ACTIONS(8093),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8091),
    [anon_sym_LBRACK] = ACTIONS(8093),
    [aux_sym_record_type_token1] = ACTIONS(8091),
    [aux_sym_basic_type_token21] = ACTIONS(8091),
    [aux_sym_basic_type_token22] = ACTIONS(8091),
    [aux_sym_basic_type_token48] = ACTIONS(8091),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(8091),
    [anon_sym_POUNDif] = ACTIONS(8093),
    [anon_sym_POUNDIF] = ACTIONS(8093),
    [anon_sym_POUNDIf] = ACTIONS(8093),
    [anon_sym_not] = ACTIONS(8091),
    [anon_sym_NOT] = ACTIONS(8091),
    [anon_sym_Not] = ACTIONS(8091),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8091),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8091),
    [anon_sym_PLUS] = ACTIONS(8093),
    [sym_datetime_literal] = ACTIONS(8093),
    [sym_date_literal] = ACTIONS(8091),
    [sym_time_literal] = ACTIONS(8091),
    [sym_biginteger_literal] = ACTIONS(8093),
    [anon_sym_if] = ACTIONS(8091),
    [anon_sym_IF] = ACTIONS(8091),
    [anon_sym_If] = ACTIONS(8091),
    [anon_sym_case] = ACTIONS(8091),
    [anon_sym_CASE] = ACTIONS(8091),
    [anon_sym_Case] = ACTIONS(8091),
    [anon_sym_for] = ACTIONS(8091),
    [anon_sym_FOR] = ACTIONS(8091),
    [anon_sym_For] = ACTIONS(8091),
    [anon_sym_foreach] = ACTIONS(8091),
    [anon_sym_FOREACH] = ACTIONS(8091),
    [anon_sym_Foreach] = ACTIONS(8091),
    [anon_sym_while] = ACTIONS(8091),
    [anon_sym_WHILE] = ACTIONS(8091),
    [anon_sym_While] = ACTIONS(8091),
    [anon_sym_repeat] = ACTIONS(8091),
    [anon_sym_REPEAT] = ACTIONS(8091),
    [anon_sym_Repeat] = ACTIONS(8091),
    [anon_sym_exit] = ACTIONS(8091),
    [anon_sym_EXIT] = ACTIONS(8091),
    [anon_sym_Exit] = ACTIONS(8091),
    [anon_sym_continue] = ACTIONS(8091),
    [anon_sym_CONTINUE] = ACTIONS(8091),
    [anon_sym_Continue] = ACTIONS(8091),
    [anon_sym_break] = ACTIONS(8091),
    [anon_sym_BREAK] = ACTIONS(8091),
    [anon_sym_Break] = ACTIONS(8091),
    [anon_sym_with] = ACTIONS(8091),
    [anon_sym_WITH] = ACTIONS(8091),
    [anon_sym_With] = ACTIONS(8091),
    [sym_asserterror_keyword] = ACTIONS(8093),
    [sym_page_keyword] = ACTIONS(8091),
    [anon_sym_codeunit] = ACTIONS(8091),
    [anon_sym_CODEUNIT] = ACTIONS(8091),
    [anon_sym_Codeunit] = ACTIONS(8091),
    [anon_sym_CodeUnit] = ACTIONS(8091),
    [anon_sym_COdeunit] = ACTIONS(8091),
    [anon_sym_codeUnit] = ACTIONS(8091),
    [sym_report_keyword] = ACTIONS(8091),
    [sym_query_keyword] = ACTIONS(8091),
    [anon_sym_xmlport] = ACTIONS(8091),
    [anon_sym_XMLPORT] = ACTIONS(8091),
    [anon_sym_Xmlport] = ACTIONS(8091),
    [anon_sym_XMLport] = ACTIONS(8091),
    [anon_sym_XMLPort] = ACTIONS(8091),
    [anon_sym_XmlPort] = ACTIONS(8091),
    [anon_sym_enum] = ACTIONS(8091),
    [anon_sym_ENUM] = ACTIONS(8091),
    [anon_sym_Enum] = ACTIONS(8091),
    [anon_sym_eNUM] = ACTIONS(8091),
    [anon_sym_eNum] = ACTIONS(8091),
    [anon_sym_ENum] = ACTIONS(8091),
    [sym_quoted_identifier] = ACTIONS(8093),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8093),
    [sym_verbatim_string] = ACTIONS(8093),
    [sym_integer] = ACTIONS(8091),
    [sym_continue_as_identifier] = ACTIONS(8093),
    [sym_preproc_open] = ACTIONS(8093),
    [sym_begin_keyword] = ACTIONS(8093),
  },
  [STATE(3605)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_elif] = STATE(3808),
    [sym_preproc_else] = STATE(4077),
    [sym_preproc_endif] = STATE(9950),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [aux_sym_preproc_conditional_report_repeat1] = STATE(10992),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3606)] = {
    [sym_identifier] = ACTIONS(6683),
    [anon_sym_DOT] = ACTIONS(3873),
    [anon_sym_EQ] = ACTIONS(3875),
    [anon_sym_COMMA] = ACTIONS(6685),
    [anon_sym_COLON] = ACTIONS(6683),
    [anon_sym_DASH] = ACTIONS(6687),
    [aux_sym_boolean_token1] = ACTIONS(6683),
    [aux_sym_boolean_token2] = ACTIONS(6683),
    [sym_decimal] = ACTIONS(6683),
    [anon_sym_LPAREN] = ACTIONS(6685),
    [anon_sym_DOT_DOT] = ACTIONS(3875),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6683),
    [anon_sym_STAR] = ACTIONS(3873),
    [anon_sym_LBRACK] = ACTIONS(6690),
    [aux_sym_record_type_token1] = ACTIONS(6683),
    [aux_sym_basic_type_token21] = ACTIONS(6683),
    [aux_sym_basic_type_token22] = ACTIONS(6683),
    [aux_sym_basic_type_token48] = ACTIONS(6683),
    [anon_sym_POUNDif] = ACTIONS(6685),
    [anon_sym_POUNDIF] = ACTIONS(6685),
    [anon_sym_POUNDIf] = ACTIONS(6685),
    [anon_sym_not] = ACTIONS(6683),
    [anon_sym_NOT] = ACTIONS(6683),
    [anon_sym_Not] = ACTIONS(6683),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3875),
    [aux_sym__expression_token1] = ACTIONS(3875),
    [aux_sym__expression_token2] = ACTIONS(3875),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6683),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6683),
    [anon_sym_SLASH] = ACTIONS(3873),
    [anon_sym_div] = ACTIONS(3873),
    [anon_sym_DIV] = ACTIONS(3873),
    [anon_sym_Div] = ACTIONS(3873),
    [anon_sym_mod] = ACTIONS(3873),
    [anon_sym_MOD] = ACTIONS(3873),
    [anon_sym_Mod] = ACTIONS(3873),
    [anon_sym_PLUS] = ACTIONS(6687),
    [anon_sym_GT_EQ] = ACTIONS(3875),
    [anon_sym_LT_EQ] = ACTIONS(3875),
    [anon_sym_GT] = ACTIONS(3873),
    [anon_sym_LT] = ACTIONS(3873),
    [anon_sym_LT_GT] = ACTIONS(3875),
    [anon_sym_and] = ACTIONS(3873),
    [anon_sym_AND] = ACTIONS(3873),
    [anon_sym_And] = ACTIONS(3873),
    [anon_sym_or] = ACTIONS(3873),
    [anon_sym_OR] = ACTIONS(3873),
    [anon_sym_Or] = ACTIONS(3873),
    [anon_sym_xor] = ACTIONS(3873),
    [anon_sym_XOR] = ACTIONS(3873),
    [anon_sym_Xor] = ACTIONS(3873),
    [anon_sym_QMARK] = ACTIONS(3875),
    [sym_datetime_literal] = ACTIONS(6685),
    [sym_date_literal] = ACTIONS(6683),
    [sym_time_literal] = ACTIONS(6683),
    [sym_biginteger_literal] = ACTIONS(6685),
    [anon_sym_in] = ACTIONS(3873),
    [anon_sym_IN] = ACTIONS(3873),
    [anon_sym_In] = ACTIONS(3873),
    [sym_page_keyword] = ACTIONS(6683),
    [anon_sym_codeunit] = ACTIONS(6683),
    [anon_sym_CODEUNIT] = ACTIONS(6683),
    [anon_sym_Codeunit] = ACTIONS(6683),
    [anon_sym_CodeUnit] = ACTIONS(6683),
    [anon_sym_COdeunit] = ACTIONS(6683),
    [anon_sym_codeUnit] = ACTIONS(6683),
    [sym_report_keyword] = ACTIONS(6683),
    [sym_query_keyword] = ACTIONS(6683),
    [anon_sym_xmlport] = ACTIONS(6683),
    [anon_sym_XMLPORT] = ACTIONS(6683),
    [anon_sym_Xmlport] = ACTIONS(6683),
    [anon_sym_XMLport] = ACTIONS(6683),
    [anon_sym_XMLPort] = ACTIONS(6683),
    [anon_sym_XmlPort] = ACTIONS(6683),
    [anon_sym_enum] = ACTIONS(6683),
    [anon_sym_ENUM] = ACTIONS(6683),
    [anon_sym_Enum] = ACTIONS(6683),
    [anon_sym_eNUM] = ACTIONS(6683),
    [anon_sym_eNum] = ACTIONS(6683),
    [anon_sym_ENum] = ACTIONS(6683),
    [sym_quoted_identifier] = ACTIONS(6685),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6685),
    [sym_verbatim_string] = ACTIONS(6685),
    [sym_integer] = ACTIONS(6683),
    [sym_continue_as_identifier] = ACTIONS(6685),
    [sym_preproc_open] = ACTIONS(6685),
  },
  [STATE(3607)] = {
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(6589),
    [anon_sym_EQ] = ACTIONS(6591),
    [anon_sym_DASH] = ACTIONS(6589),
    [aux_sym_where_clause_token1] = ACTIONS(3695),
    [anon_sym_DOT_DOT] = ACTIONS(6591),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3695),
    [anon_sym_STAR] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(6593),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3695),
    [aux_sym_modify_modification_token1] = ACTIONS(3695),
    [aux_sym_xmlport_element_token1] = ACTIONS(3695),
    [aux_sym_xmlport_element_token2] = ACTIONS(3695),
    [aux_sym_xmlport_element_token3] = ACTIONS(3695),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(3695),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(3695),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_POUNDelif] = ACTIONS(3695),
    [anon_sym_POUNDELIF] = ACTIONS(3695),
    [anon_sym_POUNDElif] = ACTIONS(3695),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [anon_sym_POUNDendif] = ACTIONS(3695),
    [anon_sym_POUNDENDIF] = ACTIONS(3695),
    [anon_sym_POUNDEndif] = ACTIONS(3695),
    [anon_sym_POUNDendif2] = ACTIONS(3695),
    [anon_sym_POUNDENDIF2] = ACTIONS(3695),
    [anon_sym_POUNDEndif2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6591),
    [aux_sym__expression_token1] = ACTIONS(6591),
    [aux_sym__expression_token2] = ACTIONS(6591),
    [anon_sym_SLASH] = ACTIONS(6589),
    [anon_sym_div] = ACTIONS(6591),
    [anon_sym_DIV] = ACTIONS(6591),
    [anon_sym_Div] = ACTIONS(6591),
    [anon_sym_mod] = ACTIONS(6589),
    [anon_sym_MOD] = ACTIONS(6589),
    [anon_sym_Mod] = ACTIONS(6589),
    [anon_sym_PLUS] = ACTIONS(6589),
    [anon_sym_GT_EQ] = ACTIONS(6591),
    [anon_sym_LT_EQ] = ACTIONS(6591),
    [anon_sym_GT] = ACTIONS(6589),
    [anon_sym_LT] = ACTIONS(6589),
    [anon_sym_LT_GT] = ACTIONS(6591),
    [anon_sym_and] = ACTIONS(6591),
    [anon_sym_AND] = ACTIONS(6591),
    [anon_sym_And] = ACTIONS(6591),
    [anon_sym_or] = ACTIONS(6591),
    [anon_sym_OR] = ACTIONS(6591),
    [anon_sym_Or] = ACTIONS(6591),
    [anon_sym_xor] = ACTIONS(6591),
    [anon_sym_XOR] = ACTIONS(6591),
    [anon_sym_Xor] = ACTIONS(6591),
    [anon_sym_QMARK] = ACTIONS(6591),
    [anon_sym_in] = ACTIONS(6589),
    [anon_sym_IN] = ACTIONS(6589),
    [anon_sym_In] = ACTIONS(6589),
    [sym_procedure_keyword] = ACTIONS(3695),
    [sym_trigger_keyword] = ACTIONS(3695),
    [sym_var_keyword] = ACTIONS(3695),
    [sym_local_keyword] = ACTIONS(3695),
    [sym_internal_keyword] = ACTIONS(3695),
    [sym_protected_keyword] = ACTIONS(3695),
    [sym_event_keyword] = ACTIONS(3695),
    [sym_fields_keyword] = ACTIONS(3695),
    [sym_keys_keyword] = ACTIONS(3695),
    [sym_fieldgroups_keyword] = ACTIONS(3695),
    [sym_actions_keyword] = ACTIONS(3695),
    [sym_layout_keyword] = ACTIONS(3695),
    [sym_dataset_keyword] = ACTIONS(3695),
    [sym_elements_keyword] = ACTIONS(3695),
    [sym_labels_keyword] = ACTIONS(3695),
    [sym_rendering_keyword] = ACTIONS(3695),
    [sym_requestpage_keyword] = ACTIONS(3695),
    [sym_schema_keyword] = ACTIONS(3695),
    [sym_views_keyword] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
    [sym_preproc_close] = ACTIONS(3695),
  },
  [STATE(3608)] = {
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_COLON] = ACTIONS(6000),
    [anon_sym_DASH] = ACTIONS(6004),
    [aux_sym_boolean_token1] = ACTIONS(6000),
    [aux_sym_boolean_token2] = ACTIONS(6000),
    [sym_decimal] = ACTIONS(6000),
    [anon_sym_LPAREN] = ACTIONS(6002),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(6007),
    [aux_sym_record_type_token1] = ACTIONS(6000),
    [aux_sym_basic_type_token21] = ACTIONS(6000),
    [aux_sym_basic_type_token22] = ACTIONS(6000),
    [aux_sym_basic_type_token48] = ACTIONS(6000),
    [anon_sym_POUNDif] = ACTIONS(6002),
    [anon_sym_POUNDIF] = ACTIONS(6002),
    [anon_sym_POUNDIf] = ACTIONS(6002),
    [anon_sym_not] = ACTIONS(6000),
    [anon_sym_NOT] = ACTIONS(6000),
    [anon_sym_Not] = ACTIONS(6000),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6000),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(6004),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(6002),
    [sym_date_literal] = ACTIONS(6000),
    [sym_time_literal] = ACTIONS(6000),
    [sym_biginteger_literal] = ACTIONS(6002),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(6000),
    [anon_sym_codeunit] = ACTIONS(6000),
    [anon_sym_CODEUNIT] = ACTIONS(6000),
    [anon_sym_Codeunit] = ACTIONS(6000),
    [anon_sym_CodeUnit] = ACTIONS(6000),
    [anon_sym_COdeunit] = ACTIONS(6000),
    [anon_sym_codeUnit] = ACTIONS(6000),
    [sym_report_keyword] = ACTIONS(6000),
    [sym_query_keyword] = ACTIONS(6000),
    [anon_sym_xmlport] = ACTIONS(6000),
    [anon_sym_XMLPORT] = ACTIONS(6000),
    [anon_sym_Xmlport] = ACTIONS(6000),
    [anon_sym_XMLport] = ACTIONS(6000),
    [anon_sym_XMLPort] = ACTIONS(6000),
    [anon_sym_XmlPort] = ACTIONS(6000),
    [anon_sym_enum] = ACTIONS(6000),
    [anon_sym_ENUM] = ACTIONS(6000),
    [anon_sym_Enum] = ACTIONS(6000),
    [anon_sym_eNUM] = ACTIONS(6000),
    [anon_sym_eNum] = ACTIONS(6000),
    [anon_sym_ENum] = ACTIONS(6000),
    [sym_quoted_identifier] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6002),
    [sym_verbatim_string] = ACTIONS(6002),
    [sym_integer] = ACTIONS(6000),
    [sym_continue_as_identifier] = ACTIONS(6002),
    [sym_preproc_open] = ACTIONS(6002),
  },
  [STATE(3609)] = {
    [sym__body_element] = STATE(7554),
    [sym_empty_statement] = STATE(7554),
    [sym_property] = STATE(7554),
    [sym_permissions_property] = STATE(7554),
    [sym_table_relation_property] = STATE(7554),
    [sym_fields_section] = STATE(7554),
    [sym_keys_section] = STATE(7554),
    [sym_fieldgroups_section] = STATE(7554),
    [sym_enum_value_declaration] = STATE(7554),
    [sym_labels_section] = STATE(7554),
    [sym_layout_section] = STATE(7554),
    [sym_modify_modification] = STATE(7554),
    [sym_actions_section] = STATE(7554),
    [sym_views_section] = STATE(7554),
    [sym_dataset_section] = STATE(7554),
    [sym_requestpage_section] = STATE(7554),
    [sym_rendering_section] = STATE(7554),
    [sym_elements_section] = STATE(7554),
    [sym_schema_section] = STATE(7554),
    [sym_xmlport_element] = STATE(3618),
    [sym__xmlport_body_element] = STATE(3618),
    [sym_preproc_conditional_xmlport] = STATE(3618),
    [sym_xmlport_attribute] = STATE(3618),
    [sym_assembly_declaration] = STATE(7554),
    [sym_event_declaration] = STATE(7554),
    [sym_procedure] = STATE(7554),
    [sym_preproc_split_procedure] = STATE(7554),
    [sym_preproc_split_procedure_preamble] = STATE(7554),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(7554),
    [sym_var_section] = STATE(7554),
    [sym_attribute_item] = STATE(7554),
    [sym_preproc_conditional] = STATE(7554),
    [sym_preproc_if] = STATE(3423),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4033),
    [aux_sym_xmlport_element_repeat1] = STATE(3618),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDelif] = ACTIONS(8095),
    [anon_sym_POUNDELIF] = ACTIONS(8095),
    [anon_sym_POUNDElif] = ACTIONS(8095),
    [anon_sym_POUNDelse] = ACTIONS(8095),
    [anon_sym_POUNDELSE] = ACTIONS(8095),
    [anon_sym_POUNDElse] = ACTIONS(8095),
    [anon_sym_POUNDelse2] = ACTIONS(8095),
    [anon_sym_POUNDELSE2] = ACTIONS(8095),
    [anon_sym_POUNDElse2] = ACTIONS(8095),
    [anon_sym_POUNDendif] = ACTIONS(8095),
    [anon_sym_POUNDENDIF] = ACTIONS(8095),
    [anon_sym_POUNDEndif] = ACTIONS(8095),
    [anon_sym_POUNDendif2] = ACTIONS(8095),
    [anon_sym_POUNDENDIF2] = ACTIONS(8095),
    [anon_sym_POUNDEndif2] = ACTIONS(8095),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(8095),
  },
  [STATE(3610)] = {
    [sym_boolean] = STATE(8663),
    [sym_assignment_expression] = STATE(8663),
    [sym__expression] = STATE(8663),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8663),
    [sym_multiplicative_expression] = STATE(8663),
    [sym_additive_expression] = STATE(8663),
    [sym_comparison_expression] = STATE(8663),
    [sym_logical_expression] = STATE(8663),
    [sym_ternary_expression] = STATE(8663),
    [sym_unary_expression] = STATE(8663),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8663),
    [sym_list_literal] = STATE(8663),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8663),
    [sym__literal_value] = STATE(8663),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8083),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [anon_sym_POUNDelif] = ACTIONS(8098),
    [anon_sym_POUNDELIF] = ACTIONS(8098),
    [anon_sym_POUNDElif] = ACTIONS(8098),
    [anon_sym_POUNDelse] = ACTIONS(8098),
    [anon_sym_POUNDELSE] = ACTIONS(8098),
    [anon_sym_POUNDElse] = ACTIONS(8098),
    [anon_sym_POUNDelse2] = ACTIONS(8098),
    [anon_sym_POUNDELSE2] = ACTIONS(8098),
    [anon_sym_POUNDElse2] = ACTIONS(8098),
    [anon_sym_POUNDendif] = ACTIONS(8098),
    [anon_sym_POUNDENDIF] = ACTIONS(8098),
    [anon_sym_POUNDEndif] = ACTIONS(8098),
    [anon_sym_POUNDendif2] = ACTIONS(8098),
    [anon_sym_POUNDENDIF2] = ACTIONS(8098),
    [anon_sym_POUNDEndif2] = ACTIONS(8098),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(8087),
    [sym_date_literal] = ACTIONS(8083),
    [sym_time_literal] = ACTIONS(8083),
    [sym_biginteger_literal] = ACTIONS(8087),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8087),
    [sym_verbatim_string] = ACTIONS(8087),
    [sym_integer] = ACTIONS(8083),
    [sym_continue_as_identifier] = ACTIONS(8087),
    [sym_preproc_close] = ACTIONS(8098),
  },
  [STATE(3611)] = {
    [sym_identifier] = ACTIONS(5358),
    [anon_sym_COMMA] = ACTIONS(5360),
    [anon_sym_DASH] = ACTIONS(5360),
    [aux_sym_boolean_token1] = ACTIONS(5358),
    [aux_sym_boolean_token2] = ACTIONS(5358),
    [sym_decimal] = ACTIONS(5358),
    [anon_sym_LPAREN] = ACTIONS(5360),
    [aux_sym_where_condition_token1] = ACTIONS(5358),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5358),
    [aux_sym_if_table_relation_token1] = ACTIONS(5358),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5358),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5358),
    [anon_sym_LBRACK] = ACTIONS(5360),
    [aux_sym_record_type_token1] = ACTIONS(5358),
    [aux_sym_basic_type_token21] = ACTIONS(5358),
    [aux_sym_basic_type_token22] = ACTIONS(5358),
    [aux_sym_basic_type_token48] = ACTIONS(5358),
    [aux_sym_basic_type_token53] = ACTIONS(5358),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5358),
    [aux_sym_separator_action_token1] = ACTIONS(5358),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5358),
    [aux_sym_type_declaration_token1] = ACTIONS(5358),
    [anon_sym_POUNDif] = ACTIONS(5360),
    [anon_sym_POUNDIF] = ACTIONS(5360),
    [anon_sym_POUNDIf] = ACTIONS(5360),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8100),
    [anon_sym_PIPE_PIPE] = ACTIONS(8102),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8104),
    [anon_sym_AMP_AMP] = ACTIONS(8106),
    [anon_sym_not] = ACTIONS(5358),
    [anon_sym_NOT] = ACTIONS(5358),
    [anon_sym_Not] = ACTIONS(5358),
    [anon_sym_POUNDelif] = ACTIONS(5360),
    [anon_sym_POUNDELIF] = ACTIONS(5360),
    [anon_sym_POUNDElif] = ACTIONS(5360),
    [anon_sym_POUNDelse] = ACTIONS(5360),
    [anon_sym_POUNDELSE] = ACTIONS(5360),
    [anon_sym_POUNDElse] = ACTIONS(5360),
    [anon_sym_POUNDelse2] = ACTIONS(5360),
    [anon_sym_POUNDELSE2] = ACTIONS(5360),
    [anon_sym_POUNDElse2] = ACTIONS(5360),
    [anon_sym_POUNDendif] = ACTIONS(5360),
    [anon_sym_POUNDENDIF] = ACTIONS(5360),
    [anon_sym_POUNDEndif] = ACTIONS(5360),
    [anon_sym_POUNDendif2] = ACTIONS(5360),
    [anon_sym_POUNDENDIF2] = ACTIONS(5360),
    [anon_sym_POUNDEndif2] = ACTIONS(5360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5358),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5358),
    [anon_sym_PLUS] = ACTIONS(5360),
    [sym_datetime_literal] = ACTIONS(5360),
    [sym_date_literal] = ACTIONS(5358),
    [sym_time_literal] = ACTIONS(5358),
    [sym_biginteger_literal] = ACTIONS(5360),
    [sym_table_keyword] = ACTIONS(5358),
    [sym_page_keyword] = ACTIONS(5358),
    [anon_sym_codeunit] = ACTIONS(5358),
    [anon_sym_CODEUNIT] = ACTIONS(5358),
    [anon_sym_Codeunit] = ACTIONS(5358),
    [anon_sym_CodeUnit] = ACTIONS(5358),
    [anon_sym_COdeunit] = ACTIONS(5358),
    [anon_sym_codeUnit] = ACTIONS(5358),
    [sym_report_keyword] = ACTIONS(5358),
    [sym_query_keyword] = ACTIONS(5358),
    [anon_sym_xmlport] = ACTIONS(5358),
    [anon_sym_XMLPORT] = ACTIONS(5358),
    [anon_sym_Xmlport] = ACTIONS(5358),
    [anon_sym_XMLport] = ACTIONS(5358),
    [anon_sym_XMLPort] = ACTIONS(5358),
    [anon_sym_XmlPort] = ACTIONS(5358),
    [anon_sym_enum] = ACTIONS(5358),
    [anon_sym_ENUM] = ACTIONS(5358),
    [anon_sym_Enum] = ACTIONS(5358),
    [anon_sym_eNUM] = ACTIONS(5358),
    [anon_sym_eNum] = ACTIONS(5358),
    [anon_sym_ENum] = ACTIONS(5358),
    [sym_key_keyword] = ACTIONS(5358),
    [sym_dataset_keyword] = ACTIONS(5358),
    [sym_quoted_identifier] = ACTIONS(5360),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5360),
    [sym_verbatim_string] = ACTIONS(5360),
    [sym_integer] = ACTIONS(5358),
    [sym_continue_as_identifier] = ACTIONS(5360),
    [sym_preproc_open] = ACTIONS(5360),
    [sym_preproc_close] = ACTIONS(5360),
  },
  [STATE(3612)] = {
    [sym_identifier] = ACTIONS(5370),
    [anon_sym_COMMA] = ACTIONS(5372),
    [anon_sym_DASH] = ACTIONS(5372),
    [aux_sym_boolean_token1] = ACTIONS(5370),
    [aux_sym_boolean_token2] = ACTIONS(5370),
    [sym_decimal] = ACTIONS(5370),
    [anon_sym_LPAREN] = ACTIONS(5372),
    [aux_sym_where_condition_token1] = ACTIONS(5370),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5370),
    [aux_sym_if_table_relation_token1] = ACTIONS(5370),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5370),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5370),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [aux_sym_record_type_token1] = ACTIONS(5370),
    [aux_sym_basic_type_token21] = ACTIONS(5370),
    [aux_sym_basic_type_token22] = ACTIONS(5370),
    [aux_sym_basic_type_token48] = ACTIONS(5370),
    [aux_sym_basic_type_token53] = ACTIONS(5370),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5370),
    [aux_sym_separator_action_token1] = ACTIONS(5370),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5370),
    [aux_sym_type_declaration_token1] = ACTIONS(5370),
    [anon_sym_POUNDif] = ACTIONS(5372),
    [anon_sym_POUNDIF] = ACTIONS(5372),
    [anon_sym_POUNDIf] = ACTIONS(5372),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8100),
    [anon_sym_PIPE_PIPE] = ACTIONS(8102),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8104),
    [anon_sym_AMP_AMP] = ACTIONS(8106),
    [anon_sym_not] = ACTIONS(5370),
    [anon_sym_NOT] = ACTIONS(5370),
    [anon_sym_Not] = ACTIONS(5370),
    [anon_sym_POUNDelif] = ACTIONS(5372),
    [anon_sym_POUNDELIF] = ACTIONS(5372),
    [anon_sym_POUNDElif] = ACTIONS(5372),
    [anon_sym_POUNDelse] = ACTIONS(5372),
    [anon_sym_POUNDELSE] = ACTIONS(5372),
    [anon_sym_POUNDElse] = ACTIONS(5372),
    [anon_sym_POUNDelse2] = ACTIONS(5372),
    [anon_sym_POUNDELSE2] = ACTIONS(5372),
    [anon_sym_POUNDElse2] = ACTIONS(5372),
    [anon_sym_POUNDendif] = ACTIONS(5372),
    [anon_sym_POUNDENDIF] = ACTIONS(5372),
    [anon_sym_POUNDEndif] = ACTIONS(5372),
    [anon_sym_POUNDendif2] = ACTIONS(5372),
    [anon_sym_POUNDENDIF2] = ACTIONS(5372),
    [anon_sym_POUNDEndif2] = ACTIONS(5372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5370),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5370),
    [anon_sym_PLUS] = ACTIONS(5372),
    [sym_datetime_literal] = ACTIONS(5372),
    [sym_date_literal] = ACTIONS(5370),
    [sym_time_literal] = ACTIONS(5370),
    [sym_biginteger_literal] = ACTIONS(5372),
    [sym_table_keyword] = ACTIONS(5370),
    [sym_page_keyword] = ACTIONS(5370),
    [anon_sym_codeunit] = ACTIONS(5370),
    [anon_sym_CODEUNIT] = ACTIONS(5370),
    [anon_sym_Codeunit] = ACTIONS(5370),
    [anon_sym_CodeUnit] = ACTIONS(5370),
    [anon_sym_COdeunit] = ACTIONS(5370),
    [anon_sym_codeUnit] = ACTIONS(5370),
    [sym_report_keyword] = ACTIONS(5370),
    [sym_query_keyword] = ACTIONS(5370),
    [anon_sym_xmlport] = ACTIONS(5370),
    [anon_sym_XMLPORT] = ACTIONS(5370),
    [anon_sym_Xmlport] = ACTIONS(5370),
    [anon_sym_XMLport] = ACTIONS(5370),
    [anon_sym_XMLPort] = ACTIONS(5370),
    [anon_sym_XmlPort] = ACTIONS(5370),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_ENUM] = ACTIONS(5370),
    [anon_sym_Enum] = ACTIONS(5370),
    [anon_sym_eNUM] = ACTIONS(5370),
    [anon_sym_eNum] = ACTIONS(5370),
    [anon_sym_ENum] = ACTIONS(5370),
    [sym_key_keyword] = ACTIONS(5370),
    [sym_dataset_keyword] = ACTIONS(5370),
    [sym_quoted_identifier] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5372),
    [sym_verbatim_string] = ACTIONS(5372),
    [sym_integer] = ACTIONS(5370),
    [sym_continue_as_identifier] = ACTIONS(5372),
    [sym_preproc_open] = ACTIONS(5372),
    [sym_preproc_close] = ACTIONS(5372),
  },
  [STATE(3613)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(8108),
    [anon_sym_LBRACK] = ACTIONS(8111),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8114),
    [aux_sym_modify_modification_token1] = ACTIONS(8117),
    [aux_sym_xmlport_element_token1] = ACTIONS(8120),
    [aux_sym_xmlport_element_token2] = ACTIONS(8120),
    [aux_sym_xmlport_element_token3] = ACTIONS(8120),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8123),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8123),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8126),
    [anon_sym_POUNDif] = ACTIONS(8129),
    [anon_sym_POUNDIF] = ACTIONS(8129),
    [anon_sym_POUNDIf] = ACTIONS(8129),
    [anon_sym_POUNDelif] = ACTIONS(8132),
    [anon_sym_POUNDELIF] = ACTIONS(8132),
    [anon_sym_POUNDElif] = ACTIONS(8132),
    [anon_sym_POUNDelse] = ACTIONS(8132),
    [anon_sym_POUNDELSE] = ACTIONS(8132),
    [anon_sym_POUNDElse] = ACTIONS(8132),
    [anon_sym_POUNDelse2] = ACTIONS(8132),
    [anon_sym_POUNDELSE2] = ACTIONS(8132),
    [anon_sym_POUNDElse2] = ACTIONS(8132),
    [anon_sym_POUNDendif] = ACTIONS(8132),
    [anon_sym_POUNDENDIF] = ACTIONS(8132),
    [anon_sym_POUNDEndif] = ACTIONS(8132),
    [anon_sym_POUNDendif2] = ACTIONS(8132),
    [anon_sym_POUNDENDIF2] = ACTIONS(8132),
    [anon_sym_POUNDEndif2] = ACTIONS(8132),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8134),
    [sym_trigger_keyword] = ACTIONS(8137),
    [sym_var_keyword] = ACTIONS(8140),
    [sym_local_keyword] = ACTIONS(8143),
    [sym_internal_keyword] = ACTIONS(8146),
    [sym_protected_keyword] = ACTIONS(8143),
    [sym_event_keyword] = ACTIONS(8149),
    [sym_fields_keyword] = ACTIONS(8152),
    [sym_keys_keyword] = ACTIONS(8155),
    [sym_fieldgroups_keyword] = ACTIONS(8158),
    [sym_actions_keyword] = ACTIONS(8161),
    [sym_layout_keyword] = ACTIONS(8164),
    [sym_dataset_keyword] = ACTIONS(8167),
    [sym_elements_keyword] = ACTIONS(8170),
    [sym_labels_keyword] = ACTIONS(8173),
    [sym_rendering_keyword] = ACTIONS(8176),
    [sym_requestpage_keyword] = ACTIONS(8179),
    [sym_schema_keyword] = ACTIONS(8182),
    [sym_views_keyword] = ACTIONS(8185),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8188),
    [sym_preproc_open] = ACTIONS(8129),
    [sym_preproc_close] = ACTIONS(8132),
  },
  [STATE(3614)] = {
    [sym_identifier] = ACTIONS(5374),
    [anon_sym_COMMA] = ACTIONS(5376),
    [anon_sym_DASH] = ACTIONS(5376),
    [aux_sym_boolean_token1] = ACTIONS(5374),
    [aux_sym_boolean_token2] = ACTIONS(5374),
    [sym_decimal] = ACTIONS(5374),
    [anon_sym_LPAREN] = ACTIONS(5376),
    [aux_sym_where_condition_token1] = ACTIONS(5374),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5374),
    [aux_sym_if_table_relation_token1] = ACTIONS(5374),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5374),
    [anon_sym_LBRACK] = ACTIONS(5376),
    [aux_sym_record_type_token1] = ACTIONS(5374),
    [aux_sym_basic_type_token21] = ACTIONS(5374),
    [aux_sym_basic_type_token22] = ACTIONS(5374),
    [aux_sym_basic_type_token48] = ACTIONS(5374),
    [aux_sym_basic_type_token53] = ACTIONS(5374),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5374),
    [aux_sym_separator_action_token1] = ACTIONS(5374),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5374),
    [aux_sym_type_declaration_token1] = ACTIONS(5374),
    [anon_sym_POUNDif] = ACTIONS(5376),
    [anon_sym_POUNDIF] = ACTIONS(5376),
    [anon_sym_POUNDIf] = ACTIONS(5376),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5374),
    [anon_sym_PIPE_PIPE] = ACTIONS(5376),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5374),
    [anon_sym_AMP_AMP] = ACTIONS(5376),
    [anon_sym_not] = ACTIONS(5374),
    [anon_sym_NOT] = ACTIONS(5374),
    [anon_sym_Not] = ACTIONS(5374),
    [anon_sym_POUNDelif] = ACTIONS(5376),
    [anon_sym_POUNDELIF] = ACTIONS(5376),
    [anon_sym_POUNDElif] = ACTIONS(5376),
    [anon_sym_POUNDelse] = ACTIONS(5376),
    [anon_sym_POUNDELSE] = ACTIONS(5376),
    [anon_sym_POUNDElse] = ACTIONS(5376),
    [anon_sym_POUNDelse2] = ACTIONS(5376),
    [anon_sym_POUNDELSE2] = ACTIONS(5376),
    [anon_sym_POUNDElse2] = ACTIONS(5376),
    [anon_sym_POUNDendif] = ACTIONS(5376),
    [anon_sym_POUNDENDIF] = ACTIONS(5376),
    [anon_sym_POUNDEndif] = ACTIONS(5376),
    [anon_sym_POUNDendif2] = ACTIONS(5376),
    [anon_sym_POUNDENDIF2] = ACTIONS(5376),
    [anon_sym_POUNDEndif2] = ACTIONS(5376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5374),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5374),
    [anon_sym_PLUS] = ACTIONS(5376),
    [sym_datetime_literal] = ACTIONS(5376),
    [sym_date_literal] = ACTIONS(5374),
    [sym_time_literal] = ACTIONS(5374),
    [sym_biginteger_literal] = ACTIONS(5376),
    [sym_table_keyword] = ACTIONS(5374),
    [sym_page_keyword] = ACTIONS(5374),
    [anon_sym_codeunit] = ACTIONS(5374),
    [anon_sym_CODEUNIT] = ACTIONS(5374),
    [anon_sym_Codeunit] = ACTIONS(5374),
    [anon_sym_CodeUnit] = ACTIONS(5374),
    [anon_sym_COdeunit] = ACTIONS(5374),
    [anon_sym_codeUnit] = ACTIONS(5374),
    [sym_report_keyword] = ACTIONS(5374),
    [sym_query_keyword] = ACTIONS(5374),
    [anon_sym_xmlport] = ACTIONS(5374),
    [anon_sym_XMLPORT] = ACTIONS(5374),
    [anon_sym_Xmlport] = ACTIONS(5374),
    [anon_sym_XMLport] = ACTIONS(5374),
    [anon_sym_XMLPort] = ACTIONS(5374),
    [anon_sym_XmlPort] = ACTIONS(5374),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_ENUM] = ACTIONS(5374),
    [anon_sym_Enum] = ACTIONS(5374),
    [anon_sym_eNUM] = ACTIONS(5374),
    [anon_sym_eNum] = ACTIONS(5374),
    [anon_sym_ENum] = ACTIONS(5374),
    [sym_key_keyword] = ACTIONS(5374),
    [sym_dataset_keyword] = ACTIONS(5374),
    [sym_quoted_identifier] = ACTIONS(5376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5376),
    [sym_verbatim_string] = ACTIONS(5376),
    [sym_integer] = ACTIONS(5374),
    [sym_continue_as_identifier] = ACTIONS(5376),
    [sym_preproc_open] = ACTIONS(5376),
    [sym_preproc_close] = ACTIONS(5376),
  },
  [STATE(3615)] = {
    [sym_identifier] = ACTIONS(5399),
    [anon_sym_COMMA] = ACTIONS(5401),
    [anon_sym_DASH] = ACTIONS(5401),
    [aux_sym_boolean_token1] = ACTIONS(5399),
    [aux_sym_boolean_token2] = ACTIONS(5399),
    [sym_decimal] = ACTIONS(5399),
    [anon_sym_LPAREN] = ACTIONS(5401),
    [aux_sym_where_condition_token1] = ACTIONS(5399),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5399),
    [aux_sym_if_table_relation_token1] = ACTIONS(5399),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5399),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5399),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [aux_sym_record_type_token1] = ACTIONS(5399),
    [aux_sym_basic_type_token21] = ACTIONS(5399),
    [aux_sym_basic_type_token22] = ACTIONS(5399),
    [aux_sym_basic_type_token48] = ACTIONS(5399),
    [aux_sym_basic_type_token53] = ACTIONS(5399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5399),
    [aux_sym_separator_action_token1] = ACTIONS(5399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5399),
    [aux_sym_type_declaration_token1] = ACTIONS(5399),
    [anon_sym_POUNDif] = ACTIONS(5401),
    [anon_sym_POUNDIF] = ACTIONS(5401),
    [anon_sym_POUNDIf] = ACTIONS(5401),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8100),
    [anon_sym_PIPE_PIPE] = ACTIONS(8102),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8104),
    [anon_sym_AMP_AMP] = ACTIONS(8106),
    [anon_sym_not] = ACTIONS(5399),
    [anon_sym_NOT] = ACTIONS(5399),
    [anon_sym_Not] = ACTIONS(5399),
    [anon_sym_POUNDelif] = ACTIONS(5401),
    [anon_sym_POUNDELIF] = ACTIONS(5401),
    [anon_sym_POUNDElif] = ACTIONS(5401),
    [anon_sym_POUNDelse] = ACTIONS(5401),
    [anon_sym_POUNDELSE] = ACTIONS(5401),
    [anon_sym_POUNDElse] = ACTIONS(5401),
    [anon_sym_POUNDelse2] = ACTIONS(5401),
    [anon_sym_POUNDELSE2] = ACTIONS(5401),
    [anon_sym_POUNDElse2] = ACTIONS(5401),
    [anon_sym_POUNDendif] = ACTIONS(5401),
    [anon_sym_POUNDENDIF] = ACTIONS(5401),
    [anon_sym_POUNDEndif] = ACTIONS(5401),
    [anon_sym_POUNDendif2] = ACTIONS(5401),
    [anon_sym_POUNDENDIF2] = ACTIONS(5401),
    [anon_sym_POUNDEndif2] = ACTIONS(5401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5399),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5399),
    [anon_sym_PLUS] = ACTIONS(5401),
    [sym_datetime_literal] = ACTIONS(5401),
    [sym_date_literal] = ACTIONS(5399),
    [sym_time_literal] = ACTIONS(5399),
    [sym_biginteger_literal] = ACTIONS(5401),
    [sym_table_keyword] = ACTIONS(5399),
    [sym_page_keyword] = ACTIONS(5399),
    [anon_sym_codeunit] = ACTIONS(5399),
    [anon_sym_CODEUNIT] = ACTIONS(5399),
    [anon_sym_Codeunit] = ACTIONS(5399),
    [anon_sym_CodeUnit] = ACTIONS(5399),
    [anon_sym_COdeunit] = ACTIONS(5399),
    [anon_sym_codeUnit] = ACTIONS(5399),
    [sym_report_keyword] = ACTIONS(5399),
    [sym_query_keyword] = ACTIONS(5399),
    [anon_sym_xmlport] = ACTIONS(5399),
    [anon_sym_XMLPORT] = ACTIONS(5399),
    [anon_sym_Xmlport] = ACTIONS(5399),
    [anon_sym_XMLport] = ACTIONS(5399),
    [anon_sym_XMLPort] = ACTIONS(5399),
    [anon_sym_XmlPort] = ACTIONS(5399),
    [anon_sym_enum] = ACTIONS(5399),
    [anon_sym_ENUM] = ACTIONS(5399),
    [anon_sym_Enum] = ACTIONS(5399),
    [anon_sym_eNUM] = ACTIONS(5399),
    [anon_sym_eNum] = ACTIONS(5399),
    [anon_sym_ENum] = ACTIONS(5399),
    [sym_key_keyword] = ACTIONS(5399),
    [sym_dataset_keyword] = ACTIONS(5399),
    [sym_quoted_identifier] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5401),
    [sym_verbatim_string] = ACTIONS(5401),
    [sym_integer] = ACTIONS(5399),
    [sym_continue_as_identifier] = ACTIONS(5401),
    [sym_preproc_open] = ACTIONS(5401),
    [sym_preproc_close] = ACTIONS(5401),
  },
  [STATE(3616)] = {
    [sym_identifier] = ACTIONS(5378),
    [anon_sym_COMMA] = ACTIONS(5380),
    [anon_sym_DASH] = ACTIONS(5380),
    [aux_sym_boolean_token1] = ACTIONS(5378),
    [aux_sym_boolean_token2] = ACTIONS(5378),
    [sym_decimal] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5380),
    [aux_sym_where_condition_token1] = ACTIONS(5378),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5378),
    [aux_sym_if_table_relation_token1] = ACTIONS(5378),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5378),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5378),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [aux_sym_record_type_token1] = ACTIONS(5378),
    [aux_sym_basic_type_token21] = ACTIONS(5378),
    [aux_sym_basic_type_token22] = ACTIONS(5378),
    [aux_sym_basic_type_token48] = ACTIONS(5378),
    [aux_sym_basic_type_token53] = ACTIONS(5378),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5378),
    [aux_sym_separator_action_token1] = ACTIONS(5378),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5378),
    [aux_sym_type_declaration_token1] = ACTIONS(5378),
    [anon_sym_POUNDif] = ACTIONS(5380),
    [anon_sym_POUNDIF] = ACTIONS(5380),
    [anon_sym_POUNDIf] = ACTIONS(5380),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5380),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8104),
    [anon_sym_AMP_AMP] = ACTIONS(8106),
    [anon_sym_not] = ACTIONS(5378),
    [anon_sym_NOT] = ACTIONS(5378),
    [anon_sym_Not] = ACTIONS(5378),
    [anon_sym_POUNDelif] = ACTIONS(5380),
    [anon_sym_POUNDELIF] = ACTIONS(5380),
    [anon_sym_POUNDElif] = ACTIONS(5380),
    [anon_sym_POUNDelse] = ACTIONS(5380),
    [anon_sym_POUNDELSE] = ACTIONS(5380),
    [anon_sym_POUNDElse] = ACTIONS(5380),
    [anon_sym_POUNDelse2] = ACTIONS(5380),
    [anon_sym_POUNDELSE2] = ACTIONS(5380),
    [anon_sym_POUNDElse2] = ACTIONS(5380),
    [anon_sym_POUNDendif] = ACTIONS(5380),
    [anon_sym_POUNDENDIF] = ACTIONS(5380),
    [anon_sym_POUNDEndif] = ACTIONS(5380),
    [anon_sym_POUNDendif2] = ACTIONS(5380),
    [anon_sym_POUNDENDIF2] = ACTIONS(5380),
    [anon_sym_POUNDEndif2] = ACTIONS(5380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [sym_datetime_literal] = ACTIONS(5380),
    [sym_date_literal] = ACTIONS(5378),
    [sym_time_literal] = ACTIONS(5378),
    [sym_biginteger_literal] = ACTIONS(5380),
    [sym_table_keyword] = ACTIONS(5378),
    [sym_page_keyword] = ACTIONS(5378),
    [anon_sym_codeunit] = ACTIONS(5378),
    [anon_sym_CODEUNIT] = ACTIONS(5378),
    [anon_sym_Codeunit] = ACTIONS(5378),
    [anon_sym_CodeUnit] = ACTIONS(5378),
    [anon_sym_COdeunit] = ACTIONS(5378),
    [anon_sym_codeUnit] = ACTIONS(5378),
    [sym_report_keyword] = ACTIONS(5378),
    [sym_query_keyword] = ACTIONS(5378),
    [anon_sym_xmlport] = ACTIONS(5378),
    [anon_sym_XMLPORT] = ACTIONS(5378),
    [anon_sym_Xmlport] = ACTIONS(5378),
    [anon_sym_XMLport] = ACTIONS(5378),
    [anon_sym_XMLPort] = ACTIONS(5378),
    [anon_sym_XmlPort] = ACTIONS(5378),
    [anon_sym_enum] = ACTIONS(5378),
    [anon_sym_ENUM] = ACTIONS(5378),
    [anon_sym_Enum] = ACTIONS(5378),
    [anon_sym_eNUM] = ACTIONS(5378),
    [anon_sym_eNum] = ACTIONS(5378),
    [anon_sym_ENum] = ACTIONS(5378),
    [sym_key_keyword] = ACTIONS(5378),
    [sym_dataset_keyword] = ACTIONS(5378),
    [sym_quoted_identifier] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5380),
    [sym_verbatim_string] = ACTIONS(5380),
    [sym_integer] = ACTIONS(5378),
    [sym_continue_as_identifier] = ACTIONS(5380),
    [sym_preproc_open] = ACTIONS(5380),
    [sym_preproc_close] = ACTIONS(5380),
  },
  [STATE(3617)] = {
    [sym__body_element] = STATE(8030),
    [sym_empty_statement] = STATE(8030),
    [sym_property] = STATE(8030),
    [sym_permissions_property] = STATE(8030),
    [sym_table_relation_property] = STATE(8030),
    [sym_fields_section] = STATE(8030),
    [sym_keys_section] = STATE(8030),
    [sym_fieldgroups_section] = STATE(8030),
    [sym_enum_value_declaration] = STATE(8030),
    [sym_labels_section] = STATE(8030),
    [sym_layout_section] = STATE(8030),
    [sym_modify_modification] = STATE(8030),
    [sym_actions_section] = STATE(8030),
    [sym_views_section] = STATE(8030),
    [sym_dataset_section] = STATE(8030),
    [sym_requestpage_section] = STATE(8030),
    [sym_rendering_section] = STATE(8030),
    [sym_elements_section] = STATE(8030),
    [sym_query_dataitem] = STATE(3625),
    [sym__query_body_element] = STATE(3625),
    [sym_preproc_conditional_query] = STATE(3625),
    [sym_query_column] = STATE(3625),
    [sym_query_filter] = STATE(3625),
    [sym_schema_section] = STATE(8030),
    [sym_assembly_declaration] = STATE(8030),
    [sym_event_declaration] = STATE(8030),
    [sym_procedure] = STATE(8030),
    [sym_preproc_split_procedure] = STATE(8030),
    [sym_preproc_split_procedure_preamble] = STATE(8030),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8030),
    [sym_var_section] = STATE(8030),
    [sym_attribute_item] = STATE(8030),
    [sym_preproc_conditional] = STATE(8030),
    [sym_preproc_if] = STATE(3463),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4033),
    [aux_sym_query_dataitem_repeat1] = STATE(3625),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8191),
    [anon_sym_POUNDELIF] = ACTIONS(8191),
    [anon_sym_POUNDElif] = ACTIONS(8191),
    [anon_sym_POUNDelse] = ACTIONS(8191),
    [anon_sym_POUNDELSE] = ACTIONS(8191),
    [anon_sym_POUNDElse] = ACTIONS(8191),
    [anon_sym_POUNDelse2] = ACTIONS(8191),
    [anon_sym_POUNDELSE2] = ACTIONS(8191),
    [anon_sym_POUNDElse2] = ACTIONS(8191),
    [anon_sym_POUNDendif] = ACTIONS(8191),
    [anon_sym_POUNDENDIF] = ACTIONS(8191),
    [anon_sym_POUNDEndif] = ACTIONS(8191),
    [anon_sym_POUNDendif2] = ACTIONS(8191),
    [anon_sym_POUNDENDIF2] = ACTIONS(8191),
    [anon_sym_POUNDEndif2] = ACTIONS(8191),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8191),
  },
  [STATE(3618)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDelif] = ACTIONS(8194),
    [anon_sym_POUNDELIF] = ACTIONS(8194),
    [anon_sym_POUNDElif] = ACTIONS(8194),
    [anon_sym_POUNDelse] = ACTIONS(8194),
    [anon_sym_POUNDELSE] = ACTIONS(8194),
    [anon_sym_POUNDElse] = ACTIONS(8194),
    [anon_sym_POUNDelse2] = ACTIONS(8194),
    [anon_sym_POUNDELSE2] = ACTIONS(8194),
    [anon_sym_POUNDElse2] = ACTIONS(8194),
    [anon_sym_POUNDendif] = ACTIONS(8194),
    [anon_sym_POUNDENDIF] = ACTIONS(8194),
    [anon_sym_POUNDEndif] = ACTIONS(8194),
    [anon_sym_POUNDendif2] = ACTIONS(8194),
    [anon_sym_POUNDENDIF2] = ACTIONS(8194),
    [anon_sym_POUNDEndif2] = ACTIONS(8194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(8194),
  },
  [STATE(3619)] = {
    [sym_identifier] = ACTIONS(7418),
    [anon_sym_SEMI] = ACTIONS(7420),
    [anon_sym_DASH] = ACTIONS(7420),
    [aux_sym_boolean_token1] = ACTIONS(7418),
    [aux_sym_boolean_token2] = ACTIONS(7418),
    [sym_decimal] = ACTIONS(7418),
    [anon_sym_LPAREN] = ACTIONS(7420),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7418),
    [anon_sym_LBRACK] = ACTIONS(7420),
    [aux_sym_record_type_token1] = ACTIONS(7418),
    [aux_sym_basic_type_token21] = ACTIONS(7418),
    [aux_sym_basic_type_token22] = ACTIONS(7418),
    [aux_sym_basic_type_token48] = ACTIONS(7418),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(7418),
    [anon_sym_POUNDif] = ACTIONS(7420),
    [anon_sym_POUNDIF] = ACTIONS(7420),
    [anon_sym_POUNDIf] = ACTIONS(7420),
    [anon_sym_not] = ACTIONS(7418),
    [anon_sym_NOT] = ACTIONS(7418),
    [anon_sym_Not] = ACTIONS(7418),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7418),
    [anon_sym_PLUS] = ACTIONS(7420),
    [sym_datetime_literal] = ACTIONS(7420),
    [sym_date_literal] = ACTIONS(7418),
    [sym_time_literal] = ACTIONS(7418),
    [sym_biginteger_literal] = ACTIONS(7420),
    [anon_sym_if] = ACTIONS(7418),
    [anon_sym_IF] = ACTIONS(7418),
    [anon_sym_If] = ACTIONS(7418),
    [anon_sym_case] = ACTIONS(7418),
    [anon_sym_CASE] = ACTIONS(7418),
    [anon_sym_Case] = ACTIONS(7418),
    [anon_sym_for] = ACTIONS(7418),
    [anon_sym_FOR] = ACTIONS(7418),
    [anon_sym_For] = ACTIONS(7418),
    [anon_sym_foreach] = ACTIONS(7418),
    [anon_sym_FOREACH] = ACTIONS(7418),
    [anon_sym_Foreach] = ACTIONS(7418),
    [anon_sym_while] = ACTIONS(7418),
    [anon_sym_WHILE] = ACTIONS(7418),
    [anon_sym_While] = ACTIONS(7418),
    [anon_sym_repeat] = ACTIONS(7418),
    [anon_sym_REPEAT] = ACTIONS(7418),
    [anon_sym_Repeat] = ACTIONS(7418),
    [anon_sym_exit] = ACTIONS(7418),
    [anon_sym_EXIT] = ACTIONS(7418),
    [anon_sym_Exit] = ACTIONS(7418),
    [anon_sym_continue] = ACTIONS(7418),
    [anon_sym_CONTINUE] = ACTIONS(7418),
    [anon_sym_Continue] = ACTIONS(7418),
    [anon_sym_break] = ACTIONS(7418),
    [anon_sym_BREAK] = ACTIONS(7418),
    [anon_sym_Break] = ACTIONS(7418),
    [anon_sym_with] = ACTIONS(7418),
    [anon_sym_WITH] = ACTIONS(7418),
    [anon_sym_With] = ACTIONS(7418),
    [sym_asserterror_keyword] = ACTIONS(7420),
    [sym_page_keyword] = ACTIONS(7418),
    [anon_sym_codeunit] = ACTIONS(7418),
    [anon_sym_CODEUNIT] = ACTIONS(7418),
    [anon_sym_Codeunit] = ACTIONS(7418),
    [anon_sym_CodeUnit] = ACTIONS(7418),
    [anon_sym_COdeunit] = ACTIONS(7418),
    [anon_sym_codeUnit] = ACTIONS(7418),
    [sym_report_keyword] = ACTIONS(7418),
    [sym_query_keyword] = ACTIONS(7418),
    [anon_sym_xmlport] = ACTIONS(7418),
    [anon_sym_XMLPORT] = ACTIONS(7418),
    [anon_sym_Xmlport] = ACTIONS(7418),
    [anon_sym_XMLport] = ACTIONS(7418),
    [anon_sym_XMLPort] = ACTIONS(7418),
    [anon_sym_XmlPort] = ACTIONS(7418),
    [anon_sym_enum] = ACTIONS(7418),
    [anon_sym_ENUM] = ACTIONS(7418),
    [anon_sym_Enum] = ACTIONS(7418),
    [anon_sym_eNUM] = ACTIONS(7418),
    [anon_sym_eNum] = ACTIONS(7418),
    [anon_sym_ENum] = ACTIONS(7418),
    [sym_quoted_identifier] = ACTIONS(7420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7420),
    [sym_verbatim_string] = ACTIONS(7420),
    [sym_integer] = ACTIONS(7418),
    [sym_continue_as_identifier] = ACTIONS(7420),
    [sym_preproc_open] = ACTIONS(7420),
  },
  [STATE(3620)] = {
    [sym__body_element] = STATE(3618),
    [sym_empty_statement] = STATE(3618),
    [sym_property] = STATE(3618),
    [sym_permissions_property] = STATE(3618),
    [sym_table_relation_property] = STATE(3618),
    [sym_fields_section] = STATE(3618),
    [sym_keys_section] = STATE(3618),
    [sym_fieldgroups_section] = STATE(3618),
    [sym_enum_value_declaration] = STATE(3618),
    [sym_labels_section] = STATE(3618),
    [sym_layout_section] = STATE(3618),
    [sym_modify_modification] = STATE(3618),
    [sym_actions_section] = STATE(3618),
    [sym_views_section] = STATE(3618),
    [sym_dataset_section] = STATE(3618),
    [sym_requestpage_section] = STATE(3618),
    [sym_rendering_section] = STATE(3618),
    [sym_elements_section] = STATE(3618),
    [sym_schema_section] = STATE(3618),
    [sym_xmlport_element] = STATE(3618),
    [sym__xmlport_body_element] = STATE(3618),
    [sym_preproc_conditional_xmlport] = STATE(3618),
    [sym_xmlport_attribute] = STATE(3618),
    [sym_assembly_declaration] = STATE(3618),
    [sym_event_declaration] = STATE(3618),
    [sym_procedure] = STATE(3618),
    [sym_preproc_split_procedure] = STATE(3618),
    [sym_preproc_split_procedure_preamble] = STATE(3618),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3618),
    [sym_var_section] = STATE(3618),
    [sym_attribute_item] = STATE(3618),
    [sym_preproc_conditional] = STATE(3618),
    [sym_preproc_if] = STATE(3423),
    [aux_sym_xmlport_element_repeat1] = STATE(3618),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDelif] = ACTIONS(8196),
    [anon_sym_POUNDELIF] = ACTIONS(8196),
    [anon_sym_POUNDElif] = ACTIONS(8196),
    [anon_sym_POUNDelse] = ACTIONS(8196),
    [anon_sym_POUNDELSE] = ACTIONS(8196),
    [anon_sym_POUNDElse] = ACTIONS(8196),
    [anon_sym_POUNDelse2] = ACTIONS(8196),
    [anon_sym_POUNDELSE2] = ACTIONS(8196),
    [anon_sym_POUNDElse2] = ACTIONS(8196),
    [anon_sym_POUNDendif] = ACTIONS(8196),
    [anon_sym_POUNDENDIF] = ACTIONS(8196),
    [anon_sym_POUNDEndif] = ACTIONS(8196),
    [anon_sym_POUNDendif2] = ACTIONS(8196),
    [anon_sym_POUNDENDIF2] = ACTIONS(8196),
    [anon_sym_POUNDEndif2] = ACTIONS(8196),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(8196),
  },
  [STATE(3621)] = {
    [sym_argument_list] = STATE(7165),
    [sym_identifier] = ACTIONS(8198),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(8200),
    [aux_sym_boolean_token1] = ACTIONS(8198),
    [aux_sym_boolean_token2] = ACTIONS(8198),
    [sym_decimal] = ACTIONS(8198),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [anon_sym_RPAREN] = ACTIONS(8203),
    [anon_sym_DOT_DOT] = ACTIONS(8205),
    [aux_sym_filter_value_token1] = ACTIONS(8198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8198),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(8205),
    [aux_sym_record_type_token1] = ACTIONS(8198),
    [aux_sym_basic_type_token21] = ACTIONS(8198),
    [aux_sym_basic_type_token22] = ACTIONS(8198),
    [aux_sym_basic_type_token48] = ACTIONS(8198),
    [anon_sym_COLON_COLON] = ACTIONS(8208),
    [anon_sym_not] = ACTIONS(8198),
    [anon_sym_NOT] = ACTIONS(8198),
    [anon_sym_Not] = ACTIONS(8198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8198),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8198),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(8200),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(8203),
    [sym_date_literal] = ACTIONS(8198),
    [sym_time_literal] = ACTIONS(8198),
    [sym_biginteger_literal] = ACTIONS(8203),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(8198),
    [anon_sym_codeunit] = ACTIONS(8198),
    [anon_sym_CODEUNIT] = ACTIONS(8198),
    [anon_sym_Codeunit] = ACTIONS(8198),
    [anon_sym_CodeUnit] = ACTIONS(8198),
    [anon_sym_COdeunit] = ACTIONS(8198),
    [anon_sym_codeUnit] = ACTIONS(8198),
    [sym_report_keyword] = ACTIONS(8198),
    [sym_query_keyword] = ACTIONS(8198),
    [anon_sym_xmlport] = ACTIONS(8198),
    [anon_sym_XMLPORT] = ACTIONS(8198),
    [anon_sym_Xmlport] = ACTIONS(8198),
    [anon_sym_XMLport] = ACTIONS(8198),
    [anon_sym_XMLPort] = ACTIONS(8198),
    [anon_sym_XmlPort] = ACTIONS(8198),
    [anon_sym_enum] = ACTIONS(8198),
    [anon_sym_ENUM] = ACTIONS(8198),
    [anon_sym_Enum] = ACTIONS(8198),
    [anon_sym_eNUM] = ACTIONS(8198),
    [anon_sym_eNum] = ACTIONS(8198),
    [anon_sym_ENum] = ACTIONS(8198),
    [sym_quoted_identifier] = ACTIONS(8203),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8203),
    [sym_verbatim_string] = ACTIONS(8203),
    [sym_integer] = ACTIONS(8198),
    [sym_continue_as_identifier] = ACTIONS(8203),
  },
  [STATE(3622)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(8210),
    [anon_sym_LBRACK] = ACTIONS(8213),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8216),
    [aux_sym_modify_modification_token1] = ACTIONS(8219),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8222),
    [anon_sym_POUNDif] = ACTIONS(8225),
    [anon_sym_POUNDIF] = ACTIONS(8225),
    [anon_sym_POUNDIf] = ACTIONS(8225),
    [anon_sym_POUNDelif] = ACTIONS(8228),
    [anon_sym_POUNDELIF] = ACTIONS(8228),
    [anon_sym_POUNDElif] = ACTIONS(8228),
    [anon_sym_POUNDelse] = ACTIONS(8228),
    [anon_sym_POUNDELSE] = ACTIONS(8228),
    [anon_sym_POUNDElse] = ACTIONS(8228),
    [anon_sym_POUNDelse2] = ACTIONS(8228),
    [anon_sym_POUNDELSE2] = ACTIONS(8228),
    [anon_sym_POUNDElse2] = ACTIONS(8228),
    [anon_sym_POUNDendif] = ACTIONS(8228),
    [anon_sym_POUNDENDIF] = ACTIONS(8228),
    [anon_sym_POUNDEndif] = ACTIONS(8228),
    [anon_sym_POUNDendif2] = ACTIONS(8228),
    [anon_sym_POUNDENDIF2] = ACTIONS(8228),
    [anon_sym_POUNDEndif2] = ACTIONS(8228),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8230),
    [sym_trigger_keyword] = ACTIONS(8233),
    [sym_var_keyword] = ACTIONS(8236),
    [sym_local_keyword] = ACTIONS(8239),
    [sym_internal_keyword] = ACTIONS(8242),
    [sym_protected_keyword] = ACTIONS(8239),
    [sym_event_keyword] = ACTIONS(8245),
    [sym_fields_keyword] = ACTIONS(8248),
    [sym_keys_keyword] = ACTIONS(8251),
    [sym_fieldgroups_keyword] = ACTIONS(8254),
    [sym_actions_keyword] = ACTIONS(8257),
    [sym_layout_keyword] = ACTIONS(8260),
    [sym_dataset_keyword] = ACTIONS(8263),
    [sym_elements_keyword] = ACTIONS(8266),
    [sym_dataitem_keyword] = ACTIONS(8269),
    [sym_column_keyword] = ACTIONS(8272),
    [sym_filter_keyword] = ACTIONS(8275),
    [sym_labels_keyword] = ACTIONS(8278),
    [sym_rendering_keyword] = ACTIONS(8281),
    [sym_requestpage_keyword] = ACTIONS(8284),
    [sym_schema_keyword] = ACTIONS(8287),
    [sym_views_keyword] = ACTIONS(8290),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8293),
    [sym_preproc_open] = ACTIONS(8225),
    [sym_preproc_close] = ACTIONS(8228),
  },
  [STATE(3623)] = {
    [sym_preproc_split_procedure] = STATE(3628),
    [sym_var_attribute_item] = STATE(3628),
    [sym_preproc_conditional_var] = STATE(3628),
    [sym_variable_declaration] = STATE(3628),
    [sym_preproc_if] = STATE(3152),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_var_section_repeat1] = STATE(3628),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(8296),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8298),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8298),
    [anon_sym_LBRACK] = ACTIONS(8296),
    [aux_sym_basic_type_token6] = ACTIONS(8298),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_addafter_modification_token1] = ACTIONS(8298),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8298),
    [aux_sym_modify_modification_token1] = ACTIONS(8298),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8298),
    [aux_sym_movelast_modification_token1] = ACTIONS(8298),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8298),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8298),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [anon_sym_POUNDelif] = ACTIONS(8296),
    [anon_sym_POUNDELIF] = ACTIONS(8296),
    [anon_sym_POUNDElif] = ACTIONS(8296),
    [anon_sym_POUNDelse] = ACTIONS(8296),
    [anon_sym_POUNDELSE] = ACTIONS(8296),
    [anon_sym_POUNDElse] = ACTIONS(8296),
    [anon_sym_POUNDelse2] = ACTIONS(8296),
    [anon_sym_POUNDELSE2] = ACTIONS(8296),
    [anon_sym_POUNDElse2] = ACTIONS(8296),
    [anon_sym_POUNDendif] = ACTIONS(8296),
    [anon_sym_POUNDENDIF] = ACTIONS(8296),
    [anon_sym_POUNDEndif] = ACTIONS(8296),
    [anon_sym_POUNDendif2] = ACTIONS(8296),
    [anon_sym_POUNDENDIF2] = ACTIONS(8296),
    [anon_sym_POUNDEndif2] = ACTIONS(8296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8298),
    [sym_trigger_keyword] = ACTIONS(8298),
    [sym_var_keyword] = ACTIONS(8298),
    [sym_local_keyword] = ACTIONS(8298),
    [sym_internal_keyword] = ACTIONS(8298),
    [sym_protected_keyword] = ACTIONS(8298),
    [sym_event_keyword] = ACTIONS(8298),
    [sym_fields_keyword] = ACTIONS(8298),
    [sym_keys_keyword] = ACTIONS(8298),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8298),
    [sym_actions_keyword] = ACTIONS(8298),
    [sym_layout_keyword] = ACTIONS(8298),
    [sym_area_keyword] = ACTIONS(8298),
    [sym_group_keyword] = ACTIONS(8298),
    [sym_repeater_keyword] = ACTIONS(8298),
    [sym_cuegroup_keyword] = ACTIONS(8298),
    [sym_fixed_keyword] = ACTIONS(8298),
    [sym_grid_keyword] = ACTIONS(8298),
    [sym_part_keyword] = ACTIONS(8298),
    [sym_systempart_keyword] = ACTIONS(8298),
    [sym_usercontrol_keyword] = ACTIONS(8298),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8298),
    [sym_dataitem_keyword] = ACTIONS(8298),
    [sym_column_keyword] = ACTIONS(8298),
    [sym_filter_keyword] = ACTIONS(8298),
    [sym_labels_keyword] = ACTIONS(8298),
    [sym_rendering_keyword] = ACTIONS(8298),
    [sym_requestpage_keyword] = ACTIONS(8298),
    [sym_schema_keyword] = ACTIONS(8298),
    [sym_views_keyword] = ACTIONS(8298),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8296),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_preproc_close] = ACTIONS(8296),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3624)] = {
    [sym__body_element] = STATE(3625),
    [sym_empty_statement] = STATE(3625),
    [sym_property] = STATE(3625),
    [sym_permissions_property] = STATE(3625),
    [sym_table_relation_property] = STATE(3625),
    [sym_fields_section] = STATE(3625),
    [sym_keys_section] = STATE(3625),
    [sym_fieldgroups_section] = STATE(3625),
    [sym_enum_value_declaration] = STATE(3625),
    [sym_labels_section] = STATE(3625),
    [sym_layout_section] = STATE(3625),
    [sym_modify_modification] = STATE(3625),
    [sym_actions_section] = STATE(3625),
    [sym_views_section] = STATE(3625),
    [sym_dataset_section] = STATE(3625),
    [sym_requestpage_section] = STATE(3625),
    [sym_rendering_section] = STATE(3625),
    [sym_elements_section] = STATE(3625),
    [sym_query_dataitem] = STATE(3625),
    [sym__query_body_element] = STATE(3625),
    [sym_preproc_conditional_query] = STATE(3625),
    [sym_query_column] = STATE(3625),
    [sym_query_filter] = STATE(3625),
    [sym_schema_section] = STATE(3625),
    [sym_assembly_declaration] = STATE(3625),
    [sym_event_declaration] = STATE(3625),
    [sym_procedure] = STATE(3625),
    [sym_preproc_split_procedure] = STATE(3625),
    [sym_preproc_split_procedure_preamble] = STATE(3625),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3625),
    [sym_var_section] = STATE(3625),
    [sym_attribute_item] = STATE(3625),
    [sym_preproc_conditional] = STATE(3625),
    [sym_preproc_if] = STATE(3463),
    [aux_sym_query_dataitem_repeat1] = STATE(3625),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8302),
    [anon_sym_POUNDELIF] = ACTIONS(8302),
    [anon_sym_POUNDElif] = ACTIONS(8302),
    [anon_sym_POUNDelse] = ACTIONS(8302),
    [anon_sym_POUNDELSE] = ACTIONS(8302),
    [anon_sym_POUNDElse] = ACTIONS(8302),
    [anon_sym_POUNDelse2] = ACTIONS(8302),
    [anon_sym_POUNDELSE2] = ACTIONS(8302),
    [anon_sym_POUNDElse2] = ACTIONS(8302),
    [anon_sym_POUNDendif] = ACTIONS(8302),
    [anon_sym_POUNDENDIF] = ACTIONS(8302),
    [anon_sym_POUNDEndif] = ACTIONS(8302),
    [anon_sym_POUNDendif2] = ACTIONS(8302),
    [anon_sym_POUNDENDIF2] = ACTIONS(8302),
    [anon_sym_POUNDEndif2] = ACTIONS(8302),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8302),
  },
  [STATE(3625)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8304),
    [anon_sym_POUNDELIF] = ACTIONS(8304),
    [anon_sym_POUNDElif] = ACTIONS(8304),
    [anon_sym_POUNDelse] = ACTIONS(8304),
    [anon_sym_POUNDELSE] = ACTIONS(8304),
    [anon_sym_POUNDElse] = ACTIONS(8304),
    [anon_sym_POUNDelse2] = ACTIONS(8304),
    [anon_sym_POUNDELSE2] = ACTIONS(8304),
    [anon_sym_POUNDElse2] = ACTIONS(8304),
    [anon_sym_POUNDendif] = ACTIONS(8304),
    [anon_sym_POUNDENDIF] = ACTIONS(8304),
    [anon_sym_POUNDEndif] = ACTIONS(8304),
    [anon_sym_POUNDendif2] = ACTIONS(8304),
    [anon_sym_POUNDENDIF2] = ACTIONS(8304),
    [anon_sym_POUNDEndif2] = ACTIONS(8304),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8304),
  },
  [STATE(3626)] = {
    [sym_preproc_split_procedure] = STATE(3628),
    [sym_var_attribute_item] = STATE(3628),
    [sym_preproc_conditional_var] = STATE(3628),
    [sym_variable_declaration] = STATE(3628),
    [sym_preproc_if] = STATE(3152),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_var_section_repeat1] = STATE(3628),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(8306),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8308),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8308),
    [anon_sym_LBRACK] = ACTIONS(8306),
    [aux_sym_basic_type_token6] = ACTIONS(8308),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_addafter_modification_token1] = ACTIONS(8308),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8308),
    [aux_sym_modify_modification_token1] = ACTIONS(8308),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8308),
    [aux_sym_movelast_modification_token1] = ACTIONS(8308),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8308),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8308),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [anon_sym_POUNDelif] = ACTIONS(8306),
    [anon_sym_POUNDELIF] = ACTIONS(8306),
    [anon_sym_POUNDElif] = ACTIONS(8306),
    [anon_sym_POUNDelse] = ACTIONS(8306),
    [anon_sym_POUNDELSE] = ACTIONS(8306),
    [anon_sym_POUNDElse] = ACTIONS(8306),
    [anon_sym_POUNDelse2] = ACTIONS(8306),
    [anon_sym_POUNDELSE2] = ACTIONS(8306),
    [anon_sym_POUNDElse2] = ACTIONS(8306),
    [anon_sym_POUNDendif] = ACTIONS(8306),
    [anon_sym_POUNDENDIF] = ACTIONS(8306),
    [anon_sym_POUNDEndif] = ACTIONS(8306),
    [anon_sym_POUNDendif2] = ACTIONS(8306),
    [anon_sym_POUNDENDIF2] = ACTIONS(8306),
    [anon_sym_POUNDEndif2] = ACTIONS(8306),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8308),
    [sym_trigger_keyword] = ACTIONS(8308),
    [sym_var_keyword] = ACTIONS(8308),
    [sym_local_keyword] = ACTIONS(8308),
    [sym_internal_keyword] = ACTIONS(8308),
    [sym_protected_keyword] = ACTIONS(8308),
    [sym_event_keyword] = ACTIONS(8308),
    [sym_fields_keyword] = ACTIONS(8308),
    [sym_keys_keyword] = ACTIONS(8308),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8308),
    [sym_actions_keyword] = ACTIONS(8308),
    [sym_layout_keyword] = ACTIONS(8308),
    [sym_area_keyword] = ACTIONS(8308),
    [sym_group_keyword] = ACTIONS(8308),
    [sym_repeater_keyword] = ACTIONS(8308),
    [sym_cuegroup_keyword] = ACTIONS(8308),
    [sym_fixed_keyword] = ACTIONS(8308),
    [sym_grid_keyword] = ACTIONS(8308),
    [sym_part_keyword] = ACTIONS(8308),
    [sym_systempart_keyword] = ACTIONS(8308),
    [sym_usercontrol_keyword] = ACTIONS(8308),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8308),
    [sym_dataitem_keyword] = ACTIONS(8308),
    [sym_column_keyword] = ACTIONS(8308),
    [sym_filter_keyword] = ACTIONS(8308),
    [sym_labels_keyword] = ACTIONS(8308),
    [sym_rendering_keyword] = ACTIONS(8308),
    [sym_requestpage_keyword] = ACTIONS(8308),
    [sym_schema_keyword] = ACTIONS(8308),
    [sym_views_keyword] = ACTIONS(8308),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8306),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_preproc_close] = ACTIONS(8306),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3627)] = {
    [sym_preproc_split_procedure] = STATE(3626),
    [sym_var_attribute_item] = STATE(3626),
    [sym_preproc_conditional_var] = STATE(3626),
    [sym_variable_declaration] = STATE(3626),
    [sym_preproc_if] = STATE(3152),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_var_section_repeat1] = STATE(3626),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(8296),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8298),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8298),
    [anon_sym_LBRACK] = ACTIONS(8296),
    [aux_sym_basic_type_token6] = ACTIONS(8298),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_addafter_modification_token1] = ACTIONS(8298),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8298),
    [aux_sym_modify_modification_token1] = ACTIONS(8298),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8298),
    [aux_sym_movelast_modification_token1] = ACTIONS(8298),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8298),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8298),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [anon_sym_POUNDelif] = ACTIONS(8296),
    [anon_sym_POUNDELIF] = ACTIONS(8296),
    [anon_sym_POUNDElif] = ACTIONS(8296),
    [anon_sym_POUNDelse] = ACTIONS(8296),
    [anon_sym_POUNDELSE] = ACTIONS(8296),
    [anon_sym_POUNDElse] = ACTIONS(8296),
    [anon_sym_POUNDelse2] = ACTIONS(8296),
    [anon_sym_POUNDELSE2] = ACTIONS(8296),
    [anon_sym_POUNDElse2] = ACTIONS(8296),
    [anon_sym_POUNDendif] = ACTIONS(8296),
    [anon_sym_POUNDENDIF] = ACTIONS(8296),
    [anon_sym_POUNDEndif] = ACTIONS(8296),
    [anon_sym_POUNDendif2] = ACTIONS(8296),
    [anon_sym_POUNDENDIF2] = ACTIONS(8296),
    [anon_sym_POUNDEndif2] = ACTIONS(8296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8298),
    [sym_trigger_keyword] = ACTIONS(8298),
    [sym_var_keyword] = ACTIONS(8298),
    [sym_local_keyword] = ACTIONS(8298),
    [sym_internal_keyword] = ACTIONS(8298),
    [sym_protected_keyword] = ACTIONS(8298),
    [sym_event_keyword] = ACTIONS(8298),
    [sym_fields_keyword] = ACTIONS(8298),
    [sym_keys_keyword] = ACTIONS(8298),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8298),
    [sym_actions_keyword] = ACTIONS(8298),
    [sym_layout_keyword] = ACTIONS(8298),
    [sym_area_keyword] = ACTIONS(8298),
    [sym_group_keyword] = ACTIONS(8298),
    [sym_repeater_keyword] = ACTIONS(8298),
    [sym_cuegroup_keyword] = ACTIONS(8298),
    [sym_fixed_keyword] = ACTIONS(8298),
    [sym_grid_keyword] = ACTIONS(8298),
    [sym_part_keyword] = ACTIONS(8298),
    [sym_systempart_keyword] = ACTIONS(8298),
    [sym_usercontrol_keyword] = ACTIONS(8298),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8298),
    [sym_dataitem_keyword] = ACTIONS(8298),
    [sym_column_keyword] = ACTIONS(8298),
    [sym_filter_keyword] = ACTIONS(8298),
    [sym_labels_keyword] = ACTIONS(8298),
    [sym_rendering_keyword] = ACTIONS(8298),
    [sym_requestpage_keyword] = ACTIONS(8298),
    [sym_schema_keyword] = ACTIONS(8298),
    [sym_views_keyword] = ACTIONS(8298),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8296),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_preproc_close] = ACTIONS(8296),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3628)] = {
    [sym_preproc_split_procedure] = STATE(3628),
    [sym_var_attribute_item] = STATE(3628),
    [sym_preproc_conditional_var] = STATE(3628),
    [sym_variable_declaration] = STATE(3628),
    [sym_preproc_if] = STATE(3152),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_var_section_repeat1] = STATE(3628),
    [sym_identifier] = ACTIONS(8310),
    [anon_sym_SEMI] = ACTIONS(8313),
    [aux_sym_where_condition_token1] = ACTIONS(8315),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8318),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8318),
    [anon_sym_LBRACK] = ACTIONS(8313),
    [aux_sym_basic_type_token6] = ACTIONS(8318),
    [aux_sym_basic_type_token22] = ACTIONS(8315),
    [aux_sym_basic_type_token53] = ACTIONS(8315),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8315),
    [aux_sym_addafter_modification_token1] = ACTIONS(8318),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8318),
    [aux_sym_modify_modification_token1] = ACTIONS(8318),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8318),
    [aux_sym_movelast_modification_token1] = ACTIONS(8318),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8318),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8318),
    [aux_sym_separator_action_token1] = ACTIONS(8315),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8315),
    [aux_sym_type_declaration_token1] = ACTIONS(8315),
    [anon_sym_POUNDif] = ACTIONS(8320),
    [anon_sym_POUNDIF] = ACTIONS(8320),
    [anon_sym_POUNDIf] = ACTIONS(8320),
    [anon_sym_POUNDelif] = ACTIONS(8313),
    [anon_sym_POUNDELIF] = ACTIONS(8313),
    [anon_sym_POUNDElif] = ACTIONS(8313),
    [anon_sym_POUNDelse] = ACTIONS(8313),
    [anon_sym_POUNDELSE] = ACTIONS(8313),
    [anon_sym_POUNDElse] = ACTIONS(8313),
    [anon_sym_POUNDelse2] = ACTIONS(8313),
    [anon_sym_POUNDELSE2] = ACTIONS(8313),
    [anon_sym_POUNDElse2] = ACTIONS(8313),
    [anon_sym_POUNDendif] = ACTIONS(8313),
    [anon_sym_POUNDENDIF] = ACTIONS(8313),
    [anon_sym_POUNDEndif] = ACTIONS(8313),
    [anon_sym_POUNDendif2] = ACTIONS(8313),
    [anon_sym_POUNDENDIF2] = ACTIONS(8313),
    [anon_sym_POUNDEndif2] = ACTIONS(8313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8315),
    [sym_procedure_keyword] = ACTIONS(8318),
    [sym_trigger_keyword] = ACTIONS(8318),
    [sym_var_keyword] = ACTIONS(8318),
    [sym_local_keyword] = ACTIONS(8318),
    [sym_internal_keyword] = ACTIONS(8318),
    [sym_protected_keyword] = ACTIONS(8318),
    [sym_event_keyword] = ACTIONS(8318),
    [sym_fields_keyword] = ACTIONS(8318),
    [sym_keys_keyword] = ACTIONS(8318),
    [sym_key_keyword] = ACTIONS(8315),
    [sym_fieldgroups_keyword] = ACTIONS(8318),
    [sym_actions_keyword] = ACTIONS(8318),
    [sym_layout_keyword] = ACTIONS(8318),
    [sym_area_keyword] = ACTIONS(8318),
    [sym_group_keyword] = ACTIONS(8318),
    [sym_repeater_keyword] = ACTIONS(8318),
    [sym_cuegroup_keyword] = ACTIONS(8318),
    [sym_fixed_keyword] = ACTIONS(8318),
    [sym_grid_keyword] = ACTIONS(8318),
    [sym_part_keyword] = ACTIONS(8318),
    [sym_systempart_keyword] = ACTIONS(8318),
    [sym_usercontrol_keyword] = ACTIONS(8318),
    [sym_dataset_keyword] = ACTIONS(8315),
    [sym_elements_keyword] = ACTIONS(8318),
    [sym_dataitem_keyword] = ACTIONS(8318),
    [sym_column_keyword] = ACTIONS(8318),
    [sym_filter_keyword] = ACTIONS(8318),
    [sym_labels_keyword] = ACTIONS(8318),
    [sym_rendering_keyword] = ACTIONS(8318),
    [sym_requestpage_keyword] = ACTIONS(8318),
    [sym_schema_keyword] = ACTIONS(8318),
    [sym_views_keyword] = ACTIONS(8318),
    [sym_quoted_identifier] = ACTIONS(8323),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8313),
    [sym_preproc_open] = ACTIONS(8320),
    [sym_preproc_close] = ACTIONS(8313),
    [sym_var_attribute_open] = ACTIONS(8326),
  },
  [STATE(3629)] = {
    [sym_preproc_split_procedure] = STATE(3623),
    [sym_var_attribute_item] = STATE(3623),
    [sym_preproc_conditional_var] = STATE(3623),
    [sym_variable_declaration] = STATE(3623),
    [sym_preproc_if] = STATE(3152),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_var_section_repeat1] = STATE(3623),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(8329),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8331),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8331),
    [anon_sym_LBRACK] = ACTIONS(8329),
    [aux_sym_basic_type_token6] = ACTIONS(8331),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_addafter_modification_token1] = ACTIONS(8331),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8331),
    [aux_sym_modify_modification_token1] = ACTIONS(8331),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8331),
    [aux_sym_movelast_modification_token1] = ACTIONS(8331),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8331),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8331),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [anon_sym_POUNDelif] = ACTIONS(8329),
    [anon_sym_POUNDELIF] = ACTIONS(8329),
    [anon_sym_POUNDElif] = ACTIONS(8329),
    [anon_sym_POUNDelse] = ACTIONS(8329),
    [anon_sym_POUNDELSE] = ACTIONS(8329),
    [anon_sym_POUNDElse] = ACTIONS(8329),
    [anon_sym_POUNDelse2] = ACTIONS(8329),
    [anon_sym_POUNDELSE2] = ACTIONS(8329),
    [anon_sym_POUNDElse2] = ACTIONS(8329),
    [anon_sym_POUNDendif] = ACTIONS(8329),
    [anon_sym_POUNDENDIF] = ACTIONS(8329),
    [anon_sym_POUNDEndif] = ACTIONS(8329),
    [anon_sym_POUNDendif2] = ACTIONS(8329),
    [anon_sym_POUNDENDIF2] = ACTIONS(8329),
    [anon_sym_POUNDEndif2] = ACTIONS(8329),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8331),
    [sym_trigger_keyword] = ACTIONS(8331),
    [sym_var_keyword] = ACTIONS(8331),
    [sym_local_keyword] = ACTIONS(8331),
    [sym_internal_keyword] = ACTIONS(8331),
    [sym_protected_keyword] = ACTIONS(8331),
    [sym_event_keyword] = ACTIONS(8331),
    [sym_fields_keyword] = ACTIONS(8331),
    [sym_keys_keyword] = ACTIONS(8331),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8331),
    [sym_actions_keyword] = ACTIONS(8331),
    [sym_layout_keyword] = ACTIONS(8331),
    [sym_area_keyword] = ACTIONS(8331),
    [sym_group_keyword] = ACTIONS(8331),
    [sym_repeater_keyword] = ACTIONS(8331),
    [sym_cuegroup_keyword] = ACTIONS(8331),
    [sym_fixed_keyword] = ACTIONS(8331),
    [sym_grid_keyword] = ACTIONS(8331),
    [sym_part_keyword] = ACTIONS(8331),
    [sym_systempart_keyword] = ACTIONS(8331),
    [sym_usercontrol_keyword] = ACTIONS(8331),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8331),
    [sym_dataitem_keyword] = ACTIONS(8331),
    [sym_column_keyword] = ACTIONS(8331),
    [sym_filter_keyword] = ACTIONS(8331),
    [sym_labels_keyword] = ACTIONS(8331),
    [sym_rendering_keyword] = ACTIONS(8331),
    [sym_requestpage_keyword] = ACTIONS(8331),
    [sym_schema_keyword] = ACTIONS(8331),
    [sym_views_keyword] = ACTIONS(8331),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8329),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_preproc_close] = ACTIONS(8329),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3630)] = {
    [ts_builtin_sym_end] = ACTIONS(6826),
    [anon_sym_POUNDif] = ACTIONS(6826),
    [anon_sym_POUNDIF] = ACTIONS(6826),
    [anon_sym_POUNDIf] = ACTIONS(6826),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6828),
    [anon_sym_tableextension] = ACTIONS(6826),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6826),
    [anon_sym_Tableextension] = ACTIONS(6826),
    [anon_sym_TableExtension] = ACTIONS(6826),
    [anon_sym_tableExtension] = ACTIONS(6826),
    [sym_page_keyword] = ACTIONS(6828),
    [anon_sym_pageextension] = ACTIONS(6826),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6826),
    [anon_sym_Pageextension] = ACTIONS(6826),
    [anon_sym_PageExtension] = ACTIONS(6826),
    [anon_sym_pageExtension] = ACTIONS(6826),
    [anon_sym_codeunit] = ACTIONS(6826),
    [anon_sym_CODEUNIT] = ACTIONS(6826),
    [anon_sym_Codeunit] = ACTIONS(6826),
    [anon_sym_CodeUnit] = ACTIONS(6826),
    [anon_sym_COdeunit] = ACTIONS(6826),
    [anon_sym_codeUnit] = ACTIONS(6826),
    [sym_report_keyword] = ACTIONS(6828),
    [anon_sym_reportextension] = ACTIONS(6826),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6826),
    [anon_sym_Reportextension] = ACTIONS(6826),
    [anon_sym_ReportExtension] = ACTIONS(6826),
    [anon_sym_reportExtension] = ACTIONS(6826),
    [sym_query_keyword] = ACTIONS(6826),
    [anon_sym_xmlport] = ACTIONS(6826),
    [anon_sym_XMLPORT] = ACTIONS(6826),
    [anon_sym_Xmlport] = ACTIONS(6826),
    [anon_sym_XMLport] = ACTIONS(6826),
    [anon_sym_XMLPort] = ACTIONS(6826),
    [anon_sym_XmlPort] = ACTIONS(6826),
    [anon_sym_enum] = ACTIONS(6828),
    [anon_sym_ENUM] = ACTIONS(6828),
    [anon_sym_Enum] = ACTIONS(6828),
    [anon_sym_eNUM] = ACTIONS(6826),
    [anon_sym_eNum] = ACTIONS(6826),
    [anon_sym_ENum] = ACTIONS(6826),
    [anon_sym_enumextension] = ACTIONS(6826),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6826),
    [anon_sym_Enumextension] = ACTIONS(6826),
    [anon_sym_EnumExtension] = ACTIONS(6826),
    [anon_sym_enumExtension] = ACTIONS(6826),
    [sym_interface_keyword] = ACTIONS(6826),
    [anon_sym_controladdin] = ACTIONS(6826),
    [anon_sym_CONTROLADDIN] = ACTIONS(6826),
    [anon_sym_Controladdin] = ACTIONS(6826),
    [anon_sym_ControlAddIn] = ACTIONS(6826),
    [anon_sym_ControlAddin] = ACTIONS(6826),
    [anon_sym_controlAddIn] = ACTIONS(6826),
    [anon_sym_controlAddin] = ACTIONS(6826),
    [anon_sym_dotnet] = ACTIONS(6826),
    [anon_sym_DOTNET] = ACTIONS(6826),
    [anon_sym_Dotnet] = ACTIONS(6826),
    [anon_sym_DotNet] = ACTIONS(6826),
    [anon_sym_dotNet] = ACTIONS(6826),
    [sym_profile_keyword] = ACTIONS(6828),
    [anon_sym_profileextension] = ACTIONS(6826),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6826),
    [anon_sym_Profileextension] = ACTIONS(6826),
    [anon_sym_ProfileExtension] = ACTIONS(6826),
    [anon_sym_profileExtension] = ACTIONS(6826),
    [anon_sym_permissionset] = ACTIONS(6828),
    [anon_sym_PERMISSIONSET] = ACTIONS(6828),
    [anon_sym_Permissionset] = ACTIONS(6828),
    [anon_sym_PermissionSet] = ACTIONS(6828),
    [anon_sym_permissionSet] = ACTIONS(6828),
    [anon_sym_permissionsetextension] = ACTIONS(6826),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6826),
    [anon_sym_Permissionsetextension] = ACTIONS(6826),
    [anon_sym_PermissionSetExtension] = ACTIONS(6826),
    [anon_sym_permissionSetExtension] = ACTIONS(6826),
    [sym_entitlement_keyword] = ACTIONS(6826),
    [anon_sym_pagecustomization] = ACTIONS(6826),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6826),
    [anon_sym_Pagecustomization] = ACTIONS(6826),
    [anon_sym_PageCustomization] = ACTIONS(6826),
    [anon_sym_pageCustomization] = ACTIONS(6826),
    [sym_using_keyword] = ACTIONS(6826),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6826),
  },
  [STATE(3631)] = {
    [ts_builtin_sym_end] = ACTIONS(7087),
    [anon_sym_POUNDif] = ACTIONS(7087),
    [anon_sym_POUNDIF] = ACTIONS(7087),
    [anon_sym_POUNDIf] = ACTIONS(7087),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7089),
    [anon_sym_tableextension] = ACTIONS(7087),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7087),
    [anon_sym_Tableextension] = ACTIONS(7087),
    [anon_sym_TableExtension] = ACTIONS(7087),
    [anon_sym_tableExtension] = ACTIONS(7087),
    [sym_page_keyword] = ACTIONS(7089),
    [anon_sym_pageextension] = ACTIONS(7087),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7087),
    [anon_sym_Pageextension] = ACTIONS(7087),
    [anon_sym_PageExtension] = ACTIONS(7087),
    [anon_sym_pageExtension] = ACTIONS(7087),
    [anon_sym_codeunit] = ACTIONS(7087),
    [anon_sym_CODEUNIT] = ACTIONS(7087),
    [anon_sym_Codeunit] = ACTIONS(7087),
    [anon_sym_CodeUnit] = ACTIONS(7087),
    [anon_sym_COdeunit] = ACTIONS(7087),
    [anon_sym_codeUnit] = ACTIONS(7087),
    [sym_report_keyword] = ACTIONS(7089),
    [anon_sym_reportextension] = ACTIONS(7087),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7087),
    [anon_sym_Reportextension] = ACTIONS(7087),
    [anon_sym_ReportExtension] = ACTIONS(7087),
    [anon_sym_reportExtension] = ACTIONS(7087),
    [sym_query_keyword] = ACTIONS(7087),
    [anon_sym_xmlport] = ACTIONS(7087),
    [anon_sym_XMLPORT] = ACTIONS(7087),
    [anon_sym_Xmlport] = ACTIONS(7087),
    [anon_sym_XMLport] = ACTIONS(7087),
    [anon_sym_XMLPort] = ACTIONS(7087),
    [anon_sym_XmlPort] = ACTIONS(7087),
    [anon_sym_enum] = ACTIONS(7089),
    [anon_sym_ENUM] = ACTIONS(7089),
    [anon_sym_Enum] = ACTIONS(7089),
    [anon_sym_eNUM] = ACTIONS(7087),
    [anon_sym_eNum] = ACTIONS(7087),
    [anon_sym_ENum] = ACTIONS(7087),
    [anon_sym_enumextension] = ACTIONS(7087),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7087),
    [anon_sym_Enumextension] = ACTIONS(7087),
    [anon_sym_EnumExtension] = ACTIONS(7087),
    [anon_sym_enumExtension] = ACTIONS(7087),
    [sym_interface_keyword] = ACTIONS(7087),
    [anon_sym_controladdin] = ACTIONS(7087),
    [anon_sym_CONTROLADDIN] = ACTIONS(7087),
    [anon_sym_Controladdin] = ACTIONS(7087),
    [anon_sym_ControlAddIn] = ACTIONS(7087),
    [anon_sym_ControlAddin] = ACTIONS(7087),
    [anon_sym_controlAddIn] = ACTIONS(7087),
    [anon_sym_controlAddin] = ACTIONS(7087),
    [anon_sym_dotnet] = ACTIONS(7087),
    [anon_sym_DOTNET] = ACTIONS(7087),
    [anon_sym_Dotnet] = ACTIONS(7087),
    [anon_sym_DotNet] = ACTIONS(7087),
    [anon_sym_dotNet] = ACTIONS(7087),
    [sym_profile_keyword] = ACTIONS(7089),
    [anon_sym_profileextension] = ACTIONS(7087),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7087),
    [anon_sym_Profileextension] = ACTIONS(7087),
    [anon_sym_ProfileExtension] = ACTIONS(7087),
    [anon_sym_profileExtension] = ACTIONS(7087),
    [anon_sym_permissionset] = ACTIONS(7089),
    [anon_sym_PERMISSIONSET] = ACTIONS(7089),
    [anon_sym_Permissionset] = ACTIONS(7089),
    [anon_sym_PermissionSet] = ACTIONS(7089),
    [anon_sym_permissionSet] = ACTIONS(7089),
    [anon_sym_permissionsetextension] = ACTIONS(7087),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7087),
    [anon_sym_Permissionsetextension] = ACTIONS(7087),
    [anon_sym_PermissionSetExtension] = ACTIONS(7087),
    [anon_sym_permissionSetExtension] = ACTIONS(7087),
    [sym_entitlement_keyword] = ACTIONS(7087),
    [anon_sym_pagecustomization] = ACTIONS(7087),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7087),
    [anon_sym_Pagecustomization] = ACTIONS(7087),
    [anon_sym_PageCustomization] = ACTIONS(7087),
    [anon_sym_pageCustomization] = ACTIONS(7087),
    [sym_using_keyword] = ACTIONS(7087),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7087),
  },
  [STATE(3632)] = {
    [sym_boolean] = STATE(8820),
    [sym_simple_table_relation] = STATE(6570),
    [sym__namespaced_or_simple_ref] = STATE(5577),
    [sym_assignment_expression] = STATE(8820),
    [sym__expression] = STATE(8820),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8820),
    [sym_multiplicative_expression] = STATE(8820),
    [sym_additive_expression] = STATE(8820),
    [sym_comparison_expression] = STATE(8820),
    [sym_logical_expression] = STATE(8820),
    [sym_ternary_expression] = STATE(8820),
    [sym_unary_expression] = STATE(8820),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(2813),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8820),
    [sym_list_literal] = STATE(8820),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8820),
    [sym__literal_value] = STATE(8820),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(5439),
    [sym_keyword_as_identifier] = STATE(5439),
    [sym_identifier] = ACTIONS(7553),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7555),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7559),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7557),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7557),
    [aux_sym_separator_action_token1] = ACTIONS(7557),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7557),
    [aux_sym_type_declaration_token1] = ACTIONS(7557),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7561),
    [sym_date_literal] = ACTIONS(7555),
    [sym_time_literal] = ACTIONS(7555),
    [sym_biginteger_literal] = ACTIONS(7561),
    [sym_table_keyword] = ACTIONS(7557),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7557),
    [sym_dataset_keyword] = ACTIONS(7557),
    [sym_quoted_identifier] = ACTIONS(7563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7561),
    [sym_verbatim_string] = ACTIONS(7561),
    [sym_integer] = ACTIONS(7565),
    [sym_continue_as_identifier] = ACTIONS(7561),
  },
  [STATE(3633)] = {
    [ts_builtin_sym_end] = ACTIONS(7091),
    [anon_sym_POUNDif] = ACTIONS(7091),
    [anon_sym_POUNDIF] = ACTIONS(7091),
    [anon_sym_POUNDIf] = ACTIONS(7091),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7093),
    [anon_sym_tableextension] = ACTIONS(7091),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7091),
    [anon_sym_Tableextension] = ACTIONS(7091),
    [anon_sym_TableExtension] = ACTIONS(7091),
    [anon_sym_tableExtension] = ACTIONS(7091),
    [sym_page_keyword] = ACTIONS(7093),
    [anon_sym_pageextension] = ACTIONS(7091),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7091),
    [anon_sym_Pageextension] = ACTIONS(7091),
    [anon_sym_PageExtension] = ACTIONS(7091),
    [anon_sym_pageExtension] = ACTIONS(7091),
    [anon_sym_codeunit] = ACTIONS(7091),
    [anon_sym_CODEUNIT] = ACTIONS(7091),
    [anon_sym_Codeunit] = ACTIONS(7091),
    [anon_sym_CodeUnit] = ACTIONS(7091),
    [anon_sym_COdeunit] = ACTIONS(7091),
    [anon_sym_codeUnit] = ACTIONS(7091),
    [sym_report_keyword] = ACTIONS(7093),
    [anon_sym_reportextension] = ACTIONS(7091),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7091),
    [anon_sym_Reportextension] = ACTIONS(7091),
    [anon_sym_ReportExtension] = ACTIONS(7091),
    [anon_sym_reportExtension] = ACTIONS(7091),
    [sym_query_keyword] = ACTIONS(7091),
    [anon_sym_xmlport] = ACTIONS(7091),
    [anon_sym_XMLPORT] = ACTIONS(7091),
    [anon_sym_Xmlport] = ACTIONS(7091),
    [anon_sym_XMLport] = ACTIONS(7091),
    [anon_sym_XMLPort] = ACTIONS(7091),
    [anon_sym_XmlPort] = ACTIONS(7091),
    [anon_sym_enum] = ACTIONS(7093),
    [anon_sym_ENUM] = ACTIONS(7093),
    [anon_sym_Enum] = ACTIONS(7093),
    [anon_sym_eNUM] = ACTIONS(7091),
    [anon_sym_eNum] = ACTIONS(7091),
    [anon_sym_ENum] = ACTIONS(7091),
    [anon_sym_enumextension] = ACTIONS(7091),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7091),
    [anon_sym_Enumextension] = ACTIONS(7091),
    [anon_sym_EnumExtension] = ACTIONS(7091),
    [anon_sym_enumExtension] = ACTIONS(7091),
    [sym_interface_keyword] = ACTIONS(7091),
    [anon_sym_controladdin] = ACTIONS(7091),
    [anon_sym_CONTROLADDIN] = ACTIONS(7091),
    [anon_sym_Controladdin] = ACTIONS(7091),
    [anon_sym_ControlAddIn] = ACTIONS(7091),
    [anon_sym_ControlAddin] = ACTIONS(7091),
    [anon_sym_controlAddIn] = ACTIONS(7091),
    [anon_sym_controlAddin] = ACTIONS(7091),
    [anon_sym_dotnet] = ACTIONS(7091),
    [anon_sym_DOTNET] = ACTIONS(7091),
    [anon_sym_Dotnet] = ACTIONS(7091),
    [anon_sym_DotNet] = ACTIONS(7091),
    [anon_sym_dotNet] = ACTIONS(7091),
    [sym_profile_keyword] = ACTIONS(7093),
    [anon_sym_profileextension] = ACTIONS(7091),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7091),
    [anon_sym_Profileextension] = ACTIONS(7091),
    [anon_sym_ProfileExtension] = ACTIONS(7091),
    [anon_sym_profileExtension] = ACTIONS(7091),
    [anon_sym_permissionset] = ACTIONS(7093),
    [anon_sym_PERMISSIONSET] = ACTIONS(7093),
    [anon_sym_Permissionset] = ACTIONS(7093),
    [anon_sym_PermissionSet] = ACTIONS(7093),
    [anon_sym_permissionSet] = ACTIONS(7093),
    [anon_sym_permissionsetextension] = ACTIONS(7091),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7091),
    [anon_sym_Permissionsetextension] = ACTIONS(7091),
    [anon_sym_PermissionSetExtension] = ACTIONS(7091),
    [anon_sym_permissionSetExtension] = ACTIONS(7091),
    [sym_entitlement_keyword] = ACTIONS(7091),
    [anon_sym_pagecustomization] = ACTIONS(7091),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7091),
    [anon_sym_Pagecustomization] = ACTIONS(7091),
    [anon_sym_PageCustomization] = ACTIONS(7091),
    [anon_sym_pageCustomization] = ACTIONS(7091),
    [sym_using_keyword] = ACTIONS(7091),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7091),
  },
  [STATE(3634)] = {
    [ts_builtin_sym_end] = ACTIONS(6935),
    [anon_sym_POUNDif] = ACTIONS(6935),
    [anon_sym_POUNDIF] = ACTIONS(6935),
    [anon_sym_POUNDIf] = ACTIONS(6935),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6937),
    [anon_sym_tableextension] = ACTIONS(6935),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6935),
    [anon_sym_Tableextension] = ACTIONS(6935),
    [anon_sym_TableExtension] = ACTIONS(6935),
    [anon_sym_tableExtension] = ACTIONS(6935),
    [sym_page_keyword] = ACTIONS(6937),
    [anon_sym_pageextension] = ACTIONS(6935),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6935),
    [anon_sym_Pageextension] = ACTIONS(6935),
    [anon_sym_PageExtension] = ACTIONS(6935),
    [anon_sym_pageExtension] = ACTIONS(6935),
    [anon_sym_codeunit] = ACTIONS(6935),
    [anon_sym_CODEUNIT] = ACTIONS(6935),
    [anon_sym_Codeunit] = ACTIONS(6935),
    [anon_sym_CodeUnit] = ACTIONS(6935),
    [anon_sym_COdeunit] = ACTIONS(6935),
    [anon_sym_codeUnit] = ACTIONS(6935),
    [sym_report_keyword] = ACTIONS(6937),
    [anon_sym_reportextension] = ACTIONS(6935),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6935),
    [anon_sym_Reportextension] = ACTIONS(6935),
    [anon_sym_ReportExtension] = ACTIONS(6935),
    [anon_sym_reportExtension] = ACTIONS(6935),
    [sym_query_keyword] = ACTIONS(6935),
    [anon_sym_xmlport] = ACTIONS(6935),
    [anon_sym_XMLPORT] = ACTIONS(6935),
    [anon_sym_Xmlport] = ACTIONS(6935),
    [anon_sym_XMLport] = ACTIONS(6935),
    [anon_sym_XMLPort] = ACTIONS(6935),
    [anon_sym_XmlPort] = ACTIONS(6935),
    [anon_sym_enum] = ACTIONS(6937),
    [anon_sym_ENUM] = ACTIONS(6937),
    [anon_sym_Enum] = ACTIONS(6937),
    [anon_sym_eNUM] = ACTIONS(6935),
    [anon_sym_eNum] = ACTIONS(6935),
    [anon_sym_ENum] = ACTIONS(6935),
    [anon_sym_enumextension] = ACTIONS(6935),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6935),
    [anon_sym_Enumextension] = ACTIONS(6935),
    [anon_sym_EnumExtension] = ACTIONS(6935),
    [anon_sym_enumExtension] = ACTIONS(6935),
    [sym_interface_keyword] = ACTIONS(6935),
    [anon_sym_controladdin] = ACTIONS(6935),
    [anon_sym_CONTROLADDIN] = ACTIONS(6935),
    [anon_sym_Controladdin] = ACTIONS(6935),
    [anon_sym_ControlAddIn] = ACTIONS(6935),
    [anon_sym_ControlAddin] = ACTIONS(6935),
    [anon_sym_controlAddIn] = ACTIONS(6935),
    [anon_sym_controlAddin] = ACTIONS(6935),
    [anon_sym_dotnet] = ACTIONS(6935),
    [anon_sym_DOTNET] = ACTIONS(6935),
    [anon_sym_Dotnet] = ACTIONS(6935),
    [anon_sym_DotNet] = ACTIONS(6935),
    [anon_sym_dotNet] = ACTIONS(6935),
    [sym_profile_keyword] = ACTIONS(6937),
    [anon_sym_profileextension] = ACTIONS(6935),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6935),
    [anon_sym_Profileextension] = ACTIONS(6935),
    [anon_sym_ProfileExtension] = ACTIONS(6935),
    [anon_sym_profileExtension] = ACTIONS(6935),
    [anon_sym_permissionset] = ACTIONS(6937),
    [anon_sym_PERMISSIONSET] = ACTIONS(6937),
    [anon_sym_Permissionset] = ACTIONS(6937),
    [anon_sym_PermissionSet] = ACTIONS(6937),
    [anon_sym_permissionSet] = ACTIONS(6937),
    [anon_sym_permissionsetextension] = ACTIONS(6935),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6935),
    [anon_sym_Permissionsetextension] = ACTIONS(6935),
    [anon_sym_PermissionSetExtension] = ACTIONS(6935),
    [anon_sym_permissionSetExtension] = ACTIONS(6935),
    [sym_entitlement_keyword] = ACTIONS(6935),
    [anon_sym_pagecustomization] = ACTIONS(6935),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6935),
    [anon_sym_Pagecustomization] = ACTIONS(6935),
    [anon_sym_PageCustomization] = ACTIONS(6935),
    [anon_sym_pageCustomization] = ACTIONS(6935),
    [sym_using_keyword] = ACTIONS(6935),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6935),
  },
  [STATE(3635)] = {
    [sym_identifier] = ACTIONS(3651),
    [anon_sym_DOT] = ACTIONS(3651),
    [anon_sym_EQ] = ACTIONS(3653),
    [anon_sym_DASH] = ACTIONS(3651),
    [aux_sym_boolean_token1] = ACTIONS(3651),
    [aux_sym_boolean_token2] = ACTIONS(3651),
    [sym_decimal] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3653),
    [anon_sym_RPAREN] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3653),
    [aux_sym_filter_value_token1] = ACTIONS(3651),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3651),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_LBRACK] = ACTIONS(3653),
    [aux_sym_record_type_token1] = ACTIONS(3651),
    [aux_sym_basic_type_token21] = ACTIONS(3651),
    [aux_sym_basic_type_token22] = ACTIONS(3651),
    [aux_sym_basic_type_token48] = ACTIONS(3651),
    [anon_sym_COLON_COLON] = ACTIONS(3653),
    [anon_sym_not] = ACTIONS(3651),
    [anon_sym_NOT] = ACTIONS(3651),
    [anon_sym_Not] = ACTIONS(3651),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3653),
    [aux_sym__expression_token1] = ACTIONS(3653),
    [aux_sym__expression_token2] = ACTIONS(3653),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3651),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3651),
    [anon_sym_SLASH] = ACTIONS(3651),
    [anon_sym_div] = ACTIONS(3651),
    [anon_sym_DIV] = ACTIONS(3651),
    [anon_sym_Div] = ACTIONS(3651),
    [anon_sym_mod] = ACTIONS(3651),
    [anon_sym_MOD] = ACTIONS(3651),
    [anon_sym_Mod] = ACTIONS(3651),
    [anon_sym_PLUS] = ACTIONS(3651),
    [anon_sym_GT_EQ] = ACTIONS(3653),
    [anon_sym_LT_EQ] = ACTIONS(3653),
    [anon_sym_GT] = ACTIONS(3651),
    [anon_sym_LT] = ACTIONS(3651),
    [anon_sym_LT_GT] = ACTIONS(3653),
    [anon_sym_and] = ACTIONS(3651),
    [anon_sym_AND] = ACTIONS(3651),
    [anon_sym_And] = ACTIONS(3651),
    [anon_sym_or] = ACTIONS(3651),
    [anon_sym_OR] = ACTIONS(3651),
    [anon_sym_Or] = ACTIONS(3651),
    [anon_sym_xor] = ACTIONS(3651),
    [anon_sym_XOR] = ACTIONS(3651),
    [anon_sym_Xor] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [sym_datetime_literal] = ACTIONS(3653),
    [sym_date_literal] = ACTIONS(3651),
    [sym_time_literal] = ACTIONS(3651),
    [sym_biginteger_literal] = ACTIONS(3653),
    [anon_sym_in] = ACTIONS(3651),
    [anon_sym_IN] = ACTIONS(3651),
    [anon_sym_In] = ACTIONS(3651),
    [sym_page_keyword] = ACTIONS(3651),
    [anon_sym_codeunit] = ACTIONS(3651),
    [anon_sym_CODEUNIT] = ACTIONS(3651),
    [anon_sym_Codeunit] = ACTIONS(3651),
    [anon_sym_CodeUnit] = ACTIONS(3651),
    [anon_sym_COdeunit] = ACTIONS(3651),
    [anon_sym_codeUnit] = ACTIONS(3651),
    [sym_report_keyword] = ACTIONS(3651),
    [sym_query_keyword] = ACTIONS(3651),
    [anon_sym_xmlport] = ACTIONS(3651),
    [anon_sym_XMLPORT] = ACTIONS(3651),
    [anon_sym_Xmlport] = ACTIONS(3651),
    [anon_sym_XMLport] = ACTIONS(3651),
    [anon_sym_XMLPort] = ACTIONS(3651),
    [anon_sym_XmlPort] = ACTIONS(3651),
    [anon_sym_enum] = ACTIONS(3651),
    [anon_sym_ENUM] = ACTIONS(3651),
    [anon_sym_Enum] = ACTIONS(3651),
    [anon_sym_eNUM] = ACTIONS(3651),
    [anon_sym_eNum] = ACTIONS(3651),
    [anon_sym_ENum] = ACTIONS(3651),
    [sym_quoted_identifier] = ACTIONS(3653),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3653),
    [sym_verbatim_string] = ACTIONS(3653),
    [sym_integer] = ACTIONS(3651),
    [sym_continue_as_identifier] = ACTIONS(3653),
  },
  [STATE(3636)] = {
    [ts_builtin_sym_end] = ACTIONS(6850),
    [anon_sym_POUNDif] = ACTIONS(6850),
    [anon_sym_POUNDIF] = ACTIONS(6850),
    [anon_sym_POUNDIf] = ACTIONS(6850),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6852),
    [anon_sym_tableextension] = ACTIONS(6850),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6850),
    [anon_sym_Tableextension] = ACTIONS(6850),
    [anon_sym_TableExtension] = ACTIONS(6850),
    [anon_sym_tableExtension] = ACTIONS(6850),
    [sym_page_keyword] = ACTIONS(6852),
    [anon_sym_pageextension] = ACTIONS(6850),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6850),
    [anon_sym_Pageextension] = ACTIONS(6850),
    [anon_sym_PageExtension] = ACTIONS(6850),
    [anon_sym_pageExtension] = ACTIONS(6850),
    [anon_sym_codeunit] = ACTIONS(6850),
    [anon_sym_CODEUNIT] = ACTIONS(6850),
    [anon_sym_Codeunit] = ACTIONS(6850),
    [anon_sym_CodeUnit] = ACTIONS(6850),
    [anon_sym_COdeunit] = ACTIONS(6850),
    [anon_sym_codeUnit] = ACTIONS(6850),
    [sym_report_keyword] = ACTIONS(6852),
    [anon_sym_reportextension] = ACTIONS(6850),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6850),
    [anon_sym_Reportextension] = ACTIONS(6850),
    [anon_sym_ReportExtension] = ACTIONS(6850),
    [anon_sym_reportExtension] = ACTIONS(6850),
    [sym_query_keyword] = ACTIONS(6850),
    [anon_sym_xmlport] = ACTIONS(6850),
    [anon_sym_XMLPORT] = ACTIONS(6850),
    [anon_sym_Xmlport] = ACTIONS(6850),
    [anon_sym_XMLport] = ACTIONS(6850),
    [anon_sym_XMLPort] = ACTIONS(6850),
    [anon_sym_XmlPort] = ACTIONS(6850),
    [anon_sym_enum] = ACTIONS(6852),
    [anon_sym_ENUM] = ACTIONS(6852),
    [anon_sym_Enum] = ACTIONS(6852),
    [anon_sym_eNUM] = ACTIONS(6850),
    [anon_sym_eNum] = ACTIONS(6850),
    [anon_sym_ENum] = ACTIONS(6850),
    [anon_sym_enumextension] = ACTIONS(6850),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6850),
    [anon_sym_Enumextension] = ACTIONS(6850),
    [anon_sym_EnumExtension] = ACTIONS(6850),
    [anon_sym_enumExtension] = ACTIONS(6850),
    [sym_interface_keyword] = ACTIONS(6850),
    [anon_sym_controladdin] = ACTIONS(6850),
    [anon_sym_CONTROLADDIN] = ACTIONS(6850),
    [anon_sym_Controladdin] = ACTIONS(6850),
    [anon_sym_ControlAddIn] = ACTIONS(6850),
    [anon_sym_ControlAddin] = ACTIONS(6850),
    [anon_sym_controlAddIn] = ACTIONS(6850),
    [anon_sym_controlAddin] = ACTIONS(6850),
    [anon_sym_dotnet] = ACTIONS(6850),
    [anon_sym_DOTNET] = ACTIONS(6850),
    [anon_sym_Dotnet] = ACTIONS(6850),
    [anon_sym_DotNet] = ACTIONS(6850),
    [anon_sym_dotNet] = ACTIONS(6850),
    [sym_profile_keyword] = ACTIONS(6852),
    [anon_sym_profileextension] = ACTIONS(6850),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6850),
    [anon_sym_Profileextension] = ACTIONS(6850),
    [anon_sym_ProfileExtension] = ACTIONS(6850),
    [anon_sym_profileExtension] = ACTIONS(6850),
    [anon_sym_permissionset] = ACTIONS(6852),
    [anon_sym_PERMISSIONSET] = ACTIONS(6852),
    [anon_sym_Permissionset] = ACTIONS(6852),
    [anon_sym_PermissionSet] = ACTIONS(6852),
    [anon_sym_permissionSet] = ACTIONS(6852),
    [anon_sym_permissionsetextension] = ACTIONS(6850),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6850),
    [anon_sym_Permissionsetextension] = ACTIONS(6850),
    [anon_sym_PermissionSetExtension] = ACTIONS(6850),
    [anon_sym_permissionSetExtension] = ACTIONS(6850),
    [sym_entitlement_keyword] = ACTIONS(6850),
    [anon_sym_pagecustomization] = ACTIONS(6850),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6850),
    [anon_sym_Pagecustomization] = ACTIONS(6850),
    [anon_sym_PageCustomization] = ACTIONS(6850),
    [anon_sym_pageCustomization] = ACTIONS(6850),
    [sym_using_keyword] = ACTIONS(6850),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6850),
  },
  [STATE(3637)] = {
    [ts_builtin_sym_end] = ACTIONS(7097),
    [anon_sym_POUNDif] = ACTIONS(7097),
    [anon_sym_POUNDIF] = ACTIONS(7097),
    [anon_sym_POUNDIf] = ACTIONS(7097),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7099),
    [anon_sym_tableextension] = ACTIONS(7097),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7097),
    [anon_sym_Tableextension] = ACTIONS(7097),
    [anon_sym_TableExtension] = ACTIONS(7097),
    [anon_sym_tableExtension] = ACTIONS(7097),
    [sym_page_keyword] = ACTIONS(7099),
    [anon_sym_pageextension] = ACTIONS(7097),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7097),
    [anon_sym_Pageextension] = ACTIONS(7097),
    [anon_sym_PageExtension] = ACTIONS(7097),
    [anon_sym_pageExtension] = ACTIONS(7097),
    [anon_sym_codeunit] = ACTIONS(7097),
    [anon_sym_CODEUNIT] = ACTIONS(7097),
    [anon_sym_Codeunit] = ACTIONS(7097),
    [anon_sym_CodeUnit] = ACTIONS(7097),
    [anon_sym_COdeunit] = ACTIONS(7097),
    [anon_sym_codeUnit] = ACTIONS(7097),
    [sym_report_keyword] = ACTIONS(7099),
    [anon_sym_reportextension] = ACTIONS(7097),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7097),
    [anon_sym_Reportextension] = ACTIONS(7097),
    [anon_sym_ReportExtension] = ACTIONS(7097),
    [anon_sym_reportExtension] = ACTIONS(7097),
    [sym_query_keyword] = ACTIONS(7097),
    [anon_sym_xmlport] = ACTIONS(7097),
    [anon_sym_XMLPORT] = ACTIONS(7097),
    [anon_sym_Xmlport] = ACTIONS(7097),
    [anon_sym_XMLport] = ACTIONS(7097),
    [anon_sym_XMLPort] = ACTIONS(7097),
    [anon_sym_XmlPort] = ACTIONS(7097),
    [anon_sym_enum] = ACTIONS(7099),
    [anon_sym_ENUM] = ACTIONS(7099),
    [anon_sym_Enum] = ACTIONS(7099),
    [anon_sym_eNUM] = ACTIONS(7097),
    [anon_sym_eNum] = ACTIONS(7097),
    [anon_sym_ENum] = ACTIONS(7097),
    [anon_sym_enumextension] = ACTIONS(7097),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7097),
    [anon_sym_Enumextension] = ACTIONS(7097),
    [anon_sym_EnumExtension] = ACTIONS(7097),
    [anon_sym_enumExtension] = ACTIONS(7097),
    [sym_interface_keyword] = ACTIONS(7097),
    [anon_sym_controladdin] = ACTIONS(7097),
    [anon_sym_CONTROLADDIN] = ACTIONS(7097),
    [anon_sym_Controladdin] = ACTIONS(7097),
    [anon_sym_ControlAddIn] = ACTIONS(7097),
    [anon_sym_ControlAddin] = ACTIONS(7097),
    [anon_sym_controlAddIn] = ACTIONS(7097),
    [anon_sym_controlAddin] = ACTIONS(7097),
    [anon_sym_dotnet] = ACTIONS(7097),
    [anon_sym_DOTNET] = ACTIONS(7097),
    [anon_sym_Dotnet] = ACTIONS(7097),
    [anon_sym_DotNet] = ACTIONS(7097),
    [anon_sym_dotNet] = ACTIONS(7097),
    [sym_profile_keyword] = ACTIONS(7099),
    [anon_sym_profileextension] = ACTIONS(7097),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7097),
    [anon_sym_Profileextension] = ACTIONS(7097),
    [anon_sym_ProfileExtension] = ACTIONS(7097),
    [anon_sym_profileExtension] = ACTIONS(7097),
    [anon_sym_permissionset] = ACTIONS(7099),
    [anon_sym_PERMISSIONSET] = ACTIONS(7099),
    [anon_sym_Permissionset] = ACTIONS(7099),
    [anon_sym_PermissionSet] = ACTIONS(7099),
    [anon_sym_permissionSet] = ACTIONS(7099),
    [anon_sym_permissionsetextension] = ACTIONS(7097),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7097),
    [anon_sym_Permissionsetextension] = ACTIONS(7097),
    [anon_sym_PermissionSetExtension] = ACTIONS(7097),
    [anon_sym_permissionSetExtension] = ACTIONS(7097),
    [sym_entitlement_keyword] = ACTIONS(7097),
    [anon_sym_pagecustomization] = ACTIONS(7097),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7097),
    [anon_sym_Pagecustomization] = ACTIONS(7097),
    [anon_sym_PageCustomization] = ACTIONS(7097),
    [anon_sym_pageCustomization] = ACTIONS(7097),
    [sym_using_keyword] = ACTIONS(7097),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7097),
  },
  [STATE(3638)] = {
    [ts_builtin_sym_end] = ACTIONS(7129),
    [anon_sym_POUNDif] = ACTIONS(7129),
    [anon_sym_POUNDIF] = ACTIONS(7129),
    [anon_sym_POUNDIf] = ACTIONS(7129),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7131),
    [anon_sym_tableextension] = ACTIONS(7129),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7129),
    [anon_sym_Tableextension] = ACTIONS(7129),
    [anon_sym_TableExtension] = ACTIONS(7129),
    [anon_sym_tableExtension] = ACTIONS(7129),
    [sym_page_keyword] = ACTIONS(7131),
    [anon_sym_pageextension] = ACTIONS(7129),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7129),
    [anon_sym_Pageextension] = ACTIONS(7129),
    [anon_sym_PageExtension] = ACTIONS(7129),
    [anon_sym_pageExtension] = ACTIONS(7129),
    [anon_sym_codeunit] = ACTIONS(7129),
    [anon_sym_CODEUNIT] = ACTIONS(7129),
    [anon_sym_Codeunit] = ACTIONS(7129),
    [anon_sym_CodeUnit] = ACTIONS(7129),
    [anon_sym_COdeunit] = ACTIONS(7129),
    [anon_sym_codeUnit] = ACTIONS(7129),
    [sym_report_keyword] = ACTIONS(7131),
    [anon_sym_reportextension] = ACTIONS(7129),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7129),
    [anon_sym_Reportextension] = ACTIONS(7129),
    [anon_sym_ReportExtension] = ACTIONS(7129),
    [anon_sym_reportExtension] = ACTIONS(7129),
    [sym_query_keyword] = ACTIONS(7129),
    [anon_sym_xmlport] = ACTIONS(7129),
    [anon_sym_XMLPORT] = ACTIONS(7129),
    [anon_sym_Xmlport] = ACTIONS(7129),
    [anon_sym_XMLport] = ACTIONS(7129),
    [anon_sym_XMLPort] = ACTIONS(7129),
    [anon_sym_XmlPort] = ACTIONS(7129),
    [anon_sym_enum] = ACTIONS(7131),
    [anon_sym_ENUM] = ACTIONS(7131),
    [anon_sym_Enum] = ACTIONS(7131),
    [anon_sym_eNUM] = ACTIONS(7129),
    [anon_sym_eNum] = ACTIONS(7129),
    [anon_sym_ENum] = ACTIONS(7129),
    [anon_sym_enumextension] = ACTIONS(7129),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7129),
    [anon_sym_Enumextension] = ACTIONS(7129),
    [anon_sym_EnumExtension] = ACTIONS(7129),
    [anon_sym_enumExtension] = ACTIONS(7129),
    [sym_interface_keyword] = ACTIONS(7129),
    [anon_sym_controladdin] = ACTIONS(7129),
    [anon_sym_CONTROLADDIN] = ACTIONS(7129),
    [anon_sym_Controladdin] = ACTIONS(7129),
    [anon_sym_ControlAddIn] = ACTIONS(7129),
    [anon_sym_ControlAddin] = ACTIONS(7129),
    [anon_sym_controlAddIn] = ACTIONS(7129),
    [anon_sym_controlAddin] = ACTIONS(7129),
    [anon_sym_dotnet] = ACTIONS(7129),
    [anon_sym_DOTNET] = ACTIONS(7129),
    [anon_sym_Dotnet] = ACTIONS(7129),
    [anon_sym_DotNet] = ACTIONS(7129),
    [anon_sym_dotNet] = ACTIONS(7129),
    [sym_profile_keyword] = ACTIONS(7131),
    [anon_sym_profileextension] = ACTIONS(7129),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7129),
    [anon_sym_Profileextension] = ACTIONS(7129),
    [anon_sym_ProfileExtension] = ACTIONS(7129),
    [anon_sym_profileExtension] = ACTIONS(7129),
    [anon_sym_permissionset] = ACTIONS(7131),
    [anon_sym_PERMISSIONSET] = ACTIONS(7131),
    [anon_sym_Permissionset] = ACTIONS(7131),
    [anon_sym_PermissionSet] = ACTIONS(7131),
    [anon_sym_permissionSet] = ACTIONS(7131),
    [anon_sym_permissionsetextension] = ACTIONS(7129),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7129),
    [anon_sym_Permissionsetextension] = ACTIONS(7129),
    [anon_sym_PermissionSetExtension] = ACTIONS(7129),
    [anon_sym_permissionSetExtension] = ACTIONS(7129),
    [sym_entitlement_keyword] = ACTIONS(7129),
    [anon_sym_pagecustomization] = ACTIONS(7129),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7129),
    [anon_sym_Pagecustomization] = ACTIONS(7129),
    [anon_sym_PageCustomization] = ACTIONS(7129),
    [anon_sym_pageCustomization] = ACTIONS(7129),
    [sym_using_keyword] = ACTIONS(7129),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7129),
  },
  [STATE(3639)] = {
    [ts_builtin_sym_end] = ACTIONS(7015),
    [anon_sym_POUNDif] = ACTIONS(7015),
    [anon_sym_POUNDIF] = ACTIONS(7015),
    [anon_sym_POUNDIf] = ACTIONS(7015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7017),
    [anon_sym_tableextension] = ACTIONS(7015),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7015),
    [anon_sym_Tableextension] = ACTIONS(7015),
    [anon_sym_TableExtension] = ACTIONS(7015),
    [anon_sym_tableExtension] = ACTIONS(7015),
    [sym_page_keyword] = ACTIONS(7017),
    [anon_sym_pageextension] = ACTIONS(7015),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7015),
    [anon_sym_Pageextension] = ACTIONS(7015),
    [anon_sym_PageExtension] = ACTIONS(7015),
    [anon_sym_pageExtension] = ACTIONS(7015),
    [anon_sym_codeunit] = ACTIONS(7015),
    [anon_sym_CODEUNIT] = ACTIONS(7015),
    [anon_sym_Codeunit] = ACTIONS(7015),
    [anon_sym_CodeUnit] = ACTIONS(7015),
    [anon_sym_COdeunit] = ACTIONS(7015),
    [anon_sym_codeUnit] = ACTIONS(7015),
    [sym_report_keyword] = ACTIONS(7017),
    [anon_sym_reportextension] = ACTIONS(7015),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7015),
    [anon_sym_Reportextension] = ACTIONS(7015),
    [anon_sym_ReportExtension] = ACTIONS(7015),
    [anon_sym_reportExtension] = ACTIONS(7015),
    [sym_query_keyword] = ACTIONS(7015),
    [anon_sym_xmlport] = ACTIONS(7015),
    [anon_sym_XMLPORT] = ACTIONS(7015),
    [anon_sym_Xmlport] = ACTIONS(7015),
    [anon_sym_XMLport] = ACTIONS(7015),
    [anon_sym_XMLPort] = ACTIONS(7015),
    [anon_sym_XmlPort] = ACTIONS(7015),
    [anon_sym_enum] = ACTIONS(7017),
    [anon_sym_ENUM] = ACTIONS(7017),
    [anon_sym_Enum] = ACTIONS(7017),
    [anon_sym_eNUM] = ACTIONS(7015),
    [anon_sym_eNum] = ACTIONS(7015),
    [anon_sym_ENum] = ACTIONS(7015),
    [anon_sym_enumextension] = ACTIONS(7015),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7015),
    [anon_sym_Enumextension] = ACTIONS(7015),
    [anon_sym_EnumExtension] = ACTIONS(7015),
    [anon_sym_enumExtension] = ACTIONS(7015),
    [sym_interface_keyword] = ACTIONS(7015),
    [anon_sym_controladdin] = ACTIONS(7015),
    [anon_sym_CONTROLADDIN] = ACTIONS(7015),
    [anon_sym_Controladdin] = ACTIONS(7015),
    [anon_sym_ControlAddIn] = ACTIONS(7015),
    [anon_sym_ControlAddin] = ACTIONS(7015),
    [anon_sym_controlAddIn] = ACTIONS(7015),
    [anon_sym_controlAddin] = ACTIONS(7015),
    [anon_sym_dotnet] = ACTIONS(7015),
    [anon_sym_DOTNET] = ACTIONS(7015),
    [anon_sym_Dotnet] = ACTIONS(7015),
    [anon_sym_DotNet] = ACTIONS(7015),
    [anon_sym_dotNet] = ACTIONS(7015),
    [sym_profile_keyword] = ACTIONS(7017),
    [anon_sym_profileextension] = ACTIONS(7015),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7015),
    [anon_sym_Profileextension] = ACTIONS(7015),
    [anon_sym_ProfileExtension] = ACTIONS(7015),
    [anon_sym_profileExtension] = ACTIONS(7015),
    [anon_sym_permissionset] = ACTIONS(7017),
    [anon_sym_PERMISSIONSET] = ACTIONS(7017),
    [anon_sym_Permissionset] = ACTIONS(7017),
    [anon_sym_PermissionSet] = ACTIONS(7017),
    [anon_sym_permissionSet] = ACTIONS(7017),
    [anon_sym_permissionsetextension] = ACTIONS(7015),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7015),
    [anon_sym_Permissionsetextension] = ACTIONS(7015),
    [anon_sym_PermissionSetExtension] = ACTIONS(7015),
    [anon_sym_permissionSetExtension] = ACTIONS(7015),
    [sym_entitlement_keyword] = ACTIONS(7015),
    [anon_sym_pagecustomization] = ACTIONS(7015),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7015),
    [anon_sym_Pagecustomization] = ACTIONS(7015),
    [anon_sym_PageCustomization] = ACTIONS(7015),
    [anon_sym_pageCustomization] = ACTIONS(7015),
    [sym_using_keyword] = ACTIONS(7015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7015),
  },
  [STATE(3640)] = {
    [anon_sym_SEMI] = ACTIONS(8333),
    [anon_sym_COMMA] = ACTIONS(8333),
    [aux_sym_where_condition_token1] = ACTIONS(8335),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8333),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8335),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8333),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8333),
    [anon_sym_LBRACK] = ACTIONS(8333),
    [aux_sym_basic_type_token6] = ACTIONS(8335),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8333),
    [aux_sym_addafter_modification_token1] = ACTIONS(8333),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8333),
    [aux_sym_modify_modification_token1] = ACTIONS(8333),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8333),
    [aux_sym_movelast_modification_token1] = ACTIONS(8333),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8333),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8333),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8333),
    [anon_sym_POUNDif] = ACTIONS(8333),
    [anon_sym_POUNDIF] = ACTIONS(8333),
    [anon_sym_POUNDIf] = ACTIONS(8333),
    [anon_sym_POUNDelif] = ACTIONS(8333),
    [anon_sym_POUNDELIF] = ACTIONS(8333),
    [anon_sym_POUNDElif] = ACTIONS(8333),
    [anon_sym_POUNDelse] = ACTIONS(8333),
    [anon_sym_POUNDELSE] = ACTIONS(8333),
    [anon_sym_POUNDElse] = ACTIONS(8333),
    [anon_sym_POUNDelse2] = ACTIONS(8333),
    [anon_sym_POUNDELSE2] = ACTIONS(8333),
    [anon_sym_POUNDElse2] = ACTIONS(8333),
    [anon_sym_POUNDendif] = ACTIONS(8333),
    [anon_sym_POUNDENDIF] = ACTIONS(8333),
    [anon_sym_POUNDEndif] = ACTIONS(8333),
    [anon_sym_POUNDendif2] = ACTIONS(8333),
    [anon_sym_POUNDENDIF2] = ACTIONS(8333),
    [anon_sym_POUNDEndif2] = ACTIONS(8333),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8335),
    [sym_page_keyword] = ACTIONS(8333),
    [anon_sym_codeunit] = ACTIONS(8333),
    [anon_sym_CODEUNIT] = ACTIONS(8333),
    [anon_sym_Codeunit] = ACTIONS(8333),
    [anon_sym_CodeUnit] = ACTIONS(8333),
    [anon_sym_COdeunit] = ACTIONS(8333),
    [anon_sym_codeUnit] = ACTIONS(8333),
    [sym_report_keyword] = ACTIONS(8333),
    [sym_query_keyword] = ACTIONS(8333),
    [anon_sym_xmlport] = ACTIONS(8333),
    [anon_sym_XMLPORT] = ACTIONS(8333),
    [anon_sym_Xmlport] = ACTIONS(8333),
    [anon_sym_XMLport] = ACTIONS(8333),
    [anon_sym_XMLPort] = ACTIONS(8333),
    [anon_sym_XmlPort] = ACTIONS(8333),
    [sym_procedure_keyword] = ACTIONS(8333),
    [sym_trigger_keyword] = ACTIONS(8333),
    [sym_var_keyword] = ACTIONS(8333),
    [sym_local_keyword] = ACTIONS(8333),
    [sym_internal_keyword] = ACTIONS(8333),
    [sym_protected_keyword] = ACTIONS(8333),
    [sym_event_keyword] = ACTIONS(8333),
    [sym_fields_keyword] = ACTIONS(8333),
    [sym_keys_keyword] = ACTIONS(8333),
    [sym_fieldgroups_keyword] = ACTIONS(8333),
    [sym_actions_keyword] = ACTIONS(8333),
    [sym_layout_keyword] = ACTIONS(8333),
    [sym_area_keyword] = ACTIONS(8333),
    [sym_group_keyword] = ACTIONS(8333),
    [sym_repeater_keyword] = ACTIONS(8333),
    [sym_cuegroup_keyword] = ACTIONS(8333),
    [sym_fixed_keyword] = ACTIONS(8333),
    [sym_grid_keyword] = ACTIONS(8333),
    [sym_part_keyword] = ACTIONS(8333),
    [sym_systempart_keyword] = ACTIONS(8333),
    [sym_usercontrol_keyword] = ACTIONS(8333),
    [sym_dataset_keyword] = ACTIONS(8333),
    [sym_elements_keyword] = ACTIONS(8333),
    [sym_labels_keyword] = ACTIONS(8333),
    [sym_rendering_keyword] = ACTIONS(8333),
    [sym_requestpage_keyword] = ACTIONS(8333),
    [sym_schema_keyword] = ACTIONS(8333),
    [sym_views_keyword] = ACTIONS(8333),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8333),
    [sym_preproc_open] = ACTIONS(8333),
    [sym_preproc_close] = ACTIONS(8333),
  },
  [STATE(3641)] = {
    [ts_builtin_sym_end] = ACTIONS(7101),
    [anon_sym_POUNDif] = ACTIONS(7101),
    [anon_sym_POUNDIF] = ACTIONS(7101),
    [anon_sym_POUNDIf] = ACTIONS(7101),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7103),
    [anon_sym_tableextension] = ACTIONS(7101),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7101),
    [anon_sym_Tableextension] = ACTIONS(7101),
    [anon_sym_TableExtension] = ACTIONS(7101),
    [anon_sym_tableExtension] = ACTIONS(7101),
    [sym_page_keyword] = ACTIONS(7103),
    [anon_sym_pageextension] = ACTIONS(7101),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7101),
    [anon_sym_Pageextension] = ACTIONS(7101),
    [anon_sym_PageExtension] = ACTIONS(7101),
    [anon_sym_pageExtension] = ACTIONS(7101),
    [anon_sym_codeunit] = ACTIONS(7101),
    [anon_sym_CODEUNIT] = ACTIONS(7101),
    [anon_sym_Codeunit] = ACTIONS(7101),
    [anon_sym_CodeUnit] = ACTIONS(7101),
    [anon_sym_COdeunit] = ACTIONS(7101),
    [anon_sym_codeUnit] = ACTIONS(7101),
    [sym_report_keyword] = ACTIONS(7103),
    [anon_sym_reportextension] = ACTIONS(7101),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7101),
    [anon_sym_Reportextension] = ACTIONS(7101),
    [anon_sym_ReportExtension] = ACTIONS(7101),
    [anon_sym_reportExtension] = ACTIONS(7101),
    [sym_query_keyword] = ACTIONS(7101),
    [anon_sym_xmlport] = ACTIONS(7101),
    [anon_sym_XMLPORT] = ACTIONS(7101),
    [anon_sym_Xmlport] = ACTIONS(7101),
    [anon_sym_XMLport] = ACTIONS(7101),
    [anon_sym_XMLPort] = ACTIONS(7101),
    [anon_sym_XmlPort] = ACTIONS(7101),
    [anon_sym_enum] = ACTIONS(7103),
    [anon_sym_ENUM] = ACTIONS(7103),
    [anon_sym_Enum] = ACTIONS(7103),
    [anon_sym_eNUM] = ACTIONS(7101),
    [anon_sym_eNum] = ACTIONS(7101),
    [anon_sym_ENum] = ACTIONS(7101),
    [anon_sym_enumextension] = ACTIONS(7101),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7101),
    [anon_sym_Enumextension] = ACTIONS(7101),
    [anon_sym_EnumExtension] = ACTIONS(7101),
    [anon_sym_enumExtension] = ACTIONS(7101),
    [sym_interface_keyword] = ACTIONS(7101),
    [anon_sym_controladdin] = ACTIONS(7101),
    [anon_sym_CONTROLADDIN] = ACTIONS(7101),
    [anon_sym_Controladdin] = ACTIONS(7101),
    [anon_sym_ControlAddIn] = ACTIONS(7101),
    [anon_sym_ControlAddin] = ACTIONS(7101),
    [anon_sym_controlAddIn] = ACTIONS(7101),
    [anon_sym_controlAddin] = ACTIONS(7101),
    [anon_sym_dotnet] = ACTIONS(7101),
    [anon_sym_DOTNET] = ACTIONS(7101),
    [anon_sym_Dotnet] = ACTIONS(7101),
    [anon_sym_DotNet] = ACTIONS(7101),
    [anon_sym_dotNet] = ACTIONS(7101),
    [sym_profile_keyword] = ACTIONS(7103),
    [anon_sym_profileextension] = ACTIONS(7101),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7101),
    [anon_sym_Profileextension] = ACTIONS(7101),
    [anon_sym_ProfileExtension] = ACTIONS(7101),
    [anon_sym_profileExtension] = ACTIONS(7101),
    [anon_sym_permissionset] = ACTIONS(7103),
    [anon_sym_PERMISSIONSET] = ACTIONS(7103),
    [anon_sym_Permissionset] = ACTIONS(7103),
    [anon_sym_PermissionSet] = ACTIONS(7103),
    [anon_sym_permissionSet] = ACTIONS(7103),
    [anon_sym_permissionsetextension] = ACTIONS(7101),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7101),
    [anon_sym_Permissionsetextension] = ACTIONS(7101),
    [anon_sym_PermissionSetExtension] = ACTIONS(7101),
    [anon_sym_permissionSetExtension] = ACTIONS(7101),
    [sym_entitlement_keyword] = ACTIONS(7101),
    [anon_sym_pagecustomization] = ACTIONS(7101),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7101),
    [anon_sym_Pagecustomization] = ACTIONS(7101),
    [anon_sym_PageCustomization] = ACTIONS(7101),
    [anon_sym_pageCustomization] = ACTIONS(7101),
    [sym_using_keyword] = ACTIONS(7101),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7101),
  },
  [STATE(3642)] = {
    [sym_boolean] = STATE(8824),
    [sym_simple_table_relation] = STATE(8003),
    [sym__namespaced_or_simple_ref] = STATE(4477),
    [sym_assignment_expression] = STATE(8824),
    [sym__expression] = STATE(8824),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8824),
    [sym_multiplicative_expression] = STATE(8824),
    [sym_additive_expression] = STATE(8824),
    [sym_comparison_expression] = STATE(8824),
    [sym_logical_expression] = STATE(8824),
    [sym_ternary_expression] = STATE(8824),
    [sym_unary_expression] = STATE(8824),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(2302),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8824),
    [sym_list_literal] = STATE(8824),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8824),
    [sym__literal_value] = STATE(8824),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(4330),
    [sym_keyword_as_identifier] = STATE(4330),
    [sym_identifier] = ACTIONS(7572),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7574),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7576),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7578),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7576),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7576),
    [aux_sym_separator_action_token1] = ACTIONS(7576),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7576),
    [aux_sym_type_declaration_token1] = ACTIONS(7576),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7580),
    [sym_date_literal] = ACTIONS(7574),
    [sym_time_literal] = ACTIONS(7574),
    [sym_biginteger_literal] = ACTIONS(7580),
    [sym_table_keyword] = ACTIONS(7576),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7576),
    [sym_dataset_keyword] = ACTIONS(7576),
    [sym_quoted_identifier] = ACTIONS(7582),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7580),
    [sym_verbatim_string] = ACTIONS(7580),
    [sym_integer] = ACTIONS(7584),
    [sym_continue_as_identifier] = ACTIONS(7580),
  },
  [STATE(3643)] = {
    [ts_builtin_sym_end] = ACTIONS(7055),
    [anon_sym_POUNDif] = ACTIONS(7055),
    [anon_sym_POUNDIF] = ACTIONS(7055),
    [anon_sym_POUNDIf] = ACTIONS(7055),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7057),
    [anon_sym_tableextension] = ACTIONS(7055),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7055),
    [anon_sym_Tableextension] = ACTIONS(7055),
    [anon_sym_TableExtension] = ACTIONS(7055),
    [anon_sym_tableExtension] = ACTIONS(7055),
    [sym_page_keyword] = ACTIONS(7057),
    [anon_sym_pageextension] = ACTIONS(7055),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7055),
    [anon_sym_Pageextension] = ACTIONS(7055),
    [anon_sym_PageExtension] = ACTIONS(7055),
    [anon_sym_pageExtension] = ACTIONS(7055),
    [anon_sym_codeunit] = ACTIONS(7055),
    [anon_sym_CODEUNIT] = ACTIONS(7055),
    [anon_sym_Codeunit] = ACTIONS(7055),
    [anon_sym_CodeUnit] = ACTIONS(7055),
    [anon_sym_COdeunit] = ACTIONS(7055),
    [anon_sym_codeUnit] = ACTIONS(7055),
    [sym_report_keyword] = ACTIONS(7057),
    [anon_sym_reportextension] = ACTIONS(7055),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7055),
    [anon_sym_Reportextension] = ACTIONS(7055),
    [anon_sym_ReportExtension] = ACTIONS(7055),
    [anon_sym_reportExtension] = ACTIONS(7055),
    [sym_query_keyword] = ACTIONS(7055),
    [anon_sym_xmlport] = ACTIONS(7055),
    [anon_sym_XMLPORT] = ACTIONS(7055),
    [anon_sym_Xmlport] = ACTIONS(7055),
    [anon_sym_XMLport] = ACTIONS(7055),
    [anon_sym_XMLPort] = ACTIONS(7055),
    [anon_sym_XmlPort] = ACTIONS(7055),
    [anon_sym_enum] = ACTIONS(7057),
    [anon_sym_ENUM] = ACTIONS(7057),
    [anon_sym_Enum] = ACTIONS(7057),
    [anon_sym_eNUM] = ACTIONS(7055),
    [anon_sym_eNum] = ACTIONS(7055),
    [anon_sym_ENum] = ACTIONS(7055),
    [anon_sym_enumextension] = ACTIONS(7055),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7055),
    [anon_sym_Enumextension] = ACTIONS(7055),
    [anon_sym_EnumExtension] = ACTIONS(7055),
    [anon_sym_enumExtension] = ACTIONS(7055),
    [sym_interface_keyword] = ACTIONS(7055),
    [anon_sym_controladdin] = ACTIONS(7055),
    [anon_sym_CONTROLADDIN] = ACTIONS(7055),
    [anon_sym_Controladdin] = ACTIONS(7055),
    [anon_sym_ControlAddIn] = ACTIONS(7055),
    [anon_sym_ControlAddin] = ACTIONS(7055),
    [anon_sym_controlAddIn] = ACTIONS(7055),
    [anon_sym_controlAddin] = ACTIONS(7055),
    [anon_sym_dotnet] = ACTIONS(7055),
    [anon_sym_DOTNET] = ACTIONS(7055),
    [anon_sym_Dotnet] = ACTIONS(7055),
    [anon_sym_DotNet] = ACTIONS(7055),
    [anon_sym_dotNet] = ACTIONS(7055),
    [sym_profile_keyword] = ACTIONS(7057),
    [anon_sym_profileextension] = ACTIONS(7055),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7055),
    [anon_sym_Profileextension] = ACTIONS(7055),
    [anon_sym_ProfileExtension] = ACTIONS(7055),
    [anon_sym_profileExtension] = ACTIONS(7055),
    [anon_sym_permissionset] = ACTIONS(7057),
    [anon_sym_PERMISSIONSET] = ACTIONS(7057),
    [anon_sym_Permissionset] = ACTIONS(7057),
    [anon_sym_PermissionSet] = ACTIONS(7057),
    [anon_sym_permissionSet] = ACTIONS(7057),
    [anon_sym_permissionsetextension] = ACTIONS(7055),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7055),
    [anon_sym_Permissionsetextension] = ACTIONS(7055),
    [anon_sym_PermissionSetExtension] = ACTIONS(7055),
    [anon_sym_permissionSetExtension] = ACTIONS(7055),
    [sym_entitlement_keyword] = ACTIONS(7055),
    [anon_sym_pagecustomization] = ACTIONS(7055),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7055),
    [anon_sym_Pagecustomization] = ACTIONS(7055),
    [anon_sym_PageCustomization] = ACTIONS(7055),
    [anon_sym_pageCustomization] = ACTIONS(7055),
    [sym_using_keyword] = ACTIONS(7055),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7055),
  },
  [STATE(3644)] = {
    [ts_builtin_sym_end] = ACTIONS(6989),
    [anon_sym_POUNDif] = ACTIONS(6989),
    [anon_sym_POUNDIF] = ACTIONS(6989),
    [anon_sym_POUNDIf] = ACTIONS(6989),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6991),
    [anon_sym_tableextension] = ACTIONS(6989),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6989),
    [anon_sym_Tableextension] = ACTIONS(6989),
    [anon_sym_TableExtension] = ACTIONS(6989),
    [anon_sym_tableExtension] = ACTIONS(6989),
    [sym_page_keyword] = ACTIONS(6991),
    [anon_sym_pageextension] = ACTIONS(6989),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6989),
    [anon_sym_Pageextension] = ACTIONS(6989),
    [anon_sym_PageExtension] = ACTIONS(6989),
    [anon_sym_pageExtension] = ACTIONS(6989),
    [anon_sym_codeunit] = ACTIONS(6989),
    [anon_sym_CODEUNIT] = ACTIONS(6989),
    [anon_sym_Codeunit] = ACTIONS(6989),
    [anon_sym_CodeUnit] = ACTIONS(6989),
    [anon_sym_COdeunit] = ACTIONS(6989),
    [anon_sym_codeUnit] = ACTIONS(6989),
    [sym_report_keyword] = ACTIONS(6991),
    [anon_sym_reportextension] = ACTIONS(6989),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6989),
    [anon_sym_Reportextension] = ACTIONS(6989),
    [anon_sym_ReportExtension] = ACTIONS(6989),
    [anon_sym_reportExtension] = ACTIONS(6989),
    [sym_query_keyword] = ACTIONS(6989),
    [anon_sym_xmlport] = ACTIONS(6989),
    [anon_sym_XMLPORT] = ACTIONS(6989),
    [anon_sym_Xmlport] = ACTIONS(6989),
    [anon_sym_XMLport] = ACTIONS(6989),
    [anon_sym_XMLPort] = ACTIONS(6989),
    [anon_sym_XmlPort] = ACTIONS(6989),
    [anon_sym_enum] = ACTIONS(6991),
    [anon_sym_ENUM] = ACTIONS(6991),
    [anon_sym_Enum] = ACTIONS(6991),
    [anon_sym_eNUM] = ACTIONS(6989),
    [anon_sym_eNum] = ACTIONS(6989),
    [anon_sym_ENum] = ACTIONS(6989),
    [anon_sym_enumextension] = ACTIONS(6989),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6989),
    [anon_sym_Enumextension] = ACTIONS(6989),
    [anon_sym_EnumExtension] = ACTIONS(6989),
    [anon_sym_enumExtension] = ACTIONS(6989),
    [sym_interface_keyword] = ACTIONS(6989),
    [anon_sym_controladdin] = ACTIONS(6989),
    [anon_sym_CONTROLADDIN] = ACTIONS(6989),
    [anon_sym_Controladdin] = ACTIONS(6989),
    [anon_sym_ControlAddIn] = ACTIONS(6989),
    [anon_sym_ControlAddin] = ACTIONS(6989),
    [anon_sym_controlAddIn] = ACTIONS(6989),
    [anon_sym_controlAddin] = ACTIONS(6989),
    [anon_sym_dotnet] = ACTIONS(6989),
    [anon_sym_DOTNET] = ACTIONS(6989),
    [anon_sym_Dotnet] = ACTIONS(6989),
    [anon_sym_DotNet] = ACTIONS(6989),
    [anon_sym_dotNet] = ACTIONS(6989),
    [sym_profile_keyword] = ACTIONS(6991),
    [anon_sym_profileextension] = ACTIONS(6989),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6989),
    [anon_sym_Profileextension] = ACTIONS(6989),
    [anon_sym_ProfileExtension] = ACTIONS(6989),
    [anon_sym_profileExtension] = ACTIONS(6989),
    [anon_sym_permissionset] = ACTIONS(6991),
    [anon_sym_PERMISSIONSET] = ACTIONS(6991),
    [anon_sym_Permissionset] = ACTIONS(6991),
    [anon_sym_PermissionSet] = ACTIONS(6991),
    [anon_sym_permissionSet] = ACTIONS(6991),
    [anon_sym_permissionsetextension] = ACTIONS(6989),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6989),
    [anon_sym_Permissionsetextension] = ACTIONS(6989),
    [anon_sym_PermissionSetExtension] = ACTIONS(6989),
    [anon_sym_permissionSetExtension] = ACTIONS(6989),
    [sym_entitlement_keyword] = ACTIONS(6989),
    [anon_sym_pagecustomization] = ACTIONS(6989),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6989),
    [anon_sym_Pagecustomization] = ACTIONS(6989),
    [anon_sym_PageCustomization] = ACTIONS(6989),
    [anon_sym_pageCustomization] = ACTIONS(6989),
    [sym_using_keyword] = ACTIONS(6989),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6989),
  },
  [STATE(3645)] = {
    [ts_builtin_sym_end] = ACTIONS(7105),
    [anon_sym_POUNDif] = ACTIONS(7105),
    [anon_sym_POUNDIF] = ACTIONS(7105),
    [anon_sym_POUNDIf] = ACTIONS(7105),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7107),
    [anon_sym_tableextension] = ACTIONS(7105),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7105),
    [anon_sym_Tableextension] = ACTIONS(7105),
    [anon_sym_TableExtension] = ACTIONS(7105),
    [anon_sym_tableExtension] = ACTIONS(7105),
    [sym_page_keyword] = ACTIONS(7107),
    [anon_sym_pageextension] = ACTIONS(7105),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7105),
    [anon_sym_Pageextension] = ACTIONS(7105),
    [anon_sym_PageExtension] = ACTIONS(7105),
    [anon_sym_pageExtension] = ACTIONS(7105),
    [anon_sym_codeunit] = ACTIONS(7105),
    [anon_sym_CODEUNIT] = ACTIONS(7105),
    [anon_sym_Codeunit] = ACTIONS(7105),
    [anon_sym_CodeUnit] = ACTIONS(7105),
    [anon_sym_COdeunit] = ACTIONS(7105),
    [anon_sym_codeUnit] = ACTIONS(7105),
    [sym_report_keyword] = ACTIONS(7107),
    [anon_sym_reportextension] = ACTIONS(7105),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7105),
    [anon_sym_Reportextension] = ACTIONS(7105),
    [anon_sym_ReportExtension] = ACTIONS(7105),
    [anon_sym_reportExtension] = ACTIONS(7105),
    [sym_query_keyword] = ACTIONS(7105),
    [anon_sym_xmlport] = ACTIONS(7105),
    [anon_sym_XMLPORT] = ACTIONS(7105),
    [anon_sym_Xmlport] = ACTIONS(7105),
    [anon_sym_XMLport] = ACTIONS(7105),
    [anon_sym_XMLPort] = ACTIONS(7105),
    [anon_sym_XmlPort] = ACTIONS(7105),
    [anon_sym_enum] = ACTIONS(7107),
    [anon_sym_ENUM] = ACTIONS(7107),
    [anon_sym_Enum] = ACTIONS(7107),
    [anon_sym_eNUM] = ACTIONS(7105),
    [anon_sym_eNum] = ACTIONS(7105),
    [anon_sym_ENum] = ACTIONS(7105),
    [anon_sym_enumextension] = ACTIONS(7105),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7105),
    [anon_sym_Enumextension] = ACTIONS(7105),
    [anon_sym_EnumExtension] = ACTIONS(7105),
    [anon_sym_enumExtension] = ACTIONS(7105),
    [sym_interface_keyword] = ACTIONS(7105),
    [anon_sym_controladdin] = ACTIONS(7105),
    [anon_sym_CONTROLADDIN] = ACTIONS(7105),
    [anon_sym_Controladdin] = ACTIONS(7105),
    [anon_sym_ControlAddIn] = ACTIONS(7105),
    [anon_sym_ControlAddin] = ACTIONS(7105),
    [anon_sym_controlAddIn] = ACTIONS(7105),
    [anon_sym_controlAddin] = ACTIONS(7105),
    [anon_sym_dotnet] = ACTIONS(7105),
    [anon_sym_DOTNET] = ACTIONS(7105),
    [anon_sym_Dotnet] = ACTIONS(7105),
    [anon_sym_DotNet] = ACTIONS(7105),
    [anon_sym_dotNet] = ACTIONS(7105),
    [sym_profile_keyword] = ACTIONS(7107),
    [anon_sym_profileextension] = ACTIONS(7105),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7105),
    [anon_sym_Profileextension] = ACTIONS(7105),
    [anon_sym_ProfileExtension] = ACTIONS(7105),
    [anon_sym_profileExtension] = ACTIONS(7105),
    [anon_sym_permissionset] = ACTIONS(7107),
    [anon_sym_PERMISSIONSET] = ACTIONS(7107),
    [anon_sym_Permissionset] = ACTIONS(7107),
    [anon_sym_PermissionSet] = ACTIONS(7107),
    [anon_sym_permissionSet] = ACTIONS(7107),
    [anon_sym_permissionsetextension] = ACTIONS(7105),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7105),
    [anon_sym_Permissionsetextension] = ACTIONS(7105),
    [anon_sym_PermissionSetExtension] = ACTIONS(7105),
    [anon_sym_permissionSetExtension] = ACTIONS(7105),
    [sym_entitlement_keyword] = ACTIONS(7105),
    [anon_sym_pagecustomization] = ACTIONS(7105),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7105),
    [anon_sym_Pagecustomization] = ACTIONS(7105),
    [anon_sym_PageCustomization] = ACTIONS(7105),
    [anon_sym_pageCustomization] = ACTIONS(7105),
    [sym_using_keyword] = ACTIONS(7105),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7105),
  },
  [STATE(3646)] = {
    [ts_builtin_sym_end] = ACTIONS(6981),
    [anon_sym_POUNDif] = ACTIONS(6981),
    [anon_sym_POUNDIF] = ACTIONS(6981),
    [anon_sym_POUNDIf] = ACTIONS(6981),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6983),
    [anon_sym_tableextension] = ACTIONS(6981),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6981),
    [anon_sym_Tableextension] = ACTIONS(6981),
    [anon_sym_TableExtension] = ACTIONS(6981),
    [anon_sym_tableExtension] = ACTIONS(6981),
    [sym_page_keyword] = ACTIONS(6983),
    [anon_sym_pageextension] = ACTIONS(6981),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6981),
    [anon_sym_Pageextension] = ACTIONS(6981),
    [anon_sym_PageExtension] = ACTIONS(6981),
    [anon_sym_pageExtension] = ACTIONS(6981),
    [anon_sym_codeunit] = ACTIONS(6981),
    [anon_sym_CODEUNIT] = ACTIONS(6981),
    [anon_sym_Codeunit] = ACTIONS(6981),
    [anon_sym_CodeUnit] = ACTIONS(6981),
    [anon_sym_COdeunit] = ACTIONS(6981),
    [anon_sym_codeUnit] = ACTIONS(6981),
    [sym_report_keyword] = ACTIONS(6983),
    [anon_sym_reportextension] = ACTIONS(6981),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6981),
    [anon_sym_Reportextension] = ACTIONS(6981),
    [anon_sym_ReportExtension] = ACTIONS(6981),
    [anon_sym_reportExtension] = ACTIONS(6981),
    [sym_query_keyword] = ACTIONS(6981),
    [anon_sym_xmlport] = ACTIONS(6981),
    [anon_sym_XMLPORT] = ACTIONS(6981),
    [anon_sym_Xmlport] = ACTIONS(6981),
    [anon_sym_XMLport] = ACTIONS(6981),
    [anon_sym_XMLPort] = ACTIONS(6981),
    [anon_sym_XmlPort] = ACTIONS(6981),
    [anon_sym_enum] = ACTIONS(6983),
    [anon_sym_ENUM] = ACTIONS(6983),
    [anon_sym_Enum] = ACTIONS(6983),
    [anon_sym_eNUM] = ACTIONS(6981),
    [anon_sym_eNum] = ACTIONS(6981),
    [anon_sym_ENum] = ACTIONS(6981),
    [anon_sym_enumextension] = ACTIONS(6981),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6981),
    [anon_sym_Enumextension] = ACTIONS(6981),
    [anon_sym_EnumExtension] = ACTIONS(6981),
    [anon_sym_enumExtension] = ACTIONS(6981),
    [sym_interface_keyword] = ACTIONS(6981),
    [anon_sym_controladdin] = ACTIONS(6981),
    [anon_sym_CONTROLADDIN] = ACTIONS(6981),
    [anon_sym_Controladdin] = ACTIONS(6981),
    [anon_sym_ControlAddIn] = ACTIONS(6981),
    [anon_sym_ControlAddin] = ACTIONS(6981),
    [anon_sym_controlAddIn] = ACTIONS(6981),
    [anon_sym_controlAddin] = ACTIONS(6981),
    [anon_sym_dotnet] = ACTIONS(6981),
    [anon_sym_DOTNET] = ACTIONS(6981),
    [anon_sym_Dotnet] = ACTIONS(6981),
    [anon_sym_DotNet] = ACTIONS(6981),
    [anon_sym_dotNet] = ACTIONS(6981),
    [sym_profile_keyword] = ACTIONS(6983),
    [anon_sym_profileextension] = ACTIONS(6981),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6981),
    [anon_sym_Profileextension] = ACTIONS(6981),
    [anon_sym_ProfileExtension] = ACTIONS(6981),
    [anon_sym_profileExtension] = ACTIONS(6981),
    [anon_sym_permissionset] = ACTIONS(6983),
    [anon_sym_PERMISSIONSET] = ACTIONS(6983),
    [anon_sym_Permissionset] = ACTIONS(6983),
    [anon_sym_PermissionSet] = ACTIONS(6983),
    [anon_sym_permissionSet] = ACTIONS(6983),
    [anon_sym_permissionsetextension] = ACTIONS(6981),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6981),
    [anon_sym_Permissionsetextension] = ACTIONS(6981),
    [anon_sym_PermissionSetExtension] = ACTIONS(6981),
    [anon_sym_permissionSetExtension] = ACTIONS(6981),
    [sym_entitlement_keyword] = ACTIONS(6981),
    [anon_sym_pagecustomization] = ACTIONS(6981),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6981),
    [anon_sym_Pagecustomization] = ACTIONS(6981),
    [anon_sym_PageCustomization] = ACTIONS(6981),
    [anon_sym_pageCustomization] = ACTIONS(6981),
    [sym_using_keyword] = ACTIONS(6981),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6981),
  },
  [STATE(3647)] = {
    [ts_builtin_sym_end] = ACTIONS(7109),
    [anon_sym_POUNDif] = ACTIONS(7109),
    [anon_sym_POUNDIF] = ACTIONS(7109),
    [anon_sym_POUNDIf] = ACTIONS(7109),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7111),
    [anon_sym_tableextension] = ACTIONS(7109),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7109),
    [anon_sym_Tableextension] = ACTIONS(7109),
    [anon_sym_TableExtension] = ACTIONS(7109),
    [anon_sym_tableExtension] = ACTIONS(7109),
    [sym_page_keyword] = ACTIONS(7111),
    [anon_sym_pageextension] = ACTIONS(7109),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7109),
    [anon_sym_Pageextension] = ACTIONS(7109),
    [anon_sym_PageExtension] = ACTIONS(7109),
    [anon_sym_pageExtension] = ACTIONS(7109),
    [anon_sym_codeunit] = ACTIONS(7109),
    [anon_sym_CODEUNIT] = ACTIONS(7109),
    [anon_sym_Codeunit] = ACTIONS(7109),
    [anon_sym_CodeUnit] = ACTIONS(7109),
    [anon_sym_COdeunit] = ACTIONS(7109),
    [anon_sym_codeUnit] = ACTIONS(7109),
    [sym_report_keyword] = ACTIONS(7111),
    [anon_sym_reportextension] = ACTIONS(7109),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7109),
    [anon_sym_Reportextension] = ACTIONS(7109),
    [anon_sym_ReportExtension] = ACTIONS(7109),
    [anon_sym_reportExtension] = ACTIONS(7109),
    [sym_query_keyword] = ACTIONS(7109),
    [anon_sym_xmlport] = ACTIONS(7109),
    [anon_sym_XMLPORT] = ACTIONS(7109),
    [anon_sym_Xmlport] = ACTIONS(7109),
    [anon_sym_XMLport] = ACTIONS(7109),
    [anon_sym_XMLPort] = ACTIONS(7109),
    [anon_sym_XmlPort] = ACTIONS(7109),
    [anon_sym_enum] = ACTIONS(7111),
    [anon_sym_ENUM] = ACTIONS(7111),
    [anon_sym_Enum] = ACTIONS(7111),
    [anon_sym_eNUM] = ACTIONS(7109),
    [anon_sym_eNum] = ACTIONS(7109),
    [anon_sym_ENum] = ACTIONS(7109),
    [anon_sym_enumextension] = ACTIONS(7109),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7109),
    [anon_sym_Enumextension] = ACTIONS(7109),
    [anon_sym_EnumExtension] = ACTIONS(7109),
    [anon_sym_enumExtension] = ACTIONS(7109),
    [sym_interface_keyword] = ACTIONS(7109),
    [anon_sym_controladdin] = ACTIONS(7109),
    [anon_sym_CONTROLADDIN] = ACTIONS(7109),
    [anon_sym_Controladdin] = ACTIONS(7109),
    [anon_sym_ControlAddIn] = ACTIONS(7109),
    [anon_sym_ControlAddin] = ACTIONS(7109),
    [anon_sym_controlAddIn] = ACTIONS(7109),
    [anon_sym_controlAddin] = ACTIONS(7109),
    [anon_sym_dotnet] = ACTIONS(7109),
    [anon_sym_DOTNET] = ACTIONS(7109),
    [anon_sym_Dotnet] = ACTIONS(7109),
    [anon_sym_DotNet] = ACTIONS(7109),
    [anon_sym_dotNet] = ACTIONS(7109),
    [sym_profile_keyword] = ACTIONS(7111),
    [anon_sym_profileextension] = ACTIONS(7109),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7109),
    [anon_sym_Profileextension] = ACTIONS(7109),
    [anon_sym_ProfileExtension] = ACTIONS(7109),
    [anon_sym_profileExtension] = ACTIONS(7109),
    [anon_sym_permissionset] = ACTIONS(7111),
    [anon_sym_PERMISSIONSET] = ACTIONS(7111),
    [anon_sym_Permissionset] = ACTIONS(7111),
    [anon_sym_PermissionSet] = ACTIONS(7111),
    [anon_sym_permissionSet] = ACTIONS(7111),
    [anon_sym_permissionsetextension] = ACTIONS(7109),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7109),
    [anon_sym_Permissionsetextension] = ACTIONS(7109),
    [anon_sym_PermissionSetExtension] = ACTIONS(7109),
    [anon_sym_permissionSetExtension] = ACTIONS(7109),
    [sym_entitlement_keyword] = ACTIONS(7109),
    [anon_sym_pagecustomization] = ACTIONS(7109),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7109),
    [anon_sym_Pagecustomization] = ACTIONS(7109),
    [anon_sym_PageCustomization] = ACTIONS(7109),
    [anon_sym_pageCustomization] = ACTIONS(7109),
    [sym_using_keyword] = ACTIONS(7109),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7109),
  },
  [STATE(3648)] = {
    [ts_builtin_sym_end] = ACTIONS(6872),
    [anon_sym_POUNDif] = ACTIONS(6872),
    [anon_sym_POUNDIF] = ACTIONS(6872),
    [anon_sym_POUNDIf] = ACTIONS(6872),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6874),
    [anon_sym_tableextension] = ACTIONS(6872),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6872),
    [anon_sym_Tableextension] = ACTIONS(6872),
    [anon_sym_TableExtension] = ACTIONS(6872),
    [anon_sym_tableExtension] = ACTIONS(6872),
    [sym_page_keyword] = ACTIONS(6874),
    [anon_sym_pageextension] = ACTIONS(6872),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6872),
    [anon_sym_Pageextension] = ACTIONS(6872),
    [anon_sym_PageExtension] = ACTIONS(6872),
    [anon_sym_pageExtension] = ACTIONS(6872),
    [anon_sym_codeunit] = ACTIONS(6872),
    [anon_sym_CODEUNIT] = ACTIONS(6872),
    [anon_sym_Codeunit] = ACTIONS(6872),
    [anon_sym_CodeUnit] = ACTIONS(6872),
    [anon_sym_COdeunit] = ACTIONS(6872),
    [anon_sym_codeUnit] = ACTIONS(6872),
    [sym_report_keyword] = ACTIONS(6874),
    [anon_sym_reportextension] = ACTIONS(6872),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6872),
    [anon_sym_Reportextension] = ACTIONS(6872),
    [anon_sym_ReportExtension] = ACTIONS(6872),
    [anon_sym_reportExtension] = ACTIONS(6872),
    [sym_query_keyword] = ACTIONS(6872),
    [anon_sym_xmlport] = ACTIONS(6872),
    [anon_sym_XMLPORT] = ACTIONS(6872),
    [anon_sym_Xmlport] = ACTIONS(6872),
    [anon_sym_XMLport] = ACTIONS(6872),
    [anon_sym_XMLPort] = ACTIONS(6872),
    [anon_sym_XmlPort] = ACTIONS(6872),
    [anon_sym_enum] = ACTIONS(6874),
    [anon_sym_ENUM] = ACTIONS(6874),
    [anon_sym_Enum] = ACTIONS(6874),
    [anon_sym_eNUM] = ACTIONS(6872),
    [anon_sym_eNum] = ACTIONS(6872),
    [anon_sym_ENum] = ACTIONS(6872),
    [anon_sym_enumextension] = ACTIONS(6872),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6872),
    [anon_sym_Enumextension] = ACTIONS(6872),
    [anon_sym_EnumExtension] = ACTIONS(6872),
    [anon_sym_enumExtension] = ACTIONS(6872),
    [sym_interface_keyword] = ACTIONS(6872),
    [anon_sym_controladdin] = ACTIONS(6872),
    [anon_sym_CONTROLADDIN] = ACTIONS(6872),
    [anon_sym_Controladdin] = ACTIONS(6872),
    [anon_sym_ControlAddIn] = ACTIONS(6872),
    [anon_sym_ControlAddin] = ACTIONS(6872),
    [anon_sym_controlAddIn] = ACTIONS(6872),
    [anon_sym_controlAddin] = ACTIONS(6872),
    [anon_sym_dotnet] = ACTIONS(6872),
    [anon_sym_DOTNET] = ACTIONS(6872),
    [anon_sym_Dotnet] = ACTIONS(6872),
    [anon_sym_DotNet] = ACTIONS(6872),
    [anon_sym_dotNet] = ACTIONS(6872),
    [sym_profile_keyword] = ACTIONS(6874),
    [anon_sym_profileextension] = ACTIONS(6872),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6872),
    [anon_sym_Profileextension] = ACTIONS(6872),
    [anon_sym_ProfileExtension] = ACTIONS(6872),
    [anon_sym_profileExtension] = ACTIONS(6872),
    [anon_sym_permissionset] = ACTIONS(6874),
    [anon_sym_PERMISSIONSET] = ACTIONS(6874),
    [anon_sym_Permissionset] = ACTIONS(6874),
    [anon_sym_PermissionSet] = ACTIONS(6874),
    [anon_sym_permissionSet] = ACTIONS(6874),
    [anon_sym_permissionsetextension] = ACTIONS(6872),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6872),
    [anon_sym_Permissionsetextension] = ACTIONS(6872),
    [anon_sym_PermissionSetExtension] = ACTIONS(6872),
    [anon_sym_permissionSetExtension] = ACTIONS(6872),
    [sym_entitlement_keyword] = ACTIONS(6872),
    [anon_sym_pagecustomization] = ACTIONS(6872),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6872),
    [anon_sym_Pagecustomization] = ACTIONS(6872),
    [anon_sym_PageCustomization] = ACTIONS(6872),
    [anon_sym_pageCustomization] = ACTIONS(6872),
    [sym_using_keyword] = ACTIONS(6872),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6872),
  },
  [STATE(3649)] = {
    [sym_boolean] = STATE(9829),
    [sym_option_member_list] = STATE(9940),
    [sym_option_member] = STATE(9746),
    [sym_keyword_identifier] = STATE(9829),
    [sym_codeunit_keyword] = STATE(9824),
    [sym_xmlport_keyword] = STATE(9824),
    [sym_enum_keyword] = STATE(9824),
    [sym_keyword_as_identifier] = STATE(9829),
    [aux_sym_option_member_list_repeat2] = STATE(3806),
    [sym_identifier] = ACTIONS(8337),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_RBRACE] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(8339),
    [anon_sym_DASH] = ACTIONS(8341),
    [aux_sym_boolean_token1] = ACTIONS(8343),
    [aux_sym_boolean_token2] = ACTIONS(8343),
    [aux_sym_where_condition_token1] = ACTIONS(8345),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8347),
    [anon_sym_LBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(8347),
    [aux_sym_basic_type_token21] = ACTIONS(8347),
    [aux_sym_basic_type_token22] = ACTIONS(8349),
    [aux_sym_basic_type_token48] = ACTIONS(8347),
    [aux_sym_basic_type_token53] = ACTIONS(8345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8345),
    [aux_sym_modify_modification_token1] = ACTIONS(584),
    [aux_sym_separator_action_token1] = ACTIONS(8345),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8345),
    [aux_sym_type_declaration_token1] = ACTIONS(8345),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(584),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8347),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8347),
    [sym_table_keyword] = ACTIONS(8345),
    [sym_page_keyword] = ACTIONS(8347),
    [anon_sym_codeunit] = ACTIONS(8351),
    [anon_sym_CODEUNIT] = ACTIONS(8351),
    [anon_sym_Codeunit] = ACTIONS(8351),
    [anon_sym_CodeUnit] = ACTIONS(8351),
    [anon_sym_COdeunit] = ACTIONS(8351),
    [anon_sym_codeUnit] = ACTIONS(8351),
    [sym_report_keyword] = ACTIONS(8347),
    [sym_query_keyword] = ACTIONS(8347),
    [anon_sym_xmlport] = ACTIONS(8353),
    [anon_sym_XMLPORT] = ACTIONS(8353),
    [anon_sym_Xmlport] = ACTIONS(8353),
    [anon_sym_XMLport] = ACTIONS(8353),
    [anon_sym_XMLPort] = ACTIONS(8353),
    [anon_sym_XmlPort] = ACTIONS(8353),
    [anon_sym_enum] = ACTIONS(8355),
    [anon_sym_ENUM] = ACTIONS(8355),
    [anon_sym_Enum] = ACTIONS(8355),
    [anon_sym_eNUM] = ACTIONS(8355),
    [anon_sym_eNum] = ACTIONS(8355),
    [anon_sym_ENum] = ACTIONS(8355),
    [sym_procedure_keyword] = ACTIONS(584),
    [sym_trigger_keyword] = ACTIONS(584),
    [sym_var_keyword] = ACTIONS(584),
    [sym_local_keyword] = ACTIONS(8337),
    [sym_internal_keyword] = ACTIONS(8337),
    [sym_protected_keyword] = ACTIONS(8337),
    [sym_event_keyword] = ACTIONS(584),
    [sym_fields_keyword] = ACTIONS(584),
    [sym_keys_keyword] = ACTIONS(584),
    [sym_key_keyword] = ACTIONS(8345),
    [sym_fieldgroups_keyword] = ACTIONS(584),
    [sym_actions_keyword] = ACTIONS(584),
    [sym_layout_keyword] = ACTIONS(584),
    [sym_dataset_keyword] = ACTIONS(8345),
    [sym_elements_keyword] = ACTIONS(584),
    [sym_labels_keyword] = ACTIONS(584),
    [sym_rendering_keyword] = ACTIONS(584),
    [sym_requestpage_keyword] = ACTIONS(584),
    [sym_schema_keyword] = ACTIONS(584),
    [sym_views_keyword] = ACTIONS(584),
    [sym_quoted_identifier] = ACTIONS(8357),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8357),
    [sym_integer] = ACTIONS(8357),
    [sym_property_name] = ACTIONS(582),
    [sym_preproc_open] = ACTIONS(582),
    [sym_begin_keyword] = ACTIONS(582),
  },
  [STATE(3650)] = {
    [sym_identifier] = ACTIONS(3655),
    [anon_sym_DOT] = ACTIONS(3655),
    [anon_sym_EQ] = ACTIONS(3657),
    [anon_sym_DASH] = ACTIONS(3655),
    [aux_sym_boolean_token1] = ACTIONS(3655),
    [aux_sym_boolean_token2] = ACTIONS(3655),
    [sym_decimal] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3657),
    [anon_sym_RPAREN] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3657),
    [aux_sym_filter_value_token1] = ACTIONS(3655),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3655),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [aux_sym_record_type_token1] = ACTIONS(3655),
    [aux_sym_basic_type_token21] = ACTIONS(3655),
    [aux_sym_basic_type_token22] = ACTIONS(3655),
    [aux_sym_basic_type_token48] = ACTIONS(3655),
    [anon_sym_COLON_COLON] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3655),
    [anon_sym_NOT] = ACTIONS(3655),
    [anon_sym_Not] = ACTIONS(3655),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3657),
    [aux_sym__expression_token1] = ACTIONS(3657),
    [aux_sym__expression_token2] = ACTIONS(3657),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3655),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3655),
    [anon_sym_SLASH] = ACTIONS(3655),
    [anon_sym_div] = ACTIONS(3655),
    [anon_sym_DIV] = ACTIONS(3655),
    [anon_sym_Div] = ACTIONS(3655),
    [anon_sym_mod] = ACTIONS(3655),
    [anon_sym_MOD] = ACTIONS(3655),
    [anon_sym_Mod] = ACTIONS(3655),
    [anon_sym_PLUS] = ACTIONS(3655),
    [anon_sym_GT_EQ] = ACTIONS(3657),
    [anon_sym_LT_EQ] = ACTIONS(3657),
    [anon_sym_GT] = ACTIONS(3655),
    [anon_sym_LT] = ACTIONS(3655),
    [anon_sym_LT_GT] = ACTIONS(3657),
    [anon_sym_and] = ACTIONS(3655),
    [anon_sym_AND] = ACTIONS(3655),
    [anon_sym_And] = ACTIONS(3655),
    [anon_sym_or] = ACTIONS(3655),
    [anon_sym_OR] = ACTIONS(3655),
    [anon_sym_Or] = ACTIONS(3655),
    [anon_sym_xor] = ACTIONS(3655),
    [anon_sym_XOR] = ACTIONS(3655),
    [anon_sym_Xor] = ACTIONS(3655),
    [anon_sym_QMARK] = ACTIONS(3657),
    [sym_datetime_literal] = ACTIONS(3657),
    [sym_date_literal] = ACTIONS(3655),
    [sym_time_literal] = ACTIONS(3655),
    [sym_biginteger_literal] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3655),
    [anon_sym_IN] = ACTIONS(3655),
    [anon_sym_In] = ACTIONS(3655),
    [sym_page_keyword] = ACTIONS(3655),
    [anon_sym_codeunit] = ACTIONS(3655),
    [anon_sym_CODEUNIT] = ACTIONS(3655),
    [anon_sym_Codeunit] = ACTIONS(3655),
    [anon_sym_CodeUnit] = ACTIONS(3655),
    [anon_sym_COdeunit] = ACTIONS(3655),
    [anon_sym_codeUnit] = ACTIONS(3655),
    [sym_report_keyword] = ACTIONS(3655),
    [sym_query_keyword] = ACTIONS(3655),
    [anon_sym_xmlport] = ACTIONS(3655),
    [anon_sym_XMLPORT] = ACTIONS(3655),
    [anon_sym_Xmlport] = ACTIONS(3655),
    [anon_sym_XMLport] = ACTIONS(3655),
    [anon_sym_XMLPort] = ACTIONS(3655),
    [anon_sym_XmlPort] = ACTIONS(3655),
    [anon_sym_enum] = ACTIONS(3655),
    [anon_sym_ENUM] = ACTIONS(3655),
    [anon_sym_Enum] = ACTIONS(3655),
    [anon_sym_eNUM] = ACTIONS(3655),
    [anon_sym_eNum] = ACTIONS(3655),
    [anon_sym_ENum] = ACTIONS(3655),
    [sym_quoted_identifier] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3657),
    [sym_verbatim_string] = ACTIONS(3657),
    [sym_integer] = ACTIONS(3655),
    [sym_continue_as_identifier] = ACTIONS(3657),
  },
  [STATE(3651)] = {
    [ts_builtin_sym_end] = ACTIONS(6892),
    [anon_sym_POUNDif] = ACTIONS(6892),
    [anon_sym_POUNDIF] = ACTIONS(6892),
    [anon_sym_POUNDIf] = ACTIONS(6892),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6894),
    [anon_sym_tableextension] = ACTIONS(6892),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6892),
    [anon_sym_Tableextension] = ACTIONS(6892),
    [anon_sym_TableExtension] = ACTIONS(6892),
    [anon_sym_tableExtension] = ACTIONS(6892),
    [sym_page_keyword] = ACTIONS(6894),
    [anon_sym_pageextension] = ACTIONS(6892),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6892),
    [anon_sym_Pageextension] = ACTIONS(6892),
    [anon_sym_PageExtension] = ACTIONS(6892),
    [anon_sym_pageExtension] = ACTIONS(6892),
    [anon_sym_codeunit] = ACTIONS(6892),
    [anon_sym_CODEUNIT] = ACTIONS(6892),
    [anon_sym_Codeunit] = ACTIONS(6892),
    [anon_sym_CodeUnit] = ACTIONS(6892),
    [anon_sym_COdeunit] = ACTIONS(6892),
    [anon_sym_codeUnit] = ACTIONS(6892),
    [sym_report_keyword] = ACTIONS(6894),
    [anon_sym_reportextension] = ACTIONS(6892),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6892),
    [anon_sym_Reportextension] = ACTIONS(6892),
    [anon_sym_ReportExtension] = ACTIONS(6892),
    [anon_sym_reportExtension] = ACTIONS(6892),
    [sym_query_keyword] = ACTIONS(6892),
    [anon_sym_xmlport] = ACTIONS(6892),
    [anon_sym_XMLPORT] = ACTIONS(6892),
    [anon_sym_Xmlport] = ACTIONS(6892),
    [anon_sym_XMLport] = ACTIONS(6892),
    [anon_sym_XMLPort] = ACTIONS(6892),
    [anon_sym_XmlPort] = ACTIONS(6892),
    [anon_sym_enum] = ACTIONS(6894),
    [anon_sym_ENUM] = ACTIONS(6894),
    [anon_sym_Enum] = ACTIONS(6894),
    [anon_sym_eNUM] = ACTIONS(6892),
    [anon_sym_eNum] = ACTIONS(6892),
    [anon_sym_ENum] = ACTIONS(6892),
    [anon_sym_enumextension] = ACTIONS(6892),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6892),
    [anon_sym_Enumextension] = ACTIONS(6892),
    [anon_sym_EnumExtension] = ACTIONS(6892),
    [anon_sym_enumExtension] = ACTIONS(6892),
    [sym_interface_keyword] = ACTIONS(6892),
    [anon_sym_controladdin] = ACTIONS(6892),
    [anon_sym_CONTROLADDIN] = ACTIONS(6892),
    [anon_sym_Controladdin] = ACTIONS(6892),
    [anon_sym_ControlAddIn] = ACTIONS(6892),
    [anon_sym_ControlAddin] = ACTIONS(6892),
    [anon_sym_controlAddIn] = ACTIONS(6892),
    [anon_sym_controlAddin] = ACTIONS(6892),
    [anon_sym_dotnet] = ACTIONS(6892),
    [anon_sym_DOTNET] = ACTIONS(6892),
    [anon_sym_Dotnet] = ACTIONS(6892),
    [anon_sym_DotNet] = ACTIONS(6892),
    [anon_sym_dotNet] = ACTIONS(6892),
    [sym_profile_keyword] = ACTIONS(6894),
    [anon_sym_profileextension] = ACTIONS(6892),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6892),
    [anon_sym_Profileextension] = ACTIONS(6892),
    [anon_sym_ProfileExtension] = ACTIONS(6892),
    [anon_sym_profileExtension] = ACTIONS(6892),
    [anon_sym_permissionset] = ACTIONS(6894),
    [anon_sym_PERMISSIONSET] = ACTIONS(6894),
    [anon_sym_Permissionset] = ACTIONS(6894),
    [anon_sym_PermissionSet] = ACTIONS(6894),
    [anon_sym_permissionSet] = ACTIONS(6894),
    [anon_sym_permissionsetextension] = ACTIONS(6892),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6892),
    [anon_sym_Permissionsetextension] = ACTIONS(6892),
    [anon_sym_PermissionSetExtension] = ACTIONS(6892),
    [anon_sym_permissionSetExtension] = ACTIONS(6892),
    [sym_entitlement_keyword] = ACTIONS(6892),
    [anon_sym_pagecustomization] = ACTIONS(6892),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6892),
    [anon_sym_Pagecustomization] = ACTIONS(6892),
    [anon_sym_PageCustomization] = ACTIONS(6892),
    [anon_sym_pageCustomization] = ACTIONS(6892),
    [sym_using_keyword] = ACTIONS(6892),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6892),
  },
  [STATE(3652)] = {
    [ts_builtin_sym_end] = ACTIONS(7113),
    [anon_sym_POUNDif] = ACTIONS(7113),
    [anon_sym_POUNDIF] = ACTIONS(7113),
    [anon_sym_POUNDIf] = ACTIONS(7113),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7115),
    [anon_sym_tableextension] = ACTIONS(7113),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7113),
    [anon_sym_Tableextension] = ACTIONS(7113),
    [anon_sym_TableExtension] = ACTIONS(7113),
    [anon_sym_tableExtension] = ACTIONS(7113),
    [sym_page_keyword] = ACTIONS(7115),
    [anon_sym_pageextension] = ACTIONS(7113),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7113),
    [anon_sym_Pageextension] = ACTIONS(7113),
    [anon_sym_PageExtension] = ACTIONS(7113),
    [anon_sym_pageExtension] = ACTIONS(7113),
    [anon_sym_codeunit] = ACTIONS(7113),
    [anon_sym_CODEUNIT] = ACTIONS(7113),
    [anon_sym_Codeunit] = ACTIONS(7113),
    [anon_sym_CodeUnit] = ACTIONS(7113),
    [anon_sym_COdeunit] = ACTIONS(7113),
    [anon_sym_codeUnit] = ACTIONS(7113),
    [sym_report_keyword] = ACTIONS(7115),
    [anon_sym_reportextension] = ACTIONS(7113),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7113),
    [anon_sym_Reportextension] = ACTIONS(7113),
    [anon_sym_ReportExtension] = ACTIONS(7113),
    [anon_sym_reportExtension] = ACTIONS(7113),
    [sym_query_keyword] = ACTIONS(7113),
    [anon_sym_xmlport] = ACTIONS(7113),
    [anon_sym_XMLPORT] = ACTIONS(7113),
    [anon_sym_Xmlport] = ACTIONS(7113),
    [anon_sym_XMLport] = ACTIONS(7113),
    [anon_sym_XMLPort] = ACTIONS(7113),
    [anon_sym_XmlPort] = ACTIONS(7113),
    [anon_sym_enum] = ACTIONS(7115),
    [anon_sym_ENUM] = ACTIONS(7115),
    [anon_sym_Enum] = ACTIONS(7115),
    [anon_sym_eNUM] = ACTIONS(7113),
    [anon_sym_eNum] = ACTIONS(7113),
    [anon_sym_ENum] = ACTIONS(7113),
    [anon_sym_enumextension] = ACTIONS(7113),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7113),
    [anon_sym_Enumextension] = ACTIONS(7113),
    [anon_sym_EnumExtension] = ACTIONS(7113),
    [anon_sym_enumExtension] = ACTIONS(7113),
    [sym_interface_keyword] = ACTIONS(7113),
    [anon_sym_controladdin] = ACTIONS(7113),
    [anon_sym_CONTROLADDIN] = ACTIONS(7113),
    [anon_sym_Controladdin] = ACTIONS(7113),
    [anon_sym_ControlAddIn] = ACTIONS(7113),
    [anon_sym_ControlAddin] = ACTIONS(7113),
    [anon_sym_controlAddIn] = ACTIONS(7113),
    [anon_sym_controlAddin] = ACTIONS(7113),
    [anon_sym_dotnet] = ACTIONS(7113),
    [anon_sym_DOTNET] = ACTIONS(7113),
    [anon_sym_Dotnet] = ACTIONS(7113),
    [anon_sym_DotNet] = ACTIONS(7113),
    [anon_sym_dotNet] = ACTIONS(7113),
    [sym_profile_keyword] = ACTIONS(7115),
    [anon_sym_profileextension] = ACTIONS(7113),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7113),
    [anon_sym_Profileextension] = ACTIONS(7113),
    [anon_sym_ProfileExtension] = ACTIONS(7113),
    [anon_sym_profileExtension] = ACTIONS(7113),
    [anon_sym_permissionset] = ACTIONS(7115),
    [anon_sym_PERMISSIONSET] = ACTIONS(7115),
    [anon_sym_Permissionset] = ACTIONS(7115),
    [anon_sym_PermissionSet] = ACTIONS(7115),
    [anon_sym_permissionSet] = ACTIONS(7115),
    [anon_sym_permissionsetextension] = ACTIONS(7113),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7113),
    [anon_sym_Permissionsetextension] = ACTIONS(7113),
    [anon_sym_PermissionSetExtension] = ACTIONS(7113),
    [anon_sym_permissionSetExtension] = ACTIONS(7113),
    [sym_entitlement_keyword] = ACTIONS(7113),
    [anon_sym_pagecustomization] = ACTIONS(7113),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7113),
    [anon_sym_Pagecustomization] = ACTIONS(7113),
    [anon_sym_PageCustomization] = ACTIONS(7113),
    [anon_sym_pageCustomization] = ACTIONS(7113),
    [sym_using_keyword] = ACTIONS(7113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7113),
  },
  [STATE(3653)] = {
    [ts_builtin_sym_end] = ACTIONS(6858),
    [anon_sym_POUNDif] = ACTIONS(6858),
    [anon_sym_POUNDIF] = ACTIONS(6858),
    [anon_sym_POUNDIf] = ACTIONS(6858),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6860),
    [anon_sym_tableextension] = ACTIONS(6858),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6858),
    [anon_sym_Tableextension] = ACTIONS(6858),
    [anon_sym_TableExtension] = ACTIONS(6858),
    [anon_sym_tableExtension] = ACTIONS(6858),
    [sym_page_keyword] = ACTIONS(6860),
    [anon_sym_pageextension] = ACTIONS(6858),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6858),
    [anon_sym_Pageextension] = ACTIONS(6858),
    [anon_sym_PageExtension] = ACTIONS(6858),
    [anon_sym_pageExtension] = ACTIONS(6858),
    [anon_sym_codeunit] = ACTIONS(6858),
    [anon_sym_CODEUNIT] = ACTIONS(6858),
    [anon_sym_Codeunit] = ACTIONS(6858),
    [anon_sym_CodeUnit] = ACTIONS(6858),
    [anon_sym_COdeunit] = ACTIONS(6858),
    [anon_sym_codeUnit] = ACTIONS(6858),
    [sym_report_keyword] = ACTIONS(6860),
    [anon_sym_reportextension] = ACTIONS(6858),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6858),
    [anon_sym_Reportextension] = ACTIONS(6858),
    [anon_sym_ReportExtension] = ACTIONS(6858),
    [anon_sym_reportExtension] = ACTIONS(6858),
    [sym_query_keyword] = ACTIONS(6858),
    [anon_sym_xmlport] = ACTIONS(6858),
    [anon_sym_XMLPORT] = ACTIONS(6858),
    [anon_sym_Xmlport] = ACTIONS(6858),
    [anon_sym_XMLport] = ACTIONS(6858),
    [anon_sym_XMLPort] = ACTIONS(6858),
    [anon_sym_XmlPort] = ACTIONS(6858),
    [anon_sym_enum] = ACTIONS(6860),
    [anon_sym_ENUM] = ACTIONS(6860),
    [anon_sym_Enum] = ACTIONS(6860),
    [anon_sym_eNUM] = ACTIONS(6858),
    [anon_sym_eNum] = ACTIONS(6858),
    [anon_sym_ENum] = ACTIONS(6858),
    [anon_sym_enumextension] = ACTIONS(6858),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6858),
    [anon_sym_Enumextension] = ACTIONS(6858),
    [anon_sym_EnumExtension] = ACTIONS(6858),
    [anon_sym_enumExtension] = ACTIONS(6858),
    [sym_interface_keyword] = ACTIONS(6858),
    [anon_sym_controladdin] = ACTIONS(6858),
    [anon_sym_CONTROLADDIN] = ACTIONS(6858),
    [anon_sym_Controladdin] = ACTIONS(6858),
    [anon_sym_ControlAddIn] = ACTIONS(6858),
    [anon_sym_ControlAddin] = ACTIONS(6858),
    [anon_sym_controlAddIn] = ACTIONS(6858),
    [anon_sym_controlAddin] = ACTIONS(6858),
    [anon_sym_dotnet] = ACTIONS(6858),
    [anon_sym_DOTNET] = ACTIONS(6858),
    [anon_sym_Dotnet] = ACTIONS(6858),
    [anon_sym_DotNet] = ACTIONS(6858),
    [anon_sym_dotNet] = ACTIONS(6858),
    [sym_profile_keyword] = ACTIONS(6860),
    [anon_sym_profileextension] = ACTIONS(6858),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6858),
    [anon_sym_Profileextension] = ACTIONS(6858),
    [anon_sym_ProfileExtension] = ACTIONS(6858),
    [anon_sym_profileExtension] = ACTIONS(6858),
    [anon_sym_permissionset] = ACTIONS(6860),
    [anon_sym_PERMISSIONSET] = ACTIONS(6860),
    [anon_sym_Permissionset] = ACTIONS(6860),
    [anon_sym_PermissionSet] = ACTIONS(6860),
    [anon_sym_permissionSet] = ACTIONS(6860),
    [anon_sym_permissionsetextension] = ACTIONS(6858),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6858),
    [anon_sym_Permissionsetextension] = ACTIONS(6858),
    [anon_sym_PermissionSetExtension] = ACTIONS(6858),
    [anon_sym_permissionSetExtension] = ACTIONS(6858),
    [sym_entitlement_keyword] = ACTIONS(6858),
    [anon_sym_pagecustomization] = ACTIONS(6858),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6858),
    [anon_sym_Pagecustomization] = ACTIONS(6858),
    [anon_sym_PageCustomization] = ACTIONS(6858),
    [anon_sym_pageCustomization] = ACTIONS(6858),
    [sym_using_keyword] = ACTIONS(6858),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6858),
  },
  [STATE(3654)] = {
    [sym_boolean] = STATE(8824),
    [sym_simple_table_relation] = STATE(5335),
    [sym__namespaced_or_simple_ref] = STATE(4477),
    [sym_assignment_expression] = STATE(8824),
    [sym__expression] = STATE(8824),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8824),
    [sym_multiplicative_expression] = STATE(8824),
    [sym_additive_expression] = STATE(8824),
    [sym_comparison_expression] = STATE(8824),
    [sym_logical_expression] = STATE(8824),
    [sym_ternary_expression] = STATE(8824),
    [sym_unary_expression] = STATE(8824),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(2302),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8824),
    [sym_list_literal] = STATE(8824),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8824),
    [sym__literal_value] = STATE(8824),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(4330),
    [sym_keyword_as_identifier] = STATE(4330),
    [sym_identifier] = ACTIONS(7572),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7574),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7576),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7578),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7576),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7576),
    [aux_sym_separator_action_token1] = ACTIONS(7576),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7576),
    [aux_sym_type_declaration_token1] = ACTIONS(7576),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7580),
    [sym_date_literal] = ACTIONS(7574),
    [sym_time_literal] = ACTIONS(7574),
    [sym_biginteger_literal] = ACTIONS(7580),
    [sym_table_keyword] = ACTIONS(7576),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7576),
    [sym_dataset_keyword] = ACTIONS(7576),
    [sym_quoted_identifier] = ACTIONS(7582),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7580),
    [sym_verbatim_string] = ACTIONS(7580),
    [sym_integer] = ACTIONS(7584),
    [sym_continue_as_identifier] = ACTIONS(7580),
  },
  [STATE(3655)] = {
    [ts_builtin_sym_end] = ACTIONS(6896),
    [anon_sym_POUNDif] = ACTIONS(6896),
    [anon_sym_POUNDIF] = ACTIONS(6896),
    [anon_sym_POUNDIf] = ACTIONS(6896),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6898),
    [anon_sym_tableextension] = ACTIONS(6896),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6896),
    [anon_sym_Tableextension] = ACTIONS(6896),
    [anon_sym_TableExtension] = ACTIONS(6896),
    [anon_sym_tableExtension] = ACTIONS(6896),
    [sym_page_keyword] = ACTIONS(6898),
    [anon_sym_pageextension] = ACTIONS(6896),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6896),
    [anon_sym_Pageextension] = ACTIONS(6896),
    [anon_sym_PageExtension] = ACTIONS(6896),
    [anon_sym_pageExtension] = ACTIONS(6896),
    [anon_sym_codeunit] = ACTIONS(6896),
    [anon_sym_CODEUNIT] = ACTIONS(6896),
    [anon_sym_Codeunit] = ACTIONS(6896),
    [anon_sym_CodeUnit] = ACTIONS(6896),
    [anon_sym_COdeunit] = ACTIONS(6896),
    [anon_sym_codeUnit] = ACTIONS(6896),
    [sym_report_keyword] = ACTIONS(6898),
    [anon_sym_reportextension] = ACTIONS(6896),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6896),
    [anon_sym_Reportextension] = ACTIONS(6896),
    [anon_sym_ReportExtension] = ACTIONS(6896),
    [anon_sym_reportExtension] = ACTIONS(6896),
    [sym_query_keyword] = ACTIONS(6896),
    [anon_sym_xmlport] = ACTIONS(6896),
    [anon_sym_XMLPORT] = ACTIONS(6896),
    [anon_sym_Xmlport] = ACTIONS(6896),
    [anon_sym_XMLport] = ACTIONS(6896),
    [anon_sym_XMLPort] = ACTIONS(6896),
    [anon_sym_XmlPort] = ACTIONS(6896),
    [anon_sym_enum] = ACTIONS(6898),
    [anon_sym_ENUM] = ACTIONS(6898),
    [anon_sym_Enum] = ACTIONS(6898),
    [anon_sym_eNUM] = ACTIONS(6896),
    [anon_sym_eNum] = ACTIONS(6896),
    [anon_sym_ENum] = ACTIONS(6896),
    [anon_sym_enumextension] = ACTIONS(6896),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6896),
    [anon_sym_Enumextension] = ACTIONS(6896),
    [anon_sym_EnumExtension] = ACTIONS(6896),
    [anon_sym_enumExtension] = ACTIONS(6896),
    [sym_interface_keyword] = ACTIONS(6896),
    [anon_sym_controladdin] = ACTIONS(6896),
    [anon_sym_CONTROLADDIN] = ACTIONS(6896),
    [anon_sym_Controladdin] = ACTIONS(6896),
    [anon_sym_ControlAddIn] = ACTIONS(6896),
    [anon_sym_ControlAddin] = ACTIONS(6896),
    [anon_sym_controlAddIn] = ACTIONS(6896),
    [anon_sym_controlAddin] = ACTIONS(6896),
    [anon_sym_dotnet] = ACTIONS(6896),
    [anon_sym_DOTNET] = ACTIONS(6896),
    [anon_sym_Dotnet] = ACTIONS(6896),
    [anon_sym_DotNet] = ACTIONS(6896),
    [anon_sym_dotNet] = ACTIONS(6896),
    [sym_profile_keyword] = ACTIONS(6898),
    [anon_sym_profileextension] = ACTIONS(6896),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6896),
    [anon_sym_Profileextension] = ACTIONS(6896),
    [anon_sym_ProfileExtension] = ACTIONS(6896),
    [anon_sym_profileExtension] = ACTIONS(6896),
    [anon_sym_permissionset] = ACTIONS(6898),
    [anon_sym_PERMISSIONSET] = ACTIONS(6898),
    [anon_sym_Permissionset] = ACTIONS(6898),
    [anon_sym_PermissionSet] = ACTIONS(6898),
    [anon_sym_permissionSet] = ACTIONS(6898),
    [anon_sym_permissionsetextension] = ACTIONS(6896),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6896),
    [anon_sym_Permissionsetextension] = ACTIONS(6896),
    [anon_sym_PermissionSetExtension] = ACTIONS(6896),
    [anon_sym_permissionSetExtension] = ACTIONS(6896),
    [sym_entitlement_keyword] = ACTIONS(6896),
    [anon_sym_pagecustomization] = ACTIONS(6896),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6896),
    [anon_sym_Pagecustomization] = ACTIONS(6896),
    [anon_sym_PageCustomization] = ACTIONS(6896),
    [anon_sym_pageCustomization] = ACTIONS(6896),
    [sym_using_keyword] = ACTIONS(6896),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6896),
  },
  [STATE(3656)] = {
    [sym__body_element] = STATE(3841),
    [sym_empty_statement] = STATE(3841),
    [sym_property] = STATE(3841),
    [sym_permissions_property] = STATE(3841),
    [sym_table_relation_property] = STATE(3841),
    [sym_fields_section] = STATE(3841),
    [sym_keys_section] = STATE(3841),
    [sym_fieldgroups_section] = STATE(3841),
    [sym_enum_value_declaration] = STATE(3841),
    [sym_labels_section] = STATE(3841),
    [sym_layout_section] = STATE(3841),
    [sym_modify_modification] = STATE(3841),
    [sym_actions_section] = STATE(3841),
    [sym_views_section] = STATE(3841),
    [sym_dataset_section] = STATE(3841),
    [sym_requestpage_section] = STATE(3841),
    [sym_rendering_section] = STATE(3841),
    [sym_elements_section] = STATE(3841),
    [sym_schema_section] = STATE(3841),
    [sym_assembly_declaration] = STATE(3841),
    [sym_event_declaration] = STATE(3841),
    [sym_procedure] = STATE(3841),
    [sym_preproc_split_procedure] = STATE(3841),
    [sym__procedure_preamble] = STATE(10899),
    [sym_preproc_split_procedure_preamble] = STATE(3841),
    [sym__procedure_header] = STATE(9979),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(3841),
    [sym_var_section] = STATE(3841),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(3841),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4916),
    [sym_preproc_endif] = STATE(6875),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3841),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10997),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(3657)] = {
    [ts_builtin_sym_end] = ACTIONS(6993),
    [anon_sym_POUNDif] = ACTIONS(6993),
    [anon_sym_POUNDIF] = ACTIONS(6993),
    [anon_sym_POUNDIf] = ACTIONS(6993),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6995),
    [anon_sym_tableextension] = ACTIONS(6993),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6993),
    [anon_sym_Tableextension] = ACTIONS(6993),
    [anon_sym_TableExtension] = ACTIONS(6993),
    [anon_sym_tableExtension] = ACTIONS(6993),
    [sym_page_keyword] = ACTIONS(6995),
    [anon_sym_pageextension] = ACTIONS(6993),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6993),
    [anon_sym_Pageextension] = ACTIONS(6993),
    [anon_sym_PageExtension] = ACTIONS(6993),
    [anon_sym_pageExtension] = ACTIONS(6993),
    [anon_sym_codeunit] = ACTIONS(6993),
    [anon_sym_CODEUNIT] = ACTIONS(6993),
    [anon_sym_Codeunit] = ACTIONS(6993),
    [anon_sym_CodeUnit] = ACTIONS(6993),
    [anon_sym_COdeunit] = ACTIONS(6993),
    [anon_sym_codeUnit] = ACTIONS(6993),
    [sym_report_keyword] = ACTIONS(6995),
    [anon_sym_reportextension] = ACTIONS(6993),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6993),
    [anon_sym_Reportextension] = ACTIONS(6993),
    [anon_sym_ReportExtension] = ACTIONS(6993),
    [anon_sym_reportExtension] = ACTIONS(6993),
    [sym_query_keyword] = ACTIONS(6993),
    [anon_sym_xmlport] = ACTIONS(6993),
    [anon_sym_XMLPORT] = ACTIONS(6993),
    [anon_sym_Xmlport] = ACTIONS(6993),
    [anon_sym_XMLport] = ACTIONS(6993),
    [anon_sym_XMLPort] = ACTIONS(6993),
    [anon_sym_XmlPort] = ACTIONS(6993),
    [anon_sym_enum] = ACTIONS(6995),
    [anon_sym_ENUM] = ACTIONS(6995),
    [anon_sym_Enum] = ACTIONS(6995),
    [anon_sym_eNUM] = ACTIONS(6993),
    [anon_sym_eNum] = ACTIONS(6993),
    [anon_sym_ENum] = ACTIONS(6993),
    [anon_sym_enumextension] = ACTIONS(6993),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6993),
    [anon_sym_Enumextension] = ACTIONS(6993),
    [anon_sym_EnumExtension] = ACTIONS(6993),
    [anon_sym_enumExtension] = ACTIONS(6993),
    [sym_interface_keyword] = ACTIONS(6993),
    [anon_sym_controladdin] = ACTIONS(6993),
    [anon_sym_CONTROLADDIN] = ACTIONS(6993),
    [anon_sym_Controladdin] = ACTIONS(6993),
    [anon_sym_ControlAddIn] = ACTIONS(6993),
    [anon_sym_ControlAddin] = ACTIONS(6993),
    [anon_sym_controlAddIn] = ACTIONS(6993),
    [anon_sym_controlAddin] = ACTIONS(6993),
    [anon_sym_dotnet] = ACTIONS(6993),
    [anon_sym_DOTNET] = ACTIONS(6993),
    [anon_sym_Dotnet] = ACTIONS(6993),
    [anon_sym_DotNet] = ACTIONS(6993),
    [anon_sym_dotNet] = ACTIONS(6993),
    [sym_profile_keyword] = ACTIONS(6995),
    [anon_sym_profileextension] = ACTIONS(6993),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6993),
    [anon_sym_Profileextension] = ACTIONS(6993),
    [anon_sym_ProfileExtension] = ACTIONS(6993),
    [anon_sym_profileExtension] = ACTIONS(6993),
    [anon_sym_permissionset] = ACTIONS(6995),
    [anon_sym_PERMISSIONSET] = ACTIONS(6995),
    [anon_sym_Permissionset] = ACTIONS(6995),
    [anon_sym_PermissionSet] = ACTIONS(6995),
    [anon_sym_permissionSet] = ACTIONS(6995),
    [anon_sym_permissionsetextension] = ACTIONS(6993),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6993),
    [anon_sym_Permissionsetextension] = ACTIONS(6993),
    [anon_sym_PermissionSetExtension] = ACTIONS(6993),
    [anon_sym_permissionSetExtension] = ACTIONS(6993),
    [sym_entitlement_keyword] = ACTIONS(6993),
    [anon_sym_pagecustomization] = ACTIONS(6993),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6993),
    [anon_sym_Pagecustomization] = ACTIONS(6993),
    [anon_sym_PageCustomization] = ACTIONS(6993),
    [anon_sym_pageCustomization] = ACTIONS(6993),
    [sym_using_keyword] = ACTIONS(6993),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6993),
  },
  [STATE(3658)] = {
    [ts_builtin_sym_end] = ACTIONS(7181),
    [anon_sym_POUNDif] = ACTIONS(7181),
    [anon_sym_POUNDIF] = ACTIONS(7181),
    [anon_sym_POUNDIf] = ACTIONS(7181),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7183),
    [anon_sym_tableextension] = ACTIONS(7181),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7181),
    [anon_sym_Tableextension] = ACTIONS(7181),
    [anon_sym_TableExtension] = ACTIONS(7181),
    [anon_sym_tableExtension] = ACTIONS(7181),
    [sym_page_keyword] = ACTIONS(7183),
    [anon_sym_pageextension] = ACTIONS(7181),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7181),
    [anon_sym_Pageextension] = ACTIONS(7181),
    [anon_sym_PageExtension] = ACTIONS(7181),
    [anon_sym_pageExtension] = ACTIONS(7181),
    [anon_sym_codeunit] = ACTIONS(7181),
    [anon_sym_CODEUNIT] = ACTIONS(7181),
    [anon_sym_Codeunit] = ACTIONS(7181),
    [anon_sym_CodeUnit] = ACTIONS(7181),
    [anon_sym_COdeunit] = ACTIONS(7181),
    [anon_sym_codeUnit] = ACTIONS(7181),
    [sym_report_keyword] = ACTIONS(7183),
    [anon_sym_reportextension] = ACTIONS(7181),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7181),
    [anon_sym_Reportextension] = ACTIONS(7181),
    [anon_sym_ReportExtension] = ACTIONS(7181),
    [anon_sym_reportExtension] = ACTIONS(7181),
    [sym_query_keyword] = ACTIONS(7181),
    [anon_sym_xmlport] = ACTIONS(7181),
    [anon_sym_XMLPORT] = ACTIONS(7181),
    [anon_sym_Xmlport] = ACTIONS(7181),
    [anon_sym_XMLport] = ACTIONS(7181),
    [anon_sym_XMLPort] = ACTIONS(7181),
    [anon_sym_XmlPort] = ACTIONS(7181),
    [anon_sym_enum] = ACTIONS(7183),
    [anon_sym_ENUM] = ACTIONS(7183),
    [anon_sym_Enum] = ACTIONS(7183),
    [anon_sym_eNUM] = ACTIONS(7181),
    [anon_sym_eNum] = ACTIONS(7181),
    [anon_sym_ENum] = ACTIONS(7181),
    [anon_sym_enumextension] = ACTIONS(7181),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7181),
    [anon_sym_Enumextension] = ACTIONS(7181),
    [anon_sym_EnumExtension] = ACTIONS(7181),
    [anon_sym_enumExtension] = ACTIONS(7181),
    [sym_interface_keyword] = ACTIONS(7181),
    [anon_sym_controladdin] = ACTIONS(7181),
    [anon_sym_CONTROLADDIN] = ACTIONS(7181),
    [anon_sym_Controladdin] = ACTIONS(7181),
    [anon_sym_ControlAddIn] = ACTIONS(7181),
    [anon_sym_ControlAddin] = ACTIONS(7181),
    [anon_sym_controlAddIn] = ACTIONS(7181),
    [anon_sym_controlAddin] = ACTIONS(7181),
    [anon_sym_dotnet] = ACTIONS(7181),
    [anon_sym_DOTNET] = ACTIONS(7181),
    [anon_sym_Dotnet] = ACTIONS(7181),
    [anon_sym_DotNet] = ACTIONS(7181),
    [anon_sym_dotNet] = ACTIONS(7181),
    [sym_profile_keyword] = ACTIONS(7183),
    [anon_sym_profileextension] = ACTIONS(7181),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7181),
    [anon_sym_Profileextension] = ACTIONS(7181),
    [anon_sym_ProfileExtension] = ACTIONS(7181),
    [anon_sym_profileExtension] = ACTIONS(7181),
    [anon_sym_permissionset] = ACTIONS(7183),
    [anon_sym_PERMISSIONSET] = ACTIONS(7183),
    [anon_sym_Permissionset] = ACTIONS(7183),
    [anon_sym_PermissionSet] = ACTIONS(7183),
    [anon_sym_permissionSet] = ACTIONS(7183),
    [anon_sym_permissionsetextension] = ACTIONS(7181),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7181),
    [anon_sym_Permissionsetextension] = ACTIONS(7181),
    [anon_sym_PermissionSetExtension] = ACTIONS(7181),
    [anon_sym_permissionSetExtension] = ACTIONS(7181),
    [sym_entitlement_keyword] = ACTIONS(7181),
    [anon_sym_pagecustomization] = ACTIONS(7181),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7181),
    [anon_sym_Pagecustomization] = ACTIONS(7181),
    [anon_sym_PageCustomization] = ACTIONS(7181),
    [anon_sym_pageCustomization] = ACTIONS(7181),
    [sym_using_keyword] = ACTIONS(7181),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7181),
  },
  [STATE(3659)] = {
    [sym__body_element] = STATE(3834),
    [sym_empty_statement] = STATE(3834),
    [sym_property] = STATE(3834),
    [sym_permissions_property] = STATE(3834),
    [sym_table_relation_property] = STATE(3834),
    [sym_fields_section] = STATE(3834),
    [sym_keys_section] = STATE(3834),
    [sym_fieldgroups_section] = STATE(3834),
    [sym_enum_value_declaration] = STATE(3834),
    [sym_labels_section] = STATE(3834),
    [sym_layout_section] = STATE(3834),
    [sym_modify_modification] = STATE(3834),
    [sym_actions_section] = STATE(3834),
    [sym_views_section] = STATE(3834),
    [sym_dataset_section] = STATE(3834),
    [sym_requestpage_section] = STATE(3834),
    [sym_rendering_section] = STATE(3834),
    [sym_elements_section] = STATE(3834),
    [sym_schema_section] = STATE(3834),
    [sym_assembly_declaration] = STATE(3834),
    [sym_event_declaration] = STATE(3834),
    [sym_procedure] = STATE(3834),
    [sym_preproc_split_procedure] = STATE(3834),
    [sym__procedure_preamble] = STATE(10930),
    [sym_preproc_split_procedure_preamble] = STATE(3834),
    [sym__procedure_header] = STATE(9970),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(3834),
    [sym_var_section] = STATE(3834),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(3834),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4941),
    [sym_preproc_endif] = STATE(8229),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3834),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10978),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3660)] = {
    [ts_builtin_sym_end] = ACTIONS(7117),
    [anon_sym_POUNDif] = ACTIONS(7117),
    [anon_sym_POUNDIF] = ACTIONS(7117),
    [anon_sym_POUNDIf] = ACTIONS(7117),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7119),
    [anon_sym_tableextension] = ACTIONS(7117),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7117),
    [anon_sym_Tableextension] = ACTIONS(7117),
    [anon_sym_TableExtension] = ACTIONS(7117),
    [anon_sym_tableExtension] = ACTIONS(7117),
    [sym_page_keyword] = ACTIONS(7119),
    [anon_sym_pageextension] = ACTIONS(7117),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7117),
    [anon_sym_Pageextension] = ACTIONS(7117),
    [anon_sym_PageExtension] = ACTIONS(7117),
    [anon_sym_pageExtension] = ACTIONS(7117),
    [anon_sym_codeunit] = ACTIONS(7117),
    [anon_sym_CODEUNIT] = ACTIONS(7117),
    [anon_sym_Codeunit] = ACTIONS(7117),
    [anon_sym_CodeUnit] = ACTIONS(7117),
    [anon_sym_COdeunit] = ACTIONS(7117),
    [anon_sym_codeUnit] = ACTIONS(7117),
    [sym_report_keyword] = ACTIONS(7119),
    [anon_sym_reportextension] = ACTIONS(7117),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7117),
    [anon_sym_Reportextension] = ACTIONS(7117),
    [anon_sym_ReportExtension] = ACTIONS(7117),
    [anon_sym_reportExtension] = ACTIONS(7117),
    [sym_query_keyword] = ACTIONS(7117),
    [anon_sym_xmlport] = ACTIONS(7117),
    [anon_sym_XMLPORT] = ACTIONS(7117),
    [anon_sym_Xmlport] = ACTIONS(7117),
    [anon_sym_XMLport] = ACTIONS(7117),
    [anon_sym_XMLPort] = ACTIONS(7117),
    [anon_sym_XmlPort] = ACTIONS(7117),
    [anon_sym_enum] = ACTIONS(7119),
    [anon_sym_ENUM] = ACTIONS(7119),
    [anon_sym_Enum] = ACTIONS(7119),
    [anon_sym_eNUM] = ACTIONS(7117),
    [anon_sym_eNum] = ACTIONS(7117),
    [anon_sym_ENum] = ACTIONS(7117),
    [anon_sym_enumextension] = ACTIONS(7117),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7117),
    [anon_sym_Enumextension] = ACTIONS(7117),
    [anon_sym_EnumExtension] = ACTIONS(7117),
    [anon_sym_enumExtension] = ACTIONS(7117),
    [sym_interface_keyword] = ACTIONS(7117),
    [anon_sym_controladdin] = ACTIONS(7117),
    [anon_sym_CONTROLADDIN] = ACTIONS(7117),
    [anon_sym_Controladdin] = ACTIONS(7117),
    [anon_sym_ControlAddIn] = ACTIONS(7117),
    [anon_sym_ControlAddin] = ACTIONS(7117),
    [anon_sym_controlAddIn] = ACTIONS(7117),
    [anon_sym_controlAddin] = ACTIONS(7117),
    [anon_sym_dotnet] = ACTIONS(7117),
    [anon_sym_DOTNET] = ACTIONS(7117),
    [anon_sym_Dotnet] = ACTIONS(7117),
    [anon_sym_DotNet] = ACTIONS(7117),
    [anon_sym_dotNet] = ACTIONS(7117),
    [sym_profile_keyword] = ACTIONS(7119),
    [anon_sym_profileextension] = ACTIONS(7117),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7117),
    [anon_sym_Profileextension] = ACTIONS(7117),
    [anon_sym_ProfileExtension] = ACTIONS(7117),
    [anon_sym_profileExtension] = ACTIONS(7117),
    [anon_sym_permissionset] = ACTIONS(7119),
    [anon_sym_PERMISSIONSET] = ACTIONS(7119),
    [anon_sym_Permissionset] = ACTIONS(7119),
    [anon_sym_PermissionSet] = ACTIONS(7119),
    [anon_sym_permissionSet] = ACTIONS(7119),
    [anon_sym_permissionsetextension] = ACTIONS(7117),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7117),
    [anon_sym_Permissionsetextension] = ACTIONS(7117),
    [anon_sym_PermissionSetExtension] = ACTIONS(7117),
    [anon_sym_permissionSetExtension] = ACTIONS(7117),
    [sym_entitlement_keyword] = ACTIONS(7117),
    [anon_sym_pagecustomization] = ACTIONS(7117),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7117),
    [anon_sym_Pagecustomization] = ACTIONS(7117),
    [anon_sym_PageCustomization] = ACTIONS(7117),
    [anon_sym_pageCustomization] = ACTIONS(7117),
    [sym_using_keyword] = ACTIONS(7117),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7117),
  },
  [STATE(3661)] = {
    [ts_builtin_sym_end] = ACTIONS(7007),
    [anon_sym_POUNDif] = ACTIONS(7007),
    [anon_sym_POUNDIF] = ACTIONS(7007),
    [anon_sym_POUNDIf] = ACTIONS(7007),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7009),
    [anon_sym_tableextension] = ACTIONS(7007),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7007),
    [anon_sym_Tableextension] = ACTIONS(7007),
    [anon_sym_TableExtension] = ACTIONS(7007),
    [anon_sym_tableExtension] = ACTIONS(7007),
    [sym_page_keyword] = ACTIONS(7009),
    [anon_sym_pageextension] = ACTIONS(7007),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7007),
    [anon_sym_Pageextension] = ACTIONS(7007),
    [anon_sym_PageExtension] = ACTIONS(7007),
    [anon_sym_pageExtension] = ACTIONS(7007),
    [anon_sym_codeunit] = ACTIONS(7007),
    [anon_sym_CODEUNIT] = ACTIONS(7007),
    [anon_sym_Codeunit] = ACTIONS(7007),
    [anon_sym_CodeUnit] = ACTIONS(7007),
    [anon_sym_COdeunit] = ACTIONS(7007),
    [anon_sym_codeUnit] = ACTIONS(7007),
    [sym_report_keyword] = ACTIONS(7009),
    [anon_sym_reportextension] = ACTIONS(7007),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7007),
    [anon_sym_Reportextension] = ACTIONS(7007),
    [anon_sym_ReportExtension] = ACTIONS(7007),
    [anon_sym_reportExtension] = ACTIONS(7007),
    [sym_query_keyword] = ACTIONS(7007),
    [anon_sym_xmlport] = ACTIONS(7007),
    [anon_sym_XMLPORT] = ACTIONS(7007),
    [anon_sym_Xmlport] = ACTIONS(7007),
    [anon_sym_XMLport] = ACTIONS(7007),
    [anon_sym_XMLPort] = ACTIONS(7007),
    [anon_sym_XmlPort] = ACTIONS(7007),
    [anon_sym_enum] = ACTIONS(7009),
    [anon_sym_ENUM] = ACTIONS(7009),
    [anon_sym_Enum] = ACTIONS(7009),
    [anon_sym_eNUM] = ACTIONS(7007),
    [anon_sym_eNum] = ACTIONS(7007),
    [anon_sym_ENum] = ACTIONS(7007),
    [anon_sym_enumextension] = ACTIONS(7007),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7007),
    [anon_sym_Enumextension] = ACTIONS(7007),
    [anon_sym_EnumExtension] = ACTIONS(7007),
    [anon_sym_enumExtension] = ACTIONS(7007),
    [sym_interface_keyword] = ACTIONS(7007),
    [anon_sym_controladdin] = ACTIONS(7007),
    [anon_sym_CONTROLADDIN] = ACTIONS(7007),
    [anon_sym_Controladdin] = ACTIONS(7007),
    [anon_sym_ControlAddIn] = ACTIONS(7007),
    [anon_sym_ControlAddin] = ACTIONS(7007),
    [anon_sym_controlAddIn] = ACTIONS(7007),
    [anon_sym_controlAddin] = ACTIONS(7007),
    [anon_sym_dotnet] = ACTIONS(7007),
    [anon_sym_DOTNET] = ACTIONS(7007),
    [anon_sym_Dotnet] = ACTIONS(7007),
    [anon_sym_DotNet] = ACTIONS(7007),
    [anon_sym_dotNet] = ACTIONS(7007),
    [sym_profile_keyword] = ACTIONS(7009),
    [anon_sym_profileextension] = ACTIONS(7007),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7007),
    [anon_sym_Profileextension] = ACTIONS(7007),
    [anon_sym_ProfileExtension] = ACTIONS(7007),
    [anon_sym_profileExtension] = ACTIONS(7007),
    [anon_sym_permissionset] = ACTIONS(7009),
    [anon_sym_PERMISSIONSET] = ACTIONS(7009),
    [anon_sym_Permissionset] = ACTIONS(7009),
    [anon_sym_PermissionSet] = ACTIONS(7009),
    [anon_sym_permissionSet] = ACTIONS(7009),
    [anon_sym_permissionsetextension] = ACTIONS(7007),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7007),
    [anon_sym_Permissionsetextension] = ACTIONS(7007),
    [anon_sym_PermissionSetExtension] = ACTIONS(7007),
    [anon_sym_permissionSetExtension] = ACTIONS(7007),
    [sym_entitlement_keyword] = ACTIONS(7007),
    [anon_sym_pagecustomization] = ACTIONS(7007),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7007),
    [anon_sym_Pagecustomization] = ACTIONS(7007),
    [anon_sym_PageCustomization] = ACTIONS(7007),
    [anon_sym_pageCustomization] = ACTIONS(7007),
    [sym_using_keyword] = ACTIONS(7007),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7007),
  },
  [STATE(3662)] = {
    [sym_boolean] = STATE(8806),
    [sym_simple_table_relation] = STATE(11220),
    [sym__namespaced_or_simple_ref] = STATE(10966),
    [sym_assignment_expression] = STATE(8806),
    [sym__expression] = STATE(8806),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8806),
    [sym_multiplicative_expression] = STATE(8806),
    [sym_additive_expression] = STATE(8806),
    [sym_comparison_expression] = STATE(8806),
    [sym_logical_expression] = STATE(8806),
    [sym_ternary_expression] = STATE(8806),
    [sym_unary_expression] = STATE(8806),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(6030),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_list_literal] = STATE(8806),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8806),
    [sym__literal_value] = STATE(8806),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(10341),
    [sym_keyword_as_identifier] = STATE(10341),
    [sym_identifier] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8359),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(8361),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(4377),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(8361),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8361),
    [aux_sym_separator_action_token1] = ACTIONS(8361),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8361),
    [aux_sym_type_declaration_token1] = ACTIONS(8361),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(8363),
    [sym_date_literal] = ACTIONS(8359),
    [sym_time_literal] = ACTIONS(8359),
    [sym_biginteger_literal] = ACTIONS(8363),
    [sym_table_keyword] = ACTIONS(8361),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(8361),
    [sym_dataset_keyword] = ACTIONS(8361),
    [sym_quoted_identifier] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8363),
    [sym_verbatim_string] = ACTIONS(8363),
    [sym_integer] = ACTIONS(4395),
    [sym_continue_as_identifier] = ACTIONS(8363),
  },
  [STATE(3663)] = {
    [ts_builtin_sym_end] = ACTIONS(7023),
    [anon_sym_POUNDif] = ACTIONS(7023),
    [anon_sym_POUNDIF] = ACTIONS(7023),
    [anon_sym_POUNDIf] = ACTIONS(7023),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7025),
    [anon_sym_tableextension] = ACTIONS(7023),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7023),
    [anon_sym_Tableextension] = ACTIONS(7023),
    [anon_sym_TableExtension] = ACTIONS(7023),
    [anon_sym_tableExtension] = ACTIONS(7023),
    [sym_page_keyword] = ACTIONS(7025),
    [anon_sym_pageextension] = ACTIONS(7023),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7023),
    [anon_sym_Pageextension] = ACTIONS(7023),
    [anon_sym_PageExtension] = ACTIONS(7023),
    [anon_sym_pageExtension] = ACTIONS(7023),
    [anon_sym_codeunit] = ACTIONS(7023),
    [anon_sym_CODEUNIT] = ACTIONS(7023),
    [anon_sym_Codeunit] = ACTIONS(7023),
    [anon_sym_CodeUnit] = ACTIONS(7023),
    [anon_sym_COdeunit] = ACTIONS(7023),
    [anon_sym_codeUnit] = ACTIONS(7023),
    [sym_report_keyword] = ACTIONS(7025),
    [anon_sym_reportextension] = ACTIONS(7023),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7023),
    [anon_sym_Reportextension] = ACTIONS(7023),
    [anon_sym_ReportExtension] = ACTIONS(7023),
    [anon_sym_reportExtension] = ACTIONS(7023),
    [sym_query_keyword] = ACTIONS(7023),
    [anon_sym_xmlport] = ACTIONS(7023),
    [anon_sym_XMLPORT] = ACTIONS(7023),
    [anon_sym_Xmlport] = ACTIONS(7023),
    [anon_sym_XMLport] = ACTIONS(7023),
    [anon_sym_XMLPort] = ACTIONS(7023),
    [anon_sym_XmlPort] = ACTIONS(7023),
    [anon_sym_enum] = ACTIONS(7025),
    [anon_sym_ENUM] = ACTIONS(7025),
    [anon_sym_Enum] = ACTIONS(7025),
    [anon_sym_eNUM] = ACTIONS(7023),
    [anon_sym_eNum] = ACTIONS(7023),
    [anon_sym_ENum] = ACTIONS(7023),
    [anon_sym_enumextension] = ACTIONS(7023),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7023),
    [anon_sym_Enumextension] = ACTIONS(7023),
    [anon_sym_EnumExtension] = ACTIONS(7023),
    [anon_sym_enumExtension] = ACTIONS(7023),
    [sym_interface_keyword] = ACTIONS(7023),
    [anon_sym_controladdin] = ACTIONS(7023),
    [anon_sym_CONTROLADDIN] = ACTIONS(7023),
    [anon_sym_Controladdin] = ACTIONS(7023),
    [anon_sym_ControlAddIn] = ACTIONS(7023),
    [anon_sym_ControlAddin] = ACTIONS(7023),
    [anon_sym_controlAddIn] = ACTIONS(7023),
    [anon_sym_controlAddin] = ACTIONS(7023),
    [anon_sym_dotnet] = ACTIONS(7023),
    [anon_sym_DOTNET] = ACTIONS(7023),
    [anon_sym_Dotnet] = ACTIONS(7023),
    [anon_sym_DotNet] = ACTIONS(7023),
    [anon_sym_dotNet] = ACTIONS(7023),
    [sym_profile_keyword] = ACTIONS(7025),
    [anon_sym_profileextension] = ACTIONS(7023),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7023),
    [anon_sym_Profileextension] = ACTIONS(7023),
    [anon_sym_ProfileExtension] = ACTIONS(7023),
    [anon_sym_profileExtension] = ACTIONS(7023),
    [anon_sym_permissionset] = ACTIONS(7025),
    [anon_sym_PERMISSIONSET] = ACTIONS(7025),
    [anon_sym_Permissionset] = ACTIONS(7025),
    [anon_sym_PermissionSet] = ACTIONS(7025),
    [anon_sym_permissionSet] = ACTIONS(7025),
    [anon_sym_permissionsetextension] = ACTIONS(7023),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7023),
    [anon_sym_Permissionsetextension] = ACTIONS(7023),
    [anon_sym_PermissionSetExtension] = ACTIONS(7023),
    [anon_sym_permissionSetExtension] = ACTIONS(7023),
    [sym_entitlement_keyword] = ACTIONS(7023),
    [anon_sym_pagecustomization] = ACTIONS(7023),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7023),
    [anon_sym_Pagecustomization] = ACTIONS(7023),
    [anon_sym_PageCustomization] = ACTIONS(7023),
    [anon_sym_pageCustomization] = ACTIONS(7023),
    [sym_using_keyword] = ACTIONS(7023),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7023),
  },
  [STATE(3664)] = {
    [ts_builtin_sym_end] = ACTIONS(6943),
    [anon_sym_POUNDif] = ACTIONS(6943),
    [anon_sym_POUNDIF] = ACTIONS(6943),
    [anon_sym_POUNDIf] = ACTIONS(6943),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6945),
    [anon_sym_tableextension] = ACTIONS(6943),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6943),
    [anon_sym_Tableextension] = ACTIONS(6943),
    [anon_sym_TableExtension] = ACTIONS(6943),
    [anon_sym_tableExtension] = ACTIONS(6943),
    [sym_page_keyword] = ACTIONS(6945),
    [anon_sym_pageextension] = ACTIONS(6943),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6943),
    [anon_sym_Pageextension] = ACTIONS(6943),
    [anon_sym_PageExtension] = ACTIONS(6943),
    [anon_sym_pageExtension] = ACTIONS(6943),
    [anon_sym_codeunit] = ACTIONS(6943),
    [anon_sym_CODEUNIT] = ACTIONS(6943),
    [anon_sym_Codeunit] = ACTIONS(6943),
    [anon_sym_CodeUnit] = ACTIONS(6943),
    [anon_sym_COdeunit] = ACTIONS(6943),
    [anon_sym_codeUnit] = ACTIONS(6943),
    [sym_report_keyword] = ACTIONS(6945),
    [anon_sym_reportextension] = ACTIONS(6943),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6943),
    [anon_sym_Reportextension] = ACTIONS(6943),
    [anon_sym_ReportExtension] = ACTIONS(6943),
    [anon_sym_reportExtension] = ACTIONS(6943),
    [sym_query_keyword] = ACTIONS(6943),
    [anon_sym_xmlport] = ACTIONS(6943),
    [anon_sym_XMLPORT] = ACTIONS(6943),
    [anon_sym_Xmlport] = ACTIONS(6943),
    [anon_sym_XMLport] = ACTIONS(6943),
    [anon_sym_XMLPort] = ACTIONS(6943),
    [anon_sym_XmlPort] = ACTIONS(6943),
    [anon_sym_enum] = ACTIONS(6945),
    [anon_sym_ENUM] = ACTIONS(6945),
    [anon_sym_Enum] = ACTIONS(6945),
    [anon_sym_eNUM] = ACTIONS(6943),
    [anon_sym_eNum] = ACTIONS(6943),
    [anon_sym_ENum] = ACTIONS(6943),
    [anon_sym_enumextension] = ACTIONS(6943),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6943),
    [anon_sym_Enumextension] = ACTIONS(6943),
    [anon_sym_EnumExtension] = ACTIONS(6943),
    [anon_sym_enumExtension] = ACTIONS(6943),
    [sym_interface_keyword] = ACTIONS(6943),
    [anon_sym_controladdin] = ACTIONS(6943),
    [anon_sym_CONTROLADDIN] = ACTIONS(6943),
    [anon_sym_Controladdin] = ACTIONS(6943),
    [anon_sym_ControlAddIn] = ACTIONS(6943),
    [anon_sym_ControlAddin] = ACTIONS(6943),
    [anon_sym_controlAddIn] = ACTIONS(6943),
    [anon_sym_controlAddin] = ACTIONS(6943),
    [anon_sym_dotnet] = ACTIONS(6943),
    [anon_sym_DOTNET] = ACTIONS(6943),
    [anon_sym_Dotnet] = ACTIONS(6943),
    [anon_sym_DotNet] = ACTIONS(6943),
    [anon_sym_dotNet] = ACTIONS(6943),
    [sym_profile_keyword] = ACTIONS(6945),
    [anon_sym_profileextension] = ACTIONS(6943),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6943),
    [anon_sym_Profileextension] = ACTIONS(6943),
    [anon_sym_ProfileExtension] = ACTIONS(6943),
    [anon_sym_profileExtension] = ACTIONS(6943),
    [anon_sym_permissionset] = ACTIONS(6945),
    [anon_sym_PERMISSIONSET] = ACTIONS(6945),
    [anon_sym_Permissionset] = ACTIONS(6945),
    [anon_sym_PermissionSet] = ACTIONS(6945),
    [anon_sym_permissionSet] = ACTIONS(6945),
    [anon_sym_permissionsetextension] = ACTIONS(6943),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6943),
    [anon_sym_Permissionsetextension] = ACTIONS(6943),
    [anon_sym_PermissionSetExtension] = ACTIONS(6943),
    [anon_sym_permissionSetExtension] = ACTIONS(6943),
    [sym_entitlement_keyword] = ACTIONS(6943),
    [anon_sym_pagecustomization] = ACTIONS(6943),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6943),
    [anon_sym_Pagecustomization] = ACTIONS(6943),
    [anon_sym_PageCustomization] = ACTIONS(6943),
    [anon_sym_pageCustomization] = ACTIONS(6943),
    [sym_using_keyword] = ACTIONS(6943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6943),
  },
  [STATE(3665)] = {
    [ts_builtin_sym_end] = ACTIONS(7027),
    [anon_sym_POUNDif] = ACTIONS(7027),
    [anon_sym_POUNDIF] = ACTIONS(7027),
    [anon_sym_POUNDIf] = ACTIONS(7027),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7029),
    [anon_sym_tableextension] = ACTIONS(7027),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7027),
    [anon_sym_Tableextension] = ACTIONS(7027),
    [anon_sym_TableExtension] = ACTIONS(7027),
    [anon_sym_tableExtension] = ACTIONS(7027),
    [sym_page_keyword] = ACTIONS(7029),
    [anon_sym_pageextension] = ACTIONS(7027),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7027),
    [anon_sym_Pageextension] = ACTIONS(7027),
    [anon_sym_PageExtension] = ACTIONS(7027),
    [anon_sym_pageExtension] = ACTIONS(7027),
    [anon_sym_codeunit] = ACTIONS(7027),
    [anon_sym_CODEUNIT] = ACTIONS(7027),
    [anon_sym_Codeunit] = ACTIONS(7027),
    [anon_sym_CodeUnit] = ACTIONS(7027),
    [anon_sym_COdeunit] = ACTIONS(7027),
    [anon_sym_codeUnit] = ACTIONS(7027),
    [sym_report_keyword] = ACTIONS(7029),
    [anon_sym_reportextension] = ACTIONS(7027),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7027),
    [anon_sym_Reportextension] = ACTIONS(7027),
    [anon_sym_ReportExtension] = ACTIONS(7027),
    [anon_sym_reportExtension] = ACTIONS(7027),
    [sym_query_keyword] = ACTIONS(7027),
    [anon_sym_xmlport] = ACTIONS(7027),
    [anon_sym_XMLPORT] = ACTIONS(7027),
    [anon_sym_Xmlport] = ACTIONS(7027),
    [anon_sym_XMLport] = ACTIONS(7027),
    [anon_sym_XMLPort] = ACTIONS(7027),
    [anon_sym_XmlPort] = ACTIONS(7027),
    [anon_sym_enum] = ACTIONS(7029),
    [anon_sym_ENUM] = ACTIONS(7029),
    [anon_sym_Enum] = ACTIONS(7029),
    [anon_sym_eNUM] = ACTIONS(7027),
    [anon_sym_eNum] = ACTIONS(7027),
    [anon_sym_ENum] = ACTIONS(7027),
    [anon_sym_enumextension] = ACTIONS(7027),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7027),
    [anon_sym_Enumextension] = ACTIONS(7027),
    [anon_sym_EnumExtension] = ACTIONS(7027),
    [anon_sym_enumExtension] = ACTIONS(7027),
    [sym_interface_keyword] = ACTIONS(7027),
    [anon_sym_controladdin] = ACTIONS(7027),
    [anon_sym_CONTROLADDIN] = ACTIONS(7027),
    [anon_sym_Controladdin] = ACTIONS(7027),
    [anon_sym_ControlAddIn] = ACTIONS(7027),
    [anon_sym_ControlAddin] = ACTIONS(7027),
    [anon_sym_controlAddIn] = ACTIONS(7027),
    [anon_sym_controlAddin] = ACTIONS(7027),
    [anon_sym_dotnet] = ACTIONS(7027),
    [anon_sym_DOTNET] = ACTIONS(7027),
    [anon_sym_Dotnet] = ACTIONS(7027),
    [anon_sym_DotNet] = ACTIONS(7027),
    [anon_sym_dotNet] = ACTIONS(7027),
    [sym_profile_keyword] = ACTIONS(7029),
    [anon_sym_profileextension] = ACTIONS(7027),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7027),
    [anon_sym_Profileextension] = ACTIONS(7027),
    [anon_sym_ProfileExtension] = ACTIONS(7027),
    [anon_sym_profileExtension] = ACTIONS(7027),
    [anon_sym_permissionset] = ACTIONS(7029),
    [anon_sym_PERMISSIONSET] = ACTIONS(7029),
    [anon_sym_Permissionset] = ACTIONS(7029),
    [anon_sym_PermissionSet] = ACTIONS(7029),
    [anon_sym_permissionSet] = ACTIONS(7029),
    [anon_sym_permissionsetextension] = ACTIONS(7027),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7027),
    [anon_sym_Permissionsetextension] = ACTIONS(7027),
    [anon_sym_PermissionSetExtension] = ACTIONS(7027),
    [anon_sym_permissionSetExtension] = ACTIONS(7027),
    [sym_entitlement_keyword] = ACTIONS(7027),
    [anon_sym_pagecustomization] = ACTIONS(7027),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7027),
    [anon_sym_Pagecustomization] = ACTIONS(7027),
    [anon_sym_PageCustomization] = ACTIONS(7027),
    [anon_sym_pageCustomization] = ACTIONS(7027),
    [sym_using_keyword] = ACTIONS(7027),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7027),
  },
  [STATE(3666)] = {
    [ts_builtin_sym_end] = ACTIONS(7031),
    [anon_sym_POUNDif] = ACTIONS(7031),
    [anon_sym_POUNDIF] = ACTIONS(7031),
    [anon_sym_POUNDIf] = ACTIONS(7031),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7033),
    [anon_sym_tableextension] = ACTIONS(7031),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7031),
    [anon_sym_Tableextension] = ACTIONS(7031),
    [anon_sym_TableExtension] = ACTIONS(7031),
    [anon_sym_tableExtension] = ACTIONS(7031),
    [sym_page_keyword] = ACTIONS(7033),
    [anon_sym_pageextension] = ACTIONS(7031),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7031),
    [anon_sym_Pageextension] = ACTIONS(7031),
    [anon_sym_PageExtension] = ACTIONS(7031),
    [anon_sym_pageExtension] = ACTIONS(7031),
    [anon_sym_codeunit] = ACTIONS(7031),
    [anon_sym_CODEUNIT] = ACTIONS(7031),
    [anon_sym_Codeunit] = ACTIONS(7031),
    [anon_sym_CodeUnit] = ACTIONS(7031),
    [anon_sym_COdeunit] = ACTIONS(7031),
    [anon_sym_codeUnit] = ACTIONS(7031),
    [sym_report_keyword] = ACTIONS(7033),
    [anon_sym_reportextension] = ACTIONS(7031),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7031),
    [anon_sym_Reportextension] = ACTIONS(7031),
    [anon_sym_ReportExtension] = ACTIONS(7031),
    [anon_sym_reportExtension] = ACTIONS(7031),
    [sym_query_keyword] = ACTIONS(7031),
    [anon_sym_xmlport] = ACTIONS(7031),
    [anon_sym_XMLPORT] = ACTIONS(7031),
    [anon_sym_Xmlport] = ACTIONS(7031),
    [anon_sym_XMLport] = ACTIONS(7031),
    [anon_sym_XMLPort] = ACTIONS(7031),
    [anon_sym_XmlPort] = ACTIONS(7031),
    [anon_sym_enum] = ACTIONS(7033),
    [anon_sym_ENUM] = ACTIONS(7033),
    [anon_sym_Enum] = ACTIONS(7033),
    [anon_sym_eNUM] = ACTIONS(7031),
    [anon_sym_eNum] = ACTIONS(7031),
    [anon_sym_ENum] = ACTIONS(7031),
    [anon_sym_enumextension] = ACTIONS(7031),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7031),
    [anon_sym_Enumextension] = ACTIONS(7031),
    [anon_sym_EnumExtension] = ACTIONS(7031),
    [anon_sym_enumExtension] = ACTIONS(7031),
    [sym_interface_keyword] = ACTIONS(7031),
    [anon_sym_controladdin] = ACTIONS(7031),
    [anon_sym_CONTROLADDIN] = ACTIONS(7031),
    [anon_sym_Controladdin] = ACTIONS(7031),
    [anon_sym_ControlAddIn] = ACTIONS(7031),
    [anon_sym_ControlAddin] = ACTIONS(7031),
    [anon_sym_controlAddIn] = ACTIONS(7031),
    [anon_sym_controlAddin] = ACTIONS(7031),
    [anon_sym_dotnet] = ACTIONS(7031),
    [anon_sym_DOTNET] = ACTIONS(7031),
    [anon_sym_Dotnet] = ACTIONS(7031),
    [anon_sym_DotNet] = ACTIONS(7031),
    [anon_sym_dotNet] = ACTIONS(7031),
    [sym_profile_keyword] = ACTIONS(7033),
    [anon_sym_profileextension] = ACTIONS(7031),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7031),
    [anon_sym_Profileextension] = ACTIONS(7031),
    [anon_sym_ProfileExtension] = ACTIONS(7031),
    [anon_sym_profileExtension] = ACTIONS(7031),
    [anon_sym_permissionset] = ACTIONS(7033),
    [anon_sym_PERMISSIONSET] = ACTIONS(7033),
    [anon_sym_Permissionset] = ACTIONS(7033),
    [anon_sym_PermissionSet] = ACTIONS(7033),
    [anon_sym_permissionSet] = ACTIONS(7033),
    [anon_sym_permissionsetextension] = ACTIONS(7031),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7031),
    [anon_sym_Permissionsetextension] = ACTIONS(7031),
    [anon_sym_PermissionSetExtension] = ACTIONS(7031),
    [anon_sym_permissionSetExtension] = ACTIONS(7031),
    [sym_entitlement_keyword] = ACTIONS(7031),
    [anon_sym_pagecustomization] = ACTIONS(7031),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7031),
    [anon_sym_Pagecustomization] = ACTIONS(7031),
    [anon_sym_PageCustomization] = ACTIONS(7031),
    [anon_sym_pageCustomization] = ACTIONS(7031),
    [sym_using_keyword] = ACTIONS(7031),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7031),
  },
  [STATE(3667)] = {
    [ts_builtin_sym_end] = ACTIONS(7035),
    [anon_sym_POUNDif] = ACTIONS(7035),
    [anon_sym_POUNDIF] = ACTIONS(7035),
    [anon_sym_POUNDIf] = ACTIONS(7035),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7037),
    [anon_sym_tableextension] = ACTIONS(7035),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7035),
    [anon_sym_Tableextension] = ACTIONS(7035),
    [anon_sym_TableExtension] = ACTIONS(7035),
    [anon_sym_tableExtension] = ACTIONS(7035),
    [sym_page_keyword] = ACTIONS(7037),
    [anon_sym_pageextension] = ACTIONS(7035),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7035),
    [anon_sym_Pageextension] = ACTIONS(7035),
    [anon_sym_PageExtension] = ACTIONS(7035),
    [anon_sym_pageExtension] = ACTIONS(7035),
    [anon_sym_codeunit] = ACTIONS(7035),
    [anon_sym_CODEUNIT] = ACTIONS(7035),
    [anon_sym_Codeunit] = ACTIONS(7035),
    [anon_sym_CodeUnit] = ACTIONS(7035),
    [anon_sym_COdeunit] = ACTIONS(7035),
    [anon_sym_codeUnit] = ACTIONS(7035),
    [sym_report_keyword] = ACTIONS(7037),
    [anon_sym_reportextension] = ACTIONS(7035),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7035),
    [anon_sym_Reportextension] = ACTIONS(7035),
    [anon_sym_ReportExtension] = ACTIONS(7035),
    [anon_sym_reportExtension] = ACTIONS(7035),
    [sym_query_keyword] = ACTIONS(7035),
    [anon_sym_xmlport] = ACTIONS(7035),
    [anon_sym_XMLPORT] = ACTIONS(7035),
    [anon_sym_Xmlport] = ACTIONS(7035),
    [anon_sym_XMLport] = ACTIONS(7035),
    [anon_sym_XMLPort] = ACTIONS(7035),
    [anon_sym_XmlPort] = ACTIONS(7035),
    [anon_sym_enum] = ACTIONS(7037),
    [anon_sym_ENUM] = ACTIONS(7037),
    [anon_sym_Enum] = ACTIONS(7037),
    [anon_sym_eNUM] = ACTIONS(7035),
    [anon_sym_eNum] = ACTIONS(7035),
    [anon_sym_ENum] = ACTIONS(7035),
    [anon_sym_enumextension] = ACTIONS(7035),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7035),
    [anon_sym_Enumextension] = ACTIONS(7035),
    [anon_sym_EnumExtension] = ACTIONS(7035),
    [anon_sym_enumExtension] = ACTIONS(7035),
    [sym_interface_keyword] = ACTIONS(7035),
    [anon_sym_controladdin] = ACTIONS(7035),
    [anon_sym_CONTROLADDIN] = ACTIONS(7035),
    [anon_sym_Controladdin] = ACTIONS(7035),
    [anon_sym_ControlAddIn] = ACTIONS(7035),
    [anon_sym_ControlAddin] = ACTIONS(7035),
    [anon_sym_controlAddIn] = ACTIONS(7035),
    [anon_sym_controlAddin] = ACTIONS(7035),
    [anon_sym_dotnet] = ACTIONS(7035),
    [anon_sym_DOTNET] = ACTIONS(7035),
    [anon_sym_Dotnet] = ACTIONS(7035),
    [anon_sym_DotNet] = ACTIONS(7035),
    [anon_sym_dotNet] = ACTIONS(7035),
    [sym_profile_keyword] = ACTIONS(7037),
    [anon_sym_profileextension] = ACTIONS(7035),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7035),
    [anon_sym_Profileextension] = ACTIONS(7035),
    [anon_sym_ProfileExtension] = ACTIONS(7035),
    [anon_sym_profileExtension] = ACTIONS(7035),
    [anon_sym_permissionset] = ACTIONS(7037),
    [anon_sym_PERMISSIONSET] = ACTIONS(7037),
    [anon_sym_Permissionset] = ACTIONS(7037),
    [anon_sym_PermissionSet] = ACTIONS(7037),
    [anon_sym_permissionSet] = ACTIONS(7037),
    [anon_sym_permissionsetextension] = ACTIONS(7035),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7035),
    [anon_sym_Permissionsetextension] = ACTIONS(7035),
    [anon_sym_PermissionSetExtension] = ACTIONS(7035),
    [anon_sym_permissionSetExtension] = ACTIONS(7035),
    [sym_entitlement_keyword] = ACTIONS(7035),
    [anon_sym_pagecustomization] = ACTIONS(7035),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7035),
    [anon_sym_Pagecustomization] = ACTIONS(7035),
    [anon_sym_PageCustomization] = ACTIONS(7035),
    [anon_sym_pageCustomization] = ACTIONS(7035),
    [sym_using_keyword] = ACTIONS(7035),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7035),
  },
  [STATE(3668)] = {
    [ts_builtin_sym_end] = ACTIONS(7039),
    [anon_sym_POUNDif] = ACTIONS(7039),
    [anon_sym_POUNDIF] = ACTIONS(7039),
    [anon_sym_POUNDIf] = ACTIONS(7039),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7041),
    [anon_sym_tableextension] = ACTIONS(7039),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7039),
    [anon_sym_Tableextension] = ACTIONS(7039),
    [anon_sym_TableExtension] = ACTIONS(7039),
    [anon_sym_tableExtension] = ACTIONS(7039),
    [sym_page_keyword] = ACTIONS(7041),
    [anon_sym_pageextension] = ACTIONS(7039),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7039),
    [anon_sym_Pageextension] = ACTIONS(7039),
    [anon_sym_PageExtension] = ACTIONS(7039),
    [anon_sym_pageExtension] = ACTIONS(7039),
    [anon_sym_codeunit] = ACTIONS(7039),
    [anon_sym_CODEUNIT] = ACTIONS(7039),
    [anon_sym_Codeunit] = ACTIONS(7039),
    [anon_sym_CodeUnit] = ACTIONS(7039),
    [anon_sym_COdeunit] = ACTIONS(7039),
    [anon_sym_codeUnit] = ACTIONS(7039),
    [sym_report_keyword] = ACTIONS(7041),
    [anon_sym_reportextension] = ACTIONS(7039),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7039),
    [anon_sym_Reportextension] = ACTIONS(7039),
    [anon_sym_ReportExtension] = ACTIONS(7039),
    [anon_sym_reportExtension] = ACTIONS(7039),
    [sym_query_keyword] = ACTIONS(7039),
    [anon_sym_xmlport] = ACTIONS(7039),
    [anon_sym_XMLPORT] = ACTIONS(7039),
    [anon_sym_Xmlport] = ACTIONS(7039),
    [anon_sym_XMLport] = ACTIONS(7039),
    [anon_sym_XMLPort] = ACTIONS(7039),
    [anon_sym_XmlPort] = ACTIONS(7039),
    [anon_sym_enum] = ACTIONS(7041),
    [anon_sym_ENUM] = ACTIONS(7041),
    [anon_sym_Enum] = ACTIONS(7041),
    [anon_sym_eNUM] = ACTIONS(7039),
    [anon_sym_eNum] = ACTIONS(7039),
    [anon_sym_ENum] = ACTIONS(7039),
    [anon_sym_enumextension] = ACTIONS(7039),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7039),
    [anon_sym_Enumextension] = ACTIONS(7039),
    [anon_sym_EnumExtension] = ACTIONS(7039),
    [anon_sym_enumExtension] = ACTIONS(7039),
    [sym_interface_keyword] = ACTIONS(7039),
    [anon_sym_controladdin] = ACTIONS(7039),
    [anon_sym_CONTROLADDIN] = ACTIONS(7039),
    [anon_sym_Controladdin] = ACTIONS(7039),
    [anon_sym_ControlAddIn] = ACTIONS(7039),
    [anon_sym_ControlAddin] = ACTIONS(7039),
    [anon_sym_controlAddIn] = ACTIONS(7039),
    [anon_sym_controlAddin] = ACTIONS(7039),
    [anon_sym_dotnet] = ACTIONS(7039),
    [anon_sym_DOTNET] = ACTIONS(7039),
    [anon_sym_Dotnet] = ACTIONS(7039),
    [anon_sym_DotNet] = ACTIONS(7039),
    [anon_sym_dotNet] = ACTIONS(7039),
    [sym_profile_keyword] = ACTIONS(7041),
    [anon_sym_profileextension] = ACTIONS(7039),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7039),
    [anon_sym_Profileextension] = ACTIONS(7039),
    [anon_sym_ProfileExtension] = ACTIONS(7039),
    [anon_sym_profileExtension] = ACTIONS(7039),
    [anon_sym_permissionset] = ACTIONS(7041),
    [anon_sym_PERMISSIONSET] = ACTIONS(7041),
    [anon_sym_Permissionset] = ACTIONS(7041),
    [anon_sym_PermissionSet] = ACTIONS(7041),
    [anon_sym_permissionSet] = ACTIONS(7041),
    [anon_sym_permissionsetextension] = ACTIONS(7039),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7039),
    [anon_sym_Permissionsetextension] = ACTIONS(7039),
    [anon_sym_PermissionSetExtension] = ACTIONS(7039),
    [anon_sym_permissionSetExtension] = ACTIONS(7039),
    [sym_entitlement_keyword] = ACTIONS(7039),
    [anon_sym_pagecustomization] = ACTIONS(7039),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7039),
    [anon_sym_Pagecustomization] = ACTIONS(7039),
    [anon_sym_PageCustomization] = ACTIONS(7039),
    [anon_sym_pageCustomization] = ACTIONS(7039),
    [sym_using_keyword] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7039),
  },
  [STATE(3669)] = {
    [ts_builtin_sym_end] = ACTIONS(7043),
    [anon_sym_POUNDif] = ACTIONS(7043),
    [anon_sym_POUNDIF] = ACTIONS(7043),
    [anon_sym_POUNDIf] = ACTIONS(7043),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7045),
    [anon_sym_tableextension] = ACTIONS(7043),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7043),
    [anon_sym_Tableextension] = ACTIONS(7043),
    [anon_sym_TableExtension] = ACTIONS(7043),
    [anon_sym_tableExtension] = ACTIONS(7043),
    [sym_page_keyword] = ACTIONS(7045),
    [anon_sym_pageextension] = ACTIONS(7043),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7043),
    [anon_sym_Pageextension] = ACTIONS(7043),
    [anon_sym_PageExtension] = ACTIONS(7043),
    [anon_sym_pageExtension] = ACTIONS(7043),
    [anon_sym_codeunit] = ACTIONS(7043),
    [anon_sym_CODEUNIT] = ACTIONS(7043),
    [anon_sym_Codeunit] = ACTIONS(7043),
    [anon_sym_CodeUnit] = ACTIONS(7043),
    [anon_sym_COdeunit] = ACTIONS(7043),
    [anon_sym_codeUnit] = ACTIONS(7043),
    [sym_report_keyword] = ACTIONS(7045),
    [anon_sym_reportextension] = ACTIONS(7043),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7043),
    [anon_sym_Reportextension] = ACTIONS(7043),
    [anon_sym_ReportExtension] = ACTIONS(7043),
    [anon_sym_reportExtension] = ACTIONS(7043),
    [sym_query_keyword] = ACTIONS(7043),
    [anon_sym_xmlport] = ACTIONS(7043),
    [anon_sym_XMLPORT] = ACTIONS(7043),
    [anon_sym_Xmlport] = ACTIONS(7043),
    [anon_sym_XMLport] = ACTIONS(7043),
    [anon_sym_XMLPort] = ACTIONS(7043),
    [anon_sym_XmlPort] = ACTIONS(7043),
    [anon_sym_enum] = ACTIONS(7045),
    [anon_sym_ENUM] = ACTIONS(7045),
    [anon_sym_Enum] = ACTIONS(7045),
    [anon_sym_eNUM] = ACTIONS(7043),
    [anon_sym_eNum] = ACTIONS(7043),
    [anon_sym_ENum] = ACTIONS(7043),
    [anon_sym_enumextension] = ACTIONS(7043),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7043),
    [anon_sym_Enumextension] = ACTIONS(7043),
    [anon_sym_EnumExtension] = ACTIONS(7043),
    [anon_sym_enumExtension] = ACTIONS(7043),
    [sym_interface_keyword] = ACTIONS(7043),
    [anon_sym_controladdin] = ACTIONS(7043),
    [anon_sym_CONTROLADDIN] = ACTIONS(7043),
    [anon_sym_Controladdin] = ACTIONS(7043),
    [anon_sym_ControlAddIn] = ACTIONS(7043),
    [anon_sym_ControlAddin] = ACTIONS(7043),
    [anon_sym_controlAddIn] = ACTIONS(7043),
    [anon_sym_controlAddin] = ACTIONS(7043),
    [anon_sym_dotnet] = ACTIONS(7043),
    [anon_sym_DOTNET] = ACTIONS(7043),
    [anon_sym_Dotnet] = ACTIONS(7043),
    [anon_sym_DotNet] = ACTIONS(7043),
    [anon_sym_dotNet] = ACTIONS(7043),
    [sym_profile_keyword] = ACTIONS(7045),
    [anon_sym_profileextension] = ACTIONS(7043),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7043),
    [anon_sym_Profileextension] = ACTIONS(7043),
    [anon_sym_ProfileExtension] = ACTIONS(7043),
    [anon_sym_profileExtension] = ACTIONS(7043),
    [anon_sym_permissionset] = ACTIONS(7045),
    [anon_sym_PERMISSIONSET] = ACTIONS(7045),
    [anon_sym_Permissionset] = ACTIONS(7045),
    [anon_sym_PermissionSet] = ACTIONS(7045),
    [anon_sym_permissionSet] = ACTIONS(7045),
    [anon_sym_permissionsetextension] = ACTIONS(7043),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7043),
    [anon_sym_Permissionsetextension] = ACTIONS(7043),
    [anon_sym_PermissionSetExtension] = ACTIONS(7043),
    [anon_sym_permissionSetExtension] = ACTIONS(7043),
    [sym_entitlement_keyword] = ACTIONS(7043),
    [anon_sym_pagecustomization] = ACTIONS(7043),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7043),
    [anon_sym_Pagecustomization] = ACTIONS(7043),
    [anon_sym_PageCustomization] = ACTIONS(7043),
    [anon_sym_pageCustomization] = ACTIONS(7043),
    [sym_using_keyword] = ACTIONS(7043),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7043),
  },
  [STATE(3670)] = {
    [ts_builtin_sym_end] = ACTIONS(7047),
    [anon_sym_POUNDif] = ACTIONS(7047),
    [anon_sym_POUNDIF] = ACTIONS(7047),
    [anon_sym_POUNDIf] = ACTIONS(7047),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7049),
    [anon_sym_tableextension] = ACTIONS(7047),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7047),
    [anon_sym_Tableextension] = ACTIONS(7047),
    [anon_sym_TableExtension] = ACTIONS(7047),
    [anon_sym_tableExtension] = ACTIONS(7047),
    [sym_page_keyword] = ACTIONS(7049),
    [anon_sym_pageextension] = ACTIONS(7047),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7047),
    [anon_sym_Pageextension] = ACTIONS(7047),
    [anon_sym_PageExtension] = ACTIONS(7047),
    [anon_sym_pageExtension] = ACTIONS(7047),
    [anon_sym_codeunit] = ACTIONS(7047),
    [anon_sym_CODEUNIT] = ACTIONS(7047),
    [anon_sym_Codeunit] = ACTIONS(7047),
    [anon_sym_CodeUnit] = ACTIONS(7047),
    [anon_sym_COdeunit] = ACTIONS(7047),
    [anon_sym_codeUnit] = ACTIONS(7047),
    [sym_report_keyword] = ACTIONS(7049),
    [anon_sym_reportextension] = ACTIONS(7047),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7047),
    [anon_sym_Reportextension] = ACTIONS(7047),
    [anon_sym_ReportExtension] = ACTIONS(7047),
    [anon_sym_reportExtension] = ACTIONS(7047),
    [sym_query_keyword] = ACTIONS(7047),
    [anon_sym_xmlport] = ACTIONS(7047),
    [anon_sym_XMLPORT] = ACTIONS(7047),
    [anon_sym_Xmlport] = ACTIONS(7047),
    [anon_sym_XMLport] = ACTIONS(7047),
    [anon_sym_XMLPort] = ACTIONS(7047),
    [anon_sym_XmlPort] = ACTIONS(7047),
    [anon_sym_enum] = ACTIONS(7049),
    [anon_sym_ENUM] = ACTIONS(7049),
    [anon_sym_Enum] = ACTIONS(7049),
    [anon_sym_eNUM] = ACTIONS(7047),
    [anon_sym_eNum] = ACTIONS(7047),
    [anon_sym_ENum] = ACTIONS(7047),
    [anon_sym_enumextension] = ACTIONS(7047),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7047),
    [anon_sym_Enumextension] = ACTIONS(7047),
    [anon_sym_EnumExtension] = ACTIONS(7047),
    [anon_sym_enumExtension] = ACTIONS(7047),
    [sym_interface_keyword] = ACTIONS(7047),
    [anon_sym_controladdin] = ACTIONS(7047),
    [anon_sym_CONTROLADDIN] = ACTIONS(7047),
    [anon_sym_Controladdin] = ACTIONS(7047),
    [anon_sym_ControlAddIn] = ACTIONS(7047),
    [anon_sym_ControlAddin] = ACTIONS(7047),
    [anon_sym_controlAddIn] = ACTIONS(7047),
    [anon_sym_controlAddin] = ACTIONS(7047),
    [anon_sym_dotnet] = ACTIONS(7047),
    [anon_sym_DOTNET] = ACTIONS(7047),
    [anon_sym_Dotnet] = ACTIONS(7047),
    [anon_sym_DotNet] = ACTIONS(7047),
    [anon_sym_dotNet] = ACTIONS(7047),
    [sym_profile_keyword] = ACTIONS(7049),
    [anon_sym_profileextension] = ACTIONS(7047),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7047),
    [anon_sym_Profileextension] = ACTIONS(7047),
    [anon_sym_ProfileExtension] = ACTIONS(7047),
    [anon_sym_profileExtension] = ACTIONS(7047),
    [anon_sym_permissionset] = ACTIONS(7049),
    [anon_sym_PERMISSIONSET] = ACTIONS(7049),
    [anon_sym_Permissionset] = ACTIONS(7049),
    [anon_sym_PermissionSet] = ACTIONS(7049),
    [anon_sym_permissionSet] = ACTIONS(7049),
    [anon_sym_permissionsetextension] = ACTIONS(7047),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7047),
    [anon_sym_Permissionsetextension] = ACTIONS(7047),
    [anon_sym_PermissionSetExtension] = ACTIONS(7047),
    [anon_sym_permissionSetExtension] = ACTIONS(7047),
    [sym_entitlement_keyword] = ACTIONS(7047),
    [anon_sym_pagecustomization] = ACTIONS(7047),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7047),
    [anon_sym_Pagecustomization] = ACTIONS(7047),
    [anon_sym_PageCustomization] = ACTIONS(7047),
    [anon_sym_pageCustomization] = ACTIONS(7047),
    [sym_using_keyword] = ACTIONS(7047),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7047),
  },
  [STATE(3671)] = {
    [ts_builtin_sym_end] = ACTIONS(7051),
    [anon_sym_POUNDif] = ACTIONS(7051),
    [anon_sym_POUNDIF] = ACTIONS(7051),
    [anon_sym_POUNDIf] = ACTIONS(7051),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7053),
    [anon_sym_tableextension] = ACTIONS(7051),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7051),
    [anon_sym_Tableextension] = ACTIONS(7051),
    [anon_sym_TableExtension] = ACTIONS(7051),
    [anon_sym_tableExtension] = ACTIONS(7051),
    [sym_page_keyword] = ACTIONS(7053),
    [anon_sym_pageextension] = ACTIONS(7051),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7051),
    [anon_sym_Pageextension] = ACTIONS(7051),
    [anon_sym_PageExtension] = ACTIONS(7051),
    [anon_sym_pageExtension] = ACTIONS(7051),
    [anon_sym_codeunit] = ACTIONS(7051),
    [anon_sym_CODEUNIT] = ACTIONS(7051),
    [anon_sym_Codeunit] = ACTIONS(7051),
    [anon_sym_CodeUnit] = ACTIONS(7051),
    [anon_sym_COdeunit] = ACTIONS(7051),
    [anon_sym_codeUnit] = ACTIONS(7051),
    [sym_report_keyword] = ACTIONS(7053),
    [anon_sym_reportextension] = ACTIONS(7051),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7051),
    [anon_sym_Reportextension] = ACTIONS(7051),
    [anon_sym_ReportExtension] = ACTIONS(7051),
    [anon_sym_reportExtension] = ACTIONS(7051),
    [sym_query_keyword] = ACTIONS(7051),
    [anon_sym_xmlport] = ACTIONS(7051),
    [anon_sym_XMLPORT] = ACTIONS(7051),
    [anon_sym_Xmlport] = ACTIONS(7051),
    [anon_sym_XMLport] = ACTIONS(7051),
    [anon_sym_XMLPort] = ACTIONS(7051),
    [anon_sym_XmlPort] = ACTIONS(7051),
    [anon_sym_enum] = ACTIONS(7053),
    [anon_sym_ENUM] = ACTIONS(7053),
    [anon_sym_Enum] = ACTIONS(7053),
    [anon_sym_eNUM] = ACTIONS(7051),
    [anon_sym_eNum] = ACTIONS(7051),
    [anon_sym_ENum] = ACTIONS(7051),
    [anon_sym_enumextension] = ACTIONS(7051),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7051),
    [anon_sym_Enumextension] = ACTIONS(7051),
    [anon_sym_EnumExtension] = ACTIONS(7051),
    [anon_sym_enumExtension] = ACTIONS(7051),
    [sym_interface_keyword] = ACTIONS(7051),
    [anon_sym_controladdin] = ACTIONS(7051),
    [anon_sym_CONTROLADDIN] = ACTIONS(7051),
    [anon_sym_Controladdin] = ACTIONS(7051),
    [anon_sym_ControlAddIn] = ACTIONS(7051),
    [anon_sym_ControlAddin] = ACTIONS(7051),
    [anon_sym_controlAddIn] = ACTIONS(7051),
    [anon_sym_controlAddin] = ACTIONS(7051),
    [anon_sym_dotnet] = ACTIONS(7051),
    [anon_sym_DOTNET] = ACTIONS(7051),
    [anon_sym_Dotnet] = ACTIONS(7051),
    [anon_sym_DotNet] = ACTIONS(7051),
    [anon_sym_dotNet] = ACTIONS(7051),
    [sym_profile_keyword] = ACTIONS(7053),
    [anon_sym_profileextension] = ACTIONS(7051),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7051),
    [anon_sym_Profileextension] = ACTIONS(7051),
    [anon_sym_ProfileExtension] = ACTIONS(7051),
    [anon_sym_profileExtension] = ACTIONS(7051),
    [anon_sym_permissionset] = ACTIONS(7053),
    [anon_sym_PERMISSIONSET] = ACTIONS(7053),
    [anon_sym_Permissionset] = ACTIONS(7053),
    [anon_sym_PermissionSet] = ACTIONS(7053),
    [anon_sym_permissionSet] = ACTIONS(7053),
    [anon_sym_permissionsetextension] = ACTIONS(7051),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7051),
    [anon_sym_Permissionsetextension] = ACTIONS(7051),
    [anon_sym_PermissionSetExtension] = ACTIONS(7051),
    [anon_sym_permissionSetExtension] = ACTIONS(7051),
    [sym_entitlement_keyword] = ACTIONS(7051),
    [anon_sym_pagecustomization] = ACTIONS(7051),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7051),
    [anon_sym_Pagecustomization] = ACTIONS(7051),
    [anon_sym_PageCustomization] = ACTIONS(7051),
    [anon_sym_pageCustomization] = ACTIONS(7051),
    [sym_using_keyword] = ACTIONS(7051),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7051),
  },
  [STATE(3672)] = {
    [ts_builtin_sym_end] = ACTIONS(6985),
    [anon_sym_POUNDif] = ACTIONS(6985),
    [anon_sym_POUNDIF] = ACTIONS(6985),
    [anon_sym_POUNDIf] = ACTIONS(6985),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6987),
    [anon_sym_tableextension] = ACTIONS(6985),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6985),
    [anon_sym_Tableextension] = ACTIONS(6985),
    [anon_sym_TableExtension] = ACTIONS(6985),
    [anon_sym_tableExtension] = ACTIONS(6985),
    [sym_page_keyword] = ACTIONS(6987),
    [anon_sym_pageextension] = ACTIONS(6985),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6985),
    [anon_sym_Pageextension] = ACTIONS(6985),
    [anon_sym_PageExtension] = ACTIONS(6985),
    [anon_sym_pageExtension] = ACTIONS(6985),
    [anon_sym_codeunit] = ACTIONS(6985),
    [anon_sym_CODEUNIT] = ACTIONS(6985),
    [anon_sym_Codeunit] = ACTIONS(6985),
    [anon_sym_CodeUnit] = ACTIONS(6985),
    [anon_sym_COdeunit] = ACTIONS(6985),
    [anon_sym_codeUnit] = ACTIONS(6985),
    [sym_report_keyword] = ACTIONS(6987),
    [anon_sym_reportextension] = ACTIONS(6985),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6985),
    [anon_sym_Reportextension] = ACTIONS(6985),
    [anon_sym_ReportExtension] = ACTIONS(6985),
    [anon_sym_reportExtension] = ACTIONS(6985),
    [sym_query_keyword] = ACTIONS(6985),
    [anon_sym_xmlport] = ACTIONS(6985),
    [anon_sym_XMLPORT] = ACTIONS(6985),
    [anon_sym_Xmlport] = ACTIONS(6985),
    [anon_sym_XMLport] = ACTIONS(6985),
    [anon_sym_XMLPort] = ACTIONS(6985),
    [anon_sym_XmlPort] = ACTIONS(6985),
    [anon_sym_enum] = ACTIONS(6987),
    [anon_sym_ENUM] = ACTIONS(6987),
    [anon_sym_Enum] = ACTIONS(6987),
    [anon_sym_eNUM] = ACTIONS(6985),
    [anon_sym_eNum] = ACTIONS(6985),
    [anon_sym_ENum] = ACTIONS(6985),
    [anon_sym_enumextension] = ACTIONS(6985),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6985),
    [anon_sym_Enumextension] = ACTIONS(6985),
    [anon_sym_EnumExtension] = ACTIONS(6985),
    [anon_sym_enumExtension] = ACTIONS(6985),
    [sym_interface_keyword] = ACTIONS(6985),
    [anon_sym_controladdin] = ACTIONS(6985),
    [anon_sym_CONTROLADDIN] = ACTIONS(6985),
    [anon_sym_Controladdin] = ACTIONS(6985),
    [anon_sym_ControlAddIn] = ACTIONS(6985),
    [anon_sym_ControlAddin] = ACTIONS(6985),
    [anon_sym_controlAddIn] = ACTIONS(6985),
    [anon_sym_controlAddin] = ACTIONS(6985),
    [anon_sym_dotnet] = ACTIONS(6985),
    [anon_sym_DOTNET] = ACTIONS(6985),
    [anon_sym_Dotnet] = ACTIONS(6985),
    [anon_sym_DotNet] = ACTIONS(6985),
    [anon_sym_dotNet] = ACTIONS(6985),
    [sym_profile_keyword] = ACTIONS(6987),
    [anon_sym_profileextension] = ACTIONS(6985),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6985),
    [anon_sym_Profileextension] = ACTIONS(6985),
    [anon_sym_ProfileExtension] = ACTIONS(6985),
    [anon_sym_profileExtension] = ACTIONS(6985),
    [anon_sym_permissionset] = ACTIONS(6987),
    [anon_sym_PERMISSIONSET] = ACTIONS(6987),
    [anon_sym_Permissionset] = ACTIONS(6987),
    [anon_sym_PermissionSet] = ACTIONS(6987),
    [anon_sym_permissionSet] = ACTIONS(6987),
    [anon_sym_permissionsetextension] = ACTIONS(6985),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6985),
    [anon_sym_Permissionsetextension] = ACTIONS(6985),
    [anon_sym_PermissionSetExtension] = ACTIONS(6985),
    [anon_sym_permissionSetExtension] = ACTIONS(6985),
    [sym_entitlement_keyword] = ACTIONS(6985),
    [anon_sym_pagecustomization] = ACTIONS(6985),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6985),
    [anon_sym_Pagecustomization] = ACTIONS(6985),
    [anon_sym_PageCustomization] = ACTIONS(6985),
    [anon_sym_pageCustomization] = ACTIONS(6985),
    [sym_using_keyword] = ACTIONS(6985),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6985),
  },
  [STATE(3673)] = {
    [ts_builtin_sym_end] = ACTIONS(6939),
    [anon_sym_POUNDif] = ACTIONS(6939),
    [anon_sym_POUNDIF] = ACTIONS(6939),
    [anon_sym_POUNDIf] = ACTIONS(6939),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6941),
    [anon_sym_tableextension] = ACTIONS(6939),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6939),
    [anon_sym_Tableextension] = ACTIONS(6939),
    [anon_sym_TableExtension] = ACTIONS(6939),
    [anon_sym_tableExtension] = ACTIONS(6939),
    [sym_page_keyword] = ACTIONS(6941),
    [anon_sym_pageextension] = ACTIONS(6939),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6939),
    [anon_sym_Pageextension] = ACTIONS(6939),
    [anon_sym_PageExtension] = ACTIONS(6939),
    [anon_sym_pageExtension] = ACTIONS(6939),
    [anon_sym_codeunit] = ACTIONS(6939),
    [anon_sym_CODEUNIT] = ACTIONS(6939),
    [anon_sym_Codeunit] = ACTIONS(6939),
    [anon_sym_CodeUnit] = ACTIONS(6939),
    [anon_sym_COdeunit] = ACTIONS(6939),
    [anon_sym_codeUnit] = ACTIONS(6939),
    [sym_report_keyword] = ACTIONS(6941),
    [anon_sym_reportextension] = ACTIONS(6939),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6939),
    [anon_sym_Reportextension] = ACTIONS(6939),
    [anon_sym_ReportExtension] = ACTIONS(6939),
    [anon_sym_reportExtension] = ACTIONS(6939),
    [sym_query_keyword] = ACTIONS(6939),
    [anon_sym_xmlport] = ACTIONS(6939),
    [anon_sym_XMLPORT] = ACTIONS(6939),
    [anon_sym_Xmlport] = ACTIONS(6939),
    [anon_sym_XMLport] = ACTIONS(6939),
    [anon_sym_XMLPort] = ACTIONS(6939),
    [anon_sym_XmlPort] = ACTIONS(6939),
    [anon_sym_enum] = ACTIONS(6941),
    [anon_sym_ENUM] = ACTIONS(6941),
    [anon_sym_Enum] = ACTIONS(6941),
    [anon_sym_eNUM] = ACTIONS(6939),
    [anon_sym_eNum] = ACTIONS(6939),
    [anon_sym_ENum] = ACTIONS(6939),
    [anon_sym_enumextension] = ACTIONS(6939),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6939),
    [anon_sym_Enumextension] = ACTIONS(6939),
    [anon_sym_EnumExtension] = ACTIONS(6939),
    [anon_sym_enumExtension] = ACTIONS(6939),
    [sym_interface_keyword] = ACTIONS(6939),
    [anon_sym_controladdin] = ACTIONS(6939),
    [anon_sym_CONTROLADDIN] = ACTIONS(6939),
    [anon_sym_Controladdin] = ACTIONS(6939),
    [anon_sym_ControlAddIn] = ACTIONS(6939),
    [anon_sym_ControlAddin] = ACTIONS(6939),
    [anon_sym_controlAddIn] = ACTIONS(6939),
    [anon_sym_controlAddin] = ACTIONS(6939),
    [anon_sym_dotnet] = ACTIONS(6939),
    [anon_sym_DOTNET] = ACTIONS(6939),
    [anon_sym_Dotnet] = ACTIONS(6939),
    [anon_sym_DotNet] = ACTIONS(6939),
    [anon_sym_dotNet] = ACTIONS(6939),
    [sym_profile_keyword] = ACTIONS(6941),
    [anon_sym_profileextension] = ACTIONS(6939),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6939),
    [anon_sym_Profileextension] = ACTIONS(6939),
    [anon_sym_ProfileExtension] = ACTIONS(6939),
    [anon_sym_profileExtension] = ACTIONS(6939),
    [anon_sym_permissionset] = ACTIONS(6941),
    [anon_sym_PERMISSIONSET] = ACTIONS(6941),
    [anon_sym_Permissionset] = ACTIONS(6941),
    [anon_sym_PermissionSet] = ACTIONS(6941),
    [anon_sym_permissionSet] = ACTIONS(6941),
    [anon_sym_permissionsetextension] = ACTIONS(6939),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6939),
    [anon_sym_Permissionsetextension] = ACTIONS(6939),
    [anon_sym_PermissionSetExtension] = ACTIONS(6939),
    [anon_sym_permissionSetExtension] = ACTIONS(6939),
    [sym_entitlement_keyword] = ACTIONS(6939),
    [anon_sym_pagecustomization] = ACTIONS(6939),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6939),
    [anon_sym_Pagecustomization] = ACTIONS(6939),
    [anon_sym_PageCustomization] = ACTIONS(6939),
    [anon_sym_pageCustomization] = ACTIONS(6939),
    [sym_using_keyword] = ACTIONS(6939),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6939),
  },
  [STATE(3674)] = {
    [sym_identifier] = ACTIONS(3659),
    [anon_sym_DOT] = ACTIONS(3659),
    [anon_sym_EQ] = ACTIONS(3661),
    [anon_sym_DASH] = ACTIONS(3659),
    [aux_sym_boolean_token1] = ACTIONS(3659),
    [aux_sym_boolean_token2] = ACTIONS(3659),
    [sym_decimal] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3661),
    [anon_sym_RPAREN] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3661),
    [aux_sym_filter_value_token1] = ACTIONS(3659),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3661),
    [aux_sym_record_type_token1] = ACTIONS(3659),
    [aux_sym_basic_type_token21] = ACTIONS(3659),
    [aux_sym_basic_type_token22] = ACTIONS(3659),
    [aux_sym_basic_type_token48] = ACTIONS(3659),
    [anon_sym_COLON_COLON] = ACTIONS(3661),
    [anon_sym_not] = ACTIONS(3659),
    [anon_sym_NOT] = ACTIONS(3659),
    [anon_sym_Not] = ACTIONS(3659),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3661),
    [aux_sym__expression_token1] = ACTIONS(3661),
    [aux_sym__expression_token2] = ACTIONS(3661),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3659),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3659),
    [anon_sym_SLASH] = ACTIONS(3659),
    [anon_sym_div] = ACTIONS(3659),
    [anon_sym_DIV] = ACTIONS(3659),
    [anon_sym_Div] = ACTIONS(3659),
    [anon_sym_mod] = ACTIONS(3659),
    [anon_sym_MOD] = ACTIONS(3659),
    [anon_sym_Mod] = ACTIONS(3659),
    [anon_sym_PLUS] = ACTIONS(3659),
    [anon_sym_GT_EQ] = ACTIONS(3661),
    [anon_sym_LT_EQ] = ACTIONS(3661),
    [anon_sym_GT] = ACTIONS(3659),
    [anon_sym_LT] = ACTIONS(3659),
    [anon_sym_LT_GT] = ACTIONS(3661),
    [anon_sym_and] = ACTIONS(3659),
    [anon_sym_AND] = ACTIONS(3659),
    [anon_sym_And] = ACTIONS(3659),
    [anon_sym_or] = ACTIONS(3659),
    [anon_sym_OR] = ACTIONS(3659),
    [anon_sym_Or] = ACTIONS(3659),
    [anon_sym_xor] = ACTIONS(3659),
    [anon_sym_XOR] = ACTIONS(3659),
    [anon_sym_Xor] = ACTIONS(3659),
    [anon_sym_QMARK] = ACTIONS(3661),
    [sym_datetime_literal] = ACTIONS(3661),
    [sym_date_literal] = ACTIONS(3659),
    [sym_time_literal] = ACTIONS(3659),
    [sym_biginteger_literal] = ACTIONS(3661),
    [anon_sym_in] = ACTIONS(3659),
    [anon_sym_IN] = ACTIONS(3659),
    [anon_sym_In] = ACTIONS(3659),
    [sym_page_keyword] = ACTIONS(3659),
    [anon_sym_codeunit] = ACTIONS(3659),
    [anon_sym_CODEUNIT] = ACTIONS(3659),
    [anon_sym_Codeunit] = ACTIONS(3659),
    [anon_sym_CodeUnit] = ACTIONS(3659),
    [anon_sym_COdeunit] = ACTIONS(3659),
    [anon_sym_codeUnit] = ACTIONS(3659),
    [sym_report_keyword] = ACTIONS(3659),
    [sym_query_keyword] = ACTIONS(3659),
    [anon_sym_xmlport] = ACTIONS(3659),
    [anon_sym_XMLPORT] = ACTIONS(3659),
    [anon_sym_Xmlport] = ACTIONS(3659),
    [anon_sym_XMLport] = ACTIONS(3659),
    [anon_sym_XMLPort] = ACTIONS(3659),
    [anon_sym_XmlPort] = ACTIONS(3659),
    [anon_sym_enum] = ACTIONS(3659),
    [anon_sym_ENUM] = ACTIONS(3659),
    [anon_sym_Enum] = ACTIONS(3659),
    [anon_sym_eNUM] = ACTIONS(3659),
    [anon_sym_eNum] = ACTIONS(3659),
    [anon_sym_ENum] = ACTIONS(3659),
    [sym_quoted_identifier] = ACTIONS(3661),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3661),
    [sym_verbatim_string] = ACTIONS(3661),
    [sym_integer] = ACTIONS(3659),
    [sym_continue_as_identifier] = ACTIONS(3661),
  },
  [STATE(3675)] = {
    [ts_builtin_sym_end] = ACTIONS(7153),
    [anon_sym_POUNDif] = ACTIONS(7153),
    [anon_sym_POUNDIF] = ACTIONS(7153),
    [anon_sym_POUNDIf] = ACTIONS(7153),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7155),
    [anon_sym_tableextension] = ACTIONS(7153),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7153),
    [anon_sym_Tableextension] = ACTIONS(7153),
    [anon_sym_TableExtension] = ACTIONS(7153),
    [anon_sym_tableExtension] = ACTIONS(7153),
    [sym_page_keyword] = ACTIONS(7155),
    [anon_sym_pageextension] = ACTIONS(7153),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7153),
    [anon_sym_Pageextension] = ACTIONS(7153),
    [anon_sym_PageExtension] = ACTIONS(7153),
    [anon_sym_pageExtension] = ACTIONS(7153),
    [anon_sym_codeunit] = ACTIONS(7153),
    [anon_sym_CODEUNIT] = ACTIONS(7153),
    [anon_sym_Codeunit] = ACTIONS(7153),
    [anon_sym_CodeUnit] = ACTIONS(7153),
    [anon_sym_COdeunit] = ACTIONS(7153),
    [anon_sym_codeUnit] = ACTIONS(7153),
    [sym_report_keyword] = ACTIONS(7155),
    [anon_sym_reportextension] = ACTIONS(7153),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7153),
    [anon_sym_Reportextension] = ACTIONS(7153),
    [anon_sym_ReportExtension] = ACTIONS(7153),
    [anon_sym_reportExtension] = ACTIONS(7153),
    [sym_query_keyword] = ACTIONS(7153),
    [anon_sym_xmlport] = ACTIONS(7153),
    [anon_sym_XMLPORT] = ACTIONS(7153),
    [anon_sym_Xmlport] = ACTIONS(7153),
    [anon_sym_XMLport] = ACTIONS(7153),
    [anon_sym_XMLPort] = ACTIONS(7153),
    [anon_sym_XmlPort] = ACTIONS(7153),
    [anon_sym_enum] = ACTIONS(7155),
    [anon_sym_ENUM] = ACTIONS(7155),
    [anon_sym_Enum] = ACTIONS(7155),
    [anon_sym_eNUM] = ACTIONS(7153),
    [anon_sym_eNum] = ACTIONS(7153),
    [anon_sym_ENum] = ACTIONS(7153),
    [anon_sym_enumextension] = ACTIONS(7153),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7153),
    [anon_sym_Enumextension] = ACTIONS(7153),
    [anon_sym_EnumExtension] = ACTIONS(7153),
    [anon_sym_enumExtension] = ACTIONS(7153),
    [sym_interface_keyword] = ACTIONS(7153),
    [anon_sym_controladdin] = ACTIONS(7153),
    [anon_sym_CONTROLADDIN] = ACTIONS(7153),
    [anon_sym_Controladdin] = ACTIONS(7153),
    [anon_sym_ControlAddIn] = ACTIONS(7153),
    [anon_sym_ControlAddin] = ACTIONS(7153),
    [anon_sym_controlAddIn] = ACTIONS(7153),
    [anon_sym_controlAddin] = ACTIONS(7153),
    [anon_sym_dotnet] = ACTIONS(7153),
    [anon_sym_DOTNET] = ACTIONS(7153),
    [anon_sym_Dotnet] = ACTIONS(7153),
    [anon_sym_DotNet] = ACTIONS(7153),
    [anon_sym_dotNet] = ACTIONS(7153),
    [sym_profile_keyword] = ACTIONS(7155),
    [anon_sym_profileextension] = ACTIONS(7153),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7153),
    [anon_sym_Profileextension] = ACTIONS(7153),
    [anon_sym_ProfileExtension] = ACTIONS(7153),
    [anon_sym_profileExtension] = ACTIONS(7153),
    [anon_sym_permissionset] = ACTIONS(7155),
    [anon_sym_PERMISSIONSET] = ACTIONS(7155),
    [anon_sym_Permissionset] = ACTIONS(7155),
    [anon_sym_PermissionSet] = ACTIONS(7155),
    [anon_sym_permissionSet] = ACTIONS(7155),
    [anon_sym_permissionsetextension] = ACTIONS(7153),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7153),
    [anon_sym_Permissionsetextension] = ACTIONS(7153),
    [anon_sym_PermissionSetExtension] = ACTIONS(7153),
    [anon_sym_permissionSetExtension] = ACTIONS(7153),
    [sym_entitlement_keyword] = ACTIONS(7153),
    [anon_sym_pagecustomization] = ACTIONS(7153),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7153),
    [anon_sym_Pagecustomization] = ACTIONS(7153),
    [anon_sym_PageCustomization] = ACTIONS(7153),
    [anon_sym_pageCustomization] = ACTIONS(7153),
    [sym_using_keyword] = ACTIONS(7153),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7153),
  },
  [STATE(3676)] = {
    [sym_identifier] = ACTIONS(5358),
    [anon_sym_DASH] = ACTIONS(5360),
    [aux_sym_boolean_token1] = ACTIONS(5358),
    [aux_sym_boolean_token2] = ACTIONS(5358),
    [sym_decimal] = ACTIONS(5358),
    [anon_sym_LPAREN] = ACTIONS(5360),
    [aux_sym_where_condition_token1] = ACTIONS(5358),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5358),
    [aux_sym_if_table_relation_token1] = ACTIONS(5358),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5358),
    [anon_sym_LBRACK] = ACTIONS(5360),
    [aux_sym_record_type_token1] = ACTIONS(5358),
    [aux_sym_basic_type_token21] = ACTIONS(5358),
    [aux_sym_basic_type_token22] = ACTIONS(5358),
    [aux_sym_basic_type_token48] = ACTIONS(5358),
    [aux_sym_basic_type_token53] = ACTIONS(5358),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5358),
    [aux_sym_separator_action_token1] = ACTIONS(5358),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5358),
    [aux_sym_type_declaration_token1] = ACTIONS(5358),
    [anon_sym_POUNDif] = ACTIONS(5360),
    [anon_sym_POUNDIF] = ACTIONS(5360),
    [anon_sym_POUNDIf] = ACTIONS(5360),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8365),
    [anon_sym_PIPE_PIPE] = ACTIONS(8367),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8369),
    [anon_sym_AMP_AMP] = ACTIONS(8371),
    [anon_sym_not] = ACTIONS(5358),
    [anon_sym_NOT] = ACTIONS(5358),
    [anon_sym_Not] = ACTIONS(5358),
    [anon_sym_POUNDelif] = ACTIONS(5360),
    [anon_sym_POUNDELIF] = ACTIONS(5360),
    [anon_sym_POUNDElif] = ACTIONS(5360),
    [anon_sym_POUNDelse] = ACTIONS(5360),
    [anon_sym_POUNDELSE] = ACTIONS(5360),
    [anon_sym_POUNDElse] = ACTIONS(5360),
    [anon_sym_POUNDelse2] = ACTIONS(5360),
    [anon_sym_POUNDELSE2] = ACTIONS(5360),
    [anon_sym_POUNDElse2] = ACTIONS(5360),
    [anon_sym_POUNDendif] = ACTIONS(5360),
    [anon_sym_POUNDENDIF] = ACTIONS(5360),
    [anon_sym_POUNDEndif] = ACTIONS(5360),
    [anon_sym_POUNDendif2] = ACTIONS(5360),
    [anon_sym_POUNDENDIF2] = ACTIONS(5360),
    [anon_sym_POUNDEndif2] = ACTIONS(5360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5358),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5358),
    [anon_sym_PLUS] = ACTIONS(5360),
    [sym_datetime_literal] = ACTIONS(5360),
    [sym_date_literal] = ACTIONS(5358),
    [sym_time_literal] = ACTIONS(5358),
    [sym_biginteger_literal] = ACTIONS(5360),
    [sym_table_keyword] = ACTIONS(5358),
    [sym_page_keyword] = ACTIONS(5358),
    [anon_sym_codeunit] = ACTIONS(5358),
    [anon_sym_CODEUNIT] = ACTIONS(5358),
    [anon_sym_Codeunit] = ACTIONS(5358),
    [anon_sym_CodeUnit] = ACTIONS(5358),
    [anon_sym_COdeunit] = ACTIONS(5358),
    [anon_sym_codeUnit] = ACTIONS(5358),
    [sym_report_keyword] = ACTIONS(5358),
    [sym_query_keyword] = ACTIONS(5358),
    [anon_sym_xmlport] = ACTIONS(5358),
    [anon_sym_XMLPORT] = ACTIONS(5358),
    [anon_sym_Xmlport] = ACTIONS(5358),
    [anon_sym_XMLport] = ACTIONS(5358),
    [anon_sym_XMLPort] = ACTIONS(5358),
    [anon_sym_XmlPort] = ACTIONS(5358),
    [anon_sym_enum] = ACTIONS(5358),
    [anon_sym_ENUM] = ACTIONS(5358),
    [anon_sym_Enum] = ACTIONS(5358),
    [anon_sym_eNUM] = ACTIONS(5358),
    [anon_sym_eNum] = ACTIONS(5358),
    [anon_sym_ENum] = ACTIONS(5358),
    [sym_key_keyword] = ACTIONS(5358),
    [sym_dataset_keyword] = ACTIONS(5358),
    [sym_quoted_identifier] = ACTIONS(5360),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5360),
    [sym_verbatim_string] = ACTIONS(5360),
    [sym_integer] = ACTIONS(5358),
    [sym_continue_as_identifier] = ACTIONS(5360),
    [sym_preproc_open] = ACTIONS(5360),
    [sym_preproc_close] = ACTIONS(5360),
  },
  [STATE(3677)] = {
    [sym_identifier] = ACTIONS(3776),
    [anon_sym_DOT] = ACTIONS(3776),
    [anon_sym_EQ] = ACTIONS(3778),
    [anon_sym_DASH] = ACTIONS(3776),
    [aux_sym_boolean_token1] = ACTIONS(3776),
    [aux_sym_boolean_token2] = ACTIONS(3776),
    [sym_decimal] = ACTIONS(3776),
    [anon_sym_LPAREN] = ACTIONS(3778),
    [anon_sym_RPAREN] = ACTIONS(3778),
    [anon_sym_DOT_DOT] = ACTIONS(3778),
    [aux_sym_filter_value_token1] = ACTIONS(3776),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3776),
    [anon_sym_STAR] = ACTIONS(3776),
    [anon_sym_LBRACK] = ACTIONS(3778),
    [aux_sym_record_type_token1] = ACTIONS(3776),
    [aux_sym_basic_type_token21] = ACTIONS(3776),
    [aux_sym_basic_type_token22] = ACTIONS(3776),
    [aux_sym_basic_type_token48] = ACTIONS(3776),
    [anon_sym_COLON_COLON] = ACTIONS(3778),
    [anon_sym_not] = ACTIONS(3776),
    [anon_sym_NOT] = ACTIONS(3776),
    [anon_sym_Not] = ACTIONS(3776),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3778),
    [aux_sym__expression_token1] = ACTIONS(3778),
    [aux_sym__expression_token2] = ACTIONS(3778),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3776),
    [anon_sym_SLASH] = ACTIONS(3776),
    [anon_sym_div] = ACTIONS(3776),
    [anon_sym_DIV] = ACTIONS(3776),
    [anon_sym_Div] = ACTIONS(3776),
    [anon_sym_mod] = ACTIONS(3776),
    [anon_sym_MOD] = ACTIONS(3776),
    [anon_sym_Mod] = ACTIONS(3776),
    [anon_sym_PLUS] = ACTIONS(3776),
    [anon_sym_GT_EQ] = ACTIONS(3778),
    [anon_sym_LT_EQ] = ACTIONS(3778),
    [anon_sym_GT] = ACTIONS(3776),
    [anon_sym_LT] = ACTIONS(3776),
    [anon_sym_LT_GT] = ACTIONS(3778),
    [anon_sym_and] = ACTIONS(3776),
    [anon_sym_AND] = ACTIONS(3776),
    [anon_sym_And] = ACTIONS(3776),
    [anon_sym_or] = ACTIONS(3776),
    [anon_sym_OR] = ACTIONS(3776),
    [anon_sym_Or] = ACTIONS(3776),
    [anon_sym_xor] = ACTIONS(3776),
    [anon_sym_XOR] = ACTIONS(3776),
    [anon_sym_Xor] = ACTIONS(3776),
    [anon_sym_QMARK] = ACTIONS(3778),
    [sym_datetime_literal] = ACTIONS(3778),
    [sym_date_literal] = ACTIONS(3776),
    [sym_time_literal] = ACTIONS(3776),
    [sym_biginteger_literal] = ACTIONS(3778),
    [anon_sym_in] = ACTIONS(3776),
    [anon_sym_IN] = ACTIONS(3776),
    [anon_sym_In] = ACTIONS(3776),
    [sym_page_keyword] = ACTIONS(3776),
    [anon_sym_codeunit] = ACTIONS(3776),
    [anon_sym_CODEUNIT] = ACTIONS(3776),
    [anon_sym_Codeunit] = ACTIONS(3776),
    [anon_sym_CodeUnit] = ACTIONS(3776),
    [anon_sym_COdeunit] = ACTIONS(3776),
    [anon_sym_codeUnit] = ACTIONS(3776),
    [sym_report_keyword] = ACTIONS(3776),
    [sym_query_keyword] = ACTIONS(3776),
    [anon_sym_xmlport] = ACTIONS(3776),
    [anon_sym_XMLPORT] = ACTIONS(3776),
    [anon_sym_Xmlport] = ACTIONS(3776),
    [anon_sym_XMLport] = ACTIONS(3776),
    [anon_sym_XMLPort] = ACTIONS(3776),
    [anon_sym_XmlPort] = ACTIONS(3776),
    [anon_sym_enum] = ACTIONS(3776),
    [anon_sym_ENUM] = ACTIONS(3776),
    [anon_sym_Enum] = ACTIONS(3776),
    [anon_sym_eNUM] = ACTIONS(3776),
    [anon_sym_eNum] = ACTIONS(3776),
    [anon_sym_ENum] = ACTIONS(3776),
    [sym_quoted_identifier] = ACTIONS(3778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3778),
    [sym_verbatim_string] = ACTIONS(3778),
    [sym_integer] = ACTIONS(3776),
    [sym_continue_as_identifier] = ACTIONS(3778),
  },
  [STATE(3678)] = {
    [sym_identifier] = ACTIONS(5370),
    [anon_sym_DASH] = ACTIONS(5372),
    [aux_sym_boolean_token1] = ACTIONS(5370),
    [aux_sym_boolean_token2] = ACTIONS(5370),
    [sym_decimal] = ACTIONS(5370),
    [anon_sym_LPAREN] = ACTIONS(5372),
    [aux_sym_where_condition_token1] = ACTIONS(5370),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5370),
    [aux_sym_if_table_relation_token1] = ACTIONS(5370),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5370),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [aux_sym_record_type_token1] = ACTIONS(5370),
    [aux_sym_basic_type_token21] = ACTIONS(5370),
    [aux_sym_basic_type_token22] = ACTIONS(5370),
    [aux_sym_basic_type_token48] = ACTIONS(5370),
    [aux_sym_basic_type_token53] = ACTIONS(5370),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5370),
    [aux_sym_separator_action_token1] = ACTIONS(5370),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5370),
    [aux_sym_type_declaration_token1] = ACTIONS(5370),
    [anon_sym_POUNDif] = ACTIONS(5372),
    [anon_sym_POUNDIF] = ACTIONS(5372),
    [anon_sym_POUNDIf] = ACTIONS(5372),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8365),
    [anon_sym_PIPE_PIPE] = ACTIONS(8367),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8369),
    [anon_sym_AMP_AMP] = ACTIONS(8371),
    [anon_sym_not] = ACTIONS(5370),
    [anon_sym_NOT] = ACTIONS(5370),
    [anon_sym_Not] = ACTIONS(5370),
    [anon_sym_POUNDelif] = ACTIONS(5372),
    [anon_sym_POUNDELIF] = ACTIONS(5372),
    [anon_sym_POUNDElif] = ACTIONS(5372),
    [anon_sym_POUNDelse] = ACTIONS(5372),
    [anon_sym_POUNDELSE] = ACTIONS(5372),
    [anon_sym_POUNDElse] = ACTIONS(5372),
    [anon_sym_POUNDelse2] = ACTIONS(5372),
    [anon_sym_POUNDELSE2] = ACTIONS(5372),
    [anon_sym_POUNDElse2] = ACTIONS(5372),
    [anon_sym_POUNDendif] = ACTIONS(5372),
    [anon_sym_POUNDENDIF] = ACTIONS(5372),
    [anon_sym_POUNDEndif] = ACTIONS(5372),
    [anon_sym_POUNDendif2] = ACTIONS(5372),
    [anon_sym_POUNDENDIF2] = ACTIONS(5372),
    [anon_sym_POUNDEndif2] = ACTIONS(5372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5370),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5370),
    [anon_sym_PLUS] = ACTIONS(5372),
    [sym_datetime_literal] = ACTIONS(5372),
    [sym_date_literal] = ACTIONS(5370),
    [sym_time_literal] = ACTIONS(5370),
    [sym_biginteger_literal] = ACTIONS(5372),
    [sym_table_keyword] = ACTIONS(5370),
    [sym_page_keyword] = ACTIONS(5370),
    [anon_sym_codeunit] = ACTIONS(5370),
    [anon_sym_CODEUNIT] = ACTIONS(5370),
    [anon_sym_Codeunit] = ACTIONS(5370),
    [anon_sym_CodeUnit] = ACTIONS(5370),
    [anon_sym_COdeunit] = ACTIONS(5370),
    [anon_sym_codeUnit] = ACTIONS(5370),
    [sym_report_keyword] = ACTIONS(5370),
    [sym_query_keyword] = ACTIONS(5370),
    [anon_sym_xmlport] = ACTIONS(5370),
    [anon_sym_XMLPORT] = ACTIONS(5370),
    [anon_sym_Xmlport] = ACTIONS(5370),
    [anon_sym_XMLport] = ACTIONS(5370),
    [anon_sym_XMLPort] = ACTIONS(5370),
    [anon_sym_XmlPort] = ACTIONS(5370),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_ENUM] = ACTIONS(5370),
    [anon_sym_Enum] = ACTIONS(5370),
    [anon_sym_eNUM] = ACTIONS(5370),
    [anon_sym_eNum] = ACTIONS(5370),
    [anon_sym_ENum] = ACTIONS(5370),
    [sym_key_keyword] = ACTIONS(5370),
    [sym_dataset_keyword] = ACTIONS(5370),
    [sym_quoted_identifier] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5372),
    [sym_verbatim_string] = ACTIONS(5372),
    [sym_integer] = ACTIONS(5370),
    [sym_continue_as_identifier] = ACTIONS(5372),
    [sym_preproc_open] = ACTIONS(5372),
    [sym_preproc_close] = ACTIONS(5372),
  },
  [STATE(3679)] = {
    [sym_identifier] = ACTIONS(5374),
    [anon_sym_DASH] = ACTIONS(5376),
    [aux_sym_boolean_token1] = ACTIONS(5374),
    [aux_sym_boolean_token2] = ACTIONS(5374),
    [sym_decimal] = ACTIONS(5374),
    [anon_sym_LPAREN] = ACTIONS(5376),
    [aux_sym_where_condition_token1] = ACTIONS(5374),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5374),
    [aux_sym_if_table_relation_token1] = ACTIONS(5374),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5374),
    [anon_sym_LBRACK] = ACTIONS(5376),
    [aux_sym_record_type_token1] = ACTIONS(5374),
    [aux_sym_basic_type_token21] = ACTIONS(5374),
    [aux_sym_basic_type_token22] = ACTIONS(5374),
    [aux_sym_basic_type_token48] = ACTIONS(5374),
    [aux_sym_basic_type_token53] = ACTIONS(5374),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5374),
    [aux_sym_separator_action_token1] = ACTIONS(5374),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5374),
    [aux_sym_type_declaration_token1] = ACTIONS(5374),
    [anon_sym_POUNDif] = ACTIONS(5376),
    [anon_sym_POUNDIF] = ACTIONS(5376),
    [anon_sym_POUNDIf] = ACTIONS(5376),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5374),
    [anon_sym_PIPE_PIPE] = ACTIONS(5376),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5374),
    [anon_sym_AMP_AMP] = ACTIONS(5376),
    [anon_sym_not] = ACTIONS(5374),
    [anon_sym_NOT] = ACTIONS(5374),
    [anon_sym_Not] = ACTIONS(5374),
    [anon_sym_POUNDelif] = ACTIONS(5376),
    [anon_sym_POUNDELIF] = ACTIONS(5376),
    [anon_sym_POUNDElif] = ACTIONS(5376),
    [anon_sym_POUNDelse] = ACTIONS(5376),
    [anon_sym_POUNDELSE] = ACTIONS(5376),
    [anon_sym_POUNDElse] = ACTIONS(5376),
    [anon_sym_POUNDelse2] = ACTIONS(5376),
    [anon_sym_POUNDELSE2] = ACTIONS(5376),
    [anon_sym_POUNDElse2] = ACTIONS(5376),
    [anon_sym_POUNDendif] = ACTIONS(5376),
    [anon_sym_POUNDENDIF] = ACTIONS(5376),
    [anon_sym_POUNDEndif] = ACTIONS(5376),
    [anon_sym_POUNDendif2] = ACTIONS(5376),
    [anon_sym_POUNDENDIF2] = ACTIONS(5376),
    [anon_sym_POUNDEndif2] = ACTIONS(5376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5374),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5374),
    [anon_sym_PLUS] = ACTIONS(5376),
    [sym_datetime_literal] = ACTIONS(5376),
    [sym_date_literal] = ACTIONS(5374),
    [sym_time_literal] = ACTIONS(5374),
    [sym_biginteger_literal] = ACTIONS(5376),
    [sym_table_keyword] = ACTIONS(5374),
    [sym_page_keyword] = ACTIONS(5374),
    [anon_sym_codeunit] = ACTIONS(5374),
    [anon_sym_CODEUNIT] = ACTIONS(5374),
    [anon_sym_Codeunit] = ACTIONS(5374),
    [anon_sym_CodeUnit] = ACTIONS(5374),
    [anon_sym_COdeunit] = ACTIONS(5374),
    [anon_sym_codeUnit] = ACTIONS(5374),
    [sym_report_keyword] = ACTIONS(5374),
    [sym_query_keyword] = ACTIONS(5374),
    [anon_sym_xmlport] = ACTIONS(5374),
    [anon_sym_XMLPORT] = ACTIONS(5374),
    [anon_sym_Xmlport] = ACTIONS(5374),
    [anon_sym_XMLport] = ACTIONS(5374),
    [anon_sym_XMLPort] = ACTIONS(5374),
    [anon_sym_XmlPort] = ACTIONS(5374),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_ENUM] = ACTIONS(5374),
    [anon_sym_Enum] = ACTIONS(5374),
    [anon_sym_eNUM] = ACTIONS(5374),
    [anon_sym_eNum] = ACTIONS(5374),
    [anon_sym_ENum] = ACTIONS(5374),
    [sym_key_keyword] = ACTIONS(5374),
    [sym_dataset_keyword] = ACTIONS(5374),
    [sym_quoted_identifier] = ACTIONS(5376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5376),
    [sym_verbatim_string] = ACTIONS(5376),
    [sym_integer] = ACTIONS(5374),
    [sym_continue_as_identifier] = ACTIONS(5376),
    [sym_preproc_open] = ACTIONS(5376),
    [sym_preproc_close] = ACTIONS(5376),
  },
  [STATE(3680)] = {
    [ts_builtin_sym_end] = ACTIONS(7137),
    [anon_sym_POUNDif] = ACTIONS(7137),
    [anon_sym_POUNDIF] = ACTIONS(7137),
    [anon_sym_POUNDIf] = ACTIONS(7137),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7139),
    [anon_sym_tableextension] = ACTIONS(7137),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7137),
    [anon_sym_Tableextension] = ACTIONS(7137),
    [anon_sym_TableExtension] = ACTIONS(7137),
    [anon_sym_tableExtension] = ACTIONS(7137),
    [sym_page_keyword] = ACTIONS(7139),
    [anon_sym_pageextension] = ACTIONS(7137),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7137),
    [anon_sym_Pageextension] = ACTIONS(7137),
    [anon_sym_PageExtension] = ACTIONS(7137),
    [anon_sym_pageExtension] = ACTIONS(7137),
    [anon_sym_codeunit] = ACTIONS(7137),
    [anon_sym_CODEUNIT] = ACTIONS(7137),
    [anon_sym_Codeunit] = ACTIONS(7137),
    [anon_sym_CodeUnit] = ACTIONS(7137),
    [anon_sym_COdeunit] = ACTIONS(7137),
    [anon_sym_codeUnit] = ACTIONS(7137),
    [sym_report_keyword] = ACTIONS(7139),
    [anon_sym_reportextension] = ACTIONS(7137),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7137),
    [anon_sym_Reportextension] = ACTIONS(7137),
    [anon_sym_ReportExtension] = ACTIONS(7137),
    [anon_sym_reportExtension] = ACTIONS(7137),
    [sym_query_keyword] = ACTIONS(7137),
    [anon_sym_xmlport] = ACTIONS(7137),
    [anon_sym_XMLPORT] = ACTIONS(7137),
    [anon_sym_Xmlport] = ACTIONS(7137),
    [anon_sym_XMLport] = ACTIONS(7137),
    [anon_sym_XMLPort] = ACTIONS(7137),
    [anon_sym_XmlPort] = ACTIONS(7137),
    [anon_sym_enum] = ACTIONS(7139),
    [anon_sym_ENUM] = ACTIONS(7139),
    [anon_sym_Enum] = ACTIONS(7139),
    [anon_sym_eNUM] = ACTIONS(7137),
    [anon_sym_eNum] = ACTIONS(7137),
    [anon_sym_ENum] = ACTIONS(7137),
    [anon_sym_enumextension] = ACTIONS(7137),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7137),
    [anon_sym_Enumextension] = ACTIONS(7137),
    [anon_sym_EnumExtension] = ACTIONS(7137),
    [anon_sym_enumExtension] = ACTIONS(7137),
    [sym_interface_keyword] = ACTIONS(7137),
    [anon_sym_controladdin] = ACTIONS(7137),
    [anon_sym_CONTROLADDIN] = ACTIONS(7137),
    [anon_sym_Controladdin] = ACTIONS(7137),
    [anon_sym_ControlAddIn] = ACTIONS(7137),
    [anon_sym_ControlAddin] = ACTIONS(7137),
    [anon_sym_controlAddIn] = ACTIONS(7137),
    [anon_sym_controlAddin] = ACTIONS(7137),
    [anon_sym_dotnet] = ACTIONS(7137),
    [anon_sym_DOTNET] = ACTIONS(7137),
    [anon_sym_Dotnet] = ACTIONS(7137),
    [anon_sym_DotNet] = ACTIONS(7137),
    [anon_sym_dotNet] = ACTIONS(7137),
    [sym_profile_keyword] = ACTIONS(7139),
    [anon_sym_profileextension] = ACTIONS(7137),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7137),
    [anon_sym_Profileextension] = ACTIONS(7137),
    [anon_sym_ProfileExtension] = ACTIONS(7137),
    [anon_sym_profileExtension] = ACTIONS(7137),
    [anon_sym_permissionset] = ACTIONS(7139),
    [anon_sym_PERMISSIONSET] = ACTIONS(7139),
    [anon_sym_Permissionset] = ACTIONS(7139),
    [anon_sym_PermissionSet] = ACTIONS(7139),
    [anon_sym_permissionSet] = ACTIONS(7139),
    [anon_sym_permissionsetextension] = ACTIONS(7137),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7137),
    [anon_sym_Permissionsetextension] = ACTIONS(7137),
    [anon_sym_PermissionSetExtension] = ACTIONS(7137),
    [anon_sym_permissionSetExtension] = ACTIONS(7137),
    [sym_entitlement_keyword] = ACTIONS(7137),
    [anon_sym_pagecustomization] = ACTIONS(7137),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7137),
    [anon_sym_Pagecustomization] = ACTIONS(7137),
    [anon_sym_PageCustomization] = ACTIONS(7137),
    [anon_sym_pageCustomization] = ACTIONS(7137),
    [sym_using_keyword] = ACTIONS(7137),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7137),
  },
  [STATE(3681)] = {
    [sym__body_element] = STATE(3826),
    [sym_empty_statement] = STATE(3826),
    [sym_property] = STATE(3826),
    [sym_permissions_property] = STATE(3826),
    [sym_table_relation_property] = STATE(3826),
    [sym_fields_section] = STATE(3826),
    [sym_keys_section] = STATE(3826),
    [sym_fieldgroups_section] = STATE(3826),
    [sym_enum_value_declaration] = STATE(3826),
    [sym_labels_section] = STATE(3826),
    [sym_layout_section] = STATE(3826),
    [sym_modify_modification] = STATE(3826),
    [sym_actions_section] = STATE(3826),
    [sym_views_section] = STATE(3826),
    [sym_dataset_section] = STATE(3826),
    [sym_requestpage_section] = STATE(3826),
    [sym_rendering_section] = STATE(3826),
    [sym_elements_section] = STATE(3826),
    [sym_schema_section] = STATE(3826),
    [sym_assembly_declaration] = STATE(3826),
    [sym_event_declaration] = STATE(3826),
    [sym_procedure] = STATE(3826),
    [sym_preproc_split_procedure] = STATE(3826),
    [sym__procedure_preamble] = STATE(10810),
    [sym_preproc_split_procedure_preamble] = STATE(3826),
    [sym__procedure_header] = STATE(9981),
    [sym_procedure_modifier] = STATE(17385),
    [sym_trigger_declaration] = STATE(3826),
    [sym_var_section] = STATE(3826),
    [sym_attribute_item] = STATE(5188),
    [sym_preproc_conditional] = STATE(3826),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4963),
    [sym_preproc_endif] = STATE(9865),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(3826),
    [aux_sym__procedure_header_repeat1] = STATE(14631),
    [aux_sym_preproc_conditional_repeat1] = STATE(10844),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4459),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3682)] = {
    [sym_boolean] = STATE(8802),
    [sym_simple_table_relation] = STATE(7271),
    [sym__namespaced_or_simple_ref] = STATE(7175),
    [sym_assignment_expression] = STATE(8802),
    [sym__expression] = STATE(8802),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8802),
    [sym_multiplicative_expression] = STATE(8802),
    [sym_additive_expression] = STATE(8802),
    [sym_comparison_expression] = STATE(8802),
    [sym_logical_expression] = STATE(8802),
    [sym_ternary_expression] = STATE(8802),
    [sym_unary_expression] = STATE(8802),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(3559),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8802),
    [sym_list_literal] = STATE(8802),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8802),
    [sym__literal_value] = STATE(8802),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(7118),
    [sym_keyword_as_identifier] = STATE(7118),
    [sym_identifier] = ACTIONS(7513),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7515),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7517),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7519),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7517),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7517),
    [aux_sym_separator_action_token1] = ACTIONS(7517),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7517),
    [aux_sym_type_declaration_token1] = ACTIONS(7517),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7521),
    [sym_date_literal] = ACTIONS(7515),
    [sym_time_literal] = ACTIONS(7515),
    [sym_biginteger_literal] = ACTIONS(7521),
    [sym_table_keyword] = ACTIONS(7517),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7517),
    [sym_dataset_keyword] = ACTIONS(7517),
    [sym_quoted_identifier] = ACTIONS(7523),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7521),
    [sym_verbatim_string] = ACTIONS(7521),
    [sym_integer] = ACTIONS(7525),
    [sym_continue_as_identifier] = ACTIONS(7521),
  },
  [STATE(3683)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_RPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_filter_value_token1] = ACTIONS(3663),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
  },
  [STATE(3684)] = {
    [ts_builtin_sym_end] = ACTIONS(7145),
    [anon_sym_POUNDif] = ACTIONS(7145),
    [anon_sym_POUNDIF] = ACTIONS(7145),
    [anon_sym_POUNDIf] = ACTIONS(7145),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7147),
    [anon_sym_tableextension] = ACTIONS(7145),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7145),
    [anon_sym_Tableextension] = ACTIONS(7145),
    [anon_sym_TableExtension] = ACTIONS(7145),
    [anon_sym_tableExtension] = ACTIONS(7145),
    [sym_page_keyword] = ACTIONS(7147),
    [anon_sym_pageextension] = ACTIONS(7145),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7145),
    [anon_sym_Pageextension] = ACTIONS(7145),
    [anon_sym_PageExtension] = ACTIONS(7145),
    [anon_sym_pageExtension] = ACTIONS(7145),
    [anon_sym_codeunit] = ACTIONS(7145),
    [anon_sym_CODEUNIT] = ACTIONS(7145),
    [anon_sym_Codeunit] = ACTIONS(7145),
    [anon_sym_CodeUnit] = ACTIONS(7145),
    [anon_sym_COdeunit] = ACTIONS(7145),
    [anon_sym_codeUnit] = ACTIONS(7145),
    [sym_report_keyword] = ACTIONS(7147),
    [anon_sym_reportextension] = ACTIONS(7145),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7145),
    [anon_sym_Reportextension] = ACTIONS(7145),
    [anon_sym_ReportExtension] = ACTIONS(7145),
    [anon_sym_reportExtension] = ACTIONS(7145),
    [sym_query_keyword] = ACTIONS(7145),
    [anon_sym_xmlport] = ACTIONS(7145),
    [anon_sym_XMLPORT] = ACTIONS(7145),
    [anon_sym_Xmlport] = ACTIONS(7145),
    [anon_sym_XMLport] = ACTIONS(7145),
    [anon_sym_XMLPort] = ACTIONS(7145),
    [anon_sym_XmlPort] = ACTIONS(7145),
    [anon_sym_enum] = ACTIONS(7147),
    [anon_sym_ENUM] = ACTIONS(7147),
    [anon_sym_Enum] = ACTIONS(7147),
    [anon_sym_eNUM] = ACTIONS(7145),
    [anon_sym_eNum] = ACTIONS(7145),
    [anon_sym_ENum] = ACTIONS(7145),
    [anon_sym_enumextension] = ACTIONS(7145),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7145),
    [anon_sym_Enumextension] = ACTIONS(7145),
    [anon_sym_EnumExtension] = ACTIONS(7145),
    [anon_sym_enumExtension] = ACTIONS(7145),
    [sym_interface_keyword] = ACTIONS(7145),
    [anon_sym_controladdin] = ACTIONS(7145),
    [anon_sym_CONTROLADDIN] = ACTIONS(7145),
    [anon_sym_Controladdin] = ACTIONS(7145),
    [anon_sym_ControlAddIn] = ACTIONS(7145),
    [anon_sym_ControlAddin] = ACTIONS(7145),
    [anon_sym_controlAddIn] = ACTIONS(7145),
    [anon_sym_controlAddin] = ACTIONS(7145),
    [anon_sym_dotnet] = ACTIONS(7145),
    [anon_sym_DOTNET] = ACTIONS(7145),
    [anon_sym_Dotnet] = ACTIONS(7145),
    [anon_sym_DotNet] = ACTIONS(7145),
    [anon_sym_dotNet] = ACTIONS(7145),
    [sym_profile_keyword] = ACTIONS(7147),
    [anon_sym_profileextension] = ACTIONS(7145),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7145),
    [anon_sym_Profileextension] = ACTIONS(7145),
    [anon_sym_ProfileExtension] = ACTIONS(7145),
    [anon_sym_profileExtension] = ACTIONS(7145),
    [anon_sym_permissionset] = ACTIONS(7147),
    [anon_sym_PERMISSIONSET] = ACTIONS(7147),
    [anon_sym_Permissionset] = ACTIONS(7147),
    [anon_sym_PermissionSet] = ACTIONS(7147),
    [anon_sym_permissionSet] = ACTIONS(7147),
    [anon_sym_permissionsetextension] = ACTIONS(7145),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7145),
    [anon_sym_Permissionsetextension] = ACTIONS(7145),
    [anon_sym_PermissionSetExtension] = ACTIONS(7145),
    [anon_sym_permissionSetExtension] = ACTIONS(7145),
    [sym_entitlement_keyword] = ACTIONS(7145),
    [anon_sym_pagecustomization] = ACTIONS(7145),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7145),
    [anon_sym_Pagecustomization] = ACTIONS(7145),
    [anon_sym_PageCustomization] = ACTIONS(7145),
    [anon_sym_pageCustomization] = ACTIONS(7145),
    [sym_using_keyword] = ACTIONS(7145),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7145),
  },
  [STATE(3685)] = {
    [ts_builtin_sym_end] = ACTIONS(7169),
    [anon_sym_POUNDif] = ACTIONS(7169),
    [anon_sym_POUNDIF] = ACTIONS(7169),
    [anon_sym_POUNDIf] = ACTIONS(7169),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7171),
    [anon_sym_tableextension] = ACTIONS(7169),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7169),
    [anon_sym_Tableextension] = ACTIONS(7169),
    [anon_sym_TableExtension] = ACTIONS(7169),
    [anon_sym_tableExtension] = ACTIONS(7169),
    [sym_page_keyword] = ACTIONS(7171),
    [anon_sym_pageextension] = ACTIONS(7169),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7169),
    [anon_sym_Pageextension] = ACTIONS(7169),
    [anon_sym_PageExtension] = ACTIONS(7169),
    [anon_sym_pageExtension] = ACTIONS(7169),
    [anon_sym_codeunit] = ACTIONS(7169),
    [anon_sym_CODEUNIT] = ACTIONS(7169),
    [anon_sym_Codeunit] = ACTIONS(7169),
    [anon_sym_CodeUnit] = ACTIONS(7169),
    [anon_sym_COdeunit] = ACTIONS(7169),
    [anon_sym_codeUnit] = ACTIONS(7169),
    [sym_report_keyword] = ACTIONS(7171),
    [anon_sym_reportextension] = ACTIONS(7169),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7169),
    [anon_sym_Reportextension] = ACTIONS(7169),
    [anon_sym_ReportExtension] = ACTIONS(7169),
    [anon_sym_reportExtension] = ACTIONS(7169),
    [sym_query_keyword] = ACTIONS(7169),
    [anon_sym_xmlport] = ACTIONS(7169),
    [anon_sym_XMLPORT] = ACTIONS(7169),
    [anon_sym_Xmlport] = ACTIONS(7169),
    [anon_sym_XMLport] = ACTIONS(7169),
    [anon_sym_XMLPort] = ACTIONS(7169),
    [anon_sym_XmlPort] = ACTIONS(7169),
    [anon_sym_enum] = ACTIONS(7171),
    [anon_sym_ENUM] = ACTIONS(7171),
    [anon_sym_Enum] = ACTIONS(7171),
    [anon_sym_eNUM] = ACTIONS(7169),
    [anon_sym_eNum] = ACTIONS(7169),
    [anon_sym_ENum] = ACTIONS(7169),
    [anon_sym_enumextension] = ACTIONS(7169),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7169),
    [anon_sym_Enumextension] = ACTIONS(7169),
    [anon_sym_EnumExtension] = ACTIONS(7169),
    [anon_sym_enumExtension] = ACTIONS(7169),
    [sym_interface_keyword] = ACTIONS(7169),
    [anon_sym_controladdin] = ACTIONS(7169),
    [anon_sym_CONTROLADDIN] = ACTIONS(7169),
    [anon_sym_Controladdin] = ACTIONS(7169),
    [anon_sym_ControlAddIn] = ACTIONS(7169),
    [anon_sym_ControlAddin] = ACTIONS(7169),
    [anon_sym_controlAddIn] = ACTIONS(7169),
    [anon_sym_controlAddin] = ACTIONS(7169),
    [anon_sym_dotnet] = ACTIONS(7169),
    [anon_sym_DOTNET] = ACTIONS(7169),
    [anon_sym_Dotnet] = ACTIONS(7169),
    [anon_sym_DotNet] = ACTIONS(7169),
    [anon_sym_dotNet] = ACTIONS(7169),
    [sym_profile_keyword] = ACTIONS(7171),
    [anon_sym_profileextension] = ACTIONS(7169),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7169),
    [anon_sym_Profileextension] = ACTIONS(7169),
    [anon_sym_ProfileExtension] = ACTIONS(7169),
    [anon_sym_profileExtension] = ACTIONS(7169),
    [anon_sym_permissionset] = ACTIONS(7171),
    [anon_sym_PERMISSIONSET] = ACTIONS(7171),
    [anon_sym_Permissionset] = ACTIONS(7171),
    [anon_sym_PermissionSet] = ACTIONS(7171),
    [anon_sym_permissionSet] = ACTIONS(7171),
    [anon_sym_permissionsetextension] = ACTIONS(7169),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7169),
    [anon_sym_Permissionsetextension] = ACTIONS(7169),
    [anon_sym_PermissionSetExtension] = ACTIONS(7169),
    [anon_sym_permissionSetExtension] = ACTIONS(7169),
    [sym_entitlement_keyword] = ACTIONS(7169),
    [anon_sym_pagecustomization] = ACTIONS(7169),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7169),
    [anon_sym_Pagecustomization] = ACTIONS(7169),
    [anon_sym_PageCustomization] = ACTIONS(7169),
    [anon_sym_pageCustomization] = ACTIONS(7169),
    [sym_using_keyword] = ACTIONS(7169),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7169),
  },
  [STATE(3686)] = {
    [sym_boolean] = STATE(8677),
    [sym_calc_field_reference] = STATE(16019),
    [sym_assignment_expression] = STATE(8677),
    [sym__expression] = STATE(8677),
    [sym_keyword_identifier] = STATE(8333),
    [sym_range_expression] = STATE(8677),
    [sym_multiplicative_expression] = STATE(8677),
    [sym_additive_expression] = STATE(8677),
    [sym_comparison_expression] = STATE(8677),
    [sym_logical_expression] = STATE(8677),
    [sym_ternary_expression] = STATE(8677),
    [sym_unary_expression] = STATE(8677),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8677),
    [sym_list_literal] = STATE(8677),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8677),
    [sym__literal_value] = STATE(8677),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(15227),
    [sym_keyword_as_identifier] = STATE(15227),
    [sym_identifier] = ACTIONS(7527),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8373),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(8375),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(6034),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(8377),
    [sym_date_literal] = ACTIONS(8373),
    [sym_time_literal] = ACTIONS(8373),
    [sym_biginteger_literal] = ACTIONS(8377),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(7533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8377),
    [sym_verbatim_string] = ACTIONS(8377),
    [sym_integer] = ACTIONS(8373),
    [sym_continue_as_identifier] = ACTIONS(8377),
  },
  [STATE(3687)] = {
    [ts_builtin_sym_end] = ACTIONS(6842),
    [anon_sym_POUNDif] = ACTIONS(6842),
    [anon_sym_POUNDIF] = ACTIONS(6842),
    [anon_sym_POUNDIf] = ACTIONS(6842),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6844),
    [anon_sym_tableextension] = ACTIONS(6842),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6842),
    [anon_sym_Tableextension] = ACTIONS(6842),
    [anon_sym_TableExtension] = ACTIONS(6842),
    [anon_sym_tableExtension] = ACTIONS(6842),
    [sym_page_keyword] = ACTIONS(6844),
    [anon_sym_pageextension] = ACTIONS(6842),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6842),
    [anon_sym_Pageextension] = ACTIONS(6842),
    [anon_sym_PageExtension] = ACTIONS(6842),
    [anon_sym_pageExtension] = ACTIONS(6842),
    [anon_sym_codeunit] = ACTIONS(6842),
    [anon_sym_CODEUNIT] = ACTIONS(6842),
    [anon_sym_Codeunit] = ACTIONS(6842),
    [anon_sym_CodeUnit] = ACTIONS(6842),
    [anon_sym_COdeunit] = ACTIONS(6842),
    [anon_sym_codeUnit] = ACTIONS(6842),
    [sym_report_keyword] = ACTIONS(6844),
    [anon_sym_reportextension] = ACTIONS(6842),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6842),
    [anon_sym_Reportextension] = ACTIONS(6842),
    [anon_sym_ReportExtension] = ACTIONS(6842),
    [anon_sym_reportExtension] = ACTIONS(6842),
    [sym_query_keyword] = ACTIONS(6842),
    [anon_sym_xmlport] = ACTIONS(6842),
    [anon_sym_XMLPORT] = ACTIONS(6842),
    [anon_sym_Xmlport] = ACTIONS(6842),
    [anon_sym_XMLport] = ACTIONS(6842),
    [anon_sym_XMLPort] = ACTIONS(6842),
    [anon_sym_XmlPort] = ACTIONS(6842),
    [anon_sym_enum] = ACTIONS(6844),
    [anon_sym_ENUM] = ACTIONS(6844),
    [anon_sym_Enum] = ACTIONS(6844),
    [anon_sym_eNUM] = ACTIONS(6842),
    [anon_sym_eNum] = ACTIONS(6842),
    [anon_sym_ENum] = ACTIONS(6842),
    [anon_sym_enumextension] = ACTIONS(6842),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6842),
    [anon_sym_Enumextension] = ACTIONS(6842),
    [anon_sym_EnumExtension] = ACTIONS(6842),
    [anon_sym_enumExtension] = ACTIONS(6842),
    [sym_interface_keyword] = ACTIONS(6842),
    [anon_sym_controladdin] = ACTIONS(6842),
    [anon_sym_CONTROLADDIN] = ACTIONS(6842),
    [anon_sym_Controladdin] = ACTIONS(6842),
    [anon_sym_ControlAddIn] = ACTIONS(6842),
    [anon_sym_ControlAddin] = ACTIONS(6842),
    [anon_sym_controlAddIn] = ACTIONS(6842),
    [anon_sym_controlAddin] = ACTIONS(6842),
    [anon_sym_dotnet] = ACTIONS(6842),
    [anon_sym_DOTNET] = ACTIONS(6842),
    [anon_sym_Dotnet] = ACTIONS(6842),
    [anon_sym_DotNet] = ACTIONS(6842),
    [anon_sym_dotNet] = ACTIONS(6842),
    [sym_profile_keyword] = ACTIONS(6844),
    [anon_sym_profileextension] = ACTIONS(6842),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6842),
    [anon_sym_Profileextension] = ACTIONS(6842),
    [anon_sym_ProfileExtension] = ACTIONS(6842),
    [anon_sym_profileExtension] = ACTIONS(6842),
    [anon_sym_permissionset] = ACTIONS(6844),
    [anon_sym_PERMISSIONSET] = ACTIONS(6844),
    [anon_sym_Permissionset] = ACTIONS(6844),
    [anon_sym_PermissionSet] = ACTIONS(6844),
    [anon_sym_permissionSet] = ACTIONS(6844),
    [anon_sym_permissionsetextension] = ACTIONS(6842),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6842),
    [anon_sym_Permissionsetextension] = ACTIONS(6842),
    [anon_sym_PermissionSetExtension] = ACTIONS(6842),
    [anon_sym_permissionSetExtension] = ACTIONS(6842),
    [sym_entitlement_keyword] = ACTIONS(6842),
    [anon_sym_pagecustomization] = ACTIONS(6842),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6842),
    [anon_sym_Pagecustomization] = ACTIONS(6842),
    [anon_sym_PageCustomization] = ACTIONS(6842),
    [anon_sym_pageCustomization] = ACTIONS(6842),
    [sym_using_keyword] = ACTIONS(6842),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6842),
  },
  [STATE(3688)] = {
    [anon_sym_SEMI] = ACTIONS(8379),
    [anon_sym_COMMA] = ACTIONS(8381),
    [aux_sym_where_condition_token1] = ACTIONS(8383),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8379),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8379),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8379),
    [anon_sym_LBRACK] = ACTIONS(8379),
    [aux_sym_basic_type_token6] = ACTIONS(8383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8379),
    [aux_sym_addafter_modification_token1] = ACTIONS(8379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8379),
    [aux_sym_modify_modification_token1] = ACTIONS(8379),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8379),
    [aux_sym_movelast_modification_token1] = ACTIONS(8379),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8379),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8379),
    [anon_sym_POUNDif] = ACTIONS(8379),
    [anon_sym_POUNDIF] = ACTIONS(8379),
    [anon_sym_POUNDIf] = ACTIONS(8379),
    [anon_sym_POUNDelif] = ACTIONS(8379),
    [anon_sym_POUNDELIF] = ACTIONS(8379),
    [anon_sym_POUNDElif] = ACTIONS(8379),
    [anon_sym_POUNDelse] = ACTIONS(8379),
    [anon_sym_POUNDELSE] = ACTIONS(8379),
    [anon_sym_POUNDElse] = ACTIONS(8379),
    [anon_sym_POUNDelse2] = ACTIONS(8379),
    [anon_sym_POUNDELSE2] = ACTIONS(8379),
    [anon_sym_POUNDElse2] = ACTIONS(8379),
    [anon_sym_POUNDendif] = ACTIONS(8379),
    [anon_sym_POUNDENDIF] = ACTIONS(8379),
    [anon_sym_POUNDEndif] = ACTIONS(8379),
    [anon_sym_POUNDendif2] = ACTIONS(8379),
    [anon_sym_POUNDENDIF2] = ACTIONS(8379),
    [anon_sym_POUNDEndif2] = ACTIONS(8379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8383),
    [sym_page_keyword] = ACTIONS(8379),
    [anon_sym_codeunit] = ACTIONS(8379),
    [anon_sym_CODEUNIT] = ACTIONS(8379),
    [anon_sym_Codeunit] = ACTIONS(8379),
    [anon_sym_CodeUnit] = ACTIONS(8379),
    [anon_sym_COdeunit] = ACTIONS(8379),
    [anon_sym_codeUnit] = ACTIONS(8379),
    [sym_report_keyword] = ACTIONS(8379),
    [sym_query_keyword] = ACTIONS(8379),
    [anon_sym_xmlport] = ACTIONS(8379),
    [anon_sym_XMLPORT] = ACTIONS(8379),
    [anon_sym_Xmlport] = ACTIONS(8379),
    [anon_sym_XMLport] = ACTIONS(8379),
    [anon_sym_XMLPort] = ACTIONS(8379),
    [anon_sym_XmlPort] = ACTIONS(8379),
    [sym_procedure_keyword] = ACTIONS(8379),
    [sym_trigger_keyword] = ACTIONS(8379),
    [sym_var_keyword] = ACTIONS(8379),
    [sym_local_keyword] = ACTIONS(8379),
    [sym_internal_keyword] = ACTIONS(8379),
    [sym_protected_keyword] = ACTIONS(8379),
    [sym_event_keyword] = ACTIONS(8379),
    [sym_fields_keyword] = ACTIONS(8379),
    [sym_keys_keyword] = ACTIONS(8379),
    [sym_fieldgroups_keyword] = ACTIONS(8379),
    [sym_actions_keyword] = ACTIONS(8379),
    [sym_layout_keyword] = ACTIONS(8379),
    [sym_area_keyword] = ACTIONS(8379),
    [sym_group_keyword] = ACTIONS(8379),
    [sym_repeater_keyword] = ACTIONS(8379),
    [sym_cuegroup_keyword] = ACTIONS(8379),
    [sym_fixed_keyword] = ACTIONS(8379),
    [sym_grid_keyword] = ACTIONS(8379),
    [sym_part_keyword] = ACTIONS(8379),
    [sym_systempart_keyword] = ACTIONS(8379),
    [sym_usercontrol_keyword] = ACTIONS(8379),
    [sym_dataset_keyword] = ACTIONS(8379),
    [sym_elements_keyword] = ACTIONS(8379),
    [sym_labels_keyword] = ACTIONS(8379),
    [sym_rendering_keyword] = ACTIONS(8379),
    [sym_requestpage_keyword] = ACTIONS(8379),
    [sym_schema_keyword] = ACTIONS(8379),
    [sym_views_keyword] = ACTIONS(8379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8379),
    [sym_preproc_open] = ACTIONS(8379),
    [sym_preproc_close] = ACTIONS(8379),
  },
  [STATE(3689)] = {
    [ts_builtin_sym_end] = ACTIONS(6862),
    [anon_sym_POUNDif] = ACTIONS(6862),
    [anon_sym_POUNDIF] = ACTIONS(6862),
    [anon_sym_POUNDIf] = ACTIONS(6862),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6864),
    [anon_sym_tableextension] = ACTIONS(6862),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6862),
    [anon_sym_Tableextension] = ACTIONS(6862),
    [anon_sym_TableExtension] = ACTIONS(6862),
    [anon_sym_tableExtension] = ACTIONS(6862),
    [sym_page_keyword] = ACTIONS(6864),
    [anon_sym_pageextension] = ACTIONS(6862),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6862),
    [anon_sym_Pageextension] = ACTIONS(6862),
    [anon_sym_PageExtension] = ACTIONS(6862),
    [anon_sym_pageExtension] = ACTIONS(6862),
    [anon_sym_codeunit] = ACTIONS(6862),
    [anon_sym_CODEUNIT] = ACTIONS(6862),
    [anon_sym_Codeunit] = ACTIONS(6862),
    [anon_sym_CodeUnit] = ACTIONS(6862),
    [anon_sym_COdeunit] = ACTIONS(6862),
    [anon_sym_codeUnit] = ACTIONS(6862),
    [sym_report_keyword] = ACTIONS(6864),
    [anon_sym_reportextension] = ACTIONS(6862),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6862),
    [anon_sym_Reportextension] = ACTIONS(6862),
    [anon_sym_ReportExtension] = ACTIONS(6862),
    [anon_sym_reportExtension] = ACTIONS(6862),
    [sym_query_keyword] = ACTIONS(6862),
    [anon_sym_xmlport] = ACTIONS(6862),
    [anon_sym_XMLPORT] = ACTIONS(6862),
    [anon_sym_Xmlport] = ACTIONS(6862),
    [anon_sym_XMLport] = ACTIONS(6862),
    [anon_sym_XMLPort] = ACTIONS(6862),
    [anon_sym_XmlPort] = ACTIONS(6862),
    [anon_sym_enum] = ACTIONS(6864),
    [anon_sym_ENUM] = ACTIONS(6864),
    [anon_sym_Enum] = ACTIONS(6864),
    [anon_sym_eNUM] = ACTIONS(6862),
    [anon_sym_eNum] = ACTIONS(6862),
    [anon_sym_ENum] = ACTIONS(6862),
    [anon_sym_enumextension] = ACTIONS(6862),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6862),
    [anon_sym_Enumextension] = ACTIONS(6862),
    [anon_sym_EnumExtension] = ACTIONS(6862),
    [anon_sym_enumExtension] = ACTIONS(6862),
    [sym_interface_keyword] = ACTIONS(6862),
    [anon_sym_controladdin] = ACTIONS(6862),
    [anon_sym_CONTROLADDIN] = ACTIONS(6862),
    [anon_sym_Controladdin] = ACTIONS(6862),
    [anon_sym_ControlAddIn] = ACTIONS(6862),
    [anon_sym_ControlAddin] = ACTIONS(6862),
    [anon_sym_controlAddIn] = ACTIONS(6862),
    [anon_sym_controlAddin] = ACTIONS(6862),
    [anon_sym_dotnet] = ACTIONS(6862),
    [anon_sym_DOTNET] = ACTIONS(6862),
    [anon_sym_Dotnet] = ACTIONS(6862),
    [anon_sym_DotNet] = ACTIONS(6862),
    [anon_sym_dotNet] = ACTIONS(6862),
    [sym_profile_keyword] = ACTIONS(6864),
    [anon_sym_profileextension] = ACTIONS(6862),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6862),
    [anon_sym_Profileextension] = ACTIONS(6862),
    [anon_sym_ProfileExtension] = ACTIONS(6862),
    [anon_sym_profileExtension] = ACTIONS(6862),
    [anon_sym_permissionset] = ACTIONS(6864),
    [anon_sym_PERMISSIONSET] = ACTIONS(6864),
    [anon_sym_Permissionset] = ACTIONS(6864),
    [anon_sym_PermissionSet] = ACTIONS(6864),
    [anon_sym_permissionSet] = ACTIONS(6864),
    [anon_sym_permissionsetextension] = ACTIONS(6862),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6862),
    [anon_sym_Permissionsetextension] = ACTIONS(6862),
    [anon_sym_PermissionSetExtension] = ACTIONS(6862),
    [anon_sym_permissionSetExtension] = ACTIONS(6862),
    [sym_entitlement_keyword] = ACTIONS(6862),
    [anon_sym_pagecustomization] = ACTIONS(6862),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6862),
    [anon_sym_Pagecustomization] = ACTIONS(6862),
    [anon_sym_PageCustomization] = ACTIONS(6862),
    [anon_sym_pageCustomization] = ACTIONS(6862),
    [sym_using_keyword] = ACTIONS(6862),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6862),
  },
  [STATE(3690)] = {
    [ts_builtin_sym_end] = ACTIONS(6923),
    [anon_sym_POUNDif] = ACTIONS(6923),
    [anon_sym_POUNDIF] = ACTIONS(6923),
    [anon_sym_POUNDIf] = ACTIONS(6923),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6925),
    [anon_sym_tableextension] = ACTIONS(6923),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6923),
    [anon_sym_Tableextension] = ACTIONS(6923),
    [anon_sym_TableExtension] = ACTIONS(6923),
    [anon_sym_tableExtension] = ACTIONS(6923),
    [sym_page_keyword] = ACTIONS(6925),
    [anon_sym_pageextension] = ACTIONS(6923),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6923),
    [anon_sym_Pageextension] = ACTIONS(6923),
    [anon_sym_PageExtension] = ACTIONS(6923),
    [anon_sym_pageExtension] = ACTIONS(6923),
    [anon_sym_codeunit] = ACTIONS(6923),
    [anon_sym_CODEUNIT] = ACTIONS(6923),
    [anon_sym_Codeunit] = ACTIONS(6923),
    [anon_sym_CodeUnit] = ACTIONS(6923),
    [anon_sym_COdeunit] = ACTIONS(6923),
    [anon_sym_codeUnit] = ACTIONS(6923),
    [sym_report_keyword] = ACTIONS(6925),
    [anon_sym_reportextension] = ACTIONS(6923),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6923),
    [anon_sym_Reportextension] = ACTIONS(6923),
    [anon_sym_ReportExtension] = ACTIONS(6923),
    [anon_sym_reportExtension] = ACTIONS(6923),
    [sym_query_keyword] = ACTIONS(6923),
    [anon_sym_xmlport] = ACTIONS(6923),
    [anon_sym_XMLPORT] = ACTIONS(6923),
    [anon_sym_Xmlport] = ACTIONS(6923),
    [anon_sym_XMLport] = ACTIONS(6923),
    [anon_sym_XMLPort] = ACTIONS(6923),
    [anon_sym_XmlPort] = ACTIONS(6923),
    [anon_sym_enum] = ACTIONS(6925),
    [anon_sym_ENUM] = ACTIONS(6925),
    [anon_sym_Enum] = ACTIONS(6925),
    [anon_sym_eNUM] = ACTIONS(6923),
    [anon_sym_eNum] = ACTIONS(6923),
    [anon_sym_ENum] = ACTIONS(6923),
    [anon_sym_enumextension] = ACTIONS(6923),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6923),
    [anon_sym_Enumextension] = ACTIONS(6923),
    [anon_sym_EnumExtension] = ACTIONS(6923),
    [anon_sym_enumExtension] = ACTIONS(6923),
    [sym_interface_keyword] = ACTIONS(6923),
    [anon_sym_controladdin] = ACTIONS(6923),
    [anon_sym_CONTROLADDIN] = ACTIONS(6923),
    [anon_sym_Controladdin] = ACTIONS(6923),
    [anon_sym_ControlAddIn] = ACTIONS(6923),
    [anon_sym_ControlAddin] = ACTIONS(6923),
    [anon_sym_controlAddIn] = ACTIONS(6923),
    [anon_sym_controlAddin] = ACTIONS(6923),
    [anon_sym_dotnet] = ACTIONS(6923),
    [anon_sym_DOTNET] = ACTIONS(6923),
    [anon_sym_Dotnet] = ACTIONS(6923),
    [anon_sym_DotNet] = ACTIONS(6923),
    [anon_sym_dotNet] = ACTIONS(6923),
    [sym_profile_keyword] = ACTIONS(6925),
    [anon_sym_profileextension] = ACTIONS(6923),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6923),
    [anon_sym_Profileextension] = ACTIONS(6923),
    [anon_sym_ProfileExtension] = ACTIONS(6923),
    [anon_sym_profileExtension] = ACTIONS(6923),
    [anon_sym_permissionset] = ACTIONS(6925),
    [anon_sym_PERMISSIONSET] = ACTIONS(6925),
    [anon_sym_Permissionset] = ACTIONS(6925),
    [anon_sym_PermissionSet] = ACTIONS(6925),
    [anon_sym_permissionSet] = ACTIONS(6925),
    [anon_sym_permissionsetextension] = ACTIONS(6923),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6923),
    [anon_sym_Permissionsetextension] = ACTIONS(6923),
    [anon_sym_PermissionSetExtension] = ACTIONS(6923),
    [anon_sym_permissionSetExtension] = ACTIONS(6923),
    [sym_entitlement_keyword] = ACTIONS(6923),
    [anon_sym_pagecustomization] = ACTIONS(6923),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6923),
    [anon_sym_Pagecustomization] = ACTIONS(6923),
    [anon_sym_PageCustomization] = ACTIONS(6923),
    [anon_sym_pageCustomization] = ACTIONS(6923),
    [sym_using_keyword] = ACTIONS(6923),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6923),
  },
  [STATE(3691)] = {
    [ts_builtin_sym_end] = ACTIONS(6907),
    [anon_sym_POUNDif] = ACTIONS(6907),
    [anon_sym_POUNDIF] = ACTIONS(6907),
    [anon_sym_POUNDIf] = ACTIONS(6907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6909),
    [anon_sym_tableextension] = ACTIONS(6907),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6907),
    [anon_sym_Tableextension] = ACTIONS(6907),
    [anon_sym_TableExtension] = ACTIONS(6907),
    [anon_sym_tableExtension] = ACTIONS(6907),
    [sym_page_keyword] = ACTIONS(6909),
    [anon_sym_pageextension] = ACTIONS(6907),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6907),
    [anon_sym_Pageextension] = ACTIONS(6907),
    [anon_sym_PageExtension] = ACTIONS(6907),
    [anon_sym_pageExtension] = ACTIONS(6907),
    [anon_sym_codeunit] = ACTIONS(6907),
    [anon_sym_CODEUNIT] = ACTIONS(6907),
    [anon_sym_Codeunit] = ACTIONS(6907),
    [anon_sym_CodeUnit] = ACTIONS(6907),
    [anon_sym_COdeunit] = ACTIONS(6907),
    [anon_sym_codeUnit] = ACTIONS(6907),
    [sym_report_keyword] = ACTIONS(6909),
    [anon_sym_reportextension] = ACTIONS(6907),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6907),
    [anon_sym_Reportextension] = ACTIONS(6907),
    [anon_sym_ReportExtension] = ACTIONS(6907),
    [anon_sym_reportExtension] = ACTIONS(6907),
    [sym_query_keyword] = ACTIONS(6907),
    [anon_sym_xmlport] = ACTIONS(6907),
    [anon_sym_XMLPORT] = ACTIONS(6907),
    [anon_sym_Xmlport] = ACTIONS(6907),
    [anon_sym_XMLport] = ACTIONS(6907),
    [anon_sym_XMLPort] = ACTIONS(6907),
    [anon_sym_XmlPort] = ACTIONS(6907),
    [anon_sym_enum] = ACTIONS(6909),
    [anon_sym_ENUM] = ACTIONS(6909),
    [anon_sym_Enum] = ACTIONS(6909),
    [anon_sym_eNUM] = ACTIONS(6907),
    [anon_sym_eNum] = ACTIONS(6907),
    [anon_sym_ENum] = ACTIONS(6907),
    [anon_sym_enumextension] = ACTIONS(6907),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6907),
    [anon_sym_Enumextension] = ACTIONS(6907),
    [anon_sym_EnumExtension] = ACTIONS(6907),
    [anon_sym_enumExtension] = ACTIONS(6907),
    [sym_interface_keyword] = ACTIONS(6907),
    [anon_sym_controladdin] = ACTIONS(6907),
    [anon_sym_CONTROLADDIN] = ACTIONS(6907),
    [anon_sym_Controladdin] = ACTIONS(6907),
    [anon_sym_ControlAddIn] = ACTIONS(6907),
    [anon_sym_ControlAddin] = ACTIONS(6907),
    [anon_sym_controlAddIn] = ACTIONS(6907),
    [anon_sym_controlAddin] = ACTIONS(6907),
    [anon_sym_dotnet] = ACTIONS(6907),
    [anon_sym_DOTNET] = ACTIONS(6907),
    [anon_sym_Dotnet] = ACTIONS(6907),
    [anon_sym_DotNet] = ACTIONS(6907),
    [anon_sym_dotNet] = ACTIONS(6907),
    [sym_profile_keyword] = ACTIONS(6909),
    [anon_sym_profileextension] = ACTIONS(6907),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6907),
    [anon_sym_Profileextension] = ACTIONS(6907),
    [anon_sym_ProfileExtension] = ACTIONS(6907),
    [anon_sym_profileExtension] = ACTIONS(6907),
    [anon_sym_permissionset] = ACTIONS(6909),
    [anon_sym_PERMISSIONSET] = ACTIONS(6909),
    [anon_sym_Permissionset] = ACTIONS(6909),
    [anon_sym_PermissionSet] = ACTIONS(6909),
    [anon_sym_permissionSet] = ACTIONS(6909),
    [anon_sym_permissionsetextension] = ACTIONS(6907),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6907),
    [anon_sym_Permissionsetextension] = ACTIONS(6907),
    [anon_sym_PermissionSetExtension] = ACTIONS(6907),
    [anon_sym_permissionSetExtension] = ACTIONS(6907),
    [sym_entitlement_keyword] = ACTIONS(6907),
    [anon_sym_pagecustomization] = ACTIONS(6907),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6907),
    [anon_sym_Pagecustomization] = ACTIONS(6907),
    [anon_sym_PageCustomization] = ACTIONS(6907),
    [anon_sym_pageCustomization] = ACTIONS(6907),
    [sym_using_keyword] = ACTIONS(6907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6907),
  },
  [STATE(3692)] = {
    [ts_builtin_sym_end] = ACTIONS(6973),
    [anon_sym_POUNDif] = ACTIONS(6973),
    [anon_sym_POUNDIF] = ACTIONS(6973),
    [anon_sym_POUNDIf] = ACTIONS(6973),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6975),
    [anon_sym_tableextension] = ACTIONS(6973),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6973),
    [anon_sym_Tableextension] = ACTIONS(6973),
    [anon_sym_TableExtension] = ACTIONS(6973),
    [anon_sym_tableExtension] = ACTIONS(6973),
    [sym_page_keyword] = ACTIONS(6975),
    [anon_sym_pageextension] = ACTIONS(6973),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6973),
    [anon_sym_Pageextension] = ACTIONS(6973),
    [anon_sym_PageExtension] = ACTIONS(6973),
    [anon_sym_pageExtension] = ACTIONS(6973),
    [anon_sym_codeunit] = ACTIONS(6973),
    [anon_sym_CODEUNIT] = ACTIONS(6973),
    [anon_sym_Codeunit] = ACTIONS(6973),
    [anon_sym_CodeUnit] = ACTIONS(6973),
    [anon_sym_COdeunit] = ACTIONS(6973),
    [anon_sym_codeUnit] = ACTIONS(6973),
    [sym_report_keyword] = ACTIONS(6975),
    [anon_sym_reportextension] = ACTIONS(6973),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6973),
    [anon_sym_Reportextension] = ACTIONS(6973),
    [anon_sym_ReportExtension] = ACTIONS(6973),
    [anon_sym_reportExtension] = ACTIONS(6973),
    [sym_query_keyword] = ACTIONS(6973),
    [anon_sym_xmlport] = ACTIONS(6973),
    [anon_sym_XMLPORT] = ACTIONS(6973),
    [anon_sym_Xmlport] = ACTIONS(6973),
    [anon_sym_XMLport] = ACTIONS(6973),
    [anon_sym_XMLPort] = ACTIONS(6973),
    [anon_sym_XmlPort] = ACTIONS(6973),
    [anon_sym_enum] = ACTIONS(6975),
    [anon_sym_ENUM] = ACTIONS(6975),
    [anon_sym_Enum] = ACTIONS(6975),
    [anon_sym_eNUM] = ACTIONS(6973),
    [anon_sym_eNum] = ACTIONS(6973),
    [anon_sym_ENum] = ACTIONS(6973),
    [anon_sym_enumextension] = ACTIONS(6973),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6973),
    [anon_sym_Enumextension] = ACTIONS(6973),
    [anon_sym_EnumExtension] = ACTIONS(6973),
    [anon_sym_enumExtension] = ACTIONS(6973),
    [sym_interface_keyword] = ACTIONS(6973),
    [anon_sym_controladdin] = ACTIONS(6973),
    [anon_sym_CONTROLADDIN] = ACTIONS(6973),
    [anon_sym_Controladdin] = ACTIONS(6973),
    [anon_sym_ControlAddIn] = ACTIONS(6973),
    [anon_sym_ControlAddin] = ACTIONS(6973),
    [anon_sym_controlAddIn] = ACTIONS(6973),
    [anon_sym_controlAddin] = ACTIONS(6973),
    [anon_sym_dotnet] = ACTIONS(6973),
    [anon_sym_DOTNET] = ACTIONS(6973),
    [anon_sym_Dotnet] = ACTIONS(6973),
    [anon_sym_DotNet] = ACTIONS(6973),
    [anon_sym_dotNet] = ACTIONS(6973),
    [sym_profile_keyword] = ACTIONS(6975),
    [anon_sym_profileextension] = ACTIONS(6973),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6973),
    [anon_sym_Profileextension] = ACTIONS(6973),
    [anon_sym_ProfileExtension] = ACTIONS(6973),
    [anon_sym_profileExtension] = ACTIONS(6973),
    [anon_sym_permissionset] = ACTIONS(6975),
    [anon_sym_PERMISSIONSET] = ACTIONS(6975),
    [anon_sym_Permissionset] = ACTIONS(6975),
    [anon_sym_PermissionSet] = ACTIONS(6975),
    [anon_sym_permissionSet] = ACTIONS(6975),
    [anon_sym_permissionsetextension] = ACTIONS(6973),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6973),
    [anon_sym_Permissionsetextension] = ACTIONS(6973),
    [anon_sym_PermissionSetExtension] = ACTIONS(6973),
    [anon_sym_permissionSetExtension] = ACTIONS(6973),
    [sym_entitlement_keyword] = ACTIONS(6973),
    [anon_sym_pagecustomization] = ACTIONS(6973),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6973),
    [anon_sym_Pagecustomization] = ACTIONS(6973),
    [anon_sym_PageCustomization] = ACTIONS(6973),
    [anon_sym_pageCustomization] = ACTIONS(6973),
    [sym_using_keyword] = ACTIONS(6973),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6973),
  },
  [STATE(3693)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3880),
    [sym_preproc_conditional_case_patterns] = STATE(3880),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8385),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(8387),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(8387),
    [anon_sym_ELSE] = ACTIONS(8387),
    [anon_sym_Else] = ACTIONS(8387),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3694)] = {
    [sym_boolean] = STATE(8820),
    [sym_simple_table_relation] = STATE(9751),
    [sym__namespaced_or_simple_ref] = STATE(5577),
    [sym_assignment_expression] = STATE(8820),
    [sym__expression] = STATE(8820),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8820),
    [sym_multiplicative_expression] = STATE(8820),
    [sym_additive_expression] = STATE(8820),
    [sym_comparison_expression] = STATE(8820),
    [sym_logical_expression] = STATE(8820),
    [sym_ternary_expression] = STATE(8820),
    [sym_unary_expression] = STATE(8820),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(2813),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8820),
    [sym_list_literal] = STATE(8820),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8820),
    [sym__literal_value] = STATE(8820),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(5439),
    [sym_keyword_as_identifier] = STATE(5439),
    [sym_identifier] = ACTIONS(7553),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7555),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7557),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7559),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7557),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7557),
    [aux_sym_separator_action_token1] = ACTIONS(7557),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7557),
    [aux_sym_type_declaration_token1] = ACTIONS(7557),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7561),
    [sym_date_literal] = ACTIONS(7555),
    [sym_time_literal] = ACTIONS(7555),
    [sym_biginteger_literal] = ACTIONS(7561),
    [sym_table_keyword] = ACTIONS(7557),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7557),
    [sym_dataset_keyword] = ACTIONS(7557),
    [sym_quoted_identifier] = ACTIONS(7563),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7561),
    [sym_verbatim_string] = ACTIONS(7561),
    [sym_integer] = ACTIONS(7565),
    [sym_continue_as_identifier] = ACTIONS(7561),
  },
  [STATE(3695)] = {
    [sym_identifier] = ACTIONS(3663),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [aux_sym_boolean_token1] = ACTIONS(3663),
    [aux_sym_boolean_token2] = ACTIONS(3663),
    [sym_decimal] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [anon_sym_RPAREN] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_filter_value_token1] = ACTIONS(3663),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3663),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_record_type_token1] = ACTIONS(3663),
    [aux_sym_basic_type_token21] = ACTIONS(3663),
    [aux_sym_basic_type_token22] = ACTIONS(3663),
    [aux_sym_basic_type_token48] = ACTIONS(3663),
    [anon_sym_COLON_COLON] = ACTIONS(8389),
    [anon_sym_not] = ACTIONS(3663),
    [anon_sym_NOT] = ACTIONS(3663),
    [anon_sym_Not] = ACTIONS(3663),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3663),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3663),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3663),
    [anon_sym_DIV] = ACTIONS(3663),
    [anon_sym_Div] = ACTIONS(3663),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3663),
    [anon_sym_AND] = ACTIONS(3663),
    [anon_sym_And] = ACTIONS(3663),
    [anon_sym_or] = ACTIONS(3663),
    [anon_sym_OR] = ACTIONS(3663),
    [anon_sym_Or] = ACTIONS(3663),
    [anon_sym_xor] = ACTIONS(3663),
    [anon_sym_XOR] = ACTIONS(3663),
    [anon_sym_Xor] = ACTIONS(3663),
    [anon_sym_QMARK] = ACTIONS(3665),
    [sym_datetime_literal] = ACTIONS(3665),
    [sym_date_literal] = ACTIONS(3663),
    [sym_time_literal] = ACTIONS(3663),
    [sym_biginteger_literal] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_page_keyword] = ACTIONS(3663),
    [anon_sym_codeunit] = ACTIONS(3663),
    [anon_sym_CODEUNIT] = ACTIONS(3663),
    [anon_sym_Codeunit] = ACTIONS(3663),
    [anon_sym_CodeUnit] = ACTIONS(3663),
    [anon_sym_COdeunit] = ACTIONS(3663),
    [anon_sym_codeUnit] = ACTIONS(3663),
    [sym_report_keyword] = ACTIONS(3663),
    [sym_query_keyword] = ACTIONS(3663),
    [anon_sym_xmlport] = ACTIONS(3663),
    [anon_sym_XMLPORT] = ACTIONS(3663),
    [anon_sym_Xmlport] = ACTIONS(3663),
    [anon_sym_XMLport] = ACTIONS(3663),
    [anon_sym_XMLPort] = ACTIONS(3663),
    [anon_sym_XmlPort] = ACTIONS(3663),
    [anon_sym_enum] = ACTIONS(3663),
    [anon_sym_ENUM] = ACTIONS(3663),
    [anon_sym_Enum] = ACTIONS(3663),
    [anon_sym_eNUM] = ACTIONS(3663),
    [anon_sym_eNum] = ACTIONS(3663),
    [anon_sym_ENum] = ACTIONS(3663),
    [sym_quoted_identifier] = ACTIONS(3665),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3665),
    [sym_verbatim_string] = ACTIONS(3665),
    [sym_integer] = ACTIONS(3663),
    [sym_continue_as_identifier] = ACTIONS(3665),
  },
  [STATE(3696)] = {
    [ts_builtin_sym_end] = ACTIONS(7173),
    [anon_sym_POUNDif] = ACTIONS(7173),
    [anon_sym_POUNDIF] = ACTIONS(7173),
    [anon_sym_POUNDIf] = ACTIONS(7173),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7175),
    [anon_sym_tableextension] = ACTIONS(7173),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7173),
    [anon_sym_Tableextension] = ACTIONS(7173),
    [anon_sym_TableExtension] = ACTIONS(7173),
    [anon_sym_tableExtension] = ACTIONS(7173),
    [sym_page_keyword] = ACTIONS(7175),
    [anon_sym_pageextension] = ACTIONS(7173),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7173),
    [anon_sym_Pageextension] = ACTIONS(7173),
    [anon_sym_PageExtension] = ACTIONS(7173),
    [anon_sym_pageExtension] = ACTIONS(7173),
    [anon_sym_codeunit] = ACTIONS(7173),
    [anon_sym_CODEUNIT] = ACTIONS(7173),
    [anon_sym_Codeunit] = ACTIONS(7173),
    [anon_sym_CodeUnit] = ACTIONS(7173),
    [anon_sym_COdeunit] = ACTIONS(7173),
    [anon_sym_codeUnit] = ACTIONS(7173),
    [sym_report_keyword] = ACTIONS(7175),
    [anon_sym_reportextension] = ACTIONS(7173),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7173),
    [anon_sym_Reportextension] = ACTIONS(7173),
    [anon_sym_ReportExtension] = ACTIONS(7173),
    [anon_sym_reportExtension] = ACTIONS(7173),
    [sym_query_keyword] = ACTIONS(7173),
    [anon_sym_xmlport] = ACTIONS(7173),
    [anon_sym_XMLPORT] = ACTIONS(7173),
    [anon_sym_Xmlport] = ACTIONS(7173),
    [anon_sym_XMLport] = ACTIONS(7173),
    [anon_sym_XMLPort] = ACTIONS(7173),
    [anon_sym_XmlPort] = ACTIONS(7173),
    [anon_sym_enum] = ACTIONS(7175),
    [anon_sym_ENUM] = ACTIONS(7175),
    [anon_sym_Enum] = ACTIONS(7175),
    [anon_sym_eNUM] = ACTIONS(7173),
    [anon_sym_eNum] = ACTIONS(7173),
    [anon_sym_ENum] = ACTIONS(7173),
    [anon_sym_enumextension] = ACTIONS(7173),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7173),
    [anon_sym_Enumextension] = ACTIONS(7173),
    [anon_sym_EnumExtension] = ACTIONS(7173),
    [anon_sym_enumExtension] = ACTIONS(7173),
    [sym_interface_keyword] = ACTIONS(7173),
    [anon_sym_controladdin] = ACTIONS(7173),
    [anon_sym_CONTROLADDIN] = ACTIONS(7173),
    [anon_sym_Controladdin] = ACTIONS(7173),
    [anon_sym_ControlAddIn] = ACTIONS(7173),
    [anon_sym_ControlAddin] = ACTIONS(7173),
    [anon_sym_controlAddIn] = ACTIONS(7173),
    [anon_sym_controlAddin] = ACTIONS(7173),
    [anon_sym_dotnet] = ACTIONS(7173),
    [anon_sym_DOTNET] = ACTIONS(7173),
    [anon_sym_Dotnet] = ACTIONS(7173),
    [anon_sym_DotNet] = ACTIONS(7173),
    [anon_sym_dotNet] = ACTIONS(7173),
    [sym_profile_keyword] = ACTIONS(7175),
    [anon_sym_profileextension] = ACTIONS(7173),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7173),
    [anon_sym_Profileextension] = ACTIONS(7173),
    [anon_sym_ProfileExtension] = ACTIONS(7173),
    [anon_sym_profileExtension] = ACTIONS(7173),
    [anon_sym_permissionset] = ACTIONS(7175),
    [anon_sym_PERMISSIONSET] = ACTIONS(7175),
    [anon_sym_Permissionset] = ACTIONS(7175),
    [anon_sym_PermissionSet] = ACTIONS(7175),
    [anon_sym_permissionSet] = ACTIONS(7175),
    [anon_sym_permissionsetextension] = ACTIONS(7173),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7173),
    [anon_sym_Permissionsetextension] = ACTIONS(7173),
    [anon_sym_PermissionSetExtension] = ACTIONS(7173),
    [anon_sym_permissionSetExtension] = ACTIONS(7173),
    [sym_entitlement_keyword] = ACTIONS(7173),
    [anon_sym_pagecustomization] = ACTIONS(7173),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7173),
    [anon_sym_Pagecustomization] = ACTIONS(7173),
    [anon_sym_PageCustomization] = ACTIONS(7173),
    [anon_sym_pageCustomization] = ACTIONS(7173),
    [sym_using_keyword] = ACTIONS(7173),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7173),
  },
  [STATE(3697)] = {
    [sym_identifier] = ACTIONS(5399),
    [anon_sym_DASH] = ACTIONS(5401),
    [aux_sym_boolean_token1] = ACTIONS(5399),
    [aux_sym_boolean_token2] = ACTIONS(5399),
    [sym_decimal] = ACTIONS(5399),
    [anon_sym_LPAREN] = ACTIONS(5401),
    [aux_sym_where_condition_token1] = ACTIONS(5399),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5399),
    [aux_sym_if_table_relation_token1] = ACTIONS(5399),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5399),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [aux_sym_record_type_token1] = ACTIONS(5399),
    [aux_sym_basic_type_token21] = ACTIONS(5399),
    [aux_sym_basic_type_token22] = ACTIONS(5399),
    [aux_sym_basic_type_token48] = ACTIONS(5399),
    [aux_sym_basic_type_token53] = ACTIONS(5399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5399),
    [aux_sym_separator_action_token1] = ACTIONS(5399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5399),
    [aux_sym_type_declaration_token1] = ACTIONS(5399),
    [anon_sym_POUNDif] = ACTIONS(5401),
    [anon_sym_POUNDIF] = ACTIONS(5401),
    [anon_sym_POUNDIf] = ACTIONS(5401),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8365),
    [anon_sym_PIPE_PIPE] = ACTIONS(8367),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8369),
    [anon_sym_AMP_AMP] = ACTIONS(8371),
    [anon_sym_not] = ACTIONS(5399),
    [anon_sym_NOT] = ACTIONS(5399),
    [anon_sym_Not] = ACTIONS(5399),
    [anon_sym_POUNDelif] = ACTIONS(5401),
    [anon_sym_POUNDELIF] = ACTIONS(5401),
    [anon_sym_POUNDElif] = ACTIONS(5401),
    [anon_sym_POUNDelse] = ACTIONS(5401),
    [anon_sym_POUNDELSE] = ACTIONS(5401),
    [anon_sym_POUNDElse] = ACTIONS(5401),
    [anon_sym_POUNDelse2] = ACTIONS(5401),
    [anon_sym_POUNDELSE2] = ACTIONS(5401),
    [anon_sym_POUNDElse2] = ACTIONS(5401),
    [anon_sym_POUNDendif] = ACTIONS(5401),
    [anon_sym_POUNDENDIF] = ACTIONS(5401),
    [anon_sym_POUNDEndif] = ACTIONS(5401),
    [anon_sym_POUNDendif2] = ACTIONS(5401),
    [anon_sym_POUNDENDIF2] = ACTIONS(5401),
    [anon_sym_POUNDEndif2] = ACTIONS(5401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5399),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5399),
    [anon_sym_PLUS] = ACTIONS(5401),
    [sym_datetime_literal] = ACTIONS(5401),
    [sym_date_literal] = ACTIONS(5399),
    [sym_time_literal] = ACTIONS(5399),
    [sym_biginteger_literal] = ACTIONS(5401),
    [sym_table_keyword] = ACTIONS(5399),
    [sym_page_keyword] = ACTIONS(5399),
    [anon_sym_codeunit] = ACTIONS(5399),
    [anon_sym_CODEUNIT] = ACTIONS(5399),
    [anon_sym_Codeunit] = ACTIONS(5399),
    [anon_sym_CodeUnit] = ACTIONS(5399),
    [anon_sym_COdeunit] = ACTIONS(5399),
    [anon_sym_codeUnit] = ACTIONS(5399),
    [sym_report_keyword] = ACTIONS(5399),
    [sym_query_keyword] = ACTIONS(5399),
    [anon_sym_xmlport] = ACTIONS(5399),
    [anon_sym_XMLPORT] = ACTIONS(5399),
    [anon_sym_Xmlport] = ACTIONS(5399),
    [anon_sym_XMLport] = ACTIONS(5399),
    [anon_sym_XMLPort] = ACTIONS(5399),
    [anon_sym_XmlPort] = ACTIONS(5399),
    [anon_sym_enum] = ACTIONS(5399),
    [anon_sym_ENUM] = ACTIONS(5399),
    [anon_sym_Enum] = ACTIONS(5399),
    [anon_sym_eNUM] = ACTIONS(5399),
    [anon_sym_eNum] = ACTIONS(5399),
    [anon_sym_ENum] = ACTIONS(5399),
    [sym_key_keyword] = ACTIONS(5399),
    [sym_dataset_keyword] = ACTIONS(5399),
    [sym_quoted_identifier] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5401),
    [sym_verbatim_string] = ACTIONS(5401),
    [sym_integer] = ACTIONS(5399),
    [sym_continue_as_identifier] = ACTIONS(5401),
    [sym_preproc_open] = ACTIONS(5401),
    [sym_preproc_close] = ACTIONS(5401),
  },
  [STATE(3698)] = {
    [sym_identifier] = ACTIONS(5378),
    [anon_sym_DASH] = ACTIONS(5380),
    [aux_sym_boolean_token1] = ACTIONS(5378),
    [aux_sym_boolean_token2] = ACTIONS(5378),
    [sym_decimal] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5380),
    [aux_sym_where_condition_token1] = ACTIONS(5378),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5378),
    [aux_sym_if_table_relation_token1] = ACTIONS(5378),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5378),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [aux_sym_record_type_token1] = ACTIONS(5378),
    [aux_sym_basic_type_token21] = ACTIONS(5378),
    [aux_sym_basic_type_token22] = ACTIONS(5378),
    [aux_sym_basic_type_token48] = ACTIONS(5378),
    [aux_sym_basic_type_token53] = ACTIONS(5378),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5378),
    [aux_sym_separator_action_token1] = ACTIONS(5378),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5378),
    [aux_sym_type_declaration_token1] = ACTIONS(5378),
    [anon_sym_POUNDif] = ACTIONS(5380),
    [anon_sym_POUNDIF] = ACTIONS(5380),
    [anon_sym_POUNDIf] = ACTIONS(5380),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5380),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8369),
    [anon_sym_AMP_AMP] = ACTIONS(8371),
    [anon_sym_not] = ACTIONS(5378),
    [anon_sym_NOT] = ACTIONS(5378),
    [anon_sym_Not] = ACTIONS(5378),
    [anon_sym_POUNDelif] = ACTIONS(5380),
    [anon_sym_POUNDELIF] = ACTIONS(5380),
    [anon_sym_POUNDElif] = ACTIONS(5380),
    [anon_sym_POUNDelse] = ACTIONS(5380),
    [anon_sym_POUNDELSE] = ACTIONS(5380),
    [anon_sym_POUNDElse] = ACTIONS(5380),
    [anon_sym_POUNDelse2] = ACTIONS(5380),
    [anon_sym_POUNDELSE2] = ACTIONS(5380),
    [anon_sym_POUNDElse2] = ACTIONS(5380),
    [anon_sym_POUNDendif] = ACTIONS(5380),
    [anon_sym_POUNDENDIF] = ACTIONS(5380),
    [anon_sym_POUNDEndif] = ACTIONS(5380),
    [anon_sym_POUNDendif2] = ACTIONS(5380),
    [anon_sym_POUNDENDIF2] = ACTIONS(5380),
    [anon_sym_POUNDEndif2] = ACTIONS(5380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [sym_datetime_literal] = ACTIONS(5380),
    [sym_date_literal] = ACTIONS(5378),
    [sym_time_literal] = ACTIONS(5378),
    [sym_biginteger_literal] = ACTIONS(5380),
    [sym_table_keyword] = ACTIONS(5378),
    [sym_page_keyword] = ACTIONS(5378),
    [anon_sym_codeunit] = ACTIONS(5378),
    [anon_sym_CODEUNIT] = ACTIONS(5378),
    [anon_sym_Codeunit] = ACTIONS(5378),
    [anon_sym_CodeUnit] = ACTIONS(5378),
    [anon_sym_COdeunit] = ACTIONS(5378),
    [anon_sym_codeUnit] = ACTIONS(5378),
    [sym_report_keyword] = ACTIONS(5378),
    [sym_query_keyword] = ACTIONS(5378),
    [anon_sym_xmlport] = ACTIONS(5378),
    [anon_sym_XMLPORT] = ACTIONS(5378),
    [anon_sym_Xmlport] = ACTIONS(5378),
    [anon_sym_XMLport] = ACTIONS(5378),
    [anon_sym_XMLPort] = ACTIONS(5378),
    [anon_sym_XmlPort] = ACTIONS(5378),
    [anon_sym_enum] = ACTIONS(5378),
    [anon_sym_ENUM] = ACTIONS(5378),
    [anon_sym_Enum] = ACTIONS(5378),
    [anon_sym_eNUM] = ACTIONS(5378),
    [anon_sym_eNum] = ACTIONS(5378),
    [anon_sym_ENum] = ACTIONS(5378),
    [sym_key_keyword] = ACTIONS(5378),
    [sym_dataset_keyword] = ACTIONS(5378),
    [sym_quoted_identifier] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5380),
    [sym_verbatim_string] = ACTIONS(5380),
    [sym_integer] = ACTIONS(5378),
    [sym_continue_as_identifier] = ACTIONS(5380),
    [sym_preproc_open] = ACTIONS(5380),
    [sym_preproc_close] = ACTIONS(5380),
  },
  [STATE(3699)] = {
    [ts_builtin_sym_end] = ACTIONS(6900),
    [anon_sym_POUNDif] = ACTIONS(6900),
    [anon_sym_POUNDIF] = ACTIONS(6900),
    [anon_sym_POUNDIf] = ACTIONS(6900),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6902),
    [anon_sym_tableextension] = ACTIONS(6900),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6900),
    [anon_sym_Tableextension] = ACTIONS(6900),
    [anon_sym_TableExtension] = ACTIONS(6900),
    [anon_sym_tableExtension] = ACTIONS(6900),
    [sym_page_keyword] = ACTIONS(6902),
    [anon_sym_pageextension] = ACTIONS(6900),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6900),
    [anon_sym_Pageextension] = ACTIONS(6900),
    [anon_sym_PageExtension] = ACTIONS(6900),
    [anon_sym_pageExtension] = ACTIONS(6900),
    [anon_sym_codeunit] = ACTIONS(6900),
    [anon_sym_CODEUNIT] = ACTIONS(6900),
    [anon_sym_Codeunit] = ACTIONS(6900),
    [anon_sym_CodeUnit] = ACTIONS(6900),
    [anon_sym_COdeunit] = ACTIONS(6900),
    [anon_sym_codeUnit] = ACTIONS(6900),
    [sym_report_keyword] = ACTIONS(6902),
    [anon_sym_reportextension] = ACTIONS(6900),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6900),
    [anon_sym_Reportextension] = ACTIONS(6900),
    [anon_sym_ReportExtension] = ACTIONS(6900),
    [anon_sym_reportExtension] = ACTIONS(6900),
    [sym_query_keyword] = ACTIONS(6900),
    [anon_sym_xmlport] = ACTIONS(6900),
    [anon_sym_XMLPORT] = ACTIONS(6900),
    [anon_sym_Xmlport] = ACTIONS(6900),
    [anon_sym_XMLport] = ACTIONS(6900),
    [anon_sym_XMLPort] = ACTIONS(6900),
    [anon_sym_XmlPort] = ACTIONS(6900),
    [anon_sym_enum] = ACTIONS(6902),
    [anon_sym_ENUM] = ACTIONS(6902),
    [anon_sym_Enum] = ACTIONS(6902),
    [anon_sym_eNUM] = ACTIONS(6900),
    [anon_sym_eNum] = ACTIONS(6900),
    [anon_sym_ENum] = ACTIONS(6900),
    [anon_sym_enumextension] = ACTIONS(6900),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6900),
    [anon_sym_Enumextension] = ACTIONS(6900),
    [anon_sym_EnumExtension] = ACTIONS(6900),
    [anon_sym_enumExtension] = ACTIONS(6900),
    [sym_interface_keyword] = ACTIONS(6900),
    [anon_sym_controladdin] = ACTIONS(6900),
    [anon_sym_CONTROLADDIN] = ACTIONS(6900),
    [anon_sym_Controladdin] = ACTIONS(6900),
    [anon_sym_ControlAddIn] = ACTIONS(6900),
    [anon_sym_ControlAddin] = ACTIONS(6900),
    [anon_sym_controlAddIn] = ACTIONS(6900),
    [anon_sym_controlAddin] = ACTIONS(6900),
    [anon_sym_dotnet] = ACTIONS(6900),
    [anon_sym_DOTNET] = ACTIONS(6900),
    [anon_sym_Dotnet] = ACTIONS(6900),
    [anon_sym_DotNet] = ACTIONS(6900),
    [anon_sym_dotNet] = ACTIONS(6900),
    [sym_profile_keyword] = ACTIONS(6902),
    [anon_sym_profileextension] = ACTIONS(6900),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6900),
    [anon_sym_Profileextension] = ACTIONS(6900),
    [anon_sym_ProfileExtension] = ACTIONS(6900),
    [anon_sym_profileExtension] = ACTIONS(6900),
    [anon_sym_permissionset] = ACTIONS(6902),
    [anon_sym_PERMISSIONSET] = ACTIONS(6902),
    [anon_sym_Permissionset] = ACTIONS(6902),
    [anon_sym_PermissionSet] = ACTIONS(6902),
    [anon_sym_permissionSet] = ACTIONS(6902),
    [anon_sym_permissionsetextension] = ACTIONS(6900),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6900),
    [anon_sym_Permissionsetextension] = ACTIONS(6900),
    [anon_sym_PermissionSetExtension] = ACTIONS(6900),
    [anon_sym_permissionSetExtension] = ACTIONS(6900),
    [sym_entitlement_keyword] = ACTIONS(6900),
    [anon_sym_pagecustomization] = ACTIONS(6900),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6900),
    [anon_sym_Pagecustomization] = ACTIONS(6900),
    [anon_sym_PageCustomization] = ACTIONS(6900),
    [anon_sym_pageCustomization] = ACTIONS(6900),
    [sym_using_keyword] = ACTIONS(6900),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6900),
  },
  [STATE(3700)] = {
    [ts_builtin_sym_end] = ACTIONS(6911),
    [anon_sym_POUNDif] = ACTIONS(6911),
    [anon_sym_POUNDIF] = ACTIONS(6911),
    [anon_sym_POUNDIf] = ACTIONS(6911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6913),
    [anon_sym_tableextension] = ACTIONS(6911),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6911),
    [anon_sym_Tableextension] = ACTIONS(6911),
    [anon_sym_TableExtension] = ACTIONS(6911),
    [anon_sym_tableExtension] = ACTIONS(6911),
    [sym_page_keyword] = ACTIONS(6913),
    [anon_sym_pageextension] = ACTIONS(6911),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6911),
    [anon_sym_Pageextension] = ACTIONS(6911),
    [anon_sym_PageExtension] = ACTIONS(6911),
    [anon_sym_pageExtension] = ACTIONS(6911),
    [anon_sym_codeunit] = ACTIONS(6911),
    [anon_sym_CODEUNIT] = ACTIONS(6911),
    [anon_sym_Codeunit] = ACTIONS(6911),
    [anon_sym_CodeUnit] = ACTIONS(6911),
    [anon_sym_COdeunit] = ACTIONS(6911),
    [anon_sym_codeUnit] = ACTIONS(6911),
    [sym_report_keyword] = ACTIONS(6913),
    [anon_sym_reportextension] = ACTIONS(6911),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6911),
    [anon_sym_Reportextension] = ACTIONS(6911),
    [anon_sym_ReportExtension] = ACTIONS(6911),
    [anon_sym_reportExtension] = ACTIONS(6911),
    [sym_query_keyword] = ACTIONS(6911),
    [anon_sym_xmlport] = ACTIONS(6911),
    [anon_sym_XMLPORT] = ACTIONS(6911),
    [anon_sym_Xmlport] = ACTIONS(6911),
    [anon_sym_XMLport] = ACTIONS(6911),
    [anon_sym_XMLPort] = ACTIONS(6911),
    [anon_sym_XmlPort] = ACTIONS(6911),
    [anon_sym_enum] = ACTIONS(6913),
    [anon_sym_ENUM] = ACTIONS(6913),
    [anon_sym_Enum] = ACTIONS(6913),
    [anon_sym_eNUM] = ACTIONS(6911),
    [anon_sym_eNum] = ACTIONS(6911),
    [anon_sym_ENum] = ACTIONS(6911),
    [anon_sym_enumextension] = ACTIONS(6911),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6911),
    [anon_sym_Enumextension] = ACTIONS(6911),
    [anon_sym_EnumExtension] = ACTIONS(6911),
    [anon_sym_enumExtension] = ACTIONS(6911),
    [sym_interface_keyword] = ACTIONS(6911),
    [anon_sym_controladdin] = ACTIONS(6911),
    [anon_sym_CONTROLADDIN] = ACTIONS(6911),
    [anon_sym_Controladdin] = ACTIONS(6911),
    [anon_sym_ControlAddIn] = ACTIONS(6911),
    [anon_sym_ControlAddin] = ACTIONS(6911),
    [anon_sym_controlAddIn] = ACTIONS(6911),
    [anon_sym_controlAddin] = ACTIONS(6911),
    [anon_sym_dotnet] = ACTIONS(6911),
    [anon_sym_DOTNET] = ACTIONS(6911),
    [anon_sym_Dotnet] = ACTIONS(6911),
    [anon_sym_DotNet] = ACTIONS(6911),
    [anon_sym_dotNet] = ACTIONS(6911),
    [sym_profile_keyword] = ACTIONS(6913),
    [anon_sym_profileextension] = ACTIONS(6911),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6911),
    [anon_sym_Profileextension] = ACTIONS(6911),
    [anon_sym_ProfileExtension] = ACTIONS(6911),
    [anon_sym_profileExtension] = ACTIONS(6911),
    [anon_sym_permissionset] = ACTIONS(6913),
    [anon_sym_PERMISSIONSET] = ACTIONS(6913),
    [anon_sym_Permissionset] = ACTIONS(6913),
    [anon_sym_PermissionSet] = ACTIONS(6913),
    [anon_sym_permissionSet] = ACTIONS(6913),
    [anon_sym_permissionsetextension] = ACTIONS(6911),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6911),
    [anon_sym_Permissionsetextension] = ACTIONS(6911),
    [anon_sym_PermissionSetExtension] = ACTIONS(6911),
    [anon_sym_permissionSetExtension] = ACTIONS(6911),
    [sym_entitlement_keyword] = ACTIONS(6911),
    [anon_sym_pagecustomization] = ACTIONS(6911),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6911),
    [anon_sym_Pagecustomization] = ACTIONS(6911),
    [anon_sym_PageCustomization] = ACTIONS(6911),
    [anon_sym_pageCustomization] = ACTIONS(6911),
    [sym_using_keyword] = ACTIONS(6911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6911),
  },
  [STATE(3701)] = {
    [ts_builtin_sym_end] = ACTIONS(7165),
    [anon_sym_POUNDif] = ACTIONS(7165),
    [anon_sym_POUNDIF] = ACTIONS(7165),
    [anon_sym_POUNDIf] = ACTIONS(7165),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7167),
    [anon_sym_tableextension] = ACTIONS(7165),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7165),
    [anon_sym_Tableextension] = ACTIONS(7165),
    [anon_sym_TableExtension] = ACTIONS(7165),
    [anon_sym_tableExtension] = ACTIONS(7165),
    [sym_page_keyword] = ACTIONS(7167),
    [anon_sym_pageextension] = ACTIONS(7165),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7165),
    [anon_sym_Pageextension] = ACTIONS(7165),
    [anon_sym_PageExtension] = ACTIONS(7165),
    [anon_sym_pageExtension] = ACTIONS(7165),
    [anon_sym_codeunit] = ACTIONS(7165),
    [anon_sym_CODEUNIT] = ACTIONS(7165),
    [anon_sym_Codeunit] = ACTIONS(7165),
    [anon_sym_CodeUnit] = ACTIONS(7165),
    [anon_sym_COdeunit] = ACTIONS(7165),
    [anon_sym_codeUnit] = ACTIONS(7165),
    [sym_report_keyword] = ACTIONS(7167),
    [anon_sym_reportextension] = ACTIONS(7165),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7165),
    [anon_sym_Reportextension] = ACTIONS(7165),
    [anon_sym_ReportExtension] = ACTIONS(7165),
    [anon_sym_reportExtension] = ACTIONS(7165),
    [sym_query_keyword] = ACTIONS(7165),
    [anon_sym_xmlport] = ACTIONS(7165),
    [anon_sym_XMLPORT] = ACTIONS(7165),
    [anon_sym_Xmlport] = ACTIONS(7165),
    [anon_sym_XMLport] = ACTIONS(7165),
    [anon_sym_XMLPort] = ACTIONS(7165),
    [anon_sym_XmlPort] = ACTIONS(7165),
    [anon_sym_enum] = ACTIONS(7167),
    [anon_sym_ENUM] = ACTIONS(7167),
    [anon_sym_Enum] = ACTIONS(7167),
    [anon_sym_eNUM] = ACTIONS(7165),
    [anon_sym_eNum] = ACTIONS(7165),
    [anon_sym_ENum] = ACTIONS(7165),
    [anon_sym_enumextension] = ACTIONS(7165),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7165),
    [anon_sym_Enumextension] = ACTIONS(7165),
    [anon_sym_EnumExtension] = ACTIONS(7165),
    [anon_sym_enumExtension] = ACTIONS(7165),
    [sym_interface_keyword] = ACTIONS(7165),
    [anon_sym_controladdin] = ACTIONS(7165),
    [anon_sym_CONTROLADDIN] = ACTIONS(7165),
    [anon_sym_Controladdin] = ACTIONS(7165),
    [anon_sym_ControlAddIn] = ACTIONS(7165),
    [anon_sym_ControlAddin] = ACTIONS(7165),
    [anon_sym_controlAddIn] = ACTIONS(7165),
    [anon_sym_controlAddin] = ACTIONS(7165),
    [anon_sym_dotnet] = ACTIONS(7165),
    [anon_sym_DOTNET] = ACTIONS(7165),
    [anon_sym_Dotnet] = ACTIONS(7165),
    [anon_sym_DotNet] = ACTIONS(7165),
    [anon_sym_dotNet] = ACTIONS(7165),
    [sym_profile_keyword] = ACTIONS(7167),
    [anon_sym_profileextension] = ACTIONS(7165),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7165),
    [anon_sym_Profileextension] = ACTIONS(7165),
    [anon_sym_ProfileExtension] = ACTIONS(7165),
    [anon_sym_profileExtension] = ACTIONS(7165),
    [anon_sym_permissionset] = ACTIONS(7167),
    [anon_sym_PERMISSIONSET] = ACTIONS(7167),
    [anon_sym_Permissionset] = ACTIONS(7167),
    [anon_sym_PermissionSet] = ACTIONS(7167),
    [anon_sym_permissionSet] = ACTIONS(7167),
    [anon_sym_permissionsetextension] = ACTIONS(7165),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7165),
    [anon_sym_Permissionsetextension] = ACTIONS(7165),
    [anon_sym_PermissionSetExtension] = ACTIONS(7165),
    [anon_sym_permissionSetExtension] = ACTIONS(7165),
    [sym_entitlement_keyword] = ACTIONS(7165),
    [anon_sym_pagecustomization] = ACTIONS(7165),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7165),
    [anon_sym_Pagecustomization] = ACTIONS(7165),
    [anon_sym_PageCustomization] = ACTIONS(7165),
    [anon_sym_pageCustomization] = ACTIONS(7165),
    [sym_using_keyword] = ACTIONS(7165),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7165),
  },
  [STATE(3702)] = {
    [ts_builtin_sym_end] = ACTIONS(6949),
    [anon_sym_POUNDif] = ACTIONS(6949),
    [anon_sym_POUNDIF] = ACTIONS(6949),
    [anon_sym_POUNDIf] = ACTIONS(6949),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6951),
    [anon_sym_tableextension] = ACTIONS(6949),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6949),
    [anon_sym_Tableextension] = ACTIONS(6949),
    [anon_sym_TableExtension] = ACTIONS(6949),
    [anon_sym_tableExtension] = ACTIONS(6949),
    [sym_page_keyword] = ACTIONS(6951),
    [anon_sym_pageextension] = ACTIONS(6949),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6949),
    [anon_sym_Pageextension] = ACTIONS(6949),
    [anon_sym_PageExtension] = ACTIONS(6949),
    [anon_sym_pageExtension] = ACTIONS(6949),
    [anon_sym_codeunit] = ACTIONS(6949),
    [anon_sym_CODEUNIT] = ACTIONS(6949),
    [anon_sym_Codeunit] = ACTIONS(6949),
    [anon_sym_CodeUnit] = ACTIONS(6949),
    [anon_sym_COdeunit] = ACTIONS(6949),
    [anon_sym_codeUnit] = ACTIONS(6949),
    [sym_report_keyword] = ACTIONS(6951),
    [anon_sym_reportextension] = ACTIONS(6949),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6949),
    [anon_sym_Reportextension] = ACTIONS(6949),
    [anon_sym_ReportExtension] = ACTIONS(6949),
    [anon_sym_reportExtension] = ACTIONS(6949),
    [sym_query_keyword] = ACTIONS(6949),
    [anon_sym_xmlport] = ACTIONS(6949),
    [anon_sym_XMLPORT] = ACTIONS(6949),
    [anon_sym_Xmlport] = ACTIONS(6949),
    [anon_sym_XMLport] = ACTIONS(6949),
    [anon_sym_XMLPort] = ACTIONS(6949),
    [anon_sym_XmlPort] = ACTIONS(6949),
    [anon_sym_enum] = ACTIONS(6951),
    [anon_sym_ENUM] = ACTIONS(6951),
    [anon_sym_Enum] = ACTIONS(6951),
    [anon_sym_eNUM] = ACTIONS(6949),
    [anon_sym_eNum] = ACTIONS(6949),
    [anon_sym_ENum] = ACTIONS(6949),
    [anon_sym_enumextension] = ACTIONS(6949),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6949),
    [anon_sym_Enumextension] = ACTIONS(6949),
    [anon_sym_EnumExtension] = ACTIONS(6949),
    [anon_sym_enumExtension] = ACTIONS(6949),
    [sym_interface_keyword] = ACTIONS(6949),
    [anon_sym_controladdin] = ACTIONS(6949),
    [anon_sym_CONTROLADDIN] = ACTIONS(6949),
    [anon_sym_Controladdin] = ACTIONS(6949),
    [anon_sym_ControlAddIn] = ACTIONS(6949),
    [anon_sym_ControlAddin] = ACTIONS(6949),
    [anon_sym_controlAddIn] = ACTIONS(6949),
    [anon_sym_controlAddin] = ACTIONS(6949),
    [anon_sym_dotnet] = ACTIONS(6949),
    [anon_sym_DOTNET] = ACTIONS(6949),
    [anon_sym_Dotnet] = ACTIONS(6949),
    [anon_sym_DotNet] = ACTIONS(6949),
    [anon_sym_dotNet] = ACTIONS(6949),
    [sym_profile_keyword] = ACTIONS(6951),
    [anon_sym_profileextension] = ACTIONS(6949),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6949),
    [anon_sym_Profileextension] = ACTIONS(6949),
    [anon_sym_ProfileExtension] = ACTIONS(6949),
    [anon_sym_profileExtension] = ACTIONS(6949),
    [anon_sym_permissionset] = ACTIONS(6951),
    [anon_sym_PERMISSIONSET] = ACTIONS(6951),
    [anon_sym_Permissionset] = ACTIONS(6951),
    [anon_sym_PermissionSet] = ACTIONS(6951),
    [anon_sym_permissionSet] = ACTIONS(6951),
    [anon_sym_permissionsetextension] = ACTIONS(6949),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6949),
    [anon_sym_Permissionsetextension] = ACTIONS(6949),
    [anon_sym_PermissionSetExtension] = ACTIONS(6949),
    [anon_sym_permissionSetExtension] = ACTIONS(6949),
    [sym_entitlement_keyword] = ACTIONS(6949),
    [anon_sym_pagecustomization] = ACTIONS(6949),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6949),
    [anon_sym_Pagecustomization] = ACTIONS(6949),
    [anon_sym_PageCustomization] = ACTIONS(6949),
    [anon_sym_pageCustomization] = ACTIONS(6949),
    [sym_using_keyword] = ACTIONS(6949),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6949),
  },
  [STATE(3703)] = {
    [sym_identifier] = ACTIONS(8198),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(8200),
    [aux_sym_boolean_token1] = ACTIONS(8198),
    [aux_sym_boolean_token2] = ACTIONS(8198),
    [sym_decimal] = ACTIONS(8198),
    [anon_sym_LPAREN] = ACTIONS(8203),
    [anon_sym_RPAREN] = ACTIONS(8203),
    [anon_sym_DOT_DOT] = ACTIONS(8205),
    [aux_sym_filter_value_token1] = ACTIONS(8198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8198),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(8205),
    [aux_sym_record_type_token1] = ACTIONS(8198),
    [aux_sym_basic_type_token21] = ACTIONS(8198),
    [aux_sym_basic_type_token22] = ACTIONS(8198),
    [aux_sym_basic_type_token48] = ACTIONS(8198),
    [anon_sym_COLON_COLON] = ACTIONS(8208),
    [anon_sym_not] = ACTIONS(8198),
    [anon_sym_NOT] = ACTIONS(8198),
    [anon_sym_Not] = ACTIONS(8198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8198),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8198),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(8200),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(8203),
    [sym_date_literal] = ACTIONS(8198),
    [sym_time_literal] = ACTIONS(8198),
    [sym_biginteger_literal] = ACTIONS(8203),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(8198),
    [anon_sym_codeunit] = ACTIONS(8198),
    [anon_sym_CODEUNIT] = ACTIONS(8198),
    [anon_sym_Codeunit] = ACTIONS(8198),
    [anon_sym_CodeUnit] = ACTIONS(8198),
    [anon_sym_COdeunit] = ACTIONS(8198),
    [anon_sym_codeUnit] = ACTIONS(8198),
    [sym_report_keyword] = ACTIONS(8198),
    [sym_query_keyword] = ACTIONS(8198),
    [anon_sym_xmlport] = ACTIONS(8198),
    [anon_sym_XMLPORT] = ACTIONS(8198),
    [anon_sym_Xmlport] = ACTIONS(8198),
    [anon_sym_XMLport] = ACTIONS(8198),
    [anon_sym_XMLPort] = ACTIONS(8198),
    [anon_sym_XmlPort] = ACTIONS(8198),
    [anon_sym_enum] = ACTIONS(8198),
    [anon_sym_ENUM] = ACTIONS(8198),
    [anon_sym_Enum] = ACTIONS(8198),
    [anon_sym_eNUM] = ACTIONS(8198),
    [anon_sym_eNum] = ACTIONS(8198),
    [anon_sym_ENum] = ACTIONS(8198),
    [sym_quoted_identifier] = ACTIONS(8203),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8203),
    [sym_verbatim_string] = ACTIONS(8203),
    [sym_integer] = ACTIONS(8198),
    [sym_continue_as_identifier] = ACTIONS(8203),
  },
  [STATE(3704)] = {
    [ts_builtin_sym_end] = ACTIONS(6927),
    [anon_sym_POUNDif] = ACTIONS(6927),
    [anon_sym_POUNDIF] = ACTIONS(6927),
    [anon_sym_POUNDIf] = ACTIONS(6927),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6929),
    [anon_sym_tableextension] = ACTIONS(6927),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6927),
    [anon_sym_Tableextension] = ACTIONS(6927),
    [anon_sym_TableExtension] = ACTIONS(6927),
    [anon_sym_tableExtension] = ACTIONS(6927),
    [sym_page_keyword] = ACTIONS(6929),
    [anon_sym_pageextension] = ACTIONS(6927),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6927),
    [anon_sym_Pageextension] = ACTIONS(6927),
    [anon_sym_PageExtension] = ACTIONS(6927),
    [anon_sym_pageExtension] = ACTIONS(6927),
    [anon_sym_codeunit] = ACTIONS(6927),
    [anon_sym_CODEUNIT] = ACTIONS(6927),
    [anon_sym_Codeunit] = ACTIONS(6927),
    [anon_sym_CodeUnit] = ACTIONS(6927),
    [anon_sym_COdeunit] = ACTIONS(6927),
    [anon_sym_codeUnit] = ACTIONS(6927),
    [sym_report_keyword] = ACTIONS(6929),
    [anon_sym_reportextension] = ACTIONS(6927),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6927),
    [anon_sym_Reportextension] = ACTIONS(6927),
    [anon_sym_ReportExtension] = ACTIONS(6927),
    [anon_sym_reportExtension] = ACTIONS(6927),
    [sym_query_keyword] = ACTIONS(6927),
    [anon_sym_xmlport] = ACTIONS(6927),
    [anon_sym_XMLPORT] = ACTIONS(6927),
    [anon_sym_Xmlport] = ACTIONS(6927),
    [anon_sym_XMLport] = ACTIONS(6927),
    [anon_sym_XMLPort] = ACTIONS(6927),
    [anon_sym_XmlPort] = ACTIONS(6927),
    [anon_sym_enum] = ACTIONS(6929),
    [anon_sym_ENUM] = ACTIONS(6929),
    [anon_sym_Enum] = ACTIONS(6929),
    [anon_sym_eNUM] = ACTIONS(6927),
    [anon_sym_eNum] = ACTIONS(6927),
    [anon_sym_ENum] = ACTIONS(6927),
    [anon_sym_enumextension] = ACTIONS(6927),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6927),
    [anon_sym_Enumextension] = ACTIONS(6927),
    [anon_sym_EnumExtension] = ACTIONS(6927),
    [anon_sym_enumExtension] = ACTIONS(6927),
    [sym_interface_keyword] = ACTIONS(6927),
    [anon_sym_controladdin] = ACTIONS(6927),
    [anon_sym_CONTROLADDIN] = ACTIONS(6927),
    [anon_sym_Controladdin] = ACTIONS(6927),
    [anon_sym_ControlAddIn] = ACTIONS(6927),
    [anon_sym_ControlAddin] = ACTIONS(6927),
    [anon_sym_controlAddIn] = ACTIONS(6927),
    [anon_sym_controlAddin] = ACTIONS(6927),
    [anon_sym_dotnet] = ACTIONS(6927),
    [anon_sym_DOTNET] = ACTIONS(6927),
    [anon_sym_Dotnet] = ACTIONS(6927),
    [anon_sym_DotNet] = ACTIONS(6927),
    [anon_sym_dotNet] = ACTIONS(6927),
    [sym_profile_keyword] = ACTIONS(6929),
    [anon_sym_profileextension] = ACTIONS(6927),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6927),
    [anon_sym_Profileextension] = ACTIONS(6927),
    [anon_sym_ProfileExtension] = ACTIONS(6927),
    [anon_sym_profileExtension] = ACTIONS(6927),
    [anon_sym_permissionset] = ACTIONS(6929),
    [anon_sym_PERMISSIONSET] = ACTIONS(6929),
    [anon_sym_Permissionset] = ACTIONS(6929),
    [anon_sym_PermissionSet] = ACTIONS(6929),
    [anon_sym_permissionSet] = ACTIONS(6929),
    [anon_sym_permissionsetextension] = ACTIONS(6927),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6927),
    [anon_sym_Permissionsetextension] = ACTIONS(6927),
    [anon_sym_PermissionSetExtension] = ACTIONS(6927),
    [anon_sym_permissionSetExtension] = ACTIONS(6927),
    [sym_entitlement_keyword] = ACTIONS(6927),
    [anon_sym_pagecustomization] = ACTIONS(6927),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6927),
    [anon_sym_Pagecustomization] = ACTIONS(6927),
    [anon_sym_PageCustomization] = ACTIONS(6927),
    [anon_sym_pageCustomization] = ACTIONS(6927),
    [sym_using_keyword] = ACTIONS(6927),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6927),
  },
  [STATE(3705)] = {
    [ts_builtin_sym_end] = ACTIONS(7011),
    [anon_sym_POUNDif] = ACTIONS(7011),
    [anon_sym_POUNDIF] = ACTIONS(7011),
    [anon_sym_POUNDIf] = ACTIONS(7011),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7013),
    [anon_sym_tableextension] = ACTIONS(7011),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7011),
    [anon_sym_Tableextension] = ACTIONS(7011),
    [anon_sym_TableExtension] = ACTIONS(7011),
    [anon_sym_tableExtension] = ACTIONS(7011),
    [sym_page_keyword] = ACTIONS(7013),
    [anon_sym_pageextension] = ACTIONS(7011),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7011),
    [anon_sym_Pageextension] = ACTIONS(7011),
    [anon_sym_PageExtension] = ACTIONS(7011),
    [anon_sym_pageExtension] = ACTIONS(7011),
    [anon_sym_codeunit] = ACTIONS(7011),
    [anon_sym_CODEUNIT] = ACTIONS(7011),
    [anon_sym_Codeunit] = ACTIONS(7011),
    [anon_sym_CodeUnit] = ACTIONS(7011),
    [anon_sym_COdeunit] = ACTIONS(7011),
    [anon_sym_codeUnit] = ACTIONS(7011),
    [sym_report_keyword] = ACTIONS(7013),
    [anon_sym_reportextension] = ACTIONS(7011),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7011),
    [anon_sym_Reportextension] = ACTIONS(7011),
    [anon_sym_ReportExtension] = ACTIONS(7011),
    [anon_sym_reportExtension] = ACTIONS(7011),
    [sym_query_keyword] = ACTIONS(7011),
    [anon_sym_xmlport] = ACTIONS(7011),
    [anon_sym_XMLPORT] = ACTIONS(7011),
    [anon_sym_Xmlport] = ACTIONS(7011),
    [anon_sym_XMLport] = ACTIONS(7011),
    [anon_sym_XMLPort] = ACTIONS(7011),
    [anon_sym_XmlPort] = ACTIONS(7011),
    [anon_sym_enum] = ACTIONS(7013),
    [anon_sym_ENUM] = ACTIONS(7013),
    [anon_sym_Enum] = ACTIONS(7013),
    [anon_sym_eNUM] = ACTIONS(7011),
    [anon_sym_eNum] = ACTIONS(7011),
    [anon_sym_ENum] = ACTIONS(7011),
    [anon_sym_enumextension] = ACTIONS(7011),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7011),
    [anon_sym_Enumextension] = ACTIONS(7011),
    [anon_sym_EnumExtension] = ACTIONS(7011),
    [anon_sym_enumExtension] = ACTIONS(7011),
    [sym_interface_keyword] = ACTIONS(7011),
    [anon_sym_controladdin] = ACTIONS(7011),
    [anon_sym_CONTROLADDIN] = ACTIONS(7011),
    [anon_sym_Controladdin] = ACTIONS(7011),
    [anon_sym_ControlAddIn] = ACTIONS(7011),
    [anon_sym_ControlAddin] = ACTIONS(7011),
    [anon_sym_controlAddIn] = ACTIONS(7011),
    [anon_sym_controlAddin] = ACTIONS(7011),
    [anon_sym_dotnet] = ACTIONS(7011),
    [anon_sym_DOTNET] = ACTIONS(7011),
    [anon_sym_Dotnet] = ACTIONS(7011),
    [anon_sym_DotNet] = ACTIONS(7011),
    [anon_sym_dotNet] = ACTIONS(7011),
    [sym_profile_keyword] = ACTIONS(7013),
    [anon_sym_profileextension] = ACTIONS(7011),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7011),
    [anon_sym_Profileextension] = ACTIONS(7011),
    [anon_sym_ProfileExtension] = ACTIONS(7011),
    [anon_sym_profileExtension] = ACTIONS(7011),
    [anon_sym_permissionset] = ACTIONS(7013),
    [anon_sym_PERMISSIONSET] = ACTIONS(7013),
    [anon_sym_Permissionset] = ACTIONS(7013),
    [anon_sym_PermissionSet] = ACTIONS(7013),
    [anon_sym_permissionSet] = ACTIONS(7013),
    [anon_sym_permissionsetextension] = ACTIONS(7011),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7011),
    [anon_sym_Permissionsetextension] = ACTIONS(7011),
    [anon_sym_PermissionSetExtension] = ACTIONS(7011),
    [anon_sym_permissionSetExtension] = ACTIONS(7011),
    [sym_entitlement_keyword] = ACTIONS(7011),
    [anon_sym_pagecustomization] = ACTIONS(7011),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7011),
    [anon_sym_Pagecustomization] = ACTIONS(7011),
    [anon_sym_PageCustomization] = ACTIONS(7011),
    [anon_sym_pageCustomization] = ACTIONS(7011),
    [sym_using_keyword] = ACTIONS(7011),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7011),
  },
  [STATE(3706)] = {
    [ts_builtin_sym_end] = ACTIONS(6846),
    [anon_sym_POUNDif] = ACTIONS(6846),
    [anon_sym_POUNDIF] = ACTIONS(6846),
    [anon_sym_POUNDIf] = ACTIONS(6846),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6848),
    [anon_sym_tableextension] = ACTIONS(6846),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6846),
    [anon_sym_Tableextension] = ACTIONS(6846),
    [anon_sym_TableExtension] = ACTIONS(6846),
    [anon_sym_tableExtension] = ACTIONS(6846),
    [sym_page_keyword] = ACTIONS(6848),
    [anon_sym_pageextension] = ACTIONS(6846),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6846),
    [anon_sym_Pageextension] = ACTIONS(6846),
    [anon_sym_PageExtension] = ACTIONS(6846),
    [anon_sym_pageExtension] = ACTIONS(6846),
    [anon_sym_codeunit] = ACTIONS(6846),
    [anon_sym_CODEUNIT] = ACTIONS(6846),
    [anon_sym_Codeunit] = ACTIONS(6846),
    [anon_sym_CodeUnit] = ACTIONS(6846),
    [anon_sym_COdeunit] = ACTIONS(6846),
    [anon_sym_codeUnit] = ACTIONS(6846),
    [sym_report_keyword] = ACTIONS(6848),
    [anon_sym_reportextension] = ACTIONS(6846),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6846),
    [anon_sym_Reportextension] = ACTIONS(6846),
    [anon_sym_ReportExtension] = ACTIONS(6846),
    [anon_sym_reportExtension] = ACTIONS(6846),
    [sym_query_keyword] = ACTIONS(6846),
    [anon_sym_xmlport] = ACTIONS(6846),
    [anon_sym_XMLPORT] = ACTIONS(6846),
    [anon_sym_Xmlport] = ACTIONS(6846),
    [anon_sym_XMLport] = ACTIONS(6846),
    [anon_sym_XMLPort] = ACTIONS(6846),
    [anon_sym_XmlPort] = ACTIONS(6846),
    [anon_sym_enum] = ACTIONS(6848),
    [anon_sym_ENUM] = ACTIONS(6848),
    [anon_sym_Enum] = ACTIONS(6848),
    [anon_sym_eNUM] = ACTIONS(6846),
    [anon_sym_eNum] = ACTIONS(6846),
    [anon_sym_ENum] = ACTIONS(6846),
    [anon_sym_enumextension] = ACTIONS(6846),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6846),
    [anon_sym_Enumextension] = ACTIONS(6846),
    [anon_sym_EnumExtension] = ACTIONS(6846),
    [anon_sym_enumExtension] = ACTIONS(6846),
    [sym_interface_keyword] = ACTIONS(6846),
    [anon_sym_controladdin] = ACTIONS(6846),
    [anon_sym_CONTROLADDIN] = ACTIONS(6846),
    [anon_sym_Controladdin] = ACTIONS(6846),
    [anon_sym_ControlAddIn] = ACTIONS(6846),
    [anon_sym_ControlAddin] = ACTIONS(6846),
    [anon_sym_controlAddIn] = ACTIONS(6846),
    [anon_sym_controlAddin] = ACTIONS(6846),
    [anon_sym_dotnet] = ACTIONS(6846),
    [anon_sym_DOTNET] = ACTIONS(6846),
    [anon_sym_Dotnet] = ACTIONS(6846),
    [anon_sym_DotNet] = ACTIONS(6846),
    [anon_sym_dotNet] = ACTIONS(6846),
    [sym_profile_keyword] = ACTIONS(6848),
    [anon_sym_profileextension] = ACTIONS(6846),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6846),
    [anon_sym_Profileextension] = ACTIONS(6846),
    [anon_sym_ProfileExtension] = ACTIONS(6846),
    [anon_sym_profileExtension] = ACTIONS(6846),
    [anon_sym_permissionset] = ACTIONS(6848),
    [anon_sym_PERMISSIONSET] = ACTIONS(6848),
    [anon_sym_Permissionset] = ACTIONS(6848),
    [anon_sym_PermissionSet] = ACTIONS(6848),
    [anon_sym_permissionSet] = ACTIONS(6848),
    [anon_sym_permissionsetextension] = ACTIONS(6846),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6846),
    [anon_sym_Permissionsetextension] = ACTIONS(6846),
    [anon_sym_PermissionSetExtension] = ACTIONS(6846),
    [anon_sym_permissionSetExtension] = ACTIONS(6846),
    [sym_entitlement_keyword] = ACTIONS(6846),
    [anon_sym_pagecustomization] = ACTIONS(6846),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6846),
    [anon_sym_Pagecustomization] = ACTIONS(6846),
    [anon_sym_PageCustomization] = ACTIONS(6846),
    [anon_sym_pageCustomization] = ACTIONS(6846),
    [sym_using_keyword] = ACTIONS(6846),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6846),
  },
  [STATE(3707)] = {
    [ts_builtin_sym_end] = ACTIONS(6961),
    [anon_sym_POUNDif] = ACTIONS(6961),
    [anon_sym_POUNDIF] = ACTIONS(6961),
    [anon_sym_POUNDIf] = ACTIONS(6961),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6963),
    [anon_sym_tableextension] = ACTIONS(6961),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6961),
    [anon_sym_Tableextension] = ACTIONS(6961),
    [anon_sym_TableExtension] = ACTIONS(6961),
    [anon_sym_tableExtension] = ACTIONS(6961),
    [sym_page_keyword] = ACTIONS(6963),
    [anon_sym_pageextension] = ACTIONS(6961),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6961),
    [anon_sym_Pageextension] = ACTIONS(6961),
    [anon_sym_PageExtension] = ACTIONS(6961),
    [anon_sym_pageExtension] = ACTIONS(6961),
    [anon_sym_codeunit] = ACTIONS(6961),
    [anon_sym_CODEUNIT] = ACTIONS(6961),
    [anon_sym_Codeunit] = ACTIONS(6961),
    [anon_sym_CodeUnit] = ACTIONS(6961),
    [anon_sym_COdeunit] = ACTIONS(6961),
    [anon_sym_codeUnit] = ACTIONS(6961),
    [sym_report_keyword] = ACTIONS(6963),
    [anon_sym_reportextension] = ACTIONS(6961),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6961),
    [anon_sym_Reportextension] = ACTIONS(6961),
    [anon_sym_ReportExtension] = ACTIONS(6961),
    [anon_sym_reportExtension] = ACTIONS(6961),
    [sym_query_keyword] = ACTIONS(6961),
    [anon_sym_xmlport] = ACTIONS(6961),
    [anon_sym_XMLPORT] = ACTIONS(6961),
    [anon_sym_Xmlport] = ACTIONS(6961),
    [anon_sym_XMLport] = ACTIONS(6961),
    [anon_sym_XMLPort] = ACTIONS(6961),
    [anon_sym_XmlPort] = ACTIONS(6961),
    [anon_sym_enum] = ACTIONS(6963),
    [anon_sym_ENUM] = ACTIONS(6963),
    [anon_sym_Enum] = ACTIONS(6963),
    [anon_sym_eNUM] = ACTIONS(6961),
    [anon_sym_eNum] = ACTIONS(6961),
    [anon_sym_ENum] = ACTIONS(6961),
    [anon_sym_enumextension] = ACTIONS(6961),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6961),
    [anon_sym_Enumextension] = ACTIONS(6961),
    [anon_sym_EnumExtension] = ACTIONS(6961),
    [anon_sym_enumExtension] = ACTIONS(6961),
    [sym_interface_keyword] = ACTIONS(6961),
    [anon_sym_controladdin] = ACTIONS(6961),
    [anon_sym_CONTROLADDIN] = ACTIONS(6961),
    [anon_sym_Controladdin] = ACTIONS(6961),
    [anon_sym_ControlAddIn] = ACTIONS(6961),
    [anon_sym_ControlAddin] = ACTIONS(6961),
    [anon_sym_controlAddIn] = ACTIONS(6961),
    [anon_sym_controlAddin] = ACTIONS(6961),
    [anon_sym_dotnet] = ACTIONS(6961),
    [anon_sym_DOTNET] = ACTIONS(6961),
    [anon_sym_Dotnet] = ACTIONS(6961),
    [anon_sym_DotNet] = ACTIONS(6961),
    [anon_sym_dotNet] = ACTIONS(6961),
    [sym_profile_keyword] = ACTIONS(6963),
    [anon_sym_profileextension] = ACTIONS(6961),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6961),
    [anon_sym_Profileextension] = ACTIONS(6961),
    [anon_sym_ProfileExtension] = ACTIONS(6961),
    [anon_sym_profileExtension] = ACTIONS(6961),
    [anon_sym_permissionset] = ACTIONS(6963),
    [anon_sym_PERMISSIONSET] = ACTIONS(6963),
    [anon_sym_Permissionset] = ACTIONS(6963),
    [anon_sym_PermissionSet] = ACTIONS(6963),
    [anon_sym_permissionSet] = ACTIONS(6963),
    [anon_sym_permissionsetextension] = ACTIONS(6961),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6961),
    [anon_sym_Permissionsetextension] = ACTIONS(6961),
    [anon_sym_PermissionSetExtension] = ACTIONS(6961),
    [anon_sym_permissionSetExtension] = ACTIONS(6961),
    [sym_entitlement_keyword] = ACTIONS(6961),
    [anon_sym_pagecustomization] = ACTIONS(6961),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6961),
    [anon_sym_Pagecustomization] = ACTIONS(6961),
    [anon_sym_PageCustomization] = ACTIONS(6961),
    [anon_sym_pageCustomization] = ACTIONS(6961),
    [sym_using_keyword] = ACTIONS(6961),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6961),
  },
  [STATE(3708)] = {
    [ts_builtin_sym_end] = ACTIONS(6876),
    [anon_sym_POUNDif] = ACTIONS(6876),
    [anon_sym_POUNDIF] = ACTIONS(6876),
    [anon_sym_POUNDIf] = ACTIONS(6876),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6878),
    [anon_sym_tableextension] = ACTIONS(6876),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6876),
    [anon_sym_Tableextension] = ACTIONS(6876),
    [anon_sym_TableExtension] = ACTIONS(6876),
    [anon_sym_tableExtension] = ACTIONS(6876),
    [sym_page_keyword] = ACTIONS(6878),
    [anon_sym_pageextension] = ACTIONS(6876),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6876),
    [anon_sym_Pageextension] = ACTIONS(6876),
    [anon_sym_PageExtension] = ACTIONS(6876),
    [anon_sym_pageExtension] = ACTIONS(6876),
    [anon_sym_codeunit] = ACTIONS(6876),
    [anon_sym_CODEUNIT] = ACTIONS(6876),
    [anon_sym_Codeunit] = ACTIONS(6876),
    [anon_sym_CodeUnit] = ACTIONS(6876),
    [anon_sym_COdeunit] = ACTIONS(6876),
    [anon_sym_codeUnit] = ACTIONS(6876),
    [sym_report_keyword] = ACTIONS(6878),
    [anon_sym_reportextension] = ACTIONS(6876),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6876),
    [anon_sym_Reportextension] = ACTIONS(6876),
    [anon_sym_ReportExtension] = ACTIONS(6876),
    [anon_sym_reportExtension] = ACTIONS(6876),
    [sym_query_keyword] = ACTIONS(6876),
    [anon_sym_xmlport] = ACTIONS(6876),
    [anon_sym_XMLPORT] = ACTIONS(6876),
    [anon_sym_Xmlport] = ACTIONS(6876),
    [anon_sym_XMLport] = ACTIONS(6876),
    [anon_sym_XMLPort] = ACTIONS(6876),
    [anon_sym_XmlPort] = ACTIONS(6876),
    [anon_sym_enum] = ACTIONS(6878),
    [anon_sym_ENUM] = ACTIONS(6878),
    [anon_sym_Enum] = ACTIONS(6878),
    [anon_sym_eNUM] = ACTIONS(6876),
    [anon_sym_eNum] = ACTIONS(6876),
    [anon_sym_ENum] = ACTIONS(6876),
    [anon_sym_enumextension] = ACTIONS(6876),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6876),
    [anon_sym_Enumextension] = ACTIONS(6876),
    [anon_sym_EnumExtension] = ACTIONS(6876),
    [anon_sym_enumExtension] = ACTIONS(6876),
    [sym_interface_keyword] = ACTIONS(6876),
    [anon_sym_controladdin] = ACTIONS(6876),
    [anon_sym_CONTROLADDIN] = ACTIONS(6876),
    [anon_sym_Controladdin] = ACTIONS(6876),
    [anon_sym_ControlAddIn] = ACTIONS(6876),
    [anon_sym_ControlAddin] = ACTIONS(6876),
    [anon_sym_controlAddIn] = ACTIONS(6876),
    [anon_sym_controlAddin] = ACTIONS(6876),
    [anon_sym_dotnet] = ACTIONS(6876),
    [anon_sym_DOTNET] = ACTIONS(6876),
    [anon_sym_Dotnet] = ACTIONS(6876),
    [anon_sym_DotNet] = ACTIONS(6876),
    [anon_sym_dotNet] = ACTIONS(6876),
    [sym_profile_keyword] = ACTIONS(6878),
    [anon_sym_profileextension] = ACTIONS(6876),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6876),
    [anon_sym_Profileextension] = ACTIONS(6876),
    [anon_sym_ProfileExtension] = ACTIONS(6876),
    [anon_sym_profileExtension] = ACTIONS(6876),
    [anon_sym_permissionset] = ACTIONS(6878),
    [anon_sym_PERMISSIONSET] = ACTIONS(6878),
    [anon_sym_Permissionset] = ACTIONS(6878),
    [anon_sym_PermissionSet] = ACTIONS(6878),
    [anon_sym_permissionSet] = ACTIONS(6878),
    [anon_sym_permissionsetextension] = ACTIONS(6876),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6876),
    [anon_sym_Permissionsetextension] = ACTIONS(6876),
    [anon_sym_PermissionSetExtension] = ACTIONS(6876),
    [anon_sym_permissionSetExtension] = ACTIONS(6876),
    [sym_entitlement_keyword] = ACTIONS(6876),
    [anon_sym_pagecustomization] = ACTIONS(6876),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6876),
    [anon_sym_Pagecustomization] = ACTIONS(6876),
    [anon_sym_PageCustomization] = ACTIONS(6876),
    [anon_sym_pageCustomization] = ACTIONS(6876),
    [sym_using_keyword] = ACTIONS(6876),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6876),
  },
  [STATE(3709)] = {
    [ts_builtin_sym_end] = ACTIONS(6977),
    [anon_sym_POUNDif] = ACTIONS(6977),
    [anon_sym_POUNDIF] = ACTIONS(6977),
    [anon_sym_POUNDIf] = ACTIONS(6977),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6979),
    [anon_sym_tableextension] = ACTIONS(6977),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6977),
    [anon_sym_Tableextension] = ACTIONS(6977),
    [anon_sym_TableExtension] = ACTIONS(6977),
    [anon_sym_tableExtension] = ACTIONS(6977),
    [sym_page_keyword] = ACTIONS(6979),
    [anon_sym_pageextension] = ACTIONS(6977),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6977),
    [anon_sym_Pageextension] = ACTIONS(6977),
    [anon_sym_PageExtension] = ACTIONS(6977),
    [anon_sym_pageExtension] = ACTIONS(6977),
    [anon_sym_codeunit] = ACTIONS(6977),
    [anon_sym_CODEUNIT] = ACTIONS(6977),
    [anon_sym_Codeunit] = ACTIONS(6977),
    [anon_sym_CodeUnit] = ACTIONS(6977),
    [anon_sym_COdeunit] = ACTIONS(6977),
    [anon_sym_codeUnit] = ACTIONS(6977),
    [sym_report_keyword] = ACTIONS(6979),
    [anon_sym_reportextension] = ACTIONS(6977),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6977),
    [anon_sym_Reportextension] = ACTIONS(6977),
    [anon_sym_ReportExtension] = ACTIONS(6977),
    [anon_sym_reportExtension] = ACTIONS(6977),
    [sym_query_keyword] = ACTIONS(6977),
    [anon_sym_xmlport] = ACTIONS(6977),
    [anon_sym_XMLPORT] = ACTIONS(6977),
    [anon_sym_Xmlport] = ACTIONS(6977),
    [anon_sym_XMLport] = ACTIONS(6977),
    [anon_sym_XMLPort] = ACTIONS(6977),
    [anon_sym_XmlPort] = ACTIONS(6977),
    [anon_sym_enum] = ACTIONS(6979),
    [anon_sym_ENUM] = ACTIONS(6979),
    [anon_sym_Enum] = ACTIONS(6979),
    [anon_sym_eNUM] = ACTIONS(6977),
    [anon_sym_eNum] = ACTIONS(6977),
    [anon_sym_ENum] = ACTIONS(6977),
    [anon_sym_enumextension] = ACTIONS(6977),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6977),
    [anon_sym_Enumextension] = ACTIONS(6977),
    [anon_sym_EnumExtension] = ACTIONS(6977),
    [anon_sym_enumExtension] = ACTIONS(6977),
    [sym_interface_keyword] = ACTIONS(6977),
    [anon_sym_controladdin] = ACTIONS(6977),
    [anon_sym_CONTROLADDIN] = ACTIONS(6977),
    [anon_sym_Controladdin] = ACTIONS(6977),
    [anon_sym_ControlAddIn] = ACTIONS(6977),
    [anon_sym_ControlAddin] = ACTIONS(6977),
    [anon_sym_controlAddIn] = ACTIONS(6977),
    [anon_sym_controlAddin] = ACTIONS(6977),
    [anon_sym_dotnet] = ACTIONS(6977),
    [anon_sym_DOTNET] = ACTIONS(6977),
    [anon_sym_Dotnet] = ACTIONS(6977),
    [anon_sym_DotNet] = ACTIONS(6977),
    [anon_sym_dotNet] = ACTIONS(6977),
    [sym_profile_keyword] = ACTIONS(6979),
    [anon_sym_profileextension] = ACTIONS(6977),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6977),
    [anon_sym_Profileextension] = ACTIONS(6977),
    [anon_sym_ProfileExtension] = ACTIONS(6977),
    [anon_sym_profileExtension] = ACTIONS(6977),
    [anon_sym_permissionset] = ACTIONS(6979),
    [anon_sym_PERMISSIONSET] = ACTIONS(6979),
    [anon_sym_Permissionset] = ACTIONS(6979),
    [anon_sym_PermissionSet] = ACTIONS(6979),
    [anon_sym_permissionSet] = ACTIONS(6979),
    [anon_sym_permissionsetextension] = ACTIONS(6977),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6977),
    [anon_sym_Permissionsetextension] = ACTIONS(6977),
    [anon_sym_PermissionSetExtension] = ACTIONS(6977),
    [anon_sym_permissionSetExtension] = ACTIONS(6977),
    [sym_entitlement_keyword] = ACTIONS(6977),
    [anon_sym_pagecustomization] = ACTIONS(6977),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6977),
    [anon_sym_Pagecustomization] = ACTIONS(6977),
    [anon_sym_PageCustomization] = ACTIONS(6977),
    [anon_sym_pageCustomization] = ACTIONS(6977),
    [sym_using_keyword] = ACTIONS(6977),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6977),
  },
  [STATE(3710)] = {
    [ts_builtin_sym_end] = ACTIONS(6880),
    [anon_sym_POUNDif] = ACTIONS(6880),
    [anon_sym_POUNDIF] = ACTIONS(6880),
    [anon_sym_POUNDIf] = ACTIONS(6880),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6882),
    [anon_sym_tableextension] = ACTIONS(6880),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6880),
    [anon_sym_Tableextension] = ACTIONS(6880),
    [anon_sym_TableExtension] = ACTIONS(6880),
    [anon_sym_tableExtension] = ACTIONS(6880),
    [sym_page_keyword] = ACTIONS(6882),
    [anon_sym_pageextension] = ACTIONS(6880),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6880),
    [anon_sym_Pageextension] = ACTIONS(6880),
    [anon_sym_PageExtension] = ACTIONS(6880),
    [anon_sym_pageExtension] = ACTIONS(6880),
    [anon_sym_codeunit] = ACTIONS(6880),
    [anon_sym_CODEUNIT] = ACTIONS(6880),
    [anon_sym_Codeunit] = ACTIONS(6880),
    [anon_sym_CodeUnit] = ACTIONS(6880),
    [anon_sym_COdeunit] = ACTIONS(6880),
    [anon_sym_codeUnit] = ACTIONS(6880),
    [sym_report_keyword] = ACTIONS(6882),
    [anon_sym_reportextension] = ACTIONS(6880),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6880),
    [anon_sym_Reportextension] = ACTIONS(6880),
    [anon_sym_ReportExtension] = ACTIONS(6880),
    [anon_sym_reportExtension] = ACTIONS(6880),
    [sym_query_keyword] = ACTIONS(6880),
    [anon_sym_xmlport] = ACTIONS(6880),
    [anon_sym_XMLPORT] = ACTIONS(6880),
    [anon_sym_Xmlport] = ACTIONS(6880),
    [anon_sym_XMLport] = ACTIONS(6880),
    [anon_sym_XMLPort] = ACTIONS(6880),
    [anon_sym_XmlPort] = ACTIONS(6880),
    [anon_sym_enum] = ACTIONS(6882),
    [anon_sym_ENUM] = ACTIONS(6882),
    [anon_sym_Enum] = ACTIONS(6882),
    [anon_sym_eNUM] = ACTIONS(6880),
    [anon_sym_eNum] = ACTIONS(6880),
    [anon_sym_ENum] = ACTIONS(6880),
    [anon_sym_enumextension] = ACTIONS(6880),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6880),
    [anon_sym_Enumextension] = ACTIONS(6880),
    [anon_sym_EnumExtension] = ACTIONS(6880),
    [anon_sym_enumExtension] = ACTIONS(6880),
    [sym_interface_keyword] = ACTIONS(6880),
    [anon_sym_controladdin] = ACTIONS(6880),
    [anon_sym_CONTROLADDIN] = ACTIONS(6880),
    [anon_sym_Controladdin] = ACTIONS(6880),
    [anon_sym_ControlAddIn] = ACTIONS(6880),
    [anon_sym_ControlAddin] = ACTIONS(6880),
    [anon_sym_controlAddIn] = ACTIONS(6880),
    [anon_sym_controlAddin] = ACTIONS(6880),
    [anon_sym_dotnet] = ACTIONS(6880),
    [anon_sym_DOTNET] = ACTIONS(6880),
    [anon_sym_Dotnet] = ACTIONS(6880),
    [anon_sym_DotNet] = ACTIONS(6880),
    [anon_sym_dotNet] = ACTIONS(6880),
    [sym_profile_keyword] = ACTIONS(6882),
    [anon_sym_profileextension] = ACTIONS(6880),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6880),
    [anon_sym_Profileextension] = ACTIONS(6880),
    [anon_sym_ProfileExtension] = ACTIONS(6880),
    [anon_sym_profileExtension] = ACTIONS(6880),
    [anon_sym_permissionset] = ACTIONS(6882),
    [anon_sym_PERMISSIONSET] = ACTIONS(6882),
    [anon_sym_Permissionset] = ACTIONS(6882),
    [anon_sym_PermissionSet] = ACTIONS(6882),
    [anon_sym_permissionSet] = ACTIONS(6882),
    [anon_sym_permissionsetextension] = ACTIONS(6880),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6880),
    [anon_sym_Permissionsetextension] = ACTIONS(6880),
    [anon_sym_PermissionSetExtension] = ACTIONS(6880),
    [anon_sym_permissionSetExtension] = ACTIONS(6880),
    [sym_entitlement_keyword] = ACTIONS(6880),
    [anon_sym_pagecustomization] = ACTIONS(6880),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6880),
    [anon_sym_Pagecustomization] = ACTIONS(6880),
    [anon_sym_PageCustomization] = ACTIONS(6880),
    [anon_sym_pageCustomization] = ACTIONS(6880),
    [sym_using_keyword] = ACTIONS(6880),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6880),
  },
  [STATE(3711)] = {
    [ts_builtin_sym_end] = ACTIONS(6969),
    [anon_sym_POUNDif] = ACTIONS(6969),
    [anon_sym_POUNDIF] = ACTIONS(6969),
    [anon_sym_POUNDIf] = ACTIONS(6969),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6971),
    [anon_sym_tableextension] = ACTIONS(6969),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6969),
    [anon_sym_Tableextension] = ACTIONS(6969),
    [anon_sym_TableExtension] = ACTIONS(6969),
    [anon_sym_tableExtension] = ACTIONS(6969),
    [sym_page_keyword] = ACTIONS(6971),
    [anon_sym_pageextension] = ACTIONS(6969),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6969),
    [anon_sym_Pageextension] = ACTIONS(6969),
    [anon_sym_PageExtension] = ACTIONS(6969),
    [anon_sym_pageExtension] = ACTIONS(6969),
    [anon_sym_codeunit] = ACTIONS(6969),
    [anon_sym_CODEUNIT] = ACTIONS(6969),
    [anon_sym_Codeunit] = ACTIONS(6969),
    [anon_sym_CodeUnit] = ACTIONS(6969),
    [anon_sym_COdeunit] = ACTIONS(6969),
    [anon_sym_codeUnit] = ACTIONS(6969),
    [sym_report_keyword] = ACTIONS(6971),
    [anon_sym_reportextension] = ACTIONS(6969),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6969),
    [anon_sym_Reportextension] = ACTIONS(6969),
    [anon_sym_ReportExtension] = ACTIONS(6969),
    [anon_sym_reportExtension] = ACTIONS(6969),
    [sym_query_keyword] = ACTIONS(6969),
    [anon_sym_xmlport] = ACTIONS(6969),
    [anon_sym_XMLPORT] = ACTIONS(6969),
    [anon_sym_Xmlport] = ACTIONS(6969),
    [anon_sym_XMLport] = ACTIONS(6969),
    [anon_sym_XMLPort] = ACTIONS(6969),
    [anon_sym_XmlPort] = ACTIONS(6969),
    [anon_sym_enum] = ACTIONS(6971),
    [anon_sym_ENUM] = ACTIONS(6971),
    [anon_sym_Enum] = ACTIONS(6971),
    [anon_sym_eNUM] = ACTIONS(6969),
    [anon_sym_eNum] = ACTIONS(6969),
    [anon_sym_ENum] = ACTIONS(6969),
    [anon_sym_enumextension] = ACTIONS(6969),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6969),
    [anon_sym_Enumextension] = ACTIONS(6969),
    [anon_sym_EnumExtension] = ACTIONS(6969),
    [anon_sym_enumExtension] = ACTIONS(6969),
    [sym_interface_keyword] = ACTIONS(6969),
    [anon_sym_controladdin] = ACTIONS(6969),
    [anon_sym_CONTROLADDIN] = ACTIONS(6969),
    [anon_sym_Controladdin] = ACTIONS(6969),
    [anon_sym_ControlAddIn] = ACTIONS(6969),
    [anon_sym_ControlAddin] = ACTIONS(6969),
    [anon_sym_controlAddIn] = ACTIONS(6969),
    [anon_sym_controlAddin] = ACTIONS(6969),
    [anon_sym_dotnet] = ACTIONS(6969),
    [anon_sym_DOTNET] = ACTIONS(6969),
    [anon_sym_Dotnet] = ACTIONS(6969),
    [anon_sym_DotNet] = ACTIONS(6969),
    [anon_sym_dotNet] = ACTIONS(6969),
    [sym_profile_keyword] = ACTIONS(6971),
    [anon_sym_profileextension] = ACTIONS(6969),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6969),
    [anon_sym_Profileextension] = ACTIONS(6969),
    [anon_sym_ProfileExtension] = ACTIONS(6969),
    [anon_sym_profileExtension] = ACTIONS(6969),
    [anon_sym_permissionset] = ACTIONS(6971),
    [anon_sym_PERMISSIONSET] = ACTIONS(6971),
    [anon_sym_Permissionset] = ACTIONS(6971),
    [anon_sym_PermissionSet] = ACTIONS(6971),
    [anon_sym_permissionSet] = ACTIONS(6971),
    [anon_sym_permissionsetextension] = ACTIONS(6969),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6969),
    [anon_sym_Permissionsetextension] = ACTIONS(6969),
    [anon_sym_PermissionSetExtension] = ACTIONS(6969),
    [anon_sym_permissionSetExtension] = ACTIONS(6969),
    [sym_entitlement_keyword] = ACTIONS(6969),
    [anon_sym_pagecustomization] = ACTIONS(6969),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6969),
    [anon_sym_Pagecustomization] = ACTIONS(6969),
    [anon_sym_PageCustomization] = ACTIONS(6969),
    [anon_sym_pageCustomization] = ACTIONS(6969),
    [sym_using_keyword] = ACTIONS(6969),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6969),
  },
  [STATE(3712)] = {
    [ts_builtin_sym_end] = ACTIONS(6866),
    [anon_sym_POUNDif] = ACTIONS(6866),
    [anon_sym_POUNDIF] = ACTIONS(6866),
    [anon_sym_POUNDIf] = ACTIONS(6866),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6868),
    [anon_sym_tableextension] = ACTIONS(6866),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6866),
    [anon_sym_Tableextension] = ACTIONS(6866),
    [anon_sym_TableExtension] = ACTIONS(6866),
    [anon_sym_tableExtension] = ACTIONS(6866),
    [sym_page_keyword] = ACTIONS(6868),
    [anon_sym_pageextension] = ACTIONS(6866),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6866),
    [anon_sym_Pageextension] = ACTIONS(6866),
    [anon_sym_PageExtension] = ACTIONS(6866),
    [anon_sym_pageExtension] = ACTIONS(6866),
    [anon_sym_codeunit] = ACTIONS(6866),
    [anon_sym_CODEUNIT] = ACTIONS(6866),
    [anon_sym_Codeunit] = ACTIONS(6866),
    [anon_sym_CodeUnit] = ACTIONS(6866),
    [anon_sym_COdeunit] = ACTIONS(6866),
    [anon_sym_codeUnit] = ACTIONS(6866),
    [sym_report_keyword] = ACTIONS(6868),
    [anon_sym_reportextension] = ACTIONS(6866),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6866),
    [anon_sym_Reportextension] = ACTIONS(6866),
    [anon_sym_ReportExtension] = ACTIONS(6866),
    [anon_sym_reportExtension] = ACTIONS(6866),
    [sym_query_keyword] = ACTIONS(6866),
    [anon_sym_xmlport] = ACTIONS(6866),
    [anon_sym_XMLPORT] = ACTIONS(6866),
    [anon_sym_Xmlport] = ACTIONS(6866),
    [anon_sym_XMLport] = ACTIONS(6866),
    [anon_sym_XMLPort] = ACTIONS(6866),
    [anon_sym_XmlPort] = ACTIONS(6866),
    [anon_sym_enum] = ACTIONS(6868),
    [anon_sym_ENUM] = ACTIONS(6868),
    [anon_sym_Enum] = ACTIONS(6868),
    [anon_sym_eNUM] = ACTIONS(6866),
    [anon_sym_eNum] = ACTIONS(6866),
    [anon_sym_ENum] = ACTIONS(6866),
    [anon_sym_enumextension] = ACTIONS(6866),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6866),
    [anon_sym_Enumextension] = ACTIONS(6866),
    [anon_sym_EnumExtension] = ACTIONS(6866),
    [anon_sym_enumExtension] = ACTIONS(6866),
    [sym_interface_keyword] = ACTIONS(6866),
    [anon_sym_controladdin] = ACTIONS(6866),
    [anon_sym_CONTROLADDIN] = ACTIONS(6866),
    [anon_sym_Controladdin] = ACTIONS(6866),
    [anon_sym_ControlAddIn] = ACTIONS(6866),
    [anon_sym_ControlAddin] = ACTIONS(6866),
    [anon_sym_controlAddIn] = ACTIONS(6866),
    [anon_sym_controlAddin] = ACTIONS(6866),
    [anon_sym_dotnet] = ACTIONS(6866),
    [anon_sym_DOTNET] = ACTIONS(6866),
    [anon_sym_Dotnet] = ACTIONS(6866),
    [anon_sym_DotNet] = ACTIONS(6866),
    [anon_sym_dotNet] = ACTIONS(6866),
    [sym_profile_keyword] = ACTIONS(6868),
    [anon_sym_profileextension] = ACTIONS(6866),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6866),
    [anon_sym_Profileextension] = ACTIONS(6866),
    [anon_sym_ProfileExtension] = ACTIONS(6866),
    [anon_sym_profileExtension] = ACTIONS(6866),
    [anon_sym_permissionset] = ACTIONS(6868),
    [anon_sym_PERMISSIONSET] = ACTIONS(6868),
    [anon_sym_Permissionset] = ACTIONS(6868),
    [anon_sym_PermissionSet] = ACTIONS(6868),
    [anon_sym_permissionSet] = ACTIONS(6868),
    [anon_sym_permissionsetextension] = ACTIONS(6866),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6866),
    [anon_sym_Permissionsetextension] = ACTIONS(6866),
    [anon_sym_PermissionSetExtension] = ACTIONS(6866),
    [anon_sym_permissionSetExtension] = ACTIONS(6866),
    [sym_entitlement_keyword] = ACTIONS(6866),
    [anon_sym_pagecustomization] = ACTIONS(6866),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6866),
    [anon_sym_Pagecustomization] = ACTIONS(6866),
    [anon_sym_PageCustomization] = ACTIONS(6866),
    [anon_sym_pageCustomization] = ACTIONS(6866),
    [sym_using_keyword] = ACTIONS(6866),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6866),
  },
  [STATE(3713)] = {
    [ts_builtin_sym_end] = ACTIONS(7121),
    [anon_sym_POUNDif] = ACTIONS(7121),
    [anon_sym_POUNDIF] = ACTIONS(7121),
    [anon_sym_POUNDIf] = ACTIONS(7121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7123),
    [anon_sym_tableextension] = ACTIONS(7121),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7121),
    [anon_sym_Tableextension] = ACTIONS(7121),
    [anon_sym_TableExtension] = ACTIONS(7121),
    [anon_sym_tableExtension] = ACTIONS(7121),
    [sym_page_keyword] = ACTIONS(7123),
    [anon_sym_pageextension] = ACTIONS(7121),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7121),
    [anon_sym_Pageextension] = ACTIONS(7121),
    [anon_sym_PageExtension] = ACTIONS(7121),
    [anon_sym_pageExtension] = ACTIONS(7121),
    [anon_sym_codeunit] = ACTIONS(7121),
    [anon_sym_CODEUNIT] = ACTIONS(7121),
    [anon_sym_Codeunit] = ACTIONS(7121),
    [anon_sym_CodeUnit] = ACTIONS(7121),
    [anon_sym_COdeunit] = ACTIONS(7121),
    [anon_sym_codeUnit] = ACTIONS(7121),
    [sym_report_keyword] = ACTIONS(7123),
    [anon_sym_reportextension] = ACTIONS(7121),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7121),
    [anon_sym_Reportextension] = ACTIONS(7121),
    [anon_sym_ReportExtension] = ACTIONS(7121),
    [anon_sym_reportExtension] = ACTIONS(7121),
    [sym_query_keyword] = ACTIONS(7121),
    [anon_sym_xmlport] = ACTIONS(7121),
    [anon_sym_XMLPORT] = ACTIONS(7121),
    [anon_sym_Xmlport] = ACTIONS(7121),
    [anon_sym_XMLport] = ACTIONS(7121),
    [anon_sym_XMLPort] = ACTIONS(7121),
    [anon_sym_XmlPort] = ACTIONS(7121),
    [anon_sym_enum] = ACTIONS(7123),
    [anon_sym_ENUM] = ACTIONS(7123),
    [anon_sym_Enum] = ACTIONS(7123),
    [anon_sym_eNUM] = ACTIONS(7121),
    [anon_sym_eNum] = ACTIONS(7121),
    [anon_sym_ENum] = ACTIONS(7121),
    [anon_sym_enumextension] = ACTIONS(7121),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7121),
    [anon_sym_Enumextension] = ACTIONS(7121),
    [anon_sym_EnumExtension] = ACTIONS(7121),
    [anon_sym_enumExtension] = ACTIONS(7121),
    [sym_interface_keyword] = ACTIONS(7121),
    [anon_sym_controladdin] = ACTIONS(7121),
    [anon_sym_CONTROLADDIN] = ACTIONS(7121),
    [anon_sym_Controladdin] = ACTIONS(7121),
    [anon_sym_ControlAddIn] = ACTIONS(7121),
    [anon_sym_ControlAddin] = ACTIONS(7121),
    [anon_sym_controlAddIn] = ACTIONS(7121),
    [anon_sym_controlAddin] = ACTIONS(7121),
    [anon_sym_dotnet] = ACTIONS(7121),
    [anon_sym_DOTNET] = ACTIONS(7121),
    [anon_sym_Dotnet] = ACTIONS(7121),
    [anon_sym_DotNet] = ACTIONS(7121),
    [anon_sym_dotNet] = ACTIONS(7121),
    [sym_profile_keyword] = ACTIONS(7123),
    [anon_sym_profileextension] = ACTIONS(7121),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7121),
    [anon_sym_Profileextension] = ACTIONS(7121),
    [anon_sym_ProfileExtension] = ACTIONS(7121),
    [anon_sym_profileExtension] = ACTIONS(7121),
    [anon_sym_permissionset] = ACTIONS(7123),
    [anon_sym_PERMISSIONSET] = ACTIONS(7123),
    [anon_sym_Permissionset] = ACTIONS(7123),
    [anon_sym_PermissionSet] = ACTIONS(7123),
    [anon_sym_permissionSet] = ACTIONS(7123),
    [anon_sym_permissionsetextension] = ACTIONS(7121),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7121),
    [anon_sym_Permissionsetextension] = ACTIONS(7121),
    [anon_sym_PermissionSetExtension] = ACTIONS(7121),
    [anon_sym_permissionSetExtension] = ACTIONS(7121),
    [sym_entitlement_keyword] = ACTIONS(7121),
    [anon_sym_pagecustomization] = ACTIONS(7121),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7121),
    [anon_sym_Pagecustomization] = ACTIONS(7121),
    [anon_sym_PageCustomization] = ACTIONS(7121),
    [anon_sym_pageCustomization] = ACTIONS(7121),
    [sym_using_keyword] = ACTIONS(7121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7121),
  },
  [STATE(3714)] = {
    [ts_builtin_sym_end] = ACTIONS(7157),
    [anon_sym_POUNDif] = ACTIONS(7157),
    [anon_sym_POUNDIF] = ACTIONS(7157),
    [anon_sym_POUNDIf] = ACTIONS(7157),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7159),
    [anon_sym_tableextension] = ACTIONS(7157),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7157),
    [anon_sym_Tableextension] = ACTIONS(7157),
    [anon_sym_TableExtension] = ACTIONS(7157),
    [anon_sym_tableExtension] = ACTIONS(7157),
    [sym_page_keyword] = ACTIONS(7159),
    [anon_sym_pageextension] = ACTIONS(7157),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7157),
    [anon_sym_Pageextension] = ACTIONS(7157),
    [anon_sym_PageExtension] = ACTIONS(7157),
    [anon_sym_pageExtension] = ACTIONS(7157),
    [anon_sym_codeunit] = ACTIONS(7157),
    [anon_sym_CODEUNIT] = ACTIONS(7157),
    [anon_sym_Codeunit] = ACTIONS(7157),
    [anon_sym_CodeUnit] = ACTIONS(7157),
    [anon_sym_COdeunit] = ACTIONS(7157),
    [anon_sym_codeUnit] = ACTIONS(7157),
    [sym_report_keyword] = ACTIONS(7159),
    [anon_sym_reportextension] = ACTIONS(7157),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7157),
    [anon_sym_Reportextension] = ACTIONS(7157),
    [anon_sym_ReportExtension] = ACTIONS(7157),
    [anon_sym_reportExtension] = ACTIONS(7157),
    [sym_query_keyword] = ACTIONS(7157),
    [anon_sym_xmlport] = ACTIONS(7157),
    [anon_sym_XMLPORT] = ACTIONS(7157),
    [anon_sym_Xmlport] = ACTIONS(7157),
    [anon_sym_XMLport] = ACTIONS(7157),
    [anon_sym_XMLPort] = ACTIONS(7157),
    [anon_sym_XmlPort] = ACTIONS(7157),
    [anon_sym_enum] = ACTIONS(7159),
    [anon_sym_ENUM] = ACTIONS(7159),
    [anon_sym_Enum] = ACTIONS(7159),
    [anon_sym_eNUM] = ACTIONS(7157),
    [anon_sym_eNum] = ACTIONS(7157),
    [anon_sym_ENum] = ACTIONS(7157),
    [anon_sym_enumextension] = ACTIONS(7157),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7157),
    [anon_sym_Enumextension] = ACTIONS(7157),
    [anon_sym_EnumExtension] = ACTIONS(7157),
    [anon_sym_enumExtension] = ACTIONS(7157),
    [sym_interface_keyword] = ACTIONS(7157),
    [anon_sym_controladdin] = ACTIONS(7157),
    [anon_sym_CONTROLADDIN] = ACTIONS(7157),
    [anon_sym_Controladdin] = ACTIONS(7157),
    [anon_sym_ControlAddIn] = ACTIONS(7157),
    [anon_sym_ControlAddin] = ACTIONS(7157),
    [anon_sym_controlAddIn] = ACTIONS(7157),
    [anon_sym_controlAddin] = ACTIONS(7157),
    [anon_sym_dotnet] = ACTIONS(7157),
    [anon_sym_DOTNET] = ACTIONS(7157),
    [anon_sym_Dotnet] = ACTIONS(7157),
    [anon_sym_DotNet] = ACTIONS(7157),
    [anon_sym_dotNet] = ACTIONS(7157),
    [sym_profile_keyword] = ACTIONS(7159),
    [anon_sym_profileextension] = ACTIONS(7157),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7157),
    [anon_sym_Profileextension] = ACTIONS(7157),
    [anon_sym_ProfileExtension] = ACTIONS(7157),
    [anon_sym_profileExtension] = ACTIONS(7157),
    [anon_sym_permissionset] = ACTIONS(7159),
    [anon_sym_PERMISSIONSET] = ACTIONS(7159),
    [anon_sym_Permissionset] = ACTIONS(7159),
    [anon_sym_PermissionSet] = ACTIONS(7159),
    [anon_sym_permissionSet] = ACTIONS(7159),
    [anon_sym_permissionsetextension] = ACTIONS(7157),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7157),
    [anon_sym_Permissionsetextension] = ACTIONS(7157),
    [anon_sym_PermissionSetExtension] = ACTIONS(7157),
    [anon_sym_permissionSetExtension] = ACTIONS(7157),
    [sym_entitlement_keyword] = ACTIONS(7157),
    [anon_sym_pagecustomization] = ACTIONS(7157),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7157),
    [anon_sym_Pagecustomization] = ACTIONS(7157),
    [anon_sym_PageCustomization] = ACTIONS(7157),
    [anon_sym_pageCustomization] = ACTIONS(7157),
    [sym_using_keyword] = ACTIONS(7157),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7157),
  },
  [STATE(3715)] = {
    [ts_builtin_sym_end] = ACTIONS(7019),
    [anon_sym_POUNDif] = ACTIONS(7019),
    [anon_sym_POUNDIF] = ACTIONS(7019),
    [anon_sym_POUNDIf] = ACTIONS(7019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7021),
    [anon_sym_tableextension] = ACTIONS(7019),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7019),
    [anon_sym_Tableextension] = ACTIONS(7019),
    [anon_sym_TableExtension] = ACTIONS(7019),
    [anon_sym_tableExtension] = ACTIONS(7019),
    [sym_page_keyword] = ACTIONS(7021),
    [anon_sym_pageextension] = ACTIONS(7019),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7019),
    [anon_sym_Pageextension] = ACTIONS(7019),
    [anon_sym_PageExtension] = ACTIONS(7019),
    [anon_sym_pageExtension] = ACTIONS(7019),
    [anon_sym_codeunit] = ACTIONS(7019),
    [anon_sym_CODEUNIT] = ACTIONS(7019),
    [anon_sym_Codeunit] = ACTIONS(7019),
    [anon_sym_CodeUnit] = ACTIONS(7019),
    [anon_sym_COdeunit] = ACTIONS(7019),
    [anon_sym_codeUnit] = ACTIONS(7019),
    [sym_report_keyword] = ACTIONS(7021),
    [anon_sym_reportextension] = ACTIONS(7019),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7019),
    [anon_sym_Reportextension] = ACTIONS(7019),
    [anon_sym_ReportExtension] = ACTIONS(7019),
    [anon_sym_reportExtension] = ACTIONS(7019),
    [sym_query_keyword] = ACTIONS(7019),
    [anon_sym_xmlport] = ACTIONS(7019),
    [anon_sym_XMLPORT] = ACTIONS(7019),
    [anon_sym_Xmlport] = ACTIONS(7019),
    [anon_sym_XMLport] = ACTIONS(7019),
    [anon_sym_XMLPort] = ACTIONS(7019),
    [anon_sym_XmlPort] = ACTIONS(7019),
    [anon_sym_enum] = ACTIONS(7021),
    [anon_sym_ENUM] = ACTIONS(7021),
    [anon_sym_Enum] = ACTIONS(7021),
    [anon_sym_eNUM] = ACTIONS(7019),
    [anon_sym_eNum] = ACTIONS(7019),
    [anon_sym_ENum] = ACTIONS(7019),
    [anon_sym_enumextension] = ACTIONS(7019),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7019),
    [anon_sym_Enumextension] = ACTIONS(7019),
    [anon_sym_EnumExtension] = ACTIONS(7019),
    [anon_sym_enumExtension] = ACTIONS(7019),
    [sym_interface_keyword] = ACTIONS(7019),
    [anon_sym_controladdin] = ACTIONS(7019),
    [anon_sym_CONTROLADDIN] = ACTIONS(7019),
    [anon_sym_Controladdin] = ACTIONS(7019),
    [anon_sym_ControlAddIn] = ACTIONS(7019),
    [anon_sym_ControlAddin] = ACTIONS(7019),
    [anon_sym_controlAddIn] = ACTIONS(7019),
    [anon_sym_controlAddin] = ACTIONS(7019),
    [anon_sym_dotnet] = ACTIONS(7019),
    [anon_sym_DOTNET] = ACTIONS(7019),
    [anon_sym_Dotnet] = ACTIONS(7019),
    [anon_sym_DotNet] = ACTIONS(7019),
    [anon_sym_dotNet] = ACTIONS(7019),
    [sym_profile_keyword] = ACTIONS(7021),
    [anon_sym_profileextension] = ACTIONS(7019),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7019),
    [anon_sym_Profileextension] = ACTIONS(7019),
    [anon_sym_ProfileExtension] = ACTIONS(7019),
    [anon_sym_profileExtension] = ACTIONS(7019),
    [anon_sym_permissionset] = ACTIONS(7021),
    [anon_sym_PERMISSIONSET] = ACTIONS(7021),
    [anon_sym_Permissionset] = ACTIONS(7021),
    [anon_sym_PermissionSet] = ACTIONS(7021),
    [anon_sym_permissionSet] = ACTIONS(7021),
    [anon_sym_permissionsetextension] = ACTIONS(7019),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7019),
    [anon_sym_Permissionsetextension] = ACTIONS(7019),
    [anon_sym_PermissionSetExtension] = ACTIONS(7019),
    [anon_sym_permissionSetExtension] = ACTIONS(7019),
    [sym_entitlement_keyword] = ACTIONS(7019),
    [anon_sym_pagecustomization] = ACTIONS(7019),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7019),
    [anon_sym_Pagecustomization] = ACTIONS(7019),
    [anon_sym_PageCustomization] = ACTIONS(7019),
    [anon_sym_pageCustomization] = ACTIONS(7019),
    [sym_using_keyword] = ACTIONS(7019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7019),
  },
  [STATE(3716)] = {
    [ts_builtin_sym_end] = ACTIONS(6830),
    [anon_sym_POUNDif] = ACTIONS(6830),
    [anon_sym_POUNDIF] = ACTIONS(6830),
    [anon_sym_POUNDIf] = ACTIONS(6830),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6832),
    [anon_sym_tableextension] = ACTIONS(6830),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6830),
    [anon_sym_Tableextension] = ACTIONS(6830),
    [anon_sym_TableExtension] = ACTIONS(6830),
    [anon_sym_tableExtension] = ACTIONS(6830),
    [sym_page_keyword] = ACTIONS(6832),
    [anon_sym_pageextension] = ACTIONS(6830),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6830),
    [anon_sym_Pageextension] = ACTIONS(6830),
    [anon_sym_PageExtension] = ACTIONS(6830),
    [anon_sym_pageExtension] = ACTIONS(6830),
    [anon_sym_codeunit] = ACTIONS(6830),
    [anon_sym_CODEUNIT] = ACTIONS(6830),
    [anon_sym_Codeunit] = ACTIONS(6830),
    [anon_sym_CodeUnit] = ACTIONS(6830),
    [anon_sym_COdeunit] = ACTIONS(6830),
    [anon_sym_codeUnit] = ACTIONS(6830),
    [sym_report_keyword] = ACTIONS(6832),
    [anon_sym_reportextension] = ACTIONS(6830),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6830),
    [anon_sym_Reportextension] = ACTIONS(6830),
    [anon_sym_ReportExtension] = ACTIONS(6830),
    [anon_sym_reportExtension] = ACTIONS(6830),
    [sym_query_keyword] = ACTIONS(6830),
    [anon_sym_xmlport] = ACTIONS(6830),
    [anon_sym_XMLPORT] = ACTIONS(6830),
    [anon_sym_Xmlport] = ACTIONS(6830),
    [anon_sym_XMLport] = ACTIONS(6830),
    [anon_sym_XMLPort] = ACTIONS(6830),
    [anon_sym_XmlPort] = ACTIONS(6830),
    [anon_sym_enum] = ACTIONS(6832),
    [anon_sym_ENUM] = ACTIONS(6832),
    [anon_sym_Enum] = ACTIONS(6832),
    [anon_sym_eNUM] = ACTIONS(6830),
    [anon_sym_eNum] = ACTIONS(6830),
    [anon_sym_ENum] = ACTIONS(6830),
    [anon_sym_enumextension] = ACTIONS(6830),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6830),
    [anon_sym_Enumextension] = ACTIONS(6830),
    [anon_sym_EnumExtension] = ACTIONS(6830),
    [anon_sym_enumExtension] = ACTIONS(6830),
    [sym_interface_keyword] = ACTIONS(6830),
    [anon_sym_controladdin] = ACTIONS(6830),
    [anon_sym_CONTROLADDIN] = ACTIONS(6830),
    [anon_sym_Controladdin] = ACTIONS(6830),
    [anon_sym_ControlAddIn] = ACTIONS(6830),
    [anon_sym_ControlAddin] = ACTIONS(6830),
    [anon_sym_controlAddIn] = ACTIONS(6830),
    [anon_sym_controlAddin] = ACTIONS(6830),
    [anon_sym_dotnet] = ACTIONS(6830),
    [anon_sym_DOTNET] = ACTIONS(6830),
    [anon_sym_Dotnet] = ACTIONS(6830),
    [anon_sym_DotNet] = ACTIONS(6830),
    [anon_sym_dotNet] = ACTIONS(6830),
    [sym_profile_keyword] = ACTIONS(6832),
    [anon_sym_profileextension] = ACTIONS(6830),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6830),
    [anon_sym_Profileextension] = ACTIONS(6830),
    [anon_sym_ProfileExtension] = ACTIONS(6830),
    [anon_sym_profileExtension] = ACTIONS(6830),
    [anon_sym_permissionset] = ACTIONS(6832),
    [anon_sym_PERMISSIONSET] = ACTIONS(6832),
    [anon_sym_Permissionset] = ACTIONS(6832),
    [anon_sym_PermissionSet] = ACTIONS(6832),
    [anon_sym_permissionSet] = ACTIONS(6832),
    [anon_sym_permissionsetextension] = ACTIONS(6830),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6830),
    [anon_sym_Permissionsetextension] = ACTIONS(6830),
    [anon_sym_PermissionSetExtension] = ACTIONS(6830),
    [anon_sym_permissionSetExtension] = ACTIONS(6830),
    [sym_entitlement_keyword] = ACTIONS(6830),
    [anon_sym_pagecustomization] = ACTIONS(6830),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6830),
    [anon_sym_Pagecustomization] = ACTIONS(6830),
    [anon_sym_PageCustomization] = ACTIONS(6830),
    [anon_sym_pageCustomization] = ACTIONS(6830),
    [sym_using_keyword] = ACTIONS(6830),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6830),
  },
  [STATE(3717)] = {
    [ts_builtin_sym_end] = ACTIONS(6884),
    [anon_sym_POUNDif] = ACTIONS(6884),
    [anon_sym_POUNDIF] = ACTIONS(6884),
    [anon_sym_POUNDIf] = ACTIONS(6884),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6886),
    [anon_sym_tableextension] = ACTIONS(6884),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6884),
    [anon_sym_Tableextension] = ACTIONS(6884),
    [anon_sym_TableExtension] = ACTIONS(6884),
    [anon_sym_tableExtension] = ACTIONS(6884),
    [sym_page_keyword] = ACTIONS(6886),
    [anon_sym_pageextension] = ACTIONS(6884),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6884),
    [anon_sym_Pageextension] = ACTIONS(6884),
    [anon_sym_PageExtension] = ACTIONS(6884),
    [anon_sym_pageExtension] = ACTIONS(6884),
    [anon_sym_codeunit] = ACTIONS(6884),
    [anon_sym_CODEUNIT] = ACTIONS(6884),
    [anon_sym_Codeunit] = ACTIONS(6884),
    [anon_sym_CodeUnit] = ACTIONS(6884),
    [anon_sym_COdeunit] = ACTIONS(6884),
    [anon_sym_codeUnit] = ACTIONS(6884),
    [sym_report_keyword] = ACTIONS(6886),
    [anon_sym_reportextension] = ACTIONS(6884),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6884),
    [anon_sym_Reportextension] = ACTIONS(6884),
    [anon_sym_ReportExtension] = ACTIONS(6884),
    [anon_sym_reportExtension] = ACTIONS(6884),
    [sym_query_keyword] = ACTIONS(6884),
    [anon_sym_xmlport] = ACTIONS(6884),
    [anon_sym_XMLPORT] = ACTIONS(6884),
    [anon_sym_Xmlport] = ACTIONS(6884),
    [anon_sym_XMLport] = ACTIONS(6884),
    [anon_sym_XMLPort] = ACTIONS(6884),
    [anon_sym_XmlPort] = ACTIONS(6884),
    [anon_sym_enum] = ACTIONS(6886),
    [anon_sym_ENUM] = ACTIONS(6886),
    [anon_sym_Enum] = ACTIONS(6886),
    [anon_sym_eNUM] = ACTIONS(6884),
    [anon_sym_eNum] = ACTIONS(6884),
    [anon_sym_ENum] = ACTIONS(6884),
    [anon_sym_enumextension] = ACTIONS(6884),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6884),
    [anon_sym_Enumextension] = ACTIONS(6884),
    [anon_sym_EnumExtension] = ACTIONS(6884),
    [anon_sym_enumExtension] = ACTIONS(6884),
    [sym_interface_keyword] = ACTIONS(6884),
    [anon_sym_controladdin] = ACTIONS(6884),
    [anon_sym_CONTROLADDIN] = ACTIONS(6884),
    [anon_sym_Controladdin] = ACTIONS(6884),
    [anon_sym_ControlAddIn] = ACTIONS(6884),
    [anon_sym_ControlAddin] = ACTIONS(6884),
    [anon_sym_controlAddIn] = ACTIONS(6884),
    [anon_sym_controlAddin] = ACTIONS(6884),
    [anon_sym_dotnet] = ACTIONS(6884),
    [anon_sym_DOTNET] = ACTIONS(6884),
    [anon_sym_Dotnet] = ACTIONS(6884),
    [anon_sym_DotNet] = ACTIONS(6884),
    [anon_sym_dotNet] = ACTIONS(6884),
    [sym_profile_keyword] = ACTIONS(6886),
    [anon_sym_profileextension] = ACTIONS(6884),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6884),
    [anon_sym_Profileextension] = ACTIONS(6884),
    [anon_sym_ProfileExtension] = ACTIONS(6884),
    [anon_sym_profileExtension] = ACTIONS(6884),
    [anon_sym_permissionset] = ACTIONS(6886),
    [anon_sym_PERMISSIONSET] = ACTIONS(6886),
    [anon_sym_Permissionset] = ACTIONS(6886),
    [anon_sym_PermissionSet] = ACTIONS(6886),
    [anon_sym_permissionSet] = ACTIONS(6886),
    [anon_sym_permissionsetextension] = ACTIONS(6884),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6884),
    [anon_sym_Permissionsetextension] = ACTIONS(6884),
    [anon_sym_PermissionSetExtension] = ACTIONS(6884),
    [anon_sym_permissionSetExtension] = ACTIONS(6884),
    [sym_entitlement_keyword] = ACTIONS(6884),
    [anon_sym_pagecustomization] = ACTIONS(6884),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6884),
    [anon_sym_Pagecustomization] = ACTIONS(6884),
    [anon_sym_PageCustomization] = ACTIONS(6884),
    [anon_sym_pageCustomization] = ACTIONS(6884),
    [sym_using_keyword] = ACTIONS(6884),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6884),
  },
  [STATE(3718)] = {
    [sym_boolean] = STATE(8783),
    [sym_simple_table_relation] = STATE(6519),
    [sym__namespaced_or_simple_ref] = STATE(6378),
    [sym_assignment_expression] = STATE(8783),
    [sym__expression] = STATE(8783),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8783),
    [sym_multiplicative_expression] = STATE(8783),
    [sym_additive_expression] = STATE(8783),
    [sym_comparison_expression] = STATE(8783),
    [sym_logical_expression] = STATE(8783),
    [sym_ternary_expression] = STATE(8783),
    [sym_unary_expression] = STATE(8783),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(3254),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8783),
    [sym_list_literal] = STATE(8783),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8783),
    [sym__literal_value] = STATE(8783),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(5937),
    [sym_keyword_as_identifier] = STATE(5937),
    [sym_identifier] = ACTIONS(8391),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8393),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(8395),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(8397),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(8395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8395),
    [aux_sym_separator_action_token1] = ACTIONS(8395),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8395),
    [aux_sym_type_declaration_token1] = ACTIONS(8395),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(8399),
    [sym_date_literal] = ACTIONS(8393),
    [sym_time_literal] = ACTIONS(8393),
    [sym_biginteger_literal] = ACTIONS(8399),
    [sym_table_keyword] = ACTIONS(8395),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(8395),
    [sym_dataset_keyword] = ACTIONS(8395),
    [sym_quoted_identifier] = ACTIONS(8401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8399),
    [sym_verbatim_string] = ACTIONS(8399),
    [sym_integer] = ACTIONS(8403),
    [sym_continue_as_identifier] = ACTIONS(8399),
  },
  [STATE(3719)] = {
    [ts_builtin_sym_end] = ACTIONS(7177),
    [anon_sym_POUNDif] = ACTIONS(7177),
    [anon_sym_POUNDIF] = ACTIONS(7177),
    [anon_sym_POUNDIf] = ACTIONS(7177),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7179),
    [anon_sym_tableextension] = ACTIONS(7177),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7177),
    [anon_sym_Tableextension] = ACTIONS(7177),
    [anon_sym_TableExtension] = ACTIONS(7177),
    [anon_sym_tableExtension] = ACTIONS(7177),
    [sym_page_keyword] = ACTIONS(7179),
    [anon_sym_pageextension] = ACTIONS(7177),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7177),
    [anon_sym_Pageextension] = ACTIONS(7177),
    [anon_sym_PageExtension] = ACTIONS(7177),
    [anon_sym_pageExtension] = ACTIONS(7177),
    [anon_sym_codeunit] = ACTIONS(7177),
    [anon_sym_CODEUNIT] = ACTIONS(7177),
    [anon_sym_Codeunit] = ACTIONS(7177),
    [anon_sym_CodeUnit] = ACTIONS(7177),
    [anon_sym_COdeunit] = ACTIONS(7177),
    [anon_sym_codeUnit] = ACTIONS(7177),
    [sym_report_keyword] = ACTIONS(7179),
    [anon_sym_reportextension] = ACTIONS(7177),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7177),
    [anon_sym_Reportextension] = ACTIONS(7177),
    [anon_sym_ReportExtension] = ACTIONS(7177),
    [anon_sym_reportExtension] = ACTIONS(7177),
    [sym_query_keyword] = ACTIONS(7177),
    [anon_sym_xmlport] = ACTIONS(7177),
    [anon_sym_XMLPORT] = ACTIONS(7177),
    [anon_sym_Xmlport] = ACTIONS(7177),
    [anon_sym_XMLport] = ACTIONS(7177),
    [anon_sym_XMLPort] = ACTIONS(7177),
    [anon_sym_XmlPort] = ACTIONS(7177),
    [anon_sym_enum] = ACTIONS(7179),
    [anon_sym_ENUM] = ACTIONS(7179),
    [anon_sym_Enum] = ACTIONS(7179),
    [anon_sym_eNUM] = ACTIONS(7177),
    [anon_sym_eNum] = ACTIONS(7177),
    [anon_sym_ENum] = ACTIONS(7177),
    [anon_sym_enumextension] = ACTIONS(7177),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7177),
    [anon_sym_Enumextension] = ACTIONS(7177),
    [anon_sym_EnumExtension] = ACTIONS(7177),
    [anon_sym_enumExtension] = ACTIONS(7177),
    [sym_interface_keyword] = ACTIONS(7177),
    [anon_sym_controladdin] = ACTIONS(7177),
    [anon_sym_CONTROLADDIN] = ACTIONS(7177),
    [anon_sym_Controladdin] = ACTIONS(7177),
    [anon_sym_ControlAddIn] = ACTIONS(7177),
    [anon_sym_ControlAddin] = ACTIONS(7177),
    [anon_sym_controlAddIn] = ACTIONS(7177),
    [anon_sym_controlAddin] = ACTIONS(7177),
    [anon_sym_dotnet] = ACTIONS(7177),
    [anon_sym_DOTNET] = ACTIONS(7177),
    [anon_sym_Dotnet] = ACTIONS(7177),
    [anon_sym_DotNet] = ACTIONS(7177),
    [anon_sym_dotNet] = ACTIONS(7177),
    [sym_profile_keyword] = ACTIONS(7179),
    [anon_sym_profileextension] = ACTIONS(7177),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7177),
    [anon_sym_Profileextension] = ACTIONS(7177),
    [anon_sym_ProfileExtension] = ACTIONS(7177),
    [anon_sym_profileExtension] = ACTIONS(7177),
    [anon_sym_permissionset] = ACTIONS(7179),
    [anon_sym_PERMISSIONSET] = ACTIONS(7179),
    [anon_sym_Permissionset] = ACTIONS(7179),
    [anon_sym_PermissionSet] = ACTIONS(7179),
    [anon_sym_permissionSet] = ACTIONS(7179),
    [anon_sym_permissionsetextension] = ACTIONS(7177),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7177),
    [anon_sym_Permissionsetextension] = ACTIONS(7177),
    [anon_sym_PermissionSetExtension] = ACTIONS(7177),
    [anon_sym_permissionSetExtension] = ACTIONS(7177),
    [sym_entitlement_keyword] = ACTIONS(7177),
    [anon_sym_pagecustomization] = ACTIONS(7177),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7177),
    [anon_sym_Pagecustomization] = ACTIONS(7177),
    [anon_sym_PageCustomization] = ACTIONS(7177),
    [anon_sym_pageCustomization] = ACTIONS(7177),
    [sym_using_keyword] = ACTIONS(7177),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7177),
  },
  [STATE(3720)] = {
    [ts_builtin_sym_end] = ACTIONS(6888),
    [anon_sym_POUNDif] = ACTIONS(6888),
    [anon_sym_POUNDIF] = ACTIONS(6888),
    [anon_sym_POUNDIf] = ACTIONS(6888),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6890),
    [anon_sym_tableextension] = ACTIONS(6888),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6888),
    [anon_sym_Tableextension] = ACTIONS(6888),
    [anon_sym_TableExtension] = ACTIONS(6888),
    [anon_sym_tableExtension] = ACTIONS(6888),
    [sym_page_keyword] = ACTIONS(6890),
    [anon_sym_pageextension] = ACTIONS(6888),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6888),
    [anon_sym_Pageextension] = ACTIONS(6888),
    [anon_sym_PageExtension] = ACTIONS(6888),
    [anon_sym_pageExtension] = ACTIONS(6888),
    [anon_sym_codeunit] = ACTIONS(6888),
    [anon_sym_CODEUNIT] = ACTIONS(6888),
    [anon_sym_Codeunit] = ACTIONS(6888),
    [anon_sym_CodeUnit] = ACTIONS(6888),
    [anon_sym_COdeunit] = ACTIONS(6888),
    [anon_sym_codeUnit] = ACTIONS(6888),
    [sym_report_keyword] = ACTIONS(6890),
    [anon_sym_reportextension] = ACTIONS(6888),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6888),
    [anon_sym_Reportextension] = ACTIONS(6888),
    [anon_sym_ReportExtension] = ACTIONS(6888),
    [anon_sym_reportExtension] = ACTIONS(6888),
    [sym_query_keyword] = ACTIONS(6888),
    [anon_sym_xmlport] = ACTIONS(6888),
    [anon_sym_XMLPORT] = ACTIONS(6888),
    [anon_sym_Xmlport] = ACTIONS(6888),
    [anon_sym_XMLport] = ACTIONS(6888),
    [anon_sym_XMLPort] = ACTIONS(6888),
    [anon_sym_XmlPort] = ACTIONS(6888),
    [anon_sym_enum] = ACTIONS(6890),
    [anon_sym_ENUM] = ACTIONS(6890),
    [anon_sym_Enum] = ACTIONS(6890),
    [anon_sym_eNUM] = ACTIONS(6888),
    [anon_sym_eNum] = ACTIONS(6888),
    [anon_sym_ENum] = ACTIONS(6888),
    [anon_sym_enumextension] = ACTIONS(6888),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6888),
    [anon_sym_Enumextension] = ACTIONS(6888),
    [anon_sym_EnumExtension] = ACTIONS(6888),
    [anon_sym_enumExtension] = ACTIONS(6888),
    [sym_interface_keyword] = ACTIONS(6888),
    [anon_sym_controladdin] = ACTIONS(6888),
    [anon_sym_CONTROLADDIN] = ACTIONS(6888),
    [anon_sym_Controladdin] = ACTIONS(6888),
    [anon_sym_ControlAddIn] = ACTIONS(6888),
    [anon_sym_ControlAddin] = ACTIONS(6888),
    [anon_sym_controlAddIn] = ACTIONS(6888),
    [anon_sym_controlAddin] = ACTIONS(6888),
    [anon_sym_dotnet] = ACTIONS(6888),
    [anon_sym_DOTNET] = ACTIONS(6888),
    [anon_sym_Dotnet] = ACTIONS(6888),
    [anon_sym_DotNet] = ACTIONS(6888),
    [anon_sym_dotNet] = ACTIONS(6888),
    [sym_profile_keyword] = ACTIONS(6890),
    [anon_sym_profileextension] = ACTIONS(6888),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6888),
    [anon_sym_Profileextension] = ACTIONS(6888),
    [anon_sym_ProfileExtension] = ACTIONS(6888),
    [anon_sym_profileExtension] = ACTIONS(6888),
    [anon_sym_permissionset] = ACTIONS(6890),
    [anon_sym_PERMISSIONSET] = ACTIONS(6890),
    [anon_sym_Permissionset] = ACTIONS(6890),
    [anon_sym_PermissionSet] = ACTIONS(6890),
    [anon_sym_permissionSet] = ACTIONS(6890),
    [anon_sym_permissionsetextension] = ACTIONS(6888),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6888),
    [anon_sym_Permissionsetextension] = ACTIONS(6888),
    [anon_sym_PermissionSetExtension] = ACTIONS(6888),
    [anon_sym_permissionSetExtension] = ACTIONS(6888),
    [sym_entitlement_keyword] = ACTIONS(6888),
    [anon_sym_pagecustomization] = ACTIONS(6888),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6888),
    [anon_sym_Pagecustomization] = ACTIONS(6888),
    [anon_sym_PageCustomization] = ACTIONS(6888),
    [anon_sym_pageCustomization] = ACTIONS(6888),
    [sym_using_keyword] = ACTIONS(6888),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6888),
  },
  [STATE(3721)] = {
    [ts_builtin_sym_end] = ACTIONS(6999),
    [anon_sym_POUNDif] = ACTIONS(6999),
    [anon_sym_POUNDIF] = ACTIONS(6999),
    [anon_sym_POUNDIf] = ACTIONS(6999),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7001),
    [anon_sym_tableextension] = ACTIONS(6999),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6999),
    [anon_sym_Tableextension] = ACTIONS(6999),
    [anon_sym_TableExtension] = ACTIONS(6999),
    [anon_sym_tableExtension] = ACTIONS(6999),
    [sym_page_keyword] = ACTIONS(7001),
    [anon_sym_pageextension] = ACTIONS(6999),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6999),
    [anon_sym_Pageextension] = ACTIONS(6999),
    [anon_sym_PageExtension] = ACTIONS(6999),
    [anon_sym_pageExtension] = ACTIONS(6999),
    [anon_sym_codeunit] = ACTIONS(6999),
    [anon_sym_CODEUNIT] = ACTIONS(6999),
    [anon_sym_Codeunit] = ACTIONS(6999),
    [anon_sym_CodeUnit] = ACTIONS(6999),
    [anon_sym_COdeunit] = ACTIONS(6999),
    [anon_sym_codeUnit] = ACTIONS(6999),
    [sym_report_keyword] = ACTIONS(7001),
    [anon_sym_reportextension] = ACTIONS(6999),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6999),
    [anon_sym_Reportextension] = ACTIONS(6999),
    [anon_sym_ReportExtension] = ACTIONS(6999),
    [anon_sym_reportExtension] = ACTIONS(6999),
    [sym_query_keyword] = ACTIONS(6999),
    [anon_sym_xmlport] = ACTIONS(6999),
    [anon_sym_XMLPORT] = ACTIONS(6999),
    [anon_sym_Xmlport] = ACTIONS(6999),
    [anon_sym_XMLport] = ACTIONS(6999),
    [anon_sym_XMLPort] = ACTIONS(6999),
    [anon_sym_XmlPort] = ACTIONS(6999),
    [anon_sym_enum] = ACTIONS(7001),
    [anon_sym_ENUM] = ACTIONS(7001),
    [anon_sym_Enum] = ACTIONS(7001),
    [anon_sym_eNUM] = ACTIONS(6999),
    [anon_sym_eNum] = ACTIONS(6999),
    [anon_sym_ENum] = ACTIONS(6999),
    [anon_sym_enumextension] = ACTIONS(6999),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6999),
    [anon_sym_Enumextension] = ACTIONS(6999),
    [anon_sym_EnumExtension] = ACTIONS(6999),
    [anon_sym_enumExtension] = ACTIONS(6999),
    [sym_interface_keyword] = ACTIONS(6999),
    [anon_sym_controladdin] = ACTIONS(6999),
    [anon_sym_CONTROLADDIN] = ACTIONS(6999),
    [anon_sym_Controladdin] = ACTIONS(6999),
    [anon_sym_ControlAddIn] = ACTIONS(6999),
    [anon_sym_ControlAddin] = ACTIONS(6999),
    [anon_sym_controlAddIn] = ACTIONS(6999),
    [anon_sym_controlAddin] = ACTIONS(6999),
    [anon_sym_dotnet] = ACTIONS(6999),
    [anon_sym_DOTNET] = ACTIONS(6999),
    [anon_sym_Dotnet] = ACTIONS(6999),
    [anon_sym_DotNet] = ACTIONS(6999),
    [anon_sym_dotNet] = ACTIONS(6999),
    [sym_profile_keyword] = ACTIONS(7001),
    [anon_sym_profileextension] = ACTIONS(6999),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6999),
    [anon_sym_Profileextension] = ACTIONS(6999),
    [anon_sym_ProfileExtension] = ACTIONS(6999),
    [anon_sym_profileExtension] = ACTIONS(6999),
    [anon_sym_permissionset] = ACTIONS(7001),
    [anon_sym_PERMISSIONSET] = ACTIONS(7001),
    [anon_sym_Permissionset] = ACTIONS(7001),
    [anon_sym_PermissionSet] = ACTIONS(7001),
    [anon_sym_permissionSet] = ACTIONS(7001),
    [anon_sym_permissionsetextension] = ACTIONS(6999),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6999),
    [anon_sym_Permissionsetextension] = ACTIONS(6999),
    [anon_sym_PermissionSetExtension] = ACTIONS(6999),
    [anon_sym_permissionSetExtension] = ACTIONS(6999),
    [sym_entitlement_keyword] = ACTIONS(6999),
    [anon_sym_pagecustomization] = ACTIONS(6999),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6999),
    [anon_sym_Pagecustomization] = ACTIONS(6999),
    [anon_sym_PageCustomization] = ACTIONS(6999),
    [anon_sym_pageCustomization] = ACTIONS(6999),
    [sym_using_keyword] = ACTIONS(6999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6999),
  },
  [STATE(3722)] = {
    [ts_builtin_sym_end] = ACTIONS(7149),
    [anon_sym_POUNDif] = ACTIONS(7149),
    [anon_sym_POUNDIF] = ACTIONS(7149),
    [anon_sym_POUNDIf] = ACTIONS(7149),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7151),
    [anon_sym_tableextension] = ACTIONS(7149),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7149),
    [anon_sym_Tableextension] = ACTIONS(7149),
    [anon_sym_TableExtension] = ACTIONS(7149),
    [anon_sym_tableExtension] = ACTIONS(7149),
    [sym_page_keyword] = ACTIONS(7151),
    [anon_sym_pageextension] = ACTIONS(7149),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7149),
    [anon_sym_Pageextension] = ACTIONS(7149),
    [anon_sym_PageExtension] = ACTIONS(7149),
    [anon_sym_pageExtension] = ACTIONS(7149),
    [anon_sym_codeunit] = ACTIONS(7149),
    [anon_sym_CODEUNIT] = ACTIONS(7149),
    [anon_sym_Codeunit] = ACTIONS(7149),
    [anon_sym_CodeUnit] = ACTIONS(7149),
    [anon_sym_COdeunit] = ACTIONS(7149),
    [anon_sym_codeUnit] = ACTIONS(7149),
    [sym_report_keyword] = ACTIONS(7151),
    [anon_sym_reportextension] = ACTIONS(7149),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7149),
    [anon_sym_Reportextension] = ACTIONS(7149),
    [anon_sym_ReportExtension] = ACTIONS(7149),
    [anon_sym_reportExtension] = ACTIONS(7149),
    [sym_query_keyword] = ACTIONS(7149),
    [anon_sym_xmlport] = ACTIONS(7149),
    [anon_sym_XMLPORT] = ACTIONS(7149),
    [anon_sym_Xmlport] = ACTIONS(7149),
    [anon_sym_XMLport] = ACTIONS(7149),
    [anon_sym_XMLPort] = ACTIONS(7149),
    [anon_sym_XmlPort] = ACTIONS(7149),
    [anon_sym_enum] = ACTIONS(7151),
    [anon_sym_ENUM] = ACTIONS(7151),
    [anon_sym_Enum] = ACTIONS(7151),
    [anon_sym_eNUM] = ACTIONS(7149),
    [anon_sym_eNum] = ACTIONS(7149),
    [anon_sym_ENum] = ACTIONS(7149),
    [anon_sym_enumextension] = ACTIONS(7149),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7149),
    [anon_sym_Enumextension] = ACTIONS(7149),
    [anon_sym_EnumExtension] = ACTIONS(7149),
    [anon_sym_enumExtension] = ACTIONS(7149),
    [sym_interface_keyword] = ACTIONS(7149),
    [anon_sym_controladdin] = ACTIONS(7149),
    [anon_sym_CONTROLADDIN] = ACTIONS(7149),
    [anon_sym_Controladdin] = ACTIONS(7149),
    [anon_sym_ControlAddIn] = ACTIONS(7149),
    [anon_sym_ControlAddin] = ACTIONS(7149),
    [anon_sym_controlAddIn] = ACTIONS(7149),
    [anon_sym_controlAddin] = ACTIONS(7149),
    [anon_sym_dotnet] = ACTIONS(7149),
    [anon_sym_DOTNET] = ACTIONS(7149),
    [anon_sym_Dotnet] = ACTIONS(7149),
    [anon_sym_DotNet] = ACTIONS(7149),
    [anon_sym_dotNet] = ACTIONS(7149),
    [sym_profile_keyword] = ACTIONS(7151),
    [anon_sym_profileextension] = ACTIONS(7149),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7149),
    [anon_sym_Profileextension] = ACTIONS(7149),
    [anon_sym_ProfileExtension] = ACTIONS(7149),
    [anon_sym_profileExtension] = ACTIONS(7149),
    [anon_sym_permissionset] = ACTIONS(7151),
    [anon_sym_PERMISSIONSET] = ACTIONS(7151),
    [anon_sym_Permissionset] = ACTIONS(7151),
    [anon_sym_PermissionSet] = ACTIONS(7151),
    [anon_sym_permissionSet] = ACTIONS(7151),
    [anon_sym_permissionsetextension] = ACTIONS(7149),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7149),
    [anon_sym_Permissionsetextension] = ACTIONS(7149),
    [anon_sym_PermissionSetExtension] = ACTIONS(7149),
    [anon_sym_permissionSetExtension] = ACTIONS(7149),
    [sym_entitlement_keyword] = ACTIONS(7149),
    [anon_sym_pagecustomization] = ACTIONS(7149),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7149),
    [anon_sym_Pagecustomization] = ACTIONS(7149),
    [anon_sym_PageCustomization] = ACTIONS(7149),
    [anon_sym_pageCustomization] = ACTIONS(7149),
    [sym_using_keyword] = ACTIONS(7149),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7149),
  },
  [STATE(3723)] = {
    [ts_builtin_sym_end] = ACTIONS(6915),
    [anon_sym_POUNDif] = ACTIONS(6915),
    [anon_sym_POUNDIF] = ACTIONS(6915),
    [anon_sym_POUNDIf] = ACTIONS(6915),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6917),
    [anon_sym_tableextension] = ACTIONS(6915),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6915),
    [anon_sym_Tableextension] = ACTIONS(6915),
    [anon_sym_TableExtension] = ACTIONS(6915),
    [anon_sym_tableExtension] = ACTIONS(6915),
    [sym_page_keyword] = ACTIONS(6917),
    [anon_sym_pageextension] = ACTIONS(6915),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6915),
    [anon_sym_Pageextension] = ACTIONS(6915),
    [anon_sym_PageExtension] = ACTIONS(6915),
    [anon_sym_pageExtension] = ACTIONS(6915),
    [anon_sym_codeunit] = ACTIONS(6915),
    [anon_sym_CODEUNIT] = ACTIONS(6915),
    [anon_sym_Codeunit] = ACTIONS(6915),
    [anon_sym_CodeUnit] = ACTIONS(6915),
    [anon_sym_COdeunit] = ACTIONS(6915),
    [anon_sym_codeUnit] = ACTIONS(6915),
    [sym_report_keyword] = ACTIONS(6917),
    [anon_sym_reportextension] = ACTIONS(6915),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6915),
    [anon_sym_Reportextension] = ACTIONS(6915),
    [anon_sym_ReportExtension] = ACTIONS(6915),
    [anon_sym_reportExtension] = ACTIONS(6915),
    [sym_query_keyword] = ACTIONS(6915),
    [anon_sym_xmlport] = ACTIONS(6915),
    [anon_sym_XMLPORT] = ACTIONS(6915),
    [anon_sym_Xmlport] = ACTIONS(6915),
    [anon_sym_XMLport] = ACTIONS(6915),
    [anon_sym_XMLPort] = ACTIONS(6915),
    [anon_sym_XmlPort] = ACTIONS(6915),
    [anon_sym_enum] = ACTIONS(6917),
    [anon_sym_ENUM] = ACTIONS(6917),
    [anon_sym_Enum] = ACTIONS(6917),
    [anon_sym_eNUM] = ACTIONS(6915),
    [anon_sym_eNum] = ACTIONS(6915),
    [anon_sym_ENum] = ACTIONS(6915),
    [anon_sym_enumextension] = ACTIONS(6915),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6915),
    [anon_sym_Enumextension] = ACTIONS(6915),
    [anon_sym_EnumExtension] = ACTIONS(6915),
    [anon_sym_enumExtension] = ACTIONS(6915),
    [sym_interface_keyword] = ACTIONS(6915),
    [anon_sym_controladdin] = ACTIONS(6915),
    [anon_sym_CONTROLADDIN] = ACTIONS(6915),
    [anon_sym_Controladdin] = ACTIONS(6915),
    [anon_sym_ControlAddIn] = ACTIONS(6915),
    [anon_sym_ControlAddin] = ACTIONS(6915),
    [anon_sym_controlAddIn] = ACTIONS(6915),
    [anon_sym_controlAddin] = ACTIONS(6915),
    [anon_sym_dotnet] = ACTIONS(6915),
    [anon_sym_DOTNET] = ACTIONS(6915),
    [anon_sym_Dotnet] = ACTIONS(6915),
    [anon_sym_DotNet] = ACTIONS(6915),
    [anon_sym_dotNet] = ACTIONS(6915),
    [sym_profile_keyword] = ACTIONS(6917),
    [anon_sym_profileextension] = ACTIONS(6915),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6915),
    [anon_sym_Profileextension] = ACTIONS(6915),
    [anon_sym_ProfileExtension] = ACTIONS(6915),
    [anon_sym_profileExtension] = ACTIONS(6915),
    [anon_sym_permissionset] = ACTIONS(6917),
    [anon_sym_PERMISSIONSET] = ACTIONS(6917),
    [anon_sym_Permissionset] = ACTIONS(6917),
    [anon_sym_PermissionSet] = ACTIONS(6917),
    [anon_sym_permissionSet] = ACTIONS(6917),
    [anon_sym_permissionsetextension] = ACTIONS(6915),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6915),
    [anon_sym_Permissionsetextension] = ACTIONS(6915),
    [anon_sym_PermissionSetExtension] = ACTIONS(6915),
    [anon_sym_permissionSetExtension] = ACTIONS(6915),
    [sym_entitlement_keyword] = ACTIONS(6915),
    [anon_sym_pagecustomization] = ACTIONS(6915),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6915),
    [anon_sym_Pagecustomization] = ACTIONS(6915),
    [anon_sym_PageCustomization] = ACTIONS(6915),
    [anon_sym_pageCustomization] = ACTIONS(6915),
    [sym_using_keyword] = ACTIONS(6915),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6915),
  },
  [STATE(3724)] = {
    [ts_builtin_sym_end] = ACTIONS(7083),
    [anon_sym_POUNDif] = ACTIONS(7083),
    [anon_sym_POUNDIF] = ACTIONS(7083),
    [anon_sym_POUNDIf] = ACTIONS(7083),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7085),
    [anon_sym_tableextension] = ACTIONS(7083),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7083),
    [anon_sym_Tableextension] = ACTIONS(7083),
    [anon_sym_TableExtension] = ACTIONS(7083),
    [anon_sym_tableExtension] = ACTIONS(7083),
    [sym_page_keyword] = ACTIONS(7085),
    [anon_sym_pageextension] = ACTIONS(7083),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7083),
    [anon_sym_Pageextension] = ACTIONS(7083),
    [anon_sym_PageExtension] = ACTIONS(7083),
    [anon_sym_pageExtension] = ACTIONS(7083),
    [anon_sym_codeunit] = ACTIONS(7083),
    [anon_sym_CODEUNIT] = ACTIONS(7083),
    [anon_sym_Codeunit] = ACTIONS(7083),
    [anon_sym_CodeUnit] = ACTIONS(7083),
    [anon_sym_COdeunit] = ACTIONS(7083),
    [anon_sym_codeUnit] = ACTIONS(7083),
    [sym_report_keyword] = ACTIONS(7085),
    [anon_sym_reportextension] = ACTIONS(7083),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7083),
    [anon_sym_Reportextension] = ACTIONS(7083),
    [anon_sym_ReportExtension] = ACTIONS(7083),
    [anon_sym_reportExtension] = ACTIONS(7083),
    [sym_query_keyword] = ACTIONS(7083),
    [anon_sym_xmlport] = ACTIONS(7083),
    [anon_sym_XMLPORT] = ACTIONS(7083),
    [anon_sym_Xmlport] = ACTIONS(7083),
    [anon_sym_XMLport] = ACTIONS(7083),
    [anon_sym_XMLPort] = ACTIONS(7083),
    [anon_sym_XmlPort] = ACTIONS(7083),
    [anon_sym_enum] = ACTIONS(7085),
    [anon_sym_ENUM] = ACTIONS(7085),
    [anon_sym_Enum] = ACTIONS(7085),
    [anon_sym_eNUM] = ACTIONS(7083),
    [anon_sym_eNum] = ACTIONS(7083),
    [anon_sym_ENum] = ACTIONS(7083),
    [anon_sym_enumextension] = ACTIONS(7083),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7083),
    [anon_sym_Enumextension] = ACTIONS(7083),
    [anon_sym_EnumExtension] = ACTIONS(7083),
    [anon_sym_enumExtension] = ACTIONS(7083),
    [sym_interface_keyword] = ACTIONS(7083),
    [anon_sym_controladdin] = ACTIONS(7083),
    [anon_sym_CONTROLADDIN] = ACTIONS(7083),
    [anon_sym_Controladdin] = ACTIONS(7083),
    [anon_sym_ControlAddIn] = ACTIONS(7083),
    [anon_sym_ControlAddin] = ACTIONS(7083),
    [anon_sym_controlAddIn] = ACTIONS(7083),
    [anon_sym_controlAddin] = ACTIONS(7083),
    [anon_sym_dotnet] = ACTIONS(7083),
    [anon_sym_DOTNET] = ACTIONS(7083),
    [anon_sym_Dotnet] = ACTIONS(7083),
    [anon_sym_DotNet] = ACTIONS(7083),
    [anon_sym_dotNet] = ACTIONS(7083),
    [sym_profile_keyword] = ACTIONS(7085),
    [anon_sym_profileextension] = ACTIONS(7083),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7083),
    [anon_sym_Profileextension] = ACTIONS(7083),
    [anon_sym_ProfileExtension] = ACTIONS(7083),
    [anon_sym_profileExtension] = ACTIONS(7083),
    [anon_sym_permissionset] = ACTIONS(7085),
    [anon_sym_PERMISSIONSET] = ACTIONS(7085),
    [anon_sym_Permissionset] = ACTIONS(7085),
    [anon_sym_PermissionSet] = ACTIONS(7085),
    [anon_sym_permissionSet] = ACTIONS(7085),
    [anon_sym_permissionsetextension] = ACTIONS(7083),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7083),
    [anon_sym_Permissionsetextension] = ACTIONS(7083),
    [anon_sym_PermissionSetExtension] = ACTIONS(7083),
    [anon_sym_permissionSetExtension] = ACTIONS(7083),
    [sym_entitlement_keyword] = ACTIONS(7083),
    [anon_sym_pagecustomization] = ACTIONS(7083),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7083),
    [anon_sym_Pagecustomization] = ACTIONS(7083),
    [anon_sym_PageCustomization] = ACTIONS(7083),
    [anon_sym_pageCustomization] = ACTIONS(7083),
    [sym_using_keyword] = ACTIONS(7083),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7083),
  },
  [STATE(3725)] = {
    [ts_builtin_sym_end] = ACTIONS(6919),
    [anon_sym_POUNDif] = ACTIONS(6919),
    [anon_sym_POUNDIF] = ACTIONS(6919),
    [anon_sym_POUNDIf] = ACTIONS(6919),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6921),
    [anon_sym_tableextension] = ACTIONS(6919),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6919),
    [anon_sym_Tableextension] = ACTIONS(6919),
    [anon_sym_TableExtension] = ACTIONS(6919),
    [anon_sym_tableExtension] = ACTIONS(6919),
    [sym_page_keyword] = ACTIONS(6921),
    [anon_sym_pageextension] = ACTIONS(6919),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6919),
    [anon_sym_Pageextension] = ACTIONS(6919),
    [anon_sym_PageExtension] = ACTIONS(6919),
    [anon_sym_pageExtension] = ACTIONS(6919),
    [anon_sym_codeunit] = ACTIONS(6919),
    [anon_sym_CODEUNIT] = ACTIONS(6919),
    [anon_sym_Codeunit] = ACTIONS(6919),
    [anon_sym_CodeUnit] = ACTIONS(6919),
    [anon_sym_COdeunit] = ACTIONS(6919),
    [anon_sym_codeUnit] = ACTIONS(6919),
    [sym_report_keyword] = ACTIONS(6921),
    [anon_sym_reportextension] = ACTIONS(6919),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6919),
    [anon_sym_Reportextension] = ACTIONS(6919),
    [anon_sym_ReportExtension] = ACTIONS(6919),
    [anon_sym_reportExtension] = ACTIONS(6919),
    [sym_query_keyword] = ACTIONS(6919),
    [anon_sym_xmlport] = ACTIONS(6919),
    [anon_sym_XMLPORT] = ACTIONS(6919),
    [anon_sym_Xmlport] = ACTIONS(6919),
    [anon_sym_XMLport] = ACTIONS(6919),
    [anon_sym_XMLPort] = ACTIONS(6919),
    [anon_sym_XmlPort] = ACTIONS(6919),
    [anon_sym_enum] = ACTIONS(6921),
    [anon_sym_ENUM] = ACTIONS(6921),
    [anon_sym_Enum] = ACTIONS(6921),
    [anon_sym_eNUM] = ACTIONS(6919),
    [anon_sym_eNum] = ACTIONS(6919),
    [anon_sym_ENum] = ACTIONS(6919),
    [anon_sym_enumextension] = ACTIONS(6919),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6919),
    [anon_sym_Enumextension] = ACTIONS(6919),
    [anon_sym_EnumExtension] = ACTIONS(6919),
    [anon_sym_enumExtension] = ACTIONS(6919),
    [sym_interface_keyword] = ACTIONS(6919),
    [anon_sym_controladdin] = ACTIONS(6919),
    [anon_sym_CONTROLADDIN] = ACTIONS(6919),
    [anon_sym_Controladdin] = ACTIONS(6919),
    [anon_sym_ControlAddIn] = ACTIONS(6919),
    [anon_sym_ControlAddin] = ACTIONS(6919),
    [anon_sym_controlAddIn] = ACTIONS(6919),
    [anon_sym_controlAddin] = ACTIONS(6919),
    [anon_sym_dotnet] = ACTIONS(6919),
    [anon_sym_DOTNET] = ACTIONS(6919),
    [anon_sym_Dotnet] = ACTIONS(6919),
    [anon_sym_DotNet] = ACTIONS(6919),
    [anon_sym_dotNet] = ACTIONS(6919),
    [sym_profile_keyword] = ACTIONS(6921),
    [anon_sym_profileextension] = ACTIONS(6919),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6919),
    [anon_sym_Profileextension] = ACTIONS(6919),
    [anon_sym_ProfileExtension] = ACTIONS(6919),
    [anon_sym_profileExtension] = ACTIONS(6919),
    [anon_sym_permissionset] = ACTIONS(6921),
    [anon_sym_PERMISSIONSET] = ACTIONS(6921),
    [anon_sym_Permissionset] = ACTIONS(6921),
    [anon_sym_PermissionSet] = ACTIONS(6921),
    [anon_sym_permissionSet] = ACTIONS(6921),
    [anon_sym_permissionsetextension] = ACTIONS(6919),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6919),
    [anon_sym_Permissionsetextension] = ACTIONS(6919),
    [anon_sym_PermissionSetExtension] = ACTIONS(6919),
    [anon_sym_permissionSetExtension] = ACTIONS(6919),
    [sym_entitlement_keyword] = ACTIONS(6919),
    [anon_sym_pagecustomization] = ACTIONS(6919),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6919),
    [anon_sym_Pagecustomization] = ACTIONS(6919),
    [anon_sym_PageCustomization] = ACTIONS(6919),
    [anon_sym_pageCustomization] = ACTIONS(6919),
    [sym_using_keyword] = ACTIONS(6919),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6919),
  },
  [STATE(3726)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [aux_sym_boolean_token1] = ACTIONS(3562),
    [aux_sym_boolean_token2] = ACTIONS(3562),
    [sym_decimal] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [anon_sym_RPAREN] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_filter_value_token1] = ACTIONS(3562),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3562),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_record_type_token1] = ACTIONS(3562),
    [aux_sym_basic_type_token21] = ACTIONS(3562),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token48] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_not] = ACTIONS(3562),
    [anon_sym_NOT] = ACTIONS(3562),
    [anon_sym_Not] = ACTIONS(3562),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3562),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3562),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [sym_datetime_literal] = ACTIONS(3564),
    [sym_date_literal] = ACTIONS(3562),
    [sym_time_literal] = ACTIONS(3562),
    [sym_biginteger_literal] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_page_keyword] = ACTIONS(3562),
    [anon_sym_codeunit] = ACTIONS(3562),
    [anon_sym_CODEUNIT] = ACTIONS(3562),
    [anon_sym_Codeunit] = ACTIONS(3562),
    [anon_sym_CodeUnit] = ACTIONS(3562),
    [anon_sym_COdeunit] = ACTIONS(3562),
    [anon_sym_codeUnit] = ACTIONS(3562),
    [sym_report_keyword] = ACTIONS(3562),
    [sym_query_keyword] = ACTIONS(3562),
    [anon_sym_xmlport] = ACTIONS(3562),
    [anon_sym_XMLPORT] = ACTIONS(3562),
    [anon_sym_Xmlport] = ACTIONS(3562),
    [anon_sym_XMLport] = ACTIONS(3562),
    [anon_sym_XMLPort] = ACTIONS(3562),
    [anon_sym_XmlPort] = ACTIONS(3562),
    [anon_sym_enum] = ACTIONS(3562),
    [anon_sym_ENUM] = ACTIONS(3562),
    [anon_sym_Enum] = ACTIONS(3562),
    [anon_sym_eNUM] = ACTIONS(3562),
    [anon_sym_eNum] = ACTIONS(3562),
    [anon_sym_ENum] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3564),
    [sym_verbatim_string] = ACTIONS(3564),
    [sym_integer] = ACTIONS(3562),
    [sym_continue_as_identifier] = ACTIONS(3564),
  },
  [STATE(3727)] = {
    [ts_builtin_sym_end] = ACTIONS(6854),
    [anon_sym_POUNDif] = ACTIONS(6854),
    [anon_sym_POUNDIF] = ACTIONS(6854),
    [anon_sym_POUNDIf] = ACTIONS(6854),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6856),
    [anon_sym_tableextension] = ACTIONS(6854),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6854),
    [anon_sym_Tableextension] = ACTIONS(6854),
    [anon_sym_TableExtension] = ACTIONS(6854),
    [anon_sym_tableExtension] = ACTIONS(6854),
    [sym_page_keyword] = ACTIONS(6856),
    [anon_sym_pageextension] = ACTIONS(6854),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6854),
    [anon_sym_Pageextension] = ACTIONS(6854),
    [anon_sym_PageExtension] = ACTIONS(6854),
    [anon_sym_pageExtension] = ACTIONS(6854),
    [anon_sym_codeunit] = ACTIONS(6854),
    [anon_sym_CODEUNIT] = ACTIONS(6854),
    [anon_sym_Codeunit] = ACTIONS(6854),
    [anon_sym_CodeUnit] = ACTIONS(6854),
    [anon_sym_COdeunit] = ACTIONS(6854),
    [anon_sym_codeUnit] = ACTIONS(6854),
    [sym_report_keyword] = ACTIONS(6856),
    [anon_sym_reportextension] = ACTIONS(6854),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6854),
    [anon_sym_Reportextension] = ACTIONS(6854),
    [anon_sym_ReportExtension] = ACTIONS(6854),
    [anon_sym_reportExtension] = ACTIONS(6854),
    [sym_query_keyword] = ACTIONS(6854),
    [anon_sym_xmlport] = ACTIONS(6854),
    [anon_sym_XMLPORT] = ACTIONS(6854),
    [anon_sym_Xmlport] = ACTIONS(6854),
    [anon_sym_XMLport] = ACTIONS(6854),
    [anon_sym_XMLPort] = ACTIONS(6854),
    [anon_sym_XmlPort] = ACTIONS(6854),
    [anon_sym_enum] = ACTIONS(6856),
    [anon_sym_ENUM] = ACTIONS(6856),
    [anon_sym_Enum] = ACTIONS(6856),
    [anon_sym_eNUM] = ACTIONS(6854),
    [anon_sym_eNum] = ACTIONS(6854),
    [anon_sym_ENum] = ACTIONS(6854),
    [anon_sym_enumextension] = ACTIONS(6854),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6854),
    [anon_sym_Enumextension] = ACTIONS(6854),
    [anon_sym_EnumExtension] = ACTIONS(6854),
    [anon_sym_enumExtension] = ACTIONS(6854),
    [sym_interface_keyword] = ACTIONS(6854),
    [anon_sym_controladdin] = ACTIONS(6854),
    [anon_sym_CONTROLADDIN] = ACTIONS(6854),
    [anon_sym_Controladdin] = ACTIONS(6854),
    [anon_sym_ControlAddIn] = ACTIONS(6854),
    [anon_sym_ControlAddin] = ACTIONS(6854),
    [anon_sym_controlAddIn] = ACTIONS(6854),
    [anon_sym_controlAddin] = ACTIONS(6854),
    [anon_sym_dotnet] = ACTIONS(6854),
    [anon_sym_DOTNET] = ACTIONS(6854),
    [anon_sym_Dotnet] = ACTIONS(6854),
    [anon_sym_DotNet] = ACTIONS(6854),
    [anon_sym_dotNet] = ACTIONS(6854),
    [sym_profile_keyword] = ACTIONS(6856),
    [anon_sym_profileextension] = ACTIONS(6854),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6854),
    [anon_sym_Profileextension] = ACTIONS(6854),
    [anon_sym_ProfileExtension] = ACTIONS(6854),
    [anon_sym_profileExtension] = ACTIONS(6854),
    [anon_sym_permissionset] = ACTIONS(6856),
    [anon_sym_PERMISSIONSET] = ACTIONS(6856),
    [anon_sym_Permissionset] = ACTIONS(6856),
    [anon_sym_PermissionSet] = ACTIONS(6856),
    [anon_sym_permissionSet] = ACTIONS(6856),
    [anon_sym_permissionsetextension] = ACTIONS(6854),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6854),
    [anon_sym_Permissionsetextension] = ACTIONS(6854),
    [anon_sym_PermissionSetExtension] = ACTIONS(6854),
    [anon_sym_permissionSetExtension] = ACTIONS(6854),
    [sym_entitlement_keyword] = ACTIONS(6854),
    [anon_sym_pagecustomization] = ACTIONS(6854),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6854),
    [anon_sym_Pagecustomization] = ACTIONS(6854),
    [anon_sym_PageCustomization] = ACTIONS(6854),
    [anon_sym_pageCustomization] = ACTIONS(6854),
    [sym_using_keyword] = ACTIONS(6854),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6854),
  },
  [STATE(3728)] = {
    [sym_boolean] = STATE(8836),
    [sym_simple_table_relation] = STATE(16581),
    [sym__namespaced_or_simple_ref] = STATE(15111),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8317),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(7151),
    [sym_keyword_as_identifier] = STATE(7151),
    [sym_identifier] = ACTIONS(7527),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7229),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(7533),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7535),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(3729)] = {
    [ts_builtin_sym_end] = ACTIONS(6834),
    [anon_sym_POUNDif] = ACTIONS(6834),
    [anon_sym_POUNDIF] = ACTIONS(6834),
    [anon_sym_POUNDIf] = ACTIONS(6834),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6836),
    [anon_sym_tableextension] = ACTIONS(6834),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6834),
    [anon_sym_Tableextension] = ACTIONS(6834),
    [anon_sym_TableExtension] = ACTIONS(6834),
    [anon_sym_tableExtension] = ACTIONS(6834),
    [sym_page_keyword] = ACTIONS(6836),
    [anon_sym_pageextension] = ACTIONS(6834),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6834),
    [anon_sym_Pageextension] = ACTIONS(6834),
    [anon_sym_PageExtension] = ACTIONS(6834),
    [anon_sym_pageExtension] = ACTIONS(6834),
    [anon_sym_codeunit] = ACTIONS(6834),
    [anon_sym_CODEUNIT] = ACTIONS(6834),
    [anon_sym_Codeunit] = ACTIONS(6834),
    [anon_sym_CodeUnit] = ACTIONS(6834),
    [anon_sym_COdeunit] = ACTIONS(6834),
    [anon_sym_codeUnit] = ACTIONS(6834),
    [sym_report_keyword] = ACTIONS(6836),
    [anon_sym_reportextension] = ACTIONS(6834),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6834),
    [anon_sym_Reportextension] = ACTIONS(6834),
    [anon_sym_ReportExtension] = ACTIONS(6834),
    [anon_sym_reportExtension] = ACTIONS(6834),
    [sym_query_keyword] = ACTIONS(6834),
    [anon_sym_xmlport] = ACTIONS(6834),
    [anon_sym_XMLPORT] = ACTIONS(6834),
    [anon_sym_Xmlport] = ACTIONS(6834),
    [anon_sym_XMLport] = ACTIONS(6834),
    [anon_sym_XMLPort] = ACTIONS(6834),
    [anon_sym_XmlPort] = ACTIONS(6834),
    [anon_sym_enum] = ACTIONS(6836),
    [anon_sym_ENUM] = ACTIONS(6836),
    [anon_sym_Enum] = ACTIONS(6836),
    [anon_sym_eNUM] = ACTIONS(6834),
    [anon_sym_eNum] = ACTIONS(6834),
    [anon_sym_ENum] = ACTIONS(6834),
    [anon_sym_enumextension] = ACTIONS(6834),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6834),
    [anon_sym_Enumextension] = ACTIONS(6834),
    [anon_sym_EnumExtension] = ACTIONS(6834),
    [anon_sym_enumExtension] = ACTIONS(6834),
    [sym_interface_keyword] = ACTIONS(6834),
    [anon_sym_controladdin] = ACTIONS(6834),
    [anon_sym_CONTROLADDIN] = ACTIONS(6834),
    [anon_sym_Controladdin] = ACTIONS(6834),
    [anon_sym_ControlAddIn] = ACTIONS(6834),
    [anon_sym_ControlAddin] = ACTIONS(6834),
    [anon_sym_controlAddIn] = ACTIONS(6834),
    [anon_sym_controlAddin] = ACTIONS(6834),
    [anon_sym_dotnet] = ACTIONS(6834),
    [anon_sym_DOTNET] = ACTIONS(6834),
    [anon_sym_Dotnet] = ACTIONS(6834),
    [anon_sym_DotNet] = ACTIONS(6834),
    [anon_sym_dotNet] = ACTIONS(6834),
    [sym_profile_keyword] = ACTIONS(6836),
    [anon_sym_profileextension] = ACTIONS(6834),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6834),
    [anon_sym_Profileextension] = ACTIONS(6834),
    [anon_sym_ProfileExtension] = ACTIONS(6834),
    [anon_sym_profileExtension] = ACTIONS(6834),
    [anon_sym_permissionset] = ACTIONS(6836),
    [anon_sym_PERMISSIONSET] = ACTIONS(6836),
    [anon_sym_Permissionset] = ACTIONS(6836),
    [anon_sym_PermissionSet] = ACTIONS(6836),
    [anon_sym_permissionSet] = ACTIONS(6836),
    [anon_sym_permissionsetextension] = ACTIONS(6834),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6834),
    [anon_sym_Permissionsetextension] = ACTIONS(6834),
    [anon_sym_PermissionSetExtension] = ACTIONS(6834),
    [anon_sym_permissionSetExtension] = ACTIONS(6834),
    [sym_entitlement_keyword] = ACTIONS(6834),
    [anon_sym_pagecustomization] = ACTIONS(6834),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6834),
    [anon_sym_Pagecustomization] = ACTIONS(6834),
    [anon_sym_PageCustomization] = ACTIONS(6834),
    [anon_sym_pageCustomization] = ACTIONS(6834),
    [sym_using_keyword] = ACTIONS(6834),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6834),
  },
  [STATE(3730)] = {
    [sym__body_element] = STATE(8121),
    [sym_empty_statement] = STATE(8121),
    [sym_property] = STATE(8121),
    [sym_permissions_property] = STATE(8121),
    [sym_table_relation_property] = STATE(8121),
    [sym_fields_section] = STATE(8121),
    [sym_keys_section] = STATE(8121),
    [sym_fieldgroups_section] = STATE(8121),
    [sym_enum_value_declaration] = STATE(8121),
    [sym_labels_section] = STATE(8121),
    [sym_layout_section] = STATE(8121),
    [sym_modify_modification] = STATE(8121),
    [sym_actions_section] = STATE(8121),
    [sym_views_section] = STATE(8121),
    [sym_dataset_section] = STATE(8121),
    [sym_report_dataitem] = STATE(3807),
    [sym__report_body_element] = STATE(3807),
    [sym_preproc_conditional_report] = STATE(3807),
    [sym_report_column] = STATE(3807),
    [sym_requestpage_section] = STATE(8121),
    [sym_rendering_section] = STATE(8121),
    [sym_elements_section] = STATE(8121),
    [sym_schema_section] = STATE(8121),
    [sym_assembly_declaration] = STATE(8121),
    [sym_event_declaration] = STATE(8121),
    [sym_procedure] = STATE(8121),
    [sym_preproc_split_procedure] = STATE(8121),
    [sym_preproc_split_procedure_preamble] = STATE(8121),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8121),
    [sym_var_section] = STATE(8121),
    [sym_attribute_item] = STATE(8121),
    [sym_preproc_conditional] = STATE(8121),
    [sym_preproc_if] = STATE(3548),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4033),
    [aux_sym_report_dataitem_repeat1] = STATE(3807),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8405),
    [anon_sym_POUNDELIF] = ACTIONS(8405),
    [anon_sym_POUNDElif] = ACTIONS(8405),
    [anon_sym_POUNDelse] = ACTIONS(8405),
    [anon_sym_POUNDELSE] = ACTIONS(8405),
    [anon_sym_POUNDElse] = ACTIONS(8405),
    [anon_sym_POUNDelse2] = ACTIONS(8405),
    [anon_sym_POUNDELSE2] = ACTIONS(8405),
    [anon_sym_POUNDElse2] = ACTIONS(8405),
    [anon_sym_POUNDendif] = ACTIONS(8405),
    [anon_sym_POUNDENDIF] = ACTIONS(8405),
    [anon_sym_POUNDEndif] = ACTIONS(8405),
    [anon_sym_POUNDendif2] = ACTIONS(8405),
    [anon_sym_POUNDENDIF2] = ACTIONS(8405),
    [anon_sym_POUNDEndif2] = ACTIONS(8405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8405),
  },
  [STATE(3731)] = {
    [ts_builtin_sym_end] = ACTIONS(7133),
    [anon_sym_POUNDif] = ACTIONS(7133),
    [anon_sym_POUNDIF] = ACTIONS(7133),
    [anon_sym_POUNDIf] = ACTIONS(7133),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7135),
    [anon_sym_tableextension] = ACTIONS(7133),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7133),
    [anon_sym_Tableextension] = ACTIONS(7133),
    [anon_sym_TableExtension] = ACTIONS(7133),
    [anon_sym_tableExtension] = ACTIONS(7133),
    [sym_page_keyword] = ACTIONS(7135),
    [anon_sym_pageextension] = ACTIONS(7133),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7133),
    [anon_sym_Pageextension] = ACTIONS(7133),
    [anon_sym_PageExtension] = ACTIONS(7133),
    [anon_sym_pageExtension] = ACTIONS(7133),
    [anon_sym_codeunit] = ACTIONS(7133),
    [anon_sym_CODEUNIT] = ACTIONS(7133),
    [anon_sym_Codeunit] = ACTIONS(7133),
    [anon_sym_CodeUnit] = ACTIONS(7133),
    [anon_sym_COdeunit] = ACTIONS(7133),
    [anon_sym_codeUnit] = ACTIONS(7133),
    [sym_report_keyword] = ACTIONS(7135),
    [anon_sym_reportextension] = ACTIONS(7133),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7133),
    [anon_sym_Reportextension] = ACTIONS(7133),
    [anon_sym_ReportExtension] = ACTIONS(7133),
    [anon_sym_reportExtension] = ACTIONS(7133),
    [sym_query_keyword] = ACTIONS(7133),
    [anon_sym_xmlport] = ACTIONS(7133),
    [anon_sym_XMLPORT] = ACTIONS(7133),
    [anon_sym_Xmlport] = ACTIONS(7133),
    [anon_sym_XMLport] = ACTIONS(7133),
    [anon_sym_XMLPort] = ACTIONS(7133),
    [anon_sym_XmlPort] = ACTIONS(7133),
    [anon_sym_enum] = ACTIONS(7135),
    [anon_sym_ENUM] = ACTIONS(7135),
    [anon_sym_Enum] = ACTIONS(7135),
    [anon_sym_eNUM] = ACTIONS(7133),
    [anon_sym_eNum] = ACTIONS(7133),
    [anon_sym_ENum] = ACTIONS(7133),
    [anon_sym_enumextension] = ACTIONS(7133),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7133),
    [anon_sym_Enumextension] = ACTIONS(7133),
    [anon_sym_EnumExtension] = ACTIONS(7133),
    [anon_sym_enumExtension] = ACTIONS(7133),
    [sym_interface_keyword] = ACTIONS(7133),
    [anon_sym_controladdin] = ACTIONS(7133),
    [anon_sym_CONTROLADDIN] = ACTIONS(7133),
    [anon_sym_Controladdin] = ACTIONS(7133),
    [anon_sym_ControlAddIn] = ACTIONS(7133),
    [anon_sym_ControlAddin] = ACTIONS(7133),
    [anon_sym_controlAddIn] = ACTIONS(7133),
    [anon_sym_controlAddin] = ACTIONS(7133),
    [anon_sym_dotnet] = ACTIONS(7133),
    [anon_sym_DOTNET] = ACTIONS(7133),
    [anon_sym_Dotnet] = ACTIONS(7133),
    [anon_sym_DotNet] = ACTIONS(7133),
    [anon_sym_dotNet] = ACTIONS(7133),
    [sym_profile_keyword] = ACTIONS(7135),
    [anon_sym_profileextension] = ACTIONS(7133),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7133),
    [anon_sym_Profileextension] = ACTIONS(7133),
    [anon_sym_ProfileExtension] = ACTIONS(7133),
    [anon_sym_profileExtension] = ACTIONS(7133),
    [anon_sym_permissionset] = ACTIONS(7135),
    [anon_sym_PERMISSIONSET] = ACTIONS(7135),
    [anon_sym_Permissionset] = ACTIONS(7135),
    [anon_sym_PermissionSet] = ACTIONS(7135),
    [anon_sym_permissionSet] = ACTIONS(7135),
    [anon_sym_permissionsetextension] = ACTIONS(7133),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7133),
    [anon_sym_Permissionsetextension] = ACTIONS(7133),
    [anon_sym_PermissionSetExtension] = ACTIONS(7133),
    [anon_sym_permissionSetExtension] = ACTIONS(7133),
    [sym_entitlement_keyword] = ACTIONS(7133),
    [anon_sym_pagecustomization] = ACTIONS(7133),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7133),
    [anon_sym_Pagecustomization] = ACTIONS(7133),
    [anon_sym_PageCustomization] = ACTIONS(7133),
    [anon_sym_pageCustomization] = ACTIONS(7133),
    [sym_using_keyword] = ACTIONS(7133),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7133),
  },
  [STATE(3732)] = {
    [ts_builtin_sym_end] = ACTIONS(6838),
    [anon_sym_POUNDif] = ACTIONS(6838),
    [anon_sym_POUNDIF] = ACTIONS(6838),
    [anon_sym_POUNDIf] = ACTIONS(6838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6840),
    [anon_sym_tableextension] = ACTIONS(6838),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6838),
    [anon_sym_Tableextension] = ACTIONS(6838),
    [anon_sym_TableExtension] = ACTIONS(6838),
    [anon_sym_tableExtension] = ACTIONS(6838),
    [sym_page_keyword] = ACTIONS(6840),
    [anon_sym_pageextension] = ACTIONS(6838),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6838),
    [anon_sym_Pageextension] = ACTIONS(6838),
    [anon_sym_PageExtension] = ACTIONS(6838),
    [anon_sym_pageExtension] = ACTIONS(6838),
    [anon_sym_codeunit] = ACTIONS(6838),
    [anon_sym_CODEUNIT] = ACTIONS(6838),
    [anon_sym_Codeunit] = ACTIONS(6838),
    [anon_sym_CodeUnit] = ACTIONS(6838),
    [anon_sym_COdeunit] = ACTIONS(6838),
    [anon_sym_codeUnit] = ACTIONS(6838),
    [sym_report_keyword] = ACTIONS(6840),
    [anon_sym_reportextension] = ACTIONS(6838),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6838),
    [anon_sym_Reportextension] = ACTIONS(6838),
    [anon_sym_ReportExtension] = ACTIONS(6838),
    [anon_sym_reportExtension] = ACTIONS(6838),
    [sym_query_keyword] = ACTIONS(6838),
    [anon_sym_xmlport] = ACTIONS(6838),
    [anon_sym_XMLPORT] = ACTIONS(6838),
    [anon_sym_Xmlport] = ACTIONS(6838),
    [anon_sym_XMLport] = ACTIONS(6838),
    [anon_sym_XMLPort] = ACTIONS(6838),
    [anon_sym_XmlPort] = ACTIONS(6838),
    [anon_sym_enum] = ACTIONS(6840),
    [anon_sym_ENUM] = ACTIONS(6840),
    [anon_sym_Enum] = ACTIONS(6840),
    [anon_sym_eNUM] = ACTIONS(6838),
    [anon_sym_eNum] = ACTIONS(6838),
    [anon_sym_ENum] = ACTIONS(6838),
    [anon_sym_enumextension] = ACTIONS(6838),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6838),
    [anon_sym_Enumextension] = ACTIONS(6838),
    [anon_sym_EnumExtension] = ACTIONS(6838),
    [anon_sym_enumExtension] = ACTIONS(6838),
    [sym_interface_keyword] = ACTIONS(6838),
    [anon_sym_controladdin] = ACTIONS(6838),
    [anon_sym_CONTROLADDIN] = ACTIONS(6838),
    [anon_sym_Controladdin] = ACTIONS(6838),
    [anon_sym_ControlAddIn] = ACTIONS(6838),
    [anon_sym_ControlAddin] = ACTIONS(6838),
    [anon_sym_controlAddIn] = ACTIONS(6838),
    [anon_sym_controlAddin] = ACTIONS(6838),
    [anon_sym_dotnet] = ACTIONS(6838),
    [anon_sym_DOTNET] = ACTIONS(6838),
    [anon_sym_Dotnet] = ACTIONS(6838),
    [anon_sym_DotNet] = ACTIONS(6838),
    [anon_sym_dotNet] = ACTIONS(6838),
    [sym_profile_keyword] = ACTIONS(6840),
    [anon_sym_profileextension] = ACTIONS(6838),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6838),
    [anon_sym_Profileextension] = ACTIONS(6838),
    [anon_sym_ProfileExtension] = ACTIONS(6838),
    [anon_sym_profileExtension] = ACTIONS(6838),
    [anon_sym_permissionset] = ACTIONS(6840),
    [anon_sym_PERMISSIONSET] = ACTIONS(6840),
    [anon_sym_Permissionset] = ACTIONS(6840),
    [anon_sym_PermissionSet] = ACTIONS(6840),
    [anon_sym_permissionSet] = ACTIONS(6840),
    [anon_sym_permissionsetextension] = ACTIONS(6838),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6838),
    [anon_sym_Permissionsetextension] = ACTIONS(6838),
    [anon_sym_PermissionSetExtension] = ACTIONS(6838),
    [anon_sym_permissionSetExtension] = ACTIONS(6838),
    [sym_entitlement_keyword] = ACTIONS(6838),
    [anon_sym_pagecustomization] = ACTIONS(6838),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6838),
    [anon_sym_Pagecustomization] = ACTIONS(6838),
    [anon_sym_PageCustomization] = ACTIONS(6838),
    [anon_sym_pageCustomization] = ACTIONS(6838),
    [sym_using_keyword] = ACTIONS(6838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6838),
  },
  [STATE(3733)] = {
    [ts_builtin_sym_end] = ACTIONS(7141),
    [anon_sym_POUNDif] = ACTIONS(7141),
    [anon_sym_POUNDIF] = ACTIONS(7141),
    [anon_sym_POUNDIf] = ACTIONS(7141),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7143),
    [anon_sym_tableextension] = ACTIONS(7141),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7141),
    [anon_sym_Tableextension] = ACTIONS(7141),
    [anon_sym_TableExtension] = ACTIONS(7141),
    [anon_sym_tableExtension] = ACTIONS(7141),
    [sym_page_keyword] = ACTIONS(7143),
    [anon_sym_pageextension] = ACTIONS(7141),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7141),
    [anon_sym_Pageextension] = ACTIONS(7141),
    [anon_sym_PageExtension] = ACTIONS(7141),
    [anon_sym_pageExtension] = ACTIONS(7141),
    [anon_sym_codeunit] = ACTIONS(7141),
    [anon_sym_CODEUNIT] = ACTIONS(7141),
    [anon_sym_Codeunit] = ACTIONS(7141),
    [anon_sym_CodeUnit] = ACTIONS(7141),
    [anon_sym_COdeunit] = ACTIONS(7141),
    [anon_sym_codeUnit] = ACTIONS(7141),
    [sym_report_keyword] = ACTIONS(7143),
    [anon_sym_reportextension] = ACTIONS(7141),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7141),
    [anon_sym_Reportextension] = ACTIONS(7141),
    [anon_sym_ReportExtension] = ACTIONS(7141),
    [anon_sym_reportExtension] = ACTIONS(7141),
    [sym_query_keyword] = ACTIONS(7141),
    [anon_sym_xmlport] = ACTIONS(7141),
    [anon_sym_XMLPORT] = ACTIONS(7141),
    [anon_sym_Xmlport] = ACTIONS(7141),
    [anon_sym_XMLport] = ACTIONS(7141),
    [anon_sym_XMLPort] = ACTIONS(7141),
    [anon_sym_XmlPort] = ACTIONS(7141),
    [anon_sym_enum] = ACTIONS(7143),
    [anon_sym_ENUM] = ACTIONS(7143),
    [anon_sym_Enum] = ACTIONS(7143),
    [anon_sym_eNUM] = ACTIONS(7141),
    [anon_sym_eNum] = ACTIONS(7141),
    [anon_sym_ENum] = ACTIONS(7141),
    [anon_sym_enumextension] = ACTIONS(7141),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7141),
    [anon_sym_Enumextension] = ACTIONS(7141),
    [anon_sym_EnumExtension] = ACTIONS(7141),
    [anon_sym_enumExtension] = ACTIONS(7141),
    [sym_interface_keyword] = ACTIONS(7141),
    [anon_sym_controladdin] = ACTIONS(7141),
    [anon_sym_CONTROLADDIN] = ACTIONS(7141),
    [anon_sym_Controladdin] = ACTIONS(7141),
    [anon_sym_ControlAddIn] = ACTIONS(7141),
    [anon_sym_ControlAddin] = ACTIONS(7141),
    [anon_sym_controlAddIn] = ACTIONS(7141),
    [anon_sym_controlAddin] = ACTIONS(7141),
    [anon_sym_dotnet] = ACTIONS(7141),
    [anon_sym_DOTNET] = ACTIONS(7141),
    [anon_sym_Dotnet] = ACTIONS(7141),
    [anon_sym_DotNet] = ACTIONS(7141),
    [anon_sym_dotNet] = ACTIONS(7141),
    [sym_profile_keyword] = ACTIONS(7143),
    [anon_sym_profileextension] = ACTIONS(7141),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7141),
    [anon_sym_Profileextension] = ACTIONS(7141),
    [anon_sym_ProfileExtension] = ACTIONS(7141),
    [anon_sym_profileExtension] = ACTIONS(7141),
    [anon_sym_permissionset] = ACTIONS(7143),
    [anon_sym_PERMISSIONSET] = ACTIONS(7143),
    [anon_sym_Permissionset] = ACTIONS(7143),
    [anon_sym_PermissionSet] = ACTIONS(7143),
    [anon_sym_permissionSet] = ACTIONS(7143),
    [anon_sym_permissionsetextension] = ACTIONS(7141),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7141),
    [anon_sym_Permissionsetextension] = ACTIONS(7141),
    [anon_sym_PermissionSetExtension] = ACTIONS(7141),
    [anon_sym_permissionSetExtension] = ACTIONS(7141),
    [sym_entitlement_keyword] = ACTIONS(7141),
    [anon_sym_pagecustomization] = ACTIONS(7141),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7141),
    [anon_sym_Pagecustomization] = ACTIONS(7141),
    [anon_sym_PageCustomization] = ACTIONS(7141),
    [anon_sym_pageCustomization] = ACTIONS(7141),
    [sym_using_keyword] = ACTIONS(7141),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7141),
  },
  [STATE(3734)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3888),
    [sym_preproc_conditional_case_patterns] = STATE(3888),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8408),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(8410),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [anon_sym_else] = ACTIONS(8410),
    [anon_sym_ELSE] = ACTIONS(8410),
    [anon_sym_Else] = ACTIONS(8410),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3735)] = {
    [ts_builtin_sym_end] = ACTIONS(7161),
    [anon_sym_POUNDif] = ACTIONS(7161),
    [anon_sym_POUNDIF] = ACTIONS(7161),
    [anon_sym_POUNDIf] = ACTIONS(7161),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7163),
    [anon_sym_tableextension] = ACTIONS(7161),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7161),
    [anon_sym_Tableextension] = ACTIONS(7161),
    [anon_sym_TableExtension] = ACTIONS(7161),
    [anon_sym_tableExtension] = ACTIONS(7161),
    [sym_page_keyword] = ACTIONS(7163),
    [anon_sym_pageextension] = ACTIONS(7161),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7161),
    [anon_sym_Pageextension] = ACTIONS(7161),
    [anon_sym_PageExtension] = ACTIONS(7161),
    [anon_sym_pageExtension] = ACTIONS(7161),
    [anon_sym_codeunit] = ACTIONS(7161),
    [anon_sym_CODEUNIT] = ACTIONS(7161),
    [anon_sym_Codeunit] = ACTIONS(7161),
    [anon_sym_CodeUnit] = ACTIONS(7161),
    [anon_sym_COdeunit] = ACTIONS(7161),
    [anon_sym_codeUnit] = ACTIONS(7161),
    [sym_report_keyword] = ACTIONS(7163),
    [anon_sym_reportextension] = ACTIONS(7161),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7161),
    [anon_sym_Reportextension] = ACTIONS(7161),
    [anon_sym_ReportExtension] = ACTIONS(7161),
    [anon_sym_reportExtension] = ACTIONS(7161),
    [sym_query_keyword] = ACTIONS(7161),
    [anon_sym_xmlport] = ACTIONS(7161),
    [anon_sym_XMLPORT] = ACTIONS(7161),
    [anon_sym_Xmlport] = ACTIONS(7161),
    [anon_sym_XMLport] = ACTIONS(7161),
    [anon_sym_XMLPort] = ACTIONS(7161),
    [anon_sym_XmlPort] = ACTIONS(7161),
    [anon_sym_enum] = ACTIONS(7163),
    [anon_sym_ENUM] = ACTIONS(7163),
    [anon_sym_Enum] = ACTIONS(7163),
    [anon_sym_eNUM] = ACTIONS(7161),
    [anon_sym_eNum] = ACTIONS(7161),
    [anon_sym_ENum] = ACTIONS(7161),
    [anon_sym_enumextension] = ACTIONS(7161),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7161),
    [anon_sym_Enumextension] = ACTIONS(7161),
    [anon_sym_EnumExtension] = ACTIONS(7161),
    [anon_sym_enumExtension] = ACTIONS(7161),
    [sym_interface_keyword] = ACTIONS(7161),
    [anon_sym_controladdin] = ACTIONS(7161),
    [anon_sym_CONTROLADDIN] = ACTIONS(7161),
    [anon_sym_Controladdin] = ACTIONS(7161),
    [anon_sym_ControlAddIn] = ACTIONS(7161),
    [anon_sym_ControlAddin] = ACTIONS(7161),
    [anon_sym_controlAddIn] = ACTIONS(7161),
    [anon_sym_controlAddin] = ACTIONS(7161),
    [anon_sym_dotnet] = ACTIONS(7161),
    [anon_sym_DOTNET] = ACTIONS(7161),
    [anon_sym_Dotnet] = ACTIONS(7161),
    [anon_sym_DotNet] = ACTIONS(7161),
    [anon_sym_dotNet] = ACTIONS(7161),
    [sym_profile_keyword] = ACTIONS(7163),
    [anon_sym_profileextension] = ACTIONS(7161),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7161),
    [anon_sym_Profileextension] = ACTIONS(7161),
    [anon_sym_ProfileExtension] = ACTIONS(7161),
    [anon_sym_profileExtension] = ACTIONS(7161),
    [anon_sym_permissionset] = ACTIONS(7163),
    [anon_sym_PERMISSIONSET] = ACTIONS(7163),
    [anon_sym_Permissionset] = ACTIONS(7163),
    [anon_sym_PermissionSet] = ACTIONS(7163),
    [anon_sym_permissionSet] = ACTIONS(7163),
    [anon_sym_permissionsetextension] = ACTIONS(7161),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7161),
    [anon_sym_Permissionsetextension] = ACTIONS(7161),
    [anon_sym_PermissionSetExtension] = ACTIONS(7161),
    [anon_sym_permissionSetExtension] = ACTIONS(7161),
    [sym_entitlement_keyword] = ACTIONS(7161),
    [anon_sym_pagecustomization] = ACTIONS(7161),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7161),
    [anon_sym_Pagecustomization] = ACTIONS(7161),
    [anon_sym_PageCustomization] = ACTIONS(7161),
    [anon_sym_pageCustomization] = ACTIONS(7161),
    [sym_using_keyword] = ACTIONS(7161),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7161),
  },
  [STATE(3736)] = {
    [ts_builtin_sym_end] = ACTIONS(7125),
    [anon_sym_POUNDif] = ACTIONS(7125),
    [anon_sym_POUNDIF] = ACTIONS(7125),
    [anon_sym_POUNDIf] = ACTIONS(7125),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7127),
    [anon_sym_tableextension] = ACTIONS(7125),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7125),
    [anon_sym_Tableextension] = ACTIONS(7125),
    [anon_sym_TableExtension] = ACTIONS(7125),
    [anon_sym_tableExtension] = ACTIONS(7125),
    [sym_page_keyword] = ACTIONS(7127),
    [anon_sym_pageextension] = ACTIONS(7125),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7125),
    [anon_sym_Pageextension] = ACTIONS(7125),
    [anon_sym_PageExtension] = ACTIONS(7125),
    [anon_sym_pageExtension] = ACTIONS(7125),
    [anon_sym_codeunit] = ACTIONS(7125),
    [anon_sym_CODEUNIT] = ACTIONS(7125),
    [anon_sym_Codeunit] = ACTIONS(7125),
    [anon_sym_CodeUnit] = ACTIONS(7125),
    [anon_sym_COdeunit] = ACTIONS(7125),
    [anon_sym_codeUnit] = ACTIONS(7125),
    [sym_report_keyword] = ACTIONS(7127),
    [anon_sym_reportextension] = ACTIONS(7125),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7125),
    [anon_sym_Reportextension] = ACTIONS(7125),
    [anon_sym_ReportExtension] = ACTIONS(7125),
    [anon_sym_reportExtension] = ACTIONS(7125),
    [sym_query_keyword] = ACTIONS(7125),
    [anon_sym_xmlport] = ACTIONS(7125),
    [anon_sym_XMLPORT] = ACTIONS(7125),
    [anon_sym_Xmlport] = ACTIONS(7125),
    [anon_sym_XMLport] = ACTIONS(7125),
    [anon_sym_XMLPort] = ACTIONS(7125),
    [anon_sym_XmlPort] = ACTIONS(7125),
    [anon_sym_enum] = ACTIONS(7127),
    [anon_sym_ENUM] = ACTIONS(7127),
    [anon_sym_Enum] = ACTIONS(7127),
    [anon_sym_eNUM] = ACTIONS(7125),
    [anon_sym_eNum] = ACTIONS(7125),
    [anon_sym_ENum] = ACTIONS(7125),
    [anon_sym_enumextension] = ACTIONS(7125),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7125),
    [anon_sym_Enumextension] = ACTIONS(7125),
    [anon_sym_EnumExtension] = ACTIONS(7125),
    [anon_sym_enumExtension] = ACTIONS(7125),
    [sym_interface_keyword] = ACTIONS(7125),
    [anon_sym_controladdin] = ACTIONS(7125),
    [anon_sym_CONTROLADDIN] = ACTIONS(7125),
    [anon_sym_Controladdin] = ACTIONS(7125),
    [anon_sym_ControlAddIn] = ACTIONS(7125),
    [anon_sym_ControlAddin] = ACTIONS(7125),
    [anon_sym_controlAddIn] = ACTIONS(7125),
    [anon_sym_controlAddin] = ACTIONS(7125),
    [anon_sym_dotnet] = ACTIONS(7125),
    [anon_sym_DOTNET] = ACTIONS(7125),
    [anon_sym_Dotnet] = ACTIONS(7125),
    [anon_sym_DotNet] = ACTIONS(7125),
    [anon_sym_dotNet] = ACTIONS(7125),
    [sym_profile_keyword] = ACTIONS(7127),
    [anon_sym_profileextension] = ACTIONS(7125),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7125),
    [anon_sym_Profileextension] = ACTIONS(7125),
    [anon_sym_ProfileExtension] = ACTIONS(7125),
    [anon_sym_profileExtension] = ACTIONS(7125),
    [anon_sym_permissionset] = ACTIONS(7127),
    [anon_sym_PERMISSIONSET] = ACTIONS(7127),
    [anon_sym_Permissionset] = ACTIONS(7127),
    [anon_sym_PermissionSet] = ACTIONS(7127),
    [anon_sym_permissionSet] = ACTIONS(7127),
    [anon_sym_permissionsetextension] = ACTIONS(7125),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7125),
    [anon_sym_Permissionsetextension] = ACTIONS(7125),
    [anon_sym_PermissionSetExtension] = ACTIONS(7125),
    [anon_sym_permissionSetExtension] = ACTIONS(7125),
    [sym_entitlement_keyword] = ACTIONS(7125),
    [anon_sym_pagecustomization] = ACTIONS(7125),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7125),
    [anon_sym_Pagecustomization] = ACTIONS(7125),
    [anon_sym_PageCustomization] = ACTIONS(7125),
    [anon_sym_pageCustomization] = ACTIONS(7125),
    [sym_using_keyword] = ACTIONS(7125),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7125),
  },
  [STATE(3737)] = {
    [sym_boolean] = STATE(8798),
    [sym_simple_table_relation] = STATE(9003),
    [sym__namespaced_or_simple_ref] = STATE(8712),
    [sym_assignment_expression] = STATE(8798),
    [sym__expression] = STATE(8798),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8798),
    [sym_multiplicative_expression] = STATE(8798),
    [sym_additive_expression] = STATE(8798),
    [sym_comparison_expression] = STATE(8798),
    [sym_logical_expression] = STATE(8798),
    [sym_ternary_expression] = STATE(8798),
    [sym_unary_expression] = STATE(8798),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(4060),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8798),
    [sym_list_literal] = STATE(8798),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8798),
    [sym__literal_value] = STATE(8798),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym__identifier_or_quoted] = STATE(8690),
    [sym_keyword_as_identifier] = STATE(8690),
    [sym_identifier] = ACTIONS(7539),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7541),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_where_condition_token1] = ACTIONS(7543),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(7545),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(7543),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7543),
    [aux_sym_separator_action_token1] = ACTIONS(7543),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7543),
    [aux_sym_type_declaration_token1] = ACTIONS(7543),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7547),
    [sym_date_literal] = ACTIONS(7541),
    [sym_time_literal] = ACTIONS(7541),
    [sym_biginteger_literal] = ACTIONS(7547),
    [sym_table_keyword] = ACTIONS(7543),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_key_keyword] = ACTIONS(7543),
    [sym_dataset_keyword] = ACTIONS(7543),
    [sym_quoted_identifier] = ACTIONS(7549),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7547),
    [sym_verbatim_string] = ACTIONS(7547),
    [sym_integer] = ACTIONS(7551),
    [sym_continue_as_identifier] = ACTIONS(7547),
  },
  [STATE(3738)] = {
    [ts_builtin_sym_end] = ACTIONS(6931),
    [anon_sym_POUNDif] = ACTIONS(6931),
    [anon_sym_POUNDIF] = ACTIONS(6931),
    [anon_sym_POUNDIf] = ACTIONS(6931),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6933),
    [anon_sym_tableextension] = ACTIONS(6931),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6931),
    [anon_sym_Tableextension] = ACTIONS(6931),
    [anon_sym_TableExtension] = ACTIONS(6931),
    [anon_sym_tableExtension] = ACTIONS(6931),
    [sym_page_keyword] = ACTIONS(6933),
    [anon_sym_pageextension] = ACTIONS(6931),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6931),
    [anon_sym_Pageextension] = ACTIONS(6931),
    [anon_sym_PageExtension] = ACTIONS(6931),
    [anon_sym_pageExtension] = ACTIONS(6931),
    [anon_sym_codeunit] = ACTIONS(6931),
    [anon_sym_CODEUNIT] = ACTIONS(6931),
    [anon_sym_Codeunit] = ACTIONS(6931),
    [anon_sym_CodeUnit] = ACTIONS(6931),
    [anon_sym_COdeunit] = ACTIONS(6931),
    [anon_sym_codeUnit] = ACTIONS(6931),
    [sym_report_keyword] = ACTIONS(6933),
    [anon_sym_reportextension] = ACTIONS(6931),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6931),
    [anon_sym_Reportextension] = ACTIONS(6931),
    [anon_sym_ReportExtension] = ACTIONS(6931),
    [anon_sym_reportExtension] = ACTIONS(6931),
    [sym_query_keyword] = ACTIONS(6931),
    [anon_sym_xmlport] = ACTIONS(6931),
    [anon_sym_XMLPORT] = ACTIONS(6931),
    [anon_sym_Xmlport] = ACTIONS(6931),
    [anon_sym_XMLport] = ACTIONS(6931),
    [anon_sym_XMLPort] = ACTIONS(6931),
    [anon_sym_XmlPort] = ACTIONS(6931),
    [anon_sym_enum] = ACTIONS(6933),
    [anon_sym_ENUM] = ACTIONS(6933),
    [anon_sym_Enum] = ACTIONS(6933),
    [anon_sym_eNUM] = ACTIONS(6931),
    [anon_sym_eNum] = ACTIONS(6931),
    [anon_sym_ENum] = ACTIONS(6931),
    [anon_sym_enumextension] = ACTIONS(6931),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6931),
    [anon_sym_Enumextension] = ACTIONS(6931),
    [anon_sym_EnumExtension] = ACTIONS(6931),
    [anon_sym_enumExtension] = ACTIONS(6931),
    [sym_interface_keyword] = ACTIONS(6931),
    [anon_sym_controladdin] = ACTIONS(6931),
    [anon_sym_CONTROLADDIN] = ACTIONS(6931),
    [anon_sym_Controladdin] = ACTIONS(6931),
    [anon_sym_ControlAddIn] = ACTIONS(6931),
    [anon_sym_ControlAddin] = ACTIONS(6931),
    [anon_sym_controlAddIn] = ACTIONS(6931),
    [anon_sym_controlAddin] = ACTIONS(6931),
    [anon_sym_dotnet] = ACTIONS(6931),
    [anon_sym_DOTNET] = ACTIONS(6931),
    [anon_sym_Dotnet] = ACTIONS(6931),
    [anon_sym_DotNet] = ACTIONS(6931),
    [anon_sym_dotNet] = ACTIONS(6931),
    [sym_profile_keyword] = ACTIONS(6933),
    [anon_sym_profileextension] = ACTIONS(6931),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6931),
    [anon_sym_Profileextension] = ACTIONS(6931),
    [anon_sym_ProfileExtension] = ACTIONS(6931),
    [anon_sym_profileExtension] = ACTIONS(6931),
    [anon_sym_permissionset] = ACTIONS(6933),
    [anon_sym_PERMISSIONSET] = ACTIONS(6933),
    [anon_sym_Permissionset] = ACTIONS(6933),
    [anon_sym_PermissionSet] = ACTIONS(6933),
    [anon_sym_permissionSet] = ACTIONS(6933),
    [anon_sym_permissionsetextension] = ACTIONS(6931),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6931),
    [anon_sym_Permissionsetextension] = ACTIONS(6931),
    [anon_sym_PermissionSetExtension] = ACTIONS(6931),
    [anon_sym_permissionSetExtension] = ACTIONS(6931),
    [sym_entitlement_keyword] = ACTIONS(6931),
    [anon_sym_pagecustomization] = ACTIONS(6931),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6931),
    [anon_sym_Pagecustomization] = ACTIONS(6931),
    [anon_sym_PageCustomization] = ACTIONS(6931),
    [anon_sym_pageCustomization] = ACTIONS(6931),
    [sym_using_keyword] = ACTIONS(6931),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6931),
  },
  [STATE(3739)] = {
    [ts_builtin_sym_end] = ACTIONS(6965),
    [anon_sym_POUNDif] = ACTIONS(6965),
    [anon_sym_POUNDIF] = ACTIONS(6965),
    [anon_sym_POUNDIf] = ACTIONS(6965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6967),
    [anon_sym_tableextension] = ACTIONS(6965),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6965),
    [anon_sym_Tableextension] = ACTIONS(6965),
    [anon_sym_TableExtension] = ACTIONS(6965),
    [anon_sym_tableExtension] = ACTIONS(6965),
    [sym_page_keyword] = ACTIONS(6967),
    [anon_sym_pageextension] = ACTIONS(6965),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6965),
    [anon_sym_Pageextension] = ACTIONS(6965),
    [anon_sym_PageExtension] = ACTIONS(6965),
    [anon_sym_pageExtension] = ACTIONS(6965),
    [anon_sym_codeunit] = ACTIONS(6965),
    [anon_sym_CODEUNIT] = ACTIONS(6965),
    [anon_sym_Codeunit] = ACTIONS(6965),
    [anon_sym_CodeUnit] = ACTIONS(6965),
    [anon_sym_COdeunit] = ACTIONS(6965),
    [anon_sym_codeUnit] = ACTIONS(6965),
    [sym_report_keyword] = ACTIONS(6967),
    [anon_sym_reportextension] = ACTIONS(6965),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6965),
    [anon_sym_Reportextension] = ACTIONS(6965),
    [anon_sym_ReportExtension] = ACTIONS(6965),
    [anon_sym_reportExtension] = ACTIONS(6965),
    [sym_query_keyword] = ACTIONS(6965),
    [anon_sym_xmlport] = ACTIONS(6965),
    [anon_sym_XMLPORT] = ACTIONS(6965),
    [anon_sym_Xmlport] = ACTIONS(6965),
    [anon_sym_XMLport] = ACTIONS(6965),
    [anon_sym_XMLPort] = ACTIONS(6965),
    [anon_sym_XmlPort] = ACTIONS(6965),
    [anon_sym_enum] = ACTIONS(6967),
    [anon_sym_ENUM] = ACTIONS(6967),
    [anon_sym_Enum] = ACTIONS(6967),
    [anon_sym_eNUM] = ACTIONS(6965),
    [anon_sym_eNum] = ACTIONS(6965),
    [anon_sym_ENum] = ACTIONS(6965),
    [anon_sym_enumextension] = ACTIONS(6965),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6965),
    [anon_sym_Enumextension] = ACTIONS(6965),
    [anon_sym_EnumExtension] = ACTIONS(6965),
    [anon_sym_enumExtension] = ACTIONS(6965),
    [sym_interface_keyword] = ACTIONS(6965),
    [anon_sym_controladdin] = ACTIONS(6965),
    [anon_sym_CONTROLADDIN] = ACTIONS(6965),
    [anon_sym_Controladdin] = ACTIONS(6965),
    [anon_sym_ControlAddIn] = ACTIONS(6965),
    [anon_sym_ControlAddin] = ACTIONS(6965),
    [anon_sym_controlAddIn] = ACTIONS(6965),
    [anon_sym_controlAddin] = ACTIONS(6965),
    [anon_sym_dotnet] = ACTIONS(6965),
    [anon_sym_DOTNET] = ACTIONS(6965),
    [anon_sym_Dotnet] = ACTIONS(6965),
    [anon_sym_DotNet] = ACTIONS(6965),
    [anon_sym_dotNet] = ACTIONS(6965),
    [sym_profile_keyword] = ACTIONS(6967),
    [anon_sym_profileextension] = ACTIONS(6965),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6965),
    [anon_sym_Profileextension] = ACTIONS(6965),
    [anon_sym_ProfileExtension] = ACTIONS(6965),
    [anon_sym_profileExtension] = ACTIONS(6965),
    [anon_sym_permissionset] = ACTIONS(6967),
    [anon_sym_PERMISSIONSET] = ACTIONS(6967),
    [anon_sym_Permissionset] = ACTIONS(6967),
    [anon_sym_PermissionSet] = ACTIONS(6967),
    [anon_sym_permissionSet] = ACTIONS(6967),
    [anon_sym_permissionsetextension] = ACTIONS(6965),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6965),
    [anon_sym_Permissionsetextension] = ACTIONS(6965),
    [anon_sym_PermissionSetExtension] = ACTIONS(6965),
    [anon_sym_permissionSetExtension] = ACTIONS(6965),
    [sym_entitlement_keyword] = ACTIONS(6965),
    [anon_sym_pagecustomization] = ACTIONS(6965),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6965),
    [anon_sym_Pagecustomization] = ACTIONS(6965),
    [anon_sym_PageCustomization] = ACTIONS(6965),
    [anon_sym_pageCustomization] = ACTIONS(6965),
    [sym_using_keyword] = ACTIONS(6965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6965),
  },
  [STATE(3740)] = {
    [ts_builtin_sym_end] = ACTIONS(6953),
    [anon_sym_POUNDif] = ACTIONS(6953),
    [anon_sym_POUNDIF] = ACTIONS(6953),
    [anon_sym_POUNDIf] = ACTIONS(6953),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6955),
    [anon_sym_tableextension] = ACTIONS(6953),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6953),
    [anon_sym_Tableextension] = ACTIONS(6953),
    [anon_sym_TableExtension] = ACTIONS(6953),
    [anon_sym_tableExtension] = ACTIONS(6953),
    [sym_page_keyword] = ACTIONS(6955),
    [anon_sym_pageextension] = ACTIONS(6953),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6953),
    [anon_sym_Pageextension] = ACTIONS(6953),
    [anon_sym_PageExtension] = ACTIONS(6953),
    [anon_sym_pageExtension] = ACTIONS(6953),
    [anon_sym_codeunit] = ACTIONS(6953),
    [anon_sym_CODEUNIT] = ACTIONS(6953),
    [anon_sym_Codeunit] = ACTIONS(6953),
    [anon_sym_CodeUnit] = ACTIONS(6953),
    [anon_sym_COdeunit] = ACTIONS(6953),
    [anon_sym_codeUnit] = ACTIONS(6953),
    [sym_report_keyword] = ACTIONS(6955),
    [anon_sym_reportextension] = ACTIONS(6953),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6953),
    [anon_sym_Reportextension] = ACTIONS(6953),
    [anon_sym_ReportExtension] = ACTIONS(6953),
    [anon_sym_reportExtension] = ACTIONS(6953),
    [sym_query_keyword] = ACTIONS(6953),
    [anon_sym_xmlport] = ACTIONS(6953),
    [anon_sym_XMLPORT] = ACTIONS(6953),
    [anon_sym_Xmlport] = ACTIONS(6953),
    [anon_sym_XMLport] = ACTIONS(6953),
    [anon_sym_XMLPort] = ACTIONS(6953),
    [anon_sym_XmlPort] = ACTIONS(6953),
    [anon_sym_enum] = ACTIONS(6955),
    [anon_sym_ENUM] = ACTIONS(6955),
    [anon_sym_Enum] = ACTIONS(6955),
    [anon_sym_eNUM] = ACTIONS(6953),
    [anon_sym_eNum] = ACTIONS(6953),
    [anon_sym_ENum] = ACTIONS(6953),
    [anon_sym_enumextension] = ACTIONS(6953),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6953),
    [anon_sym_Enumextension] = ACTIONS(6953),
    [anon_sym_EnumExtension] = ACTIONS(6953),
    [anon_sym_enumExtension] = ACTIONS(6953),
    [sym_interface_keyword] = ACTIONS(6953),
    [anon_sym_controladdin] = ACTIONS(6953),
    [anon_sym_CONTROLADDIN] = ACTIONS(6953),
    [anon_sym_Controladdin] = ACTIONS(6953),
    [anon_sym_ControlAddIn] = ACTIONS(6953),
    [anon_sym_ControlAddin] = ACTIONS(6953),
    [anon_sym_controlAddIn] = ACTIONS(6953),
    [anon_sym_controlAddin] = ACTIONS(6953),
    [anon_sym_dotnet] = ACTIONS(6953),
    [anon_sym_DOTNET] = ACTIONS(6953),
    [anon_sym_Dotnet] = ACTIONS(6953),
    [anon_sym_DotNet] = ACTIONS(6953),
    [anon_sym_dotNet] = ACTIONS(6953),
    [sym_profile_keyword] = ACTIONS(6955),
    [anon_sym_profileextension] = ACTIONS(6953),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6953),
    [anon_sym_Profileextension] = ACTIONS(6953),
    [anon_sym_ProfileExtension] = ACTIONS(6953),
    [anon_sym_profileExtension] = ACTIONS(6953),
    [anon_sym_permissionset] = ACTIONS(6955),
    [anon_sym_PERMISSIONSET] = ACTIONS(6955),
    [anon_sym_Permissionset] = ACTIONS(6955),
    [anon_sym_PermissionSet] = ACTIONS(6955),
    [anon_sym_permissionSet] = ACTIONS(6955),
    [anon_sym_permissionsetextension] = ACTIONS(6953),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6953),
    [anon_sym_Permissionsetextension] = ACTIONS(6953),
    [anon_sym_PermissionSetExtension] = ACTIONS(6953),
    [anon_sym_permissionSetExtension] = ACTIONS(6953),
    [sym_entitlement_keyword] = ACTIONS(6953),
    [anon_sym_pagecustomization] = ACTIONS(6953),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6953),
    [anon_sym_Pagecustomization] = ACTIONS(6953),
    [anon_sym_PageCustomization] = ACTIONS(6953),
    [anon_sym_pageCustomization] = ACTIONS(6953),
    [sym_using_keyword] = ACTIONS(6953),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6953),
  },
  [STATE(3741)] = {
    [ts_builtin_sym_end] = ACTIONS(7003),
    [anon_sym_POUNDif] = ACTIONS(7003),
    [anon_sym_POUNDIF] = ACTIONS(7003),
    [anon_sym_POUNDIf] = ACTIONS(7003),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7005),
    [anon_sym_tableextension] = ACTIONS(7003),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7003),
    [anon_sym_Tableextension] = ACTIONS(7003),
    [anon_sym_TableExtension] = ACTIONS(7003),
    [anon_sym_tableExtension] = ACTIONS(7003),
    [sym_page_keyword] = ACTIONS(7005),
    [anon_sym_pageextension] = ACTIONS(7003),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7003),
    [anon_sym_Pageextension] = ACTIONS(7003),
    [anon_sym_PageExtension] = ACTIONS(7003),
    [anon_sym_pageExtension] = ACTIONS(7003),
    [anon_sym_codeunit] = ACTIONS(7003),
    [anon_sym_CODEUNIT] = ACTIONS(7003),
    [anon_sym_Codeunit] = ACTIONS(7003),
    [anon_sym_CodeUnit] = ACTIONS(7003),
    [anon_sym_COdeunit] = ACTIONS(7003),
    [anon_sym_codeUnit] = ACTIONS(7003),
    [sym_report_keyword] = ACTIONS(7005),
    [anon_sym_reportextension] = ACTIONS(7003),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7003),
    [anon_sym_Reportextension] = ACTIONS(7003),
    [anon_sym_ReportExtension] = ACTIONS(7003),
    [anon_sym_reportExtension] = ACTIONS(7003),
    [sym_query_keyword] = ACTIONS(7003),
    [anon_sym_xmlport] = ACTIONS(7003),
    [anon_sym_XMLPORT] = ACTIONS(7003),
    [anon_sym_Xmlport] = ACTIONS(7003),
    [anon_sym_XMLport] = ACTIONS(7003),
    [anon_sym_XMLPort] = ACTIONS(7003),
    [anon_sym_XmlPort] = ACTIONS(7003),
    [anon_sym_enum] = ACTIONS(7005),
    [anon_sym_ENUM] = ACTIONS(7005),
    [anon_sym_Enum] = ACTIONS(7005),
    [anon_sym_eNUM] = ACTIONS(7003),
    [anon_sym_eNum] = ACTIONS(7003),
    [anon_sym_ENum] = ACTIONS(7003),
    [anon_sym_enumextension] = ACTIONS(7003),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7003),
    [anon_sym_Enumextension] = ACTIONS(7003),
    [anon_sym_EnumExtension] = ACTIONS(7003),
    [anon_sym_enumExtension] = ACTIONS(7003),
    [sym_interface_keyword] = ACTIONS(7003),
    [anon_sym_controladdin] = ACTIONS(7003),
    [anon_sym_CONTROLADDIN] = ACTIONS(7003),
    [anon_sym_Controladdin] = ACTIONS(7003),
    [anon_sym_ControlAddIn] = ACTIONS(7003),
    [anon_sym_ControlAddin] = ACTIONS(7003),
    [anon_sym_controlAddIn] = ACTIONS(7003),
    [anon_sym_controlAddin] = ACTIONS(7003),
    [anon_sym_dotnet] = ACTIONS(7003),
    [anon_sym_DOTNET] = ACTIONS(7003),
    [anon_sym_Dotnet] = ACTIONS(7003),
    [anon_sym_DotNet] = ACTIONS(7003),
    [anon_sym_dotNet] = ACTIONS(7003),
    [sym_profile_keyword] = ACTIONS(7005),
    [anon_sym_profileextension] = ACTIONS(7003),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(7003),
    [anon_sym_Profileextension] = ACTIONS(7003),
    [anon_sym_ProfileExtension] = ACTIONS(7003),
    [anon_sym_profileExtension] = ACTIONS(7003),
    [anon_sym_permissionset] = ACTIONS(7005),
    [anon_sym_PERMISSIONSET] = ACTIONS(7005),
    [anon_sym_Permissionset] = ACTIONS(7005),
    [anon_sym_PermissionSet] = ACTIONS(7005),
    [anon_sym_permissionSet] = ACTIONS(7005),
    [anon_sym_permissionsetextension] = ACTIONS(7003),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7003),
    [anon_sym_Permissionsetextension] = ACTIONS(7003),
    [anon_sym_PermissionSetExtension] = ACTIONS(7003),
    [anon_sym_permissionSetExtension] = ACTIONS(7003),
    [sym_entitlement_keyword] = ACTIONS(7003),
    [anon_sym_pagecustomization] = ACTIONS(7003),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(7003),
    [anon_sym_Pagecustomization] = ACTIONS(7003),
    [anon_sym_PageCustomization] = ACTIONS(7003),
    [anon_sym_pageCustomization] = ACTIONS(7003),
    [sym_using_keyword] = ACTIONS(7003),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7003),
  },
  [STATE(3742)] = {
    [ts_builtin_sym_end] = ACTIONS(6957),
    [anon_sym_POUNDif] = ACTIONS(6957),
    [anon_sym_POUNDIF] = ACTIONS(6957),
    [anon_sym_POUNDIf] = ACTIONS(6957),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6959),
    [anon_sym_tableextension] = ACTIONS(6957),
    [anon_sym_TABLEEXTENSION] = ACTIONS(6957),
    [anon_sym_Tableextension] = ACTIONS(6957),
    [anon_sym_TableExtension] = ACTIONS(6957),
    [anon_sym_tableExtension] = ACTIONS(6957),
    [sym_page_keyword] = ACTIONS(6959),
    [anon_sym_pageextension] = ACTIONS(6957),
    [anon_sym_PAGEEXTENSION] = ACTIONS(6957),
    [anon_sym_Pageextension] = ACTIONS(6957),
    [anon_sym_PageExtension] = ACTIONS(6957),
    [anon_sym_pageExtension] = ACTIONS(6957),
    [anon_sym_codeunit] = ACTIONS(6957),
    [anon_sym_CODEUNIT] = ACTIONS(6957),
    [anon_sym_Codeunit] = ACTIONS(6957),
    [anon_sym_CodeUnit] = ACTIONS(6957),
    [anon_sym_COdeunit] = ACTIONS(6957),
    [anon_sym_codeUnit] = ACTIONS(6957),
    [sym_report_keyword] = ACTIONS(6959),
    [anon_sym_reportextension] = ACTIONS(6957),
    [anon_sym_REPORTEXTENSION] = ACTIONS(6957),
    [anon_sym_Reportextension] = ACTIONS(6957),
    [anon_sym_ReportExtension] = ACTIONS(6957),
    [anon_sym_reportExtension] = ACTIONS(6957),
    [sym_query_keyword] = ACTIONS(6957),
    [anon_sym_xmlport] = ACTIONS(6957),
    [anon_sym_XMLPORT] = ACTIONS(6957),
    [anon_sym_Xmlport] = ACTIONS(6957),
    [anon_sym_XMLport] = ACTIONS(6957),
    [anon_sym_XMLPort] = ACTIONS(6957),
    [anon_sym_XmlPort] = ACTIONS(6957),
    [anon_sym_enum] = ACTIONS(6959),
    [anon_sym_ENUM] = ACTIONS(6959),
    [anon_sym_Enum] = ACTIONS(6959),
    [anon_sym_eNUM] = ACTIONS(6957),
    [anon_sym_eNum] = ACTIONS(6957),
    [anon_sym_ENum] = ACTIONS(6957),
    [anon_sym_enumextension] = ACTIONS(6957),
    [anon_sym_ENUMEXTENSION] = ACTIONS(6957),
    [anon_sym_Enumextension] = ACTIONS(6957),
    [anon_sym_EnumExtension] = ACTIONS(6957),
    [anon_sym_enumExtension] = ACTIONS(6957),
    [sym_interface_keyword] = ACTIONS(6957),
    [anon_sym_controladdin] = ACTIONS(6957),
    [anon_sym_CONTROLADDIN] = ACTIONS(6957),
    [anon_sym_Controladdin] = ACTIONS(6957),
    [anon_sym_ControlAddIn] = ACTIONS(6957),
    [anon_sym_ControlAddin] = ACTIONS(6957),
    [anon_sym_controlAddIn] = ACTIONS(6957),
    [anon_sym_controlAddin] = ACTIONS(6957),
    [anon_sym_dotnet] = ACTIONS(6957),
    [anon_sym_DOTNET] = ACTIONS(6957),
    [anon_sym_Dotnet] = ACTIONS(6957),
    [anon_sym_DotNet] = ACTIONS(6957),
    [anon_sym_dotNet] = ACTIONS(6957),
    [sym_profile_keyword] = ACTIONS(6959),
    [anon_sym_profileextension] = ACTIONS(6957),
    [anon_sym_PROFILEEXTENSION] = ACTIONS(6957),
    [anon_sym_Profileextension] = ACTIONS(6957),
    [anon_sym_ProfileExtension] = ACTIONS(6957),
    [anon_sym_profileExtension] = ACTIONS(6957),
    [anon_sym_permissionset] = ACTIONS(6959),
    [anon_sym_PERMISSIONSET] = ACTIONS(6959),
    [anon_sym_Permissionset] = ACTIONS(6959),
    [anon_sym_PermissionSet] = ACTIONS(6959),
    [anon_sym_permissionSet] = ACTIONS(6959),
    [anon_sym_permissionsetextension] = ACTIONS(6957),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(6957),
    [anon_sym_Permissionsetextension] = ACTIONS(6957),
    [anon_sym_PermissionSetExtension] = ACTIONS(6957),
    [anon_sym_permissionSetExtension] = ACTIONS(6957),
    [sym_entitlement_keyword] = ACTIONS(6957),
    [anon_sym_pagecustomization] = ACTIONS(6957),
    [anon_sym_PAGECUSTOMIZATION] = ACTIONS(6957),
    [anon_sym_Pagecustomization] = ACTIONS(6957),
    [anon_sym_PageCustomization] = ACTIONS(6957),
    [anon_sym_pageCustomization] = ACTIONS(6957),
    [sym_using_keyword] = ACTIONS(6957),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(6957),
  },
  [STATE(3743)] = {
    [anon_sym_SEMI] = ACTIONS(7785),
    [aux_sym_where_condition_token1] = ACTIONS(7787),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7787),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7785),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7785),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_basic_type_token6] = ACTIONS(7787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_addafter_modification_token1] = ACTIONS(7785),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7785),
    [aux_sym_movelast_modification_token1] = ACTIONS(7785),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7785),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7785),
    [anon_sym_POUNDIF] = ACTIONS(7785),
    [anon_sym_POUNDIf] = ACTIONS(7785),
    [anon_sym_POUNDelif] = ACTIONS(7785),
    [anon_sym_POUNDELIF] = ACTIONS(7785),
    [anon_sym_POUNDElif] = ACTIONS(7785),
    [anon_sym_POUNDelse] = ACTIONS(7785),
    [anon_sym_POUNDELSE] = ACTIONS(7785),
    [anon_sym_POUNDElse] = ACTIONS(7785),
    [anon_sym_POUNDelse2] = ACTIONS(7785),
    [anon_sym_POUNDELSE2] = ACTIONS(7785),
    [anon_sym_POUNDElse2] = ACTIONS(7785),
    [anon_sym_POUNDendif] = ACTIONS(7785),
    [anon_sym_POUNDENDIF] = ACTIONS(7785),
    [anon_sym_POUNDEndif] = ACTIONS(7785),
    [anon_sym_POUNDendif2] = ACTIONS(7785),
    [anon_sym_POUNDENDIF2] = ACTIONS(7785),
    [anon_sym_POUNDEndif2] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7787),
    [sym_page_keyword] = ACTIONS(7785),
    [anon_sym_codeunit] = ACTIONS(7785),
    [anon_sym_CODEUNIT] = ACTIONS(7785),
    [anon_sym_Codeunit] = ACTIONS(7785),
    [anon_sym_CodeUnit] = ACTIONS(7785),
    [anon_sym_COdeunit] = ACTIONS(7785),
    [anon_sym_codeUnit] = ACTIONS(7785),
    [sym_report_keyword] = ACTIONS(7785),
    [sym_query_keyword] = ACTIONS(7785),
    [anon_sym_xmlport] = ACTIONS(7785),
    [anon_sym_XMLPORT] = ACTIONS(7785),
    [anon_sym_Xmlport] = ACTIONS(7785),
    [anon_sym_XMLport] = ACTIONS(7785),
    [anon_sym_XMLPort] = ACTIONS(7785),
    [anon_sym_XmlPort] = ACTIONS(7785),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_area_keyword] = ACTIONS(7785),
    [sym_group_keyword] = ACTIONS(7785),
    [sym_repeater_keyword] = ACTIONS(7785),
    [sym_cuegroup_keyword] = ACTIONS(7785),
    [sym_fixed_keyword] = ACTIONS(7785),
    [sym_grid_keyword] = ACTIONS(7785),
    [sym_part_keyword] = ACTIONS(7785),
    [sym_systempart_keyword] = ACTIONS(7785),
    [sym_usercontrol_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7785),
    [sym_preproc_close] = ACTIONS(7785),
  },
  [STATE(3744)] = {
    [sym_identifier] = ACTIONS(8198),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(8200),
    [aux_sym_boolean_token1] = ACTIONS(8198),
    [aux_sym_boolean_token2] = ACTIONS(8198),
    [sym_decimal] = ACTIONS(8198),
    [anon_sym_LPAREN] = ACTIONS(8203),
    [anon_sym_RPAREN] = ACTIONS(8203),
    [anon_sym_DOT_DOT] = ACTIONS(8205),
    [aux_sym_filter_value_token1] = ACTIONS(8198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8198),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(8205),
    [aux_sym_record_type_token1] = ACTIONS(8198),
    [aux_sym_basic_type_token21] = ACTIONS(8198),
    [aux_sym_basic_type_token22] = ACTIONS(8198),
    [aux_sym_basic_type_token48] = ACTIONS(8198),
    [anon_sym_not] = ACTIONS(8198),
    [anon_sym_NOT] = ACTIONS(8198),
    [anon_sym_Not] = ACTIONS(8198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8198),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8198),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3681),
    [anon_sym_DIV] = ACTIONS(3681),
    [anon_sym_Div] = ACTIONS(3681),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(8200),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3681),
    [anon_sym_AND] = ACTIONS(3681),
    [anon_sym_And] = ACTIONS(3681),
    [anon_sym_or] = ACTIONS(3681),
    [anon_sym_OR] = ACTIONS(3681),
    [anon_sym_Or] = ACTIONS(3681),
    [anon_sym_xor] = ACTIONS(3681),
    [anon_sym_XOR] = ACTIONS(3681),
    [anon_sym_Xor] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [sym_datetime_literal] = ACTIONS(8203),
    [sym_date_literal] = ACTIONS(8198),
    [sym_time_literal] = ACTIONS(8198),
    [sym_biginteger_literal] = ACTIONS(8203),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_page_keyword] = ACTIONS(8198),
    [anon_sym_codeunit] = ACTIONS(8198),
    [anon_sym_CODEUNIT] = ACTIONS(8198),
    [anon_sym_Codeunit] = ACTIONS(8198),
    [anon_sym_CodeUnit] = ACTIONS(8198),
    [anon_sym_COdeunit] = ACTIONS(8198),
    [anon_sym_codeUnit] = ACTIONS(8198),
    [sym_report_keyword] = ACTIONS(8198),
    [sym_query_keyword] = ACTIONS(8198),
    [anon_sym_xmlport] = ACTIONS(8198),
    [anon_sym_XMLPORT] = ACTIONS(8198),
    [anon_sym_Xmlport] = ACTIONS(8198),
    [anon_sym_XMLport] = ACTIONS(8198),
    [anon_sym_XMLPort] = ACTIONS(8198),
    [anon_sym_XmlPort] = ACTIONS(8198),
    [anon_sym_enum] = ACTIONS(8198),
    [anon_sym_ENUM] = ACTIONS(8198),
    [anon_sym_Enum] = ACTIONS(8198),
    [anon_sym_eNUM] = ACTIONS(8198),
    [anon_sym_eNum] = ACTIONS(8198),
    [anon_sym_ENum] = ACTIONS(8198),
    [sym_quoted_identifier] = ACTIONS(8203),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8203),
    [sym_verbatim_string] = ACTIONS(8203),
    [sym_integer] = ACTIONS(8198),
    [sym_continue_as_identifier] = ACTIONS(8203),
  },
  [STATE(3745)] = {
    [sym_boolean] = STATE(3525),
    [sym_code_block] = STATE(3091),
    [sym_assignment_expression] = STATE(3525),
    [sym__expression] = STATE(3525),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3525),
    [sym_multiplicative_expression] = STATE(3525),
    [sym_additive_expression] = STATE(3525),
    [sym_comparison_expression] = STATE(3525),
    [sym_logical_expression] = STATE(3525),
    [sym_ternary_expression] = STATE(3525),
    [sym_unary_expression] = STATE(3525),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3525),
    [sym_list_literal] = STATE(3525),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3525),
    [sym__literal_value] = STATE(3525),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(8412),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(441),
    [aux_sym_preproc_split_procedure_body_token2] = ACTIONS(4322),
    [anon_sym_POUNDif] = ACTIONS(4318),
    [anon_sym_POUNDIF] = ACTIONS(4318),
    [anon_sym_POUNDIf] = ACTIONS(4318),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(8414),
    [sym_date_literal] = ACTIONS(8412),
    [sym_time_literal] = ACTIONS(8412),
    [sym_biginteger_literal] = ACTIONS(8414),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_ELSE] = ACTIONS(4322),
    [anon_sym_Else] = ACTIONS(4322),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8414),
    [sym_verbatim_string] = ACTIONS(8414),
    [sym_integer] = ACTIONS(8412),
    [sym_continue_as_identifier] = ACTIONS(8414),
    [sym_preproc_open] = ACTIONS(4318),
    [sym_begin_keyword] = ACTIONS(467),
  },
  [STATE(3746)] = {
    [sym_identifier] = ACTIONS(3738),
    [anon_sym_DOT] = ACTIONS(3738),
    [anon_sym_EQ] = ACTIONS(3740),
    [anon_sym_DASH] = ACTIONS(3738),
    [aux_sym_boolean_token1] = ACTIONS(3738),
    [aux_sym_boolean_token2] = ACTIONS(3738),
    [sym_decimal] = ACTIONS(3738),
    [anon_sym_LPAREN] = ACTIONS(3740),
    [anon_sym_RPAREN] = ACTIONS(3740),
    [anon_sym_DOT_DOT] = ACTIONS(3740),
    [aux_sym_filter_value_token1] = ACTIONS(3738),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3738),
    [anon_sym_STAR] = ACTIONS(3738),
    [anon_sym_LBRACK] = ACTIONS(3740),
    [aux_sym_record_type_token1] = ACTIONS(3738),
    [aux_sym_basic_type_token21] = ACTIONS(3738),
    [aux_sym_basic_type_token22] = ACTIONS(3738),
    [aux_sym_basic_type_token48] = ACTIONS(3738),
    [anon_sym_not] = ACTIONS(3738),
    [anon_sym_NOT] = ACTIONS(3738),
    [anon_sym_Not] = ACTIONS(3738),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3740),
    [aux_sym__expression_token1] = ACTIONS(3740),
    [aux_sym__expression_token2] = ACTIONS(3740),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3738),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3738),
    [anon_sym_SLASH] = ACTIONS(3738),
    [anon_sym_div] = ACTIONS(3738),
    [anon_sym_DIV] = ACTIONS(3738),
    [anon_sym_Div] = ACTIONS(3738),
    [anon_sym_mod] = ACTIONS(3738),
    [anon_sym_MOD] = ACTIONS(3738),
    [anon_sym_Mod] = ACTIONS(3738),
    [anon_sym_PLUS] = ACTIONS(3738),
    [anon_sym_GT_EQ] = ACTIONS(3740),
    [anon_sym_LT_EQ] = ACTIONS(3740),
    [anon_sym_GT] = ACTIONS(3738),
    [anon_sym_LT] = ACTIONS(3738),
    [anon_sym_LT_GT] = ACTIONS(3740),
    [anon_sym_and] = ACTIONS(3738),
    [anon_sym_AND] = ACTIONS(3738),
    [anon_sym_And] = ACTIONS(3738),
    [anon_sym_or] = ACTIONS(3738),
    [anon_sym_OR] = ACTIONS(3738),
    [anon_sym_Or] = ACTIONS(3738),
    [anon_sym_xor] = ACTIONS(3738),
    [anon_sym_XOR] = ACTIONS(3738),
    [anon_sym_Xor] = ACTIONS(3738),
    [anon_sym_QMARK] = ACTIONS(3740),
    [sym_datetime_literal] = ACTIONS(3740),
    [sym_date_literal] = ACTIONS(3738),
    [sym_time_literal] = ACTIONS(3738),
    [sym_biginteger_literal] = ACTIONS(3740),
    [anon_sym_in] = ACTIONS(3738),
    [anon_sym_IN] = ACTIONS(3738),
    [anon_sym_In] = ACTIONS(3738),
    [sym_page_keyword] = ACTIONS(3738),
    [anon_sym_codeunit] = ACTIONS(3738),
    [anon_sym_CODEUNIT] = ACTIONS(3738),
    [anon_sym_Codeunit] = ACTIONS(3738),
    [anon_sym_CodeUnit] = ACTIONS(3738),
    [anon_sym_COdeunit] = ACTIONS(3738),
    [anon_sym_codeUnit] = ACTIONS(3738),
    [sym_report_keyword] = ACTIONS(3738),
    [sym_query_keyword] = ACTIONS(3738),
    [anon_sym_xmlport] = ACTIONS(3738),
    [anon_sym_XMLPORT] = ACTIONS(3738),
    [anon_sym_Xmlport] = ACTIONS(3738),
    [anon_sym_XMLport] = ACTIONS(3738),
    [anon_sym_XMLPort] = ACTIONS(3738),
    [anon_sym_XmlPort] = ACTIONS(3738),
    [anon_sym_enum] = ACTIONS(3738),
    [anon_sym_ENUM] = ACTIONS(3738),
    [anon_sym_Enum] = ACTIONS(3738),
    [anon_sym_eNUM] = ACTIONS(3738),
    [anon_sym_eNum] = ACTIONS(3738),
    [anon_sym_ENum] = ACTIONS(3738),
    [sym_quoted_identifier] = ACTIONS(3740),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3740),
    [sym_verbatim_string] = ACTIONS(3740),
    [sym_integer] = ACTIONS(3738),
    [sym_continue_as_identifier] = ACTIONS(3740),
  },
  [STATE(3747)] = {
    [sym_identifier] = ACTIONS(3885),
    [anon_sym_DOT] = ACTIONS(3885),
    [anon_sym_EQ] = ACTIONS(3887),
    [anon_sym_DASH] = ACTIONS(3885),
    [aux_sym_boolean_token1] = ACTIONS(3885),
    [aux_sym_boolean_token2] = ACTIONS(3885),
    [sym_decimal] = ACTIONS(3885),
    [anon_sym_LPAREN] = ACTIONS(3887),
    [anon_sym_RPAREN] = ACTIONS(3887),
    [anon_sym_DOT_DOT] = ACTIONS(3887),
    [aux_sym_filter_value_token1] = ACTIONS(3885),
    [aux_sym_tabledata_permission_token2] = ACTIONS(3885),
    [anon_sym_STAR] = ACTIONS(3885),
    [anon_sym_LBRACK] = ACTIONS(3887),
    [aux_sym_record_type_token1] = ACTIONS(3885),
    [aux_sym_basic_type_token21] = ACTIONS(3885),
    [aux_sym_basic_type_token22] = ACTIONS(3885),
    [aux_sym_basic_type_token48] = ACTIONS(3885),
    [anon_sym_not] = ACTIONS(3885),
    [anon_sym_NOT] = ACTIONS(3885),
    [anon_sym_Not] = ACTIONS(3885),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3887),
    [aux_sym__expression_token1] = ACTIONS(3887),
    [aux_sym__expression_token2] = ACTIONS(3887),
    [aux_sym_keyword_identifier_token1] = ACTIONS(3885),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3885),
    [anon_sym_SLASH] = ACTIONS(3885),
    [anon_sym_div] = ACTIONS(3885),
    [anon_sym_DIV] = ACTIONS(3885),
    [anon_sym_Div] = ACTIONS(3885),
    [anon_sym_mod] = ACTIONS(3885),
    [anon_sym_MOD] = ACTIONS(3885),
    [anon_sym_Mod] = ACTIONS(3885),
    [anon_sym_PLUS] = ACTIONS(3885),
    [anon_sym_GT_EQ] = ACTIONS(3887),
    [anon_sym_LT_EQ] = ACTIONS(3887),
    [anon_sym_GT] = ACTIONS(3885),
    [anon_sym_LT] = ACTIONS(3885),
    [anon_sym_LT_GT] = ACTIONS(3887),
    [anon_sym_and] = ACTIONS(3885),
    [anon_sym_AND] = ACTIONS(3885),
    [anon_sym_And] = ACTIONS(3885),
    [anon_sym_or] = ACTIONS(3885),
    [anon_sym_OR] = ACTIONS(3885),
    [anon_sym_Or] = ACTIONS(3885),
    [anon_sym_xor] = ACTIONS(3885),
    [anon_sym_XOR] = ACTIONS(3885),
    [anon_sym_Xor] = ACTIONS(3885),
    [anon_sym_QMARK] = ACTIONS(3887),
    [sym_datetime_literal] = ACTIONS(3887),
    [sym_date_literal] = ACTIONS(3885),
    [sym_time_literal] = ACTIONS(3885),
    [sym_biginteger_literal] = ACTIONS(3887),
    [anon_sym_in] = ACTIONS(3885),
    [anon_sym_IN] = ACTIONS(3885),
    [anon_sym_In] = ACTIONS(3885),
    [sym_page_keyword] = ACTIONS(3885),
    [anon_sym_codeunit] = ACTIONS(3885),
    [anon_sym_CODEUNIT] = ACTIONS(3885),
    [anon_sym_Codeunit] = ACTIONS(3885),
    [anon_sym_CodeUnit] = ACTIONS(3885),
    [anon_sym_COdeunit] = ACTIONS(3885),
    [anon_sym_codeUnit] = ACTIONS(3885),
    [sym_report_keyword] = ACTIONS(3885),
    [sym_query_keyword] = ACTIONS(3885),
    [anon_sym_xmlport] = ACTIONS(3885),
    [anon_sym_XMLPORT] = ACTIONS(3885),
    [anon_sym_Xmlport] = ACTIONS(3885),
    [anon_sym_XMLport] = ACTIONS(3885),
    [anon_sym_XMLPort] = ACTIONS(3885),
    [anon_sym_XmlPort] = ACTIONS(3885),
    [anon_sym_enum] = ACTIONS(3885),
    [anon_sym_ENUM] = ACTIONS(3885),
    [anon_sym_Enum] = ACTIONS(3885),
    [anon_sym_eNUM] = ACTIONS(3885),
    [anon_sym_eNum] = ACTIONS(3885),
    [anon_sym_ENum] = ACTIONS(3885),
    [sym_quoted_identifier] = ACTIONS(3887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(3887),
    [sym_verbatim_string] = ACTIONS(3887),
    [sym_integer] = ACTIONS(3885),
    [sym_continue_as_identifier] = ACTIONS(3887),
  },
  [STATE(3748)] = {
    [sym_identifier] = ACTIONS(8416),
    [anon_sym_DOT] = ACTIONS(6589),
    [anon_sym_EQ] = ACTIONS(6591),
    [anon_sym_DASH] = ACTIONS(8418),
    [aux_sym_boolean_token1] = ACTIONS(8416),
    [aux_sym_boolean_token2] = ACTIONS(8416),
    [sym_decimal] = ACTIONS(8416),
    [anon_sym_LPAREN] = ACTIONS(8421),
    [anon_sym_RPAREN] = ACTIONS(8421),
    [anon_sym_DOT_DOT] = ACTIONS(8423),
    [aux_sym_filter_value_token1] = ACTIONS(8416),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8416),
    [anon_sym_STAR] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(8423),
    [aux_sym_record_type_token1] = ACTIONS(8416),
    [aux_sym_basic_type_token21] = ACTIONS(8416),
    [aux_sym_basic_type_token22] = ACTIONS(8416),
    [aux_sym_basic_type_token48] = ACTIONS(8416),
    [anon_sym_not] = ACTIONS(8416),
    [anon_sym_NOT] = ACTIONS(8416),
    [anon_sym_Not] = ACTIONS(8416),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6591),
    [aux_sym__expression_token1] = ACTIONS(6591),
    [aux_sym__expression_token2] = ACTIONS(6591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8416),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8416),
    [anon_sym_SLASH] = ACTIONS(6589),
    [anon_sym_div] = ACTIONS(6589),
    [anon_sym_DIV] = ACTIONS(6589),
    [anon_sym_Div] = ACTIONS(6589),
    [anon_sym_mod] = ACTIONS(6589),
    [anon_sym_MOD] = ACTIONS(6589),
    [anon_sym_Mod] = ACTIONS(6589),
    [anon_sym_PLUS] = ACTIONS(8418),
    [anon_sym_GT_EQ] = ACTIONS(6591),
    [anon_sym_LT_EQ] = ACTIONS(6591),
    [anon_sym_GT] = ACTIONS(6589),
    [anon_sym_LT] = ACTIONS(6589),
    [anon_sym_LT_GT] = ACTIONS(6591),
    [anon_sym_and] = ACTIONS(6589),
    [anon_sym_AND] = ACTIONS(6589),
    [anon_sym_And] = ACTIONS(6589),
    [anon_sym_or] = ACTIONS(6589),
    [anon_sym_OR] = ACTIONS(6589),
    [anon_sym_Or] = ACTIONS(6589),
    [anon_sym_xor] = ACTIONS(6589),
    [anon_sym_XOR] = ACTIONS(6589),
    [anon_sym_Xor] = ACTIONS(6589),
    [anon_sym_QMARK] = ACTIONS(6591),
    [sym_datetime_literal] = ACTIONS(8421),
    [sym_date_literal] = ACTIONS(8416),
    [sym_time_literal] = ACTIONS(8416),
    [sym_biginteger_literal] = ACTIONS(8421),
    [anon_sym_in] = ACTIONS(6589),
    [anon_sym_IN] = ACTIONS(6589),
    [anon_sym_In] = ACTIONS(6589),
    [sym_page_keyword] = ACTIONS(8416),
    [anon_sym_codeunit] = ACTIONS(8416),
    [anon_sym_CODEUNIT] = ACTIONS(8416),
    [anon_sym_Codeunit] = ACTIONS(8416),
    [anon_sym_CodeUnit] = ACTIONS(8416),
    [anon_sym_COdeunit] = ACTIONS(8416),
    [anon_sym_codeUnit] = ACTIONS(8416),
    [sym_report_keyword] = ACTIONS(8416),
    [sym_query_keyword] = ACTIONS(8416),
    [anon_sym_xmlport] = ACTIONS(8416),
    [anon_sym_XMLPORT] = ACTIONS(8416),
    [anon_sym_Xmlport] = ACTIONS(8416),
    [anon_sym_XMLport] = ACTIONS(8416),
    [anon_sym_XMLPort] = ACTIONS(8416),
    [anon_sym_XmlPort] = ACTIONS(8416),
    [anon_sym_enum] = ACTIONS(8416),
    [anon_sym_ENUM] = ACTIONS(8416),
    [anon_sym_Enum] = ACTIONS(8416),
    [anon_sym_eNUM] = ACTIONS(8416),
    [anon_sym_eNum] = ACTIONS(8416),
    [anon_sym_ENum] = ACTIONS(8416),
    [sym_quoted_identifier] = ACTIONS(8421),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8421),
    [sym_verbatim_string] = ACTIONS(8421),
    [sym_integer] = ACTIONS(8416),
    [sym_continue_as_identifier] = ACTIONS(8421),
  },
  [STATE(3749)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5759),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7303),
    [anon_sym_POUNDENDIF] = ACTIONS(7303),
    [anon_sym_POUNDEndif] = ACTIONS(7303),
    [anon_sym_POUNDendif2] = ACTIONS(7303),
    [anon_sym_POUNDENDIF2] = ACTIONS(7303),
    [anon_sym_POUNDEndif2] = ACTIONS(7303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7303),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3750)] = {
    [sym__body_element] = STATE(3778),
    [sym_empty_statement] = STATE(3778),
    [sym_property] = STATE(3778),
    [sym_permissions_property] = STATE(3778),
    [sym_table_relation_property] = STATE(3778),
    [sym_fields_section] = STATE(3778),
    [sym_keys_section] = STATE(3778),
    [sym_fieldgroups_section] = STATE(3778),
    [sym_enum_value_declaration] = STATE(3778),
    [sym_labels_section] = STATE(3778),
    [sym_layout_section] = STATE(3778),
    [sym_modify_modification] = STATE(3778),
    [sym_actions_section] = STATE(3778),
    [sym_views_section] = STATE(3778),
    [sym_dataset_section] = STATE(3778),
    [sym_requestpage_section] = STATE(3778),
    [sym_rendering_section] = STATE(3778),
    [sym_elements_section] = STATE(3778),
    [sym_schema_section] = STATE(3778),
    [sym_assembly_declaration] = STATE(3778),
    [sym_event_declaration] = STATE(3778),
    [sym_procedure] = STATE(3778),
    [sym_preproc_split_procedure] = STATE(3778),
    [sym_preproc_split_procedure_preamble] = STATE(3778),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3778),
    [sym_var_section] = STATE(3778),
    [sym_var_attribute_item] = STATE(3778),
    [sym_variable_declaration] = STATE(3778),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3778),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5759),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3778),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7303),
    [anon_sym_POUNDENDIF] = ACTIONS(7303),
    [anon_sym_POUNDEndif] = ACTIONS(7303),
    [anon_sym_POUNDendif2] = ACTIONS(7303),
    [anon_sym_POUNDENDIF2] = ACTIONS(7303),
    [anon_sym_POUNDEndif2] = ACTIONS(7303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7303),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3751)] = {
    [anon_sym_SEMI] = ACTIONS(8426),
    [aux_sym_where_condition_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8426),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8426),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8426),
    [anon_sym_LBRACK] = ACTIONS(8426),
    [aux_sym_basic_type_token6] = ACTIONS(7770),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8426),
    [aux_sym_addafter_modification_token1] = ACTIONS(8426),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8426),
    [aux_sym_modify_modification_token1] = ACTIONS(8426),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8426),
    [aux_sym_movelast_modification_token1] = ACTIONS(8426),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8426),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8426),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8426),
    [anon_sym_POUNDif] = ACTIONS(8426),
    [anon_sym_POUNDIF] = ACTIONS(8426),
    [anon_sym_POUNDIf] = ACTIONS(8426),
    [anon_sym_POUNDelif] = ACTIONS(8426),
    [anon_sym_POUNDELIF] = ACTIONS(8426),
    [anon_sym_POUNDElif] = ACTIONS(8426),
    [anon_sym_POUNDelse] = ACTIONS(8426),
    [anon_sym_POUNDELSE] = ACTIONS(8426),
    [anon_sym_POUNDElse] = ACTIONS(8426),
    [anon_sym_POUNDelse2] = ACTIONS(8426),
    [anon_sym_POUNDELSE2] = ACTIONS(8426),
    [anon_sym_POUNDElse2] = ACTIONS(8426),
    [anon_sym_POUNDendif] = ACTIONS(8426),
    [anon_sym_POUNDENDIF] = ACTIONS(8426),
    [anon_sym_POUNDEndif] = ACTIONS(8426),
    [anon_sym_POUNDendif2] = ACTIONS(8426),
    [anon_sym_POUNDENDIF2] = ACTIONS(8426),
    [anon_sym_POUNDEndif2] = ACTIONS(8426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7770),
    [sym_page_keyword] = ACTIONS(8426),
    [anon_sym_codeunit] = ACTIONS(8426),
    [anon_sym_CODEUNIT] = ACTIONS(8426),
    [anon_sym_Codeunit] = ACTIONS(8426),
    [anon_sym_CodeUnit] = ACTIONS(8426),
    [anon_sym_COdeunit] = ACTIONS(8426),
    [anon_sym_codeUnit] = ACTIONS(8426),
    [sym_report_keyword] = ACTIONS(8426),
    [sym_query_keyword] = ACTIONS(8426),
    [anon_sym_xmlport] = ACTIONS(8426),
    [anon_sym_XMLPORT] = ACTIONS(8426),
    [anon_sym_Xmlport] = ACTIONS(8426),
    [anon_sym_XMLport] = ACTIONS(8426),
    [anon_sym_XMLPort] = ACTIONS(8426),
    [anon_sym_XmlPort] = ACTIONS(8426),
    [sym_procedure_keyword] = ACTIONS(8426),
    [sym_trigger_keyword] = ACTIONS(8426),
    [sym_var_keyword] = ACTIONS(8426),
    [sym_local_keyword] = ACTIONS(8426),
    [sym_internal_keyword] = ACTIONS(8426),
    [sym_protected_keyword] = ACTIONS(8426),
    [sym_event_keyword] = ACTIONS(8426),
    [sym_fields_keyword] = ACTIONS(8426),
    [sym_keys_keyword] = ACTIONS(8426),
    [sym_fieldgroups_keyword] = ACTIONS(8426),
    [sym_actions_keyword] = ACTIONS(8426),
    [sym_layout_keyword] = ACTIONS(8426),
    [sym_area_keyword] = ACTIONS(8426),
    [sym_group_keyword] = ACTIONS(8426),
    [sym_repeater_keyword] = ACTIONS(8426),
    [sym_cuegroup_keyword] = ACTIONS(8426),
    [sym_fixed_keyword] = ACTIONS(8426),
    [sym_grid_keyword] = ACTIONS(8426),
    [sym_part_keyword] = ACTIONS(8426),
    [sym_systempart_keyword] = ACTIONS(8426),
    [sym_usercontrol_keyword] = ACTIONS(8426),
    [sym_dataset_keyword] = ACTIONS(8426),
    [sym_elements_keyword] = ACTIONS(8426),
    [sym_labels_keyword] = ACTIONS(8426),
    [sym_rendering_keyword] = ACTIONS(8426),
    [sym_requestpage_keyword] = ACTIONS(8426),
    [sym_schema_keyword] = ACTIONS(8426),
    [sym_views_keyword] = ACTIONS(8426),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8426),
    [sym_preproc_open] = ACTIONS(8426),
    [sym_preproc_close] = ACTIONS(8426),
  },
  [STATE(3752)] = {
    [anon_sym_SEMI] = ACTIONS(8428),
    [aux_sym_where_condition_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8428),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8428),
    [anon_sym_LBRACK] = ACTIONS(8428),
    [aux_sym_basic_type_token6] = ACTIONS(7725),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8428),
    [aux_sym_addafter_modification_token1] = ACTIONS(8428),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8428),
    [aux_sym_modify_modification_token1] = ACTIONS(8428),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8428),
    [aux_sym_movelast_modification_token1] = ACTIONS(8428),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8428),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8428),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8428),
    [anon_sym_POUNDif] = ACTIONS(8428),
    [anon_sym_POUNDIF] = ACTIONS(8428),
    [anon_sym_POUNDIf] = ACTIONS(8428),
    [anon_sym_POUNDelif] = ACTIONS(8428),
    [anon_sym_POUNDELIF] = ACTIONS(8428),
    [anon_sym_POUNDElif] = ACTIONS(8428),
    [anon_sym_POUNDelse] = ACTIONS(8428),
    [anon_sym_POUNDELSE] = ACTIONS(8428),
    [anon_sym_POUNDElse] = ACTIONS(8428),
    [anon_sym_POUNDelse2] = ACTIONS(8428),
    [anon_sym_POUNDELSE2] = ACTIONS(8428),
    [anon_sym_POUNDElse2] = ACTIONS(8428),
    [anon_sym_POUNDendif] = ACTIONS(8428),
    [anon_sym_POUNDENDIF] = ACTIONS(8428),
    [anon_sym_POUNDEndif] = ACTIONS(8428),
    [anon_sym_POUNDendif2] = ACTIONS(8428),
    [anon_sym_POUNDENDIF2] = ACTIONS(8428),
    [anon_sym_POUNDEndif2] = ACTIONS(8428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7725),
    [sym_page_keyword] = ACTIONS(8428),
    [anon_sym_codeunit] = ACTIONS(8428),
    [anon_sym_CODEUNIT] = ACTIONS(8428),
    [anon_sym_Codeunit] = ACTIONS(8428),
    [anon_sym_CodeUnit] = ACTIONS(8428),
    [anon_sym_COdeunit] = ACTIONS(8428),
    [anon_sym_codeUnit] = ACTIONS(8428),
    [sym_report_keyword] = ACTIONS(8428),
    [sym_query_keyword] = ACTIONS(8428),
    [anon_sym_xmlport] = ACTIONS(8428),
    [anon_sym_XMLPORT] = ACTIONS(8428),
    [anon_sym_Xmlport] = ACTIONS(8428),
    [anon_sym_XMLport] = ACTIONS(8428),
    [anon_sym_XMLPort] = ACTIONS(8428),
    [anon_sym_XmlPort] = ACTIONS(8428),
    [sym_procedure_keyword] = ACTIONS(8428),
    [sym_trigger_keyword] = ACTIONS(8428),
    [sym_var_keyword] = ACTIONS(8428),
    [sym_local_keyword] = ACTIONS(8428),
    [sym_internal_keyword] = ACTIONS(8428),
    [sym_protected_keyword] = ACTIONS(8428),
    [sym_event_keyword] = ACTIONS(8428),
    [sym_fields_keyword] = ACTIONS(8428),
    [sym_keys_keyword] = ACTIONS(8428),
    [sym_fieldgroups_keyword] = ACTIONS(8428),
    [sym_actions_keyword] = ACTIONS(8428),
    [sym_layout_keyword] = ACTIONS(8428),
    [sym_area_keyword] = ACTIONS(8428),
    [sym_group_keyword] = ACTIONS(8428),
    [sym_repeater_keyword] = ACTIONS(8428),
    [sym_cuegroup_keyword] = ACTIONS(8428),
    [sym_fixed_keyword] = ACTIONS(8428),
    [sym_grid_keyword] = ACTIONS(8428),
    [sym_part_keyword] = ACTIONS(8428),
    [sym_systempart_keyword] = ACTIONS(8428),
    [sym_usercontrol_keyword] = ACTIONS(8428),
    [sym_dataset_keyword] = ACTIONS(8428),
    [sym_elements_keyword] = ACTIONS(8428),
    [sym_labels_keyword] = ACTIONS(8428),
    [sym_rendering_keyword] = ACTIONS(8428),
    [sym_requestpage_keyword] = ACTIONS(8428),
    [sym_schema_keyword] = ACTIONS(8428),
    [sym_views_keyword] = ACTIONS(8428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8428),
    [sym_preproc_open] = ACTIONS(8428),
    [sym_preproc_close] = ACTIONS(8428),
  },
  [STATE(3753)] = {
    [anon_sym_SEMI] = ACTIONS(8430),
    [aux_sym_where_condition_token1] = ACTIONS(8432),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8430),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8432),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8430),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8430),
    [anon_sym_LBRACK] = ACTIONS(8430),
    [aux_sym_basic_type_token6] = ACTIONS(8432),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8430),
    [aux_sym_addafter_modification_token1] = ACTIONS(8430),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8430),
    [aux_sym_modify_modification_token1] = ACTIONS(8430),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8430),
    [aux_sym_movelast_modification_token1] = ACTIONS(8430),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8430),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8430),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8430),
    [anon_sym_POUNDif] = ACTIONS(8430),
    [anon_sym_POUNDIF] = ACTIONS(8430),
    [anon_sym_POUNDIf] = ACTIONS(8430),
    [anon_sym_POUNDelif] = ACTIONS(8430),
    [anon_sym_POUNDELIF] = ACTIONS(8430),
    [anon_sym_POUNDElif] = ACTIONS(8430),
    [anon_sym_POUNDelse] = ACTIONS(8430),
    [anon_sym_POUNDELSE] = ACTIONS(8430),
    [anon_sym_POUNDElse] = ACTIONS(8430),
    [anon_sym_POUNDelse2] = ACTIONS(8430),
    [anon_sym_POUNDELSE2] = ACTIONS(8430),
    [anon_sym_POUNDElse2] = ACTIONS(8430),
    [anon_sym_POUNDendif] = ACTIONS(8430),
    [anon_sym_POUNDENDIF] = ACTIONS(8430),
    [anon_sym_POUNDEndif] = ACTIONS(8430),
    [anon_sym_POUNDendif2] = ACTIONS(8430),
    [anon_sym_POUNDENDIF2] = ACTIONS(8430),
    [anon_sym_POUNDEndif2] = ACTIONS(8430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8432),
    [sym_page_keyword] = ACTIONS(8430),
    [anon_sym_codeunit] = ACTIONS(8430),
    [anon_sym_CODEUNIT] = ACTIONS(8430),
    [anon_sym_Codeunit] = ACTIONS(8430),
    [anon_sym_CodeUnit] = ACTIONS(8430),
    [anon_sym_COdeunit] = ACTIONS(8430),
    [anon_sym_codeUnit] = ACTIONS(8430),
    [sym_report_keyword] = ACTIONS(8430),
    [sym_query_keyword] = ACTIONS(8430),
    [anon_sym_xmlport] = ACTIONS(8430),
    [anon_sym_XMLPORT] = ACTIONS(8430),
    [anon_sym_Xmlport] = ACTIONS(8430),
    [anon_sym_XMLport] = ACTIONS(8430),
    [anon_sym_XMLPort] = ACTIONS(8430),
    [anon_sym_XmlPort] = ACTIONS(8430),
    [sym_procedure_keyword] = ACTIONS(8430),
    [sym_trigger_keyword] = ACTIONS(8430),
    [sym_var_keyword] = ACTIONS(8430),
    [sym_local_keyword] = ACTIONS(8430),
    [sym_internal_keyword] = ACTIONS(8430),
    [sym_protected_keyword] = ACTIONS(8430),
    [sym_event_keyword] = ACTIONS(8430),
    [sym_fields_keyword] = ACTIONS(8430),
    [sym_keys_keyword] = ACTIONS(8430),
    [sym_fieldgroups_keyword] = ACTIONS(8430),
    [sym_actions_keyword] = ACTIONS(8430),
    [sym_layout_keyword] = ACTIONS(8430),
    [sym_area_keyword] = ACTIONS(8430),
    [sym_group_keyword] = ACTIONS(8430),
    [sym_repeater_keyword] = ACTIONS(8430),
    [sym_cuegroup_keyword] = ACTIONS(8430),
    [sym_fixed_keyword] = ACTIONS(8430),
    [sym_grid_keyword] = ACTIONS(8430),
    [sym_part_keyword] = ACTIONS(8430),
    [sym_systempart_keyword] = ACTIONS(8430),
    [sym_usercontrol_keyword] = ACTIONS(8430),
    [sym_dataset_keyword] = ACTIONS(8430),
    [sym_elements_keyword] = ACTIONS(8430),
    [sym_labels_keyword] = ACTIONS(8430),
    [sym_rendering_keyword] = ACTIONS(8430),
    [sym_requestpage_keyword] = ACTIONS(8430),
    [sym_schema_keyword] = ACTIONS(8430),
    [sym_views_keyword] = ACTIONS(8430),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8430),
    [sym_preproc_open] = ACTIONS(8430),
    [sym_preproc_close] = ACTIONS(8430),
  },
  [STATE(3754)] = {
    [anon_sym_SEMI] = ACTIONS(8434),
    [aux_sym_where_condition_token1] = ACTIONS(8436),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8434),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8436),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8434),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8434),
    [anon_sym_LBRACK] = ACTIONS(8434),
    [aux_sym_basic_type_token6] = ACTIONS(8436),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8434),
    [aux_sym_addafter_modification_token1] = ACTIONS(8434),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8434),
    [aux_sym_modify_modification_token1] = ACTIONS(8434),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8434),
    [aux_sym_movelast_modification_token1] = ACTIONS(8434),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8434),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8434),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8434),
    [anon_sym_POUNDif] = ACTIONS(8434),
    [anon_sym_POUNDIF] = ACTIONS(8434),
    [anon_sym_POUNDIf] = ACTIONS(8434),
    [anon_sym_POUNDelif] = ACTIONS(8434),
    [anon_sym_POUNDELIF] = ACTIONS(8434),
    [anon_sym_POUNDElif] = ACTIONS(8434),
    [anon_sym_POUNDelse] = ACTIONS(8434),
    [anon_sym_POUNDELSE] = ACTIONS(8434),
    [anon_sym_POUNDElse] = ACTIONS(8434),
    [anon_sym_POUNDelse2] = ACTIONS(8434),
    [anon_sym_POUNDELSE2] = ACTIONS(8434),
    [anon_sym_POUNDElse2] = ACTIONS(8434),
    [anon_sym_POUNDendif] = ACTIONS(8434),
    [anon_sym_POUNDENDIF] = ACTIONS(8434),
    [anon_sym_POUNDEndif] = ACTIONS(8434),
    [anon_sym_POUNDendif2] = ACTIONS(8434),
    [anon_sym_POUNDENDIF2] = ACTIONS(8434),
    [anon_sym_POUNDEndif2] = ACTIONS(8434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8436),
    [sym_page_keyword] = ACTIONS(8434),
    [anon_sym_codeunit] = ACTIONS(8434),
    [anon_sym_CODEUNIT] = ACTIONS(8434),
    [anon_sym_Codeunit] = ACTIONS(8434),
    [anon_sym_CodeUnit] = ACTIONS(8434),
    [anon_sym_COdeunit] = ACTIONS(8434),
    [anon_sym_codeUnit] = ACTIONS(8434),
    [sym_report_keyword] = ACTIONS(8434),
    [sym_query_keyword] = ACTIONS(8434),
    [anon_sym_xmlport] = ACTIONS(8434),
    [anon_sym_XMLPORT] = ACTIONS(8434),
    [anon_sym_Xmlport] = ACTIONS(8434),
    [anon_sym_XMLport] = ACTIONS(8434),
    [anon_sym_XMLPort] = ACTIONS(8434),
    [anon_sym_XmlPort] = ACTIONS(8434),
    [sym_procedure_keyword] = ACTIONS(8434),
    [sym_trigger_keyword] = ACTIONS(8434),
    [sym_var_keyword] = ACTIONS(8434),
    [sym_local_keyword] = ACTIONS(8434),
    [sym_internal_keyword] = ACTIONS(8434),
    [sym_protected_keyword] = ACTIONS(8434),
    [sym_event_keyword] = ACTIONS(8434),
    [sym_fields_keyword] = ACTIONS(8434),
    [sym_keys_keyword] = ACTIONS(8434),
    [sym_fieldgroups_keyword] = ACTIONS(8434),
    [sym_actions_keyword] = ACTIONS(8434),
    [sym_layout_keyword] = ACTIONS(8434),
    [sym_area_keyword] = ACTIONS(8434),
    [sym_group_keyword] = ACTIONS(8434),
    [sym_repeater_keyword] = ACTIONS(8434),
    [sym_cuegroup_keyword] = ACTIONS(8434),
    [sym_fixed_keyword] = ACTIONS(8434),
    [sym_grid_keyword] = ACTIONS(8434),
    [sym_part_keyword] = ACTIONS(8434),
    [sym_systempart_keyword] = ACTIONS(8434),
    [sym_usercontrol_keyword] = ACTIONS(8434),
    [sym_dataset_keyword] = ACTIONS(8434),
    [sym_elements_keyword] = ACTIONS(8434),
    [sym_labels_keyword] = ACTIONS(8434),
    [sym_rendering_keyword] = ACTIONS(8434),
    [sym_requestpage_keyword] = ACTIONS(8434),
    [sym_schema_keyword] = ACTIONS(8434),
    [sym_views_keyword] = ACTIONS(8434),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8434),
    [sym_preproc_open] = ACTIONS(8434),
    [sym_preproc_close] = ACTIONS(8434),
  },
  [STATE(3755)] = {
    [anon_sym_SEMI] = ACTIONS(8438),
    [aux_sym_where_condition_token1] = ACTIONS(8440),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8438),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8440),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8438),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8438),
    [anon_sym_LBRACK] = ACTIONS(8438),
    [aux_sym_basic_type_token6] = ACTIONS(8440),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8438),
    [aux_sym_addafter_modification_token1] = ACTIONS(8438),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8438),
    [aux_sym_modify_modification_token1] = ACTIONS(8438),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8438),
    [aux_sym_movelast_modification_token1] = ACTIONS(8438),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8438),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8438),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8438),
    [anon_sym_POUNDif] = ACTIONS(8438),
    [anon_sym_POUNDIF] = ACTIONS(8438),
    [anon_sym_POUNDIf] = ACTIONS(8438),
    [anon_sym_POUNDelif] = ACTIONS(8438),
    [anon_sym_POUNDELIF] = ACTIONS(8438),
    [anon_sym_POUNDElif] = ACTIONS(8438),
    [anon_sym_POUNDelse] = ACTIONS(8438),
    [anon_sym_POUNDELSE] = ACTIONS(8438),
    [anon_sym_POUNDElse] = ACTIONS(8438),
    [anon_sym_POUNDelse2] = ACTIONS(8438),
    [anon_sym_POUNDELSE2] = ACTIONS(8438),
    [anon_sym_POUNDElse2] = ACTIONS(8438),
    [anon_sym_POUNDendif] = ACTIONS(8438),
    [anon_sym_POUNDENDIF] = ACTIONS(8438),
    [anon_sym_POUNDEndif] = ACTIONS(8438),
    [anon_sym_POUNDendif2] = ACTIONS(8438),
    [anon_sym_POUNDENDIF2] = ACTIONS(8438),
    [anon_sym_POUNDEndif2] = ACTIONS(8438),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8440),
    [sym_page_keyword] = ACTIONS(8438),
    [anon_sym_codeunit] = ACTIONS(8438),
    [anon_sym_CODEUNIT] = ACTIONS(8438),
    [anon_sym_Codeunit] = ACTIONS(8438),
    [anon_sym_CodeUnit] = ACTIONS(8438),
    [anon_sym_COdeunit] = ACTIONS(8438),
    [anon_sym_codeUnit] = ACTIONS(8438),
    [sym_report_keyword] = ACTIONS(8438),
    [sym_query_keyword] = ACTIONS(8438),
    [anon_sym_xmlport] = ACTIONS(8438),
    [anon_sym_XMLPORT] = ACTIONS(8438),
    [anon_sym_Xmlport] = ACTIONS(8438),
    [anon_sym_XMLport] = ACTIONS(8438),
    [anon_sym_XMLPort] = ACTIONS(8438),
    [anon_sym_XmlPort] = ACTIONS(8438),
    [sym_procedure_keyword] = ACTIONS(8438),
    [sym_trigger_keyword] = ACTIONS(8438),
    [sym_var_keyword] = ACTIONS(8438),
    [sym_local_keyword] = ACTIONS(8438),
    [sym_internal_keyword] = ACTIONS(8438),
    [sym_protected_keyword] = ACTIONS(8438),
    [sym_event_keyword] = ACTIONS(8438),
    [sym_fields_keyword] = ACTIONS(8438),
    [sym_keys_keyword] = ACTIONS(8438),
    [sym_fieldgroups_keyword] = ACTIONS(8438),
    [sym_actions_keyword] = ACTIONS(8438),
    [sym_layout_keyword] = ACTIONS(8438),
    [sym_area_keyword] = ACTIONS(8438),
    [sym_group_keyword] = ACTIONS(8438),
    [sym_repeater_keyword] = ACTIONS(8438),
    [sym_cuegroup_keyword] = ACTIONS(8438),
    [sym_fixed_keyword] = ACTIONS(8438),
    [sym_grid_keyword] = ACTIONS(8438),
    [sym_part_keyword] = ACTIONS(8438),
    [sym_systempart_keyword] = ACTIONS(8438),
    [sym_usercontrol_keyword] = ACTIONS(8438),
    [sym_dataset_keyword] = ACTIONS(8438),
    [sym_elements_keyword] = ACTIONS(8438),
    [sym_labels_keyword] = ACTIONS(8438),
    [sym_rendering_keyword] = ACTIONS(8438),
    [sym_requestpage_keyword] = ACTIONS(8438),
    [sym_schema_keyword] = ACTIONS(8438),
    [sym_views_keyword] = ACTIONS(8438),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8438),
    [sym_preproc_open] = ACTIONS(8438),
    [sym_preproc_close] = ACTIONS(8438),
  },
  [STATE(3756)] = {
    [anon_sym_SEMI] = ACTIONS(8442),
    [aux_sym_where_condition_token1] = ACTIONS(8444),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8442),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8444),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8442),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8442),
    [anon_sym_LBRACK] = ACTIONS(8442),
    [aux_sym_basic_type_token6] = ACTIONS(8444),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8442),
    [aux_sym_addafter_modification_token1] = ACTIONS(8442),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8442),
    [aux_sym_modify_modification_token1] = ACTIONS(8442),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8442),
    [aux_sym_movelast_modification_token1] = ACTIONS(8442),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8442),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8442),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8442),
    [anon_sym_POUNDif] = ACTIONS(8442),
    [anon_sym_POUNDIF] = ACTIONS(8442),
    [anon_sym_POUNDIf] = ACTIONS(8442),
    [anon_sym_POUNDelif] = ACTIONS(8442),
    [anon_sym_POUNDELIF] = ACTIONS(8442),
    [anon_sym_POUNDElif] = ACTIONS(8442),
    [anon_sym_POUNDelse] = ACTIONS(8442),
    [anon_sym_POUNDELSE] = ACTIONS(8442),
    [anon_sym_POUNDElse] = ACTIONS(8442),
    [anon_sym_POUNDelse2] = ACTIONS(8442),
    [anon_sym_POUNDELSE2] = ACTIONS(8442),
    [anon_sym_POUNDElse2] = ACTIONS(8442),
    [anon_sym_POUNDendif] = ACTIONS(8442),
    [anon_sym_POUNDENDIF] = ACTIONS(8442),
    [anon_sym_POUNDEndif] = ACTIONS(8442),
    [anon_sym_POUNDendif2] = ACTIONS(8442),
    [anon_sym_POUNDENDIF2] = ACTIONS(8442),
    [anon_sym_POUNDEndif2] = ACTIONS(8442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8444),
    [sym_page_keyword] = ACTIONS(8442),
    [anon_sym_codeunit] = ACTIONS(8442),
    [anon_sym_CODEUNIT] = ACTIONS(8442),
    [anon_sym_Codeunit] = ACTIONS(8442),
    [anon_sym_CodeUnit] = ACTIONS(8442),
    [anon_sym_COdeunit] = ACTIONS(8442),
    [anon_sym_codeUnit] = ACTIONS(8442),
    [sym_report_keyword] = ACTIONS(8442),
    [sym_query_keyword] = ACTIONS(8442),
    [anon_sym_xmlport] = ACTIONS(8442),
    [anon_sym_XMLPORT] = ACTIONS(8442),
    [anon_sym_Xmlport] = ACTIONS(8442),
    [anon_sym_XMLport] = ACTIONS(8442),
    [anon_sym_XMLPort] = ACTIONS(8442),
    [anon_sym_XmlPort] = ACTIONS(8442),
    [sym_procedure_keyword] = ACTIONS(8442),
    [sym_trigger_keyword] = ACTIONS(8442),
    [sym_var_keyword] = ACTIONS(8442),
    [sym_local_keyword] = ACTIONS(8442),
    [sym_internal_keyword] = ACTIONS(8442),
    [sym_protected_keyword] = ACTIONS(8442),
    [sym_event_keyword] = ACTIONS(8442),
    [sym_fields_keyword] = ACTIONS(8442),
    [sym_keys_keyword] = ACTIONS(8442),
    [sym_fieldgroups_keyword] = ACTIONS(8442),
    [sym_actions_keyword] = ACTIONS(8442),
    [sym_layout_keyword] = ACTIONS(8442),
    [sym_area_keyword] = ACTIONS(8442),
    [sym_group_keyword] = ACTIONS(8442),
    [sym_repeater_keyword] = ACTIONS(8442),
    [sym_cuegroup_keyword] = ACTIONS(8442),
    [sym_fixed_keyword] = ACTIONS(8442),
    [sym_grid_keyword] = ACTIONS(8442),
    [sym_part_keyword] = ACTIONS(8442),
    [sym_systempart_keyword] = ACTIONS(8442),
    [sym_usercontrol_keyword] = ACTIONS(8442),
    [sym_dataset_keyword] = ACTIONS(8442),
    [sym_elements_keyword] = ACTIONS(8442),
    [sym_labels_keyword] = ACTIONS(8442),
    [sym_rendering_keyword] = ACTIONS(8442),
    [sym_requestpage_keyword] = ACTIONS(8442),
    [sym_schema_keyword] = ACTIONS(8442),
    [sym_views_keyword] = ACTIONS(8442),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8442),
    [sym_preproc_open] = ACTIONS(8442),
    [sym_preproc_close] = ACTIONS(8442),
  },
  [STATE(3757)] = {
    [anon_sym_SEMI] = ACTIONS(8446),
    [aux_sym_where_condition_token1] = ACTIONS(8448),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8446),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8448),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8446),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8446),
    [anon_sym_LBRACK] = ACTIONS(8446),
    [aux_sym_basic_type_token6] = ACTIONS(8448),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8446),
    [aux_sym_addafter_modification_token1] = ACTIONS(8446),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8446),
    [aux_sym_modify_modification_token1] = ACTIONS(8446),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8446),
    [aux_sym_movelast_modification_token1] = ACTIONS(8446),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8446),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8446),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8446),
    [anon_sym_POUNDif] = ACTIONS(8446),
    [anon_sym_POUNDIF] = ACTIONS(8446),
    [anon_sym_POUNDIf] = ACTIONS(8446),
    [anon_sym_POUNDelif] = ACTIONS(8446),
    [anon_sym_POUNDELIF] = ACTIONS(8446),
    [anon_sym_POUNDElif] = ACTIONS(8446),
    [anon_sym_POUNDelse] = ACTIONS(8446),
    [anon_sym_POUNDELSE] = ACTIONS(8446),
    [anon_sym_POUNDElse] = ACTIONS(8446),
    [anon_sym_POUNDelse2] = ACTIONS(8446),
    [anon_sym_POUNDELSE2] = ACTIONS(8446),
    [anon_sym_POUNDElse2] = ACTIONS(8446),
    [anon_sym_POUNDendif] = ACTIONS(8446),
    [anon_sym_POUNDENDIF] = ACTIONS(8446),
    [anon_sym_POUNDEndif] = ACTIONS(8446),
    [anon_sym_POUNDendif2] = ACTIONS(8446),
    [anon_sym_POUNDENDIF2] = ACTIONS(8446),
    [anon_sym_POUNDEndif2] = ACTIONS(8446),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8448),
    [sym_page_keyword] = ACTIONS(8446),
    [anon_sym_codeunit] = ACTIONS(8446),
    [anon_sym_CODEUNIT] = ACTIONS(8446),
    [anon_sym_Codeunit] = ACTIONS(8446),
    [anon_sym_CodeUnit] = ACTIONS(8446),
    [anon_sym_COdeunit] = ACTIONS(8446),
    [anon_sym_codeUnit] = ACTIONS(8446),
    [sym_report_keyword] = ACTIONS(8446),
    [sym_query_keyword] = ACTIONS(8446),
    [anon_sym_xmlport] = ACTIONS(8446),
    [anon_sym_XMLPORT] = ACTIONS(8446),
    [anon_sym_Xmlport] = ACTIONS(8446),
    [anon_sym_XMLport] = ACTIONS(8446),
    [anon_sym_XMLPort] = ACTIONS(8446),
    [anon_sym_XmlPort] = ACTIONS(8446),
    [sym_procedure_keyword] = ACTIONS(8446),
    [sym_trigger_keyword] = ACTIONS(8446),
    [sym_var_keyword] = ACTIONS(8446),
    [sym_local_keyword] = ACTIONS(8446),
    [sym_internal_keyword] = ACTIONS(8446),
    [sym_protected_keyword] = ACTIONS(8446),
    [sym_event_keyword] = ACTIONS(8446),
    [sym_fields_keyword] = ACTIONS(8446),
    [sym_keys_keyword] = ACTIONS(8446),
    [sym_fieldgroups_keyword] = ACTIONS(8446),
    [sym_actions_keyword] = ACTIONS(8446),
    [sym_layout_keyword] = ACTIONS(8446),
    [sym_area_keyword] = ACTIONS(8446),
    [sym_group_keyword] = ACTIONS(8446),
    [sym_repeater_keyword] = ACTIONS(8446),
    [sym_cuegroup_keyword] = ACTIONS(8446),
    [sym_fixed_keyword] = ACTIONS(8446),
    [sym_grid_keyword] = ACTIONS(8446),
    [sym_part_keyword] = ACTIONS(8446),
    [sym_systempart_keyword] = ACTIONS(8446),
    [sym_usercontrol_keyword] = ACTIONS(8446),
    [sym_dataset_keyword] = ACTIONS(8446),
    [sym_elements_keyword] = ACTIONS(8446),
    [sym_labels_keyword] = ACTIONS(8446),
    [sym_rendering_keyword] = ACTIONS(8446),
    [sym_requestpage_keyword] = ACTIONS(8446),
    [sym_schema_keyword] = ACTIONS(8446),
    [sym_views_keyword] = ACTIONS(8446),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8446),
    [sym_preproc_open] = ACTIONS(8446),
    [sym_preproc_close] = ACTIONS(8446),
  },
  [STATE(3758)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_elif] = STATE(3957),
    [sym_preproc_else] = STATE(4443),
    [sym_preproc_endif] = STATE(8155),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [aux_sym_preproc_conditional_controladdin_repeat1] = STATE(10677),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3759)] = {
    [sym__body_element] = STATE(3760),
    [sym_empty_statement] = STATE(3760),
    [sym_property] = STATE(3760),
    [sym_permissions_property] = STATE(3760),
    [sym_table_relation_property] = STATE(3760),
    [sym_fields_section] = STATE(3760),
    [sym_keys_section] = STATE(3760),
    [sym_fieldgroups_section] = STATE(3760),
    [sym_enum_value_declaration] = STATE(3760),
    [sym_labels_section] = STATE(3760),
    [sym_layout_section] = STATE(3760),
    [sym_modify_modification] = STATE(3760),
    [sym_actions_section] = STATE(3760),
    [sym_views_section] = STATE(3760),
    [sym_dataset_section] = STATE(3760),
    [sym_requestpage_section] = STATE(3760),
    [sym_rendering_section] = STATE(3760),
    [sym_elements_section] = STATE(3760),
    [sym_schema_section] = STATE(3760),
    [sym_assembly_declaration] = STATE(3760),
    [sym_event_declaration] = STATE(3760),
    [sym_procedure] = STATE(3760),
    [sym_preproc_split_procedure] = STATE(3760),
    [sym_preproc_split_procedure_preamble] = STATE(3760),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3760),
    [sym_var_section] = STATE(3760),
    [sym_var_attribute_item] = STATE(3760),
    [sym_variable_declaration] = STATE(3760),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3760),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(4025),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3760),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3760)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(4026),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3761)] = {
    [sym__body_element] = STATE(3762),
    [sym_empty_statement] = STATE(3762),
    [sym_property] = STATE(3762),
    [sym_permissions_property] = STATE(3762),
    [sym_table_relation_property] = STATE(3762),
    [sym_fields_section] = STATE(3762),
    [sym_keys_section] = STATE(3762),
    [sym_fieldgroups_section] = STATE(3762),
    [sym_enum_value_declaration] = STATE(3762),
    [sym_labels_section] = STATE(3762),
    [sym_layout_section] = STATE(3762),
    [sym_modify_modification] = STATE(3762),
    [sym_actions_section] = STATE(3762),
    [sym_views_section] = STATE(3762),
    [sym_dataset_section] = STATE(3762),
    [sym_requestpage_section] = STATE(3762),
    [sym_rendering_section] = STATE(3762),
    [sym_elements_section] = STATE(3762),
    [sym_schema_section] = STATE(3762),
    [sym_assembly_declaration] = STATE(3762),
    [sym_event_declaration] = STATE(3762),
    [sym_procedure] = STATE(3762),
    [sym_preproc_split_procedure] = STATE(3762),
    [sym_preproc_split_procedure_preamble] = STATE(3762),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3762),
    [sym_var_section] = STATE(3762),
    [sym_var_attribute_item] = STATE(3762),
    [sym_variable_declaration] = STATE(3762),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3762),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(4026),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3762),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3762)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(4028),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3763)] = {
    [sym__body_element] = STATE(3764),
    [sym_empty_statement] = STATE(3764),
    [sym_property] = STATE(3764),
    [sym_permissions_property] = STATE(3764),
    [sym_table_relation_property] = STATE(3764),
    [sym_fields_section] = STATE(3764),
    [sym_keys_section] = STATE(3764),
    [sym_fieldgroups_section] = STATE(3764),
    [sym_enum_value_declaration] = STATE(3764),
    [sym_labels_section] = STATE(3764),
    [sym_layout_section] = STATE(3764),
    [sym_modify_modification] = STATE(3764),
    [sym_actions_section] = STATE(3764),
    [sym_views_section] = STATE(3764),
    [sym_dataset_section] = STATE(3764),
    [sym_requestpage_section] = STATE(3764),
    [sym_rendering_section] = STATE(3764),
    [sym_elements_section] = STATE(3764),
    [sym_schema_section] = STATE(3764),
    [sym_assembly_declaration] = STATE(3764),
    [sym_event_declaration] = STATE(3764),
    [sym_procedure] = STATE(3764),
    [sym_preproc_split_procedure] = STATE(3764),
    [sym_preproc_split_procedure_preamble] = STATE(3764),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3764),
    [sym_var_section] = STATE(3764),
    [sym_var_attribute_item] = STATE(3764),
    [sym_variable_declaration] = STATE(3764),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3764),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(4028),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3764),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3764)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(4046),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3765)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_elif] = STATE(3957),
    [sym_preproc_else] = STATE(4507),
    [sym_preproc_endif] = STATE(9984),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [aux_sym_preproc_conditional_controladdin_repeat1] = STATE(10809),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3766)] = {
    [sym__body_element] = STATE(3767),
    [sym_empty_statement] = STATE(3767),
    [sym_property] = STATE(3767),
    [sym_permissions_property] = STATE(3767),
    [sym_table_relation_property] = STATE(3767),
    [sym_fields_section] = STATE(3767),
    [sym_keys_section] = STATE(3767),
    [sym_fieldgroups_section] = STATE(3767),
    [sym_enum_value_declaration] = STATE(3767),
    [sym_labels_section] = STATE(3767),
    [sym_layout_section] = STATE(3767),
    [sym_modify_modification] = STATE(3767),
    [sym_actions_section] = STATE(3767),
    [sym_views_section] = STATE(3767),
    [sym_dataset_section] = STATE(3767),
    [sym_requestpage_section] = STATE(3767),
    [sym_rendering_section] = STATE(3767),
    [sym_elements_section] = STATE(3767),
    [sym_schema_section] = STATE(3767),
    [sym_assembly_declaration] = STATE(3767),
    [sym_event_declaration] = STATE(3767),
    [sym_procedure] = STATE(3767),
    [sym_preproc_split_procedure] = STATE(3767),
    [sym_preproc_split_procedure_preamble] = STATE(3767),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3767),
    [sym_var_section] = STATE(3767),
    [sym_var_attribute_item] = STATE(3767),
    [sym_variable_declaration] = STATE(3767),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3767),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(9764),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3767),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7309),
    [anon_sym_POUNDENDIF] = ACTIONS(7309),
    [anon_sym_POUNDEndif] = ACTIONS(7309),
    [anon_sym_POUNDendif2] = ACTIONS(7309),
    [anon_sym_POUNDENDIF2] = ACTIONS(7309),
    [anon_sym_POUNDEndif2] = ACTIONS(7309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7309),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3767)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(9747),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7309),
    [anon_sym_POUNDENDIF] = ACTIONS(7309),
    [anon_sym_POUNDEndif] = ACTIONS(7309),
    [anon_sym_POUNDendif2] = ACTIONS(7309),
    [anon_sym_POUNDENDIF2] = ACTIONS(7309),
    [anon_sym_POUNDEndif2] = ACTIONS(7309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7309),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3768)] = {
    [sym__body_element] = STATE(3769),
    [sym_empty_statement] = STATE(3769),
    [sym_property] = STATE(3769),
    [sym_permissions_property] = STATE(3769),
    [sym_table_relation_property] = STATE(3769),
    [sym_fields_section] = STATE(3769),
    [sym_keys_section] = STATE(3769),
    [sym_fieldgroups_section] = STATE(3769),
    [sym_enum_value_declaration] = STATE(3769),
    [sym_labels_section] = STATE(3769),
    [sym_layout_section] = STATE(3769),
    [sym_modify_modification] = STATE(3769),
    [sym_actions_section] = STATE(3769),
    [sym_views_section] = STATE(3769),
    [sym_dataset_section] = STATE(3769),
    [sym_requestpage_section] = STATE(3769),
    [sym_rendering_section] = STATE(3769),
    [sym_elements_section] = STATE(3769),
    [sym_schema_section] = STATE(3769),
    [sym_assembly_declaration] = STATE(3769),
    [sym_event_declaration] = STATE(3769),
    [sym_procedure] = STATE(3769),
    [sym_preproc_split_procedure] = STATE(3769),
    [sym_preproc_split_procedure_preamble] = STATE(3769),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3769),
    [sym_var_section] = STATE(3769),
    [sym_var_attribute_item] = STATE(3769),
    [sym_variable_declaration] = STATE(3769),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3769),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(9747),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3769),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7309),
    [anon_sym_POUNDENDIF] = ACTIONS(7309),
    [anon_sym_POUNDEndif] = ACTIONS(7309),
    [anon_sym_POUNDendif2] = ACTIONS(7309),
    [anon_sym_POUNDENDIF2] = ACTIONS(7309),
    [anon_sym_POUNDEndif2] = ACTIONS(7309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7309),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3769)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(9765),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7309),
    [anon_sym_POUNDENDIF] = ACTIONS(7309),
    [anon_sym_POUNDEndif] = ACTIONS(7309),
    [anon_sym_POUNDendif2] = ACTIONS(7309),
    [anon_sym_POUNDENDIF2] = ACTIONS(7309),
    [anon_sym_POUNDEndif2] = ACTIONS(7309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7309),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3770)] = {
    [sym__body_element] = STATE(3771),
    [sym_empty_statement] = STATE(3771),
    [sym_property] = STATE(3771),
    [sym_permissions_property] = STATE(3771),
    [sym_table_relation_property] = STATE(3771),
    [sym_fields_section] = STATE(3771),
    [sym_keys_section] = STATE(3771),
    [sym_fieldgroups_section] = STATE(3771),
    [sym_enum_value_declaration] = STATE(3771),
    [sym_labels_section] = STATE(3771),
    [sym_layout_section] = STATE(3771),
    [sym_modify_modification] = STATE(3771),
    [sym_actions_section] = STATE(3771),
    [sym_views_section] = STATE(3771),
    [sym_dataset_section] = STATE(3771),
    [sym_requestpage_section] = STATE(3771),
    [sym_rendering_section] = STATE(3771),
    [sym_elements_section] = STATE(3771),
    [sym_schema_section] = STATE(3771),
    [sym_assembly_declaration] = STATE(3771),
    [sym_event_declaration] = STATE(3771),
    [sym_procedure] = STATE(3771),
    [sym_preproc_split_procedure] = STATE(3771),
    [sym_preproc_split_procedure_preamble] = STATE(3771),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3771),
    [sym_var_section] = STATE(3771),
    [sym_var_attribute_item] = STATE(3771),
    [sym_variable_declaration] = STATE(3771),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3771),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(9765),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3771),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7309),
    [anon_sym_POUNDENDIF] = ACTIONS(7309),
    [anon_sym_POUNDEndif] = ACTIONS(7309),
    [anon_sym_POUNDendif2] = ACTIONS(7309),
    [anon_sym_POUNDENDIF2] = ACTIONS(7309),
    [anon_sym_POUNDEndif2] = ACTIONS(7309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7309),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3771)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(9769),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7309),
    [anon_sym_POUNDENDIF] = ACTIONS(7309),
    [anon_sym_POUNDEndif] = ACTIONS(7309),
    [anon_sym_POUNDendif2] = ACTIONS(7309),
    [anon_sym_POUNDENDIF2] = ACTIONS(7309),
    [anon_sym_POUNDEndif2] = ACTIONS(7309),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7309),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3772)] = {
    [sym__body_element] = STATE(3773),
    [sym_empty_statement] = STATE(3773),
    [sym_property] = STATE(3773),
    [sym_permissions_property] = STATE(3773),
    [sym_table_relation_property] = STATE(3773),
    [sym_fields_section] = STATE(3773),
    [sym_keys_section] = STATE(3773),
    [sym_fieldgroups_section] = STATE(3773),
    [sym_enum_value_declaration] = STATE(3773),
    [sym_labels_section] = STATE(3773),
    [sym_layout_section] = STATE(3773),
    [sym_modify_modification] = STATE(3773),
    [sym_actions_section] = STATE(3773),
    [sym_views_section] = STATE(3773),
    [sym_dataset_section] = STATE(3773),
    [sym_requestpage_section] = STATE(3773),
    [sym_rendering_section] = STATE(3773),
    [sym_elements_section] = STATE(3773),
    [sym_schema_section] = STATE(3773),
    [sym_assembly_declaration] = STATE(3773),
    [sym_event_declaration] = STATE(3773),
    [sym_procedure] = STATE(3773),
    [sym_preproc_split_procedure] = STATE(3773),
    [sym_preproc_split_procedure_preamble] = STATE(3773),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3773),
    [sym_var_section] = STATE(3773),
    [sym_var_attribute_item] = STATE(3773),
    [sym_variable_declaration] = STATE(3773),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3773),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11095),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3773),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7307),
    [anon_sym_POUNDENDIF] = ACTIONS(7307),
    [anon_sym_POUNDEndif] = ACTIONS(7307),
    [anon_sym_POUNDendif2] = ACTIONS(7307),
    [anon_sym_POUNDENDIF2] = ACTIONS(7307),
    [anon_sym_POUNDEndif2] = ACTIONS(7307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7307),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3773)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11117),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7307),
    [anon_sym_POUNDENDIF] = ACTIONS(7307),
    [anon_sym_POUNDEndif] = ACTIONS(7307),
    [anon_sym_POUNDendif2] = ACTIONS(7307),
    [anon_sym_POUNDENDIF2] = ACTIONS(7307),
    [anon_sym_POUNDEndif2] = ACTIONS(7307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7307),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3774)] = {
    [sym__body_element] = STATE(3775),
    [sym_empty_statement] = STATE(3775),
    [sym_property] = STATE(3775),
    [sym_permissions_property] = STATE(3775),
    [sym_table_relation_property] = STATE(3775),
    [sym_fields_section] = STATE(3775),
    [sym_keys_section] = STATE(3775),
    [sym_fieldgroups_section] = STATE(3775),
    [sym_enum_value_declaration] = STATE(3775),
    [sym_labels_section] = STATE(3775),
    [sym_layout_section] = STATE(3775),
    [sym_modify_modification] = STATE(3775),
    [sym_actions_section] = STATE(3775),
    [sym_views_section] = STATE(3775),
    [sym_dataset_section] = STATE(3775),
    [sym_requestpage_section] = STATE(3775),
    [sym_rendering_section] = STATE(3775),
    [sym_elements_section] = STATE(3775),
    [sym_schema_section] = STATE(3775),
    [sym_assembly_declaration] = STATE(3775),
    [sym_event_declaration] = STATE(3775),
    [sym_procedure] = STATE(3775),
    [sym_preproc_split_procedure] = STATE(3775),
    [sym_preproc_split_procedure_preamble] = STATE(3775),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3775),
    [sym_var_section] = STATE(3775),
    [sym_var_attribute_item] = STATE(3775),
    [sym_variable_declaration] = STATE(3775),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3775),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11117),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3775),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7307),
    [anon_sym_POUNDENDIF] = ACTIONS(7307),
    [anon_sym_POUNDEndif] = ACTIONS(7307),
    [anon_sym_POUNDendif2] = ACTIONS(7307),
    [anon_sym_POUNDENDIF2] = ACTIONS(7307),
    [anon_sym_POUNDEndif2] = ACTIONS(7307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7307),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3775)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11122),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7307),
    [anon_sym_POUNDENDIF] = ACTIONS(7307),
    [anon_sym_POUNDEndif] = ACTIONS(7307),
    [anon_sym_POUNDendif2] = ACTIONS(7307),
    [anon_sym_POUNDENDIF2] = ACTIONS(7307),
    [anon_sym_POUNDEndif2] = ACTIONS(7307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7307),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3776)] = {
    [sym__body_element] = STATE(3777),
    [sym_empty_statement] = STATE(3777),
    [sym_property] = STATE(3777),
    [sym_permissions_property] = STATE(3777),
    [sym_table_relation_property] = STATE(3777),
    [sym_fields_section] = STATE(3777),
    [sym_keys_section] = STATE(3777),
    [sym_fieldgroups_section] = STATE(3777),
    [sym_enum_value_declaration] = STATE(3777),
    [sym_labels_section] = STATE(3777),
    [sym_layout_section] = STATE(3777),
    [sym_modify_modification] = STATE(3777),
    [sym_actions_section] = STATE(3777),
    [sym_views_section] = STATE(3777),
    [sym_dataset_section] = STATE(3777),
    [sym_requestpage_section] = STATE(3777),
    [sym_rendering_section] = STATE(3777),
    [sym_elements_section] = STATE(3777),
    [sym_schema_section] = STATE(3777),
    [sym_assembly_declaration] = STATE(3777),
    [sym_event_declaration] = STATE(3777),
    [sym_procedure] = STATE(3777),
    [sym_preproc_split_procedure] = STATE(3777),
    [sym_preproc_split_procedure_preamble] = STATE(3777),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3777),
    [sym_var_section] = STATE(3777),
    [sym_var_attribute_item] = STATE(3777),
    [sym_variable_declaration] = STATE(3777),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3777),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11122),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3777),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7307),
    [anon_sym_POUNDENDIF] = ACTIONS(7307),
    [anon_sym_POUNDEndif] = ACTIONS(7307),
    [anon_sym_POUNDendif2] = ACTIONS(7307),
    [anon_sym_POUNDENDIF2] = ACTIONS(7307),
    [anon_sym_POUNDEndif2] = ACTIONS(7307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7307),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3777)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11066),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7307),
    [anon_sym_POUNDENDIF] = ACTIONS(7307),
    [anon_sym_POUNDEndif] = ACTIONS(7307),
    [anon_sym_POUNDendif2] = ACTIONS(7307),
    [anon_sym_POUNDENDIF2] = ACTIONS(7307),
    [anon_sym_POUNDEndif2] = ACTIONS(7307),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7307),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3778)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5545),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7303),
    [anon_sym_POUNDENDIF] = ACTIONS(7303),
    [anon_sym_POUNDEndif] = ACTIONS(7303),
    [anon_sym_POUNDendif2] = ACTIONS(7303),
    [anon_sym_POUNDENDIF2] = ACTIONS(7303),
    [anon_sym_POUNDEndif2] = ACTIONS(7303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7303),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3779)] = {
    [sym__body_element] = STATE(3805),
    [sym_empty_statement] = STATE(3805),
    [sym_property] = STATE(3805),
    [sym_permissions_property] = STATE(3805),
    [sym_table_relation_property] = STATE(3805),
    [sym_fields_section] = STATE(3805),
    [sym_keys_section] = STATE(3805),
    [sym_fieldgroups_section] = STATE(3805),
    [sym_enum_value_declaration] = STATE(3805),
    [sym_labels_section] = STATE(3805),
    [sym_layout_section] = STATE(3805),
    [sym_modify_modification] = STATE(3805),
    [sym_actions_section] = STATE(3805),
    [sym_views_section] = STATE(3805),
    [sym_dataset_section] = STATE(3805),
    [sym_requestpage_section] = STATE(3805),
    [sym_rendering_section] = STATE(3805),
    [sym_elements_section] = STATE(3805),
    [sym_schema_section] = STATE(3805),
    [sym_assembly_declaration] = STATE(3805),
    [sym_event_declaration] = STATE(3805),
    [sym_procedure] = STATE(3805),
    [sym_preproc_split_procedure] = STATE(3805),
    [sym_preproc_split_procedure_preamble] = STATE(3805),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3805),
    [sym_var_section] = STATE(3805),
    [sym_var_attribute_item] = STATE(3805),
    [sym_variable_declaration] = STATE(3805),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3805),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5545),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3805),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7303),
    [anon_sym_POUNDENDIF] = ACTIONS(7303),
    [anon_sym_POUNDEndif] = ACTIONS(7303),
    [anon_sym_POUNDendif2] = ACTIONS(7303),
    [anon_sym_POUNDENDIF2] = ACTIONS(7303),
    [anon_sym_POUNDEndif2] = ACTIONS(7303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7303),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3780)] = {
    [sym__body_element] = STATE(3781),
    [sym_empty_statement] = STATE(3781),
    [sym_property] = STATE(3781),
    [sym_permissions_property] = STATE(3781),
    [sym_table_relation_property] = STATE(3781),
    [sym_fields_section] = STATE(3781),
    [sym_keys_section] = STATE(3781),
    [sym_fieldgroups_section] = STATE(3781),
    [sym_enum_value_declaration] = STATE(3781),
    [sym_labels_section] = STATE(3781),
    [sym_layout_section] = STATE(3781),
    [sym_modify_modification] = STATE(3781),
    [sym_actions_section] = STATE(3781),
    [sym_views_section] = STATE(3781),
    [sym_dataset_section] = STATE(3781),
    [sym_requestpage_section] = STATE(3781),
    [sym_rendering_section] = STATE(3781),
    [sym_elements_section] = STATE(3781),
    [sym_schema_section] = STATE(3781),
    [sym_assembly_declaration] = STATE(3781),
    [sym_event_declaration] = STATE(3781),
    [sym_procedure] = STATE(3781),
    [sym_preproc_split_procedure] = STATE(3781),
    [sym_preproc_split_procedure_preamble] = STATE(3781),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3781),
    [sym_var_section] = STATE(3781),
    [sym_var_attribute_item] = STATE(3781),
    [sym_variable_declaration] = STATE(3781),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3781),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11188),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3781),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7259),
    [anon_sym_POUNDENDIF] = ACTIONS(7259),
    [anon_sym_POUNDEndif] = ACTIONS(7259),
    [anon_sym_POUNDendif2] = ACTIONS(7259),
    [anon_sym_POUNDENDIF2] = ACTIONS(7259),
    [anon_sym_POUNDEndif2] = ACTIONS(7259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7259),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3781)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11254),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7259),
    [anon_sym_POUNDENDIF] = ACTIONS(7259),
    [anon_sym_POUNDEndif] = ACTIONS(7259),
    [anon_sym_POUNDendif2] = ACTIONS(7259),
    [anon_sym_POUNDENDIF2] = ACTIONS(7259),
    [anon_sym_POUNDEndif2] = ACTIONS(7259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7259),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3782)] = {
    [sym__body_element] = STATE(3783),
    [sym_empty_statement] = STATE(3783),
    [sym_property] = STATE(3783),
    [sym_permissions_property] = STATE(3783),
    [sym_table_relation_property] = STATE(3783),
    [sym_fields_section] = STATE(3783),
    [sym_keys_section] = STATE(3783),
    [sym_fieldgroups_section] = STATE(3783),
    [sym_enum_value_declaration] = STATE(3783),
    [sym_labels_section] = STATE(3783),
    [sym_layout_section] = STATE(3783),
    [sym_modify_modification] = STATE(3783),
    [sym_actions_section] = STATE(3783),
    [sym_views_section] = STATE(3783),
    [sym_dataset_section] = STATE(3783),
    [sym_requestpage_section] = STATE(3783),
    [sym_rendering_section] = STATE(3783),
    [sym_elements_section] = STATE(3783),
    [sym_schema_section] = STATE(3783),
    [sym_assembly_declaration] = STATE(3783),
    [sym_event_declaration] = STATE(3783),
    [sym_procedure] = STATE(3783),
    [sym_preproc_split_procedure] = STATE(3783),
    [sym_preproc_split_procedure_preamble] = STATE(3783),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3783),
    [sym_var_section] = STATE(3783),
    [sym_var_attribute_item] = STATE(3783),
    [sym_variable_declaration] = STATE(3783),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3783),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11254),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3783),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7259),
    [anon_sym_POUNDENDIF] = ACTIONS(7259),
    [anon_sym_POUNDEndif] = ACTIONS(7259),
    [anon_sym_POUNDendif2] = ACTIONS(7259),
    [anon_sym_POUNDENDIF2] = ACTIONS(7259),
    [anon_sym_POUNDEndif2] = ACTIONS(7259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7259),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3783)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11162),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7259),
    [anon_sym_POUNDENDIF] = ACTIONS(7259),
    [anon_sym_POUNDEndif] = ACTIONS(7259),
    [anon_sym_POUNDendif2] = ACTIONS(7259),
    [anon_sym_POUNDENDIF2] = ACTIONS(7259),
    [anon_sym_POUNDEndif2] = ACTIONS(7259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7259),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3784)] = {
    [sym__body_element] = STATE(3785),
    [sym_empty_statement] = STATE(3785),
    [sym_property] = STATE(3785),
    [sym_permissions_property] = STATE(3785),
    [sym_table_relation_property] = STATE(3785),
    [sym_fields_section] = STATE(3785),
    [sym_keys_section] = STATE(3785),
    [sym_fieldgroups_section] = STATE(3785),
    [sym_enum_value_declaration] = STATE(3785),
    [sym_labels_section] = STATE(3785),
    [sym_layout_section] = STATE(3785),
    [sym_modify_modification] = STATE(3785),
    [sym_actions_section] = STATE(3785),
    [sym_views_section] = STATE(3785),
    [sym_dataset_section] = STATE(3785),
    [sym_requestpage_section] = STATE(3785),
    [sym_rendering_section] = STATE(3785),
    [sym_elements_section] = STATE(3785),
    [sym_schema_section] = STATE(3785),
    [sym_assembly_declaration] = STATE(3785),
    [sym_event_declaration] = STATE(3785),
    [sym_procedure] = STATE(3785),
    [sym_preproc_split_procedure] = STATE(3785),
    [sym_preproc_split_procedure_preamble] = STATE(3785),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3785),
    [sym_var_section] = STATE(3785),
    [sym_var_attribute_item] = STATE(3785),
    [sym_variable_declaration] = STATE(3785),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3785),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11162),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3785),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7259),
    [anon_sym_POUNDENDIF] = ACTIONS(7259),
    [anon_sym_POUNDEndif] = ACTIONS(7259),
    [anon_sym_POUNDendif2] = ACTIONS(7259),
    [anon_sym_POUNDENDIF2] = ACTIONS(7259),
    [anon_sym_POUNDEndif2] = ACTIONS(7259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7259),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3785)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(11249),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7259),
    [anon_sym_POUNDENDIF] = ACTIONS(7259),
    [anon_sym_POUNDEndif] = ACTIONS(7259),
    [anon_sym_POUNDendif2] = ACTIONS(7259),
    [anon_sym_POUNDENDIF2] = ACTIONS(7259),
    [anon_sym_POUNDEndif2] = ACTIONS(7259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7259),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3786)] = {
    [sym__body_element] = STATE(3787),
    [sym_empty_statement] = STATE(3787),
    [sym_property] = STATE(3787),
    [sym_permissions_property] = STATE(3787),
    [sym_table_relation_property] = STATE(3787),
    [sym_fields_section] = STATE(3787),
    [sym_keys_section] = STATE(3787),
    [sym_fieldgroups_section] = STATE(3787),
    [sym_enum_value_declaration] = STATE(3787),
    [sym_labels_section] = STATE(3787),
    [sym_layout_section] = STATE(3787),
    [sym_modify_modification] = STATE(3787),
    [sym_actions_section] = STATE(3787),
    [sym_views_section] = STATE(3787),
    [sym_dataset_section] = STATE(3787),
    [sym_requestpage_section] = STATE(3787),
    [sym_rendering_section] = STATE(3787),
    [sym_elements_section] = STATE(3787),
    [sym_schema_section] = STATE(3787),
    [sym_assembly_declaration] = STATE(3787),
    [sym_event_declaration] = STATE(3787),
    [sym_procedure] = STATE(3787),
    [sym_preproc_split_procedure] = STATE(3787),
    [sym_preproc_split_procedure_preamble] = STATE(3787),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3787),
    [sym_var_section] = STATE(3787),
    [sym_var_attribute_item] = STATE(3787),
    [sym_variable_declaration] = STATE(3787),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3787),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(7884),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3787),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7313),
    [anon_sym_POUNDENDIF] = ACTIONS(7313),
    [anon_sym_POUNDEndif] = ACTIONS(7313),
    [anon_sym_POUNDendif2] = ACTIONS(7313),
    [anon_sym_POUNDENDIF2] = ACTIONS(7313),
    [anon_sym_POUNDEndif2] = ACTIONS(7313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7313),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3787)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(7886),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7313),
    [anon_sym_POUNDENDIF] = ACTIONS(7313),
    [anon_sym_POUNDEndif] = ACTIONS(7313),
    [anon_sym_POUNDendif2] = ACTIONS(7313),
    [anon_sym_POUNDENDIF2] = ACTIONS(7313),
    [anon_sym_POUNDEndif2] = ACTIONS(7313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7313),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3788)] = {
    [sym__body_element] = STATE(3789),
    [sym_empty_statement] = STATE(3789),
    [sym_property] = STATE(3789),
    [sym_permissions_property] = STATE(3789),
    [sym_table_relation_property] = STATE(3789),
    [sym_fields_section] = STATE(3789),
    [sym_keys_section] = STATE(3789),
    [sym_fieldgroups_section] = STATE(3789),
    [sym_enum_value_declaration] = STATE(3789),
    [sym_labels_section] = STATE(3789),
    [sym_layout_section] = STATE(3789),
    [sym_modify_modification] = STATE(3789),
    [sym_actions_section] = STATE(3789),
    [sym_views_section] = STATE(3789),
    [sym_dataset_section] = STATE(3789),
    [sym_requestpage_section] = STATE(3789),
    [sym_rendering_section] = STATE(3789),
    [sym_elements_section] = STATE(3789),
    [sym_schema_section] = STATE(3789),
    [sym_assembly_declaration] = STATE(3789),
    [sym_event_declaration] = STATE(3789),
    [sym_procedure] = STATE(3789),
    [sym_preproc_split_procedure] = STATE(3789),
    [sym_preproc_split_procedure_preamble] = STATE(3789),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3789),
    [sym_var_section] = STATE(3789),
    [sym_var_attribute_item] = STATE(3789),
    [sym_variable_declaration] = STATE(3789),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3789),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(7886),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3789),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7313),
    [anon_sym_POUNDENDIF] = ACTIONS(7313),
    [anon_sym_POUNDEndif] = ACTIONS(7313),
    [anon_sym_POUNDendif2] = ACTIONS(7313),
    [anon_sym_POUNDENDIF2] = ACTIONS(7313),
    [anon_sym_POUNDEndif2] = ACTIONS(7313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7313),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3789)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(7890),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7313),
    [anon_sym_POUNDENDIF] = ACTIONS(7313),
    [anon_sym_POUNDEndif] = ACTIONS(7313),
    [anon_sym_POUNDendif2] = ACTIONS(7313),
    [anon_sym_POUNDENDIF2] = ACTIONS(7313),
    [anon_sym_POUNDEndif2] = ACTIONS(7313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7313),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3790)] = {
    [sym__body_element] = STATE(3791),
    [sym_empty_statement] = STATE(3791),
    [sym_property] = STATE(3791),
    [sym_permissions_property] = STATE(3791),
    [sym_table_relation_property] = STATE(3791),
    [sym_fields_section] = STATE(3791),
    [sym_keys_section] = STATE(3791),
    [sym_fieldgroups_section] = STATE(3791),
    [sym_enum_value_declaration] = STATE(3791),
    [sym_labels_section] = STATE(3791),
    [sym_layout_section] = STATE(3791),
    [sym_modify_modification] = STATE(3791),
    [sym_actions_section] = STATE(3791),
    [sym_views_section] = STATE(3791),
    [sym_dataset_section] = STATE(3791),
    [sym_requestpage_section] = STATE(3791),
    [sym_rendering_section] = STATE(3791),
    [sym_elements_section] = STATE(3791),
    [sym_schema_section] = STATE(3791),
    [sym_assembly_declaration] = STATE(3791),
    [sym_event_declaration] = STATE(3791),
    [sym_procedure] = STATE(3791),
    [sym_preproc_split_procedure] = STATE(3791),
    [sym_preproc_split_procedure_preamble] = STATE(3791),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3791),
    [sym_var_section] = STATE(3791),
    [sym_var_attribute_item] = STATE(3791),
    [sym_variable_declaration] = STATE(3791),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3791),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(7890),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3791),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7313),
    [anon_sym_POUNDENDIF] = ACTIONS(7313),
    [anon_sym_POUNDEndif] = ACTIONS(7313),
    [anon_sym_POUNDendif2] = ACTIONS(7313),
    [anon_sym_POUNDENDIF2] = ACTIONS(7313),
    [anon_sym_POUNDEndif2] = ACTIONS(7313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7313),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3791)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(7895),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7313),
    [anon_sym_POUNDENDIF] = ACTIONS(7313),
    [anon_sym_POUNDEndif] = ACTIONS(7313),
    [anon_sym_POUNDendif2] = ACTIONS(7313),
    [anon_sym_POUNDENDIF2] = ACTIONS(7313),
    [anon_sym_POUNDEndif2] = ACTIONS(7313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7313),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3792)] = {
    [sym__body_element] = STATE(3793),
    [sym_empty_statement] = STATE(3793),
    [sym_property] = STATE(3793),
    [sym_permissions_property] = STATE(3793),
    [sym_table_relation_property] = STATE(3793),
    [sym_fields_section] = STATE(3793),
    [sym_keys_section] = STATE(3793),
    [sym_fieldgroups_section] = STATE(3793),
    [sym_enum_value_declaration] = STATE(3793),
    [sym_labels_section] = STATE(3793),
    [sym_layout_section] = STATE(3793),
    [sym_modify_modification] = STATE(3793),
    [sym_actions_section] = STATE(3793),
    [sym_views_section] = STATE(3793),
    [sym_dataset_section] = STATE(3793),
    [sym_requestpage_section] = STATE(3793),
    [sym_rendering_section] = STATE(3793),
    [sym_elements_section] = STATE(3793),
    [sym_schema_section] = STATE(3793),
    [sym_assembly_declaration] = STATE(3793),
    [sym_event_declaration] = STATE(3793),
    [sym_procedure] = STATE(3793),
    [sym_preproc_split_procedure] = STATE(3793),
    [sym_preproc_split_procedure_preamble] = STATE(3793),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3793),
    [sym_var_section] = STATE(3793),
    [sym_var_attribute_item] = STATE(3793),
    [sym_variable_declaration] = STATE(3793),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3793),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(8223),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3793),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7315),
    [anon_sym_POUNDENDIF] = ACTIONS(7315),
    [anon_sym_POUNDEndif] = ACTIONS(7315),
    [anon_sym_POUNDendif2] = ACTIONS(7315),
    [anon_sym_POUNDENDIF2] = ACTIONS(7315),
    [anon_sym_POUNDEndif2] = ACTIONS(7315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7315),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3793)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(8226),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7315),
    [anon_sym_POUNDENDIF] = ACTIONS(7315),
    [anon_sym_POUNDEndif] = ACTIONS(7315),
    [anon_sym_POUNDendif2] = ACTIONS(7315),
    [anon_sym_POUNDENDIF2] = ACTIONS(7315),
    [anon_sym_POUNDEndif2] = ACTIONS(7315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7315),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3794)] = {
    [sym__body_element] = STATE(3795),
    [sym_empty_statement] = STATE(3795),
    [sym_property] = STATE(3795),
    [sym_permissions_property] = STATE(3795),
    [sym_table_relation_property] = STATE(3795),
    [sym_fields_section] = STATE(3795),
    [sym_keys_section] = STATE(3795),
    [sym_fieldgroups_section] = STATE(3795),
    [sym_enum_value_declaration] = STATE(3795),
    [sym_labels_section] = STATE(3795),
    [sym_layout_section] = STATE(3795),
    [sym_modify_modification] = STATE(3795),
    [sym_actions_section] = STATE(3795),
    [sym_views_section] = STATE(3795),
    [sym_dataset_section] = STATE(3795),
    [sym_requestpage_section] = STATE(3795),
    [sym_rendering_section] = STATE(3795),
    [sym_elements_section] = STATE(3795),
    [sym_schema_section] = STATE(3795),
    [sym_assembly_declaration] = STATE(3795),
    [sym_event_declaration] = STATE(3795),
    [sym_procedure] = STATE(3795),
    [sym_preproc_split_procedure] = STATE(3795),
    [sym_preproc_split_procedure_preamble] = STATE(3795),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3795),
    [sym_var_section] = STATE(3795),
    [sym_var_attribute_item] = STATE(3795),
    [sym_variable_declaration] = STATE(3795),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3795),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(8226),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3795),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7315),
    [anon_sym_POUNDENDIF] = ACTIONS(7315),
    [anon_sym_POUNDEndif] = ACTIONS(7315),
    [anon_sym_POUNDendif2] = ACTIONS(7315),
    [anon_sym_POUNDENDIF2] = ACTIONS(7315),
    [anon_sym_POUNDEndif2] = ACTIONS(7315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7315),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3795)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(8230),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7315),
    [anon_sym_POUNDENDIF] = ACTIONS(7315),
    [anon_sym_POUNDEndif] = ACTIONS(7315),
    [anon_sym_POUNDendif2] = ACTIONS(7315),
    [anon_sym_POUNDENDIF2] = ACTIONS(7315),
    [anon_sym_POUNDEndif2] = ACTIONS(7315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7315),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3796)] = {
    [sym__body_element] = STATE(3797),
    [sym_empty_statement] = STATE(3797),
    [sym_property] = STATE(3797),
    [sym_permissions_property] = STATE(3797),
    [sym_table_relation_property] = STATE(3797),
    [sym_fields_section] = STATE(3797),
    [sym_keys_section] = STATE(3797),
    [sym_fieldgroups_section] = STATE(3797),
    [sym_enum_value_declaration] = STATE(3797),
    [sym_labels_section] = STATE(3797),
    [sym_layout_section] = STATE(3797),
    [sym_modify_modification] = STATE(3797),
    [sym_actions_section] = STATE(3797),
    [sym_views_section] = STATE(3797),
    [sym_dataset_section] = STATE(3797),
    [sym_requestpage_section] = STATE(3797),
    [sym_rendering_section] = STATE(3797),
    [sym_elements_section] = STATE(3797),
    [sym_schema_section] = STATE(3797),
    [sym_assembly_declaration] = STATE(3797),
    [sym_event_declaration] = STATE(3797),
    [sym_procedure] = STATE(3797),
    [sym_preproc_split_procedure] = STATE(3797),
    [sym_preproc_split_procedure_preamble] = STATE(3797),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3797),
    [sym_var_section] = STATE(3797),
    [sym_var_attribute_item] = STATE(3797),
    [sym_variable_declaration] = STATE(3797),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3797),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(8230),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3797),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7315),
    [anon_sym_POUNDENDIF] = ACTIONS(7315),
    [anon_sym_POUNDEndif] = ACTIONS(7315),
    [anon_sym_POUNDendif2] = ACTIONS(7315),
    [anon_sym_POUNDENDIF2] = ACTIONS(7315),
    [anon_sym_POUNDEndif2] = ACTIONS(7315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7315),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3797)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(8235),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7315),
    [anon_sym_POUNDENDIF] = ACTIONS(7315),
    [anon_sym_POUNDEndif] = ACTIONS(7315),
    [anon_sym_POUNDendif2] = ACTIONS(7315),
    [anon_sym_POUNDENDIF2] = ACTIONS(7315),
    [anon_sym_POUNDEndif2] = ACTIONS(7315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7315),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3798)] = {
    [sym__body_element] = STATE(3799),
    [sym_empty_statement] = STATE(3799),
    [sym_property] = STATE(3799),
    [sym_permissions_property] = STATE(3799),
    [sym_table_relation_property] = STATE(3799),
    [sym_fields_section] = STATE(3799),
    [sym_keys_section] = STATE(3799),
    [sym_fieldgroups_section] = STATE(3799),
    [sym_enum_value_declaration] = STATE(3799),
    [sym_labels_section] = STATE(3799),
    [sym_layout_section] = STATE(3799),
    [sym_modify_modification] = STATE(3799),
    [sym_actions_section] = STATE(3799),
    [sym_views_section] = STATE(3799),
    [sym_dataset_section] = STATE(3799),
    [sym_requestpage_section] = STATE(3799),
    [sym_rendering_section] = STATE(3799),
    [sym_elements_section] = STATE(3799),
    [sym_schema_section] = STATE(3799),
    [sym_assembly_declaration] = STATE(3799),
    [sym_event_declaration] = STATE(3799),
    [sym_procedure] = STATE(3799),
    [sym_preproc_split_procedure] = STATE(3799),
    [sym_preproc_split_procedure_preamble] = STATE(3799),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3799),
    [sym_var_section] = STATE(3799),
    [sym_var_attribute_item] = STATE(3799),
    [sym_variable_declaration] = STATE(3799),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3799),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5915),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3799),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7323),
    [anon_sym_POUNDENDIF] = ACTIONS(7323),
    [anon_sym_POUNDEndif] = ACTIONS(7323),
    [anon_sym_POUNDendif2] = ACTIONS(7323),
    [anon_sym_POUNDENDIF2] = ACTIONS(7323),
    [anon_sym_POUNDEndif2] = ACTIONS(7323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7323),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3799)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5876),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7323),
    [anon_sym_POUNDENDIF] = ACTIONS(7323),
    [anon_sym_POUNDEndif] = ACTIONS(7323),
    [anon_sym_POUNDendif2] = ACTIONS(7323),
    [anon_sym_POUNDENDIF2] = ACTIONS(7323),
    [anon_sym_POUNDEndif2] = ACTIONS(7323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7323),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3800)] = {
    [sym__body_element] = STATE(3801),
    [sym_empty_statement] = STATE(3801),
    [sym_property] = STATE(3801),
    [sym_permissions_property] = STATE(3801),
    [sym_table_relation_property] = STATE(3801),
    [sym_fields_section] = STATE(3801),
    [sym_keys_section] = STATE(3801),
    [sym_fieldgroups_section] = STATE(3801),
    [sym_enum_value_declaration] = STATE(3801),
    [sym_labels_section] = STATE(3801),
    [sym_layout_section] = STATE(3801),
    [sym_modify_modification] = STATE(3801),
    [sym_actions_section] = STATE(3801),
    [sym_views_section] = STATE(3801),
    [sym_dataset_section] = STATE(3801),
    [sym_requestpage_section] = STATE(3801),
    [sym_rendering_section] = STATE(3801),
    [sym_elements_section] = STATE(3801),
    [sym_schema_section] = STATE(3801),
    [sym_assembly_declaration] = STATE(3801),
    [sym_event_declaration] = STATE(3801),
    [sym_procedure] = STATE(3801),
    [sym_preproc_split_procedure] = STATE(3801),
    [sym_preproc_split_procedure_preamble] = STATE(3801),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3801),
    [sym_var_section] = STATE(3801),
    [sym_var_attribute_item] = STATE(3801),
    [sym_variable_declaration] = STATE(3801),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3801),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5876),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3801),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7323),
    [anon_sym_POUNDENDIF] = ACTIONS(7323),
    [anon_sym_POUNDEndif] = ACTIONS(7323),
    [anon_sym_POUNDendif2] = ACTIONS(7323),
    [anon_sym_POUNDENDIF2] = ACTIONS(7323),
    [anon_sym_POUNDEndif2] = ACTIONS(7323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7323),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3801)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5883),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7323),
    [anon_sym_POUNDENDIF] = ACTIONS(7323),
    [anon_sym_POUNDEndif] = ACTIONS(7323),
    [anon_sym_POUNDendif2] = ACTIONS(7323),
    [anon_sym_POUNDENDIF2] = ACTIONS(7323),
    [anon_sym_POUNDEndif2] = ACTIONS(7323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7323),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3802)] = {
    [sym__body_element] = STATE(3803),
    [sym_empty_statement] = STATE(3803),
    [sym_property] = STATE(3803),
    [sym_permissions_property] = STATE(3803),
    [sym_table_relation_property] = STATE(3803),
    [sym_fields_section] = STATE(3803),
    [sym_keys_section] = STATE(3803),
    [sym_fieldgroups_section] = STATE(3803),
    [sym_enum_value_declaration] = STATE(3803),
    [sym_labels_section] = STATE(3803),
    [sym_layout_section] = STATE(3803),
    [sym_modify_modification] = STATE(3803),
    [sym_actions_section] = STATE(3803),
    [sym_views_section] = STATE(3803),
    [sym_dataset_section] = STATE(3803),
    [sym_requestpage_section] = STATE(3803),
    [sym_rendering_section] = STATE(3803),
    [sym_elements_section] = STATE(3803),
    [sym_schema_section] = STATE(3803),
    [sym_assembly_declaration] = STATE(3803),
    [sym_event_declaration] = STATE(3803),
    [sym_procedure] = STATE(3803),
    [sym_preproc_split_procedure] = STATE(3803),
    [sym_preproc_split_procedure_preamble] = STATE(3803),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3803),
    [sym_var_section] = STATE(3803),
    [sym_var_attribute_item] = STATE(3803),
    [sym_variable_declaration] = STATE(3803),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3803),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5883),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3803),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7323),
    [anon_sym_POUNDENDIF] = ACTIONS(7323),
    [anon_sym_POUNDEndif] = ACTIONS(7323),
    [anon_sym_POUNDendif2] = ACTIONS(7323),
    [anon_sym_POUNDENDIF2] = ACTIONS(7323),
    [anon_sym_POUNDEndif2] = ACTIONS(7323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7323),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3803)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5908),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7323),
    [anon_sym_POUNDENDIF] = ACTIONS(7323),
    [anon_sym_POUNDEndif] = ACTIONS(7323),
    [anon_sym_POUNDendif2] = ACTIONS(7323),
    [anon_sym_POUNDENDIF2] = ACTIONS(7323),
    [anon_sym_POUNDEndif2] = ACTIONS(7323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7323),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3804)] = {
    [sym__body_element] = STATE(3749),
    [sym_empty_statement] = STATE(3749),
    [sym_property] = STATE(3749),
    [sym_permissions_property] = STATE(3749),
    [sym_table_relation_property] = STATE(3749),
    [sym_fields_section] = STATE(3749),
    [sym_keys_section] = STATE(3749),
    [sym_fieldgroups_section] = STATE(3749),
    [sym_enum_value_declaration] = STATE(3749),
    [sym_labels_section] = STATE(3749),
    [sym_layout_section] = STATE(3749),
    [sym_modify_modification] = STATE(3749),
    [sym_actions_section] = STATE(3749),
    [sym_views_section] = STATE(3749),
    [sym_dataset_section] = STATE(3749),
    [sym_requestpage_section] = STATE(3749),
    [sym_rendering_section] = STATE(3749),
    [sym_elements_section] = STATE(3749),
    [sym_schema_section] = STATE(3749),
    [sym_assembly_declaration] = STATE(3749),
    [sym_event_declaration] = STATE(3749),
    [sym_procedure] = STATE(3749),
    [sym_preproc_split_procedure] = STATE(3749),
    [sym_preproc_split_procedure_preamble] = STATE(3749),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3749),
    [sym_var_section] = STATE(3749),
    [sym_var_attribute_item] = STATE(3749),
    [sym_variable_declaration] = STATE(3749),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3749),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5693),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3749),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7303),
    [anon_sym_POUNDENDIF] = ACTIONS(7303),
    [anon_sym_POUNDEndif] = ACTIONS(7303),
    [anon_sym_POUNDendif2] = ACTIONS(7303),
    [anon_sym_POUNDENDIF2] = ACTIONS(7303),
    [anon_sym_POUNDEndif2] = ACTIONS(7303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7303),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3805)] = {
    [sym__body_element] = STATE(3554),
    [sym_empty_statement] = STATE(3554),
    [sym_property] = STATE(3554),
    [sym_permissions_property] = STATE(3554),
    [sym_table_relation_property] = STATE(3554),
    [sym_fields_section] = STATE(3554),
    [sym_keys_section] = STATE(3554),
    [sym_fieldgroups_section] = STATE(3554),
    [sym_enum_value_declaration] = STATE(3554),
    [sym_labels_section] = STATE(3554),
    [sym_layout_section] = STATE(3554),
    [sym_modify_modification] = STATE(3554),
    [sym_actions_section] = STATE(3554),
    [sym_views_section] = STATE(3554),
    [sym_dataset_section] = STATE(3554),
    [sym_requestpage_section] = STATE(3554),
    [sym_rendering_section] = STATE(3554),
    [sym_elements_section] = STATE(3554),
    [sym_schema_section] = STATE(3554),
    [sym_assembly_declaration] = STATE(3554),
    [sym_event_declaration] = STATE(3554),
    [sym_procedure] = STATE(3554),
    [sym_preproc_split_procedure] = STATE(3554),
    [sym_preproc_split_procedure_preamble] = STATE(3554),
    [sym_procedure_modifier] = STATE(17627),
    [sym_trigger_declaration] = STATE(3554),
    [sym_var_section] = STATE(3554),
    [sym_var_attribute_item] = STATE(3554),
    [sym_variable_declaration] = STATE(3554),
    [sym_attribute_item] = STATE(6686),
    [sym_preproc_conditional] = STATE(3554),
    [sym_preproc_if] = STATE(3656),
    [sym_preproc_endif] = STATE(5719),
    [sym__identifier_or_quoted] = STATE(15737),
    [sym_keyword_as_identifier] = STATE(15737),
    [aux_sym_preproc_conditional_var_repeat1] = STATE(3554),
    [sym_identifier] = ACTIONS(7243),
    [anon_sym_SEMI] = ACTIONS(7245),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(7247),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7249),
    [aux_sym_modify_modification_token1] = ACTIONS(7251),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7253),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(7303),
    [anon_sym_POUNDENDIF] = ACTIONS(7303),
    [anon_sym_POUNDEndif] = ACTIONS(7303),
    [anon_sym_POUNDendif2] = ACTIONS(7303),
    [anon_sym_POUNDENDIF2] = ACTIONS(7303),
    [anon_sym_POUNDEndif2] = ACTIONS(7303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(7360),
    [sym_trigger_keyword] = ACTIONS(7263),
    [sym_var_keyword] = ACTIONS(7265),
    [sym_local_keyword] = ACTIONS(7267),
    [sym_internal_keyword] = ACTIONS(7269),
    [sym_protected_keyword] = ACTIONS(7267),
    [sym_event_keyword] = ACTIONS(7271),
    [sym_fields_keyword] = ACTIONS(7273),
    [sym_keys_keyword] = ACTIONS(7275),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(7277),
    [sym_actions_keyword] = ACTIONS(7279),
    [sym_layout_keyword] = ACTIONS(7281),
    [sym_dataset_keyword] = ACTIONS(7283),
    [sym_elements_keyword] = ACTIONS(7285),
    [sym_labels_keyword] = ACTIONS(7287),
    [sym_rendering_keyword] = ACTIONS(7289),
    [sym_requestpage_keyword] = ACTIONS(7291),
    [sym_schema_keyword] = ACTIONS(7293),
    [sym_views_keyword] = ACTIONS(7295),
    [sym_quoted_identifier] = ACTIONS(7297),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7299),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(7303),
    [sym_var_attribute_open] = ACTIONS(7301),
  },
  [STATE(3806)] = {
    [sym_boolean] = STATE(9829),
    [sym_option_member] = STATE(9762),
    [sym_keyword_identifier] = STATE(9829),
    [sym_codeunit_keyword] = STATE(9824),
    [sym_xmlport_keyword] = STATE(9824),
    [sym_enum_keyword] = STATE(9824),
    [sym_keyword_as_identifier] = STATE(9829),
    [aux_sym_option_member_list_repeat2] = STATE(4061),
    [sym_identifier] = ACTIONS(8337),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_RBRACE] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(8452),
    [anon_sym_DASH] = ACTIONS(8341),
    [aux_sym_boolean_token1] = ACTIONS(8343),
    [aux_sym_boolean_token2] = ACTIONS(8343),
    [aux_sym_where_condition_token1] = ACTIONS(8345),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8347),
    [anon_sym_LBRACK] = ACTIONS(600),
    [aux_sym_record_type_token1] = ACTIONS(8347),
    [aux_sym_basic_type_token21] = ACTIONS(8347),
    [aux_sym_basic_type_token22] = ACTIONS(8349),
    [aux_sym_basic_type_token48] = ACTIONS(8347),
    [aux_sym_basic_type_token53] = ACTIONS(8345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8345),
    [aux_sym_modify_modification_token1] = ACTIONS(602),
    [aux_sym_separator_action_token1] = ACTIONS(8345),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8345),
    [aux_sym_type_declaration_token1] = ACTIONS(8345),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8347),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8347),
    [sym_table_keyword] = ACTIONS(8345),
    [sym_page_keyword] = ACTIONS(8347),
    [anon_sym_codeunit] = ACTIONS(8351),
    [anon_sym_CODEUNIT] = ACTIONS(8351),
    [anon_sym_Codeunit] = ACTIONS(8351),
    [anon_sym_CodeUnit] = ACTIONS(8351),
    [anon_sym_COdeunit] = ACTIONS(8351),
    [anon_sym_codeUnit] = ACTIONS(8351),
    [sym_report_keyword] = ACTIONS(8347),
    [sym_query_keyword] = ACTIONS(8347),
    [anon_sym_xmlport] = ACTIONS(8353),
    [anon_sym_XMLPORT] = ACTIONS(8353),
    [anon_sym_Xmlport] = ACTIONS(8353),
    [anon_sym_XMLport] = ACTIONS(8353),
    [anon_sym_XMLPort] = ACTIONS(8353),
    [anon_sym_XmlPort] = ACTIONS(8353),
    [anon_sym_enum] = ACTIONS(8355),
    [anon_sym_ENUM] = ACTIONS(8355),
    [anon_sym_Enum] = ACTIONS(8355),
    [anon_sym_eNUM] = ACTIONS(8355),
    [anon_sym_eNum] = ACTIONS(8355),
    [anon_sym_ENum] = ACTIONS(8355),
    [sym_procedure_keyword] = ACTIONS(602),
    [sym_trigger_keyword] = ACTIONS(602),
    [sym_var_keyword] = ACTIONS(602),
    [sym_local_keyword] = ACTIONS(8337),
    [sym_internal_keyword] = ACTIONS(8337),
    [sym_protected_keyword] = ACTIONS(8337),
    [sym_event_keyword] = ACTIONS(602),
    [sym_fields_keyword] = ACTIONS(602),
    [sym_keys_keyword] = ACTIONS(602),
    [sym_key_keyword] = ACTIONS(8345),
    [sym_fieldgroups_keyword] = ACTIONS(602),
    [sym_actions_keyword] = ACTIONS(602),
    [sym_layout_keyword] = ACTIONS(602),
    [sym_dataset_keyword] = ACTIONS(8345),
    [sym_elements_keyword] = ACTIONS(602),
    [sym_labels_keyword] = ACTIONS(602),
    [sym_rendering_keyword] = ACTIONS(602),
    [sym_requestpage_keyword] = ACTIONS(602),
    [sym_schema_keyword] = ACTIONS(602),
    [sym_views_keyword] = ACTIONS(602),
    [sym_quoted_identifier] = ACTIONS(8357),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8357),
    [sym_integer] = ACTIONS(8357),
    [sym_property_name] = ACTIONS(600),
    [sym_preproc_open] = ACTIONS(600),
    [sym_begin_keyword] = ACTIONS(600),
  },
  [STATE(3807)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8454),
    [anon_sym_POUNDELIF] = ACTIONS(8454),
    [anon_sym_POUNDElif] = ACTIONS(8454),
    [anon_sym_POUNDelse] = ACTIONS(8454),
    [anon_sym_POUNDELSE] = ACTIONS(8454),
    [anon_sym_POUNDElse] = ACTIONS(8454),
    [anon_sym_POUNDelse2] = ACTIONS(8454),
    [anon_sym_POUNDELSE2] = ACTIONS(8454),
    [anon_sym_POUNDElse2] = ACTIONS(8454),
    [anon_sym_POUNDendif] = ACTIONS(8454),
    [anon_sym_POUNDENDIF] = ACTIONS(8454),
    [anon_sym_POUNDEndif] = ACTIONS(8454),
    [anon_sym_POUNDendif2] = ACTIONS(8454),
    [anon_sym_POUNDENDIF2] = ACTIONS(8454),
    [anon_sym_POUNDEndif2] = ACTIONS(8454),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8454),
  },
  [STATE(3808)] = {
    [sym__body_element] = STATE(3807),
    [sym_empty_statement] = STATE(3807),
    [sym_property] = STATE(3807),
    [sym_permissions_property] = STATE(3807),
    [sym_table_relation_property] = STATE(3807),
    [sym_fields_section] = STATE(3807),
    [sym_keys_section] = STATE(3807),
    [sym_fieldgroups_section] = STATE(3807),
    [sym_enum_value_declaration] = STATE(3807),
    [sym_labels_section] = STATE(3807),
    [sym_layout_section] = STATE(3807),
    [sym_modify_modification] = STATE(3807),
    [sym_actions_section] = STATE(3807),
    [sym_views_section] = STATE(3807),
    [sym_dataset_section] = STATE(3807),
    [sym_report_dataitem] = STATE(3807),
    [sym__report_body_element] = STATE(3807),
    [sym_preproc_conditional_report] = STATE(3807),
    [sym_report_column] = STATE(3807),
    [sym_requestpage_section] = STATE(3807),
    [sym_rendering_section] = STATE(3807),
    [sym_elements_section] = STATE(3807),
    [sym_schema_section] = STATE(3807),
    [sym_assembly_declaration] = STATE(3807),
    [sym_event_declaration] = STATE(3807),
    [sym_procedure] = STATE(3807),
    [sym_preproc_split_procedure] = STATE(3807),
    [sym_preproc_split_procedure_preamble] = STATE(3807),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3807),
    [sym_var_section] = STATE(3807),
    [sym_attribute_item] = STATE(3807),
    [sym_preproc_conditional] = STATE(3807),
    [sym_preproc_if] = STATE(3548),
    [aux_sym_report_dataitem_repeat1] = STATE(3807),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8456),
    [anon_sym_POUNDELIF] = ACTIONS(8456),
    [anon_sym_POUNDElif] = ACTIONS(8456),
    [anon_sym_POUNDelse] = ACTIONS(8456),
    [anon_sym_POUNDELSE] = ACTIONS(8456),
    [anon_sym_POUNDElse] = ACTIONS(8456),
    [anon_sym_POUNDelse2] = ACTIONS(8456),
    [anon_sym_POUNDELSE2] = ACTIONS(8456),
    [anon_sym_POUNDElse2] = ACTIONS(8456),
    [anon_sym_POUNDendif] = ACTIONS(8456),
    [anon_sym_POUNDENDIF] = ACTIONS(8456),
    [anon_sym_POUNDEndif] = ACTIONS(8456),
    [anon_sym_POUNDendif2] = ACTIONS(8456),
    [anon_sym_POUNDENDIF2] = ACTIONS(8456),
    [anon_sym_POUNDEndif2] = ACTIONS(8456),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8456),
  },
  [STATE(3809)] = {
    [sym_identifier] = ACTIONS(8198),
    [anon_sym_DOT] = ACTIONS(6589),
    [anon_sym_EQ] = ACTIONS(6591),
    [anon_sym_DASH] = ACTIONS(8458),
    [aux_sym_boolean_token1] = ACTIONS(8198),
    [aux_sym_boolean_token2] = ACTIONS(8198),
    [sym_decimal] = ACTIONS(8198),
    [anon_sym_LPAREN] = ACTIONS(8203),
    [anon_sym_RPAREN] = ACTIONS(8203),
    [anon_sym_DOT_DOT] = ACTIONS(8461),
    [aux_sym_filter_value_token1] = ACTIONS(8198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8198),
    [anon_sym_STAR] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(8461),
    [aux_sym_record_type_token1] = ACTIONS(8198),
    [aux_sym_basic_type_token21] = ACTIONS(8198),
    [aux_sym_basic_type_token22] = ACTIONS(8198),
    [aux_sym_basic_type_token48] = ACTIONS(8198),
    [anon_sym_not] = ACTIONS(8198),
    [anon_sym_NOT] = ACTIONS(8198),
    [anon_sym_Not] = ACTIONS(8198),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6591),
    [aux_sym__expression_token1] = ACTIONS(6591),
    [aux_sym__expression_token2] = ACTIONS(6591),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8198),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8198),
    [anon_sym_SLASH] = ACTIONS(6589),
    [anon_sym_div] = ACTIONS(6589),
    [anon_sym_DIV] = ACTIONS(6589),
    [anon_sym_Div] = ACTIONS(6589),
    [anon_sym_mod] = ACTIONS(6589),
    [anon_sym_MOD] = ACTIONS(6589),
    [anon_sym_Mod] = ACTIONS(6589),
    [anon_sym_PLUS] = ACTIONS(8458),
    [anon_sym_GT_EQ] = ACTIONS(6591),
    [anon_sym_LT_EQ] = ACTIONS(6591),
    [anon_sym_GT] = ACTIONS(6589),
    [anon_sym_LT] = ACTIONS(6589),
    [anon_sym_LT_GT] = ACTIONS(6591),
    [anon_sym_and] = ACTIONS(6589),
    [anon_sym_AND] = ACTIONS(6589),
    [anon_sym_And] = ACTIONS(6589),
    [anon_sym_or] = ACTIONS(6589),
    [anon_sym_OR] = ACTIONS(6589),
    [anon_sym_Or] = ACTIONS(6589),
    [anon_sym_xor] = ACTIONS(6589),
    [anon_sym_XOR] = ACTIONS(6589),
    [anon_sym_Xor] = ACTIONS(6589),
    [anon_sym_QMARK] = ACTIONS(6591),
    [sym_datetime_literal] = ACTIONS(8203),
    [sym_date_literal] = ACTIONS(8198),
    [sym_time_literal] = ACTIONS(8198),
    [sym_biginteger_literal] = ACTIONS(8203),
    [anon_sym_in] = ACTIONS(6589),
    [anon_sym_IN] = ACTIONS(6589),
    [anon_sym_In] = ACTIONS(6589),
    [sym_page_keyword] = ACTIONS(8198),
    [anon_sym_codeunit] = ACTIONS(8198),
    [anon_sym_CODEUNIT] = ACTIONS(8198),
    [anon_sym_Codeunit] = ACTIONS(8198),
    [anon_sym_CodeUnit] = ACTIONS(8198),
    [anon_sym_COdeunit] = ACTIONS(8198),
    [anon_sym_codeUnit] = ACTIONS(8198),
    [sym_report_keyword] = ACTIONS(8198),
    [sym_query_keyword] = ACTIONS(8198),
    [anon_sym_xmlport] = ACTIONS(8198),
    [anon_sym_XMLPORT] = ACTIONS(8198),
    [anon_sym_Xmlport] = ACTIONS(8198),
    [anon_sym_XMLport] = ACTIONS(8198),
    [anon_sym_XMLPort] = ACTIONS(8198),
    [anon_sym_XmlPort] = ACTIONS(8198),
    [anon_sym_enum] = ACTIONS(8198),
    [anon_sym_ENUM] = ACTIONS(8198),
    [anon_sym_Enum] = ACTIONS(8198),
    [anon_sym_eNUM] = ACTIONS(8198),
    [anon_sym_eNum] = ACTIONS(8198),
    [anon_sym_ENum] = ACTIONS(8198),
    [sym_quoted_identifier] = ACTIONS(8203),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8203),
    [sym_verbatim_string] = ACTIONS(8203),
    [sym_integer] = ACTIONS(8198),
    [sym_continue_as_identifier] = ACTIONS(8203),
  },
  [STATE(3810)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [anon_sym_SEMI] = ACTIONS(8464),
    [anon_sym_LBRACK] = ACTIONS(8467),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8470),
    [aux_sym_modify_modification_token1] = ACTIONS(8473),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8476),
    [anon_sym_POUNDif] = ACTIONS(8479),
    [anon_sym_POUNDIF] = ACTIONS(8479),
    [anon_sym_POUNDIf] = ACTIONS(8479),
    [anon_sym_POUNDelif] = ACTIONS(8482),
    [anon_sym_POUNDELIF] = ACTIONS(8482),
    [anon_sym_POUNDElif] = ACTIONS(8482),
    [anon_sym_POUNDelse] = ACTIONS(8482),
    [anon_sym_POUNDELSE] = ACTIONS(8482),
    [anon_sym_POUNDElse] = ACTIONS(8482),
    [anon_sym_POUNDelse2] = ACTIONS(8482),
    [anon_sym_POUNDELSE2] = ACTIONS(8482),
    [anon_sym_POUNDElse2] = ACTIONS(8482),
    [anon_sym_POUNDendif] = ACTIONS(8482),
    [anon_sym_POUNDENDIF] = ACTIONS(8482),
    [anon_sym_POUNDEndif] = ACTIONS(8482),
    [anon_sym_POUNDendif2] = ACTIONS(8482),
    [anon_sym_POUNDENDIF2] = ACTIONS(8482),
    [anon_sym_POUNDEndif2] = ACTIONS(8482),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8484),
    [sym_trigger_keyword] = ACTIONS(8487),
    [sym_var_keyword] = ACTIONS(8490),
    [sym_local_keyword] = ACTIONS(8493),
    [sym_internal_keyword] = ACTIONS(8496),
    [sym_protected_keyword] = ACTIONS(8493),
    [sym_event_keyword] = ACTIONS(8499),
    [sym_fields_keyword] = ACTIONS(8502),
    [sym_keys_keyword] = ACTIONS(8505),
    [sym_fieldgroups_keyword] = ACTIONS(8508),
    [sym_actions_keyword] = ACTIONS(8511),
    [sym_layout_keyword] = ACTIONS(8514),
    [sym_dataset_keyword] = ACTIONS(8517),
    [sym_elements_keyword] = ACTIONS(8520),
    [sym_dataitem_keyword] = ACTIONS(8523),
    [sym_column_keyword] = ACTIONS(8526),
    [sym_labels_keyword] = ACTIONS(8529),
    [sym_rendering_keyword] = ACTIONS(8532),
    [sym_requestpage_keyword] = ACTIONS(8535),
    [sym_schema_keyword] = ACTIONS(8538),
    [sym_views_keyword] = ACTIONS(8541),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8544),
    [sym_preproc_open] = ACTIONS(8479),
    [sym_preproc_close] = ACTIONS(8482),
  },
  [STATE(3811)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3817),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3923),
    [sym_preproc_conditional_case_patterns] = STATE(3923),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3817),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3812)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3821),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3898),
    [sym_preproc_conditional_case_patterns] = STATE(3898),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3821),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3813)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3818),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3924),
    [sym_preproc_conditional_case_patterns] = STATE(3924),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3818),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3814)] = {
    [sym_boolean] = STATE(10026),
    [sym_option_member_list] = STATE(10077),
    [sym_option_member] = STATE(10017),
    [sym_keyword_identifier] = STATE(10026),
    [sym_codeunit_keyword] = STATE(10031),
    [sym_xmlport_keyword] = STATE(10031),
    [sym_enum_keyword] = STATE(10031),
    [sym_keyword_as_identifier] = STATE(10026),
    [aux_sym_option_member_list_repeat2] = STATE(3842),
    [sym_identifier] = ACTIONS(8547),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(8549),
    [anon_sym_DASH] = ACTIONS(8551),
    [aux_sym_boolean_token1] = ACTIONS(8553),
    [aux_sym_boolean_token2] = ACTIONS(8553),
    [aux_sym_where_condition_token1] = ACTIONS(8555),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8557),
    [aux_sym_record_type_token1] = ACTIONS(8557),
    [aux_sym_basic_type_token21] = ACTIONS(8557),
    [aux_sym_basic_type_token22] = ACTIONS(8559),
    [aux_sym_basic_type_token48] = ACTIONS(8557),
    [aux_sym_basic_type_token53] = ACTIONS(8555),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8555),
    [aux_sym_separator_action_token1] = ACTIONS(8555),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8555),
    [aux_sym_type_declaration_token1] = ACTIONS(8555),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(584),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [anon_sym_POUNDelif] = ACTIONS(582),
    [anon_sym_POUNDELIF] = ACTIONS(582),
    [anon_sym_POUNDElif] = ACTIONS(582),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [anon_sym_POUNDendif] = ACTIONS(582),
    [anon_sym_POUNDENDIF] = ACTIONS(582),
    [anon_sym_POUNDEndif] = ACTIONS(582),
    [anon_sym_POUNDendif2] = ACTIONS(582),
    [anon_sym_POUNDENDIF2] = ACTIONS(582),
    [anon_sym_POUNDEndif2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8557),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8557),
    [sym_table_keyword] = ACTIONS(8555),
    [sym_page_keyword] = ACTIONS(8557),
    [anon_sym_codeunit] = ACTIONS(8561),
    [anon_sym_CODEUNIT] = ACTIONS(8561),
    [anon_sym_Codeunit] = ACTIONS(8561),
    [anon_sym_CodeUnit] = ACTIONS(8561),
    [anon_sym_COdeunit] = ACTIONS(8561),
    [anon_sym_codeUnit] = ACTIONS(8561),
    [sym_report_keyword] = ACTIONS(8557),
    [sym_query_keyword] = ACTIONS(8557),
    [anon_sym_xmlport] = ACTIONS(8563),
    [anon_sym_XMLPORT] = ACTIONS(8563),
    [anon_sym_Xmlport] = ACTIONS(8563),
    [anon_sym_XMLport] = ACTIONS(8563),
    [anon_sym_XMLPort] = ACTIONS(8563),
    [anon_sym_XmlPort] = ACTIONS(8563),
    [anon_sym_enum] = ACTIONS(8565),
    [anon_sym_ENUM] = ACTIONS(8565),
    [anon_sym_Enum] = ACTIONS(8565),
    [anon_sym_eNUM] = ACTIONS(8565),
    [anon_sym_eNum] = ACTIONS(8565),
    [anon_sym_ENum] = ACTIONS(8565),
    [sym_var_keyword] = ACTIONS(584),
    [sym_local_keyword] = ACTIONS(8547),
    [sym_internal_keyword] = ACTIONS(8547),
    [sym_protected_keyword] = ACTIONS(8547),
    [sym_key_keyword] = ACTIONS(8555),
    [sym_dataset_keyword] = ACTIONS(8555),
    [sym_quoted_identifier] = ACTIONS(8567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8567),
    [sym_integer] = ACTIONS(8567),
    [sym_preproc_open] = ACTIONS(582),
    [sym_preproc_close] = ACTIONS(582),
    [sym_begin_keyword] = ACTIONS(582),
  },
  [STATE(3815)] = {
    [sym_boolean] = STATE(9829),
    [sym_option_member] = STATE(9828),
    [sym_keyword_identifier] = STATE(9829),
    [sym_codeunit_keyword] = STATE(9824),
    [sym_xmlport_keyword] = STATE(9824),
    [sym_enum_keyword] = STATE(9824),
    [sym_keyword_as_identifier] = STATE(9829),
    [sym_identifier] = ACTIONS(8337),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_RBRACE] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(8341),
    [aux_sym_boolean_token1] = ACTIONS(8343),
    [aux_sym_boolean_token2] = ACTIONS(8343),
    [aux_sym_where_condition_token1] = ACTIONS(8345),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8347),
    [anon_sym_LBRACK] = ACTIONS(611),
    [aux_sym_record_type_token1] = ACTIONS(8347),
    [aux_sym_basic_type_token21] = ACTIONS(8347),
    [aux_sym_basic_type_token22] = ACTIONS(8349),
    [aux_sym_basic_type_token48] = ACTIONS(8347),
    [aux_sym_basic_type_token53] = ACTIONS(8345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8569),
    [aux_sym_modify_modification_token1] = ACTIONS(613),
    [aux_sym_separator_action_token1] = ACTIONS(8345),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8569),
    [aux_sym_type_declaration_token1] = ACTIONS(8345),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(613),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8347),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8347),
    [sym_table_keyword] = ACTIONS(8345),
    [sym_page_keyword] = ACTIONS(8347),
    [anon_sym_codeunit] = ACTIONS(8351),
    [anon_sym_CODEUNIT] = ACTIONS(8351),
    [anon_sym_Codeunit] = ACTIONS(8351),
    [anon_sym_CodeUnit] = ACTIONS(8351),
    [anon_sym_COdeunit] = ACTIONS(8351),
    [anon_sym_codeUnit] = ACTIONS(8351),
    [sym_report_keyword] = ACTIONS(8347),
    [sym_query_keyword] = ACTIONS(8347),
    [anon_sym_xmlport] = ACTIONS(8353),
    [anon_sym_XMLPORT] = ACTIONS(8353),
    [anon_sym_Xmlport] = ACTIONS(8353),
    [anon_sym_XMLport] = ACTIONS(8353),
    [anon_sym_XMLPort] = ACTIONS(8353),
    [anon_sym_XmlPort] = ACTIONS(8353),
    [anon_sym_enum] = ACTIONS(8355),
    [anon_sym_ENUM] = ACTIONS(8355),
    [anon_sym_Enum] = ACTIONS(8355),
    [anon_sym_eNUM] = ACTIONS(8355),
    [anon_sym_eNum] = ACTIONS(8355),
    [anon_sym_ENum] = ACTIONS(8355),
    [sym_procedure_keyword] = ACTIONS(613),
    [sym_trigger_keyword] = ACTIONS(613),
    [sym_var_keyword] = ACTIONS(613),
    [sym_local_keyword] = ACTIONS(8572),
    [sym_internal_keyword] = ACTIONS(8572),
    [sym_protected_keyword] = ACTIONS(8572),
    [sym_event_keyword] = ACTIONS(613),
    [sym_fields_keyword] = ACTIONS(613),
    [sym_keys_keyword] = ACTIONS(613),
    [sym_key_keyword] = ACTIONS(8345),
    [sym_fieldgroups_keyword] = ACTIONS(613),
    [sym_actions_keyword] = ACTIONS(613),
    [sym_layout_keyword] = ACTIONS(613),
    [sym_dataset_keyword] = ACTIONS(8569),
    [sym_elements_keyword] = ACTIONS(613),
    [sym_labels_keyword] = ACTIONS(613),
    [sym_rendering_keyword] = ACTIONS(613),
    [sym_requestpage_keyword] = ACTIONS(613),
    [sym_schema_keyword] = ACTIONS(613),
    [sym_views_keyword] = ACTIONS(613),
    [sym_quoted_identifier] = ACTIONS(8357),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8357),
    [sym_integer] = ACTIONS(8357),
    [sym_property_name] = ACTIONS(611),
    [sym_preproc_open] = ACTIONS(611),
    [sym_begin_keyword] = ACTIONS(611),
  },
  [STATE(3816)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3817),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3919),
    [sym_preproc_conditional_case_patterns] = STATE(3919),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3817),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3817)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3817),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3935),
    [sym_preproc_conditional_case_patterns] = STATE(3935),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3817),
    [sym_identifier] = ACTIONS(6710),
    [anon_sym_DASH] = ACTIONS(6713),
    [aux_sym_boolean_token1] = ACTIONS(6716),
    [aux_sym_boolean_token2] = ACTIONS(6716),
    [sym_decimal] = ACTIONS(6719),
    [anon_sym_LPAREN] = ACTIONS(6722),
    [aux_sym_tabledata_permission_token2] = ACTIONS(6725),
    [anon_sym_LBRACK] = ACTIONS(6728),
    [aux_sym_record_type_token1] = ACTIONS(6725),
    [aux_sym_basic_type_token21] = ACTIONS(6725),
    [aux_sym_basic_type_token22] = ACTIONS(6725),
    [aux_sym_basic_type_token48] = ACTIONS(6725),
    [anon_sym_POUNDif] = ACTIONS(6731),
    [anon_sym_POUNDIF] = ACTIONS(6731),
    [anon_sym_POUNDIf] = ACTIONS(6731),
    [anon_sym_not] = ACTIONS(6734),
    [anon_sym_NOT] = ACTIONS(6734),
    [anon_sym_Not] = ACTIONS(6734),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(6725),
    [aux_sym_keyword_identifier_token2] = ACTIONS(6739),
    [anon_sym_PLUS] = ACTIONS(6713),
    [sym_datetime_literal] = ACTIONS(6742),
    [sym_date_literal] = ACTIONS(6719),
    [sym_time_literal] = ACTIONS(6719),
    [sym_biginteger_literal] = ACTIONS(6742),
    [sym_page_keyword] = ACTIONS(6739),
    [anon_sym_codeunit] = ACTIONS(6747),
    [anon_sym_CODEUNIT] = ACTIONS(6747),
    [anon_sym_Codeunit] = ACTIONS(6747),
    [anon_sym_CodeUnit] = ACTIONS(6747),
    [anon_sym_COdeunit] = ACTIONS(6747),
    [anon_sym_codeUnit] = ACTIONS(6747),
    [sym_report_keyword] = ACTIONS(6739),
    [sym_query_keyword] = ACTIONS(6739),
    [anon_sym_xmlport] = ACTIONS(6750),
    [anon_sym_XMLPORT] = ACTIONS(6750),
    [anon_sym_Xmlport] = ACTIONS(6750),
    [anon_sym_XMLport] = ACTIONS(6750),
    [anon_sym_XMLPort] = ACTIONS(6750),
    [anon_sym_XmlPort] = ACTIONS(6750),
    [anon_sym_enum] = ACTIONS(6753),
    [anon_sym_ENUM] = ACTIONS(6753),
    [anon_sym_Enum] = ACTIONS(6753),
    [anon_sym_eNUM] = ACTIONS(6753),
    [anon_sym_eNum] = ACTIONS(6753),
    [anon_sym_ENum] = ACTIONS(6753),
    [sym_quoted_identifier] = ACTIONS(6756),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6742),
    [sym_verbatim_string] = ACTIONS(6742),
    [sym_integer] = ACTIONS(6719),
    [sym_continue_as_identifier] = ACTIONS(6759),
    [sym_preproc_open] = ACTIONS(6731),
  },
  [STATE(3818)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3817),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3886),
    [sym_preproc_conditional_case_patterns] = STATE(3886),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3817),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3819)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3820),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3896),
    [sym_preproc_conditional_case_patterns] = STATE(3896),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3820),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3820)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3817),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3871),
    [sym_preproc_conditional_case_patterns] = STATE(3871),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3817),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3821)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3817),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3867),
    [sym_preproc_conditional_case_patterns] = STATE(3867),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3817),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3822)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3816),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3884),
    [sym_preproc_conditional_case_patterns] = STATE(3884),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3816),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3823)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3477),
    [sym_assignment_expression] = STATE(8793),
    [sym_case_branch] = STATE(3811),
    [sym_preproc_split_case_branch] = STATE(6559),
    [aux_sym__case_pattern] = STATE(3906),
    [sym_preproc_conditional_case_patterns] = STATE(3906),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [aux_sym_preproc_conditional_case_repeat1] = STATE(3811),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3824)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3910),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3856),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3825)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4949),
    [sym_preproc_endif] = STATE(7604),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [aux_sym_preproc_conditional_repeat1] = STATE(10912),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3826)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4962),
    [sym_preproc_endif] = STATE(6214),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [aux_sym_preproc_conditional_repeat1] = STATE(10989),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3827)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3879),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3849),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3828)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3901),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3829)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3902),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3844),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3830)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3905),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3831)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(7171),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3832)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(7172),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3845),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3833)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(7174),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3847),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3834)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4909),
    [sym_preproc_endif] = STATE(5175),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [aux_sym_preproc_conditional_repeat1] = STATE(10673),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3835)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3885),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3828),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3836)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3890),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3837)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(7170),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3831),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3838)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4923),
    [sym_preproc_endif] = STATE(5175),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [aux_sym_preproc_conditional_repeat1] = STATE(10853),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(3839)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3881),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3840)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(7162),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3841)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4926),
    [sym_preproc_endif] = STATE(7035),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [aux_sym_preproc_conditional_repeat1] = STATE(11012),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(3842)] = {
    [sym_boolean] = STATE(10026),
    [sym_option_member] = STATE(10016),
    [sym_keyword_identifier] = STATE(10026),
    [sym_codeunit_keyword] = STATE(10031),
    [sym_xmlport_keyword] = STATE(10031),
    [sym_enum_keyword] = STATE(10031),
    [sym_keyword_as_identifier] = STATE(10026),
    [aux_sym_option_member_list_repeat2] = STATE(4155),
    [sym_identifier] = ACTIONS(8547),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(8575),
    [anon_sym_DASH] = ACTIONS(8551),
    [aux_sym_boolean_token1] = ACTIONS(8553),
    [aux_sym_boolean_token2] = ACTIONS(8553),
    [aux_sym_where_condition_token1] = ACTIONS(8555),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8557),
    [aux_sym_record_type_token1] = ACTIONS(8557),
    [aux_sym_basic_type_token21] = ACTIONS(8557),
    [aux_sym_basic_type_token22] = ACTIONS(8559),
    [aux_sym_basic_type_token48] = ACTIONS(8557),
    [aux_sym_basic_type_token53] = ACTIONS(8555),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8555),
    [aux_sym_separator_action_token1] = ACTIONS(8555),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8555),
    [aux_sym_type_declaration_token1] = ACTIONS(8555),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8557),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8557),
    [sym_table_keyword] = ACTIONS(8555),
    [sym_page_keyword] = ACTIONS(8557),
    [anon_sym_codeunit] = ACTIONS(8561),
    [anon_sym_CODEUNIT] = ACTIONS(8561),
    [anon_sym_Codeunit] = ACTIONS(8561),
    [anon_sym_CodeUnit] = ACTIONS(8561),
    [anon_sym_COdeunit] = ACTIONS(8561),
    [anon_sym_codeUnit] = ACTIONS(8561),
    [sym_report_keyword] = ACTIONS(8557),
    [sym_query_keyword] = ACTIONS(8557),
    [anon_sym_xmlport] = ACTIONS(8563),
    [anon_sym_XMLPORT] = ACTIONS(8563),
    [anon_sym_Xmlport] = ACTIONS(8563),
    [anon_sym_XMLport] = ACTIONS(8563),
    [anon_sym_XMLPort] = ACTIONS(8563),
    [anon_sym_XmlPort] = ACTIONS(8563),
    [anon_sym_enum] = ACTIONS(8565),
    [anon_sym_ENUM] = ACTIONS(8565),
    [anon_sym_Enum] = ACTIONS(8565),
    [anon_sym_eNUM] = ACTIONS(8565),
    [anon_sym_eNum] = ACTIONS(8565),
    [anon_sym_ENum] = ACTIONS(8565),
    [sym_var_keyword] = ACTIONS(602),
    [sym_local_keyword] = ACTIONS(8547),
    [sym_internal_keyword] = ACTIONS(8547),
    [sym_protected_keyword] = ACTIONS(8547),
    [sym_key_keyword] = ACTIONS(8555),
    [sym_dataset_keyword] = ACTIONS(8555),
    [sym_quoted_identifier] = ACTIONS(8567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8567),
    [sym_integer] = ACTIONS(8567),
    [sym_preproc_open] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
    [sym_begin_keyword] = ACTIONS(600),
  },
  [STATE(3843)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4945),
    [sym_preproc_endif] = STATE(6214),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [aux_sym_preproc_conditional_repeat1] = STATE(10874),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(3844)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3948),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3845)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(7182),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3846)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(7166),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3840),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3847)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(7168),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3848)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3945),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3849)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3911),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3850)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3912),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3852),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3851)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3914),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3854),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3852)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3915),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3853)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3916),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3855),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3854)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3917),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3855)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3918),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3856)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3938),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3857)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3939),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3859),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3858)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3941),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3861),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3859)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3942),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3860)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3943),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3848),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3861)] = {
    [sym_boolean] = STATE(3032),
    [sym_preproc_endif] = STATE(3944),
    [sym_assignment_expression] = STATE(8844),
    [sym__single_pattern] = STATE(5330),
    [sym__expression] = STATE(8844),
    [sym_keyword_identifier] = STATE(2738),
    [sym_range_expression] = STATE(3032),
    [sym_multiplicative_expression] = STATE(3032),
    [sym_additive_expression] = STATE(3032),
    [sym_comparison_expression] = STATE(3032),
    [sym_logical_expression] = STATE(3032),
    [sym_ternary_expression] = STATE(8844),
    [sym_unary_expression] = STATE(3032),
    [sym_call_expression] = STATE(2783),
    [sym_member_expression] = STATE(2738),
    [sym_subscript_expression] = STATE(2738),
    [sym_parenthesized_expression] = STATE(3032),
    [sym_list_literal] = STATE(8844),
    [sym_qualified_enum_value] = STATE(2738),
    [sym_database_reference] = STATE(3032),
    [sym__literal_value] = STATE(3032),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [aux_sym_preproc_split_case_branch_repeat1] = STATE(3592),
    [sym_identifier] = ACTIONS(7491),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(7495),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [anon_sym_POUNDendif] = ACTIONS(81),
    [anon_sym_POUNDENDIF] = ACTIONS(81),
    [anon_sym_POUNDEndif] = ACTIONS(81),
    [anon_sym_POUNDendif2] = ACTIONS(81),
    [anon_sym_POUNDENDIF2] = ACTIONS(81),
    [anon_sym_POUNDEndif2] = ACTIONS(81),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(7507),
    [sym_date_literal] = ACTIONS(7495),
    [sym_time_literal] = ACTIONS(7495),
    [sym_biginteger_literal] = ACTIONS(7507),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(7509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7507),
    [sym_verbatim_string] = ACTIONS(7507),
    [sym_integer] = ACTIONS(7495),
    [sym_continue_as_identifier] = ACTIONS(7511),
    [sym_preproc_close] = ACTIONS(81),
  },
  [STATE(3862)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_elif] = STATE(4002),
    [sym_preproc_else] = STATE(4957),
    [sym_preproc_endif] = STATE(9506),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [aux_sym_preproc_conditional_repeat1] = STATE(10722),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(4220),
    [anon_sym_POUNDELIF] = ACTIONS(4220),
    [anon_sym_POUNDElif] = ACTIONS(4220),
    [anon_sym_POUNDelse] = ACTIONS(4222),
    [anon_sym_POUNDELSE] = ACTIONS(4222),
    [anon_sym_POUNDElse] = ACTIONS(4222),
    [anon_sym_POUNDelse2] = ACTIONS(4222),
    [anon_sym_POUNDELSE2] = ACTIONS(4222),
    [anon_sym_POUNDElse2] = ACTIONS(4222),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3863)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8577),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3864)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8579),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3865)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8581),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3866)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8583),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3867)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8585),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3868)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8587),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3869)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8589),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3870)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8591),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3871)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8593),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3872)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8595),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3873)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8597),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3874)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8599),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3875)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8601),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3876)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8603),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3877)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8605),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3878)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(8607),
    [anon_sym_COLON] = ACTIONS(8610),
    [anon_sym_DASH] = ACTIONS(8612),
    [aux_sym_boolean_token1] = ACTIONS(8615),
    [aux_sym_boolean_token2] = ACTIONS(8615),
    [sym_decimal] = ACTIONS(8618),
    [anon_sym_LPAREN] = ACTIONS(8621),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8624),
    [anon_sym_LBRACK] = ACTIONS(8627),
    [aux_sym_record_type_token1] = ACTIONS(8624),
    [aux_sym_basic_type_token21] = ACTIONS(8624),
    [aux_sym_basic_type_token22] = ACTIONS(8624),
    [aux_sym_basic_type_token48] = ACTIONS(8624),
    [anon_sym_POUNDif] = ACTIONS(8630),
    [anon_sym_POUNDIF] = ACTIONS(8630),
    [anon_sym_POUNDIf] = ACTIONS(8630),
    [anon_sym_not] = ACTIONS(8633),
    [anon_sym_NOT] = ACTIONS(8633),
    [anon_sym_Not] = ACTIONS(8633),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8624),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8636),
    [anon_sym_PLUS] = ACTIONS(8612),
    [sym_datetime_literal] = ACTIONS(8639),
    [sym_date_literal] = ACTIONS(8618),
    [sym_time_literal] = ACTIONS(8618),
    [sym_biginteger_literal] = ACTIONS(8639),
    [sym_page_keyword] = ACTIONS(8636),
    [anon_sym_codeunit] = ACTIONS(8642),
    [anon_sym_CODEUNIT] = ACTIONS(8642),
    [anon_sym_Codeunit] = ACTIONS(8642),
    [anon_sym_CodeUnit] = ACTIONS(8642),
    [anon_sym_COdeunit] = ACTIONS(8642),
    [anon_sym_codeUnit] = ACTIONS(8642),
    [sym_report_keyword] = ACTIONS(8636),
    [sym_query_keyword] = ACTIONS(8636),
    [anon_sym_xmlport] = ACTIONS(8645),
    [anon_sym_XMLPORT] = ACTIONS(8645),
    [anon_sym_Xmlport] = ACTIONS(8645),
    [anon_sym_XMLport] = ACTIONS(8645),
    [anon_sym_XMLPort] = ACTIONS(8645),
    [anon_sym_XmlPort] = ACTIONS(8645),
    [anon_sym_enum] = ACTIONS(8648),
    [anon_sym_ENUM] = ACTIONS(8648),
    [anon_sym_Enum] = ACTIONS(8648),
    [anon_sym_eNUM] = ACTIONS(8648),
    [anon_sym_eNum] = ACTIONS(8648),
    [anon_sym_ENum] = ACTIONS(8648),
    [sym_quoted_identifier] = ACTIONS(8651),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8639),
    [sym_verbatim_string] = ACTIONS(8639),
    [sym_integer] = ACTIONS(8618),
    [sym_continue_as_identifier] = ACTIONS(8654),
    [sym_preproc_open] = ACTIONS(8630),
  },
  [STATE(3879)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3951),
    [sym_preproc_conditional_case_patterns] = STATE(3951),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8385),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3880)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8657),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3881)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3895),
    [sym_preproc_conditional_case_patterns] = STATE(3895),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8659),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3882)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8661),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3883)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3866),
    [sym_preproc_conditional_case_patterns] = STATE(3866),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8408),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3884)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8663),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3885)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3900),
    [sym_preproc_conditional_case_patterns] = STATE(3900),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8665),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3886)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8667),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3887)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8669),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3888)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8671),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3889)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3903),
    [sym_preproc_conditional_case_patterns] = STATE(3903),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8673),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3890)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3904),
    [sym_preproc_conditional_case_patterns] = STATE(3904),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8665),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3891)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8675),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3892)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8677),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3893)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8679),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3894)] = {
    [sym_preproc_conditional_controladdin] = STATE(3956),
    [sym__body_element] = STATE(8196),
    [sym_empty_statement] = STATE(8196),
    [sym_property] = STATE(8196),
    [sym_permissions_property] = STATE(8196),
    [sym_table_relation_property] = STATE(8196),
    [sym_fields_section] = STATE(8196),
    [sym_keys_section] = STATE(8196),
    [sym_fieldgroups_section] = STATE(8196),
    [sym_enum_value_declaration] = STATE(8196),
    [sym_labels_section] = STATE(8196),
    [sym_layout_section] = STATE(8196),
    [sym_modify_modification] = STATE(8196),
    [sym_actions_section] = STATE(8196),
    [sym_views_section] = STATE(8196),
    [sym_dataset_section] = STATE(8196),
    [sym_requestpage_section] = STATE(8196),
    [sym_rendering_section] = STATE(8196),
    [sym_elements_section] = STATE(8196),
    [sym_schema_section] = STATE(8196),
    [sym_assembly_declaration] = STATE(8196),
    [sym_event_declaration] = STATE(8196),
    [sym_procedure] = STATE(8196),
    [sym_preproc_split_procedure] = STATE(8196),
    [sym_preproc_split_procedure_preamble] = STATE(8196),
    [sym_interface_procedure] = STATE(3956),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8196),
    [sym_var_section] = STATE(8196),
    [sym_attribute_item] = STATE(8196),
    [sym_preproc_conditional] = STATE(8196),
    [sym_preproc_if] = STATE(3593),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4033),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3956),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8681),
    [anon_sym_POUNDELIF] = ACTIONS(8681),
    [anon_sym_POUNDElif] = ACTIONS(8681),
    [anon_sym_POUNDelse] = ACTIONS(8681),
    [anon_sym_POUNDELSE] = ACTIONS(8681),
    [anon_sym_POUNDElse] = ACTIONS(8681),
    [anon_sym_POUNDelse2] = ACTIONS(8681),
    [anon_sym_POUNDELSE2] = ACTIONS(8681),
    [anon_sym_POUNDElse2] = ACTIONS(8681),
    [anon_sym_POUNDendif] = ACTIONS(8681),
    [anon_sym_POUNDENDIF] = ACTIONS(8681),
    [anon_sym_POUNDEndif] = ACTIONS(8681),
    [anon_sym_POUNDendif2] = ACTIONS(8681),
    [anon_sym_POUNDENDIF2] = ACTIONS(8681),
    [anon_sym_POUNDEndif2] = ACTIONS(8681),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8681),
  },
  [STATE(3895)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8684),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3896)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8686),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3897)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3887),
    [sym_preproc_conditional_case_patterns] = STATE(3887),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8688),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3898)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8690),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3899)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3891),
    [sym_preproc_conditional_case_patterns] = STATE(3891),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8688),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3900)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8692),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3901)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3928),
    [sym_preproc_conditional_case_patterns] = STATE(3928),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8694),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3902)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3947),
    [sym_preproc_conditional_case_patterns] = STATE(3947),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8696),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3903)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8698),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3904)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8700),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3905)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3882),
    [sym_preproc_conditional_case_patterns] = STATE(3882),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8694),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3906)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8702),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3907)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3920),
    [sym_preproc_conditional_case_patterns] = STATE(3920),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8408),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3908)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3868),
    [sym_preproc_conditional_case_patterns] = STATE(3868),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8688),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3909)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3869),
    [sym_preproc_conditional_case_patterns] = STATE(3869),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8688),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3910)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3921),
    [sym_preproc_conditional_case_patterns] = STATE(3921),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8385),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3911)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3870),
    [sym_preproc_conditional_case_patterns] = STATE(3870),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8659),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3912)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3863),
    [sym_preproc_conditional_case_patterns] = STATE(3863),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8665),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3913)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3872),
    [sym_preproc_conditional_case_patterns] = STATE(3872),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8673),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3914)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3873),
    [sym_preproc_conditional_case_patterns] = STATE(3873),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8665),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3915)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3874),
    [sym_preproc_conditional_case_patterns] = STATE(3874),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8694),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3916)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3875),
    [sym_preproc_conditional_case_patterns] = STATE(3875),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8696),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3917)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3876),
    [sym_preproc_conditional_case_patterns] = STATE(3876),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8694),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3918)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3877),
    [sym_preproc_conditional_case_patterns] = STATE(3877),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8704),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3919)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8706),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3920)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8708),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3921)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8710),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3922)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8712),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3923)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8714),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3924)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8716),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3925)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8718),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3926)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8720),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3927)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8722),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3928)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8724),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3929)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8726),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3930)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8728),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3931)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8730),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3932)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8732),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3933)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8734),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3934)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8736),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3935)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8738),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3936)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3922),
    [sym_preproc_conditional_case_patterns] = STATE(3922),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8688),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3937)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3925),
    [sym_preproc_conditional_case_patterns] = STATE(3925),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8688),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3938)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3926),
    [sym_preproc_conditional_case_patterns] = STATE(3926),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8659),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3939)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3927),
    [sym_preproc_conditional_case_patterns] = STATE(3927),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8665),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3940)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3929),
    [sym_preproc_conditional_case_patterns] = STATE(3929),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8673),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3941)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3930),
    [sym_preproc_conditional_case_patterns] = STATE(3930),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8665),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3942)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3931),
    [sym_preproc_conditional_case_patterns] = STATE(3931),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8694),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3943)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3932),
    [sym_preproc_conditional_case_patterns] = STATE(3932),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8696),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3944)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3933),
    [sym_preproc_conditional_case_patterns] = STATE(3933),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8694),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3945)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3934),
    [sym_preproc_conditional_case_patterns] = STATE(3934),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8704),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3946)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8740),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3947)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8742),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3948)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3946),
    [sym_preproc_conditional_case_patterns] = STATE(3946),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8704),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3949)] = {
    [sym_boolean] = STATE(10026),
    [sym_option_member] = STATE(10038),
    [sym_keyword_identifier] = STATE(10026),
    [sym_codeunit_keyword] = STATE(10031),
    [sym_xmlport_keyword] = STATE(10031),
    [sym_enum_keyword] = STATE(10031),
    [sym_keyword_as_identifier] = STATE(10026),
    [sym_identifier] = ACTIONS(8547),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(8551),
    [aux_sym_boolean_token1] = ACTIONS(8553),
    [aux_sym_boolean_token2] = ACTIONS(8553),
    [aux_sym_where_condition_token1] = ACTIONS(8555),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8557),
    [aux_sym_record_type_token1] = ACTIONS(8557),
    [aux_sym_basic_type_token21] = ACTIONS(8557),
    [aux_sym_basic_type_token22] = ACTIONS(8559),
    [aux_sym_basic_type_token48] = ACTIONS(8557),
    [aux_sym_basic_type_token53] = ACTIONS(8555),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8555),
    [aux_sym_separator_action_token1] = ACTIONS(8555),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8555),
    [aux_sym_type_declaration_token1] = ACTIONS(8555),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(613),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [anon_sym_POUNDelif] = ACTIONS(611),
    [anon_sym_POUNDELIF] = ACTIONS(611),
    [anon_sym_POUNDElif] = ACTIONS(611),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [anon_sym_POUNDendif] = ACTIONS(611),
    [anon_sym_POUNDENDIF] = ACTIONS(611),
    [anon_sym_POUNDEndif] = ACTIONS(611),
    [anon_sym_POUNDendif2] = ACTIONS(611),
    [anon_sym_POUNDENDIF2] = ACTIONS(611),
    [anon_sym_POUNDEndif2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8557),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8557),
    [sym_table_keyword] = ACTIONS(8555),
    [sym_page_keyword] = ACTIONS(8557),
    [anon_sym_codeunit] = ACTIONS(8561),
    [anon_sym_CODEUNIT] = ACTIONS(8561),
    [anon_sym_Codeunit] = ACTIONS(8561),
    [anon_sym_CodeUnit] = ACTIONS(8561),
    [anon_sym_COdeunit] = ACTIONS(8561),
    [anon_sym_codeUnit] = ACTIONS(8561),
    [sym_report_keyword] = ACTIONS(8557),
    [sym_query_keyword] = ACTIONS(8557),
    [anon_sym_xmlport] = ACTIONS(8563),
    [anon_sym_XMLPORT] = ACTIONS(8563),
    [anon_sym_Xmlport] = ACTIONS(8563),
    [anon_sym_XMLport] = ACTIONS(8563),
    [anon_sym_XMLPort] = ACTIONS(8563),
    [anon_sym_XmlPort] = ACTIONS(8563),
    [anon_sym_enum] = ACTIONS(8565),
    [anon_sym_ENUM] = ACTIONS(8565),
    [anon_sym_Enum] = ACTIONS(8565),
    [anon_sym_eNUM] = ACTIONS(8565),
    [anon_sym_eNum] = ACTIONS(8565),
    [anon_sym_ENum] = ACTIONS(8565),
    [sym_var_keyword] = ACTIONS(613),
    [sym_local_keyword] = ACTIONS(8744),
    [sym_internal_keyword] = ACTIONS(8547),
    [sym_protected_keyword] = ACTIONS(8744),
    [sym_key_keyword] = ACTIONS(8555),
    [sym_dataset_keyword] = ACTIONS(8555),
    [sym_quoted_identifier] = ACTIONS(8567),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8567),
    [sym_integer] = ACTIONS(8567),
    [sym_preproc_open] = ACTIONS(611),
    [sym_preproc_close] = ACTIONS(611),
    [sym_begin_keyword] = ACTIONS(611),
  },
  [STATE(3950)] = {
    [sym_boolean] = STATE(10130),
    [sym_option_member_list] = STATE(10229),
    [sym_option_member] = STATE(10070),
    [sym_keyword_identifier] = STATE(10130),
    [sym_codeunit_keyword] = STATE(10164),
    [sym_xmlport_keyword] = STATE(10164),
    [sym_enum_keyword] = STATE(10164),
    [sym_keyword_as_identifier] = STATE(10130),
    [aux_sym_option_member_list_repeat2] = STATE(3960),
    [sym_identifier] = ACTIONS(8747),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(8749),
    [anon_sym_DASH] = ACTIONS(8751),
    [aux_sym_boolean_token1] = ACTIONS(8753),
    [aux_sym_boolean_token2] = ACTIONS(8753),
    [aux_sym_where_condition_token1] = ACTIONS(8755),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8757),
    [aux_sym_record_type_token1] = ACTIONS(8757),
    [aux_sym_basic_type_token21] = ACTIONS(8757),
    [aux_sym_basic_type_token22] = ACTIONS(8759),
    [aux_sym_basic_type_token48] = ACTIONS(8757),
    [aux_sym_basic_type_token53] = ACTIONS(8755),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8755),
    [aux_sym_separator_action_token1] = ACTIONS(8755),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8755),
    [aux_sym_type_declaration_token1] = ACTIONS(8755),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [anon_sym_POUNDelif] = ACTIONS(582),
    [anon_sym_POUNDELIF] = ACTIONS(582),
    [anon_sym_POUNDElif] = ACTIONS(582),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [anon_sym_POUNDendif] = ACTIONS(582),
    [anon_sym_POUNDENDIF] = ACTIONS(582),
    [anon_sym_POUNDEndif] = ACTIONS(582),
    [anon_sym_POUNDendif2] = ACTIONS(582),
    [anon_sym_POUNDENDIF2] = ACTIONS(582),
    [anon_sym_POUNDEndif2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8757),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8757),
    [sym_table_keyword] = ACTIONS(8755),
    [sym_page_keyword] = ACTIONS(8757),
    [anon_sym_codeunit] = ACTIONS(8761),
    [anon_sym_CODEUNIT] = ACTIONS(8761),
    [anon_sym_Codeunit] = ACTIONS(8761),
    [anon_sym_CodeUnit] = ACTIONS(8761),
    [anon_sym_COdeunit] = ACTIONS(8761),
    [anon_sym_codeUnit] = ACTIONS(8761),
    [sym_report_keyword] = ACTIONS(8757),
    [sym_query_keyword] = ACTIONS(8757),
    [anon_sym_xmlport] = ACTIONS(8763),
    [anon_sym_XMLPORT] = ACTIONS(8763),
    [anon_sym_Xmlport] = ACTIONS(8763),
    [anon_sym_XMLport] = ACTIONS(8763),
    [anon_sym_XMLPort] = ACTIONS(8763),
    [anon_sym_XmlPort] = ACTIONS(8763),
    [anon_sym_enum] = ACTIONS(8765),
    [anon_sym_ENUM] = ACTIONS(8765),
    [anon_sym_Enum] = ACTIONS(8765),
    [anon_sym_eNUM] = ACTIONS(8765),
    [anon_sym_eNum] = ACTIONS(8765),
    [anon_sym_ENum] = ACTIONS(8765),
    [sym_var_keyword] = ACTIONS(584),
    [sym_local_keyword] = ACTIONS(8747),
    [sym_internal_keyword] = ACTIONS(8747),
    [sym_protected_keyword] = ACTIONS(8747),
    [sym_key_keyword] = ACTIONS(8755),
    [sym_dataset_keyword] = ACTIONS(8755),
    [sym_quoted_identifier] = ACTIONS(8767),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8767),
    [sym_integer] = ACTIONS(8767),
    [sym_preproc_open] = ACTIONS(582),
    [sym_preproc_close] = ACTIONS(582),
  },
  [STATE(3951)] = {
    [sym_boolean] = STATE(3608),
    [sym_preproc_if] = STATE(3480),
    [sym_assignment_expression] = STATE(8793),
    [aux_sym__case_pattern] = STATE(3878),
    [sym_preproc_conditional_case_patterns] = STATE(3878),
    [sym__single_pattern] = STATE(7125),
    [sym__expression] = STATE(8793),
    [sym_keyword_identifier] = STATE(3591),
    [sym_range_expression] = STATE(3608),
    [sym_multiplicative_expression] = STATE(3608),
    [sym_additive_expression] = STATE(3608),
    [sym_comparison_expression] = STATE(3608),
    [sym_logical_expression] = STATE(3608),
    [sym_ternary_expression] = STATE(8793),
    [sym_unary_expression] = STATE(3608),
    [sym_call_expression] = STATE(3597),
    [sym_member_expression] = STATE(3591),
    [sym_subscript_expression] = STATE(3591),
    [sym_parenthesized_expression] = STATE(3608),
    [sym_list_literal] = STATE(8793),
    [sym_qualified_enum_value] = STATE(3591),
    [sym_database_reference] = STATE(3608),
    [sym__literal_value] = STATE(3608),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(8769),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(5421),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_POUNDif] = ACTIONS(5344),
    [anon_sym_POUNDIF] = ACTIONS(5344),
    [anon_sym_POUNDIf] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(5423),
    [sym_date_literal] = ACTIONS(5421),
    [sym_time_literal] = ACTIONS(5421),
    [sym_biginteger_literal] = ACTIONS(5423),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5423),
    [sym_verbatim_string] = ACTIONS(5423),
    [sym_integer] = ACTIONS(5421),
    [sym_continue_as_identifier] = ACTIONS(5427),
    [sym_preproc_open] = ACTIONS(5344),
  },
  [STATE(3952)] = {
    [sym_preproc_conditional_permissions] = STATE(3953),
    [sym_tabledata_permission] = STATE(4228),
    [sym_preproc_if] = STATE(7962),
    [sym_codeunit_keyword] = STATE(11321),
    [sym_xmlport_keyword] = STATE(11321),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(3953),
    [sym_identifier] = ACTIONS(7848),
    [anon_sym_SEMI] = ACTIONS(7846),
    [aux_sym_where_condition_token1] = ACTIONS(7848),
    [aux_sym_tabledata_permission_token1] = ACTIONS(4019),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4019),
    [anon_sym_LBRACK] = ACTIONS(7846),
    [aux_sym_basic_type_token22] = ACTIONS(7848),
    [aux_sym_basic_type_token53] = ACTIONS(7848),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7848),
    [aux_sym_modify_modification_token1] = ACTIONS(7848),
    [aux_sym_separator_action_token1] = ACTIONS(7848),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7848),
    [aux_sym_type_declaration_token1] = ACTIONS(7848),
    [anon_sym_POUNDif] = ACTIONS(7852),
    [anon_sym_POUNDIF] = ACTIONS(7852),
    [anon_sym_POUNDIf] = ACTIONS(7852),
    [anon_sym_POUNDelif] = ACTIONS(7846),
    [anon_sym_POUNDELIF] = ACTIONS(7846),
    [anon_sym_POUNDElif] = ACTIONS(7846),
    [anon_sym_POUNDelse] = ACTIONS(7846),
    [anon_sym_POUNDELSE] = ACTIONS(7846),
    [anon_sym_POUNDElse] = ACTIONS(7846),
    [anon_sym_POUNDelse2] = ACTIONS(7846),
    [anon_sym_POUNDELSE2] = ACTIONS(7846),
    [anon_sym_POUNDElse2] = ACTIONS(7846),
    [anon_sym_POUNDendif] = ACTIONS(7846),
    [anon_sym_POUNDENDIF] = ACTIONS(7846),
    [anon_sym_POUNDEndif] = ACTIONS(7846),
    [anon_sym_POUNDendif2] = ACTIONS(7846),
    [anon_sym_POUNDENDIF2] = ACTIONS(7846),
    [anon_sym_POUNDEndif2] = ACTIONS(7846),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8771),
    [sym_page_keyword] = ACTIONS(4019),
    [anon_sym_codeunit] = ACTIONS(8774),
    [anon_sym_CODEUNIT] = ACTIONS(8774),
    [anon_sym_Codeunit] = ACTIONS(8774),
    [anon_sym_CodeUnit] = ACTIONS(8774),
    [anon_sym_COdeunit] = ACTIONS(8774),
    [anon_sym_codeUnit] = ACTIONS(8774),
    [sym_report_keyword] = ACTIONS(4019),
    [sym_query_keyword] = ACTIONS(4019),
    [anon_sym_xmlport] = ACTIONS(8776),
    [anon_sym_XMLPORT] = ACTIONS(8776),
    [anon_sym_Xmlport] = ACTIONS(8776),
    [anon_sym_XMLport] = ACTIONS(8776),
    [anon_sym_XMLPort] = ACTIONS(8776),
    [anon_sym_XmlPort] = ACTIONS(8776),
    [sym_procedure_keyword] = ACTIONS(7848),
    [sym_trigger_keyword] = ACTIONS(7848),
    [sym_var_keyword] = ACTIONS(7848),
    [sym_local_keyword] = ACTIONS(7848),
    [sym_internal_keyword] = ACTIONS(7848),
    [sym_protected_keyword] = ACTIONS(7848),
    [sym_event_keyword] = ACTIONS(7848),
    [sym_fields_keyword] = ACTIONS(7848),
    [sym_keys_keyword] = ACTIONS(7848),
    [sym_key_keyword] = ACTIONS(7848),
    [sym_fieldgroups_keyword] = ACTIONS(7848),
    [sym_actions_keyword] = ACTIONS(7848),
    [sym_layout_keyword] = ACTIONS(7848),
    [sym_dataset_keyword] = ACTIONS(7848),
    [sym_elements_keyword] = ACTIONS(7848),
    [sym_labels_keyword] = ACTIONS(7848),
    [sym_rendering_keyword] = ACTIONS(7848),
    [sym_requestpage_keyword] = ACTIONS(7848),
    [sym_schema_keyword] = ACTIONS(7848),
    [sym_views_keyword] = ACTIONS(7848),
    [sym_quoted_identifier] = ACTIONS(7846),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7846),
    [sym_preproc_open] = ACTIONS(7852),
    [sym_preproc_close] = ACTIONS(7846),
    [sym_var_attribute_open] = ACTIONS(7846),
  },
  [STATE(3953)] = {
    [sym_preproc_conditional_permissions] = STATE(3953),
    [sym_tabledata_permission] = STATE(4228),
    [sym_preproc_if] = STATE(7962),
    [sym_codeunit_keyword] = STATE(11321),
    [sym_xmlport_keyword] = STATE(11321),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(3953),
    [sym_identifier] = ACTIONS(7787),
    [anon_sym_SEMI] = ACTIONS(7785),
    [aux_sym_where_condition_token1] = ACTIONS(7787),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8778),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_basic_type_token22] = ACTIONS(7787),
    [aux_sym_basic_type_token53] = ACTIONS(7787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7787),
    [aux_sym_modify_modification_token1] = ACTIONS(7787),
    [aux_sym_separator_action_token1] = ACTIONS(7787),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7787),
    [aux_sym_type_declaration_token1] = ACTIONS(7787),
    [anon_sym_POUNDif] = ACTIONS(7795),
    [anon_sym_POUNDIF] = ACTIONS(7795),
    [anon_sym_POUNDIf] = ACTIONS(7795),
    [anon_sym_POUNDelif] = ACTIONS(7785),
    [anon_sym_POUNDELIF] = ACTIONS(7785),
    [anon_sym_POUNDElif] = ACTIONS(7785),
    [anon_sym_POUNDelse] = ACTIONS(7785),
    [anon_sym_POUNDELSE] = ACTIONS(7785),
    [anon_sym_POUNDElse] = ACTIONS(7785),
    [anon_sym_POUNDelse2] = ACTIONS(7785),
    [anon_sym_POUNDELSE2] = ACTIONS(7785),
    [anon_sym_POUNDElse2] = ACTIONS(7785),
    [anon_sym_POUNDendif] = ACTIONS(7785),
    [anon_sym_POUNDENDIF] = ACTIONS(7785),
    [anon_sym_POUNDEndif] = ACTIONS(7785),
    [anon_sym_POUNDendif2] = ACTIONS(7785),
    [anon_sym_POUNDENDIF2] = ACTIONS(7785),
    [anon_sym_POUNDEndif2] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8778),
    [sym_page_keyword] = ACTIONS(8778),
    [anon_sym_codeunit] = ACTIONS(8781),
    [anon_sym_CODEUNIT] = ACTIONS(8781),
    [anon_sym_Codeunit] = ACTIONS(8781),
    [anon_sym_CodeUnit] = ACTIONS(8781),
    [anon_sym_COdeunit] = ACTIONS(8781),
    [anon_sym_codeUnit] = ACTIONS(8781),
    [sym_report_keyword] = ACTIONS(8778),
    [sym_query_keyword] = ACTIONS(8778),
    [anon_sym_xmlport] = ACTIONS(8784),
    [anon_sym_XMLPORT] = ACTIONS(8784),
    [anon_sym_Xmlport] = ACTIONS(8784),
    [anon_sym_XMLport] = ACTIONS(8784),
    [anon_sym_XMLPort] = ACTIONS(8784),
    [anon_sym_XmlPort] = ACTIONS(8784),
    [sym_procedure_keyword] = ACTIONS(7787),
    [sym_trigger_keyword] = ACTIONS(7787),
    [sym_var_keyword] = ACTIONS(7787),
    [sym_local_keyword] = ACTIONS(7787),
    [sym_internal_keyword] = ACTIONS(7787),
    [sym_protected_keyword] = ACTIONS(7787),
    [sym_event_keyword] = ACTIONS(7787),
    [sym_fields_keyword] = ACTIONS(7787),
    [sym_keys_keyword] = ACTIONS(7787),
    [sym_key_keyword] = ACTIONS(7787),
    [sym_fieldgroups_keyword] = ACTIONS(7787),
    [sym_actions_keyword] = ACTIONS(7787),
    [sym_layout_keyword] = ACTIONS(7787),
    [sym_dataset_keyword] = ACTIONS(7787),
    [sym_elements_keyword] = ACTIONS(7787),
    [sym_labels_keyword] = ACTIONS(7787),
    [sym_rendering_keyword] = ACTIONS(7787),
    [sym_requestpage_keyword] = ACTIONS(7787),
    [sym_schema_keyword] = ACTIONS(7787),
    [sym_views_keyword] = ACTIONS(7787),
    [sym_quoted_identifier] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7795),
    [sym_preproc_close] = ACTIONS(7785),
    [sym_var_attribute_open] = ACTIONS(7785),
  },
  [STATE(3954)] = {
    [sym__body_element] = STATE(7554),
    [sym_empty_statement] = STATE(7554),
    [sym_property] = STATE(7554),
    [sym_permissions_property] = STATE(7554),
    [sym_table_relation_property] = STATE(7554),
    [sym_fields_section] = STATE(7554),
    [sym_keys_section] = STATE(7554),
    [sym_fieldgroups_section] = STATE(7554),
    [sym_enum_value_declaration] = STATE(7554),
    [sym_labels_section] = STATE(7554),
    [sym_layout_section] = STATE(7554),
    [sym_modify_modification] = STATE(7554),
    [sym_actions_section] = STATE(7554),
    [sym_views_section] = STATE(7554),
    [sym_dataset_section] = STATE(7554),
    [sym_requestpage_section] = STATE(7554),
    [sym_rendering_section] = STATE(7554),
    [sym_elements_section] = STATE(7554),
    [sym_schema_section] = STATE(7554),
    [sym_xmlport_element] = STATE(3964),
    [sym__xmlport_body_element] = STATE(3964),
    [sym_preproc_conditional_xmlport] = STATE(3964),
    [sym_xmlport_attribute] = STATE(3964),
    [sym_assembly_declaration] = STATE(7554),
    [sym_event_declaration] = STATE(7554),
    [sym_procedure] = STATE(7554),
    [sym_preproc_split_procedure] = STATE(7554),
    [sym_preproc_split_procedure_preamble] = STATE(7554),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(7554),
    [sym_var_section] = STATE(7554),
    [sym_attribute_item] = STATE(7554),
    [sym_preproc_conditional] = STATE(7554),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(7527),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4948),
    [aux_sym_xmlport_element_repeat1] = STATE(3964),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3955)] = {
    [anon_sym_RBRACE] = ACTIONS(7420),
    [aux_sym_where_condition_token1] = ACTIONS(7420),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7420),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7420),
    [aux_sym_basic_type_token6] = ACTIONS(7420),
    [aux_sym_addafter_modification_token1] = ACTIONS(7420),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7420),
    [aux_sym_modify_modification_token1] = ACTIONS(7420),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7420),
    [aux_sym_movelast_modification_token1] = ACTIONS(7420),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7420),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7420),
    [anon_sym_POUNDif] = ACTIONS(7420),
    [anon_sym_POUNDIF] = ACTIONS(7420),
    [anon_sym_POUNDIf] = ACTIONS(7420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7418),
    [anon_sym_tableextension] = ACTIONS(7420),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7420),
    [anon_sym_Tableextension] = ACTIONS(7420),
    [anon_sym_TableExtension] = ACTIONS(7420),
    [anon_sym_tableExtension] = ACTIONS(7420),
    [sym_page_keyword] = ACTIONS(7418),
    [anon_sym_pageextension] = ACTIONS(7420),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7420),
    [anon_sym_Pageextension] = ACTIONS(7420),
    [anon_sym_PageExtension] = ACTIONS(7420),
    [anon_sym_pageExtension] = ACTIONS(7420),
    [anon_sym_codeunit] = ACTIONS(7420),
    [anon_sym_CODEUNIT] = ACTIONS(7420),
    [anon_sym_Codeunit] = ACTIONS(7420),
    [anon_sym_CodeUnit] = ACTIONS(7420),
    [anon_sym_COdeunit] = ACTIONS(7420),
    [anon_sym_codeUnit] = ACTIONS(7420),
    [sym_report_keyword] = ACTIONS(7418),
    [anon_sym_reportextension] = ACTIONS(7420),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7420),
    [anon_sym_Reportextension] = ACTIONS(7420),
    [anon_sym_ReportExtension] = ACTIONS(7420),
    [anon_sym_reportExtension] = ACTIONS(7420),
    [sym_query_keyword] = ACTIONS(7420),
    [anon_sym_xmlport] = ACTIONS(7420),
    [anon_sym_XMLPORT] = ACTIONS(7420),
    [anon_sym_Xmlport] = ACTIONS(7420),
    [anon_sym_XMLport] = ACTIONS(7420),
    [anon_sym_XMLPort] = ACTIONS(7420),
    [anon_sym_XmlPort] = ACTIONS(7420),
    [anon_sym_enum] = ACTIONS(7418),
    [anon_sym_ENUM] = ACTIONS(7418),
    [anon_sym_Enum] = ACTIONS(7418),
    [anon_sym_eNUM] = ACTIONS(7420),
    [anon_sym_eNum] = ACTIONS(7420),
    [anon_sym_ENum] = ACTIONS(7420),
    [anon_sym_enumextension] = ACTIONS(7420),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7420),
    [anon_sym_Enumextension] = ACTIONS(7420),
    [anon_sym_EnumExtension] = ACTIONS(7420),
    [anon_sym_enumExtension] = ACTIONS(7420),
    [sym_interface_keyword] = ACTIONS(7420),
    [anon_sym_permissionset] = ACTIONS(7418),
    [anon_sym_PERMISSIONSET] = ACTIONS(7418),
    [anon_sym_Permissionset] = ACTIONS(7418),
    [anon_sym_PermissionSet] = ACTIONS(7418),
    [anon_sym_permissionSet] = ACTIONS(7418),
    [anon_sym_permissionsetextension] = ACTIONS(7420),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7420),
    [anon_sym_Permissionsetextension] = ACTIONS(7420),
    [anon_sym_PermissionSetExtension] = ACTIONS(7420),
    [anon_sym_permissionSetExtension] = ACTIONS(7420),
    [sym_area_keyword] = ACTIONS(7420),
    [sym_group_keyword] = ACTIONS(7420),
    [sym_repeater_keyword] = ACTIONS(7420),
    [sym_cuegroup_keyword] = ACTIONS(7420),
    [sym_fixed_keyword] = ACTIONS(7420),
    [sym_grid_keyword] = ACTIONS(7420),
    [sym_part_keyword] = ACTIONS(7420),
    [sym_systempart_keyword] = ACTIONS(7420),
    [sym_usercontrol_keyword] = ACTIONS(7420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(7420),
  },
  [STATE(3956)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8787),
    [anon_sym_POUNDELIF] = ACTIONS(8787),
    [anon_sym_POUNDElif] = ACTIONS(8787),
    [anon_sym_POUNDelse] = ACTIONS(8787),
    [anon_sym_POUNDELSE] = ACTIONS(8787),
    [anon_sym_POUNDElse] = ACTIONS(8787),
    [anon_sym_POUNDelse2] = ACTIONS(8787),
    [anon_sym_POUNDELSE2] = ACTIONS(8787),
    [anon_sym_POUNDElse2] = ACTIONS(8787),
    [anon_sym_POUNDendif] = ACTIONS(8787),
    [anon_sym_POUNDENDIF] = ACTIONS(8787),
    [anon_sym_POUNDEndif] = ACTIONS(8787),
    [anon_sym_POUNDendif2] = ACTIONS(8787),
    [anon_sym_POUNDENDIF2] = ACTIONS(8787),
    [anon_sym_POUNDEndif2] = ACTIONS(8787),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8787),
  },
  [STATE(3957)] = {
    [sym_preproc_conditional_controladdin] = STATE(3956),
    [sym__body_element] = STATE(3956),
    [sym_empty_statement] = STATE(3956),
    [sym_property] = STATE(3956),
    [sym_permissions_property] = STATE(3956),
    [sym_table_relation_property] = STATE(3956),
    [sym_fields_section] = STATE(3956),
    [sym_keys_section] = STATE(3956),
    [sym_fieldgroups_section] = STATE(3956),
    [sym_enum_value_declaration] = STATE(3956),
    [sym_labels_section] = STATE(3956),
    [sym_layout_section] = STATE(3956),
    [sym_modify_modification] = STATE(3956),
    [sym_actions_section] = STATE(3956),
    [sym_views_section] = STATE(3956),
    [sym_dataset_section] = STATE(3956),
    [sym_requestpage_section] = STATE(3956),
    [sym_rendering_section] = STATE(3956),
    [sym_elements_section] = STATE(3956),
    [sym_schema_section] = STATE(3956),
    [sym_assembly_declaration] = STATE(3956),
    [sym_event_declaration] = STATE(3956),
    [sym_procedure] = STATE(3956),
    [sym_preproc_split_procedure] = STATE(3956),
    [sym_preproc_split_procedure_preamble] = STATE(3956),
    [sym_interface_procedure] = STATE(3956),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3956),
    [sym_var_section] = STATE(3956),
    [sym_attribute_item] = STATE(3956),
    [sym_preproc_conditional] = STATE(3956),
    [sym_preproc_if] = STATE(3593),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3956),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8789),
    [anon_sym_POUNDELIF] = ACTIONS(8789),
    [anon_sym_POUNDElif] = ACTIONS(8789),
    [anon_sym_POUNDelse] = ACTIONS(8789),
    [anon_sym_POUNDELSE] = ACTIONS(8789),
    [anon_sym_POUNDElse] = ACTIONS(8789),
    [anon_sym_POUNDelse2] = ACTIONS(8789),
    [anon_sym_POUNDELSE2] = ACTIONS(8789),
    [anon_sym_POUNDElse2] = ACTIONS(8789),
    [anon_sym_POUNDendif] = ACTIONS(8789),
    [anon_sym_POUNDENDIF] = ACTIONS(8789),
    [anon_sym_POUNDEndif] = ACTIONS(8789),
    [anon_sym_POUNDendif2] = ACTIONS(8789),
    [anon_sym_POUNDENDIF2] = ACTIONS(8789),
    [anon_sym_POUNDEndif2] = ACTIONS(8789),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8789),
  },
  [STATE(3958)] = {
    [sym__body_element] = STATE(7554),
    [sym_empty_statement] = STATE(7554),
    [sym_property] = STATE(7554),
    [sym_permissions_property] = STATE(7554),
    [sym_table_relation_property] = STATE(7554),
    [sym_fields_section] = STATE(7554),
    [sym_keys_section] = STATE(7554),
    [sym_fieldgroups_section] = STATE(7554),
    [sym_enum_value_declaration] = STATE(7554),
    [sym_labels_section] = STATE(7554),
    [sym_layout_section] = STATE(7554),
    [sym_modify_modification] = STATE(7554),
    [sym_actions_section] = STATE(7554),
    [sym_views_section] = STATE(7554),
    [sym_dataset_section] = STATE(7554),
    [sym_requestpage_section] = STATE(7554),
    [sym_rendering_section] = STATE(7554),
    [sym_elements_section] = STATE(7554),
    [sym_schema_section] = STATE(7554),
    [sym_xmlport_element] = STATE(3973),
    [sym__xmlport_body_element] = STATE(3973),
    [sym_preproc_conditional_xmlport] = STATE(3973),
    [sym_xmlport_attribute] = STATE(3973),
    [sym_assembly_declaration] = STATE(7554),
    [sym_event_declaration] = STATE(7554),
    [sym_procedure] = STATE(7554),
    [sym_preproc_split_procedure] = STATE(7554),
    [sym_preproc_split_procedure_preamble] = STATE(7554),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(7554),
    [sym_var_section] = STATE(7554),
    [sym_attribute_item] = STATE(7554),
    [sym_preproc_conditional] = STATE(7554),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(9183),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4956),
    [aux_sym_xmlport_element_repeat1] = STATE(3973),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3959)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(8791),
    [anon_sym_LBRACK] = ACTIONS(8794),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8797),
    [aux_sym_modify_modification_token1] = ACTIONS(8800),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8803),
    [anon_sym_POUNDif] = ACTIONS(8806),
    [anon_sym_POUNDIF] = ACTIONS(8806),
    [anon_sym_POUNDIf] = ACTIONS(8806),
    [anon_sym_POUNDelif] = ACTIONS(8809),
    [anon_sym_POUNDELIF] = ACTIONS(8809),
    [anon_sym_POUNDElif] = ACTIONS(8809),
    [anon_sym_POUNDelse] = ACTIONS(8809),
    [anon_sym_POUNDELSE] = ACTIONS(8809),
    [anon_sym_POUNDElse] = ACTIONS(8809),
    [anon_sym_POUNDelse2] = ACTIONS(8809),
    [anon_sym_POUNDELSE2] = ACTIONS(8809),
    [anon_sym_POUNDElse2] = ACTIONS(8809),
    [anon_sym_POUNDendif] = ACTIONS(8809),
    [anon_sym_POUNDENDIF] = ACTIONS(8809),
    [anon_sym_POUNDEndif] = ACTIONS(8809),
    [anon_sym_POUNDendif2] = ACTIONS(8809),
    [anon_sym_POUNDENDIF2] = ACTIONS(8809),
    [anon_sym_POUNDEndif2] = ACTIONS(8809),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8811),
    [sym_trigger_keyword] = ACTIONS(8814),
    [sym_var_keyword] = ACTIONS(8817),
    [sym_local_keyword] = ACTIONS(8820),
    [sym_internal_keyword] = ACTIONS(8823),
    [sym_protected_keyword] = ACTIONS(8820),
    [sym_event_keyword] = ACTIONS(8826),
    [sym_fields_keyword] = ACTIONS(8829),
    [sym_keys_keyword] = ACTIONS(8832),
    [sym_fieldgroups_keyword] = ACTIONS(8835),
    [sym_actions_keyword] = ACTIONS(8838),
    [sym_layout_keyword] = ACTIONS(8841),
    [sym_dataset_keyword] = ACTIONS(8844),
    [sym_elements_keyword] = ACTIONS(8847),
    [sym_labels_keyword] = ACTIONS(8850),
    [sym_rendering_keyword] = ACTIONS(8853),
    [sym_requestpage_keyword] = ACTIONS(8856),
    [sym_schema_keyword] = ACTIONS(8859),
    [sym_views_keyword] = ACTIONS(8862),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8865),
    [sym_preproc_open] = ACTIONS(8806),
    [sym_preproc_close] = ACTIONS(8809),
  },
  [STATE(3960)] = {
    [sym_boolean] = STATE(10130),
    [sym_option_member] = STATE(10067),
    [sym_keyword_identifier] = STATE(10130),
    [sym_codeunit_keyword] = STATE(10164),
    [sym_xmlport_keyword] = STATE(10164),
    [sym_enum_keyword] = STATE(10164),
    [sym_keyword_as_identifier] = STATE(10130),
    [aux_sym_option_member_list_repeat2] = STATE(4422),
    [sym_identifier] = ACTIONS(8747),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(8868),
    [anon_sym_DASH] = ACTIONS(8751),
    [aux_sym_boolean_token1] = ACTIONS(8753),
    [aux_sym_boolean_token2] = ACTIONS(8753),
    [aux_sym_where_condition_token1] = ACTIONS(8755),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8757),
    [aux_sym_record_type_token1] = ACTIONS(8757),
    [aux_sym_basic_type_token21] = ACTIONS(8757),
    [aux_sym_basic_type_token22] = ACTIONS(8759),
    [aux_sym_basic_type_token48] = ACTIONS(8757),
    [aux_sym_basic_type_token53] = ACTIONS(8755),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8755),
    [aux_sym_separator_action_token1] = ACTIONS(8755),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8755),
    [aux_sym_type_declaration_token1] = ACTIONS(8755),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8757),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8757),
    [sym_table_keyword] = ACTIONS(8755),
    [sym_page_keyword] = ACTIONS(8757),
    [anon_sym_codeunit] = ACTIONS(8761),
    [anon_sym_CODEUNIT] = ACTIONS(8761),
    [anon_sym_Codeunit] = ACTIONS(8761),
    [anon_sym_CodeUnit] = ACTIONS(8761),
    [anon_sym_COdeunit] = ACTIONS(8761),
    [anon_sym_codeUnit] = ACTIONS(8761),
    [sym_report_keyword] = ACTIONS(8757),
    [sym_query_keyword] = ACTIONS(8757),
    [anon_sym_xmlport] = ACTIONS(8763),
    [anon_sym_XMLPORT] = ACTIONS(8763),
    [anon_sym_Xmlport] = ACTIONS(8763),
    [anon_sym_XMLport] = ACTIONS(8763),
    [anon_sym_XMLPort] = ACTIONS(8763),
    [anon_sym_XmlPort] = ACTIONS(8763),
    [anon_sym_enum] = ACTIONS(8765),
    [anon_sym_ENUM] = ACTIONS(8765),
    [anon_sym_Enum] = ACTIONS(8765),
    [anon_sym_eNUM] = ACTIONS(8765),
    [anon_sym_eNum] = ACTIONS(8765),
    [anon_sym_ENum] = ACTIONS(8765),
    [sym_var_keyword] = ACTIONS(602),
    [sym_local_keyword] = ACTIONS(8747),
    [sym_internal_keyword] = ACTIONS(8747),
    [sym_protected_keyword] = ACTIONS(8747),
    [sym_key_keyword] = ACTIONS(8755),
    [sym_dataset_keyword] = ACTIONS(8755),
    [sym_quoted_identifier] = ACTIONS(8767),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8767),
    [sym_integer] = ACTIONS(8767),
    [sym_preproc_open] = ACTIONS(600),
    [sym_preproc_close] = ACTIONS(600),
  },
  [STATE(3961)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(7562),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3962)] = {
    [sym_boolean] = STATE(8705),
    [sym__preproc_if_header] = STATE(14744),
    [sym__expression_statement] = STATE(18034),
    [sym_assignment_expression] = STATE(8705),
    [sym__expression] = STATE(8705),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8705),
    [sym_multiplicative_expression] = STATE(8705),
    [sym_additive_expression] = STATE(8705),
    [sym_comparison_expression] = STATE(8705),
    [sym_logical_expression] = STATE(8705),
    [sym_ternary_expression] = STATE(8705),
    [sym_unary_expression] = STATE(8705),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8705),
    [sym_list_literal] = STATE(8705),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8705),
    [sym__literal_value] = STATE(8705),
    [sym_if_keyword] = STATE(4441),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [aux_sym__preproc_guard_block_repeat1] = STATE(4058),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8870),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(8872),
    [sym_date_literal] = ACTIONS(8870),
    [sym_time_literal] = ACTIONS(8870),
    [sym_biginteger_literal] = ACTIONS(8872),
    [anon_sym_if] = ACTIONS(87),
    [anon_sym_IF] = ACTIONS(87),
    [anon_sym_If] = ACTIONS(87),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8872),
    [sym_verbatim_string] = ACTIONS(8872),
    [sym_integer] = ACTIONS(8870),
    [sym_continue_as_identifier] = ACTIONS(8872),
  },
  [STATE(3963)] = {
    [anon_sym_SEMI] = ACTIONS(5360),
    [aux_sym_where_condition_token1] = ACTIONS(5358),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5360),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5360),
    [anon_sym_LBRACK] = ACTIONS(5360),
    [aux_sym_basic_type_token6] = ACTIONS(5358),
    [aux_sym_basic_type_token22] = ACTIONS(5358),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5360),
    [aux_sym_addafter_modification_token1] = ACTIONS(5360),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5360),
    [aux_sym_modify_modification_token1] = ACTIONS(5360),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5360),
    [aux_sym_movelast_modification_token1] = ACTIONS(5360),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5360),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5360),
    [aux_sym_separator_action_token1] = ACTIONS(5360),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5360),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5360),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5360),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5360),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5360),
    [anon_sym_POUNDif] = ACTIONS(5360),
    [anon_sym_POUNDIF] = ACTIONS(5360),
    [anon_sym_POUNDIf] = ACTIONS(5360),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8874),
    [anon_sym_PIPE_PIPE] = ACTIONS(8874),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8876),
    [anon_sym_AMP_AMP] = ACTIONS(8876),
    [anon_sym_POUNDelif] = ACTIONS(5360),
    [anon_sym_POUNDELIF] = ACTIONS(5360),
    [anon_sym_POUNDElif] = ACTIONS(5360),
    [anon_sym_POUNDelse] = ACTIONS(5360),
    [anon_sym_POUNDELSE] = ACTIONS(5360),
    [anon_sym_POUNDElse] = ACTIONS(5360),
    [anon_sym_POUNDelse2] = ACTIONS(5360),
    [anon_sym_POUNDELSE2] = ACTIONS(5360),
    [anon_sym_POUNDElse2] = ACTIONS(5360),
    [anon_sym_POUNDendif] = ACTIONS(5360),
    [anon_sym_POUNDENDIF] = ACTIONS(5360),
    [anon_sym_POUNDEndif] = ACTIONS(5360),
    [anon_sym_POUNDendif2] = ACTIONS(5360),
    [anon_sym_POUNDENDIF2] = ACTIONS(5360),
    [anon_sym_POUNDEndif2] = ACTIONS(5360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5360),
    [sym_trigger_keyword] = ACTIONS(5360),
    [sym_var_keyword] = ACTIONS(5360),
    [sym_local_keyword] = ACTIONS(5360),
    [sym_internal_keyword] = ACTIONS(5360),
    [sym_protected_keyword] = ACTIONS(5360),
    [sym_event_keyword] = ACTIONS(5360),
    [sym_fields_keyword] = ACTIONS(5360),
    [sym_keys_keyword] = ACTIONS(5360),
    [sym_fieldgroups_keyword] = ACTIONS(5360),
    [sym_actions_keyword] = ACTIONS(5360),
    [sym_layout_keyword] = ACTIONS(5360),
    [sym_area_keyword] = ACTIONS(5360),
    [sym_group_keyword] = ACTIONS(5360),
    [sym_repeater_keyword] = ACTIONS(5360),
    [sym_cuegroup_keyword] = ACTIONS(5360),
    [sym_fixed_keyword] = ACTIONS(5360),
    [sym_grid_keyword] = ACTIONS(5360),
    [sym_part_keyword] = ACTIONS(5360),
    [sym_systempart_keyword] = ACTIONS(5360),
    [sym_usercontrol_keyword] = ACTIONS(5360),
    [sym_dataset_keyword] = ACTIONS(5360),
    [sym_elements_keyword] = ACTIONS(5360),
    [sym_dataitem_keyword] = ACTIONS(5360),
    [sym_column_keyword] = ACTIONS(5360),
    [sym_filter_keyword] = ACTIONS(5360),
    [sym_labels_keyword] = ACTIONS(5360),
    [sym_rendering_keyword] = ACTIONS(5360),
    [sym_requestpage_keyword] = ACTIONS(5360),
    [sym_schema_keyword] = ACTIONS(5360),
    [sym_views_keyword] = ACTIONS(5360),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5360),
    [sym_preproc_open] = ACTIONS(5360),
    [sym_preproc_close] = ACTIONS(5360),
  },
  [STATE(3964)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(7533),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3965)] = {
    [sym__body_element] = STATE(3971),
    [sym_empty_statement] = STATE(3971),
    [sym_property] = STATE(3971),
    [sym_permissions_property] = STATE(3971),
    [sym_table_relation_property] = STATE(3971),
    [sym_fields_section] = STATE(3971),
    [sym_keys_section] = STATE(3971),
    [sym_fieldgroups_section] = STATE(3971),
    [sym_enum_value_declaration] = STATE(3971),
    [sym_labels_section] = STATE(3971),
    [sym_layout_section] = STATE(3971),
    [sym_modify_modification] = STATE(3971),
    [sym_actions_section] = STATE(3971),
    [sym_views_section] = STATE(3971),
    [sym_dataset_section] = STATE(3971),
    [sym_requestpage_section] = STATE(3971),
    [sym_rendering_section] = STATE(3971),
    [sym_elements_section] = STATE(3971),
    [sym_schema_section] = STATE(3971),
    [sym_xmlport_element] = STATE(3971),
    [sym__xmlport_body_element] = STATE(3971),
    [sym_preproc_conditional_xmlport] = STATE(3971),
    [sym_xmlport_attribute] = STATE(3971),
    [sym_assembly_declaration] = STATE(3971),
    [sym_event_declaration] = STATE(3971),
    [sym_procedure] = STATE(3971),
    [sym_preproc_split_procedure] = STATE(3971),
    [sym_preproc_split_procedure_preamble] = STATE(3971),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3971),
    [sym_var_section] = STATE(3971),
    [sym_attribute_item] = STATE(3971),
    [sym_preproc_conditional] = STATE(3971),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(7533),
    [aux_sym_xmlport_element_repeat1] = STATE(3971),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3966)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(9483),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3967)] = {
    [sym__body_element] = STATE(8030),
    [sym_empty_statement] = STATE(8030),
    [sym_property] = STATE(8030),
    [sym_permissions_property] = STATE(8030),
    [sym_table_relation_property] = STATE(8030),
    [sym_fields_section] = STATE(8030),
    [sym_keys_section] = STATE(8030),
    [sym_fieldgroups_section] = STATE(8030),
    [sym_enum_value_declaration] = STATE(8030),
    [sym_labels_section] = STATE(8030),
    [sym_layout_section] = STATE(8030),
    [sym_modify_modification] = STATE(8030),
    [sym_actions_section] = STATE(8030),
    [sym_views_section] = STATE(8030),
    [sym_dataset_section] = STATE(8030),
    [sym_requestpage_section] = STATE(8030),
    [sym_rendering_section] = STATE(8030),
    [sym_elements_section] = STATE(8030),
    [sym_query_dataitem] = STATE(4030),
    [sym__query_body_element] = STATE(4030),
    [sym_preproc_conditional_query] = STATE(4030),
    [sym_query_column] = STATE(4030),
    [sym_query_filter] = STATE(4030),
    [sym_schema_section] = STATE(8030),
    [sym_assembly_declaration] = STATE(8030),
    [sym_event_declaration] = STATE(8030),
    [sym_procedure] = STATE(8030),
    [sym_preproc_split_procedure] = STATE(8030),
    [sym_preproc_split_procedure_preamble] = STATE(8030),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8030),
    [sym_var_section] = STATE(8030),
    [sym_attribute_item] = STATE(8030),
    [sym_preproc_conditional] = STATE(8030),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(9821),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4897),
    [aux_sym_query_dataitem_repeat1] = STATE(4030),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(3968)] = {
    [sym_boolean] = STATE(8544),
    [sym_code_block] = STATE(15228),
    [sym_assignment_expression] = STATE(8544),
    [sym__expression] = STATE(8544),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8544),
    [sym_multiplicative_expression] = STATE(8544),
    [sym_additive_expression] = STATE(8544),
    [sym_comparison_expression] = STATE(8544),
    [sym_logical_expression] = STATE(8544),
    [sym_ternary_expression] = STATE(8544),
    [sym_unary_expression] = STATE(8544),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8544),
    [sym_list_literal] = STATE(8544),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8544),
    [sym__literal_value] = STATE(8544),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_SEMI] = ACTIONS(4318),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8878),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(978),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(8880),
    [sym_date_literal] = ACTIONS(8878),
    [sym_time_literal] = ACTIONS(8878),
    [sym_biginteger_literal] = ACTIONS(8880),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_ELSE] = ACTIONS(4322),
    [anon_sym_Else] = ACTIONS(4322),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8880),
    [sym_verbatim_string] = ACTIONS(8880),
    [sym_integer] = ACTIONS(8878),
    [sym_continue_as_identifier] = ACTIONS(8880),
    [sym_begin_keyword] = ACTIONS(982),
  },
  [STATE(3969)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(9697),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3970)] = {
    [sym__body_element] = STATE(8030),
    [sym_empty_statement] = STATE(8030),
    [sym_property] = STATE(8030),
    [sym_permissions_property] = STATE(8030),
    [sym_table_relation_property] = STATE(8030),
    [sym_fields_section] = STATE(8030),
    [sym_keys_section] = STATE(8030),
    [sym_fieldgroups_section] = STATE(8030),
    [sym_enum_value_declaration] = STATE(8030),
    [sym_labels_section] = STATE(8030),
    [sym_layout_section] = STATE(8030),
    [sym_modify_modification] = STATE(8030),
    [sym_actions_section] = STATE(8030),
    [sym_views_section] = STATE(8030),
    [sym_dataset_section] = STATE(8030),
    [sym_requestpage_section] = STATE(8030),
    [sym_rendering_section] = STATE(8030),
    [sym_elements_section] = STATE(8030),
    [sym_query_dataitem] = STATE(4053),
    [sym__query_body_element] = STATE(4053),
    [sym_preproc_conditional_query] = STATE(4053),
    [sym_query_column] = STATE(4053),
    [sym_query_filter] = STATE(4053),
    [sym_schema_section] = STATE(8030),
    [sym_assembly_declaration] = STATE(8030),
    [sym_event_declaration] = STATE(8030),
    [sym_procedure] = STATE(8030),
    [sym_preproc_split_procedure] = STATE(8030),
    [sym_preproc_split_procedure_preamble] = STATE(8030),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8030),
    [sym_var_section] = STATE(8030),
    [sym_attribute_item] = STATE(8030),
    [sym_preproc_conditional] = STATE(8030),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(8074),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4908),
    [aux_sym_query_dataitem_repeat1] = STATE(4053),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(3971)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(7555),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3972)] = {
    [anon_sym_SEMI] = ACTIONS(5372),
    [aux_sym_where_condition_token1] = ACTIONS(5370),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5372),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5372),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [aux_sym_basic_type_token6] = ACTIONS(5370),
    [aux_sym_basic_type_token22] = ACTIONS(5370),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5372),
    [aux_sym_addafter_modification_token1] = ACTIONS(5372),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5372),
    [aux_sym_modify_modification_token1] = ACTIONS(5372),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5372),
    [aux_sym_movelast_modification_token1] = ACTIONS(5372),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5372),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5372),
    [aux_sym_separator_action_token1] = ACTIONS(5372),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5372),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5372),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5372),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5372),
    [anon_sym_POUNDif] = ACTIONS(5372),
    [anon_sym_POUNDIF] = ACTIONS(5372),
    [anon_sym_POUNDIf] = ACTIONS(5372),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8874),
    [anon_sym_PIPE_PIPE] = ACTIONS(8874),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8876),
    [anon_sym_AMP_AMP] = ACTIONS(8876),
    [anon_sym_POUNDelif] = ACTIONS(5372),
    [anon_sym_POUNDELIF] = ACTIONS(5372),
    [anon_sym_POUNDElif] = ACTIONS(5372),
    [anon_sym_POUNDelse] = ACTIONS(5372),
    [anon_sym_POUNDELSE] = ACTIONS(5372),
    [anon_sym_POUNDElse] = ACTIONS(5372),
    [anon_sym_POUNDelse2] = ACTIONS(5372),
    [anon_sym_POUNDELSE2] = ACTIONS(5372),
    [anon_sym_POUNDElse2] = ACTIONS(5372),
    [anon_sym_POUNDendif] = ACTIONS(5372),
    [anon_sym_POUNDENDIF] = ACTIONS(5372),
    [anon_sym_POUNDEndif] = ACTIONS(5372),
    [anon_sym_POUNDendif2] = ACTIONS(5372),
    [anon_sym_POUNDENDIF2] = ACTIONS(5372),
    [anon_sym_POUNDEndif2] = ACTIONS(5372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5372),
    [sym_trigger_keyword] = ACTIONS(5372),
    [sym_var_keyword] = ACTIONS(5372),
    [sym_local_keyword] = ACTIONS(5372),
    [sym_internal_keyword] = ACTIONS(5372),
    [sym_protected_keyword] = ACTIONS(5372),
    [sym_event_keyword] = ACTIONS(5372),
    [sym_fields_keyword] = ACTIONS(5372),
    [sym_keys_keyword] = ACTIONS(5372),
    [sym_fieldgroups_keyword] = ACTIONS(5372),
    [sym_actions_keyword] = ACTIONS(5372),
    [sym_layout_keyword] = ACTIONS(5372),
    [sym_area_keyword] = ACTIONS(5372),
    [sym_group_keyword] = ACTIONS(5372),
    [sym_repeater_keyword] = ACTIONS(5372),
    [sym_cuegroup_keyword] = ACTIONS(5372),
    [sym_fixed_keyword] = ACTIONS(5372),
    [sym_grid_keyword] = ACTIONS(5372),
    [sym_part_keyword] = ACTIONS(5372),
    [sym_systempart_keyword] = ACTIONS(5372),
    [sym_usercontrol_keyword] = ACTIONS(5372),
    [sym_dataset_keyword] = ACTIONS(5372),
    [sym_elements_keyword] = ACTIONS(5372),
    [sym_dataitem_keyword] = ACTIONS(5372),
    [sym_column_keyword] = ACTIONS(5372),
    [sym_filter_keyword] = ACTIONS(5372),
    [sym_labels_keyword] = ACTIONS(5372),
    [sym_rendering_keyword] = ACTIONS(5372),
    [sym_requestpage_keyword] = ACTIONS(5372),
    [sym_schema_keyword] = ACTIONS(5372),
    [sym_views_keyword] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5372),
    [sym_preproc_open] = ACTIONS(5372),
    [sym_preproc_close] = ACTIONS(5372),
  },
  [STATE(3973)] = {
    [sym__body_element] = STATE(3613),
    [sym_empty_statement] = STATE(3613),
    [sym_property] = STATE(3613),
    [sym_permissions_property] = STATE(3613),
    [sym_table_relation_property] = STATE(3613),
    [sym_fields_section] = STATE(3613),
    [sym_keys_section] = STATE(3613),
    [sym_fieldgroups_section] = STATE(3613),
    [sym_enum_value_declaration] = STATE(3613),
    [sym_labels_section] = STATE(3613),
    [sym_layout_section] = STATE(3613),
    [sym_modify_modification] = STATE(3613),
    [sym_actions_section] = STATE(3613),
    [sym_views_section] = STATE(3613),
    [sym_dataset_section] = STATE(3613),
    [sym_requestpage_section] = STATE(3613),
    [sym_rendering_section] = STATE(3613),
    [sym_elements_section] = STATE(3613),
    [sym_schema_section] = STATE(3613),
    [sym_xmlport_element] = STATE(3613),
    [sym__xmlport_body_element] = STATE(3613),
    [sym_preproc_conditional_xmlport] = STATE(3613),
    [sym_xmlport_attribute] = STATE(3613),
    [sym_assembly_declaration] = STATE(3613),
    [sym_event_declaration] = STATE(3613),
    [sym_procedure] = STATE(3613),
    [sym_preproc_split_procedure] = STATE(3613),
    [sym_preproc_split_procedure_preamble] = STATE(3613),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3613),
    [sym_var_section] = STATE(3613),
    [sym_attribute_item] = STATE(3613),
    [sym_preproc_conditional] = STATE(3613),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(9457),
    [aux_sym_xmlport_element_repeat1] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3974)] = {
    [sym__body_element] = STATE(3969),
    [sym_empty_statement] = STATE(3969),
    [sym_property] = STATE(3969),
    [sym_permissions_property] = STATE(3969),
    [sym_table_relation_property] = STATE(3969),
    [sym_fields_section] = STATE(3969),
    [sym_keys_section] = STATE(3969),
    [sym_fieldgroups_section] = STATE(3969),
    [sym_enum_value_declaration] = STATE(3969),
    [sym_labels_section] = STATE(3969),
    [sym_layout_section] = STATE(3969),
    [sym_modify_modification] = STATE(3969),
    [sym_actions_section] = STATE(3969),
    [sym_views_section] = STATE(3969),
    [sym_dataset_section] = STATE(3969),
    [sym_requestpage_section] = STATE(3969),
    [sym_rendering_section] = STATE(3969),
    [sym_elements_section] = STATE(3969),
    [sym_schema_section] = STATE(3969),
    [sym_xmlport_element] = STATE(3969),
    [sym__xmlport_body_element] = STATE(3969),
    [sym_preproc_conditional_xmlport] = STATE(3969),
    [sym_xmlport_attribute] = STATE(3969),
    [sym_assembly_declaration] = STATE(3969),
    [sym_event_declaration] = STATE(3969),
    [sym_procedure] = STATE(3969),
    [sym_preproc_split_procedure] = STATE(3969),
    [sym_preproc_split_procedure_preamble] = STATE(3969),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3969),
    [sym_var_section] = STATE(3969),
    [sym_attribute_item] = STATE(3969),
    [sym_preproc_conditional] = STATE(3969),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(9457),
    [aux_sym_xmlport_element_repeat1] = STATE(3969),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3975)] = {
    [anon_sym_SEMI] = ACTIONS(5380),
    [aux_sym_where_condition_token1] = ACTIONS(5378),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5380),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5380),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [aux_sym_basic_type_token6] = ACTIONS(5378),
    [aux_sym_basic_type_token22] = ACTIONS(5378),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5380),
    [aux_sym_addafter_modification_token1] = ACTIONS(5380),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5380),
    [aux_sym_modify_modification_token1] = ACTIONS(5380),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5380),
    [aux_sym_movelast_modification_token1] = ACTIONS(5380),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5380),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5380),
    [aux_sym_separator_action_token1] = ACTIONS(5380),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5380),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5380),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5380),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5380),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5380),
    [anon_sym_POUNDif] = ACTIONS(5380),
    [anon_sym_POUNDIF] = ACTIONS(5380),
    [anon_sym_POUNDIf] = ACTIONS(5380),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5380),
    [anon_sym_PIPE_PIPE] = ACTIONS(5380),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8876),
    [anon_sym_AMP_AMP] = ACTIONS(8876),
    [anon_sym_POUNDelif] = ACTIONS(5380),
    [anon_sym_POUNDELIF] = ACTIONS(5380),
    [anon_sym_POUNDElif] = ACTIONS(5380),
    [anon_sym_POUNDelse] = ACTIONS(5380),
    [anon_sym_POUNDELSE] = ACTIONS(5380),
    [anon_sym_POUNDElse] = ACTIONS(5380),
    [anon_sym_POUNDelse2] = ACTIONS(5380),
    [anon_sym_POUNDELSE2] = ACTIONS(5380),
    [anon_sym_POUNDElse2] = ACTIONS(5380),
    [anon_sym_POUNDendif] = ACTIONS(5380),
    [anon_sym_POUNDENDIF] = ACTIONS(5380),
    [anon_sym_POUNDEndif] = ACTIONS(5380),
    [anon_sym_POUNDendif2] = ACTIONS(5380),
    [anon_sym_POUNDENDIF2] = ACTIONS(5380),
    [anon_sym_POUNDEndif2] = ACTIONS(5380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5380),
    [sym_trigger_keyword] = ACTIONS(5380),
    [sym_var_keyword] = ACTIONS(5380),
    [sym_local_keyword] = ACTIONS(5380),
    [sym_internal_keyword] = ACTIONS(5380),
    [sym_protected_keyword] = ACTIONS(5380),
    [sym_event_keyword] = ACTIONS(5380),
    [sym_fields_keyword] = ACTIONS(5380),
    [sym_keys_keyword] = ACTIONS(5380),
    [sym_fieldgroups_keyword] = ACTIONS(5380),
    [sym_actions_keyword] = ACTIONS(5380),
    [sym_layout_keyword] = ACTIONS(5380),
    [sym_area_keyword] = ACTIONS(5380),
    [sym_group_keyword] = ACTIONS(5380),
    [sym_repeater_keyword] = ACTIONS(5380),
    [sym_cuegroup_keyword] = ACTIONS(5380),
    [sym_fixed_keyword] = ACTIONS(5380),
    [sym_grid_keyword] = ACTIONS(5380),
    [sym_part_keyword] = ACTIONS(5380),
    [sym_systempart_keyword] = ACTIONS(5380),
    [sym_usercontrol_keyword] = ACTIONS(5380),
    [sym_dataset_keyword] = ACTIONS(5380),
    [sym_elements_keyword] = ACTIONS(5380),
    [sym_dataitem_keyword] = ACTIONS(5380),
    [sym_column_keyword] = ACTIONS(5380),
    [sym_filter_keyword] = ACTIONS(5380),
    [sym_labels_keyword] = ACTIONS(5380),
    [sym_rendering_keyword] = ACTIONS(5380),
    [sym_requestpage_keyword] = ACTIONS(5380),
    [sym_schema_keyword] = ACTIONS(5380),
    [sym_views_keyword] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5380),
    [sym_preproc_open] = ACTIONS(5380),
    [sym_preproc_close] = ACTIONS(5380),
  },
  [STATE(3976)] = {
    [sym__body_element] = STATE(3966),
    [sym_empty_statement] = STATE(3966),
    [sym_property] = STATE(3966),
    [sym_permissions_property] = STATE(3966),
    [sym_table_relation_property] = STATE(3966),
    [sym_fields_section] = STATE(3966),
    [sym_keys_section] = STATE(3966),
    [sym_fieldgroups_section] = STATE(3966),
    [sym_enum_value_declaration] = STATE(3966),
    [sym_labels_section] = STATE(3966),
    [sym_layout_section] = STATE(3966),
    [sym_modify_modification] = STATE(3966),
    [sym_actions_section] = STATE(3966),
    [sym_views_section] = STATE(3966),
    [sym_dataset_section] = STATE(3966),
    [sym_requestpage_section] = STATE(3966),
    [sym_rendering_section] = STATE(3966),
    [sym_elements_section] = STATE(3966),
    [sym_schema_section] = STATE(3966),
    [sym_xmlport_element] = STATE(3966),
    [sym__xmlport_body_element] = STATE(3966),
    [sym_preproc_conditional_xmlport] = STATE(3966),
    [sym_xmlport_attribute] = STATE(3966),
    [sym_assembly_declaration] = STATE(3966),
    [sym_event_declaration] = STATE(3966),
    [sym_procedure] = STATE(3966),
    [sym_preproc_split_procedure] = STATE(3966),
    [sym_preproc_split_procedure_preamble] = STATE(3966),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3966),
    [sym_var_section] = STATE(3966),
    [sym_attribute_item] = STATE(3966),
    [sym_preproc_conditional] = STATE(3966),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(9697),
    [aux_sym_xmlport_element_repeat1] = STATE(3966),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(3977)] = {
    [anon_sym_SEMI] = ACTIONS(5401),
    [aux_sym_where_condition_token1] = ACTIONS(5399),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5401),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5401),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [aux_sym_basic_type_token6] = ACTIONS(5399),
    [aux_sym_basic_type_token22] = ACTIONS(5399),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5401),
    [aux_sym_addafter_modification_token1] = ACTIONS(5401),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5401),
    [aux_sym_modify_modification_token1] = ACTIONS(5401),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5401),
    [aux_sym_movelast_modification_token1] = ACTIONS(5401),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5401),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5401),
    [aux_sym_separator_action_token1] = ACTIONS(5401),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5401),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5401),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5401),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5401),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5401),
    [anon_sym_POUNDif] = ACTIONS(5401),
    [anon_sym_POUNDIF] = ACTIONS(5401),
    [anon_sym_POUNDIf] = ACTIONS(5401),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(8874),
    [anon_sym_PIPE_PIPE] = ACTIONS(8874),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(8876),
    [anon_sym_AMP_AMP] = ACTIONS(8876),
    [anon_sym_POUNDelif] = ACTIONS(5401),
    [anon_sym_POUNDELIF] = ACTIONS(5401),
    [anon_sym_POUNDElif] = ACTIONS(5401),
    [anon_sym_POUNDelse] = ACTIONS(5401),
    [anon_sym_POUNDELSE] = ACTIONS(5401),
    [anon_sym_POUNDElse] = ACTIONS(5401),
    [anon_sym_POUNDelse2] = ACTIONS(5401),
    [anon_sym_POUNDELSE2] = ACTIONS(5401),
    [anon_sym_POUNDElse2] = ACTIONS(5401),
    [anon_sym_POUNDendif] = ACTIONS(5401),
    [anon_sym_POUNDENDIF] = ACTIONS(5401),
    [anon_sym_POUNDEndif] = ACTIONS(5401),
    [anon_sym_POUNDendif2] = ACTIONS(5401),
    [anon_sym_POUNDENDIF2] = ACTIONS(5401),
    [anon_sym_POUNDEndif2] = ACTIONS(5401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5401),
    [sym_trigger_keyword] = ACTIONS(5401),
    [sym_var_keyword] = ACTIONS(5401),
    [sym_local_keyword] = ACTIONS(5401),
    [sym_internal_keyword] = ACTIONS(5401),
    [sym_protected_keyword] = ACTIONS(5401),
    [sym_event_keyword] = ACTIONS(5401),
    [sym_fields_keyword] = ACTIONS(5401),
    [sym_keys_keyword] = ACTIONS(5401),
    [sym_fieldgroups_keyword] = ACTIONS(5401),
    [sym_actions_keyword] = ACTIONS(5401),
    [sym_layout_keyword] = ACTIONS(5401),
    [sym_area_keyword] = ACTIONS(5401),
    [sym_group_keyword] = ACTIONS(5401),
    [sym_repeater_keyword] = ACTIONS(5401),
    [sym_cuegroup_keyword] = ACTIONS(5401),
    [sym_fixed_keyword] = ACTIONS(5401),
    [sym_grid_keyword] = ACTIONS(5401),
    [sym_part_keyword] = ACTIONS(5401),
    [sym_systempart_keyword] = ACTIONS(5401),
    [sym_usercontrol_keyword] = ACTIONS(5401),
    [sym_dataset_keyword] = ACTIONS(5401),
    [sym_elements_keyword] = ACTIONS(5401),
    [sym_dataitem_keyword] = ACTIONS(5401),
    [sym_column_keyword] = ACTIONS(5401),
    [sym_filter_keyword] = ACTIONS(5401),
    [sym_labels_keyword] = ACTIONS(5401),
    [sym_rendering_keyword] = ACTIONS(5401),
    [sym_requestpage_keyword] = ACTIONS(5401),
    [sym_schema_keyword] = ACTIONS(5401),
    [sym_views_keyword] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5401),
    [sym_preproc_open] = ACTIONS(5401),
    [sym_preproc_close] = ACTIONS(5401),
  },
  [STATE(3978)] = {
    [anon_sym_SEMI] = ACTIONS(5376),
    [aux_sym_where_condition_token1] = ACTIONS(5374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5376),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5376),
    [anon_sym_LBRACK] = ACTIONS(5376),
    [aux_sym_basic_type_token6] = ACTIONS(5374),
    [aux_sym_basic_type_token22] = ACTIONS(5374),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5376),
    [aux_sym_addafter_modification_token1] = ACTIONS(5376),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5376),
    [aux_sym_modify_modification_token1] = ACTIONS(5376),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5376),
    [aux_sym_movelast_modification_token1] = ACTIONS(5376),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5376),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5376),
    [aux_sym_separator_action_token1] = ACTIONS(5376),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5376),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5376),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5376),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5376),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5376),
    [anon_sym_POUNDif] = ACTIONS(5376),
    [anon_sym_POUNDIF] = ACTIONS(5376),
    [anon_sym_POUNDIf] = ACTIONS(5376),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5376),
    [anon_sym_PIPE_PIPE] = ACTIONS(5376),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5376),
    [anon_sym_AMP_AMP] = ACTIONS(5376),
    [anon_sym_POUNDelif] = ACTIONS(5376),
    [anon_sym_POUNDELIF] = ACTIONS(5376),
    [anon_sym_POUNDElif] = ACTIONS(5376),
    [anon_sym_POUNDelse] = ACTIONS(5376),
    [anon_sym_POUNDELSE] = ACTIONS(5376),
    [anon_sym_POUNDElse] = ACTIONS(5376),
    [anon_sym_POUNDelse2] = ACTIONS(5376),
    [anon_sym_POUNDELSE2] = ACTIONS(5376),
    [anon_sym_POUNDElse2] = ACTIONS(5376),
    [anon_sym_POUNDendif] = ACTIONS(5376),
    [anon_sym_POUNDENDIF] = ACTIONS(5376),
    [anon_sym_POUNDEndif] = ACTIONS(5376),
    [anon_sym_POUNDendif2] = ACTIONS(5376),
    [anon_sym_POUNDENDIF2] = ACTIONS(5376),
    [anon_sym_POUNDEndif2] = ACTIONS(5376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5376),
    [sym_trigger_keyword] = ACTIONS(5376),
    [sym_var_keyword] = ACTIONS(5376),
    [sym_local_keyword] = ACTIONS(5376),
    [sym_internal_keyword] = ACTIONS(5376),
    [sym_protected_keyword] = ACTIONS(5376),
    [sym_event_keyword] = ACTIONS(5376),
    [sym_fields_keyword] = ACTIONS(5376),
    [sym_keys_keyword] = ACTIONS(5376),
    [sym_fieldgroups_keyword] = ACTIONS(5376),
    [sym_actions_keyword] = ACTIONS(5376),
    [sym_layout_keyword] = ACTIONS(5376),
    [sym_area_keyword] = ACTIONS(5376),
    [sym_group_keyword] = ACTIONS(5376),
    [sym_repeater_keyword] = ACTIONS(5376),
    [sym_cuegroup_keyword] = ACTIONS(5376),
    [sym_fixed_keyword] = ACTIONS(5376),
    [sym_grid_keyword] = ACTIONS(5376),
    [sym_part_keyword] = ACTIONS(5376),
    [sym_systempart_keyword] = ACTIONS(5376),
    [sym_usercontrol_keyword] = ACTIONS(5376),
    [sym_dataset_keyword] = ACTIONS(5376),
    [sym_elements_keyword] = ACTIONS(5376),
    [sym_dataitem_keyword] = ACTIONS(5376),
    [sym_column_keyword] = ACTIONS(5376),
    [sym_filter_keyword] = ACTIONS(5376),
    [sym_labels_keyword] = ACTIONS(5376),
    [sym_rendering_keyword] = ACTIONS(5376),
    [sym_requestpage_keyword] = ACTIONS(5376),
    [sym_schema_keyword] = ACTIONS(5376),
    [sym_views_keyword] = ACTIONS(5376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5376),
    [sym_preproc_open] = ACTIONS(5376),
    [sym_preproc_close] = ACTIONS(5376),
  },
  [STATE(3979)] = {
    [sym_boolean] = STATE(10130),
    [sym_option_member] = STATE(10119),
    [sym_keyword_identifier] = STATE(10130),
    [sym_codeunit_keyword] = STATE(10164),
    [sym_xmlport_keyword] = STATE(10164),
    [sym_enum_keyword] = STATE(10164),
    [sym_keyword_as_identifier] = STATE(10130),
    [sym_identifier] = ACTIONS(8747),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(8751),
    [aux_sym_boolean_token1] = ACTIONS(8753),
    [aux_sym_boolean_token2] = ACTIONS(8753),
    [aux_sym_where_condition_token1] = ACTIONS(8755),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8757),
    [aux_sym_record_type_token1] = ACTIONS(8757),
    [aux_sym_basic_type_token21] = ACTIONS(8757),
    [aux_sym_basic_type_token22] = ACTIONS(8759),
    [aux_sym_basic_type_token48] = ACTIONS(8757),
    [aux_sym_basic_type_token53] = ACTIONS(8755),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8755),
    [aux_sym_separator_action_token1] = ACTIONS(8755),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8755),
    [aux_sym_type_declaration_token1] = ACTIONS(8755),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [anon_sym_POUNDelif] = ACTIONS(611),
    [anon_sym_POUNDELIF] = ACTIONS(611),
    [anon_sym_POUNDElif] = ACTIONS(611),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [anon_sym_POUNDendif] = ACTIONS(611),
    [anon_sym_POUNDENDIF] = ACTIONS(611),
    [anon_sym_POUNDEndif] = ACTIONS(611),
    [anon_sym_POUNDendif2] = ACTIONS(611),
    [anon_sym_POUNDENDIF2] = ACTIONS(611),
    [anon_sym_POUNDEndif2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(8757),
    [aux_sym_keyword_identifier_token2] = ACTIONS(8757),
    [sym_table_keyword] = ACTIONS(8755),
    [sym_page_keyword] = ACTIONS(8757),
    [anon_sym_codeunit] = ACTIONS(8761),
    [anon_sym_CODEUNIT] = ACTIONS(8761),
    [anon_sym_Codeunit] = ACTIONS(8761),
    [anon_sym_CodeUnit] = ACTIONS(8761),
    [anon_sym_COdeunit] = ACTIONS(8761),
    [anon_sym_codeUnit] = ACTIONS(8761),
    [sym_report_keyword] = ACTIONS(8757),
    [sym_query_keyword] = ACTIONS(8757),
    [anon_sym_xmlport] = ACTIONS(8763),
    [anon_sym_XMLPORT] = ACTIONS(8763),
    [anon_sym_Xmlport] = ACTIONS(8763),
    [anon_sym_XMLport] = ACTIONS(8763),
    [anon_sym_XMLPort] = ACTIONS(8763),
    [anon_sym_XmlPort] = ACTIONS(8763),
    [anon_sym_enum] = ACTIONS(8765),
    [anon_sym_ENUM] = ACTIONS(8765),
    [anon_sym_Enum] = ACTIONS(8765),
    [anon_sym_eNUM] = ACTIONS(8765),
    [anon_sym_eNum] = ACTIONS(8765),
    [anon_sym_ENum] = ACTIONS(8765),
    [sym_var_keyword] = ACTIONS(613),
    [sym_local_keyword] = ACTIONS(8882),
    [sym_internal_keyword] = ACTIONS(8747),
    [sym_protected_keyword] = ACTIONS(8882),
    [sym_key_keyword] = ACTIONS(8755),
    [sym_dataset_keyword] = ACTIONS(8755),
    [sym_quoted_identifier] = ACTIONS(8767),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8767),
    [sym_integer] = ACTIONS(8767),
    [sym_preproc_open] = ACTIONS(611),
    [sym_preproc_close] = ACTIONS(611),
  },
  [STATE(3980)] = {
    [sym__body_element] = STATE(3961),
    [sym_empty_statement] = STATE(3961),
    [sym_property] = STATE(3961),
    [sym_permissions_property] = STATE(3961),
    [sym_table_relation_property] = STATE(3961),
    [sym_fields_section] = STATE(3961),
    [sym_keys_section] = STATE(3961),
    [sym_fieldgroups_section] = STATE(3961),
    [sym_enum_value_declaration] = STATE(3961),
    [sym_labels_section] = STATE(3961),
    [sym_layout_section] = STATE(3961),
    [sym_modify_modification] = STATE(3961),
    [sym_actions_section] = STATE(3961),
    [sym_views_section] = STATE(3961),
    [sym_dataset_section] = STATE(3961),
    [sym_requestpage_section] = STATE(3961),
    [sym_rendering_section] = STATE(3961),
    [sym_elements_section] = STATE(3961),
    [sym_schema_section] = STATE(3961),
    [sym_xmlport_element] = STATE(3961),
    [sym__xmlport_body_element] = STATE(3961),
    [sym_preproc_conditional_xmlport] = STATE(3961),
    [sym_xmlport_attribute] = STATE(3961),
    [sym_assembly_declaration] = STATE(3961),
    [sym_event_declaration] = STATE(3961),
    [sym_procedure] = STATE(3961),
    [sym_preproc_split_procedure] = STATE(3961),
    [sym_preproc_split_procedure_preamble] = STATE(3961),
    [sym_procedure_modifier] = STATE(17745),
    [sym_trigger_declaration] = STATE(3961),
    [sym_var_section] = STATE(3961),
    [sym_attribute_item] = STATE(3961),
    [sym_preproc_conditional] = STATE(3961),
    [sym_preproc_if] = STATE(3423),
    [sym_preproc_endif] = STATE(7555),
    [aux_sym_xmlport_element_repeat1] = STATE(3961),
    [anon_sym_SEMI] = ACTIONS(7362),
    [anon_sym_LBRACK] = ACTIONS(7364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7366),
    [aux_sym_modify_modification_token1] = ACTIONS(7368),
    [aux_sym_xmlport_element_token1] = ACTIONS(7370),
    [aux_sym_xmlport_element_token2] = ACTIONS(7370),
    [aux_sym_xmlport_element_token3] = ACTIONS(7370),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7372),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7372),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7374),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7747),
    [sym_trigger_keyword] = ACTIONS(7384),
    [sym_var_keyword] = ACTIONS(7386),
    [sym_local_keyword] = ACTIONS(7388),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(7388),
    [sym_event_keyword] = ACTIONS(7390),
    [sym_fields_keyword] = ACTIONS(7392),
    [sym_keys_keyword] = ACTIONS(7394),
    [sym_fieldgroups_keyword] = ACTIONS(7396),
    [sym_actions_keyword] = ACTIONS(7398),
    [sym_layout_keyword] = ACTIONS(7400),
    [sym_dataset_keyword] = ACTIONS(7402),
    [sym_elements_keyword] = ACTIONS(7404),
    [sym_labels_keyword] = ACTIONS(7406),
    [sym_rendering_keyword] = ACTIONS(7408),
    [sym_requestpage_keyword] = ACTIONS(7410),
    [sym_schema_keyword] = ACTIONS(7412),
    [sym_views_keyword] = ACTIONS(7414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7416),
    [sym_preproc_open] = ACTIONS(7376),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(3981)] = {
    [sym_identifier] = ACTIONS(6160),
    [anon_sym_SEMI] = ACTIONS(6162),
    [aux_sym_where_condition_token1] = ACTIONS(6160),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6160),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6160),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [aux_sym_basic_type_token6] = ACTIONS(6160),
    [aux_sym_basic_type_token22] = ACTIONS(6160),
    [aux_sym_basic_type_token53] = ACTIONS(6160),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6160),
    [aux_sym_addafter_modification_token1] = ACTIONS(6160),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6160),
    [aux_sym_modify_modification_token1] = ACTIONS(6160),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6160),
    [aux_sym_movelast_modification_token1] = ACTIONS(6160),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6160),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6160),
    [aux_sym_separator_action_token1] = ACTIONS(6160),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6160),
    [aux_sym_type_declaration_token1] = ACTIONS(6160),
    [anon_sym_POUNDif] = ACTIONS(6162),
    [anon_sym_POUNDIF] = ACTIONS(6162),
    [anon_sym_POUNDIf] = ACTIONS(6162),
    [anon_sym_POUNDelif] = ACTIONS(6162),
    [anon_sym_POUNDELIF] = ACTIONS(6162),
    [anon_sym_POUNDElif] = ACTIONS(6162),
    [anon_sym_POUNDelse] = ACTIONS(6162),
    [anon_sym_POUNDELSE] = ACTIONS(6162),
    [anon_sym_POUNDElse] = ACTIONS(6162),
    [anon_sym_POUNDelse2] = ACTIONS(6162),
    [anon_sym_POUNDELSE2] = ACTIONS(6162),
    [anon_sym_POUNDElse2] = ACTIONS(6162),
    [anon_sym_POUNDendif] = ACTIONS(6162),
    [anon_sym_POUNDENDIF] = ACTIONS(6162),
    [anon_sym_POUNDEndif] = ACTIONS(6162),
    [anon_sym_POUNDendif2] = ACTIONS(6162),
    [anon_sym_POUNDENDIF2] = ACTIONS(6162),
    [anon_sym_POUNDEndif2] = ACTIONS(6162),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6160),
    [sym_procedure_keyword] = ACTIONS(6160),
    [sym_trigger_keyword] = ACTIONS(6160),
    [sym_var_keyword] = ACTIONS(6160),
    [sym_local_keyword] = ACTIONS(6160),
    [sym_internal_keyword] = ACTIONS(6160),
    [sym_protected_keyword] = ACTIONS(6160),
    [sym_event_keyword] = ACTIONS(6160),
    [sym_fields_keyword] = ACTIONS(6160),
    [sym_keys_keyword] = ACTIONS(6160),
    [sym_key_keyword] = ACTIONS(6160),
    [sym_fieldgroups_keyword] = ACTIONS(6160),
    [sym_actions_keyword] = ACTIONS(6160),
    [sym_layout_keyword] = ACTIONS(6160),
    [sym_area_keyword] = ACTIONS(6160),
    [sym_group_keyword] = ACTIONS(6160),
    [sym_repeater_keyword] = ACTIONS(6160),
    [sym_cuegroup_keyword] = ACTIONS(6160),
    [sym_fixed_keyword] = ACTIONS(6160),
    [sym_grid_keyword] = ACTIONS(6160),
    [sym_part_keyword] = ACTIONS(6160),
    [sym_systempart_keyword] = ACTIONS(6160),
    [sym_usercontrol_keyword] = ACTIONS(6160),
    [sym_dataset_keyword] = ACTIONS(6160),
    [sym_elements_keyword] = ACTIONS(6160),
    [sym_dataitem_keyword] = ACTIONS(6160),
    [sym_column_keyword] = ACTIONS(6160),
    [sym_filter_keyword] = ACTIONS(6160),
    [sym_labels_keyword] = ACTIONS(6160),
    [sym_rendering_keyword] = ACTIONS(6160),
    [sym_requestpage_keyword] = ACTIONS(6160),
    [sym_schema_keyword] = ACTIONS(6160),
    [sym_views_keyword] = ACTIONS(6160),
    [sym_quoted_identifier] = ACTIONS(6162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6162),
    [sym_preproc_open] = ACTIONS(6162),
    [sym_preproc_close] = ACTIONS(6162),
    [sym_var_attribute_open] = ACTIONS(6162),
  },
  [STATE(3982)] = {
    [sym_identifier] = ACTIONS(8885),
    [anon_sym_SEMI] = ACTIONS(8887),
    [aux_sym_where_condition_token1] = ACTIONS(8885),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8885),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8885),
    [anon_sym_LBRACK] = ACTIONS(8887),
    [aux_sym_basic_type_token6] = ACTIONS(8885),
    [aux_sym_basic_type_token22] = ACTIONS(8885),
    [aux_sym_basic_type_token53] = ACTIONS(8885),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8885),
    [aux_sym_addafter_modification_token1] = ACTIONS(8885),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8885),
    [aux_sym_modify_modification_token1] = ACTIONS(8885),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8885),
    [aux_sym_movelast_modification_token1] = ACTIONS(8885),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8885),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8885),
    [aux_sym_separator_action_token1] = ACTIONS(8885),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8885),
    [aux_sym_type_declaration_token1] = ACTIONS(8885),
    [anon_sym_POUNDif] = ACTIONS(8887),
    [anon_sym_POUNDIF] = ACTIONS(8887),
    [anon_sym_POUNDIf] = ACTIONS(8887),
    [anon_sym_POUNDelif] = ACTIONS(8887),
    [anon_sym_POUNDELIF] = ACTIONS(8887),
    [anon_sym_POUNDElif] = ACTIONS(8887),
    [anon_sym_POUNDelse] = ACTIONS(8887),
    [anon_sym_POUNDELSE] = ACTIONS(8887),
    [anon_sym_POUNDElse] = ACTIONS(8887),
    [anon_sym_POUNDelse2] = ACTIONS(8887),
    [anon_sym_POUNDELSE2] = ACTIONS(8887),
    [anon_sym_POUNDElse2] = ACTIONS(8887),
    [anon_sym_POUNDendif] = ACTIONS(8887),
    [anon_sym_POUNDENDIF] = ACTIONS(8887),
    [anon_sym_POUNDEndif] = ACTIONS(8887),
    [anon_sym_POUNDendif2] = ACTIONS(8887),
    [anon_sym_POUNDENDIF2] = ACTIONS(8887),
    [anon_sym_POUNDEndif2] = ACTIONS(8887),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8885),
    [sym_procedure_keyword] = ACTIONS(8885),
    [sym_trigger_keyword] = ACTIONS(8885),
    [sym_var_keyword] = ACTIONS(8885),
    [sym_local_keyword] = ACTIONS(8885),
    [sym_internal_keyword] = ACTIONS(8885),
    [sym_protected_keyword] = ACTIONS(8885),
    [sym_event_keyword] = ACTIONS(8885),
    [sym_fields_keyword] = ACTIONS(8885),
    [sym_keys_keyword] = ACTIONS(8885),
    [sym_key_keyword] = ACTIONS(8885),
    [sym_fieldgroups_keyword] = ACTIONS(8885),
    [sym_actions_keyword] = ACTIONS(8885),
    [sym_layout_keyword] = ACTIONS(8885),
    [sym_area_keyword] = ACTIONS(8885),
    [sym_group_keyword] = ACTIONS(8885),
    [sym_repeater_keyword] = ACTIONS(8885),
    [sym_cuegroup_keyword] = ACTIONS(8885),
    [sym_fixed_keyword] = ACTIONS(8885),
    [sym_grid_keyword] = ACTIONS(8885),
    [sym_part_keyword] = ACTIONS(8885),
    [sym_systempart_keyword] = ACTIONS(8885),
    [sym_usercontrol_keyword] = ACTIONS(8885),
    [sym_dataset_keyword] = ACTIONS(8885),
    [sym_elements_keyword] = ACTIONS(8885),
    [sym_dataitem_keyword] = ACTIONS(8885),
    [sym_column_keyword] = ACTIONS(8885),
    [sym_filter_keyword] = ACTIONS(8885),
    [sym_labels_keyword] = ACTIONS(8885),
    [sym_rendering_keyword] = ACTIONS(8885),
    [sym_requestpage_keyword] = ACTIONS(8885),
    [sym_schema_keyword] = ACTIONS(8885),
    [sym_views_keyword] = ACTIONS(8885),
    [sym_quoted_identifier] = ACTIONS(8887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8887),
    [sym_preproc_open] = ACTIONS(8887),
    [sym_preproc_close] = ACTIONS(8887),
    [sym_var_attribute_open] = ACTIONS(8887),
  },
  [STATE(3983)] = {
    [sym_identifier] = ACTIONS(8889),
    [anon_sym_SEMI] = ACTIONS(8891),
    [aux_sym_where_condition_token1] = ACTIONS(8889),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8889),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8889),
    [anon_sym_LBRACK] = ACTIONS(8891),
    [aux_sym_basic_type_token6] = ACTIONS(8889),
    [aux_sym_basic_type_token22] = ACTIONS(8889),
    [aux_sym_basic_type_token53] = ACTIONS(8889),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8889),
    [aux_sym_addafter_modification_token1] = ACTIONS(8889),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8889),
    [aux_sym_modify_modification_token1] = ACTIONS(8889),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8889),
    [aux_sym_movelast_modification_token1] = ACTIONS(8889),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8889),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8889),
    [aux_sym_separator_action_token1] = ACTIONS(8889),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8889),
    [aux_sym_type_declaration_token1] = ACTIONS(8889),
    [anon_sym_POUNDif] = ACTIONS(8891),
    [anon_sym_POUNDIF] = ACTIONS(8891),
    [anon_sym_POUNDIf] = ACTIONS(8891),
    [anon_sym_POUNDelif] = ACTIONS(8891),
    [anon_sym_POUNDELIF] = ACTIONS(8891),
    [anon_sym_POUNDElif] = ACTIONS(8891),
    [anon_sym_POUNDelse] = ACTIONS(8891),
    [anon_sym_POUNDELSE] = ACTIONS(8891),
    [anon_sym_POUNDElse] = ACTIONS(8891),
    [anon_sym_POUNDelse2] = ACTIONS(8891),
    [anon_sym_POUNDELSE2] = ACTIONS(8891),
    [anon_sym_POUNDElse2] = ACTIONS(8891),
    [anon_sym_POUNDendif] = ACTIONS(8891),
    [anon_sym_POUNDENDIF] = ACTIONS(8891),
    [anon_sym_POUNDEndif] = ACTIONS(8891),
    [anon_sym_POUNDendif2] = ACTIONS(8891),
    [anon_sym_POUNDENDIF2] = ACTIONS(8891),
    [anon_sym_POUNDEndif2] = ACTIONS(8891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8889),
    [sym_procedure_keyword] = ACTIONS(8889),
    [sym_trigger_keyword] = ACTIONS(8889),
    [sym_var_keyword] = ACTIONS(8889),
    [sym_local_keyword] = ACTIONS(8889),
    [sym_internal_keyword] = ACTIONS(8889),
    [sym_protected_keyword] = ACTIONS(8889),
    [sym_event_keyword] = ACTIONS(8889),
    [sym_fields_keyword] = ACTIONS(8889),
    [sym_keys_keyword] = ACTIONS(8889),
    [sym_key_keyword] = ACTIONS(8889),
    [sym_fieldgroups_keyword] = ACTIONS(8889),
    [sym_actions_keyword] = ACTIONS(8889),
    [sym_layout_keyword] = ACTIONS(8889),
    [sym_area_keyword] = ACTIONS(8889),
    [sym_group_keyword] = ACTIONS(8889),
    [sym_repeater_keyword] = ACTIONS(8889),
    [sym_cuegroup_keyword] = ACTIONS(8889),
    [sym_fixed_keyword] = ACTIONS(8889),
    [sym_grid_keyword] = ACTIONS(8889),
    [sym_part_keyword] = ACTIONS(8889),
    [sym_systempart_keyword] = ACTIONS(8889),
    [sym_usercontrol_keyword] = ACTIONS(8889),
    [sym_dataset_keyword] = ACTIONS(8889),
    [sym_elements_keyword] = ACTIONS(8889),
    [sym_dataitem_keyword] = ACTIONS(8889),
    [sym_column_keyword] = ACTIONS(8889),
    [sym_filter_keyword] = ACTIONS(8889),
    [sym_labels_keyword] = ACTIONS(8889),
    [sym_rendering_keyword] = ACTIONS(8889),
    [sym_requestpage_keyword] = ACTIONS(8889),
    [sym_schema_keyword] = ACTIONS(8889),
    [sym_views_keyword] = ACTIONS(8889),
    [sym_quoted_identifier] = ACTIONS(8891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8891),
    [sym_preproc_open] = ACTIONS(8891),
    [sym_preproc_close] = ACTIONS(8891),
    [sym_var_attribute_open] = ACTIONS(8891),
  },
  [STATE(3984)] = {
    [sym_identifier] = ACTIONS(8889),
    [anon_sym_SEMI] = ACTIONS(8891),
    [aux_sym_where_condition_token1] = ACTIONS(8889),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8889),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8889),
    [anon_sym_LBRACK] = ACTIONS(8891),
    [aux_sym_basic_type_token6] = ACTIONS(8889),
    [aux_sym_basic_type_token22] = ACTIONS(8889),
    [aux_sym_basic_type_token53] = ACTIONS(8889),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8889),
    [aux_sym_addafter_modification_token1] = ACTIONS(8889),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8889),
    [aux_sym_modify_modification_token1] = ACTIONS(8889),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8889),
    [aux_sym_movelast_modification_token1] = ACTIONS(8889),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8889),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8889),
    [aux_sym_separator_action_token1] = ACTIONS(8889),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8889),
    [aux_sym_type_declaration_token1] = ACTIONS(8889),
    [anon_sym_POUNDif] = ACTIONS(8891),
    [anon_sym_POUNDIF] = ACTIONS(8891),
    [anon_sym_POUNDIf] = ACTIONS(8891),
    [anon_sym_POUNDelif] = ACTIONS(8891),
    [anon_sym_POUNDELIF] = ACTIONS(8891),
    [anon_sym_POUNDElif] = ACTIONS(8891),
    [anon_sym_POUNDelse] = ACTIONS(8891),
    [anon_sym_POUNDELSE] = ACTIONS(8891),
    [anon_sym_POUNDElse] = ACTIONS(8891),
    [anon_sym_POUNDelse2] = ACTIONS(8891),
    [anon_sym_POUNDELSE2] = ACTIONS(8891),
    [anon_sym_POUNDElse2] = ACTIONS(8891),
    [anon_sym_POUNDendif] = ACTIONS(8891),
    [anon_sym_POUNDENDIF] = ACTIONS(8891),
    [anon_sym_POUNDEndif] = ACTIONS(8891),
    [anon_sym_POUNDendif2] = ACTIONS(8891),
    [anon_sym_POUNDENDIF2] = ACTIONS(8891),
    [anon_sym_POUNDEndif2] = ACTIONS(8891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8889),
    [sym_procedure_keyword] = ACTIONS(8889),
    [sym_trigger_keyword] = ACTIONS(8889),
    [sym_var_keyword] = ACTIONS(8889),
    [sym_local_keyword] = ACTIONS(8889),
    [sym_internal_keyword] = ACTIONS(8889),
    [sym_protected_keyword] = ACTIONS(8889),
    [sym_event_keyword] = ACTIONS(8889),
    [sym_fields_keyword] = ACTIONS(8889),
    [sym_keys_keyword] = ACTIONS(8889),
    [sym_key_keyword] = ACTIONS(8889),
    [sym_fieldgroups_keyword] = ACTIONS(8889),
    [sym_actions_keyword] = ACTIONS(8889),
    [sym_layout_keyword] = ACTIONS(8889),
    [sym_area_keyword] = ACTIONS(8889),
    [sym_group_keyword] = ACTIONS(8889),
    [sym_repeater_keyword] = ACTIONS(8889),
    [sym_cuegroup_keyword] = ACTIONS(8889),
    [sym_fixed_keyword] = ACTIONS(8889),
    [sym_grid_keyword] = ACTIONS(8889),
    [sym_part_keyword] = ACTIONS(8889),
    [sym_systempart_keyword] = ACTIONS(8889),
    [sym_usercontrol_keyword] = ACTIONS(8889),
    [sym_dataset_keyword] = ACTIONS(8889),
    [sym_elements_keyword] = ACTIONS(8889),
    [sym_dataitem_keyword] = ACTIONS(8889),
    [sym_column_keyword] = ACTIONS(8889),
    [sym_filter_keyword] = ACTIONS(8889),
    [sym_labels_keyword] = ACTIONS(8889),
    [sym_rendering_keyword] = ACTIONS(8889),
    [sym_requestpage_keyword] = ACTIONS(8889),
    [sym_schema_keyword] = ACTIONS(8889),
    [sym_views_keyword] = ACTIONS(8889),
    [sym_quoted_identifier] = ACTIONS(8891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8891),
    [sym_preproc_open] = ACTIONS(8891),
    [sym_preproc_close] = ACTIONS(8891),
    [sym_var_attribute_open] = ACTIONS(8891),
  },
  [STATE(3985)] = {
    [sym_identifier] = ACTIONS(6136),
    [anon_sym_SEMI] = ACTIONS(6138),
    [aux_sym_where_condition_token1] = ACTIONS(6136),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6136),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6136),
    [anon_sym_LBRACK] = ACTIONS(6138),
    [aux_sym_basic_type_token6] = ACTIONS(6136),
    [aux_sym_basic_type_token22] = ACTIONS(6136),
    [aux_sym_basic_type_token53] = ACTIONS(6136),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6136),
    [aux_sym_addafter_modification_token1] = ACTIONS(6136),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6136),
    [aux_sym_modify_modification_token1] = ACTIONS(6136),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6136),
    [aux_sym_movelast_modification_token1] = ACTIONS(6136),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6136),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6136),
    [aux_sym_separator_action_token1] = ACTIONS(6136),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6136),
    [aux_sym_type_declaration_token1] = ACTIONS(6136),
    [anon_sym_POUNDif] = ACTIONS(6138),
    [anon_sym_POUNDIF] = ACTIONS(6138),
    [anon_sym_POUNDIf] = ACTIONS(6138),
    [anon_sym_POUNDelif] = ACTIONS(6138),
    [anon_sym_POUNDELIF] = ACTIONS(6138),
    [anon_sym_POUNDElif] = ACTIONS(6138),
    [anon_sym_POUNDelse] = ACTIONS(6138),
    [anon_sym_POUNDELSE] = ACTIONS(6138),
    [anon_sym_POUNDElse] = ACTIONS(6138),
    [anon_sym_POUNDelse2] = ACTIONS(6138),
    [anon_sym_POUNDELSE2] = ACTIONS(6138),
    [anon_sym_POUNDElse2] = ACTIONS(6138),
    [anon_sym_POUNDendif] = ACTIONS(6138),
    [anon_sym_POUNDENDIF] = ACTIONS(6138),
    [anon_sym_POUNDEndif] = ACTIONS(6138),
    [anon_sym_POUNDendif2] = ACTIONS(6138),
    [anon_sym_POUNDENDIF2] = ACTIONS(6138),
    [anon_sym_POUNDEndif2] = ACTIONS(6138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6136),
    [sym_procedure_keyword] = ACTIONS(6136),
    [sym_trigger_keyword] = ACTIONS(6136),
    [sym_var_keyword] = ACTIONS(6136),
    [sym_local_keyword] = ACTIONS(6136),
    [sym_internal_keyword] = ACTIONS(6136),
    [sym_protected_keyword] = ACTIONS(6136),
    [sym_event_keyword] = ACTIONS(6136),
    [sym_fields_keyword] = ACTIONS(6136),
    [sym_keys_keyword] = ACTIONS(6136),
    [sym_key_keyword] = ACTIONS(6136),
    [sym_fieldgroups_keyword] = ACTIONS(6136),
    [sym_actions_keyword] = ACTIONS(6136),
    [sym_layout_keyword] = ACTIONS(6136),
    [sym_area_keyword] = ACTIONS(6136),
    [sym_group_keyword] = ACTIONS(6136),
    [sym_repeater_keyword] = ACTIONS(6136),
    [sym_cuegroup_keyword] = ACTIONS(6136),
    [sym_fixed_keyword] = ACTIONS(6136),
    [sym_grid_keyword] = ACTIONS(6136),
    [sym_part_keyword] = ACTIONS(6136),
    [sym_systempart_keyword] = ACTIONS(6136),
    [sym_usercontrol_keyword] = ACTIONS(6136),
    [sym_dataset_keyword] = ACTIONS(6136),
    [sym_elements_keyword] = ACTIONS(6136),
    [sym_dataitem_keyword] = ACTIONS(6136),
    [sym_column_keyword] = ACTIONS(6136),
    [sym_filter_keyword] = ACTIONS(6136),
    [sym_labels_keyword] = ACTIONS(6136),
    [sym_rendering_keyword] = ACTIONS(6136),
    [sym_requestpage_keyword] = ACTIONS(6136),
    [sym_schema_keyword] = ACTIONS(6136),
    [sym_views_keyword] = ACTIONS(6136),
    [sym_quoted_identifier] = ACTIONS(6138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6138),
    [sym_preproc_open] = ACTIONS(6138),
    [sym_preproc_close] = ACTIONS(6138),
    [sym_var_attribute_open] = ACTIONS(6138),
  },
  [STATE(3986)] = {
    [sym_identifier] = ACTIONS(6140),
    [anon_sym_SEMI] = ACTIONS(6142),
    [aux_sym_where_condition_token1] = ACTIONS(6140),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6140),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6140),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [aux_sym_basic_type_token6] = ACTIONS(6140),
    [aux_sym_basic_type_token22] = ACTIONS(6140),
    [aux_sym_basic_type_token53] = ACTIONS(6140),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6140),
    [aux_sym_addafter_modification_token1] = ACTIONS(6140),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6140),
    [aux_sym_modify_modification_token1] = ACTIONS(6140),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6140),
    [aux_sym_movelast_modification_token1] = ACTIONS(6140),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6140),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6140),
    [aux_sym_separator_action_token1] = ACTIONS(6140),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6140),
    [aux_sym_type_declaration_token1] = ACTIONS(6140),
    [anon_sym_POUNDif] = ACTIONS(6142),
    [anon_sym_POUNDIF] = ACTIONS(6142),
    [anon_sym_POUNDIf] = ACTIONS(6142),
    [anon_sym_POUNDelif] = ACTIONS(6142),
    [anon_sym_POUNDELIF] = ACTIONS(6142),
    [anon_sym_POUNDElif] = ACTIONS(6142),
    [anon_sym_POUNDelse] = ACTIONS(6142),
    [anon_sym_POUNDELSE] = ACTIONS(6142),
    [anon_sym_POUNDElse] = ACTIONS(6142),
    [anon_sym_POUNDelse2] = ACTIONS(6142),
    [anon_sym_POUNDELSE2] = ACTIONS(6142),
    [anon_sym_POUNDElse2] = ACTIONS(6142),
    [anon_sym_POUNDendif] = ACTIONS(6142),
    [anon_sym_POUNDENDIF] = ACTIONS(6142),
    [anon_sym_POUNDEndif] = ACTIONS(6142),
    [anon_sym_POUNDendif2] = ACTIONS(6142),
    [anon_sym_POUNDENDIF2] = ACTIONS(6142),
    [anon_sym_POUNDEndif2] = ACTIONS(6142),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6140),
    [sym_procedure_keyword] = ACTIONS(6140),
    [sym_trigger_keyword] = ACTIONS(6140),
    [sym_var_keyword] = ACTIONS(6140),
    [sym_local_keyword] = ACTIONS(6140),
    [sym_internal_keyword] = ACTIONS(6140),
    [sym_protected_keyword] = ACTIONS(6140),
    [sym_event_keyword] = ACTIONS(6140),
    [sym_fields_keyword] = ACTIONS(6140),
    [sym_keys_keyword] = ACTIONS(6140),
    [sym_key_keyword] = ACTIONS(6140),
    [sym_fieldgroups_keyword] = ACTIONS(6140),
    [sym_actions_keyword] = ACTIONS(6140),
    [sym_layout_keyword] = ACTIONS(6140),
    [sym_area_keyword] = ACTIONS(6140),
    [sym_group_keyword] = ACTIONS(6140),
    [sym_repeater_keyword] = ACTIONS(6140),
    [sym_cuegroup_keyword] = ACTIONS(6140),
    [sym_fixed_keyword] = ACTIONS(6140),
    [sym_grid_keyword] = ACTIONS(6140),
    [sym_part_keyword] = ACTIONS(6140),
    [sym_systempart_keyword] = ACTIONS(6140),
    [sym_usercontrol_keyword] = ACTIONS(6140),
    [sym_dataset_keyword] = ACTIONS(6140),
    [sym_elements_keyword] = ACTIONS(6140),
    [sym_dataitem_keyword] = ACTIONS(6140),
    [sym_column_keyword] = ACTIONS(6140),
    [sym_filter_keyword] = ACTIONS(6140),
    [sym_labels_keyword] = ACTIONS(6140),
    [sym_rendering_keyword] = ACTIONS(6140),
    [sym_requestpage_keyword] = ACTIONS(6140),
    [sym_schema_keyword] = ACTIONS(6140),
    [sym_views_keyword] = ACTIONS(6140),
    [sym_quoted_identifier] = ACTIONS(6142),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6142),
    [sym_preproc_open] = ACTIONS(6142),
    [sym_preproc_close] = ACTIONS(6142),
    [sym_var_attribute_open] = ACTIONS(6142),
  },
  [STATE(3987)] = {
    [sym_identifier] = ACTIONS(6144),
    [anon_sym_SEMI] = ACTIONS(6146),
    [aux_sym_where_condition_token1] = ACTIONS(6144),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6144),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6144),
    [anon_sym_LBRACK] = ACTIONS(6146),
    [aux_sym_basic_type_token6] = ACTIONS(6144),
    [aux_sym_basic_type_token22] = ACTIONS(6144),
    [aux_sym_basic_type_token53] = ACTIONS(6144),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6144),
    [aux_sym_addafter_modification_token1] = ACTIONS(6144),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6144),
    [aux_sym_modify_modification_token1] = ACTIONS(6144),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6144),
    [aux_sym_movelast_modification_token1] = ACTIONS(6144),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6144),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6144),
    [aux_sym_separator_action_token1] = ACTIONS(6144),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6144),
    [aux_sym_type_declaration_token1] = ACTIONS(6144),
    [anon_sym_POUNDif] = ACTIONS(6146),
    [anon_sym_POUNDIF] = ACTIONS(6146),
    [anon_sym_POUNDIf] = ACTIONS(6146),
    [anon_sym_POUNDelif] = ACTIONS(6146),
    [anon_sym_POUNDELIF] = ACTIONS(6146),
    [anon_sym_POUNDElif] = ACTIONS(6146),
    [anon_sym_POUNDelse] = ACTIONS(6146),
    [anon_sym_POUNDELSE] = ACTIONS(6146),
    [anon_sym_POUNDElse] = ACTIONS(6146),
    [anon_sym_POUNDelse2] = ACTIONS(6146),
    [anon_sym_POUNDELSE2] = ACTIONS(6146),
    [anon_sym_POUNDElse2] = ACTIONS(6146),
    [anon_sym_POUNDendif] = ACTIONS(6146),
    [anon_sym_POUNDENDIF] = ACTIONS(6146),
    [anon_sym_POUNDEndif] = ACTIONS(6146),
    [anon_sym_POUNDendif2] = ACTIONS(6146),
    [anon_sym_POUNDENDIF2] = ACTIONS(6146),
    [anon_sym_POUNDEndif2] = ACTIONS(6146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6144),
    [sym_procedure_keyword] = ACTIONS(6144),
    [sym_trigger_keyword] = ACTIONS(6144),
    [sym_var_keyword] = ACTIONS(6144),
    [sym_local_keyword] = ACTIONS(6144),
    [sym_internal_keyword] = ACTIONS(6144),
    [sym_protected_keyword] = ACTIONS(6144),
    [sym_event_keyword] = ACTIONS(6144),
    [sym_fields_keyword] = ACTIONS(6144),
    [sym_keys_keyword] = ACTIONS(6144),
    [sym_key_keyword] = ACTIONS(6144),
    [sym_fieldgroups_keyword] = ACTIONS(6144),
    [sym_actions_keyword] = ACTIONS(6144),
    [sym_layout_keyword] = ACTIONS(6144),
    [sym_area_keyword] = ACTIONS(6144),
    [sym_group_keyword] = ACTIONS(6144),
    [sym_repeater_keyword] = ACTIONS(6144),
    [sym_cuegroup_keyword] = ACTIONS(6144),
    [sym_fixed_keyword] = ACTIONS(6144),
    [sym_grid_keyword] = ACTIONS(6144),
    [sym_part_keyword] = ACTIONS(6144),
    [sym_systempart_keyword] = ACTIONS(6144),
    [sym_usercontrol_keyword] = ACTIONS(6144),
    [sym_dataset_keyword] = ACTIONS(6144),
    [sym_elements_keyword] = ACTIONS(6144),
    [sym_dataitem_keyword] = ACTIONS(6144),
    [sym_column_keyword] = ACTIONS(6144),
    [sym_filter_keyword] = ACTIONS(6144),
    [sym_labels_keyword] = ACTIONS(6144),
    [sym_rendering_keyword] = ACTIONS(6144),
    [sym_requestpage_keyword] = ACTIONS(6144),
    [sym_schema_keyword] = ACTIONS(6144),
    [sym_views_keyword] = ACTIONS(6144),
    [sym_quoted_identifier] = ACTIONS(6146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6146),
    [sym_preproc_open] = ACTIONS(6146),
    [sym_preproc_close] = ACTIONS(6146),
    [sym_var_attribute_open] = ACTIONS(6146),
  },
  [STATE(3988)] = {
    [sym_identifier] = ACTIONS(6148),
    [anon_sym_SEMI] = ACTIONS(6150),
    [aux_sym_where_condition_token1] = ACTIONS(6148),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6148),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6148),
    [anon_sym_LBRACK] = ACTIONS(6150),
    [aux_sym_basic_type_token6] = ACTIONS(6148),
    [aux_sym_basic_type_token22] = ACTIONS(6148),
    [aux_sym_basic_type_token53] = ACTIONS(6148),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6148),
    [aux_sym_addafter_modification_token1] = ACTIONS(6148),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6148),
    [aux_sym_modify_modification_token1] = ACTIONS(6148),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6148),
    [aux_sym_movelast_modification_token1] = ACTIONS(6148),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6148),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6148),
    [aux_sym_separator_action_token1] = ACTIONS(6148),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6148),
    [aux_sym_type_declaration_token1] = ACTIONS(6148),
    [anon_sym_POUNDif] = ACTIONS(6150),
    [anon_sym_POUNDIF] = ACTIONS(6150),
    [anon_sym_POUNDIf] = ACTIONS(6150),
    [anon_sym_POUNDelif] = ACTIONS(6150),
    [anon_sym_POUNDELIF] = ACTIONS(6150),
    [anon_sym_POUNDElif] = ACTIONS(6150),
    [anon_sym_POUNDelse] = ACTIONS(6150),
    [anon_sym_POUNDELSE] = ACTIONS(6150),
    [anon_sym_POUNDElse] = ACTIONS(6150),
    [anon_sym_POUNDelse2] = ACTIONS(6150),
    [anon_sym_POUNDELSE2] = ACTIONS(6150),
    [anon_sym_POUNDElse2] = ACTIONS(6150),
    [anon_sym_POUNDendif] = ACTIONS(6150),
    [anon_sym_POUNDENDIF] = ACTIONS(6150),
    [anon_sym_POUNDEndif] = ACTIONS(6150),
    [anon_sym_POUNDendif2] = ACTIONS(6150),
    [anon_sym_POUNDENDIF2] = ACTIONS(6150),
    [anon_sym_POUNDEndif2] = ACTIONS(6150),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6148),
    [sym_procedure_keyword] = ACTIONS(6148),
    [sym_trigger_keyword] = ACTIONS(6148),
    [sym_var_keyword] = ACTIONS(6148),
    [sym_local_keyword] = ACTIONS(6148),
    [sym_internal_keyword] = ACTIONS(6148),
    [sym_protected_keyword] = ACTIONS(6148),
    [sym_event_keyword] = ACTIONS(6148),
    [sym_fields_keyword] = ACTIONS(6148),
    [sym_keys_keyword] = ACTIONS(6148),
    [sym_key_keyword] = ACTIONS(6148),
    [sym_fieldgroups_keyword] = ACTIONS(6148),
    [sym_actions_keyword] = ACTIONS(6148),
    [sym_layout_keyword] = ACTIONS(6148),
    [sym_area_keyword] = ACTIONS(6148),
    [sym_group_keyword] = ACTIONS(6148),
    [sym_repeater_keyword] = ACTIONS(6148),
    [sym_cuegroup_keyword] = ACTIONS(6148),
    [sym_fixed_keyword] = ACTIONS(6148),
    [sym_grid_keyword] = ACTIONS(6148),
    [sym_part_keyword] = ACTIONS(6148),
    [sym_systempart_keyword] = ACTIONS(6148),
    [sym_usercontrol_keyword] = ACTIONS(6148),
    [sym_dataset_keyword] = ACTIONS(6148),
    [sym_elements_keyword] = ACTIONS(6148),
    [sym_dataitem_keyword] = ACTIONS(6148),
    [sym_column_keyword] = ACTIONS(6148),
    [sym_filter_keyword] = ACTIONS(6148),
    [sym_labels_keyword] = ACTIONS(6148),
    [sym_rendering_keyword] = ACTIONS(6148),
    [sym_requestpage_keyword] = ACTIONS(6148),
    [sym_schema_keyword] = ACTIONS(6148),
    [sym_views_keyword] = ACTIONS(6148),
    [sym_quoted_identifier] = ACTIONS(6150),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6150),
    [sym_preproc_open] = ACTIONS(6150),
    [sym_preproc_close] = ACTIONS(6150),
    [sym_var_attribute_open] = ACTIONS(6150),
  },
  [STATE(3989)] = {
    [sym_identifier] = ACTIONS(6152),
    [anon_sym_SEMI] = ACTIONS(6154),
    [aux_sym_where_condition_token1] = ACTIONS(6152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6152),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6152),
    [anon_sym_LBRACK] = ACTIONS(6154),
    [aux_sym_basic_type_token6] = ACTIONS(6152),
    [aux_sym_basic_type_token22] = ACTIONS(6152),
    [aux_sym_basic_type_token53] = ACTIONS(6152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6152),
    [aux_sym_addafter_modification_token1] = ACTIONS(6152),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6152),
    [aux_sym_modify_modification_token1] = ACTIONS(6152),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6152),
    [aux_sym_movelast_modification_token1] = ACTIONS(6152),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6152),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6152),
    [aux_sym_separator_action_token1] = ACTIONS(6152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6152),
    [aux_sym_type_declaration_token1] = ACTIONS(6152),
    [anon_sym_POUNDif] = ACTIONS(6154),
    [anon_sym_POUNDIF] = ACTIONS(6154),
    [anon_sym_POUNDIf] = ACTIONS(6154),
    [anon_sym_POUNDelif] = ACTIONS(6154),
    [anon_sym_POUNDELIF] = ACTIONS(6154),
    [anon_sym_POUNDElif] = ACTIONS(6154),
    [anon_sym_POUNDelse] = ACTIONS(6154),
    [anon_sym_POUNDELSE] = ACTIONS(6154),
    [anon_sym_POUNDElse] = ACTIONS(6154),
    [anon_sym_POUNDelse2] = ACTIONS(6154),
    [anon_sym_POUNDELSE2] = ACTIONS(6154),
    [anon_sym_POUNDElse2] = ACTIONS(6154),
    [anon_sym_POUNDendif] = ACTIONS(6154),
    [anon_sym_POUNDENDIF] = ACTIONS(6154),
    [anon_sym_POUNDEndif] = ACTIONS(6154),
    [anon_sym_POUNDendif2] = ACTIONS(6154),
    [anon_sym_POUNDENDIF2] = ACTIONS(6154),
    [anon_sym_POUNDEndif2] = ACTIONS(6154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6152),
    [sym_procedure_keyword] = ACTIONS(6152),
    [sym_trigger_keyword] = ACTIONS(6152),
    [sym_var_keyword] = ACTIONS(6152),
    [sym_local_keyword] = ACTIONS(6152),
    [sym_internal_keyword] = ACTIONS(6152),
    [sym_protected_keyword] = ACTIONS(6152),
    [sym_event_keyword] = ACTIONS(6152),
    [sym_fields_keyword] = ACTIONS(6152),
    [sym_keys_keyword] = ACTIONS(6152),
    [sym_key_keyword] = ACTIONS(6152),
    [sym_fieldgroups_keyword] = ACTIONS(6152),
    [sym_actions_keyword] = ACTIONS(6152),
    [sym_layout_keyword] = ACTIONS(6152),
    [sym_area_keyword] = ACTIONS(6152),
    [sym_group_keyword] = ACTIONS(6152),
    [sym_repeater_keyword] = ACTIONS(6152),
    [sym_cuegroup_keyword] = ACTIONS(6152),
    [sym_fixed_keyword] = ACTIONS(6152),
    [sym_grid_keyword] = ACTIONS(6152),
    [sym_part_keyword] = ACTIONS(6152),
    [sym_systempart_keyword] = ACTIONS(6152),
    [sym_usercontrol_keyword] = ACTIONS(6152),
    [sym_dataset_keyword] = ACTIONS(6152),
    [sym_elements_keyword] = ACTIONS(6152),
    [sym_dataitem_keyword] = ACTIONS(6152),
    [sym_column_keyword] = ACTIONS(6152),
    [sym_filter_keyword] = ACTIONS(6152),
    [sym_labels_keyword] = ACTIONS(6152),
    [sym_rendering_keyword] = ACTIONS(6152),
    [sym_requestpage_keyword] = ACTIONS(6152),
    [sym_schema_keyword] = ACTIONS(6152),
    [sym_views_keyword] = ACTIONS(6152),
    [sym_quoted_identifier] = ACTIONS(6154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6154),
    [sym_preproc_open] = ACTIONS(6154),
    [sym_preproc_close] = ACTIONS(6154),
    [sym_var_attribute_open] = ACTIONS(6154),
  },
  [STATE(3990)] = {
    [sym_identifier] = ACTIONS(6156),
    [anon_sym_SEMI] = ACTIONS(6158),
    [aux_sym_where_condition_token1] = ACTIONS(6156),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6156),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6156),
    [anon_sym_LBRACK] = ACTIONS(6158),
    [aux_sym_basic_type_token6] = ACTIONS(6156),
    [aux_sym_basic_type_token22] = ACTIONS(6156),
    [aux_sym_basic_type_token53] = ACTIONS(6156),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6156),
    [aux_sym_addafter_modification_token1] = ACTIONS(6156),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6156),
    [aux_sym_modify_modification_token1] = ACTIONS(6156),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6156),
    [aux_sym_movelast_modification_token1] = ACTIONS(6156),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6156),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6156),
    [aux_sym_separator_action_token1] = ACTIONS(6156),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6156),
    [aux_sym_type_declaration_token1] = ACTIONS(6156),
    [anon_sym_POUNDif] = ACTIONS(6158),
    [anon_sym_POUNDIF] = ACTIONS(6158),
    [anon_sym_POUNDIf] = ACTIONS(6158),
    [anon_sym_POUNDelif] = ACTIONS(6158),
    [anon_sym_POUNDELIF] = ACTIONS(6158),
    [anon_sym_POUNDElif] = ACTIONS(6158),
    [anon_sym_POUNDelse] = ACTIONS(6158),
    [anon_sym_POUNDELSE] = ACTIONS(6158),
    [anon_sym_POUNDElse] = ACTIONS(6158),
    [anon_sym_POUNDelse2] = ACTIONS(6158),
    [anon_sym_POUNDELSE2] = ACTIONS(6158),
    [anon_sym_POUNDElse2] = ACTIONS(6158),
    [anon_sym_POUNDendif] = ACTIONS(6158),
    [anon_sym_POUNDENDIF] = ACTIONS(6158),
    [anon_sym_POUNDEndif] = ACTIONS(6158),
    [anon_sym_POUNDendif2] = ACTIONS(6158),
    [anon_sym_POUNDENDIF2] = ACTIONS(6158),
    [anon_sym_POUNDEndif2] = ACTIONS(6158),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6156),
    [sym_procedure_keyword] = ACTIONS(6156),
    [sym_trigger_keyword] = ACTIONS(6156),
    [sym_var_keyword] = ACTIONS(6156),
    [sym_local_keyword] = ACTIONS(6156),
    [sym_internal_keyword] = ACTIONS(6156),
    [sym_protected_keyword] = ACTIONS(6156),
    [sym_event_keyword] = ACTIONS(6156),
    [sym_fields_keyword] = ACTIONS(6156),
    [sym_keys_keyword] = ACTIONS(6156),
    [sym_key_keyword] = ACTIONS(6156),
    [sym_fieldgroups_keyword] = ACTIONS(6156),
    [sym_actions_keyword] = ACTIONS(6156),
    [sym_layout_keyword] = ACTIONS(6156),
    [sym_area_keyword] = ACTIONS(6156),
    [sym_group_keyword] = ACTIONS(6156),
    [sym_repeater_keyword] = ACTIONS(6156),
    [sym_cuegroup_keyword] = ACTIONS(6156),
    [sym_fixed_keyword] = ACTIONS(6156),
    [sym_grid_keyword] = ACTIONS(6156),
    [sym_part_keyword] = ACTIONS(6156),
    [sym_systempart_keyword] = ACTIONS(6156),
    [sym_usercontrol_keyword] = ACTIONS(6156),
    [sym_dataset_keyword] = ACTIONS(6156),
    [sym_elements_keyword] = ACTIONS(6156),
    [sym_dataitem_keyword] = ACTIONS(6156),
    [sym_column_keyword] = ACTIONS(6156),
    [sym_filter_keyword] = ACTIONS(6156),
    [sym_labels_keyword] = ACTIONS(6156),
    [sym_rendering_keyword] = ACTIONS(6156),
    [sym_requestpage_keyword] = ACTIONS(6156),
    [sym_schema_keyword] = ACTIONS(6156),
    [sym_views_keyword] = ACTIONS(6156),
    [sym_quoted_identifier] = ACTIONS(6158),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6158),
    [sym_preproc_open] = ACTIONS(6158),
    [sym_preproc_close] = ACTIONS(6158),
    [sym_var_attribute_open] = ACTIONS(6158),
  },
  [STATE(3991)] = {
    [sym_identifier] = ACTIONS(8893),
    [anon_sym_SEMI] = ACTIONS(8895),
    [aux_sym_where_condition_token1] = ACTIONS(8893),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8893),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8893),
    [anon_sym_LBRACK] = ACTIONS(8895),
    [aux_sym_basic_type_token6] = ACTIONS(8893),
    [aux_sym_basic_type_token22] = ACTIONS(8893),
    [aux_sym_basic_type_token53] = ACTIONS(8893),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8893),
    [aux_sym_addafter_modification_token1] = ACTIONS(8893),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8893),
    [aux_sym_modify_modification_token1] = ACTIONS(8893),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8893),
    [aux_sym_movelast_modification_token1] = ACTIONS(8893),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8893),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8893),
    [aux_sym_separator_action_token1] = ACTIONS(8893),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8893),
    [aux_sym_type_declaration_token1] = ACTIONS(8893),
    [anon_sym_POUNDif] = ACTIONS(8895),
    [anon_sym_POUNDIF] = ACTIONS(8895),
    [anon_sym_POUNDIf] = ACTIONS(8895),
    [anon_sym_POUNDelif] = ACTIONS(8895),
    [anon_sym_POUNDELIF] = ACTIONS(8895),
    [anon_sym_POUNDElif] = ACTIONS(8895),
    [anon_sym_POUNDelse] = ACTIONS(8895),
    [anon_sym_POUNDELSE] = ACTIONS(8895),
    [anon_sym_POUNDElse] = ACTIONS(8895),
    [anon_sym_POUNDelse2] = ACTIONS(8895),
    [anon_sym_POUNDELSE2] = ACTIONS(8895),
    [anon_sym_POUNDElse2] = ACTIONS(8895),
    [anon_sym_POUNDendif] = ACTIONS(8895),
    [anon_sym_POUNDENDIF] = ACTIONS(8895),
    [anon_sym_POUNDEndif] = ACTIONS(8895),
    [anon_sym_POUNDendif2] = ACTIONS(8895),
    [anon_sym_POUNDENDIF2] = ACTIONS(8895),
    [anon_sym_POUNDEndif2] = ACTIONS(8895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8893),
    [sym_procedure_keyword] = ACTIONS(8893),
    [sym_trigger_keyword] = ACTIONS(8893),
    [sym_var_keyword] = ACTIONS(8893),
    [sym_local_keyword] = ACTIONS(8893),
    [sym_internal_keyword] = ACTIONS(8893),
    [sym_protected_keyword] = ACTIONS(8893),
    [sym_event_keyword] = ACTIONS(8893),
    [sym_fields_keyword] = ACTIONS(8893),
    [sym_keys_keyword] = ACTIONS(8893),
    [sym_key_keyword] = ACTIONS(8893),
    [sym_fieldgroups_keyword] = ACTIONS(8893),
    [sym_actions_keyword] = ACTIONS(8893),
    [sym_layout_keyword] = ACTIONS(8893),
    [sym_area_keyword] = ACTIONS(8893),
    [sym_group_keyword] = ACTIONS(8893),
    [sym_repeater_keyword] = ACTIONS(8893),
    [sym_cuegroup_keyword] = ACTIONS(8893),
    [sym_fixed_keyword] = ACTIONS(8893),
    [sym_grid_keyword] = ACTIONS(8893),
    [sym_part_keyword] = ACTIONS(8893),
    [sym_systempart_keyword] = ACTIONS(8893),
    [sym_usercontrol_keyword] = ACTIONS(8893),
    [sym_dataset_keyword] = ACTIONS(8893),
    [sym_elements_keyword] = ACTIONS(8893),
    [sym_dataitem_keyword] = ACTIONS(8893),
    [sym_column_keyword] = ACTIONS(8893),
    [sym_filter_keyword] = ACTIONS(8893),
    [sym_labels_keyword] = ACTIONS(8893),
    [sym_rendering_keyword] = ACTIONS(8893),
    [sym_requestpage_keyword] = ACTIONS(8893),
    [sym_schema_keyword] = ACTIONS(8893),
    [sym_views_keyword] = ACTIONS(8893),
    [sym_quoted_identifier] = ACTIONS(8895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8895),
    [sym_preproc_open] = ACTIONS(8895),
    [sym_preproc_close] = ACTIONS(8895),
    [sym_var_attribute_open] = ACTIONS(8895),
  },
  [STATE(3992)] = {
    [sym_identifier] = ACTIONS(6164),
    [anon_sym_SEMI] = ACTIONS(6166),
    [aux_sym_where_condition_token1] = ACTIONS(6164),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6164),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6164),
    [anon_sym_LBRACK] = ACTIONS(6166),
    [aux_sym_basic_type_token6] = ACTIONS(6164),
    [aux_sym_basic_type_token22] = ACTIONS(6164),
    [aux_sym_basic_type_token53] = ACTIONS(6164),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6164),
    [aux_sym_addafter_modification_token1] = ACTIONS(6164),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6164),
    [aux_sym_modify_modification_token1] = ACTIONS(6164),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6164),
    [aux_sym_movelast_modification_token1] = ACTIONS(6164),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6164),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6164),
    [aux_sym_separator_action_token1] = ACTIONS(6164),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6164),
    [aux_sym_type_declaration_token1] = ACTIONS(6164),
    [anon_sym_POUNDif] = ACTIONS(6166),
    [anon_sym_POUNDIF] = ACTIONS(6166),
    [anon_sym_POUNDIf] = ACTIONS(6166),
    [anon_sym_POUNDelif] = ACTIONS(6166),
    [anon_sym_POUNDELIF] = ACTIONS(6166),
    [anon_sym_POUNDElif] = ACTIONS(6166),
    [anon_sym_POUNDelse] = ACTIONS(6166),
    [anon_sym_POUNDELSE] = ACTIONS(6166),
    [anon_sym_POUNDElse] = ACTIONS(6166),
    [anon_sym_POUNDelse2] = ACTIONS(6166),
    [anon_sym_POUNDELSE2] = ACTIONS(6166),
    [anon_sym_POUNDElse2] = ACTIONS(6166),
    [anon_sym_POUNDendif] = ACTIONS(6166),
    [anon_sym_POUNDENDIF] = ACTIONS(6166),
    [anon_sym_POUNDEndif] = ACTIONS(6166),
    [anon_sym_POUNDendif2] = ACTIONS(6166),
    [anon_sym_POUNDENDIF2] = ACTIONS(6166),
    [anon_sym_POUNDEndif2] = ACTIONS(6166),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6164),
    [sym_procedure_keyword] = ACTIONS(6164),
    [sym_trigger_keyword] = ACTIONS(6164),
    [sym_var_keyword] = ACTIONS(6164),
    [sym_local_keyword] = ACTIONS(6164),
    [sym_internal_keyword] = ACTIONS(6164),
    [sym_protected_keyword] = ACTIONS(6164),
    [sym_event_keyword] = ACTIONS(6164),
    [sym_fields_keyword] = ACTIONS(6164),
    [sym_keys_keyword] = ACTIONS(6164),
    [sym_key_keyword] = ACTIONS(6164),
    [sym_fieldgroups_keyword] = ACTIONS(6164),
    [sym_actions_keyword] = ACTIONS(6164),
    [sym_layout_keyword] = ACTIONS(6164),
    [sym_area_keyword] = ACTIONS(6164),
    [sym_group_keyword] = ACTIONS(6164),
    [sym_repeater_keyword] = ACTIONS(6164),
    [sym_cuegroup_keyword] = ACTIONS(6164),
    [sym_fixed_keyword] = ACTIONS(6164),
    [sym_grid_keyword] = ACTIONS(6164),
    [sym_part_keyword] = ACTIONS(6164),
    [sym_systempart_keyword] = ACTIONS(6164),
    [sym_usercontrol_keyword] = ACTIONS(6164),
    [sym_dataset_keyword] = ACTIONS(6164),
    [sym_elements_keyword] = ACTIONS(6164),
    [sym_dataitem_keyword] = ACTIONS(6164),
    [sym_column_keyword] = ACTIONS(6164),
    [sym_filter_keyword] = ACTIONS(6164),
    [sym_labels_keyword] = ACTIONS(6164),
    [sym_rendering_keyword] = ACTIONS(6164),
    [sym_requestpage_keyword] = ACTIONS(6164),
    [sym_schema_keyword] = ACTIONS(6164),
    [sym_views_keyword] = ACTIONS(6164),
    [sym_quoted_identifier] = ACTIONS(6166),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6166),
    [sym_preproc_open] = ACTIONS(6166),
    [sym_preproc_close] = ACTIONS(6166),
    [sym_var_attribute_open] = ACTIONS(6166),
  },
  [STATE(3993)] = {
    [sym_identifier] = ACTIONS(6168),
    [anon_sym_SEMI] = ACTIONS(6170),
    [aux_sym_where_condition_token1] = ACTIONS(6168),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6168),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6168),
    [anon_sym_LBRACK] = ACTIONS(6170),
    [aux_sym_basic_type_token6] = ACTIONS(6168),
    [aux_sym_basic_type_token22] = ACTIONS(6168),
    [aux_sym_basic_type_token53] = ACTIONS(6168),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6168),
    [aux_sym_addafter_modification_token1] = ACTIONS(6168),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6168),
    [aux_sym_modify_modification_token1] = ACTIONS(6168),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6168),
    [aux_sym_movelast_modification_token1] = ACTIONS(6168),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6168),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6168),
    [aux_sym_separator_action_token1] = ACTIONS(6168),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6168),
    [aux_sym_type_declaration_token1] = ACTIONS(6168),
    [anon_sym_POUNDif] = ACTIONS(6170),
    [anon_sym_POUNDIF] = ACTIONS(6170),
    [anon_sym_POUNDIf] = ACTIONS(6170),
    [anon_sym_POUNDelif] = ACTIONS(6170),
    [anon_sym_POUNDELIF] = ACTIONS(6170),
    [anon_sym_POUNDElif] = ACTIONS(6170),
    [anon_sym_POUNDelse] = ACTIONS(6170),
    [anon_sym_POUNDELSE] = ACTIONS(6170),
    [anon_sym_POUNDElse] = ACTIONS(6170),
    [anon_sym_POUNDelse2] = ACTIONS(6170),
    [anon_sym_POUNDELSE2] = ACTIONS(6170),
    [anon_sym_POUNDElse2] = ACTIONS(6170),
    [anon_sym_POUNDendif] = ACTIONS(6170),
    [anon_sym_POUNDENDIF] = ACTIONS(6170),
    [anon_sym_POUNDEndif] = ACTIONS(6170),
    [anon_sym_POUNDendif2] = ACTIONS(6170),
    [anon_sym_POUNDENDIF2] = ACTIONS(6170),
    [anon_sym_POUNDEndif2] = ACTIONS(6170),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6168),
    [sym_procedure_keyword] = ACTIONS(6168),
    [sym_trigger_keyword] = ACTIONS(6168),
    [sym_var_keyword] = ACTIONS(6168),
    [sym_local_keyword] = ACTIONS(6168),
    [sym_internal_keyword] = ACTIONS(6168),
    [sym_protected_keyword] = ACTIONS(6168),
    [sym_event_keyword] = ACTIONS(6168),
    [sym_fields_keyword] = ACTIONS(6168),
    [sym_keys_keyword] = ACTIONS(6168),
    [sym_key_keyword] = ACTIONS(6168),
    [sym_fieldgroups_keyword] = ACTIONS(6168),
    [sym_actions_keyword] = ACTIONS(6168),
    [sym_layout_keyword] = ACTIONS(6168),
    [sym_area_keyword] = ACTIONS(6168),
    [sym_group_keyword] = ACTIONS(6168),
    [sym_repeater_keyword] = ACTIONS(6168),
    [sym_cuegroup_keyword] = ACTIONS(6168),
    [sym_fixed_keyword] = ACTIONS(6168),
    [sym_grid_keyword] = ACTIONS(6168),
    [sym_part_keyword] = ACTIONS(6168),
    [sym_systempart_keyword] = ACTIONS(6168),
    [sym_usercontrol_keyword] = ACTIONS(6168),
    [sym_dataset_keyword] = ACTIONS(6168),
    [sym_elements_keyword] = ACTIONS(6168),
    [sym_dataitem_keyword] = ACTIONS(6168),
    [sym_column_keyword] = ACTIONS(6168),
    [sym_filter_keyword] = ACTIONS(6168),
    [sym_labels_keyword] = ACTIONS(6168),
    [sym_rendering_keyword] = ACTIONS(6168),
    [sym_requestpage_keyword] = ACTIONS(6168),
    [sym_schema_keyword] = ACTIONS(6168),
    [sym_views_keyword] = ACTIONS(6168),
    [sym_quoted_identifier] = ACTIONS(6170),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6170),
    [sym_preproc_open] = ACTIONS(6170),
    [sym_preproc_close] = ACTIONS(6170),
    [sym_var_attribute_open] = ACTIONS(6170),
  },
  [STATE(3994)] = {
    [sym_identifier] = ACTIONS(6172),
    [anon_sym_SEMI] = ACTIONS(6174),
    [aux_sym_where_condition_token1] = ACTIONS(6172),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6172),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6172),
    [anon_sym_LBRACK] = ACTIONS(6174),
    [aux_sym_basic_type_token6] = ACTIONS(6172),
    [aux_sym_basic_type_token22] = ACTIONS(6172),
    [aux_sym_basic_type_token53] = ACTIONS(6172),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6172),
    [aux_sym_addafter_modification_token1] = ACTIONS(6172),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6172),
    [aux_sym_modify_modification_token1] = ACTIONS(6172),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6172),
    [aux_sym_movelast_modification_token1] = ACTIONS(6172),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6172),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6172),
    [aux_sym_separator_action_token1] = ACTIONS(6172),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6172),
    [aux_sym_type_declaration_token1] = ACTIONS(6172),
    [anon_sym_POUNDif] = ACTIONS(6174),
    [anon_sym_POUNDIF] = ACTIONS(6174),
    [anon_sym_POUNDIf] = ACTIONS(6174),
    [anon_sym_POUNDelif] = ACTIONS(6174),
    [anon_sym_POUNDELIF] = ACTIONS(6174),
    [anon_sym_POUNDElif] = ACTIONS(6174),
    [anon_sym_POUNDelse] = ACTIONS(6174),
    [anon_sym_POUNDELSE] = ACTIONS(6174),
    [anon_sym_POUNDElse] = ACTIONS(6174),
    [anon_sym_POUNDelse2] = ACTIONS(6174),
    [anon_sym_POUNDELSE2] = ACTIONS(6174),
    [anon_sym_POUNDElse2] = ACTIONS(6174),
    [anon_sym_POUNDendif] = ACTIONS(6174),
    [anon_sym_POUNDENDIF] = ACTIONS(6174),
    [anon_sym_POUNDEndif] = ACTIONS(6174),
    [anon_sym_POUNDendif2] = ACTIONS(6174),
    [anon_sym_POUNDENDIF2] = ACTIONS(6174),
    [anon_sym_POUNDEndif2] = ACTIONS(6174),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6172),
    [sym_procedure_keyword] = ACTIONS(6172),
    [sym_trigger_keyword] = ACTIONS(6172),
    [sym_var_keyword] = ACTIONS(6172),
    [sym_local_keyword] = ACTIONS(6172),
    [sym_internal_keyword] = ACTIONS(6172),
    [sym_protected_keyword] = ACTIONS(6172),
    [sym_event_keyword] = ACTIONS(6172),
    [sym_fields_keyword] = ACTIONS(6172),
    [sym_keys_keyword] = ACTIONS(6172),
    [sym_key_keyword] = ACTIONS(6172),
    [sym_fieldgroups_keyword] = ACTIONS(6172),
    [sym_actions_keyword] = ACTIONS(6172),
    [sym_layout_keyword] = ACTIONS(6172),
    [sym_area_keyword] = ACTIONS(6172),
    [sym_group_keyword] = ACTIONS(6172),
    [sym_repeater_keyword] = ACTIONS(6172),
    [sym_cuegroup_keyword] = ACTIONS(6172),
    [sym_fixed_keyword] = ACTIONS(6172),
    [sym_grid_keyword] = ACTIONS(6172),
    [sym_part_keyword] = ACTIONS(6172),
    [sym_systempart_keyword] = ACTIONS(6172),
    [sym_usercontrol_keyword] = ACTIONS(6172),
    [sym_dataset_keyword] = ACTIONS(6172),
    [sym_elements_keyword] = ACTIONS(6172),
    [sym_dataitem_keyword] = ACTIONS(6172),
    [sym_column_keyword] = ACTIONS(6172),
    [sym_filter_keyword] = ACTIONS(6172),
    [sym_labels_keyword] = ACTIONS(6172),
    [sym_rendering_keyword] = ACTIONS(6172),
    [sym_requestpage_keyword] = ACTIONS(6172),
    [sym_schema_keyword] = ACTIONS(6172),
    [sym_views_keyword] = ACTIONS(6172),
    [sym_quoted_identifier] = ACTIONS(6174),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6174),
    [sym_preproc_open] = ACTIONS(6174),
    [sym_preproc_close] = ACTIONS(6174),
    [sym_var_attribute_open] = ACTIONS(6174),
  },
  [STATE(3995)] = {
    [sym_identifier] = ACTIONS(6176),
    [anon_sym_SEMI] = ACTIONS(6178),
    [aux_sym_where_condition_token1] = ACTIONS(6176),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6176),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6176),
    [anon_sym_LBRACK] = ACTIONS(6178),
    [aux_sym_basic_type_token6] = ACTIONS(6176),
    [aux_sym_basic_type_token22] = ACTIONS(6176),
    [aux_sym_basic_type_token53] = ACTIONS(6176),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6176),
    [aux_sym_addafter_modification_token1] = ACTIONS(6176),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6176),
    [aux_sym_modify_modification_token1] = ACTIONS(6176),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6176),
    [aux_sym_movelast_modification_token1] = ACTIONS(6176),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6176),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6176),
    [aux_sym_separator_action_token1] = ACTIONS(6176),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6176),
    [aux_sym_type_declaration_token1] = ACTIONS(6176),
    [anon_sym_POUNDif] = ACTIONS(6178),
    [anon_sym_POUNDIF] = ACTIONS(6178),
    [anon_sym_POUNDIf] = ACTIONS(6178),
    [anon_sym_POUNDelif] = ACTIONS(6178),
    [anon_sym_POUNDELIF] = ACTIONS(6178),
    [anon_sym_POUNDElif] = ACTIONS(6178),
    [anon_sym_POUNDelse] = ACTIONS(6178),
    [anon_sym_POUNDELSE] = ACTIONS(6178),
    [anon_sym_POUNDElse] = ACTIONS(6178),
    [anon_sym_POUNDelse2] = ACTIONS(6178),
    [anon_sym_POUNDELSE2] = ACTIONS(6178),
    [anon_sym_POUNDElse2] = ACTIONS(6178),
    [anon_sym_POUNDendif] = ACTIONS(6178),
    [anon_sym_POUNDENDIF] = ACTIONS(6178),
    [anon_sym_POUNDEndif] = ACTIONS(6178),
    [anon_sym_POUNDendif2] = ACTIONS(6178),
    [anon_sym_POUNDENDIF2] = ACTIONS(6178),
    [anon_sym_POUNDEndif2] = ACTIONS(6178),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6176),
    [sym_procedure_keyword] = ACTIONS(6176),
    [sym_trigger_keyword] = ACTIONS(6176),
    [sym_var_keyword] = ACTIONS(6176),
    [sym_local_keyword] = ACTIONS(6176),
    [sym_internal_keyword] = ACTIONS(6176),
    [sym_protected_keyword] = ACTIONS(6176),
    [sym_event_keyword] = ACTIONS(6176),
    [sym_fields_keyword] = ACTIONS(6176),
    [sym_keys_keyword] = ACTIONS(6176),
    [sym_key_keyword] = ACTIONS(6176),
    [sym_fieldgroups_keyword] = ACTIONS(6176),
    [sym_actions_keyword] = ACTIONS(6176),
    [sym_layout_keyword] = ACTIONS(6176),
    [sym_area_keyword] = ACTIONS(6176),
    [sym_group_keyword] = ACTIONS(6176),
    [sym_repeater_keyword] = ACTIONS(6176),
    [sym_cuegroup_keyword] = ACTIONS(6176),
    [sym_fixed_keyword] = ACTIONS(6176),
    [sym_grid_keyword] = ACTIONS(6176),
    [sym_part_keyword] = ACTIONS(6176),
    [sym_systempart_keyword] = ACTIONS(6176),
    [sym_usercontrol_keyword] = ACTIONS(6176),
    [sym_dataset_keyword] = ACTIONS(6176),
    [sym_elements_keyword] = ACTIONS(6176),
    [sym_dataitem_keyword] = ACTIONS(6176),
    [sym_column_keyword] = ACTIONS(6176),
    [sym_filter_keyword] = ACTIONS(6176),
    [sym_labels_keyword] = ACTIONS(6176),
    [sym_rendering_keyword] = ACTIONS(6176),
    [sym_requestpage_keyword] = ACTIONS(6176),
    [sym_schema_keyword] = ACTIONS(6176),
    [sym_views_keyword] = ACTIONS(6176),
    [sym_quoted_identifier] = ACTIONS(6178),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6178),
    [sym_preproc_open] = ACTIONS(6178),
    [sym_preproc_close] = ACTIONS(6178),
    [sym_var_attribute_open] = ACTIONS(6178),
  },
  [STATE(3996)] = {
    [sym_identifier] = ACTIONS(6180),
    [anon_sym_SEMI] = ACTIONS(6182),
    [aux_sym_where_condition_token1] = ACTIONS(6180),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6180),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6180),
    [anon_sym_LBRACK] = ACTIONS(6182),
    [aux_sym_basic_type_token6] = ACTIONS(6180),
    [aux_sym_basic_type_token22] = ACTIONS(6180),
    [aux_sym_basic_type_token53] = ACTIONS(6180),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6180),
    [aux_sym_addafter_modification_token1] = ACTIONS(6180),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6180),
    [aux_sym_modify_modification_token1] = ACTIONS(6180),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6180),
    [aux_sym_movelast_modification_token1] = ACTIONS(6180),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6180),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6180),
    [aux_sym_separator_action_token1] = ACTIONS(6180),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6180),
    [aux_sym_type_declaration_token1] = ACTIONS(6180),
    [anon_sym_POUNDif] = ACTIONS(6182),
    [anon_sym_POUNDIF] = ACTIONS(6182),
    [anon_sym_POUNDIf] = ACTIONS(6182),
    [anon_sym_POUNDelif] = ACTIONS(6182),
    [anon_sym_POUNDELIF] = ACTIONS(6182),
    [anon_sym_POUNDElif] = ACTIONS(6182),
    [anon_sym_POUNDelse] = ACTIONS(6182),
    [anon_sym_POUNDELSE] = ACTIONS(6182),
    [anon_sym_POUNDElse] = ACTIONS(6182),
    [anon_sym_POUNDelse2] = ACTIONS(6182),
    [anon_sym_POUNDELSE2] = ACTIONS(6182),
    [anon_sym_POUNDElse2] = ACTIONS(6182),
    [anon_sym_POUNDendif] = ACTIONS(6182),
    [anon_sym_POUNDENDIF] = ACTIONS(6182),
    [anon_sym_POUNDEndif] = ACTIONS(6182),
    [anon_sym_POUNDendif2] = ACTIONS(6182),
    [anon_sym_POUNDENDIF2] = ACTIONS(6182),
    [anon_sym_POUNDEndif2] = ACTIONS(6182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6180),
    [sym_procedure_keyword] = ACTIONS(6180),
    [sym_trigger_keyword] = ACTIONS(6180),
    [sym_var_keyword] = ACTIONS(6180),
    [sym_local_keyword] = ACTIONS(6180),
    [sym_internal_keyword] = ACTIONS(6180),
    [sym_protected_keyword] = ACTIONS(6180),
    [sym_event_keyword] = ACTIONS(6180),
    [sym_fields_keyword] = ACTIONS(6180),
    [sym_keys_keyword] = ACTIONS(6180),
    [sym_key_keyword] = ACTIONS(6180),
    [sym_fieldgroups_keyword] = ACTIONS(6180),
    [sym_actions_keyword] = ACTIONS(6180),
    [sym_layout_keyword] = ACTIONS(6180),
    [sym_area_keyword] = ACTIONS(6180),
    [sym_group_keyword] = ACTIONS(6180),
    [sym_repeater_keyword] = ACTIONS(6180),
    [sym_cuegroup_keyword] = ACTIONS(6180),
    [sym_fixed_keyword] = ACTIONS(6180),
    [sym_grid_keyword] = ACTIONS(6180),
    [sym_part_keyword] = ACTIONS(6180),
    [sym_systempart_keyword] = ACTIONS(6180),
    [sym_usercontrol_keyword] = ACTIONS(6180),
    [sym_dataset_keyword] = ACTIONS(6180),
    [sym_elements_keyword] = ACTIONS(6180),
    [sym_dataitem_keyword] = ACTIONS(6180),
    [sym_column_keyword] = ACTIONS(6180),
    [sym_filter_keyword] = ACTIONS(6180),
    [sym_labels_keyword] = ACTIONS(6180),
    [sym_rendering_keyword] = ACTIONS(6180),
    [sym_requestpage_keyword] = ACTIONS(6180),
    [sym_schema_keyword] = ACTIONS(6180),
    [sym_views_keyword] = ACTIONS(6180),
    [sym_quoted_identifier] = ACTIONS(6182),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6182),
    [sym_preproc_open] = ACTIONS(6182),
    [sym_preproc_close] = ACTIONS(6182),
    [sym_var_attribute_open] = ACTIONS(6182),
  },
  [STATE(3997)] = {
    [sym_identifier] = ACTIONS(6184),
    [anon_sym_SEMI] = ACTIONS(6186),
    [aux_sym_where_condition_token1] = ACTIONS(6184),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6184),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6184),
    [anon_sym_LBRACK] = ACTIONS(6186),
    [aux_sym_basic_type_token6] = ACTIONS(6184),
    [aux_sym_basic_type_token22] = ACTIONS(6184),
    [aux_sym_basic_type_token53] = ACTIONS(6184),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6184),
    [aux_sym_addafter_modification_token1] = ACTIONS(6184),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6184),
    [aux_sym_modify_modification_token1] = ACTIONS(6184),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6184),
    [aux_sym_movelast_modification_token1] = ACTIONS(6184),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6184),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6184),
    [aux_sym_separator_action_token1] = ACTIONS(6184),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6184),
    [aux_sym_type_declaration_token1] = ACTIONS(6184),
    [anon_sym_POUNDif] = ACTIONS(6186),
    [anon_sym_POUNDIF] = ACTIONS(6186),
    [anon_sym_POUNDIf] = ACTIONS(6186),
    [anon_sym_POUNDelif] = ACTIONS(6186),
    [anon_sym_POUNDELIF] = ACTIONS(6186),
    [anon_sym_POUNDElif] = ACTIONS(6186),
    [anon_sym_POUNDelse] = ACTIONS(6186),
    [anon_sym_POUNDELSE] = ACTIONS(6186),
    [anon_sym_POUNDElse] = ACTIONS(6186),
    [anon_sym_POUNDelse2] = ACTIONS(6186),
    [anon_sym_POUNDELSE2] = ACTIONS(6186),
    [anon_sym_POUNDElse2] = ACTIONS(6186),
    [anon_sym_POUNDendif] = ACTIONS(6186),
    [anon_sym_POUNDENDIF] = ACTIONS(6186),
    [anon_sym_POUNDEndif] = ACTIONS(6186),
    [anon_sym_POUNDendif2] = ACTIONS(6186),
    [anon_sym_POUNDENDIF2] = ACTIONS(6186),
    [anon_sym_POUNDEndif2] = ACTIONS(6186),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6184),
    [sym_procedure_keyword] = ACTIONS(6184),
    [sym_trigger_keyword] = ACTIONS(6184),
    [sym_var_keyword] = ACTIONS(6184),
    [sym_local_keyword] = ACTIONS(6184),
    [sym_internal_keyword] = ACTIONS(6184),
    [sym_protected_keyword] = ACTIONS(6184),
    [sym_event_keyword] = ACTIONS(6184),
    [sym_fields_keyword] = ACTIONS(6184),
    [sym_keys_keyword] = ACTIONS(6184),
    [sym_key_keyword] = ACTIONS(6184),
    [sym_fieldgroups_keyword] = ACTIONS(6184),
    [sym_actions_keyword] = ACTIONS(6184),
    [sym_layout_keyword] = ACTIONS(6184),
    [sym_area_keyword] = ACTIONS(6184),
    [sym_group_keyword] = ACTIONS(6184),
    [sym_repeater_keyword] = ACTIONS(6184),
    [sym_cuegroup_keyword] = ACTIONS(6184),
    [sym_fixed_keyword] = ACTIONS(6184),
    [sym_grid_keyword] = ACTIONS(6184),
    [sym_part_keyword] = ACTIONS(6184),
    [sym_systempart_keyword] = ACTIONS(6184),
    [sym_usercontrol_keyword] = ACTIONS(6184),
    [sym_dataset_keyword] = ACTIONS(6184),
    [sym_elements_keyword] = ACTIONS(6184),
    [sym_dataitem_keyword] = ACTIONS(6184),
    [sym_column_keyword] = ACTIONS(6184),
    [sym_filter_keyword] = ACTIONS(6184),
    [sym_labels_keyword] = ACTIONS(6184),
    [sym_rendering_keyword] = ACTIONS(6184),
    [sym_requestpage_keyword] = ACTIONS(6184),
    [sym_schema_keyword] = ACTIONS(6184),
    [sym_views_keyword] = ACTIONS(6184),
    [sym_quoted_identifier] = ACTIONS(6186),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6186),
    [sym_preproc_open] = ACTIONS(6186),
    [sym_preproc_close] = ACTIONS(6186),
    [sym_var_attribute_open] = ACTIONS(6186),
  },
  [STATE(3998)] = {
    [sym_identifier] = ACTIONS(6188),
    [anon_sym_SEMI] = ACTIONS(6190),
    [aux_sym_where_condition_token1] = ACTIONS(6188),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6188),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6188),
    [anon_sym_LBRACK] = ACTIONS(6190),
    [aux_sym_basic_type_token6] = ACTIONS(6188),
    [aux_sym_basic_type_token22] = ACTIONS(6188),
    [aux_sym_basic_type_token53] = ACTIONS(6188),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6188),
    [aux_sym_addafter_modification_token1] = ACTIONS(6188),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6188),
    [aux_sym_modify_modification_token1] = ACTIONS(6188),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6188),
    [aux_sym_movelast_modification_token1] = ACTIONS(6188),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6188),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6188),
    [aux_sym_separator_action_token1] = ACTIONS(6188),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6188),
    [aux_sym_type_declaration_token1] = ACTIONS(6188),
    [anon_sym_POUNDif] = ACTIONS(6190),
    [anon_sym_POUNDIF] = ACTIONS(6190),
    [anon_sym_POUNDIf] = ACTIONS(6190),
    [anon_sym_POUNDelif] = ACTIONS(6190),
    [anon_sym_POUNDELIF] = ACTIONS(6190),
    [anon_sym_POUNDElif] = ACTIONS(6190),
    [anon_sym_POUNDelse] = ACTIONS(6190),
    [anon_sym_POUNDELSE] = ACTIONS(6190),
    [anon_sym_POUNDElse] = ACTIONS(6190),
    [anon_sym_POUNDelse2] = ACTIONS(6190),
    [anon_sym_POUNDELSE2] = ACTIONS(6190),
    [anon_sym_POUNDElse2] = ACTIONS(6190),
    [anon_sym_POUNDendif] = ACTIONS(6190),
    [anon_sym_POUNDENDIF] = ACTIONS(6190),
    [anon_sym_POUNDEndif] = ACTIONS(6190),
    [anon_sym_POUNDendif2] = ACTIONS(6190),
    [anon_sym_POUNDENDIF2] = ACTIONS(6190),
    [anon_sym_POUNDEndif2] = ACTIONS(6190),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6188),
    [sym_procedure_keyword] = ACTIONS(6188),
    [sym_trigger_keyword] = ACTIONS(6188),
    [sym_var_keyword] = ACTIONS(6188),
    [sym_local_keyword] = ACTIONS(6188),
    [sym_internal_keyword] = ACTIONS(6188),
    [sym_protected_keyword] = ACTIONS(6188),
    [sym_event_keyword] = ACTIONS(6188),
    [sym_fields_keyword] = ACTIONS(6188),
    [sym_keys_keyword] = ACTIONS(6188),
    [sym_key_keyword] = ACTIONS(6188),
    [sym_fieldgroups_keyword] = ACTIONS(6188),
    [sym_actions_keyword] = ACTIONS(6188),
    [sym_layout_keyword] = ACTIONS(6188),
    [sym_area_keyword] = ACTIONS(6188),
    [sym_group_keyword] = ACTIONS(6188),
    [sym_repeater_keyword] = ACTIONS(6188),
    [sym_cuegroup_keyword] = ACTIONS(6188),
    [sym_fixed_keyword] = ACTIONS(6188),
    [sym_grid_keyword] = ACTIONS(6188),
    [sym_part_keyword] = ACTIONS(6188),
    [sym_systempart_keyword] = ACTIONS(6188),
    [sym_usercontrol_keyword] = ACTIONS(6188),
    [sym_dataset_keyword] = ACTIONS(6188),
    [sym_elements_keyword] = ACTIONS(6188),
    [sym_dataitem_keyword] = ACTIONS(6188),
    [sym_column_keyword] = ACTIONS(6188),
    [sym_filter_keyword] = ACTIONS(6188),
    [sym_labels_keyword] = ACTIONS(6188),
    [sym_rendering_keyword] = ACTIONS(6188),
    [sym_requestpage_keyword] = ACTIONS(6188),
    [sym_schema_keyword] = ACTIONS(6188),
    [sym_views_keyword] = ACTIONS(6188),
    [sym_quoted_identifier] = ACTIONS(6190),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6190),
    [sym_preproc_open] = ACTIONS(6190),
    [sym_preproc_close] = ACTIONS(6190),
    [sym_var_attribute_open] = ACTIONS(6190),
  },
  [STATE(3999)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [aux_sym_where_condition_token1] = ACTIONS(6192),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [aux_sym_basic_type_token6] = ACTIONS(6192),
    [aux_sym_basic_type_token22] = ACTIONS(6192),
    [aux_sym_basic_type_token53] = ACTIONS(6192),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6192),
    [aux_sym_addafter_modification_token1] = ACTIONS(6192),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6192),
    [aux_sym_modify_modification_token1] = ACTIONS(6192),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6192),
    [aux_sym_movelast_modification_token1] = ACTIONS(6192),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6192),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6192),
    [aux_sym_separator_action_token1] = ACTIONS(6192),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6192),
    [aux_sym_type_declaration_token1] = ACTIONS(6192),
    [anon_sym_POUNDif] = ACTIONS(6194),
    [anon_sym_POUNDIF] = ACTIONS(6194),
    [anon_sym_POUNDIf] = ACTIONS(6194),
    [anon_sym_POUNDelif] = ACTIONS(6194),
    [anon_sym_POUNDELIF] = ACTIONS(6194),
    [anon_sym_POUNDElif] = ACTIONS(6194),
    [anon_sym_POUNDelse] = ACTIONS(6194),
    [anon_sym_POUNDELSE] = ACTIONS(6194),
    [anon_sym_POUNDElse] = ACTIONS(6194),
    [anon_sym_POUNDelse2] = ACTIONS(6194),
    [anon_sym_POUNDELSE2] = ACTIONS(6194),
    [anon_sym_POUNDElse2] = ACTIONS(6194),
    [anon_sym_POUNDendif] = ACTIONS(6194),
    [anon_sym_POUNDENDIF] = ACTIONS(6194),
    [anon_sym_POUNDEndif] = ACTIONS(6194),
    [anon_sym_POUNDendif2] = ACTIONS(6194),
    [anon_sym_POUNDENDIF2] = ACTIONS(6194),
    [anon_sym_POUNDEndif2] = ACTIONS(6194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6192),
    [sym_procedure_keyword] = ACTIONS(6192),
    [sym_trigger_keyword] = ACTIONS(6192),
    [sym_var_keyword] = ACTIONS(6192),
    [sym_local_keyword] = ACTIONS(6192),
    [sym_internal_keyword] = ACTIONS(6192),
    [sym_protected_keyword] = ACTIONS(6192),
    [sym_event_keyword] = ACTIONS(6192),
    [sym_fields_keyword] = ACTIONS(6192),
    [sym_keys_keyword] = ACTIONS(6192),
    [sym_key_keyword] = ACTIONS(6192),
    [sym_fieldgroups_keyword] = ACTIONS(6192),
    [sym_actions_keyword] = ACTIONS(6192),
    [sym_layout_keyword] = ACTIONS(6192),
    [sym_area_keyword] = ACTIONS(6192),
    [sym_group_keyword] = ACTIONS(6192),
    [sym_repeater_keyword] = ACTIONS(6192),
    [sym_cuegroup_keyword] = ACTIONS(6192),
    [sym_fixed_keyword] = ACTIONS(6192),
    [sym_grid_keyword] = ACTIONS(6192),
    [sym_part_keyword] = ACTIONS(6192),
    [sym_systempart_keyword] = ACTIONS(6192),
    [sym_usercontrol_keyword] = ACTIONS(6192),
    [sym_dataset_keyword] = ACTIONS(6192),
    [sym_elements_keyword] = ACTIONS(6192),
    [sym_dataitem_keyword] = ACTIONS(6192),
    [sym_column_keyword] = ACTIONS(6192),
    [sym_filter_keyword] = ACTIONS(6192),
    [sym_labels_keyword] = ACTIONS(6192),
    [sym_rendering_keyword] = ACTIONS(6192),
    [sym_requestpage_keyword] = ACTIONS(6192),
    [sym_schema_keyword] = ACTIONS(6192),
    [sym_views_keyword] = ACTIONS(6192),
    [sym_quoted_identifier] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6194),
    [sym_preproc_open] = ACTIONS(6194),
    [sym_preproc_close] = ACTIONS(6194),
    [sym_var_attribute_open] = ACTIONS(6194),
  },
  [STATE(4000)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(9800),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4001)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(8897),
    [aux_sym_where_condition_token1] = ACTIONS(6118),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6118),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_basic_type_token6] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token53] = ACTIONS(6118),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6118),
    [aux_sym_addafter_modification_token1] = ACTIONS(6118),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6118),
    [aux_sym_modify_modification_token1] = ACTIONS(6118),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6118),
    [aux_sym_movelast_modification_token1] = ACTIONS(6118),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6118),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6118),
    [aux_sym_separator_action_token1] = ACTIONS(6118),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6118),
    [aux_sym_type_declaration_token1] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_POUNDelif] = ACTIONS(6122),
    [anon_sym_POUNDELIF] = ACTIONS(6122),
    [anon_sym_POUNDElif] = ACTIONS(6122),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [anon_sym_POUNDendif] = ACTIONS(6122),
    [anon_sym_POUNDENDIF] = ACTIONS(6122),
    [anon_sym_POUNDEndif] = ACTIONS(6122),
    [anon_sym_POUNDendif2] = ACTIONS(6122),
    [anon_sym_POUNDENDIF2] = ACTIONS(6122),
    [anon_sym_POUNDEndif2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6118),
    [sym_procedure_keyword] = ACTIONS(6118),
    [sym_trigger_keyword] = ACTIONS(6118),
    [sym_var_keyword] = ACTIONS(6118),
    [sym_local_keyword] = ACTIONS(6118),
    [sym_internal_keyword] = ACTIONS(6118),
    [sym_protected_keyword] = ACTIONS(6118),
    [sym_event_keyword] = ACTIONS(6118),
    [sym_fields_keyword] = ACTIONS(6118),
    [sym_keys_keyword] = ACTIONS(6118),
    [sym_key_keyword] = ACTIONS(6118),
    [sym_fieldgroups_keyword] = ACTIONS(6118),
    [sym_actions_keyword] = ACTIONS(6118),
    [sym_layout_keyword] = ACTIONS(6118),
    [sym_area_keyword] = ACTIONS(6118),
    [sym_group_keyword] = ACTIONS(6118),
    [sym_repeater_keyword] = ACTIONS(6118),
    [sym_cuegroup_keyword] = ACTIONS(6118),
    [sym_fixed_keyword] = ACTIONS(6118),
    [sym_grid_keyword] = ACTIONS(6118),
    [sym_part_keyword] = ACTIONS(6118),
    [sym_systempart_keyword] = ACTIONS(6118),
    [sym_usercontrol_keyword] = ACTIONS(6118),
    [sym_dataset_keyword] = ACTIONS(6118),
    [sym_elements_keyword] = ACTIONS(6118),
    [sym_dataitem_keyword] = ACTIONS(6118),
    [sym_column_keyword] = ACTIONS(6118),
    [sym_filter_keyword] = ACTIONS(6118),
    [sym_labels_keyword] = ACTIONS(6118),
    [sym_rendering_keyword] = ACTIONS(6118),
    [sym_requestpage_keyword] = ACTIONS(6118),
    [sym_schema_keyword] = ACTIONS(6118),
    [sym_views_keyword] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_preproc_close] = ACTIONS(6122),
    [sym_var_attribute_open] = ACTIONS(6122),
  },
  [STATE(4002)] = {
    [sym__body_element] = STATE(4033),
    [sym_empty_statement] = STATE(4033),
    [sym_property] = STATE(4033),
    [sym_permissions_property] = STATE(4033),
    [sym_table_relation_property] = STATE(4033),
    [sym_fields_section] = STATE(4033),
    [sym_keys_section] = STATE(4033),
    [sym_fieldgroups_section] = STATE(4033),
    [sym_enum_value_declaration] = STATE(4033),
    [sym_labels_section] = STATE(4033),
    [sym_layout_section] = STATE(4033),
    [sym_modify_modification] = STATE(4033),
    [sym_actions_section] = STATE(4033),
    [sym_views_section] = STATE(4033),
    [sym_dataset_section] = STATE(4033),
    [sym_requestpage_section] = STATE(4033),
    [sym_rendering_section] = STATE(4033),
    [sym_elements_section] = STATE(4033),
    [sym_schema_section] = STATE(4033),
    [sym_assembly_declaration] = STATE(4033),
    [sym_event_declaration] = STATE(4033),
    [sym_procedure] = STATE(4033),
    [sym_preproc_split_procedure] = STATE(4033),
    [sym_preproc_split_procedure_preamble] = STATE(4033),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4033),
    [sym_var_section] = STATE(4033),
    [sym_attribute_item] = STATE(4033),
    [sym_preproc_conditional] = STATE(4033),
    [sym_preproc_if] = STATE(3659),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4033),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(8899),
    [anon_sym_POUNDELIF] = ACTIONS(8899),
    [anon_sym_POUNDElif] = ACTIONS(8899),
    [anon_sym_POUNDelse] = ACTIONS(8899),
    [anon_sym_POUNDELSE] = ACTIONS(8899),
    [anon_sym_POUNDElse] = ACTIONS(8899),
    [anon_sym_POUNDelse2] = ACTIONS(8899),
    [anon_sym_POUNDELSE2] = ACTIONS(8899),
    [anon_sym_POUNDElse2] = ACTIONS(8899),
    [anon_sym_POUNDendif] = ACTIONS(8899),
    [anon_sym_POUNDENDIF] = ACTIONS(8899),
    [anon_sym_POUNDEndif] = ACTIONS(8899),
    [anon_sym_POUNDendif2] = ACTIONS(8899),
    [anon_sym_POUNDENDIF2] = ACTIONS(8899),
    [anon_sym_POUNDEndif2] = ACTIONS(8899),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(8899),
  },
  [STATE(4003)] = {
    [sym_identifier] = ACTIONS(8901),
    [anon_sym_SEMI] = ACTIONS(8903),
    [aux_sym_where_condition_token1] = ACTIONS(8901),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8901),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8901),
    [anon_sym_LBRACK] = ACTIONS(8903),
    [aux_sym_basic_type_token6] = ACTIONS(8901),
    [aux_sym_basic_type_token22] = ACTIONS(8901),
    [aux_sym_basic_type_token53] = ACTIONS(8901),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8901),
    [aux_sym_addafter_modification_token1] = ACTIONS(8901),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8901),
    [aux_sym_modify_modification_token1] = ACTIONS(8901),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8901),
    [aux_sym_movelast_modification_token1] = ACTIONS(8901),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8901),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8901),
    [aux_sym_separator_action_token1] = ACTIONS(8901),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8901),
    [aux_sym_type_declaration_token1] = ACTIONS(8901),
    [anon_sym_POUNDif] = ACTIONS(8903),
    [anon_sym_POUNDIF] = ACTIONS(8903),
    [anon_sym_POUNDIf] = ACTIONS(8903),
    [anon_sym_POUNDelif] = ACTIONS(8903),
    [anon_sym_POUNDELIF] = ACTIONS(8903),
    [anon_sym_POUNDElif] = ACTIONS(8903),
    [anon_sym_POUNDelse] = ACTIONS(8903),
    [anon_sym_POUNDELSE] = ACTIONS(8903),
    [anon_sym_POUNDElse] = ACTIONS(8903),
    [anon_sym_POUNDelse2] = ACTIONS(8903),
    [anon_sym_POUNDELSE2] = ACTIONS(8903),
    [anon_sym_POUNDElse2] = ACTIONS(8903),
    [anon_sym_POUNDendif] = ACTIONS(8903),
    [anon_sym_POUNDENDIF] = ACTIONS(8903),
    [anon_sym_POUNDEndif] = ACTIONS(8903),
    [anon_sym_POUNDendif2] = ACTIONS(8903),
    [anon_sym_POUNDENDIF2] = ACTIONS(8903),
    [anon_sym_POUNDEndif2] = ACTIONS(8903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8901),
    [sym_procedure_keyword] = ACTIONS(8901),
    [sym_trigger_keyword] = ACTIONS(8901),
    [sym_var_keyword] = ACTIONS(8901),
    [sym_local_keyword] = ACTIONS(8901),
    [sym_internal_keyword] = ACTIONS(8901),
    [sym_protected_keyword] = ACTIONS(8901),
    [sym_event_keyword] = ACTIONS(8901),
    [sym_fields_keyword] = ACTIONS(8901),
    [sym_keys_keyword] = ACTIONS(8901),
    [sym_key_keyword] = ACTIONS(8901),
    [sym_fieldgroups_keyword] = ACTIONS(8901),
    [sym_actions_keyword] = ACTIONS(8901),
    [sym_layout_keyword] = ACTIONS(8901),
    [sym_area_keyword] = ACTIONS(8901),
    [sym_group_keyword] = ACTIONS(8901),
    [sym_repeater_keyword] = ACTIONS(8901),
    [sym_cuegroup_keyword] = ACTIONS(8901),
    [sym_fixed_keyword] = ACTIONS(8901),
    [sym_grid_keyword] = ACTIONS(8901),
    [sym_part_keyword] = ACTIONS(8901),
    [sym_systempart_keyword] = ACTIONS(8901),
    [sym_usercontrol_keyword] = ACTIONS(8901),
    [sym_dataset_keyword] = ACTIONS(8901),
    [sym_elements_keyword] = ACTIONS(8901),
    [sym_dataitem_keyword] = ACTIONS(8901),
    [sym_column_keyword] = ACTIONS(8901),
    [sym_filter_keyword] = ACTIONS(8901),
    [sym_labels_keyword] = ACTIONS(8901),
    [sym_rendering_keyword] = ACTIONS(8901),
    [sym_requestpage_keyword] = ACTIONS(8901),
    [sym_schema_keyword] = ACTIONS(8901),
    [sym_views_keyword] = ACTIONS(8901),
    [sym_quoted_identifier] = ACTIONS(8903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8903),
    [sym_preproc_open] = ACTIONS(8903),
    [sym_preproc_close] = ACTIONS(8903),
    [sym_var_attribute_open] = ACTIONS(8903),
  },
  [STATE(4004)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(6122),
    [aux_sym_where_condition_token1] = ACTIONS(6118),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6118),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_basic_type_token6] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token53] = ACTIONS(6118),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6118),
    [aux_sym_addafter_modification_token1] = ACTIONS(6118),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6118),
    [aux_sym_modify_modification_token1] = ACTIONS(6118),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6118),
    [aux_sym_movelast_modification_token1] = ACTIONS(6118),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6118),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6118),
    [aux_sym_separator_action_token1] = ACTIONS(6118),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6118),
    [aux_sym_type_declaration_token1] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_POUNDelif] = ACTIONS(6122),
    [anon_sym_POUNDELIF] = ACTIONS(6122),
    [anon_sym_POUNDElif] = ACTIONS(6122),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [anon_sym_POUNDendif] = ACTIONS(6122),
    [anon_sym_POUNDENDIF] = ACTIONS(6122),
    [anon_sym_POUNDEndif] = ACTIONS(6122),
    [anon_sym_POUNDendif2] = ACTIONS(6122),
    [anon_sym_POUNDENDIF2] = ACTIONS(6122),
    [anon_sym_POUNDEndif2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6118),
    [sym_procedure_keyword] = ACTIONS(6118),
    [sym_trigger_keyword] = ACTIONS(6118),
    [sym_var_keyword] = ACTIONS(6118),
    [sym_local_keyword] = ACTIONS(6118),
    [sym_internal_keyword] = ACTIONS(6118),
    [sym_protected_keyword] = ACTIONS(6118),
    [sym_event_keyword] = ACTIONS(6118),
    [sym_fields_keyword] = ACTIONS(6118),
    [sym_keys_keyword] = ACTIONS(6118),
    [sym_key_keyword] = ACTIONS(6118),
    [sym_fieldgroups_keyword] = ACTIONS(6118),
    [sym_actions_keyword] = ACTIONS(6118),
    [sym_layout_keyword] = ACTIONS(6118),
    [sym_area_keyword] = ACTIONS(6118),
    [sym_group_keyword] = ACTIONS(6118),
    [sym_repeater_keyword] = ACTIONS(6118),
    [sym_cuegroup_keyword] = ACTIONS(6118),
    [sym_fixed_keyword] = ACTIONS(6118),
    [sym_grid_keyword] = ACTIONS(6118),
    [sym_part_keyword] = ACTIONS(6118),
    [sym_systempart_keyword] = ACTIONS(6118),
    [sym_usercontrol_keyword] = ACTIONS(6118),
    [sym_dataset_keyword] = ACTIONS(6118),
    [sym_elements_keyword] = ACTIONS(6118),
    [sym_dataitem_keyword] = ACTIONS(6118),
    [sym_column_keyword] = ACTIONS(6118),
    [sym_filter_keyword] = ACTIONS(6118),
    [sym_labels_keyword] = ACTIONS(6118),
    [sym_rendering_keyword] = ACTIONS(6118),
    [sym_requestpage_keyword] = ACTIONS(6118),
    [sym_schema_keyword] = ACTIONS(6118),
    [sym_views_keyword] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_preproc_close] = ACTIONS(6122),
    [sym_var_attribute_open] = ACTIONS(6122),
  },
  [STATE(4005)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8905),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_addafter_modification_token1] = ACTIONS(8905),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8905),
    [aux_sym_movelast_modification_token1] = ACTIONS(8905),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8905),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_area_keyword] = ACTIONS(8905),
    [sym_group_keyword] = ACTIONS(8905),
    [sym_repeater_keyword] = ACTIONS(8905),
    [sym_cuegroup_keyword] = ACTIONS(8905),
    [sym_fixed_keyword] = ACTIONS(8905),
    [sym_grid_keyword] = ACTIONS(8905),
    [sym_part_keyword] = ACTIONS(8905),
    [sym_systempart_keyword] = ACTIONS(8905),
    [sym_usercontrol_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_dataitem_keyword] = ACTIONS(8905),
    [sym_column_keyword] = ACTIONS(8905),
    [sym_filter_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(4006)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8905),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_addafter_modification_token1] = ACTIONS(8905),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8905),
    [aux_sym_movelast_modification_token1] = ACTIONS(8905),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8905),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_area_keyword] = ACTIONS(8905),
    [sym_group_keyword] = ACTIONS(8905),
    [sym_repeater_keyword] = ACTIONS(8905),
    [sym_cuegroup_keyword] = ACTIONS(8905),
    [sym_fixed_keyword] = ACTIONS(8905),
    [sym_grid_keyword] = ACTIONS(8905),
    [sym_part_keyword] = ACTIONS(8905),
    [sym_systempart_keyword] = ACTIONS(8905),
    [sym_usercontrol_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_dataitem_keyword] = ACTIONS(8905),
    [sym_column_keyword] = ACTIONS(8905),
    [sym_filter_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(4007)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8905),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_addafter_modification_token1] = ACTIONS(8905),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8905),
    [aux_sym_movelast_modification_token1] = ACTIONS(8905),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8905),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_area_keyword] = ACTIONS(8905),
    [sym_group_keyword] = ACTIONS(8905),
    [sym_repeater_keyword] = ACTIONS(8905),
    [sym_cuegroup_keyword] = ACTIONS(8905),
    [sym_fixed_keyword] = ACTIONS(8905),
    [sym_grid_keyword] = ACTIONS(8905),
    [sym_part_keyword] = ACTIONS(8905),
    [sym_systempart_keyword] = ACTIONS(8905),
    [sym_usercontrol_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_dataitem_keyword] = ACTIONS(8905),
    [sym_column_keyword] = ACTIONS(8905),
    [sym_filter_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(4008)] = {
    [sym_identifier] = ACTIONS(8909),
    [anon_sym_SEMI] = ACTIONS(8911),
    [aux_sym_where_condition_token1] = ACTIONS(8909),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8909),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8909),
    [anon_sym_LBRACK] = ACTIONS(8911),
    [aux_sym_basic_type_token6] = ACTIONS(8909),
    [aux_sym_basic_type_token22] = ACTIONS(8909),
    [aux_sym_basic_type_token53] = ACTIONS(8909),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8909),
    [aux_sym_addafter_modification_token1] = ACTIONS(8909),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8909),
    [aux_sym_modify_modification_token1] = ACTIONS(8909),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8909),
    [aux_sym_movelast_modification_token1] = ACTIONS(8909),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8909),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8909),
    [aux_sym_separator_action_token1] = ACTIONS(8909),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8909),
    [aux_sym_type_declaration_token1] = ACTIONS(8909),
    [anon_sym_POUNDif] = ACTIONS(8911),
    [anon_sym_POUNDIF] = ACTIONS(8911),
    [anon_sym_POUNDIf] = ACTIONS(8911),
    [anon_sym_POUNDelif] = ACTIONS(8911),
    [anon_sym_POUNDELIF] = ACTIONS(8911),
    [anon_sym_POUNDElif] = ACTIONS(8911),
    [anon_sym_POUNDelse] = ACTIONS(8911),
    [anon_sym_POUNDELSE] = ACTIONS(8911),
    [anon_sym_POUNDElse] = ACTIONS(8911),
    [anon_sym_POUNDelse2] = ACTIONS(8911),
    [anon_sym_POUNDELSE2] = ACTIONS(8911),
    [anon_sym_POUNDElse2] = ACTIONS(8911),
    [anon_sym_POUNDendif] = ACTIONS(8911),
    [anon_sym_POUNDENDIF] = ACTIONS(8911),
    [anon_sym_POUNDEndif] = ACTIONS(8911),
    [anon_sym_POUNDendif2] = ACTIONS(8911),
    [anon_sym_POUNDENDIF2] = ACTIONS(8911),
    [anon_sym_POUNDEndif2] = ACTIONS(8911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8909),
    [sym_procedure_keyword] = ACTIONS(8909),
    [sym_trigger_keyword] = ACTIONS(8909),
    [sym_var_keyword] = ACTIONS(8909),
    [sym_local_keyword] = ACTIONS(8909),
    [sym_internal_keyword] = ACTIONS(8909),
    [sym_protected_keyword] = ACTIONS(8909),
    [sym_event_keyword] = ACTIONS(8909),
    [sym_fields_keyword] = ACTIONS(8909),
    [sym_keys_keyword] = ACTIONS(8909),
    [sym_key_keyword] = ACTIONS(8909),
    [sym_fieldgroups_keyword] = ACTIONS(8909),
    [sym_actions_keyword] = ACTIONS(8909),
    [sym_layout_keyword] = ACTIONS(8909),
    [sym_area_keyword] = ACTIONS(8909),
    [sym_group_keyword] = ACTIONS(8909),
    [sym_repeater_keyword] = ACTIONS(8909),
    [sym_cuegroup_keyword] = ACTIONS(8909),
    [sym_fixed_keyword] = ACTIONS(8909),
    [sym_grid_keyword] = ACTIONS(8909),
    [sym_part_keyword] = ACTIONS(8909),
    [sym_systempart_keyword] = ACTIONS(8909),
    [sym_usercontrol_keyword] = ACTIONS(8909),
    [sym_dataset_keyword] = ACTIONS(8909),
    [sym_elements_keyword] = ACTIONS(8909),
    [sym_dataitem_keyword] = ACTIONS(8909),
    [sym_column_keyword] = ACTIONS(8909),
    [sym_filter_keyword] = ACTIONS(8909),
    [sym_labels_keyword] = ACTIONS(8909),
    [sym_rendering_keyword] = ACTIONS(8909),
    [sym_requestpage_keyword] = ACTIONS(8909),
    [sym_schema_keyword] = ACTIONS(8909),
    [sym_views_keyword] = ACTIONS(8909),
    [sym_quoted_identifier] = ACTIONS(8911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8911),
    [sym_preproc_open] = ACTIONS(8911),
    [sym_preproc_close] = ACTIONS(8911),
    [sym_var_attribute_open] = ACTIONS(8911),
  },
  [STATE(4009)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(8913),
    [anon_sym_LBRACK] = ACTIONS(8916),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8919),
    [aux_sym_modify_modification_token1] = ACTIONS(8922),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8925),
    [anon_sym_POUNDif] = ACTIONS(8928),
    [anon_sym_POUNDIF] = ACTIONS(8928),
    [anon_sym_POUNDIf] = ACTIONS(8928),
    [anon_sym_POUNDelif] = ACTIONS(8931),
    [anon_sym_POUNDELIF] = ACTIONS(8931),
    [anon_sym_POUNDElif] = ACTIONS(8931),
    [anon_sym_POUNDelse] = ACTIONS(8931),
    [anon_sym_POUNDELSE] = ACTIONS(8931),
    [anon_sym_POUNDElse] = ACTIONS(8931),
    [anon_sym_POUNDelse2] = ACTIONS(8931),
    [anon_sym_POUNDELSE2] = ACTIONS(8931),
    [anon_sym_POUNDElse2] = ACTIONS(8931),
    [anon_sym_POUNDendif] = ACTIONS(8931),
    [anon_sym_POUNDENDIF] = ACTIONS(8931),
    [anon_sym_POUNDEndif] = ACTIONS(8931),
    [anon_sym_POUNDendif2] = ACTIONS(8931),
    [anon_sym_POUNDENDIF2] = ACTIONS(8931),
    [anon_sym_POUNDEndif2] = ACTIONS(8931),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8933),
    [sym_trigger_keyword] = ACTIONS(8936),
    [sym_var_keyword] = ACTIONS(8939),
    [sym_local_keyword] = ACTIONS(8942),
    [sym_internal_keyword] = ACTIONS(8945),
    [sym_protected_keyword] = ACTIONS(8942),
    [sym_event_keyword] = ACTIONS(8948),
    [sym_fields_keyword] = ACTIONS(8951),
    [sym_keys_keyword] = ACTIONS(8954),
    [sym_fieldgroups_keyword] = ACTIONS(8957),
    [sym_actions_keyword] = ACTIONS(8960),
    [sym_layout_keyword] = ACTIONS(8963),
    [sym_dataset_keyword] = ACTIONS(8966),
    [sym_elements_keyword] = ACTIONS(8969),
    [sym_labels_keyword] = ACTIONS(8972),
    [sym_rendering_keyword] = ACTIONS(8975),
    [sym_requestpage_keyword] = ACTIONS(8978),
    [sym_schema_keyword] = ACTIONS(8981),
    [sym_views_keyword] = ACTIONS(8984),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8987),
    [sym_preproc_open] = ACTIONS(8928),
    [sym_preproc_close] = ACTIONS(8931),
  },
  [STATE(4010)] = {
    [sym_identifier] = ACTIONS(6124),
    [anon_sym_SEMI] = ACTIONS(6126),
    [aux_sym_where_condition_token1] = ACTIONS(6124),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6124),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6124),
    [anon_sym_LBRACK] = ACTIONS(6126),
    [aux_sym_basic_type_token6] = ACTIONS(6124),
    [aux_sym_basic_type_token22] = ACTIONS(6124),
    [aux_sym_basic_type_token53] = ACTIONS(6124),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6124),
    [aux_sym_addafter_modification_token1] = ACTIONS(6124),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6124),
    [aux_sym_modify_modification_token1] = ACTIONS(6124),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6124),
    [aux_sym_movelast_modification_token1] = ACTIONS(6124),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6124),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6124),
    [aux_sym_separator_action_token1] = ACTIONS(6124),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6124),
    [aux_sym_type_declaration_token1] = ACTIONS(6124),
    [anon_sym_POUNDif] = ACTIONS(6126),
    [anon_sym_POUNDIF] = ACTIONS(6126),
    [anon_sym_POUNDIf] = ACTIONS(6126),
    [anon_sym_POUNDelif] = ACTIONS(6126),
    [anon_sym_POUNDELIF] = ACTIONS(6126),
    [anon_sym_POUNDElif] = ACTIONS(6126),
    [anon_sym_POUNDelse] = ACTIONS(6126),
    [anon_sym_POUNDELSE] = ACTIONS(6126),
    [anon_sym_POUNDElse] = ACTIONS(6126),
    [anon_sym_POUNDelse2] = ACTIONS(6126),
    [anon_sym_POUNDELSE2] = ACTIONS(6126),
    [anon_sym_POUNDElse2] = ACTIONS(6126),
    [anon_sym_POUNDendif] = ACTIONS(6126),
    [anon_sym_POUNDENDIF] = ACTIONS(6126),
    [anon_sym_POUNDEndif] = ACTIONS(6126),
    [anon_sym_POUNDendif2] = ACTIONS(6126),
    [anon_sym_POUNDENDIF2] = ACTIONS(6126),
    [anon_sym_POUNDEndif2] = ACTIONS(6126),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6124),
    [sym_procedure_keyword] = ACTIONS(6124),
    [sym_trigger_keyword] = ACTIONS(6124),
    [sym_var_keyword] = ACTIONS(6124),
    [sym_local_keyword] = ACTIONS(6124),
    [sym_internal_keyword] = ACTIONS(6124),
    [sym_protected_keyword] = ACTIONS(6124),
    [sym_event_keyword] = ACTIONS(6124),
    [sym_fields_keyword] = ACTIONS(6124),
    [sym_keys_keyword] = ACTIONS(6124),
    [sym_key_keyword] = ACTIONS(6124),
    [sym_fieldgroups_keyword] = ACTIONS(6124),
    [sym_actions_keyword] = ACTIONS(6124),
    [sym_layout_keyword] = ACTIONS(6124),
    [sym_area_keyword] = ACTIONS(6124),
    [sym_group_keyword] = ACTIONS(6124),
    [sym_repeater_keyword] = ACTIONS(6124),
    [sym_cuegroup_keyword] = ACTIONS(6124),
    [sym_fixed_keyword] = ACTIONS(6124),
    [sym_grid_keyword] = ACTIONS(6124),
    [sym_part_keyword] = ACTIONS(6124),
    [sym_systempart_keyword] = ACTIONS(6124),
    [sym_usercontrol_keyword] = ACTIONS(6124),
    [sym_dataset_keyword] = ACTIONS(6124),
    [sym_elements_keyword] = ACTIONS(6124),
    [sym_dataitem_keyword] = ACTIONS(6124),
    [sym_column_keyword] = ACTIONS(6124),
    [sym_filter_keyword] = ACTIONS(6124),
    [sym_labels_keyword] = ACTIONS(6124),
    [sym_rendering_keyword] = ACTIONS(6124),
    [sym_requestpage_keyword] = ACTIONS(6124),
    [sym_schema_keyword] = ACTIONS(6124),
    [sym_views_keyword] = ACTIONS(6124),
    [sym_quoted_identifier] = ACTIONS(6126),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6126),
    [sym_preproc_open] = ACTIONS(6126),
    [sym_preproc_close] = ACTIONS(6126),
    [sym_var_attribute_open] = ACTIONS(6126),
  },
  [STATE(4011)] = {
    [sym_identifier] = ACTIONS(8990),
    [anon_sym_SEMI] = ACTIONS(8992),
    [aux_sym_where_condition_token1] = ACTIONS(8990),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8990),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8990),
    [anon_sym_LBRACK] = ACTIONS(8992),
    [aux_sym_basic_type_token6] = ACTIONS(8990),
    [aux_sym_basic_type_token22] = ACTIONS(8990),
    [aux_sym_basic_type_token53] = ACTIONS(8990),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8990),
    [aux_sym_addafter_modification_token1] = ACTIONS(8990),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8990),
    [aux_sym_modify_modification_token1] = ACTIONS(8990),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8990),
    [aux_sym_movelast_modification_token1] = ACTIONS(8990),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8990),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8990),
    [aux_sym_separator_action_token1] = ACTIONS(8990),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8990),
    [aux_sym_type_declaration_token1] = ACTIONS(8990),
    [anon_sym_POUNDif] = ACTIONS(8992),
    [anon_sym_POUNDIF] = ACTIONS(8992),
    [anon_sym_POUNDIf] = ACTIONS(8992),
    [anon_sym_POUNDelif] = ACTIONS(8992),
    [anon_sym_POUNDELIF] = ACTIONS(8992),
    [anon_sym_POUNDElif] = ACTIONS(8992),
    [anon_sym_POUNDelse] = ACTIONS(8992),
    [anon_sym_POUNDELSE] = ACTIONS(8992),
    [anon_sym_POUNDElse] = ACTIONS(8992),
    [anon_sym_POUNDelse2] = ACTIONS(8992),
    [anon_sym_POUNDELSE2] = ACTIONS(8992),
    [anon_sym_POUNDElse2] = ACTIONS(8992),
    [anon_sym_POUNDendif] = ACTIONS(8992),
    [anon_sym_POUNDENDIF] = ACTIONS(8992),
    [anon_sym_POUNDEndif] = ACTIONS(8992),
    [anon_sym_POUNDendif2] = ACTIONS(8992),
    [anon_sym_POUNDENDIF2] = ACTIONS(8992),
    [anon_sym_POUNDEndif2] = ACTIONS(8992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8990),
    [sym_procedure_keyword] = ACTIONS(8990),
    [sym_trigger_keyword] = ACTIONS(8990),
    [sym_var_keyword] = ACTIONS(8990),
    [sym_local_keyword] = ACTIONS(8990),
    [sym_internal_keyword] = ACTIONS(8990),
    [sym_protected_keyword] = ACTIONS(8990),
    [sym_event_keyword] = ACTIONS(8990),
    [sym_fields_keyword] = ACTIONS(8990),
    [sym_keys_keyword] = ACTIONS(8990),
    [sym_key_keyword] = ACTIONS(8990),
    [sym_fieldgroups_keyword] = ACTIONS(8990),
    [sym_actions_keyword] = ACTIONS(8990),
    [sym_layout_keyword] = ACTIONS(8990),
    [sym_area_keyword] = ACTIONS(8990),
    [sym_group_keyword] = ACTIONS(8990),
    [sym_repeater_keyword] = ACTIONS(8990),
    [sym_cuegroup_keyword] = ACTIONS(8990),
    [sym_fixed_keyword] = ACTIONS(8990),
    [sym_grid_keyword] = ACTIONS(8990),
    [sym_part_keyword] = ACTIONS(8990),
    [sym_systempart_keyword] = ACTIONS(8990),
    [sym_usercontrol_keyword] = ACTIONS(8990),
    [sym_dataset_keyword] = ACTIONS(8990),
    [sym_elements_keyword] = ACTIONS(8990),
    [sym_dataitem_keyword] = ACTIONS(8990),
    [sym_column_keyword] = ACTIONS(8990),
    [sym_filter_keyword] = ACTIONS(8990),
    [sym_labels_keyword] = ACTIONS(8990),
    [sym_rendering_keyword] = ACTIONS(8990),
    [sym_requestpage_keyword] = ACTIONS(8990),
    [sym_schema_keyword] = ACTIONS(8990),
    [sym_views_keyword] = ACTIONS(8990),
    [sym_quoted_identifier] = ACTIONS(8992),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8992),
    [sym_preproc_open] = ACTIONS(8992),
    [sym_preproc_close] = ACTIONS(8992),
    [sym_var_attribute_open] = ACTIONS(8992),
  },
  [STATE(4012)] = {
    [sym_identifier] = ACTIONS(7712),
    [anon_sym_SEMI] = ACTIONS(7715),
    [aux_sym_where_condition_token1] = ACTIONS(7712),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [anon_sym_LBRACK] = ACTIONS(7730),
    [aux_sym_basic_type_token22] = ACTIONS(7712),
    [aux_sym_basic_type_token53] = ACTIONS(7712),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7720),
    [aux_sym_modify_modification_token1] = ACTIONS(7727),
    [aux_sym_separator_action_token1] = ACTIONS(7712),
    [aux_sym_xmlport_element_token1] = ACTIONS(7727),
    [aux_sym_xmlport_element_token2] = ACTIONS(7727),
    [aux_sym_xmlport_element_token3] = ACTIONS(7727),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7727),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7727),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7720),
    [aux_sym_type_declaration_token1] = ACTIONS(7712),
    [anon_sym_POUNDif] = ACTIONS(7715),
    [anon_sym_POUNDIF] = ACTIONS(7715),
    [anon_sym_POUNDIf] = ACTIONS(7715),
    [anon_sym_POUNDelif] = ACTIONS(7730),
    [anon_sym_POUNDELIF] = ACTIONS(7730),
    [anon_sym_POUNDElif] = ACTIONS(7730),
    [anon_sym_POUNDelse] = ACTIONS(7730),
    [anon_sym_POUNDELSE] = ACTIONS(7730),
    [anon_sym_POUNDElse] = ACTIONS(7730),
    [anon_sym_POUNDelse2] = ACTIONS(7730),
    [anon_sym_POUNDELSE2] = ACTIONS(7730),
    [anon_sym_POUNDElse2] = ACTIONS(7730),
    [anon_sym_POUNDendif] = ACTIONS(7730),
    [anon_sym_POUNDENDIF] = ACTIONS(7730),
    [anon_sym_POUNDEndif] = ACTIONS(7730),
    [anon_sym_POUNDendif2] = ACTIONS(7730),
    [anon_sym_POUNDENDIF2] = ACTIONS(7730),
    [anon_sym_POUNDEndif2] = ACTIONS(7730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7733),
    [sym_page_keyword] = ACTIONS(7725),
    [anon_sym_codeunit] = ACTIONS(7725),
    [anon_sym_CODEUNIT] = ACTIONS(7725),
    [anon_sym_Codeunit] = ACTIONS(7725),
    [anon_sym_CodeUnit] = ACTIONS(7725),
    [anon_sym_COdeunit] = ACTIONS(7725),
    [anon_sym_codeUnit] = ACTIONS(7725),
    [sym_report_keyword] = ACTIONS(7725),
    [sym_query_keyword] = ACTIONS(7725),
    [anon_sym_xmlport] = ACTIONS(7725),
    [anon_sym_XMLPORT] = ACTIONS(7725),
    [anon_sym_Xmlport] = ACTIONS(7725),
    [anon_sym_XMLport] = ACTIONS(7725),
    [anon_sym_XMLPort] = ACTIONS(7725),
    [anon_sym_XmlPort] = ACTIONS(7725),
    [sym_procedure_keyword] = ACTIONS(7727),
    [sym_trigger_keyword] = ACTIONS(7727),
    [sym_var_keyword] = ACTIONS(7727),
    [sym_local_keyword] = ACTIONS(7727),
    [sym_internal_keyword] = ACTIONS(7727),
    [sym_protected_keyword] = ACTIONS(7727),
    [sym_event_keyword] = ACTIONS(7727),
    [sym_fields_keyword] = ACTIONS(7727),
    [sym_keys_keyword] = ACTIONS(7727),
    [sym_key_keyword] = ACTIONS(7712),
    [sym_fieldgroups_keyword] = ACTIONS(7727),
    [sym_actions_keyword] = ACTIONS(7727),
    [sym_layout_keyword] = ACTIONS(7727),
    [sym_dataset_keyword] = ACTIONS(7720),
    [sym_elements_keyword] = ACTIONS(7727),
    [sym_labels_keyword] = ACTIONS(7727),
    [sym_rendering_keyword] = ACTIONS(7727),
    [sym_requestpage_keyword] = ACTIONS(7727),
    [sym_schema_keyword] = ACTIONS(7727),
    [sym_views_keyword] = ACTIONS(7727),
    [sym_quoted_identifier] = ACTIONS(7737),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7730),
    [sym_preproc_open] = ACTIONS(7715),
    [sym_preproc_close] = ACTIONS(7730),
  },
  [STATE(4013)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(8994),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5961),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_addafter_modification_token1] = ACTIONS(5961),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5961),
    [aux_sym_movelast_modification_token1] = ACTIONS(5961),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5961),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_area_keyword] = ACTIONS(5961),
    [sym_group_keyword] = ACTIONS(5961),
    [sym_repeater_keyword] = ACTIONS(5961),
    [sym_cuegroup_keyword] = ACTIONS(5961),
    [sym_fixed_keyword] = ACTIONS(5961),
    [sym_grid_keyword] = ACTIONS(5961),
    [sym_part_keyword] = ACTIONS(5961),
    [sym_systempart_keyword] = ACTIONS(5961),
    [sym_usercontrol_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_dataitem_keyword] = ACTIONS(5961),
    [sym_column_keyword] = ACTIONS(5961),
    [sym_filter_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(4014)] = {
    [sym_identifier] = ACTIONS(7757),
    [anon_sym_SEMI] = ACTIONS(7760),
    [aux_sym_where_condition_token1] = ACTIONS(7757),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [anon_sym_LBRACK] = ACTIONS(7775),
    [aux_sym_basic_type_token22] = ACTIONS(7757),
    [aux_sym_basic_type_token53] = ACTIONS(7757),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7765),
    [aux_sym_modify_modification_token1] = ACTIONS(7772),
    [aux_sym_separator_action_token1] = ACTIONS(7757),
    [aux_sym_xmlport_element_token1] = ACTIONS(7772),
    [aux_sym_xmlport_element_token2] = ACTIONS(7772),
    [aux_sym_xmlport_element_token3] = ACTIONS(7772),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7772),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7772),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7765),
    [aux_sym_type_declaration_token1] = ACTIONS(7757),
    [anon_sym_POUNDif] = ACTIONS(7760),
    [anon_sym_POUNDIF] = ACTIONS(7760),
    [anon_sym_POUNDIf] = ACTIONS(7760),
    [anon_sym_POUNDelif] = ACTIONS(7775),
    [anon_sym_POUNDELIF] = ACTIONS(7775),
    [anon_sym_POUNDElif] = ACTIONS(7775),
    [anon_sym_POUNDelse] = ACTIONS(7775),
    [anon_sym_POUNDELSE] = ACTIONS(7775),
    [anon_sym_POUNDElse] = ACTIONS(7775),
    [anon_sym_POUNDelse2] = ACTIONS(7775),
    [anon_sym_POUNDELSE2] = ACTIONS(7775),
    [anon_sym_POUNDElse2] = ACTIONS(7775),
    [anon_sym_POUNDendif] = ACTIONS(7775),
    [anon_sym_POUNDENDIF] = ACTIONS(7775),
    [anon_sym_POUNDEndif] = ACTIONS(7775),
    [anon_sym_POUNDendif2] = ACTIONS(7775),
    [anon_sym_POUNDENDIF2] = ACTIONS(7775),
    [anon_sym_POUNDEndif2] = ACTIONS(7775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7778),
    [sym_page_keyword] = ACTIONS(7770),
    [anon_sym_codeunit] = ACTIONS(7770),
    [anon_sym_CODEUNIT] = ACTIONS(7770),
    [anon_sym_Codeunit] = ACTIONS(7770),
    [anon_sym_CodeUnit] = ACTIONS(7770),
    [anon_sym_COdeunit] = ACTIONS(7770),
    [anon_sym_codeUnit] = ACTIONS(7770),
    [sym_report_keyword] = ACTIONS(7770),
    [sym_query_keyword] = ACTIONS(7770),
    [anon_sym_xmlport] = ACTIONS(7770),
    [anon_sym_XMLPORT] = ACTIONS(7770),
    [anon_sym_Xmlport] = ACTIONS(7770),
    [anon_sym_XMLport] = ACTIONS(7770),
    [anon_sym_XMLPort] = ACTIONS(7770),
    [anon_sym_XmlPort] = ACTIONS(7770),
    [sym_procedure_keyword] = ACTIONS(7772),
    [sym_trigger_keyword] = ACTIONS(7772),
    [sym_var_keyword] = ACTIONS(7772),
    [sym_local_keyword] = ACTIONS(7772),
    [sym_internal_keyword] = ACTIONS(7772),
    [sym_protected_keyword] = ACTIONS(7772),
    [sym_event_keyword] = ACTIONS(7772),
    [sym_fields_keyword] = ACTIONS(7772),
    [sym_keys_keyword] = ACTIONS(7772),
    [sym_key_keyword] = ACTIONS(7757),
    [sym_fieldgroups_keyword] = ACTIONS(7772),
    [sym_actions_keyword] = ACTIONS(7772),
    [sym_layout_keyword] = ACTIONS(7772),
    [sym_dataset_keyword] = ACTIONS(7765),
    [sym_elements_keyword] = ACTIONS(7772),
    [sym_labels_keyword] = ACTIONS(7772),
    [sym_rendering_keyword] = ACTIONS(7772),
    [sym_requestpage_keyword] = ACTIONS(7772),
    [sym_schema_keyword] = ACTIONS(7772),
    [sym_views_keyword] = ACTIONS(7772),
    [sym_quoted_identifier] = ACTIONS(7782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7775),
    [sym_preproc_open] = ACTIONS(7760),
    [sym_preproc_close] = ACTIONS(7775),
  },
  [STATE(4015)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(8996),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5961),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_addafter_modification_token1] = ACTIONS(5961),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5961),
    [aux_sym_movelast_modification_token1] = ACTIONS(5961),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5961),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_area_keyword] = ACTIONS(5961),
    [sym_group_keyword] = ACTIONS(5961),
    [sym_repeater_keyword] = ACTIONS(5961),
    [sym_cuegroup_keyword] = ACTIONS(5961),
    [sym_fixed_keyword] = ACTIONS(5961),
    [sym_grid_keyword] = ACTIONS(5961),
    [sym_part_keyword] = ACTIONS(5961),
    [sym_systempart_keyword] = ACTIONS(5961),
    [sym_usercontrol_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_dataitem_keyword] = ACTIONS(5961),
    [sym_column_keyword] = ACTIONS(5961),
    [sym_filter_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(4016)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5965),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5961),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_addafter_modification_token1] = ACTIONS(5961),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5961),
    [aux_sym_movelast_modification_token1] = ACTIONS(5961),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5961),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_area_keyword] = ACTIONS(5961),
    [sym_group_keyword] = ACTIONS(5961),
    [sym_repeater_keyword] = ACTIONS(5961),
    [sym_cuegroup_keyword] = ACTIONS(5961),
    [sym_fixed_keyword] = ACTIONS(5961),
    [sym_grid_keyword] = ACTIONS(5961),
    [sym_part_keyword] = ACTIONS(5961),
    [sym_systempart_keyword] = ACTIONS(5961),
    [sym_usercontrol_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_dataitem_keyword] = ACTIONS(5961),
    [sym_column_keyword] = ACTIONS(5961),
    [sym_filter_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(4017)] = {
    [sym_identifier] = ACTIONS(8998),
    [anon_sym_SEMI] = ACTIONS(9000),
    [aux_sym_where_condition_token1] = ACTIONS(8998),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8998),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8998),
    [anon_sym_LBRACK] = ACTIONS(9000),
    [aux_sym_basic_type_token6] = ACTIONS(8998),
    [aux_sym_basic_type_token22] = ACTIONS(8998),
    [aux_sym_basic_type_token53] = ACTIONS(8998),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8998),
    [aux_sym_addafter_modification_token1] = ACTIONS(8998),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8998),
    [aux_sym_modify_modification_token1] = ACTIONS(8998),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8998),
    [aux_sym_movelast_modification_token1] = ACTIONS(8998),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8998),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8998),
    [aux_sym_separator_action_token1] = ACTIONS(8998),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8998),
    [aux_sym_type_declaration_token1] = ACTIONS(8998),
    [anon_sym_POUNDif] = ACTIONS(9000),
    [anon_sym_POUNDIF] = ACTIONS(9000),
    [anon_sym_POUNDIf] = ACTIONS(9000),
    [anon_sym_POUNDelif] = ACTIONS(9000),
    [anon_sym_POUNDELIF] = ACTIONS(9000),
    [anon_sym_POUNDElif] = ACTIONS(9000),
    [anon_sym_POUNDelse] = ACTIONS(9000),
    [anon_sym_POUNDELSE] = ACTIONS(9000),
    [anon_sym_POUNDElse] = ACTIONS(9000),
    [anon_sym_POUNDelse2] = ACTIONS(9000),
    [anon_sym_POUNDELSE2] = ACTIONS(9000),
    [anon_sym_POUNDElse2] = ACTIONS(9000),
    [anon_sym_POUNDendif] = ACTIONS(9000),
    [anon_sym_POUNDENDIF] = ACTIONS(9000),
    [anon_sym_POUNDEndif] = ACTIONS(9000),
    [anon_sym_POUNDendif2] = ACTIONS(9000),
    [anon_sym_POUNDENDIF2] = ACTIONS(9000),
    [anon_sym_POUNDEndif2] = ACTIONS(9000),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8998),
    [sym_procedure_keyword] = ACTIONS(8998),
    [sym_trigger_keyword] = ACTIONS(8998),
    [sym_var_keyword] = ACTIONS(8998),
    [sym_local_keyword] = ACTIONS(8998),
    [sym_internal_keyword] = ACTIONS(8998),
    [sym_protected_keyword] = ACTIONS(8998),
    [sym_event_keyword] = ACTIONS(8998),
    [sym_fields_keyword] = ACTIONS(8998),
    [sym_keys_keyword] = ACTIONS(8998),
    [sym_key_keyword] = ACTIONS(8998),
    [sym_fieldgroups_keyword] = ACTIONS(8998),
    [sym_actions_keyword] = ACTIONS(8998),
    [sym_layout_keyword] = ACTIONS(8998),
    [sym_area_keyword] = ACTIONS(8998),
    [sym_group_keyword] = ACTIONS(8998),
    [sym_repeater_keyword] = ACTIONS(8998),
    [sym_cuegroup_keyword] = ACTIONS(8998),
    [sym_fixed_keyword] = ACTIONS(8998),
    [sym_grid_keyword] = ACTIONS(8998),
    [sym_part_keyword] = ACTIONS(8998),
    [sym_systempart_keyword] = ACTIONS(8998),
    [sym_usercontrol_keyword] = ACTIONS(8998),
    [sym_dataset_keyword] = ACTIONS(8998),
    [sym_elements_keyword] = ACTIONS(8998),
    [sym_dataitem_keyword] = ACTIONS(8998),
    [sym_column_keyword] = ACTIONS(8998),
    [sym_filter_keyword] = ACTIONS(8998),
    [sym_labels_keyword] = ACTIONS(8998),
    [sym_rendering_keyword] = ACTIONS(8998),
    [sym_requestpage_keyword] = ACTIONS(8998),
    [sym_schema_keyword] = ACTIONS(8998),
    [sym_views_keyword] = ACTIONS(8998),
    [sym_quoted_identifier] = ACTIONS(9000),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9000),
    [sym_preproc_open] = ACTIONS(9000),
    [sym_preproc_close] = ACTIONS(9000),
    [sym_var_attribute_open] = ACTIONS(9000),
  },
  [STATE(4018)] = {
    [sym_identifier] = ACTIONS(9002),
    [anon_sym_SEMI] = ACTIONS(9004),
    [aux_sym_where_condition_token1] = ACTIONS(9002),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9002),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9002),
    [anon_sym_LBRACK] = ACTIONS(9004),
    [aux_sym_basic_type_token6] = ACTIONS(9002),
    [aux_sym_basic_type_token22] = ACTIONS(9002),
    [aux_sym_basic_type_token53] = ACTIONS(9002),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9002),
    [aux_sym_addafter_modification_token1] = ACTIONS(9002),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9002),
    [aux_sym_modify_modification_token1] = ACTIONS(9002),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9002),
    [aux_sym_movelast_modification_token1] = ACTIONS(9002),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9002),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9002),
    [aux_sym_separator_action_token1] = ACTIONS(9002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9002),
    [aux_sym_type_declaration_token1] = ACTIONS(9002),
    [anon_sym_POUNDif] = ACTIONS(9004),
    [anon_sym_POUNDIF] = ACTIONS(9004),
    [anon_sym_POUNDIf] = ACTIONS(9004),
    [anon_sym_POUNDelif] = ACTIONS(9004),
    [anon_sym_POUNDELIF] = ACTIONS(9004),
    [anon_sym_POUNDElif] = ACTIONS(9004),
    [anon_sym_POUNDelse] = ACTIONS(9004),
    [anon_sym_POUNDELSE] = ACTIONS(9004),
    [anon_sym_POUNDElse] = ACTIONS(9004),
    [anon_sym_POUNDelse2] = ACTIONS(9004),
    [anon_sym_POUNDELSE2] = ACTIONS(9004),
    [anon_sym_POUNDElse2] = ACTIONS(9004),
    [anon_sym_POUNDendif] = ACTIONS(9004),
    [anon_sym_POUNDENDIF] = ACTIONS(9004),
    [anon_sym_POUNDEndif] = ACTIONS(9004),
    [anon_sym_POUNDendif2] = ACTIONS(9004),
    [anon_sym_POUNDENDIF2] = ACTIONS(9004),
    [anon_sym_POUNDEndif2] = ACTIONS(9004),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9002),
    [sym_procedure_keyword] = ACTIONS(9002),
    [sym_trigger_keyword] = ACTIONS(9002),
    [sym_var_keyword] = ACTIONS(9002),
    [sym_local_keyword] = ACTIONS(9002),
    [sym_internal_keyword] = ACTIONS(9002),
    [sym_protected_keyword] = ACTIONS(9002),
    [sym_event_keyword] = ACTIONS(9002),
    [sym_fields_keyword] = ACTIONS(9002),
    [sym_keys_keyword] = ACTIONS(9002),
    [sym_key_keyword] = ACTIONS(9002),
    [sym_fieldgroups_keyword] = ACTIONS(9002),
    [sym_actions_keyword] = ACTIONS(9002),
    [sym_layout_keyword] = ACTIONS(9002),
    [sym_area_keyword] = ACTIONS(9002),
    [sym_group_keyword] = ACTIONS(9002),
    [sym_repeater_keyword] = ACTIONS(9002),
    [sym_cuegroup_keyword] = ACTIONS(9002),
    [sym_fixed_keyword] = ACTIONS(9002),
    [sym_grid_keyword] = ACTIONS(9002),
    [sym_part_keyword] = ACTIONS(9002),
    [sym_systempart_keyword] = ACTIONS(9002),
    [sym_usercontrol_keyword] = ACTIONS(9002),
    [sym_dataset_keyword] = ACTIONS(9002),
    [sym_elements_keyword] = ACTIONS(9002),
    [sym_dataitem_keyword] = ACTIONS(9002),
    [sym_column_keyword] = ACTIONS(9002),
    [sym_filter_keyword] = ACTIONS(9002),
    [sym_labels_keyword] = ACTIONS(9002),
    [sym_rendering_keyword] = ACTIONS(9002),
    [sym_requestpage_keyword] = ACTIONS(9002),
    [sym_schema_keyword] = ACTIONS(9002),
    [sym_views_keyword] = ACTIONS(9002),
    [sym_quoted_identifier] = ACTIONS(9004),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9004),
    [sym_preproc_open] = ACTIONS(9004),
    [sym_preproc_close] = ACTIONS(9004),
    [sym_var_attribute_open] = ACTIONS(9004),
  },
  [STATE(4019)] = {
    [sym_identifier] = ACTIONS(9002),
    [anon_sym_SEMI] = ACTIONS(9004),
    [aux_sym_where_condition_token1] = ACTIONS(9002),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9002),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9002),
    [anon_sym_LBRACK] = ACTIONS(9004),
    [aux_sym_basic_type_token6] = ACTIONS(9002),
    [aux_sym_basic_type_token22] = ACTIONS(9002),
    [aux_sym_basic_type_token53] = ACTIONS(9002),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9002),
    [aux_sym_addafter_modification_token1] = ACTIONS(9002),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9002),
    [aux_sym_modify_modification_token1] = ACTIONS(9002),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9002),
    [aux_sym_movelast_modification_token1] = ACTIONS(9002),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9002),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9002),
    [aux_sym_separator_action_token1] = ACTIONS(9002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9002),
    [aux_sym_type_declaration_token1] = ACTIONS(9002),
    [anon_sym_POUNDif] = ACTIONS(9004),
    [anon_sym_POUNDIF] = ACTIONS(9004),
    [anon_sym_POUNDIf] = ACTIONS(9004),
    [anon_sym_POUNDelif] = ACTIONS(9004),
    [anon_sym_POUNDELIF] = ACTIONS(9004),
    [anon_sym_POUNDElif] = ACTIONS(9004),
    [anon_sym_POUNDelse] = ACTIONS(9004),
    [anon_sym_POUNDELSE] = ACTIONS(9004),
    [anon_sym_POUNDElse] = ACTIONS(9004),
    [anon_sym_POUNDelse2] = ACTIONS(9004),
    [anon_sym_POUNDELSE2] = ACTIONS(9004),
    [anon_sym_POUNDElse2] = ACTIONS(9004),
    [anon_sym_POUNDendif] = ACTIONS(9004),
    [anon_sym_POUNDENDIF] = ACTIONS(9004),
    [anon_sym_POUNDEndif] = ACTIONS(9004),
    [anon_sym_POUNDendif2] = ACTIONS(9004),
    [anon_sym_POUNDENDIF2] = ACTIONS(9004),
    [anon_sym_POUNDEndif2] = ACTIONS(9004),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9002),
    [sym_procedure_keyword] = ACTIONS(9002),
    [sym_trigger_keyword] = ACTIONS(9002),
    [sym_var_keyword] = ACTIONS(9002),
    [sym_local_keyword] = ACTIONS(9002),
    [sym_internal_keyword] = ACTIONS(9002),
    [sym_protected_keyword] = ACTIONS(9002),
    [sym_event_keyword] = ACTIONS(9002),
    [sym_fields_keyword] = ACTIONS(9002),
    [sym_keys_keyword] = ACTIONS(9002),
    [sym_key_keyword] = ACTIONS(9002),
    [sym_fieldgroups_keyword] = ACTIONS(9002),
    [sym_actions_keyword] = ACTIONS(9002),
    [sym_layout_keyword] = ACTIONS(9002),
    [sym_area_keyword] = ACTIONS(9002),
    [sym_group_keyword] = ACTIONS(9002),
    [sym_repeater_keyword] = ACTIONS(9002),
    [sym_cuegroup_keyword] = ACTIONS(9002),
    [sym_fixed_keyword] = ACTIONS(9002),
    [sym_grid_keyword] = ACTIONS(9002),
    [sym_part_keyword] = ACTIONS(9002),
    [sym_systempart_keyword] = ACTIONS(9002),
    [sym_usercontrol_keyword] = ACTIONS(9002),
    [sym_dataset_keyword] = ACTIONS(9002),
    [sym_elements_keyword] = ACTIONS(9002),
    [sym_dataitem_keyword] = ACTIONS(9002),
    [sym_column_keyword] = ACTIONS(9002),
    [sym_filter_keyword] = ACTIONS(9002),
    [sym_labels_keyword] = ACTIONS(9002),
    [sym_rendering_keyword] = ACTIONS(9002),
    [sym_requestpage_keyword] = ACTIONS(9002),
    [sym_schema_keyword] = ACTIONS(9002),
    [sym_views_keyword] = ACTIONS(9002),
    [sym_quoted_identifier] = ACTIONS(9004),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9004),
    [sym_preproc_open] = ACTIONS(9004),
    [sym_preproc_close] = ACTIONS(9004),
    [sym_var_attribute_open] = ACTIONS(9004),
  },
  [STATE(4020)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9006),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_addafter_modification_token1] = ACTIONS(9006),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9006),
    [aux_sym_movelast_modification_token1] = ACTIONS(9006),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9006),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_area_keyword] = ACTIONS(9006),
    [sym_group_keyword] = ACTIONS(9006),
    [sym_repeater_keyword] = ACTIONS(9006),
    [sym_cuegroup_keyword] = ACTIONS(9006),
    [sym_fixed_keyword] = ACTIONS(9006),
    [sym_grid_keyword] = ACTIONS(9006),
    [sym_part_keyword] = ACTIONS(9006),
    [sym_systempart_keyword] = ACTIONS(9006),
    [sym_usercontrol_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_dataitem_keyword] = ACTIONS(9006),
    [sym_column_keyword] = ACTIONS(9006),
    [sym_filter_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(4021)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(8060),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4022)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9006),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_addafter_modification_token1] = ACTIONS(9006),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9006),
    [aux_sym_movelast_modification_token1] = ACTIONS(9006),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9006),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_area_keyword] = ACTIONS(9006),
    [sym_group_keyword] = ACTIONS(9006),
    [sym_repeater_keyword] = ACTIONS(9006),
    [sym_cuegroup_keyword] = ACTIONS(9006),
    [sym_fixed_keyword] = ACTIONS(9006),
    [sym_grid_keyword] = ACTIONS(9006),
    [sym_part_keyword] = ACTIONS(9006),
    [sym_systempart_keyword] = ACTIONS(9006),
    [sym_usercontrol_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_dataitem_keyword] = ACTIONS(9006),
    [sym_column_keyword] = ACTIONS(9006),
    [sym_filter_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(4023)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9006),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_addafter_modification_token1] = ACTIONS(9006),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9006),
    [aux_sym_movelast_modification_token1] = ACTIONS(9006),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9006),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_area_keyword] = ACTIONS(9006),
    [sym_group_keyword] = ACTIONS(9006),
    [sym_repeater_keyword] = ACTIONS(9006),
    [sym_cuegroup_keyword] = ACTIONS(9006),
    [sym_fixed_keyword] = ACTIONS(9006),
    [sym_grid_keyword] = ACTIONS(9006),
    [sym_part_keyword] = ACTIONS(9006),
    [sym_systempart_keyword] = ACTIONS(9006),
    [sym_usercontrol_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_dataitem_keyword] = ACTIONS(9006),
    [sym_column_keyword] = ACTIONS(9006),
    [sym_filter_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(4024)] = {
    [sym_identifier] = ACTIONS(9010),
    [anon_sym_SEMI] = ACTIONS(9012),
    [aux_sym_where_condition_token1] = ACTIONS(9010),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9010),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9010),
    [anon_sym_LBRACK] = ACTIONS(9012),
    [aux_sym_basic_type_token6] = ACTIONS(9010),
    [aux_sym_basic_type_token22] = ACTIONS(9010),
    [aux_sym_basic_type_token53] = ACTIONS(9010),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9010),
    [aux_sym_addafter_modification_token1] = ACTIONS(9010),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9010),
    [aux_sym_modify_modification_token1] = ACTIONS(9010),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9010),
    [aux_sym_movelast_modification_token1] = ACTIONS(9010),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9010),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9010),
    [aux_sym_separator_action_token1] = ACTIONS(9010),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9010),
    [aux_sym_type_declaration_token1] = ACTIONS(9010),
    [anon_sym_POUNDif] = ACTIONS(9012),
    [anon_sym_POUNDIF] = ACTIONS(9012),
    [anon_sym_POUNDIf] = ACTIONS(9012),
    [anon_sym_POUNDelif] = ACTIONS(9012),
    [anon_sym_POUNDELIF] = ACTIONS(9012),
    [anon_sym_POUNDElif] = ACTIONS(9012),
    [anon_sym_POUNDelse] = ACTIONS(9012),
    [anon_sym_POUNDELSE] = ACTIONS(9012),
    [anon_sym_POUNDElse] = ACTIONS(9012),
    [anon_sym_POUNDelse2] = ACTIONS(9012),
    [anon_sym_POUNDELSE2] = ACTIONS(9012),
    [anon_sym_POUNDElse2] = ACTIONS(9012),
    [anon_sym_POUNDendif] = ACTIONS(9012),
    [anon_sym_POUNDENDIF] = ACTIONS(9012),
    [anon_sym_POUNDEndif] = ACTIONS(9012),
    [anon_sym_POUNDendif2] = ACTIONS(9012),
    [anon_sym_POUNDENDIF2] = ACTIONS(9012),
    [anon_sym_POUNDEndif2] = ACTIONS(9012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9010),
    [sym_procedure_keyword] = ACTIONS(9010),
    [sym_trigger_keyword] = ACTIONS(9010),
    [sym_var_keyword] = ACTIONS(9010),
    [sym_local_keyword] = ACTIONS(9010),
    [sym_internal_keyword] = ACTIONS(9010),
    [sym_protected_keyword] = ACTIONS(9010),
    [sym_event_keyword] = ACTIONS(9010),
    [sym_fields_keyword] = ACTIONS(9010),
    [sym_keys_keyword] = ACTIONS(9010),
    [sym_key_keyword] = ACTIONS(9010),
    [sym_fieldgroups_keyword] = ACTIONS(9010),
    [sym_actions_keyword] = ACTIONS(9010),
    [sym_layout_keyword] = ACTIONS(9010),
    [sym_area_keyword] = ACTIONS(9010),
    [sym_group_keyword] = ACTIONS(9010),
    [sym_repeater_keyword] = ACTIONS(9010),
    [sym_cuegroup_keyword] = ACTIONS(9010),
    [sym_fixed_keyword] = ACTIONS(9010),
    [sym_grid_keyword] = ACTIONS(9010),
    [sym_part_keyword] = ACTIONS(9010),
    [sym_systempart_keyword] = ACTIONS(9010),
    [sym_usercontrol_keyword] = ACTIONS(9010),
    [sym_dataset_keyword] = ACTIONS(9010),
    [sym_elements_keyword] = ACTIONS(9010),
    [sym_dataitem_keyword] = ACTIONS(9010),
    [sym_column_keyword] = ACTIONS(9010),
    [sym_filter_keyword] = ACTIONS(9010),
    [sym_labels_keyword] = ACTIONS(9010),
    [sym_rendering_keyword] = ACTIONS(9010),
    [sym_requestpage_keyword] = ACTIONS(9010),
    [sym_schema_keyword] = ACTIONS(9010),
    [sym_views_keyword] = ACTIONS(9010),
    [sym_quoted_identifier] = ACTIONS(9012),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9012),
    [sym_preproc_open] = ACTIONS(9012),
    [sym_preproc_close] = ACTIONS(9012),
    [sym_var_attribute_open] = ACTIONS(9012),
  },
  [STATE(4025)] = {
    [sym_identifier] = ACTIONS(9014),
    [anon_sym_SEMI] = ACTIONS(9016),
    [aux_sym_where_condition_token1] = ACTIONS(9014),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9014),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9014),
    [anon_sym_LBRACK] = ACTIONS(9016),
    [aux_sym_basic_type_token6] = ACTIONS(9014),
    [aux_sym_basic_type_token22] = ACTIONS(9014),
    [aux_sym_basic_type_token53] = ACTIONS(9014),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9014),
    [aux_sym_addafter_modification_token1] = ACTIONS(9014),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9014),
    [aux_sym_modify_modification_token1] = ACTIONS(9014),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9014),
    [aux_sym_movelast_modification_token1] = ACTIONS(9014),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9014),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9014),
    [aux_sym_separator_action_token1] = ACTIONS(9014),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9014),
    [aux_sym_type_declaration_token1] = ACTIONS(9014),
    [anon_sym_POUNDif] = ACTIONS(9016),
    [anon_sym_POUNDIF] = ACTIONS(9016),
    [anon_sym_POUNDIf] = ACTIONS(9016),
    [anon_sym_POUNDelif] = ACTIONS(9016),
    [anon_sym_POUNDELIF] = ACTIONS(9016),
    [anon_sym_POUNDElif] = ACTIONS(9016),
    [anon_sym_POUNDelse] = ACTIONS(9016),
    [anon_sym_POUNDELSE] = ACTIONS(9016),
    [anon_sym_POUNDElse] = ACTIONS(9016),
    [anon_sym_POUNDelse2] = ACTIONS(9016),
    [anon_sym_POUNDELSE2] = ACTIONS(9016),
    [anon_sym_POUNDElse2] = ACTIONS(9016),
    [anon_sym_POUNDendif] = ACTIONS(9016),
    [anon_sym_POUNDENDIF] = ACTIONS(9016),
    [anon_sym_POUNDEndif] = ACTIONS(9016),
    [anon_sym_POUNDendif2] = ACTIONS(9016),
    [anon_sym_POUNDENDIF2] = ACTIONS(9016),
    [anon_sym_POUNDEndif2] = ACTIONS(9016),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9014),
    [sym_procedure_keyword] = ACTIONS(9014),
    [sym_trigger_keyword] = ACTIONS(9014),
    [sym_var_keyword] = ACTIONS(9014),
    [sym_local_keyword] = ACTIONS(9014),
    [sym_internal_keyword] = ACTIONS(9014),
    [sym_protected_keyword] = ACTIONS(9014),
    [sym_event_keyword] = ACTIONS(9014),
    [sym_fields_keyword] = ACTIONS(9014),
    [sym_keys_keyword] = ACTIONS(9014),
    [sym_key_keyword] = ACTIONS(9014),
    [sym_fieldgroups_keyword] = ACTIONS(9014),
    [sym_actions_keyword] = ACTIONS(9014),
    [sym_layout_keyword] = ACTIONS(9014),
    [sym_area_keyword] = ACTIONS(9014),
    [sym_group_keyword] = ACTIONS(9014),
    [sym_repeater_keyword] = ACTIONS(9014),
    [sym_cuegroup_keyword] = ACTIONS(9014),
    [sym_fixed_keyword] = ACTIONS(9014),
    [sym_grid_keyword] = ACTIONS(9014),
    [sym_part_keyword] = ACTIONS(9014),
    [sym_systempart_keyword] = ACTIONS(9014),
    [sym_usercontrol_keyword] = ACTIONS(9014),
    [sym_dataset_keyword] = ACTIONS(9014),
    [sym_elements_keyword] = ACTIONS(9014),
    [sym_dataitem_keyword] = ACTIONS(9014),
    [sym_column_keyword] = ACTIONS(9014),
    [sym_filter_keyword] = ACTIONS(9014),
    [sym_labels_keyword] = ACTIONS(9014),
    [sym_rendering_keyword] = ACTIONS(9014),
    [sym_requestpage_keyword] = ACTIONS(9014),
    [sym_schema_keyword] = ACTIONS(9014),
    [sym_views_keyword] = ACTIONS(9014),
    [sym_quoted_identifier] = ACTIONS(9016),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9016),
    [sym_preproc_open] = ACTIONS(9016),
    [sym_preproc_close] = ACTIONS(9016),
    [sym_var_attribute_open] = ACTIONS(9016),
  },
  [STATE(4026)] = {
    [sym_identifier] = ACTIONS(9018),
    [anon_sym_SEMI] = ACTIONS(9020),
    [aux_sym_where_condition_token1] = ACTIONS(9018),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9018),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9018),
    [anon_sym_LBRACK] = ACTIONS(9020),
    [aux_sym_basic_type_token6] = ACTIONS(9018),
    [aux_sym_basic_type_token22] = ACTIONS(9018),
    [aux_sym_basic_type_token53] = ACTIONS(9018),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9018),
    [aux_sym_addafter_modification_token1] = ACTIONS(9018),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9018),
    [aux_sym_modify_modification_token1] = ACTIONS(9018),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9018),
    [aux_sym_movelast_modification_token1] = ACTIONS(9018),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9018),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9018),
    [aux_sym_separator_action_token1] = ACTIONS(9018),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9018),
    [aux_sym_type_declaration_token1] = ACTIONS(9018),
    [anon_sym_POUNDif] = ACTIONS(9020),
    [anon_sym_POUNDIF] = ACTIONS(9020),
    [anon_sym_POUNDIf] = ACTIONS(9020),
    [anon_sym_POUNDelif] = ACTIONS(9020),
    [anon_sym_POUNDELIF] = ACTIONS(9020),
    [anon_sym_POUNDElif] = ACTIONS(9020),
    [anon_sym_POUNDelse] = ACTIONS(9020),
    [anon_sym_POUNDELSE] = ACTIONS(9020),
    [anon_sym_POUNDElse] = ACTIONS(9020),
    [anon_sym_POUNDelse2] = ACTIONS(9020),
    [anon_sym_POUNDELSE2] = ACTIONS(9020),
    [anon_sym_POUNDElse2] = ACTIONS(9020),
    [anon_sym_POUNDendif] = ACTIONS(9020),
    [anon_sym_POUNDENDIF] = ACTIONS(9020),
    [anon_sym_POUNDEndif] = ACTIONS(9020),
    [anon_sym_POUNDendif2] = ACTIONS(9020),
    [anon_sym_POUNDENDIF2] = ACTIONS(9020),
    [anon_sym_POUNDEndif2] = ACTIONS(9020),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9018),
    [sym_procedure_keyword] = ACTIONS(9018),
    [sym_trigger_keyword] = ACTIONS(9018),
    [sym_var_keyword] = ACTIONS(9018),
    [sym_local_keyword] = ACTIONS(9018),
    [sym_internal_keyword] = ACTIONS(9018),
    [sym_protected_keyword] = ACTIONS(9018),
    [sym_event_keyword] = ACTIONS(9018),
    [sym_fields_keyword] = ACTIONS(9018),
    [sym_keys_keyword] = ACTIONS(9018),
    [sym_key_keyword] = ACTIONS(9018),
    [sym_fieldgroups_keyword] = ACTIONS(9018),
    [sym_actions_keyword] = ACTIONS(9018),
    [sym_layout_keyword] = ACTIONS(9018),
    [sym_area_keyword] = ACTIONS(9018),
    [sym_group_keyword] = ACTIONS(9018),
    [sym_repeater_keyword] = ACTIONS(9018),
    [sym_cuegroup_keyword] = ACTIONS(9018),
    [sym_fixed_keyword] = ACTIONS(9018),
    [sym_grid_keyword] = ACTIONS(9018),
    [sym_part_keyword] = ACTIONS(9018),
    [sym_systempart_keyword] = ACTIONS(9018),
    [sym_usercontrol_keyword] = ACTIONS(9018),
    [sym_dataset_keyword] = ACTIONS(9018),
    [sym_elements_keyword] = ACTIONS(9018),
    [sym_dataitem_keyword] = ACTIONS(9018),
    [sym_column_keyword] = ACTIONS(9018),
    [sym_filter_keyword] = ACTIONS(9018),
    [sym_labels_keyword] = ACTIONS(9018),
    [sym_rendering_keyword] = ACTIONS(9018),
    [sym_requestpage_keyword] = ACTIONS(9018),
    [sym_schema_keyword] = ACTIONS(9018),
    [sym_views_keyword] = ACTIONS(9018),
    [sym_quoted_identifier] = ACTIONS(9020),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9020),
    [sym_preproc_open] = ACTIONS(9020),
    [sym_preproc_close] = ACTIONS(9020),
    [sym_var_attribute_open] = ACTIONS(9020),
  },
  [STATE(4027)] = {
    [sym_identifier] = ACTIONS(9022),
    [anon_sym_SEMI] = ACTIONS(9024),
    [aux_sym_where_condition_token1] = ACTIONS(9022),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9022),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9022),
    [anon_sym_LBRACK] = ACTIONS(9024),
    [aux_sym_basic_type_token6] = ACTIONS(9022),
    [aux_sym_basic_type_token22] = ACTIONS(9022),
    [aux_sym_basic_type_token53] = ACTIONS(9022),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9022),
    [aux_sym_addafter_modification_token1] = ACTIONS(9022),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9022),
    [aux_sym_modify_modification_token1] = ACTIONS(9022),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9022),
    [aux_sym_movelast_modification_token1] = ACTIONS(9022),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9022),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9022),
    [aux_sym_separator_action_token1] = ACTIONS(9022),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9022),
    [aux_sym_type_declaration_token1] = ACTIONS(9022),
    [anon_sym_POUNDif] = ACTIONS(9024),
    [anon_sym_POUNDIF] = ACTIONS(9024),
    [anon_sym_POUNDIf] = ACTIONS(9024),
    [anon_sym_POUNDelif] = ACTIONS(9024),
    [anon_sym_POUNDELIF] = ACTIONS(9024),
    [anon_sym_POUNDElif] = ACTIONS(9024),
    [anon_sym_POUNDelse] = ACTIONS(9024),
    [anon_sym_POUNDELSE] = ACTIONS(9024),
    [anon_sym_POUNDElse] = ACTIONS(9024),
    [anon_sym_POUNDelse2] = ACTIONS(9024),
    [anon_sym_POUNDELSE2] = ACTIONS(9024),
    [anon_sym_POUNDElse2] = ACTIONS(9024),
    [anon_sym_POUNDendif] = ACTIONS(9024),
    [anon_sym_POUNDENDIF] = ACTIONS(9024),
    [anon_sym_POUNDEndif] = ACTIONS(9024),
    [anon_sym_POUNDendif2] = ACTIONS(9024),
    [anon_sym_POUNDENDIF2] = ACTIONS(9024),
    [anon_sym_POUNDEndif2] = ACTIONS(9024),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9022),
    [sym_procedure_keyword] = ACTIONS(9022),
    [sym_trigger_keyword] = ACTIONS(9022),
    [sym_var_keyword] = ACTIONS(9022),
    [sym_local_keyword] = ACTIONS(9022),
    [sym_internal_keyword] = ACTIONS(9022),
    [sym_protected_keyword] = ACTIONS(9022),
    [sym_event_keyword] = ACTIONS(9022),
    [sym_fields_keyword] = ACTIONS(9022),
    [sym_keys_keyword] = ACTIONS(9022),
    [sym_key_keyword] = ACTIONS(9022),
    [sym_fieldgroups_keyword] = ACTIONS(9022),
    [sym_actions_keyword] = ACTIONS(9022),
    [sym_layout_keyword] = ACTIONS(9022),
    [sym_area_keyword] = ACTIONS(9022),
    [sym_group_keyword] = ACTIONS(9022),
    [sym_repeater_keyword] = ACTIONS(9022),
    [sym_cuegroup_keyword] = ACTIONS(9022),
    [sym_fixed_keyword] = ACTIONS(9022),
    [sym_grid_keyword] = ACTIONS(9022),
    [sym_part_keyword] = ACTIONS(9022),
    [sym_systempart_keyword] = ACTIONS(9022),
    [sym_usercontrol_keyword] = ACTIONS(9022),
    [sym_dataset_keyword] = ACTIONS(9022),
    [sym_elements_keyword] = ACTIONS(9022),
    [sym_dataitem_keyword] = ACTIONS(9022),
    [sym_column_keyword] = ACTIONS(9022),
    [sym_filter_keyword] = ACTIONS(9022),
    [sym_labels_keyword] = ACTIONS(9022),
    [sym_rendering_keyword] = ACTIONS(9022),
    [sym_requestpage_keyword] = ACTIONS(9022),
    [sym_schema_keyword] = ACTIONS(9022),
    [sym_views_keyword] = ACTIONS(9022),
    [sym_quoted_identifier] = ACTIONS(9024),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9024),
    [sym_preproc_open] = ACTIONS(9024),
    [sym_preproc_close] = ACTIONS(9024),
    [sym_var_attribute_open] = ACTIONS(9024),
  },
  [STATE(4028)] = {
    [sym_identifier] = ACTIONS(9026),
    [anon_sym_SEMI] = ACTIONS(9028),
    [aux_sym_where_condition_token1] = ACTIONS(9026),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9026),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9026),
    [anon_sym_LBRACK] = ACTIONS(9028),
    [aux_sym_basic_type_token6] = ACTIONS(9026),
    [aux_sym_basic_type_token22] = ACTIONS(9026),
    [aux_sym_basic_type_token53] = ACTIONS(9026),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9026),
    [aux_sym_addafter_modification_token1] = ACTIONS(9026),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9026),
    [aux_sym_modify_modification_token1] = ACTIONS(9026),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9026),
    [aux_sym_movelast_modification_token1] = ACTIONS(9026),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9026),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9026),
    [aux_sym_separator_action_token1] = ACTIONS(9026),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9026),
    [aux_sym_type_declaration_token1] = ACTIONS(9026),
    [anon_sym_POUNDif] = ACTIONS(9028),
    [anon_sym_POUNDIF] = ACTIONS(9028),
    [anon_sym_POUNDIf] = ACTIONS(9028),
    [anon_sym_POUNDelif] = ACTIONS(9028),
    [anon_sym_POUNDELIF] = ACTIONS(9028),
    [anon_sym_POUNDElif] = ACTIONS(9028),
    [anon_sym_POUNDelse] = ACTIONS(9028),
    [anon_sym_POUNDELSE] = ACTIONS(9028),
    [anon_sym_POUNDElse] = ACTIONS(9028),
    [anon_sym_POUNDelse2] = ACTIONS(9028),
    [anon_sym_POUNDELSE2] = ACTIONS(9028),
    [anon_sym_POUNDElse2] = ACTIONS(9028),
    [anon_sym_POUNDendif] = ACTIONS(9028),
    [anon_sym_POUNDENDIF] = ACTIONS(9028),
    [anon_sym_POUNDEndif] = ACTIONS(9028),
    [anon_sym_POUNDendif2] = ACTIONS(9028),
    [anon_sym_POUNDENDIF2] = ACTIONS(9028),
    [anon_sym_POUNDEndif2] = ACTIONS(9028),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9026),
    [sym_procedure_keyword] = ACTIONS(9026),
    [sym_trigger_keyword] = ACTIONS(9026),
    [sym_var_keyword] = ACTIONS(9026),
    [sym_local_keyword] = ACTIONS(9026),
    [sym_internal_keyword] = ACTIONS(9026),
    [sym_protected_keyword] = ACTIONS(9026),
    [sym_event_keyword] = ACTIONS(9026),
    [sym_fields_keyword] = ACTIONS(9026),
    [sym_keys_keyword] = ACTIONS(9026),
    [sym_key_keyword] = ACTIONS(9026),
    [sym_fieldgroups_keyword] = ACTIONS(9026),
    [sym_actions_keyword] = ACTIONS(9026),
    [sym_layout_keyword] = ACTIONS(9026),
    [sym_area_keyword] = ACTIONS(9026),
    [sym_group_keyword] = ACTIONS(9026),
    [sym_repeater_keyword] = ACTIONS(9026),
    [sym_cuegroup_keyword] = ACTIONS(9026),
    [sym_fixed_keyword] = ACTIONS(9026),
    [sym_grid_keyword] = ACTIONS(9026),
    [sym_part_keyword] = ACTIONS(9026),
    [sym_systempart_keyword] = ACTIONS(9026),
    [sym_usercontrol_keyword] = ACTIONS(9026),
    [sym_dataset_keyword] = ACTIONS(9026),
    [sym_elements_keyword] = ACTIONS(9026),
    [sym_dataitem_keyword] = ACTIONS(9026),
    [sym_column_keyword] = ACTIONS(9026),
    [sym_filter_keyword] = ACTIONS(9026),
    [sym_labels_keyword] = ACTIONS(9026),
    [sym_rendering_keyword] = ACTIONS(9026),
    [sym_requestpage_keyword] = ACTIONS(9026),
    [sym_schema_keyword] = ACTIONS(9026),
    [sym_views_keyword] = ACTIONS(9026),
    [sym_quoted_identifier] = ACTIONS(9028),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9028),
    [sym_preproc_open] = ACTIONS(9028),
    [sym_preproc_close] = ACTIONS(9028),
    [sym_var_attribute_open] = ACTIONS(9028),
  },
  [STATE(4029)] = {
    [sym_identifier] = ACTIONS(9030),
    [anon_sym_SEMI] = ACTIONS(9032),
    [aux_sym_where_condition_token1] = ACTIONS(9030),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9030),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9030),
    [anon_sym_LBRACK] = ACTIONS(9032),
    [aux_sym_basic_type_token6] = ACTIONS(9030),
    [aux_sym_basic_type_token22] = ACTIONS(9030),
    [aux_sym_basic_type_token53] = ACTIONS(9030),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9030),
    [aux_sym_addafter_modification_token1] = ACTIONS(9030),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9030),
    [aux_sym_modify_modification_token1] = ACTIONS(9030),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9030),
    [aux_sym_movelast_modification_token1] = ACTIONS(9030),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9030),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9030),
    [aux_sym_separator_action_token1] = ACTIONS(9030),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9030),
    [aux_sym_type_declaration_token1] = ACTIONS(9030),
    [anon_sym_POUNDif] = ACTIONS(9032),
    [anon_sym_POUNDIF] = ACTIONS(9032),
    [anon_sym_POUNDIf] = ACTIONS(9032),
    [anon_sym_POUNDelif] = ACTIONS(9032),
    [anon_sym_POUNDELIF] = ACTIONS(9032),
    [anon_sym_POUNDElif] = ACTIONS(9032),
    [anon_sym_POUNDelse] = ACTIONS(9032),
    [anon_sym_POUNDELSE] = ACTIONS(9032),
    [anon_sym_POUNDElse] = ACTIONS(9032),
    [anon_sym_POUNDelse2] = ACTIONS(9032),
    [anon_sym_POUNDELSE2] = ACTIONS(9032),
    [anon_sym_POUNDElse2] = ACTIONS(9032),
    [anon_sym_POUNDendif] = ACTIONS(9032),
    [anon_sym_POUNDENDIF] = ACTIONS(9032),
    [anon_sym_POUNDEndif] = ACTIONS(9032),
    [anon_sym_POUNDendif2] = ACTIONS(9032),
    [anon_sym_POUNDENDIF2] = ACTIONS(9032),
    [anon_sym_POUNDEndif2] = ACTIONS(9032),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9030),
    [sym_procedure_keyword] = ACTIONS(9030),
    [sym_trigger_keyword] = ACTIONS(9030),
    [sym_var_keyword] = ACTIONS(9030),
    [sym_local_keyword] = ACTIONS(9030),
    [sym_internal_keyword] = ACTIONS(9030),
    [sym_protected_keyword] = ACTIONS(9030),
    [sym_event_keyword] = ACTIONS(9030),
    [sym_fields_keyword] = ACTIONS(9030),
    [sym_keys_keyword] = ACTIONS(9030),
    [sym_key_keyword] = ACTIONS(9030),
    [sym_fieldgroups_keyword] = ACTIONS(9030),
    [sym_actions_keyword] = ACTIONS(9030),
    [sym_layout_keyword] = ACTIONS(9030),
    [sym_area_keyword] = ACTIONS(9030),
    [sym_group_keyword] = ACTIONS(9030),
    [sym_repeater_keyword] = ACTIONS(9030),
    [sym_cuegroup_keyword] = ACTIONS(9030),
    [sym_fixed_keyword] = ACTIONS(9030),
    [sym_grid_keyword] = ACTIONS(9030),
    [sym_part_keyword] = ACTIONS(9030),
    [sym_systempart_keyword] = ACTIONS(9030),
    [sym_usercontrol_keyword] = ACTIONS(9030),
    [sym_dataset_keyword] = ACTIONS(9030),
    [sym_elements_keyword] = ACTIONS(9030),
    [sym_dataitem_keyword] = ACTIONS(9030),
    [sym_column_keyword] = ACTIONS(9030),
    [sym_filter_keyword] = ACTIONS(9030),
    [sym_labels_keyword] = ACTIONS(9030),
    [sym_rendering_keyword] = ACTIONS(9030),
    [sym_requestpage_keyword] = ACTIONS(9030),
    [sym_schema_keyword] = ACTIONS(9030),
    [sym_views_keyword] = ACTIONS(9030),
    [sym_quoted_identifier] = ACTIONS(9032),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9032),
    [sym_preproc_open] = ACTIONS(9032),
    [sym_preproc_close] = ACTIONS(9032),
    [sym_var_attribute_open] = ACTIONS(9032),
  },
  [STATE(4030)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(9790),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4031)] = {
    [sym__body_element] = STATE(4044),
    [sym_empty_statement] = STATE(4044),
    [sym_property] = STATE(4044),
    [sym_permissions_property] = STATE(4044),
    [sym_table_relation_property] = STATE(4044),
    [sym_fields_section] = STATE(4044),
    [sym_keys_section] = STATE(4044),
    [sym_fieldgroups_section] = STATE(4044),
    [sym_enum_value_declaration] = STATE(4044),
    [sym_labels_section] = STATE(4044),
    [sym_layout_section] = STATE(4044),
    [sym_modify_modification] = STATE(4044),
    [sym_actions_section] = STATE(4044),
    [sym_views_section] = STATE(4044),
    [sym_dataset_section] = STATE(4044),
    [sym_requestpage_section] = STATE(4044),
    [sym_rendering_section] = STATE(4044),
    [sym_elements_section] = STATE(4044),
    [sym_query_dataitem] = STATE(4044),
    [sym__query_body_element] = STATE(4044),
    [sym_preproc_conditional_query] = STATE(4044),
    [sym_query_column] = STATE(4044),
    [sym_query_filter] = STATE(4044),
    [sym_schema_section] = STATE(4044),
    [sym_assembly_declaration] = STATE(4044),
    [sym_event_declaration] = STATE(4044),
    [sym_procedure] = STATE(4044),
    [sym_preproc_split_procedure] = STATE(4044),
    [sym_preproc_split_procedure_preamble] = STATE(4044),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4044),
    [sym_var_section] = STATE(4044),
    [sym_attribute_item] = STATE(4044),
    [sym_preproc_conditional] = STATE(4044),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(9790),
    [aux_sym_query_dataitem_repeat1] = STATE(4044),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4032)] = {
    [sym_identifier] = ACTIONS(9034),
    [anon_sym_SEMI] = ACTIONS(9036),
    [aux_sym_where_condition_token1] = ACTIONS(9034),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9034),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9034),
    [anon_sym_LBRACK] = ACTIONS(9036),
    [aux_sym_basic_type_token6] = ACTIONS(9034),
    [aux_sym_basic_type_token22] = ACTIONS(9034),
    [aux_sym_basic_type_token53] = ACTIONS(9034),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9034),
    [aux_sym_addafter_modification_token1] = ACTIONS(9034),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9034),
    [aux_sym_modify_modification_token1] = ACTIONS(9034),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9034),
    [aux_sym_movelast_modification_token1] = ACTIONS(9034),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9034),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9034),
    [aux_sym_separator_action_token1] = ACTIONS(9034),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9034),
    [aux_sym_type_declaration_token1] = ACTIONS(9034),
    [anon_sym_POUNDif] = ACTIONS(9036),
    [anon_sym_POUNDIF] = ACTIONS(9036),
    [anon_sym_POUNDIf] = ACTIONS(9036),
    [anon_sym_POUNDelif] = ACTIONS(9036),
    [anon_sym_POUNDELIF] = ACTIONS(9036),
    [anon_sym_POUNDElif] = ACTIONS(9036),
    [anon_sym_POUNDelse] = ACTIONS(9036),
    [anon_sym_POUNDELSE] = ACTIONS(9036),
    [anon_sym_POUNDElse] = ACTIONS(9036),
    [anon_sym_POUNDelse2] = ACTIONS(9036),
    [anon_sym_POUNDELSE2] = ACTIONS(9036),
    [anon_sym_POUNDElse2] = ACTIONS(9036),
    [anon_sym_POUNDendif] = ACTIONS(9036),
    [anon_sym_POUNDENDIF] = ACTIONS(9036),
    [anon_sym_POUNDEndif] = ACTIONS(9036),
    [anon_sym_POUNDendif2] = ACTIONS(9036),
    [anon_sym_POUNDENDIF2] = ACTIONS(9036),
    [anon_sym_POUNDEndif2] = ACTIONS(9036),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9034),
    [sym_procedure_keyword] = ACTIONS(9034),
    [sym_trigger_keyword] = ACTIONS(9034),
    [sym_var_keyword] = ACTIONS(9034),
    [sym_local_keyword] = ACTIONS(9034),
    [sym_internal_keyword] = ACTIONS(9034),
    [sym_protected_keyword] = ACTIONS(9034),
    [sym_event_keyword] = ACTIONS(9034),
    [sym_fields_keyword] = ACTIONS(9034),
    [sym_keys_keyword] = ACTIONS(9034),
    [sym_key_keyword] = ACTIONS(9034),
    [sym_fieldgroups_keyword] = ACTIONS(9034),
    [sym_actions_keyword] = ACTIONS(9034),
    [sym_layout_keyword] = ACTIONS(9034),
    [sym_area_keyword] = ACTIONS(9034),
    [sym_group_keyword] = ACTIONS(9034),
    [sym_repeater_keyword] = ACTIONS(9034),
    [sym_cuegroup_keyword] = ACTIONS(9034),
    [sym_fixed_keyword] = ACTIONS(9034),
    [sym_grid_keyword] = ACTIONS(9034),
    [sym_part_keyword] = ACTIONS(9034),
    [sym_systempart_keyword] = ACTIONS(9034),
    [sym_usercontrol_keyword] = ACTIONS(9034),
    [sym_dataset_keyword] = ACTIONS(9034),
    [sym_elements_keyword] = ACTIONS(9034),
    [sym_dataitem_keyword] = ACTIONS(9034),
    [sym_column_keyword] = ACTIONS(9034),
    [sym_filter_keyword] = ACTIONS(9034),
    [sym_labels_keyword] = ACTIONS(9034),
    [sym_rendering_keyword] = ACTIONS(9034),
    [sym_requestpage_keyword] = ACTIONS(9034),
    [sym_schema_keyword] = ACTIONS(9034),
    [sym_views_keyword] = ACTIONS(9034),
    [sym_quoted_identifier] = ACTIONS(9036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9036),
    [sym_preproc_open] = ACTIONS(9036),
    [sym_preproc_close] = ACTIONS(9036),
    [sym_var_attribute_open] = ACTIONS(9036),
  },
  [STATE(4033)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDelif] = ACTIONS(9038),
    [anon_sym_POUNDELIF] = ACTIONS(9038),
    [anon_sym_POUNDElif] = ACTIONS(9038),
    [anon_sym_POUNDelse] = ACTIONS(9038),
    [anon_sym_POUNDELSE] = ACTIONS(9038),
    [anon_sym_POUNDElse] = ACTIONS(9038),
    [anon_sym_POUNDelse2] = ACTIONS(9038),
    [anon_sym_POUNDELSE2] = ACTIONS(9038),
    [anon_sym_POUNDElse2] = ACTIONS(9038),
    [anon_sym_POUNDendif] = ACTIONS(9038),
    [anon_sym_POUNDENDIF] = ACTIONS(9038),
    [anon_sym_POUNDEndif] = ACTIONS(9038),
    [anon_sym_POUNDendif2] = ACTIONS(9038),
    [anon_sym_POUNDENDIF2] = ACTIONS(9038),
    [anon_sym_POUNDEndif2] = ACTIONS(9038),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(9038),
  },
  [STATE(4034)] = {
    [sym_identifier] = ACTIONS(9040),
    [anon_sym_SEMI] = ACTIONS(9042),
    [aux_sym_where_condition_token1] = ACTIONS(9040),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9040),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9040),
    [anon_sym_LBRACK] = ACTIONS(9042),
    [aux_sym_basic_type_token6] = ACTIONS(9040),
    [aux_sym_basic_type_token22] = ACTIONS(9040),
    [aux_sym_basic_type_token53] = ACTIONS(9040),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9040),
    [aux_sym_addafter_modification_token1] = ACTIONS(9040),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9040),
    [aux_sym_modify_modification_token1] = ACTIONS(9040),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9040),
    [aux_sym_movelast_modification_token1] = ACTIONS(9040),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9040),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9040),
    [aux_sym_separator_action_token1] = ACTIONS(9040),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9040),
    [aux_sym_type_declaration_token1] = ACTIONS(9040),
    [anon_sym_POUNDif] = ACTIONS(9042),
    [anon_sym_POUNDIF] = ACTIONS(9042),
    [anon_sym_POUNDIf] = ACTIONS(9042),
    [anon_sym_POUNDelif] = ACTIONS(9042),
    [anon_sym_POUNDELIF] = ACTIONS(9042),
    [anon_sym_POUNDElif] = ACTIONS(9042),
    [anon_sym_POUNDelse] = ACTIONS(9042),
    [anon_sym_POUNDELSE] = ACTIONS(9042),
    [anon_sym_POUNDElse] = ACTIONS(9042),
    [anon_sym_POUNDelse2] = ACTIONS(9042),
    [anon_sym_POUNDELSE2] = ACTIONS(9042),
    [anon_sym_POUNDElse2] = ACTIONS(9042),
    [anon_sym_POUNDendif] = ACTIONS(9042),
    [anon_sym_POUNDENDIF] = ACTIONS(9042),
    [anon_sym_POUNDEndif] = ACTIONS(9042),
    [anon_sym_POUNDendif2] = ACTIONS(9042),
    [anon_sym_POUNDENDIF2] = ACTIONS(9042),
    [anon_sym_POUNDEndif2] = ACTIONS(9042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9040),
    [sym_procedure_keyword] = ACTIONS(9040),
    [sym_trigger_keyword] = ACTIONS(9040),
    [sym_var_keyword] = ACTIONS(9040),
    [sym_local_keyword] = ACTIONS(9040),
    [sym_internal_keyword] = ACTIONS(9040),
    [sym_protected_keyword] = ACTIONS(9040),
    [sym_event_keyword] = ACTIONS(9040),
    [sym_fields_keyword] = ACTIONS(9040),
    [sym_keys_keyword] = ACTIONS(9040),
    [sym_key_keyword] = ACTIONS(9040),
    [sym_fieldgroups_keyword] = ACTIONS(9040),
    [sym_actions_keyword] = ACTIONS(9040),
    [sym_layout_keyword] = ACTIONS(9040),
    [sym_area_keyword] = ACTIONS(9040),
    [sym_group_keyword] = ACTIONS(9040),
    [sym_repeater_keyword] = ACTIONS(9040),
    [sym_cuegroup_keyword] = ACTIONS(9040),
    [sym_fixed_keyword] = ACTIONS(9040),
    [sym_grid_keyword] = ACTIONS(9040),
    [sym_part_keyword] = ACTIONS(9040),
    [sym_systempart_keyword] = ACTIONS(9040),
    [sym_usercontrol_keyword] = ACTIONS(9040),
    [sym_dataset_keyword] = ACTIONS(9040),
    [sym_elements_keyword] = ACTIONS(9040),
    [sym_dataitem_keyword] = ACTIONS(9040),
    [sym_column_keyword] = ACTIONS(9040),
    [sym_filter_keyword] = ACTIONS(9040),
    [sym_labels_keyword] = ACTIONS(9040),
    [sym_rendering_keyword] = ACTIONS(9040),
    [sym_requestpage_keyword] = ACTIONS(9040),
    [sym_schema_keyword] = ACTIONS(9040),
    [sym_views_keyword] = ACTIONS(9040),
    [sym_quoted_identifier] = ACTIONS(9042),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9042),
    [sym_preproc_open] = ACTIONS(9042),
    [sym_preproc_close] = ACTIONS(9042),
    [sym_var_attribute_open] = ACTIONS(9042),
  },
  [STATE(4035)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_xmlport_element_token1] = ACTIONS(5279),
    [aux_sym_xmlport_element_token2] = ACTIONS(5279),
    [aux_sym_xmlport_element_token3] = ACTIONS(5279),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5279),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
  },
  [STATE(4036)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [aux_sym_where_condition_token1] = ACTIONS(5935),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5935),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_basic_type_token6] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token53] = ACTIONS(5935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5935),
    [aux_sym_addafter_modification_token1] = ACTIONS(5935),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5935),
    [aux_sym_modify_modification_token1] = ACTIONS(5935),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5935),
    [aux_sym_movelast_modification_token1] = ACTIONS(5935),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5935),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5935),
    [aux_sym_separator_action_token1] = ACTIONS(5935),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5935),
    [aux_sym_type_declaration_token1] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5935),
    [sym_procedure_keyword] = ACTIONS(5935),
    [sym_trigger_keyword] = ACTIONS(5935),
    [sym_var_keyword] = ACTIONS(5935),
    [sym_local_keyword] = ACTIONS(5935),
    [sym_internal_keyword] = ACTIONS(5935),
    [sym_protected_keyword] = ACTIONS(5935),
    [sym_event_keyword] = ACTIONS(5935),
    [sym_fields_keyword] = ACTIONS(5935),
    [sym_keys_keyword] = ACTIONS(5935),
    [sym_key_keyword] = ACTIONS(5935),
    [sym_fieldgroups_keyword] = ACTIONS(5935),
    [sym_actions_keyword] = ACTIONS(5935),
    [sym_layout_keyword] = ACTIONS(5935),
    [sym_area_keyword] = ACTIONS(5935),
    [sym_group_keyword] = ACTIONS(5935),
    [sym_repeater_keyword] = ACTIONS(5935),
    [sym_cuegroup_keyword] = ACTIONS(5935),
    [sym_fixed_keyword] = ACTIONS(5935),
    [sym_grid_keyword] = ACTIONS(5935),
    [sym_part_keyword] = ACTIONS(5935),
    [sym_systempart_keyword] = ACTIONS(5935),
    [sym_usercontrol_keyword] = ACTIONS(5935),
    [sym_dataset_keyword] = ACTIONS(5935),
    [sym_elements_keyword] = ACTIONS(5935),
    [sym_dataitem_keyword] = ACTIONS(5935),
    [sym_column_keyword] = ACTIONS(5935),
    [sym_filter_keyword] = ACTIONS(5935),
    [sym_labels_keyword] = ACTIONS(5935),
    [sym_rendering_keyword] = ACTIONS(5935),
    [sym_requestpage_keyword] = ACTIONS(5935),
    [sym_schema_keyword] = ACTIONS(5935),
    [sym_views_keyword] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
    [sym_var_attribute_open] = ACTIONS(5937),
  },
  [STATE(4037)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [aux_sym_where_condition_token1] = ACTIONS(5935),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5935),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_basic_type_token6] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token53] = ACTIONS(5935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5935),
    [aux_sym_addafter_modification_token1] = ACTIONS(5935),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5935),
    [aux_sym_modify_modification_token1] = ACTIONS(5935),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5935),
    [aux_sym_movelast_modification_token1] = ACTIONS(5935),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5935),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5935),
    [aux_sym_separator_action_token1] = ACTIONS(5935),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5935),
    [aux_sym_type_declaration_token1] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5935),
    [sym_procedure_keyword] = ACTIONS(5935),
    [sym_trigger_keyword] = ACTIONS(5935),
    [sym_var_keyword] = ACTIONS(5935),
    [sym_local_keyword] = ACTIONS(5935),
    [sym_internal_keyword] = ACTIONS(5935),
    [sym_protected_keyword] = ACTIONS(5935),
    [sym_event_keyword] = ACTIONS(5935),
    [sym_fields_keyword] = ACTIONS(5935),
    [sym_keys_keyword] = ACTIONS(5935),
    [sym_key_keyword] = ACTIONS(5935),
    [sym_fieldgroups_keyword] = ACTIONS(5935),
    [sym_actions_keyword] = ACTIONS(5935),
    [sym_layout_keyword] = ACTIONS(5935),
    [sym_area_keyword] = ACTIONS(5935),
    [sym_group_keyword] = ACTIONS(5935),
    [sym_repeater_keyword] = ACTIONS(5935),
    [sym_cuegroup_keyword] = ACTIONS(5935),
    [sym_fixed_keyword] = ACTIONS(5935),
    [sym_grid_keyword] = ACTIONS(5935),
    [sym_part_keyword] = ACTIONS(5935),
    [sym_systempart_keyword] = ACTIONS(5935),
    [sym_usercontrol_keyword] = ACTIONS(5935),
    [sym_dataset_keyword] = ACTIONS(5935),
    [sym_elements_keyword] = ACTIONS(5935),
    [sym_dataitem_keyword] = ACTIONS(5935),
    [sym_column_keyword] = ACTIONS(5935),
    [sym_filter_keyword] = ACTIONS(5935),
    [sym_labels_keyword] = ACTIONS(5935),
    [sym_rendering_keyword] = ACTIONS(5935),
    [sym_requestpage_keyword] = ACTIONS(5935),
    [sym_schema_keyword] = ACTIONS(5935),
    [sym_views_keyword] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
    [sym_var_attribute_open] = ACTIONS(5937),
  },
  [STATE(4038)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9044),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_addafter_modification_token1] = ACTIONS(9044),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9044),
    [aux_sym_movelast_modification_token1] = ACTIONS(9044),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9044),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_area_keyword] = ACTIONS(9044),
    [sym_group_keyword] = ACTIONS(9044),
    [sym_repeater_keyword] = ACTIONS(9044),
    [sym_cuegroup_keyword] = ACTIONS(9044),
    [sym_fixed_keyword] = ACTIONS(9044),
    [sym_grid_keyword] = ACTIONS(9044),
    [sym_part_keyword] = ACTIONS(9044),
    [sym_systempart_keyword] = ACTIONS(9044),
    [sym_usercontrol_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_dataitem_keyword] = ACTIONS(9044),
    [sym_column_keyword] = ACTIONS(9044),
    [sym_filter_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(4039)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9044),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_addafter_modification_token1] = ACTIONS(9044),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9044),
    [aux_sym_movelast_modification_token1] = ACTIONS(9044),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9044),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_area_keyword] = ACTIONS(9044),
    [sym_group_keyword] = ACTIONS(9044),
    [sym_repeater_keyword] = ACTIONS(9044),
    [sym_cuegroup_keyword] = ACTIONS(9044),
    [sym_fixed_keyword] = ACTIONS(9044),
    [sym_grid_keyword] = ACTIONS(9044),
    [sym_part_keyword] = ACTIONS(9044),
    [sym_systempart_keyword] = ACTIONS(9044),
    [sym_usercontrol_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_dataitem_keyword] = ACTIONS(9044),
    [sym_column_keyword] = ACTIONS(9044),
    [sym_filter_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(4040)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9044),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_addafter_modification_token1] = ACTIONS(9044),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9044),
    [aux_sym_movelast_modification_token1] = ACTIONS(9044),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9044),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_area_keyword] = ACTIONS(9044),
    [sym_group_keyword] = ACTIONS(9044),
    [sym_repeater_keyword] = ACTIONS(9044),
    [sym_cuegroup_keyword] = ACTIONS(9044),
    [sym_fixed_keyword] = ACTIONS(9044),
    [sym_grid_keyword] = ACTIONS(9044),
    [sym_part_keyword] = ACTIONS(9044),
    [sym_systempart_keyword] = ACTIONS(9044),
    [sym_usercontrol_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_dataitem_keyword] = ACTIONS(9044),
    [sym_column_keyword] = ACTIONS(9044),
    [sym_filter_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(4041)] = {
    [sym_identifier] = ACTIONS(9048),
    [anon_sym_SEMI] = ACTIONS(9050),
    [aux_sym_where_condition_token1] = ACTIONS(9048),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9048),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9048),
    [anon_sym_LBRACK] = ACTIONS(9050),
    [aux_sym_basic_type_token6] = ACTIONS(9048),
    [aux_sym_basic_type_token22] = ACTIONS(9048),
    [aux_sym_basic_type_token53] = ACTIONS(9048),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9048),
    [aux_sym_addafter_modification_token1] = ACTIONS(9048),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9048),
    [aux_sym_modify_modification_token1] = ACTIONS(9048),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9048),
    [aux_sym_movelast_modification_token1] = ACTIONS(9048),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9048),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9048),
    [aux_sym_separator_action_token1] = ACTIONS(9048),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9048),
    [aux_sym_type_declaration_token1] = ACTIONS(9048),
    [anon_sym_POUNDif] = ACTIONS(9050),
    [anon_sym_POUNDIF] = ACTIONS(9050),
    [anon_sym_POUNDIf] = ACTIONS(9050),
    [anon_sym_POUNDelif] = ACTIONS(9050),
    [anon_sym_POUNDELIF] = ACTIONS(9050),
    [anon_sym_POUNDElif] = ACTIONS(9050),
    [anon_sym_POUNDelse] = ACTIONS(9050),
    [anon_sym_POUNDELSE] = ACTIONS(9050),
    [anon_sym_POUNDElse] = ACTIONS(9050),
    [anon_sym_POUNDelse2] = ACTIONS(9050),
    [anon_sym_POUNDELSE2] = ACTIONS(9050),
    [anon_sym_POUNDElse2] = ACTIONS(9050),
    [anon_sym_POUNDendif] = ACTIONS(9050),
    [anon_sym_POUNDENDIF] = ACTIONS(9050),
    [anon_sym_POUNDEndif] = ACTIONS(9050),
    [anon_sym_POUNDendif2] = ACTIONS(9050),
    [anon_sym_POUNDENDIF2] = ACTIONS(9050),
    [anon_sym_POUNDEndif2] = ACTIONS(9050),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9048),
    [sym_procedure_keyword] = ACTIONS(9048),
    [sym_trigger_keyword] = ACTIONS(9048),
    [sym_var_keyword] = ACTIONS(9048),
    [sym_local_keyword] = ACTIONS(9048),
    [sym_internal_keyword] = ACTIONS(9048),
    [sym_protected_keyword] = ACTIONS(9048),
    [sym_event_keyword] = ACTIONS(9048),
    [sym_fields_keyword] = ACTIONS(9048),
    [sym_keys_keyword] = ACTIONS(9048),
    [sym_key_keyword] = ACTIONS(9048),
    [sym_fieldgroups_keyword] = ACTIONS(9048),
    [sym_actions_keyword] = ACTIONS(9048),
    [sym_layout_keyword] = ACTIONS(9048),
    [sym_area_keyword] = ACTIONS(9048),
    [sym_group_keyword] = ACTIONS(9048),
    [sym_repeater_keyword] = ACTIONS(9048),
    [sym_cuegroup_keyword] = ACTIONS(9048),
    [sym_fixed_keyword] = ACTIONS(9048),
    [sym_grid_keyword] = ACTIONS(9048),
    [sym_part_keyword] = ACTIONS(9048),
    [sym_systempart_keyword] = ACTIONS(9048),
    [sym_usercontrol_keyword] = ACTIONS(9048),
    [sym_dataset_keyword] = ACTIONS(9048),
    [sym_elements_keyword] = ACTIONS(9048),
    [sym_dataitem_keyword] = ACTIONS(9048),
    [sym_column_keyword] = ACTIONS(9048),
    [sym_filter_keyword] = ACTIONS(9048),
    [sym_labels_keyword] = ACTIONS(9048),
    [sym_rendering_keyword] = ACTIONS(9048),
    [sym_requestpage_keyword] = ACTIONS(9048),
    [sym_schema_keyword] = ACTIONS(9048),
    [sym_views_keyword] = ACTIONS(9048),
    [sym_quoted_identifier] = ACTIONS(9050),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9050),
    [sym_preproc_open] = ACTIONS(9050),
    [sym_preproc_close] = ACTIONS(9050),
    [sym_var_attribute_open] = ACTIONS(9050),
  },
  [STATE(4042)] = {
    [sym_identifier] = ACTIONS(9052),
    [anon_sym_SEMI] = ACTIONS(9054),
    [aux_sym_where_condition_token1] = ACTIONS(9052),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9052),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9052),
    [anon_sym_LBRACK] = ACTIONS(9054),
    [aux_sym_basic_type_token6] = ACTIONS(9052),
    [aux_sym_basic_type_token22] = ACTIONS(9052),
    [aux_sym_basic_type_token53] = ACTIONS(9052),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9052),
    [aux_sym_addafter_modification_token1] = ACTIONS(9052),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9052),
    [aux_sym_modify_modification_token1] = ACTIONS(9052),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9052),
    [aux_sym_movelast_modification_token1] = ACTIONS(9052),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9052),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9052),
    [aux_sym_separator_action_token1] = ACTIONS(9052),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9052),
    [aux_sym_type_declaration_token1] = ACTIONS(9052),
    [anon_sym_POUNDif] = ACTIONS(9054),
    [anon_sym_POUNDIF] = ACTIONS(9054),
    [anon_sym_POUNDIf] = ACTIONS(9054),
    [anon_sym_POUNDelif] = ACTIONS(9054),
    [anon_sym_POUNDELIF] = ACTIONS(9054),
    [anon_sym_POUNDElif] = ACTIONS(9054),
    [anon_sym_POUNDelse] = ACTIONS(9054),
    [anon_sym_POUNDELSE] = ACTIONS(9054),
    [anon_sym_POUNDElse] = ACTIONS(9054),
    [anon_sym_POUNDelse2] = ACTIONS(9054),
    [anon_sym_POUNDELSE2] = ACTIONS(9054),
    [anon_sym_POUNDElse2] = ACTIONS(9054),
    [anon_sym_POUNDendif] = ACTIONS(9054),
    [anon_sym_POUNDENDIF] = ACTIONS(9054),
    [anon_sym_POUNDEndif] = ACTIONS(9054),
    [anon_sym_POUNDendif2] = ACTIONS(9054),
    [anon_sym_POUNDENDIF2] = ACTIONS(9054),
    [anon_sym_POUNDEndif2] = ACTIONS(9054),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9052),
    [sym_procedure_keyword] = ACTIONS(9052),
    [sym_trigger_keyword] = ACTIONS(9052),
    [sym_var_keyword] = ACTIONS(9052),
    [sym_local_keyword] = ACTIONS(9052),
    [sym_internal_keyword] = ACTIONS(9052),
    [sym_protected_keyword] = ACTIONS(9052),
    [sym_event_keyword] = ACTIONS(9052),
    [sym_fields_keyword] = ACTIONS(9052),
    [sym_keys_keyword] = ACTIONS(9052),
    [sym_key_keyword] = ACTIONS(9052),
    [sym_fieldgroups_keyword] = ACTIONS(9052),
    [sym_actions_keyword] = ACTIONS(9052),
    [sym_layout_keyword] = ACTIONS(9052),
    [sym_area_keyword] = ACTIONS(9052),
    [sym_group_keyword] = ACTIONS(9052),
    [sym_repeater_keyword] = ACTIONS(9052),
    [sym_cuegroup_keyword] = ACTIONS(9052),
    [sym_fixed_keyword] = ACTIONS(9052),
    [sym_grid_keyword] = ACTIONS(9052),
    [sym_part_keyword] = ACTIONS(9052),
    [sym_systempart_keyword] = ACTIONS(9052),
    [sym_usercontrol_keyword] = ACTIONS(9052),
    [sym_dataset_keyword] = ACTIONS(9052),
    [sym_elements_keyword] = ACTIONS(9052),
    [sym_dataitem_keyword] = ACTIONS(9052),
    [sym_column_keyword] = ACTIONS(9052),
    [sym_filter_keyword] = ACTIONS(9052),
    [sym_labels_keyword] = ACTIONS(9052),
    [sym_rendering_keyword] = ACTIONS(9052),
    [sym_requestpage_keyword] = ACTIONS(9052),
    [sym_schema_keyword] = ACTIONS(9052),
    [sym_views_keyword] = ACTIONS(9052),
    [sym_quoted_identifier] = ACTIONS(9054),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9054),
    [sym_preproc_open] = ACTIONS(9054),
    [sym_preproc_close] = ACTIONS(9054),
    [sym_var_attribute_open] = ACTIONS(9054),
  },
  [STATE(4043)] = {
    [sym_identifier] = ACTIONS(9052),
    [anon_sym_SEMI] = ACTIONS(9054),
    [aux_sym_where_condition_token1] = ACTIONS(9052),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9052),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9052),
    [anon_sym_LBRACK] = ACTIONS(9054),
    [aux_sym_basic_type_token6] = ACTIONS(9052),
    [aux_sym_basic_type_token22] = ACTIONS(9052),
    [aux_sym_basic_type_token53] = ACTIONS(9052),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9052),
    [aux_sym_addafter_modification_token1] = ACTIONS(9052),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9052),
    [aux_sym_modify_modification_token1] = ACTIONS(9052),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9052),
    [aux_sym_movelast_modification_token1] = ACTIONS(9052),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9052),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9052),
    [aux_sym_separator_action_token1] = ACTIONS(9052),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9052),
    [aux_sym_type_declaration_token1] = ACTIONS(9052),
    [anon_sym_POUNDif] = ACTIONS(9054),
    [anon_sym_POUNDIF] = ACTIONS(9054),
    [anon_sym_POUNDIf] = ACTIONS(9054),
    [anon_sym_POUNDelif] = ACTIONS(9054),
    [anon_sym_POUNDELIF] = ACTIONS(9054),
    [anon_sym_POUNDElif] = ACTIONS(9054),
    [anon_sym_POUNDelse] = ACTIONS(9054),
    [anon_sym_POUNDELSE] = ACTIONS(9054),
    [anon_sym_POUNDElse] = ACTIONS(9054),
    [anon_sym_POUNDelse2] = ACTIONS(9054),
    [anon_sym_POUNDELSE2] = ACTIONS(9054),
    [anon_sym_POUNDElse2] = ACTIONS(9054),
    [anon_sym_POUNDendif] = ACTIONS(9054),
    [anon_sym_POUNDENDIF] = ACTIONS(9054),
    [anon_sym_POUNDEndif] = ACTIONS(9054),
    [anon_sym_POUNDendif2] = ACTIONS(9054),
    [anon_sym_POUNDENDIF2] = ACTIONS(9054),
    [anon_sym_POUNDEndif2] = ACTIONS(9054),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9052),
    [sym_procedure_keyword] = ACTIONS(9052),
    [sym_trigger_keyword] = ACTIONS(9052),
    [sym_var_keyword] = ACTIONS(9052),
    [sym_local_keyword] = ACTIONS(9052),
    [sym_internal_keyword] = ACTIONS(9052),
    [sym_protected_keyword] = ACTIONS(9052),
    [sym_event_keyword] = ACTIONS(9052),
    [sym_fields_keyword] = ACTIONS(9052),
    [sym_keys_keyword] = ACTIONS(9052),
    [sym_key_keyword] = ACTIONS(9052),
    [sym_fieldgroups_keyword] = ACTIONS(9052),
    [sym_actions_keyword] = ACTIONS(9052),
    [sym_layout_keyword] = ACTIONS(9052),
    [sym_area_keyword] = ACTIONS(9052),
    [sym_group_keyword] = ACTIONS(9052),
    [sym_repeater_keyword] = ACTIONS(9052),
    [sym_cuegroup_keyword] = ACTIONS(9052),
    [sym_fixed_keyword] = ACTIONS(9052),
    [sym_grid_keyword] = ACTIONS(9052),
    [sym_part_keyword] = ACTIONS(9052),
    [sym_systempart_keyword] = ACTIONS(9052),
    [sym_usercontrol_keyword] = ACTIONS(9052),
    [sym_dataset_keyword] = ACTIONS(9052),
    [sym_elements_keyword] = ACTIONS(9052),
    [sym_dataitem_keyword] = ACTIONS(9052),
    [sym_column_keyword] = ACTIONS(9052),
    [sym_filter_keyword] = ACTIONS(9052),
    [sym_labels_keyword] = ACTIONS(9052),
    [sym_rendering_keyword] = ACTIONS(9052),
    [sym_requestpage_keyword] = ACTIONS(9052),
    [sym_schema_keyword] = ACTIONS(9052),
    [sym_views_keyword] = ACTIONS(9052),
    [sym_quoted_identifier] = ACTIONS(9054),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9054),
    [sym_preproc_open] = ACTIONS(9054),
    [sym_preproc_close] = ACTIONS(9054),
    [sym_var_attribute_open] = ACTIONS(9054),
  },
  [STATE(4044)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(9833),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4045)] = {
    [sym__body_element] = STATE(4000),
    [sym_empty_statement] = STATE(4000),
    [sym_property] = STATE(4000),
    [sym_permissions_property] = STATE(4000),
    [sym_table_relation_property] = STATE(4000),
    [sym_fields_section] = STATE(4000),
    [sym_keys_section] = STATE(4000),
    [sym_fieldgroups_section] = STATE(4000),
    [sym_enum_value_declaration] = STATE(4000),
    [sym_labels_section] = STATE(4000),
    [sym_layout_section] = STATE(4000),
    [sym_modify_modification] = STATE(4000),
    [sym_actions_section] = STATE(4000),
    [sym_views_section] = STATE(4000),
    [sym_dataset_section] = STATE(4000),
    [sym_requestpage_section] = STATE(4000),
    [sym_rendering_section] = STATE(4000),
    [sym_elements_section] = STATE(4000),
    [sym_query_dataitem] = STATE(4000),
    [sym__query_body_element] = STATE(4000),
    [sym_preproc_conditional_query] = STATE(4000),
    [sym_query_column] = STATE(4000),
    [sym_query_filter] = STATE(4000),
    [sym_schema_section] = STATE(4000),
    [sym_assembly_declaration] = STATE(4000),
    [sym_event_declaration] = STATE(4000),
    [sym_procedure] = STATE(4000),
    [sym_preproc_split_procedure] = STATE(4000),
    [sym_preproc_split_procedure_preamble] = STATE(4000),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4000),
    [sym_var_section] = STATE(4000),
    [sym_attribute_item] = STATE(4000),
    [sym_preproc_conditional] = STATE(4000),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(9833),
    [aux_sym_query_dataitem_repeat1] = STATE(4000),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4046)] = {
    [sym_identifier] = ACTIONS(9056),
    [anon_sym_SEMI] = ACTIONS(9058),
    [aux_sym_where_condition_token1] = ACTIONS(9056),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9056),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9056),
    [anon_sym_LBRACK] = ACTIONS(9058),
    [aux_sym_basic_type_token6] = ACTIONS(9056),
    [aux_sym_basic_type_token22] = ACTIONS(9056),
    [aux_sym_basic_type_token53] = ACTIONS(9056),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9056),
    [aux_sym_addafter_modification_token1] = ACTIONS(9056),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9056),
    [aux_sym_modify_modification_token1] = ACTIONS(9056),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9056),
    [aux_sym_movelast_modification_token1] = ACTIONS(9056),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9056),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9056),
    [aux_sym_separator_action_token1] = ACTIONS(9056),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9056),
    [aux_sym_type_declaration_token1] = ACTIONS(9056),
    [anon_sym_POUNDif] = ACTIONS(9058),
    [anon_sym_POUNDIF] = ACTIONS(9058),
    [anon_sym_POUNDIf] = ACTIONS(9058),
    [anon_sym_POUNDelif] = ACTIONS(9058),
    [anon_sym_POUNDELIF] = ACTIONS(9058),
    [anon_sym_POUNDElif] = ACTIONS(9058),
    [anon_sym_POUNDelse] = ACTIONS(9058),
    [anon_sym_POUNDELSE] = ACTIONS(9058),
    [anon_sym_POUNDElse] = ACTIONS(9058),
    [anon_sym_POUNDelse2] = ACTIONS(9058),
    [anon_sym_POUNDELSE2] = ACTIONS(9058),
    [anon_sym_POUNDElse2] = ACTIONS(9058),
    [anon_sym_POUNDendif] = ACTIONS(9058),
    [anon_sym_POUNDENDIF] = ACTIONS(9058),
    [anon_sym_POUNDEndif] = ACTIONS(9058),
    [anon_sym_POUNDendif2] = ACTIONS(9058),
    [anon_sym_POUNDENDIF2] = ACTIONS(9058),
    [anon_sym_POUNDEndif2] = ACTIONS(9058),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9056),
    [sym_procedure_keyword] = ACTIONS(9056),
    [sym_trigger_keyword] = ACTIONS(9056),
    [sym_var_keyword] = ACTIONS(9056),
    [sym_local_keyword] = ACTIONS(9056),
    [sym_internal_keyword] = ACTIONS(9056),
    [sym_protected_keyword] = ACTIONS(9056),
    [sym_event_keyword] = ACTIONS(9056),
    [sym_fields_keyword] = ACTIONS(9056),
    [sym_keys_keyword] = ACTIONS(9056),
    [sym_key_keyword] = ACTIONS(9056),
    [sym_fieldgroups_keyword] = ACTIONS(9056),
    [sym_actions_keyword] = ACTIONS(9056),
    [sym_layout_keyword] = ACTIONS(9056),
    [sym_area_keyword] = ACTIONS(9056),
    [sym_group_keyword] = ACTIONS(9056),
    [sym_repeater_keyword] = ACTIONS(9056),
    [sym_cuegroup_keyword] = ACTIONS(9056),
    [sym_fixed_keyword] = ACTIONS(9056),
    [sym_grid_keyword] = ACTIONS(9056),
    [sym_part_keyword] = ACTIONS(9056),
    [sym_systempart_keyword] = ACTIONS(9056),
    [sym_usercontrol_keyword] = ACTIONS(9056),
    [sym_dataset_keyword] = ACTIONS(9056),
    [sym_elements_keyword] = ACTIONS(9056),
    [sym_dataitem_keyword] = ACTIONS(9056),
    [sym_column_keyword] = ACTIONS(9056),
    [sym_filter_keyword] = ACTIONS(9056),
    [sym_labels_keyword] = ACTIONS(9056),
    [sym_rendering_keyword] = ACTIONS(9056),
    [sym_requestpage_keyword] = ACTIONS(9056),
    [sym_schema_keyword] = ACTIONS(9056),
    [sym_views_keyword] = ACTIONS(9056),
    [sym_quoted_identifier] = ACTIONS(9058),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9058),
    [sym_preproc_open] = ACTIONS(9058),
    [sym_preproc_close] = ACTIONS(9058),
    [sym_var_attribute_open] = ACTIONS(9058),
  },
  [STATE(4047)] = {
    [sym_identifier] = ACTIONS(9060),
    [anon_sym_SEMI] = ACTIONS(9062),
    [aux_sym_where_condition_token1] = ACTIONS(9060),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9060),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9060),
    [anon_sym_LBRACK] = ACTIONS(9062),
    [aux_sym_basic_type_token6] = ACTIONS(9060),
    [aux_sym_basic_type_token22] = ACTIONS(9060),
    [aux_sym_basic_type_token53] = ACTIONS(9060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9060),
    [aux_sym_addafter_modification_token1] = ACTIONS(9060),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9060),
    [aux_sym_modify_modification_token1] = ACTIONS(9060),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9060),
    [aux_sym_movelast_modification_token1] = ACTIONS(9060),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9060),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9060),
    [aux_sym_separator_action_token1] = ACTIONS(9060),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9060),
    [aux_sym_type_declaration_token1] = ACTIONS(9060),
    [anon_sym_POUNDif] = ACTIONS(9062),
    [anon_sym_POUNDIF] = ACTIONS(9062),
    [anon_sym_POUNDIf] = ACTIONS(9062),
    [anon_sym_POUNDelif] = ACTIONS(9062),
    [anon_sym_POUNDELIF] = ACTIONS(9062),
    [anon_sym_POUNDElif] = ACTIONS(9062),
    [anon_sym_POUNDelse] = ACTIONS(9062),
    [anon_sym_POUNDELSE] = ACTIONS(9062),
    [anon_sym_POUNDElse] = ACTIONS(9062),
    [anon_sym_POUNDelse2] = ACTIONS(9062),
    [anon_sym_POUNDELSE2] = ACTIONS(9062),
    [anon_sym_POUNDElse2] = ACTIONS(9062),
    [anon_sym_POUNDendif] = ACTIONS(9062),
    [anon_sym_POUNDENDIF] = ACTIONS(9062),
    [anon_sym_POUNDEndif] = ACTIONS(9062),
    [anon_sym_POUNDendif2] = ACTIONS(9062),
    [anon_sym_POUNDENDIF2] = ACTIONS(9062),
    [anon_sym_POUNDEndif2] = ACTIONS(9062),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9060),
    [sym_procedure_keyword] = ACTIONS(9060),
    [sym_trigger_keyword] = ACTIONS(9060),
    [sym_var_keyword] = ACTIONS(9060),
    [sym_local_keyword] = ACTIONS(9060),
    [sym_internal_keyword] = ACTIONS(9060),
    [sym_protected_keyword] = ACTIONS(9060),
    [sym_event_keyword] = ACTIONS(9060),
    [sym_fields_keyword] = ACTIONS(9060),
    [sym_keys_keyword] = ACTIONS(9060),
    [sym_key_keyword] = ACTIONS(9060),
    [sym_fieldgroups_keyword] = ACTIONS(9060),
    [sym_actions_keyword] = ACTIONS(9060),
    [sym_layout_keyword] = ACTIONS(9060),
    [sym_area_keyword] = ACTIONS(9060),
    [sym_group_keyword] = ACTIONS(9060),
    [sym_repeater_keyword] = ACTIONS(9060),
    [sym_cuegroup_keyword] = ACTIONS(9060),
    [sym_fixed_keyword] = ACTIONS(9060),
    [sym_grid_keyword] = ACTIONS(9060),
    [sym_part_keyword] = ACTIONS(9060),
    [sym_systempart_keyword] = ACTIONS(9060),
    [sym_usercontrol_keyword] = ACTIONS(9060),
    [sym_dataset_keyword] = ACTIONS(9060),
    [sym_elements_keyword] = ACTIONS(9060),
    [sym_dataitem_keyword] = ACTIONS(9060),
    [sym_column_keyword] = ACTIONS(9060),
    [sym_filter_keyword] = ACTIONS(9060),
    [sym_labels_keyword] = ACTIONS(9060),
    [sym_rendering_keyword] = ACTIONS(9060),
    [sym_requestpage_keyword] = ACTIONS(9060),
    [sym_schema_keyword] = ACTIONS(9060),
    [sym_views_keyword] = ACTIONS(9060),
    [sym_quoted_identifier] = ACTIONS(9062),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9062),
    [sym_preproc_open] = ACTIONS(9062),
    [sym_preproc_close] = ACTIONS(9062),
    [sym_var_attribute_open] = ACTIONS(9062),
  },
  [STATE(4048)] = {
    [sym_identifier] = ACTIONS(9064),
    [anon_sym_SEMI] = ACTIONS(9066),
    [aux_sym_where_condition_token1] = ACTIONS(9064),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9064),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9064),
    [anon_sym_LBRACK] = ACTIONS(9066),
    [aux_sym_basic_type_token6] = ACTIONS(9064),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token53] = ACTIONS(9064),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9064),
    [aux_sym_addafter_modification_token1] = ACTIONS(9064),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9064),
    [aux_sym_modify_modification_token1] = ACTIONS(9064),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9064),
    [aux_sym_movelast_modification_token1] = ACTIONS(9064),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9064),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9064),
    [aux_sym_separator_action_token1] = ACTIONS(9064),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9064),
    [aux_sym_type_declaration_token1] = ACTIONS(9064),
    [anon_sym_POUNDif] = ACTIONS(9066),
    [anon_sym_POUNDIF] = ACTIONS(9066),
    [anon_sym_POUNDIf] = ACTIONS(9066),
    [anon_sym_POUNDelif] = ACTIONS(9066),
    [anon_sym_POUNDELIF] = ACTIONS(9066),
    [anon_sym_POUNDElif] = ACTIONS(9066),
    [anon_sym_POUNDelse] = ACTIONS(9066),
    [anon_sym_POUNDELSE] = ACTIONS(9066),
    [anon_sym_POUNDElse] = ACTIONS(9066),
    [anon_sym_POUNDelse2] = ACTIONS(9066),
    [anon_sym_POUNDELSE2] = ACTIONS(9066),
    [anon_sym_POUNDElse2] = ACTIONS(9066),
    [anon_sym_POUNDendif] = ACTIONS(9066),
    [anon_sym_POUNDENDIF] = ACTIONS(9066),
    [anon_sym_POUNDEndif] = ACTIONS(9066),
    [anon_sym_POUNDendif2] = ACTIONS(9066),
    [anon_sym_POUNDENDIF2] = ACTIONS(9066),
    [anon_sym_POUNDEndif2] = ACTIONS(9066),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9064),
    [sym_procedure_keyword] = ACTIONS(9064),
    [sym_trigger_keyword] = ACTIONS(9064),
    [sym_var_keyword] = ACTIONS(9064),
    [sym_local_keyword] = ACTIONS(9064),
    [sym_internal_keyword] = ACTIONS(9064),
    [sym_protected_keyword] = ACTIONS(9064),
    [sym_event_keyword] = ACTIONS(9064),
    [sym_fields_keyword] = ACTIONS(9064),
    [sym_keys_keyword] = ACTIONS(9064),
    [sym_key_keyword] = ACTIONS(9064),
    [sym_fieldgroups_keyword] = ACTIONS(9064),
    [sym_actions_keyword] = ACTIONS(9064),
    [sym_layout_keyword] = ACTIONS(9064),
    [sym_area_keyword] = ACTIONS(9064),
    [sym_group_keyword] = ACTIONS(9064),
    [sym_repeater_keyword] = ACTIONS(9064),
    [sym_cuegroup_keyword] = ACTIONS(9064),
    [sym_fixed_keyword] = ACTIONS(9064),
    [sym_grid_keyword] = ACTIONS(9064),
    [sym_part_keyword] = ACTIONS(9064),
    [sym_systempart_keyword] = ACTIONS(9064),
    [sym_usercontrol_keyword] = ACTIONS(9064),
    [sym_dataset_keyword] = ACTIONS(9064),
    [sym_elements_keyword] = ACTIONS(9064),
    [sym_dataitem_keyword] = ACTIONS(9064),
    [sym_column_keyword] = ACTIONS(9064),
    [sym_filter_keyword] = ACTIONS(9064),
    [sym_labels_keyword] = ACTIONS(9064),
    [sym_rendering_keyword] = ACTIONS(9064),
    [sym_requestpage_keyword] = ACTIONS(9064),
    [sym_schema_keyword] = ACTIONS(9064),
    [sym_views_keyword] = ACTIONS(9064),
    [sym_quoted_identifier] = ACTIONS(9066),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9066),
    [sym_preproc_open] = ACTIONS(9066),
    [sym_preproc_close] = ACTIONS(9066),
    [sym_var_attribute_open] = ACTIONS(9066),
  },
  [STATE(4049)] = {
    [sym_identifier] = ACTIONS(9064),
    [anon_sym_SEMI] = ACTIONS(9066),
    [aux_sym_where_condition_token1] = ACTIONS(9064),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9064),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9064),
    [anon_sym_LBRACK] = ACTIONS(9066),
    [aux_sym_basic_type_token6] = ACTIONS(9064),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token53] = ACTIONS(9064),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9064),
    [aux_sym_addafter_modification_token1] = ACTIONS(9064),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9064),
    [aux_sym_modify_modification_token1] = ACTIONS(9064),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9064),
    [aux_sym_movelast_modification_token1] = ACTIONS(9064),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9064),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9064),
    [aux_sym_separator_action_token1] = ACTIONS(9064),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9064),
    [aux_sym_type_declaration_token1] = ACTIONS(9064),
    [anon_sym_POUNDif] = ACTIONS(9066),
    [anon_sym_POUNDIF] = ACTIONS(9066),
    [anon_sym_POUNDIf] = ACTIONS(9066),
    [anon_sym_POUNDelif] = ACTIONS(9066),
    [anon_sym_POUNDELIF] = ACTIONS(9066),
    [anon_sym_POUNDElif] = ACTIONS(9066),
    [anon_sym_POUNDelse] = ACTIONS(9066),
    [anon_sym_POUNDELSE] = ACTIONS(9066),
    [anon_sym_POUNDElse] = ACTIONS(9066),
    [anon_sym_POUNDelse2] = ACTIONS(9066),
    [anon_sym_POUNDELSE2] = ACTIONS(9066),
    [anon_sym_POUNDElse2] = ACTIONS(9066),
    [anon_sym_POUNDendif] = ACTIONS(9066),
    [anon_sym_POUNDENDIF] = ACTIONS(9066),
    [anon_sym_POUNDEndif] = ACTIONS(9066),
    [anon_sym_POUNDendif2] = ACTIONS(9066),
    [anon_sym_POUNDENDIF2] = ACTIONS(9066),
    [anon_sym_POUNDEndif2] = ACTIONS(9066),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9064),
    [sym_procedure_keyword] = ACTIONS(9064),
    [sym_trigger_keyword] = ACTIONS(9064),
    [sym_var_keyword] = ACTIONS(9064),
    [sym_local_keyword] = ACTIONS(9064),
    [sym_internal_keyword] = ACTIONS(9064),
    [sym_protected_keyword] = ACTIONS(9064),
    [sym_event_keyword] = ACTIONS(9064),
    [sym_fields_keyword] = ACTIONS(9064),
    [sym_keys_keyword] = ACTIONS(9064),
    [sym_key_keyword] = ACTIONS(9064),
    [sym_fieldgroups_keyword] = ACTIONS(9064),
    [sym_actions_keyword] = ACTIONS(9064),
    [sym_layout_keyword] = ACTIONS(9064),
    [sym_area_keyword] = ACTIONS(9064),
    [sym_group_keyword] = ACTIONS(9064),
    [sym_repeater_keyword] = ACTIONS(9064),
    [sym_cuegroup_keyword] = ACTIONS(9064),
    [sym_fixed_keyword] = ACTIONS(9064),
    [sym_grid_keyword] = ACTIONS(9064),
    [sym_part_keyword] = ACTIONS(9064),
    [sym_systempart_keyword] = ACTIONS(9064),
    [sym_usercontrol_keyword] = ACTIONS(9064),
    [sym_dataset_keyword] = ACTIONS(9064),
    [sym_elements_keyword] = ACTIONS(9064),
    [sym_dataitem_keyword] = ACTIONS(9064),
    [sym_column_keyword] = ACTIONS(9064),
    [sym_filter_keyword] = ACTIONS(9064),
    [sym_labels_keyword] = ACTIONS(9064),
    [sym_rendering_keyword] = ACTIONS(9064),
    [sym_requestpage_keyword] = ACTIONS(9064),
    [sym_schema_keyword] = ACTIONS(9064),
    [sym_views_keyword] = ACTIONS(9064),
    [sym_quoted_identifier] = ACTIONS(9066),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9066),
    [sym_preproc_open] = ACTIONS(9066),
    [sym_preproc_close] = ACTIONS(9066),
    [sym_var_attribute_open] = ACTIONS(9066),
  },
  [STATE(4050)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9068),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_addafter_modification_token1] = ACTIONS(9068),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9068),
    [aux_sym_movelast_modification_token1] = ACTIONS(9068),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9068),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_area_keyword] = ACTIONS(9068),
    [sym_group_keyword] = ACTIONS(9068),
    [sym_repeater_keyword] = ACTIONS(9068),
    [sym_cuegroup_keyword] = ACTIONS(9068),
    [sym_fixed_keyword] = ACTIONS(9068),
    [sym_grid_keyword] = ACTIONS(9068),
    [sym_part_keyword] = ACTIONS(9068),
    [sym_systempart_keyword] = ACTIONS(9068),
    [sym_usercontrol_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_dataitem_keyword] = ACTIONS(9068),
    [sym_column_keyword] = ACTIONS(9068),
    [sym_filter_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(4051)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9068),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_addafter_modification_token1] = ACTIONS(9068),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9068),
    [aux_sym_movelast_modification_token1] = ACTIONS(9068),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9068),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_area_keyword] = ACTIONS(9068),
    [sym_group_keyword] = ACTIONS(9068),
    [sym_repeater_keyword] = ACTIONS(9068),
    [sym_cuegroup_keyword] = ACTIONS(9068),
    [sym_fixed_keyword] = ACTIONS(9068),
    [sym_grid_keyword] = ACTIONS(9068),
    [sym_part_keyword] = ACTIONS(9068),
    [sym_systempart_keyword] = ACTIONS(9068),
    [sym_usercontrol_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_dataitem_keyword] = ACTIONS(9068),
    [sym_column_keyword] = ACTIONS(9068),
    [sym_filter_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(4052)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9068),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_addafter_modification_token1] = ACTIONS(9068),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9068),
    [aux_sym_movelast_modification_token1] = ACTIONS(9068),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9068),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_area_keyword] = ACTIONS(9068),
    [sym_group_keyword] = ACTIONS(9068),
    [sym_repeater_keyword] = ACTIONS(9068),
    [sym_cuegroup_keyword] = ACTIONS(9068),
    [sym_fixed_keyword] = ACTIONS(9068),
    [sym_grid_keyword] = ACTIONS(9068),
    [sym_part_keyword] = ACTIONS(9068),
    [sym_systempart_keyword] = ACTIONS(9068),
    [sym_usercontrol_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_dataitem_keyword] = ACTIONS(9068),
    [sym_column_keyword] = ACTIONS(9068),
    [sym_filter_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(4053)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(8050),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4054)] = {
    [sym__body_element] = STATE(4055),
    [sym_empty_statement] = STATE(4055),
    [sym_property] = STATE(4055),
    [sym_permissions_property] = STATE(4055),
    [sym_table_relation_property] = STATE(4055),
    [sym_fields_section] = STATE(4055),
    [sym_keys_section] = STATE(4055),
    [sym_fieldgroups_section] = STATE(4055),
    [sym_enum_value_declaration] = STATE(4055),
    [sym_labels_section] = STATE(4055),
    [sym_layout_section] = STATE(4055),
    [sym_modify_modification] = STATE(4055),
    [sym_actions_section] = STATE(4055),
    [sym_views_section] = STATE(4055),
    [sym_dataset_section] = STATE(4055),
    [sym_requestpage_section] = STATE(4055),
    [sym_rendering_section] = STATE(4055),
    [sym_elements_section] = STATE(4055),
    [sym_query_dataitem] = STATE(4055),
    [sym__query_body_element] = STATE(4055),
    [sym_preproc_conditional_query] = STATE(4055),
    [sym_query_column] = STATE(4055),
    [sym_query_filter] = STATE(4055),
    [sym_schema_section] = STATE(4055),
    [sym_assembly_declaration] = STATE(4055),
    [sym_event_declaration] = STATE(4055),
    [sym_procedure] = STATE(4055),
    [sym_preproc_split_procedure] = STATE(4055),
    [sym_preproc_split_procedure_preamble] = STATE(4055),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4055),
    [sym_var_section] = STATE(4055),
    [sym_attribute_item] = STATE(4055),
    [sym_preproc_conditional] = STATE(4055),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(8050),
    [aux_sym_query_dataitem_repeat1] = STATE(4055),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4055)] = {
    [sym__body_element] = STATE(3622),
    [sym_empty_statement] = STATE(3622),
    [sym_property] = STATE(3622),
    [sym_permissions_property] = STATE(3622),
    [sym_table_relation_property] = STATE(3622),
    [sym_fields_section] = STATE(3622),
    [sym_keys_section] = STATE(3622),
    [sym_fieldgroups_section] = STATE(3622),
    [sym_enum_value_declaration] = STATE(3622),
    [sym_labels_section] = STATE(3622),
    [sym_layout_section] = STATE(3622),
    [sym_modify_modification] = STATE(3622),
    [sym_actions_section] = STATE(3622),
    [sym_views_section] = STATE(3622),
    [sym_dataset_section] = STATE(3622),
    [sym_requestpage_section] = STATE(3622),
    [sym_rendering_section] = STATE(3622),
    [sym_elements_section] = STATE(3622),
    [sym_query_dataitem] = STATE(3622),
    [sym__query_body_element] = STATE(3622),
    [sym_preproc_conditional_query] = STATE(3622),
    [sym_query_column] = STATE(3622),
    [sym_query_filter] = STATE(3622),
    [sym_schema_section] = STATE(3622),
    [sym_assembly_declaration] = STATE(3622),
    [sym_event_declaration] = STATE(3622),
    [sym_procedure] = STATE(3622),
    [sym_preproc_split_procedure] = STATE(3622),
    [sym_preproc_split_procedure_preamble] = STATE(3622),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3622),
    [sym_var_section] = STATE(3622),
    [sym_attribute_item] = STATE(3622),
    [sym_preproc_conditional] = STATE(3622),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(8049),
    [aux_sym_query_dataitem_repeat1] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4056)] = {
    [sym__body_element] = STATE(4021),
    [sym_empty_statement] = STATE(4021),
    [sym_property] = STATE(4021),
    [sym_permissions_property] = STATE(4021),
    [sym_table_relation_property] = STATE(4021),
    [sym_fields_section] = STATE(4021),
    [sym_keys_section] = STATE(4021),
    [sym_fieldgroups_section] = STATE(4021),
    [sym_enum_value_declaration] = STATE(4021),
    [sym_labels_section] = STATE(4021),
    [sym_layout_section] = STATE(4021),
    [sym_modify_modification] = STATE(4021),
    [sym_actions_section] = STATE(4021),
    [sym_views_section] = STATE(4021),
    [sym_dataset_section] = STATE(4021),
    [sym_requestpage_section] = STATE(4021),
    [sym_rendering_section] = STATE(4021),
    [sym_elements_section] = STATE(4021),
    [sym_query_dataitem] = STATE(4021),
    [sym__query_body_element] = STATE(4021),
    [sym_preproc_conditional_query] = STATE(4021),
    [sym_query_column] = STATE(4021),
    [sym_query_filter] = STATE(4021),
    [sym_schema_section] = STATE(4021),
    [sym_assembly_declaration] = STATE(4021),
    [sym_event_declaration] = STATE(4021),
    [sym_procedure] = STATE(4021),
    [sym_preproc_split_procedure] = STATE(4021),
    [sym_preproc_split_procedure_preamble] = STATE(4021),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4021),
    [sym_var_section] = STATE(4021),
    [sym_attribute_item] = STATE(4021),
    [sym_preproc_conditional] = STATE(4021),
    [sym_preproc_if] = STATE(3463),
    [sym_preproc_endif] = STATE(8049),
    [aux_sym_query_dataitem_repeat1] = STATE(4021),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7463),
    [sym_column_keyword] = ACTIONS(7465),
    [sym_filter_keyword] = ACTIONS(7467),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4057)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5279),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token6] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_addafter_modification_token1] = ACTIONS(5279),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5279),
    [aux_sym_movelast_modification_token1] = ACTIONS(5279),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5279),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_area_keyword] = ACTIONS(5279),
    [sym_group_keyword] = ACTIONS(5279),
    [sym_repeater_keyword] = ACTIONS(5279),
    [sym_cuegroup_keyword] = ACTIONS(5279),
    [sym_fixed_keyword] = ACTIONS(5279),
    [sym_grid_keyword] = ACTIONS(5279),
    [sym_part_keyword] = ACTIONS(5279),
    [sym_systempart_keyword] = ACTIONS(5279),
    [sym_usercontrol_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_dataitem_keyword] = ACTIONS(5279),
    [sym_column_keyword] = ACTIONS(5279),
    [sym_filter_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
    [sym_var_attribute_open] = ACTIONS(5277),
  },
  [STATE(4058)] = {
    [sym_boolean] = STATE(8705),
    [sym__expression_statement] = STATE(18034),
    [sym_assignment_expression] = STATE(8705),
    [sym__expression] = STATE(8705),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8705),
    [sym_multiplicative_expression] = STATE(8705),
    [sym_additive_expression] = STATE(8705),
    [sym_comparison_expression] = STATE(8705),
    [sym_logical_expression] = STATE(8705),
    [sym_ternary_expression] = STATE(8705),
    [sym_unary_expression] = STATE(8705),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8705),
    [sym_list_literal] = STATE(8705),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8705),
    [sym__literal_value] = STATE(8705),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [aux_sym__preproc_guard_block_repeat1] = STATE(4058),
    [sym_identifier] = ACTIONS(9072),
    [anon_sym_DASH] = ACTIONS(9075),
    [aux_sym_boolean_token1] = ACTIONS(9078),
    [aux_sym_boolean_token2] = ACTIONS(9078),
    [sym_decimal] = ACTIONS(9081),
    [anon_sym_LPAREN] = ACTIONS(9084),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9087),
    [anon_sym_LBRACK] = ACTIONS(9090),
    [aux_sym_record_type_token1] = ACTIONS(9087),
    [aux_sym_basic_type_token21] = ACTIONS(9087),
    [aux_sym_basic_type_token22] = ACTIONS(9087),
    [aux_sym_basic_type_token48] = ACTIONS(9087),
    [anon_sym_not] = ACTIONS(9093),
    [anon_sym_NOT] = ACTIONS(9093),
    [anon_sym_Not] = ACTIONS(9093),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9087),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9096),
    [anon_sym_PLUS] = ACTIONS(9075),
    [sym_datetime_literal] = ACTIONS(9099),
    [sym_date_literal] = ACTIONS(9081),
    [sym_time_literal] = ACTIONS(9081),
    [sym_biginteger_literal] = ACTIONS(9099),
    [anon_sym_if] = ACTIONS(9102),
    [anon_sym_IF] = ACTIONS(9102),
    [anon_sym_If] = ACTIONS(9102),
    [sym_page_keyword] = ACTIONS(9096),
    [anon_sym_codeunit] = ACTIONS(9104),
    [anon_sym_CODEUNIT] = ACTIONS(9104),
    [anon_sym_Codeunit] = ACTIONS(9104),
    [anon_sym_CodeUnit] = ACTIONS(9104),
    [anon_sym_COdeunit] = ACTIONS(9104),
    [anon_sym_codeUnit] = ACTIONS(9104),
    [sym_report_keyword] = ACTIONS(9096),
    [sym_query_keyword] = ACTIONS(9096),
    [anon_sym_xmlport] = ACTIONS(9107),
    [anon_sym_XMLPORT] = ACTIONS(9107),
    [anon_sym_Xmlport] = ACTIONS(9107),
    [anon_sym_XMLport] = ACTIONS(9107),
    [anon_sym_XMLPort] = ACTIONS(9107),
    [anon_sym_XmlPort] = ACTIONS(9107),
    [anon_sym_enum] = ACTIONS(9110),
    [anon_sym_ENUM] = ACTIONS(9110),
    [anon_sym_Enum] = ACTIONS(9110),
    [anon_sym_eNUM] = ACTIONS(9110),
    [anon_sym_eNum] = ACTIONS(9110),
    [anon_sym_ENum] = ACTIONS(9110),
    [sym_quoted_identifier] = ACTIONS(9113),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9099),
    [sym_verbatim_string] = ACTIONS(9099),
    [sym_integer] = ACTIONS(9081),
    [sym_continue_as_identifier] = ACTIONS(9099),
  },
  [STATE(4059)] = {
    [sym__body_element] = STATE(8121),
    [sym_empty_statement] = STATE(8121),
    [sym_property] = STATE(8121),
    [sym_permissions_property] = STATE(8121),
    [sym_table_relation_property] = STATE(8121),
    [sym_fields_section] = STATE(8121),
    [sym_keys_section] = STATE(8121),
    [sym_fieldgroups_section] = STATE(8121),
    [sym_enum_value_declaration] = STATE(8121),
    [sym_labels_section] = STATE(8121),
    [sym_layout_section] = STATE(8121),
    [sym_modify_modification] = STATE(8121),
    [sym_actions_section] = STATE(8121),
    [sym_views_section] = STATE(8121),
    [sym_dataset_section] = STATE(8121),
    [sym_report_dataitem] = STATE(4075),
    [sym__report_body_element] = STATE(4075),
    [sym_preproc_conditional_report] = STATE(4075),
    [sym_report_column] = STATE(4075),
    [sym_requestpage_section] = STATE(8121),
    [sym_rendering_section] = STATE(8121),
    [sym_elements_section] = STATE(8121),
    [sym_schema_section] = STATE(8121),
    [sym_assembly_declaration] = STATE(8121),
    [sym_event_declaration] = STATE(8121),
    [sym_procedure] = STATE(8121),
    [sym_preproc_split_procedure] = STATE(8121),
    [sym_preproc_split_procedure_preamble] = STATE(8121),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8121),
    [sym_var_section] = STATE(8121),
    [sym_attribute_item] = STATE(8121),
    [sym_preproc_conditional] = STATE(8121),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(9949),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4897),
    [aux_sym_report_dataitem_repeat1] = STATE(4075),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4060)] = {
    [sym_where_clause] = STATE(8896),
    [sym_argument_list] = STATE(7165),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_DOT] = ACTIONS(3681),
    [anon_sym_RBRACE] = ACTIONS(5386),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(9116),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5386),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5386),
    [aux_sym_modify_modification_token1] = ACTIONS(5386),
    [aux_sym_xmlport_element_token1] = ACTIONS(5386),
    [aux_sym_xmlport_element_token2] = ACTIONS(5386),
    [aux_sym_xmlport_element_token3] = ACTIONS(5386),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5386),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5386),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5392),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5386),
    [anon_sym_POUNDIF] = ACTIONS(5386),
    [anon_sym_POUNDIf] = ACTIONS(5386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5386),
    [sym_trigger_keyword] = ACTIONS(5386),
    [sym_var_keyword] = ACTIONS(5386),
    [sym_local_keyword] = ACTIONS(5386),
    [sym_internal_keyword] = ACTIONS(5386),
    [sym_protected_keyword] = ACTIONS(5386),
    [sym_event_keyword] = ACTIONS(5386),
    [sym_fields_keyword] = ACTIONS(5386),
    [sym_keys_keyword] = ACTIONS(5386),
    [sym_fieldgroups_keyword] = ACTIONS(5386),
    [sym_actions_keyword] = ACTIONS(5386),
    [sym_layout_keyword] = ACTIONS(5386),
    [sym_dataset_keyword] = ACTIONS(5386),
    [sym_elements_keyword] = ACTIONS(5386),
    [sym_labels_keyword] = ACTIONS(5386),
    [sym_rendering_keyword] = ACTIONS(5386),
    [sym_requestpage_keyword] = ACTIONS(5386),
    [sym_schema_keyword] = ACTIONS(5386),
    [sym_views_keyword] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5386),
    [sym_preproc_open] = ACTIONS(5386),
  },
  [STATE(4061)] = {
    [aux_sym_option_member_list_repeat2] = STATE(4061),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_RBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(9118),
    [anon_sym_DASH] = ACTIONS(838),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_modify_modification_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_procedure_keyword] = ACTIONS(836),
    [sym_trigger_keyword] = ACTIONS(836),
    [sym_var_keyword] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_event_keyword] = ACTIONS(836),
    [sym_fields_keyword] = ACTIONS(836),
    [sym_keys_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_fieldgroups_keyword] = ACTIONS(836),
    [sym_actions_keyword] = ACTIONS(836),
    [sym_layout_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_elements_keyword] = ACTIONS(836),
    [sym_labels_keyword] = ACTIONS(836),
    [sym_rendering_keyword] = ACTIONS(836),
    [sym_requestpage_keyword] = ACTIONS(836),
    [sym_schema_keyword] = ACTIONS(836),
    [sym_views_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(838),
    [sym_property_name] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
    [sym_begin_keyword] = ACTIONS(838),
  },
  [STATE(4062)] = {
    [sym__body_element] = STATE(8121),
    [sym_empty_statement] = STATE(8121),
    [sym_property] = STATE(8121),
    [sym_permissions_property] = STATE(8121),
    [sym_table_relation_property] = STATE(8121),
    [sym_fields_section] = STATE(8121),
    [sym_keys_section] = STATE(8121),
    [sym_fieldgroups_section] = STATE(8121),
    [sym_enum_value_declaration] = STATE(8121),
    [sym_labels_section] = STATE(8121),
    [sym_layout_section] = STATE(8121),
    [sym_modify_modification] = STATE(8121),
    [sym_actions_section] = STATE(8121),
    [sym_views_section] = STATE(8121),
    [sym_dataset_section] = STATE(8121),
    [sym_report_dataitem] = STATE(4080),
    [sym__report_body_element] = STATE(4080),
    [sym_preproc_conditional_report] = STATE(4080),
    [sym_report_column] = STATE(4080),
    [sym_requestpage_section] = STATE(8121),
    [sym_rendering_section] = STATE(8121),
    [sym_elements_section] = STATE(8121),
    [sym_schema_section] = STATE(8121),
    [sym_assembly_declaration] = STATE(8121),
    [sym_event_declaration] = STATE(8121),
    [sym_procedure] = STATE(8121),
    [sym_preproc_split_procedure] = STATE(8121),
    [sym_preproc_split_procedure_preamble] = STATE(8121),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8121),
    [sym_var_section] = STATE(8121),
    [sym_attribute_item] = STATE(8121),
    [sym_preproc_conditional] = STATE(8121),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(8138),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4908),
    [aux_sym_report_dataitem_repeat1] = STATE(4080),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4063)] = {
    [sym_identifier] = ACTIONS(7712),
    [anon_sym_SEMI] = ACTIONS(7715),
    [anon_sym_RBRACE] = ACTIONS(7730),
    [aux_sym_where_condition_token1] = ACTIONS(7720),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7727),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7727),
    [anon_sym_LBRACK] = ACTIONS(7730),
    [aux_sym_basic_type_token6] = ACTIONS(7727),
    [aux_sym_basic_type_token22] = ACTIONS(7712),
    [aux_sym_basic_type_token53] = ACTIONS(7712),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7720),
    [aux_sym_addafter_modification_token1] = ACTIONS(7727),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7727),
    [aux_sym_modify_modification_token1] = ACTIONS(7727),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7727),
    [aux_sym_movelast_modification_token1] = ACTIONS(7727),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7727),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7727),
    [aux_sym_separator_action_token1] = ACTIONS(7712),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7720),
    [aux_sym_type_declaration_token1] = ACTIONS(7712),
    [anon_sym_POUNDif] = ACTIONS(7715),
    [anon_sym_POUNDIF] = ACTIONS(7715),
    [anon_sym_POUNDIf] = ACTIONS(7715),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7733),
    [sym_page_keyword] = ACTIONS(7725),
    [anon_sym_codeunit] = ACTIONS(7725),
    [anon_sym_CODEUNIT] = ACTIONS(7725),
    [anon_sym_Codeunit] = ACTIONS(7725),
    [anon_sym_CodeUnit] = ACTIONS(7725),
    [anon_sym_COdeunit] = ACTIONS(7725),
    [anon_sym_codeUnit] = ACTIONS(7725),
    [sym_report_keyword] = ACTIONS(7725),
    [sym_query_keyword] = ACTIONS(7725),
    [anon_sym_xmlport] = ACTIONS(7725),
    [anon_sym_XMLPORT] = ACTIONS(7725),
    [anon_sym_Xmlport] = ACTIONS(7725),
    [anon_sym_XMLport] = ACTIONS(7725),
    [anon_sym_XMLPort] = ACTIONS(7725),
    [anon_sym_XmlPort] = ACTIONS(7725),
    [sym_procedure_keyword] = ACTIONS(7727),
    [sym_trigger_keyword] = ACTIONS(7727),
    [sym_var_keyword] = ACTIONS(7727),
    [sym_local_keyword] = ACTIONS(7727),
    [sym_internal_keyword] = ACTIONS(7727),
    [sym_protected_keyword] = ACTIONS(7727),
    [sym_event_keyword] = ACTIONS(7727),
    [sym_fields_keyword] = ACTIONS(7727),
    [sym_keys_keyword] = ACTIONS(7727),
    [sym_key_keyword] = ACTIONS(7712),
    [sym_fieldgroups_keyword] = ACTIONS(7727),
    [sym_actions_keyword] = ACTIONS(7727),
    [sym_layout_keyword] = ACTIONS(7727),
    [sym_area_keyword] = ACTIONS(7727),
    [sym_group_keyword] = ACTIONS(7727),
    [sym_repeater_keyword] = ACTIONS(7727),
    [sym_cuegroup_keyword] = ACTIONS(7727),
    [sym_fixed_keyword] = ACTIONS(7727),
    [sym_grid_keyword] = ACTIONS(7727),
    [sym_part_keyword] = ACTIONS(7727),
    [sym_systempart_keyword] = ACTIONS(7727),
    [sym_usercontrol_keyword] = ACTIONS(7727),
    [sym_dataset_keyword] = ACTIONS(7720),
    [sym_elements_keyword] = ACTIONS(7727),
    [sym_labels_keyword] = ACTIONS(7727),
    [sym_rendering_keyword] = ACTIONS(7727),
    [sym_requestpage_keyword] = ACTIONS(7727),
    [sym_schema_keyword] = ACTIONS(7727),
    [sym_views_keyword] = ACTIONS(7727),
    [sym_quoted_identifier] = ACTIONS(7737),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7730),
    [sym_preproc_open] = ACTIONS(7715),
  },
  [STATE(4064)] = {
    [sym_boolean] = STATE(3809),
    [sym_filter_value] = STATE(17493),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(3621),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(9134),
    [sym_member_expression] = STATE(8749),
    [sym_subscript_expression] = STATE(8749),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(3621),
    [sym_database_reference] = STATE(3744),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(3695),
    [sym_xmlport_keyword] = STATE(3695),
    [sym_enum_keyword] = STATE(3683),
    [aux_sym_filter_value_repeat1] = STATE(4087),
    [sym_identifier] = ACTIONS(9121),
    [anon_sym_DASH] = ACTIONS(9123),
    [aux_sym_boolean_token1] = ACTIONS(9125),
    [aux_sym_boolean_token2] = ACTIONS(9125),
    [sym_decimal] = ACTIONS(9127),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_DOT_DOT] = ACTIONS(9129),
    [aux_sym_filter_value_token1] = ACTIONS(9131),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9133),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(9133),
    [aux_sym_basic_type_token21] = ACTIONS(9133),
    [aux_sym_basic_type_token22] = ACTIONS(9133),
    [aux_sym_basic_type_token48] = ACTIONS(9133),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9133),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9135),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9137),
    [sym_date_literal] = ACTIONS(9127),
    [sym_time_literal] = ACTIONS(9127),
    [sym_biginteger_literal] = ACTIONS(9137),
    [sym_page_keyword] = ACTIONS(9135),
    [anon_sym_codeunit] = ACTIONS(9139),
    [anon_sym_CODEUNIT] = ACTIONS(9139),
    [anon_sym_Codeunit] = ACTIONS(9139),
    [anon_sym_CodeUnit] = ACTIONS(9139),
    [anon_sym_COdeunit] = ACTIONS(9139),
    [anon_sym_codeUnit] = ACTIONS(9139),
    [sym_report_keyword] = ACTIONS(9135),
    [sym_query_keyword] = ACTIONS(9135),
    [anon_sym_xmlport] = ACTIONS(9141),
    [anon_sym_XMLPORT] = ACTIONS(9141),
    [anon_sym_Xmlport] = ACTIONS(9141),
    [anon_sym_XMLport] = ACTIONS(9141),
    [anon_sym_XMLPort] = ACTIONS(9141),
    [anon_sym_XmlPort] = ACTIONS(9141),
    [anon_sym_enum] = ACTIONS(9143),
    [anon_sym_ENUM] = ACTIONS(9143),
    [anon_sym_Enum] = ACTIONS(9143),
    [anon_sym_eNUM] = ACTIONS(9143),
    [anon_sym_eNum] = ACTIONS(9143),
    [anon_sym_ENum] = ACTIONS(9143),
    [sym_quoted_identifier] = ACTIONS(9145),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9137),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9127),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4065)] = {
    [sym_identifier] = ACTIONS(7757),
    [anon_sym_SEMI] = ACTIONS(7760),
    [anon_sym_RBRACE] = ACTIONS(7775),
    [aux_sym_where_condition_token1] = ACTIONS(7765),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7772),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7772),
    [anon_sym_LBRACK] = ACTIONS(7775),
    [aux_sym_basic_type_token6] = ACTIONS(7772),
    [aux_sym_basic_type_token22] = ACTIONS(7757),
    [aux_sym_basic_type_token53] = ACTIONS(7757),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7765),
    [aux_sym_addafter_modification_token1] = ACTIONS(7772),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7772),
    [aux_sym_modify_modification_token1] = ACTIONS(7772),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7772),
    [aux_sym_movelast_modification_token1] = ACTIONS(7772),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7772),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7772),
    [aux_sym_separator_action_token1] = ACTIONS(7757),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7765),
    [aux_sym_type_declaration_token1] = ACTIONS(7757),
    [anon_sym_POUNDif] = ACTIONS(7760),
    [anon_sym_POUNDIF] = ACTIONS(7760),
    [anon_sym_POUNDIf] = ACTIONS(7760),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7778),
    [sym_page_keyword] = ACTIONS(7770),
    [anon_sym_codeunit] = ACTIONS(7770),
    [anon_sym_CODEUNIT] = ACTIONS(7770),
    [anon_sym_Codeunit] = ACTIONS(7770),
    [anon_sym_CodeUnit] = ACTIONS(7770),
    [anon_sym_COdeunit] = ACTIONS(7770),
    [anon_sym_codeUnit] = ACTIONS(7770),
    [sym_report_keyword] = ACTIONS(7770),
    [sym_query_keyword] = ACTIONS(7770),
    [anon_sym_xmlport] = ACTIONS(7770),
    [anon_sym_XMLPORT] = ACTIONS(7770),
    [anon_sym_Xmlport] = ACTIONS(7770),
    [anon_sym_XMLport] = ACTIONS(7770),
    [anon_sym_XMLPort] = ACTIONS(7770),
    [anon_sym_XmlPort] = ACTIONS(7770),
    [sym_procedure_keyword] = ACTIONS(7772),
    [sym_trigger_keyword] = ACTIONS(7772),
    [sym_var_keyword] = ACTIONS(7772),
    [sym_local_keyword] = ACTIONS(7772),
    [sym_internal_keyword] = ACTIONS(7772),
    [sym_protected_keyword] = ACTIONS(7772),
    [sym_event_keyword] = ACTIONS(7772),
    [sym_fields_keyword] = ACTIONS(7772),
    [sym_keys_keyword] = ACTIONS(7772),
    [sym_key_keyword] = ACTIONS(7757),
    [sym_fieldgroups_keyword] = ACTIONS(7772),
    [sym_actions_keyword] = ACTIONS(7772),
    [sym_layout_keyword] = ACTIONS(7772),
    [sym_area_keyword] = ACTIONS(7772),
    [sym_group_keyword] = ACTIONS(7772),
    [sym_repeater_keyword] = ACTIONS(7772),
    [sym_cuegroup_keyword] = ACTIONS(7772),
    [sym_fixed_keyword] = ACTIONS(7772),
    [sym_grid_keyword] = ACTIONS(7772),
    [sym_part_keyword] = ACTIONS(7772),
    [sym_systempart_keyword] = ACTIONS(7772),
    [sym_usercontrol_keyword] = ACTIONS(7772),
    [sym_dataset_keyword] = ACTIONS(7765),
    [sym_elements_keyword] = ACTIONS(7772),
    [sym_labels_keyword] = ACTIONS(7772),
    [sym_rendering_keyword] = ACTIONS(7772),
    [sym_requestpage_keyword] = ACTIONS(7772),
    [sym_schema_keyword] = ACTIONS(7772),
    [sym_views_keyword] = ACTIONS(7772),
    [sym_quoted_identifier] = ACTIONS(7782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7775),
    [sym_preproc_open] = ACTIONS(7760),
  },
  [STATE(4066)] = {
    [sym_boolean] = STATE(3809),
    [sym_filter_value] = STATE(17197),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(3621),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(9134),
    [sym_member_expression] = STATE(8749),
    [sym_subscript_expression] = STATE(8749),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(3621),
    [sym_database_reference] = STATE(3744),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(3695),
    [sym_xmlport_keyword] = STATE(3695),
    [sym_enum_keyword] = STATE(3683),
    [aux_sym_filter_value_repeat1] = STATE(4087),
    [sym_identifier] = ACTIONS(9121),
    [anon_sym_DASH] = ACTIONS(9123),
    [aux_sym_boolean_token1] = ACTIONS(9125),
    [aux_sym_boolean_token2] = ACTIONS(9125),
    [sym_decimal] = ACTIONS(9127),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_DOT_DOT] = ACTIONS(9129),
    [aux_sym_filter_value_token1] = ACTIONS(9131),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9133),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(9133),
    [aux_sym_basic_type_token21] = ACTIONS(9133),
    [aux_sym_basic_type_token22] = ACTIONS(9133),
    [aux_sym_basic_type_token48] = ACTIONS(9133),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9133),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9135),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9137),
    [sym_date_literal] = ACTIONS(9127),
    [sym_time_literal] = ACTIONS(9127),
    [sym_biginteger_literal] = ACTIONS(9137),
    [sym_page_keyword] = ACTIONS(9135),
    [anon_sym_codeunit] = ACTIONS(9139),
    [anon_sym_CODEUNIT] = ACTIONS(9139),
    [anon_sym_Codeunit] = ACTIONS(9139),
    [anon_sym_CodeUnit] = ACTIONS(9139),
    [anon_sym_COdeunit] = ACTIONS(9139),
    [anon_sym_codeUnit] = ACTIONS(9139),
    [sym_report_keyword] = ACTIONS(9135),
    [sym_query_keyword] = ACTIONS(9135),
    [anon_sym_xmlport] = ACTIONS(9141),
    [anon_sym_XMLPORT] = ACTIONS(9141),
    [anon_sym_Xmlport] = ACTIONS(9141),
    [anon_sym_XMLport] = ACTIONS(9141),
    [anon_sym_XMLPort] = ACTIONS(9141),
    [anon_sym_XmlPort] = ACTIONS(9141),
    [anon_sym_enum] = ACTIONS(9143),
    [anon_sym_ENUM] = ACTIONS(9143),
    [anon_sym_Enum] = ACTIONS(9143),
    [anon_sym_eNUM] = ACTIONS(9143),
    [anon_sym_eNum] = ACTIONS(9143),
    [anon_sym_ENum] = ACTIONS(9143),
    [sym_quoted_identifier] = ACTIONS(9145),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9137),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9127),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4067)] = {
    [sym_preproc_conditional_permissions] = STATE(4074),
    [sym_tabledata_permission] = STATE(4891),
    [sym_preproc_if] = STATE(7982),
    [sym_codeunit_keyword] = STATE(11372),
    [sym_xmlport_keyword] = STATE(11372),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4074),
    [anon_sym_SEMI] = ACTIONS(7846),
    [aux_sym_tabledata_permission_token1] = ACTIONS(9147),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9147),
    [anon_sym_LBRACK] = ACTIONS(7846),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7846),
    [aux_sym_modify_modification_token1] = ACTIONS(7846),
    [aux_sym_xmlport_element_token1] = ACTIONS(7846),
    [aux_sym_xmlport_element_token2] = ACTIONS(7846),
    [aux_sym_xmlport_element_token3] = ACTIONS(7846),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7846),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7846),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7846),
    [anon_sym_POUNDif] = ACTIONS(7852),
    [anon_sym_POUNDIF] = ACTIONS(7852),
    [anon_sym_POUNDIf] = ACTIONS(7852),
    [anon_sym_POUNDelif] = ACTIONS(7846),
    [anon_sym_POUNDELIF] = ACTIONS(7846),
    [anon_sym_POUNDElif] = ACTIONS(7846),
    [anon_sym_POUNDelse] = ACTIONS(7846),
    [anon_sym_POUNDELSE] = ACTIONS(7846),
    [anon_sym_POUNDElse] = ACTIONS(7846),
    [anon_sym_POUNDelse2] = ACTIONS(7846),
    [anon_sym_POUNDELSE2] = ACTIONS(7846),
    [anon_sym_POUNDElse2] = ACTIONS(7846),
    [anon_sym_POUNDendif] = ACTIONS(7846),
    [anon_sym_POUNDENDIF] = ACTIONS(7846),
    [anon_sym_POUNDEndif] = ACTIONS(7846),
    [anon_sym_POUNDendif2] = ACTIONS(7846),
    [anon_sym_POUNDENDIF2] = ACTIONS(7846),
    [anon_sym_POUNDEndif2] = ACTIONS(7846),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4007),
    [sym_page_keyword] = ACTIONS(9147),
    [anon_sym_codeunit] = ACTIONS(7855),
    [anon_sym_CODEUNIT] = ACTIONS(7855),
    [anon_sym_Codeunit] = ACTIONS(7855),
    [anon_sym_CodeUnit] = ACTIONS(7855),
    [anon_sym_COdeunit] = ACTIONS(7855),
    [anon_sym_codeUnit] = ACTIONS(7855),
    [sym_report_keyword] = ACTIONS(9147),
    [sym_query_keyword] = ACTIONS(9147),
    [anon_sym_xmlport] = ACTIONS(7857),
    [anon_sym_XMLPORT] = ACTIONS(7857),
    [anon_sym_Xmlport] = ACTIONS(7857),
    [anon_sym_XMLport] = ACTIONS(7857),
    [anon_sym_XMLPort] = ACTIONS(7857),
    [anon_sym_XmlPort] = ACTIONS(7857),
    [sym_procedure_keyword] = ACTIONS(7846),
    [sym_trigger_keyword] = ACTIONS(7846),
    [sym_var_keyword] = ACTIONS(7846),
    [sym_local_keyword] = ACTIONS(7846),
    [sym_internal_keyword] = ACTIONS(7846),
    [sym_protected_keyword] = ACTIONS(7846),
    [sym_event_keyword] = ACTIONS(7846),
    [sym_fields_keyword] = ACTIONS(7846),
    [sym_keys_keyword] = ACTIONS(7846),
    [sym_fieldgroups_keyword] = ACTIONS(7846),
    [sym_actions_keyword] = ACTIONS(7846),
    [sym_layout_keyword] = ACTIONS(7846),
    [sym_dataset_keyword] = ACTIONS(7846),
    [sym_elements_keyword] = ACTIONS(7846),
    [sym_labels_keyword] = ACTIONS(7846),
    [sym_rendering_keyword] = ACTIONS(7846),
    [sym_requestpage_keyword] = ACTIONS(7846),
    [sym_schema_keyword] = ACTIONS(7846),
    [sym_views_keyword] = ACTIONS(7846),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7846),
    [sym_preproc_open] = ACTIONS(7852),
    [sym_preproc_close] = ACTIONS(7846),
  },
  [STATE(4068)] = {
    [sym_identifier] = ACTIONS(7712),
    [anon_sym_SEMI] = ACTIONS(7715),
    [aux_sym_where_condition_token1] = ACTIONS(7712),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [anon_sym_LBRACK] = ACTIONS(7730),
    [aux_sym_basic_type_token22] = ACTIONS(7712),
    [aux_sym_basic_type_token53] = ACTIONS(7712),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7720),
    [aux_sym_modify_modification_token1] = ACTIONS(7727),
    [aux_sym_separator_action_token1] = ACTIONS(7712),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7720),
    [aux_sym_type_declaration_token1] = ACTIONS(7712),
    [anon_sym_POUNDif] = ACTIONS(7715),
    [anon_sym_POUNDIF] = ACTIONS(7715),
    [anon_sym_POUNDIf] = ACTIONS(7715),
    [anon_sym_POUNDelif] = ACTIONS(7730),
    [anon_sym_POUNDELIF] = ACTIONS(7730),
    [anon_sym_POUNDElif] = ACTIONS(7730),
    [anon_sym_POUNDelse] = ACTIONS(7730),
    [anon_sym_POUNDELSE] = ACTIONS(7730),
    [anon_sym_POUNDElse] = ACTIONS(7730),
    [anon_sym_POUNDelse2] = ACTIONS(7730),
    [anon_sym_POUNDELSE2] = ACTIONS(7730),
    [anon_sym_POUNDElse2] = ACTIONS(7730),
    [anon_sym_POUNDendif] = ACTIONS(7730),
    [anon_sym_POUNDENDIF] = ACTIONS(7730),
    [anon_sym_POUNDEndif] = ACTIONS(7730),
    [anon_sym_POUNDendif2] = ACTIONS(7730),
    [anon_sym_POUNDENDIF2] = ACTIONS(7730),
    [anon_sym_POUNDEndif2] = ACTIONS(7730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7733),
    [sym_page_keyword] = ACTIONS(7725),
    [anon_sym_codeunit] = ACTIONS(7725),
    [anon_sym_CODEUNIT] = ACTIONS(7725),
    [anon_sym_Codeunit] = ACTIONS(7725),
    [anon_sym_CodeUnit] = ACTIONS(7725),
    [anon_sym_COdeunit] = ACTIONS(7725),
    [anon_sym_codeUnit] = ACTIONS(7725),
    [sym_report_keyword] = ACTIONS(7725),
    [sym_query_keyword] = ACTIONS(7725),
    [anon_sym_xmlport] = ACTIONS(7725),
    [anon_sym_XMLPORT] = ACTIONS(7725),
    [anon_sym_Xmlport] = ACTIONS(7725),
    [anon_sym_XMLport] = ACTIONS(7725),
    [anon_sym_XMLPort] = ACTIONS(7725),
    [anon_sym_XmlPort] = ACTIONS(7725),
    [sym_procedure_keyword] = ACTIONS(7727),
    [sym_trigger_keyword] = ACTIONS(7727),
    [sym_var_keyword] = ACTIONS(7727),
    [sym_local_keyword] = ACTIONS(7727),
    [sym_internal_keyword] = ACTIONS(7727),
    [sym_protected_keyword] = ACTIONS(7727),
    [sym_event_keyword] = ACTIONS(7727),
    [sym_fields_keyword] = ACTIONS(7727),
    [sym_keys_keyword] = ACTIONS(7727),
    [sym_key_keyword] = ACTIONS(7712),
    [sym_fieldgroups_keyword] = ACTIONS(7727),
    [sym_actions_keyword] = ACTIONS(7727),
    [sym_layout_keyword] = ACTIONS(7727),
    [sym_dataset_keyword] = ACTIONS(7720),
    [sym_elements_keyword] = ACTIONS(7727),
    [sym_dataitem_keyword] = ACTIONS(7727),
    [sym_column_keyword] = ACTIONS(7727),
    [sym_filter_keyword] = ACTIONS(7727),
    [sym_labels_keyword] = ACTIONS(7727),
    [sym_rendering_keyword] = ACTIONS(7727),
    [sym_requestpage_keyword] = ACTIONS(7727),
    [sym_schema_keyword] = ACTIONS(7727),
    [sym_views_keyword] = ACTIONS(7727),
    [sym_quoted_identifier] = ACTIONS(7737),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7730),
    [sym_preproc_open] = ACTIONS(7715),
    [sym_preproc_close] = ACTIONS(7730),
  },
  [STATE(4069)] = {
    [sym_boolean] = STATE(11132),
    [sym_option_member_list] = STATE(11350),
    [sym_option_member] = STATE(11104),
    [sym_keyword_identifier] = STATE(11132),
    [sym_codeunit_keyword] = STATE(11155),
    [sym_xmlport_keyword] = STATE(11155),
    [sym_enum_keyword] = STATE(11155),
    [sym_keyword_as_identifier] = STATE(11132),
    [aux_sym_option_member_list_repeat2] = STATE(4222),
    [sym_identifier] = ACTIONS(9149),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(9151),
    [anon_sym_DASH] = ACTIONS(9153),
    [aux_sym_boolean_token1] = ACTIONS(9155),
    [aux_sym_boolean_token2] = ACTIONS(9155),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9157),
    [aux_sym_record_type_token1] = ACTIONS(9157),
    [aux_sym_basic_type_token21] = ACTIONS(9157),
    [aux_sym_basic_type_token22] = ACTIONS(9159),
    [aux_sym_basic_type_token48] = ACTIONS(9157),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDelif] = ACTIONS(582),
    [anon_sym_POUNDELIF] = ACTIONS(582),
    [anon_sym_POUNDElif] = ACTIONS(582),
    [anon_sym_POUNDelse] = ACTIONS(582),
    [anon_sym_POUNDELSE] = ACTIONS(582),
    [anon_sym_POUNDElse] = ACTIONS(582),
    [anon_sym_POUNDelse2] = ACTIONS(582),
    [anon_sym_POUNDELSE2] = ACTIONS(582),
    [anon_sym_POUNDElse2] = ACTIONS(582),
    [anon_sym_POUNDendif] = ACTIONS(582),
    [anon_sym_POUNDENDIF] = ACTIONS(582),
    [anon_sym_POUNDEndif] = ACTIONS(582),
    [anon_sym_POUNDendif2] = ACTIONS(582),
    [anon_sym_POUNDENDIF2] = ACTIONS(582),
    [anon_sym_POUNDEndif2] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9157),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(9157),
    [anon_sym_codeunit] = ACTIONS(9161),
    [anon_sym_CODEUNIT] = ACTIONS(9161),
    [anon_sym_Codeunit] = ACTIONS(9161),
    [anon_sym_CodeUnit] = ACTIONS(9161),
    [anon_sym_COdeunit] = ACTIONS(9161),
    [anon_sym_codeUnit] = ACTIONS(9161),
    [sym_report_keyword] = ACTIONS(9157),
    [sym_query_keyword] = ACTIONS(9157),
    [anon_sym_xmlport] = ACTIONS(9163),
    [anon_sym_XMLPORT] = ACTIONS(9163),
    [anon_sym_Xmlport] = ACTIONS(9163),
    [anon_sym_XMLport] = ACTIONS(9163),
    [anon_sym_XMLPort] = ACTIONS(9163),
    [anon_sym_XmlPort] = ACTIONS(9163),
    [anon_sym_enum] = ACTIONS(9165),
    [anon_sym_ENUM] = ACTIONS(9165),
    [anon_sym_Enum] = ACTIONS(9165),
    [anon_sym_eNUM] = ACTIONS(9165),
    [anon_sym_eNum] = ACTIONS(9165),
    [anon_sym_ENum] = ACTIONS(9165),
    [sym_local_keyword] = ACTIONS(9149),
    [sym_internal_keyword] = ACTIONS(9149),
    [sym_protected_keyword] = ACTIONS(9149),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(9167),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9167),
    [sym_integer] = ACTIONS(9167),
    [sym_preproc_close] = ACTIONS(582),
  },
  [STATE(4070)] = {
    [sym_identifier] = ACTIONS(7757),
    [anon_sym_SEMI] = ACTIONS(7760),
    [aux_sym_where_condition_token1] = ACTIONS(7757),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [anon_sym_LBRACK] = ACTIONS(7775),
    [aux_sym_basic_type_token22] = ACTIONS(7757),
    [aux_sym_basic_type_token53] = ACTIONS(7757),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7765),
    [aux_sym_modify_modification_token1] = ACTIONS(7772),
    [aux_sym_separator_action_token1] = ACTIONS(7757),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7765),
    [aux_sym_type_declaration_token1] = ACTIONS(7757),
    [anon_sym_POUNDif] = ACTIONS(7760),
    [anon_sym_POUNDIF] = ACTIONS(7760),
    [anon_sym_POUNDIf] = ACTIONS(7760),
    [anon_sym_POUNDelif] = ACTIONS(7775),
    [anon_sym_POUNDELIF] = ACTIONS(7775),
    [anon_sym_POUNDElif] = ACTIONS(7775),
    [anon_sym_POUNDelse] = ACTIONS(7775),
    [anon_sym_POUNDELSE] = ACTIONS(7775),
    [anon_sym_POUNDElse] = ACTIONS(7775),
    [anon_sym_POUNDelse2] = ACTIONS(7775),
    [anon_sym_POUNDELSE2] = ACTIONS(7775),
    [anon_sym_POUNDElse2] = ACTIONS(7775),
    [anon_sym_POUNDendif] = ACTIONS(7775),
    [anon_sym_POUNDENDIF] = ACTIONS(7775),
    [anon_sym_POUNDEndif] = ACTIONS(7775),
    [anon_sym_POUNDendif2] = ACTIONS(7775),
    [anon_sym_POUNDENDIF2] = ACTIONS(7775),
    [anon_sym_POUNDEndif2] = ACTIONS(7775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7778),
    [sym_page_keyword] = ACTIONS(7770),
    [anon_sym_codeunit] = ACTIONS(7770),
    [anon_sym_CODEUNIT] = ACTIONS(7770),
    [anon_sym_Codeunit] = ACTIONS(7770),
    [anon_sym_CodeUnit] = ACTIONS(7770),
    [anon_sym_COdeunit] = ACTIONS(7770),
    [anon_sym_codeUnit] = ACTIONS(7770),
    [sym_report_keyword] = ACTIONS(7770),
    [sym_query_keyword] = ACTIONS(7770),
    [anon_sym_xmlport] = ACTIONS(7770),
    [anon_sym_XMLPORT] = ACTIONS(7770),
    [anon_sym_Xmlport] = ACTIONS(7770),
    [anon_sym_XMLport] = ACTIONS(7770),
    [anon_sym_XMLPort] = ACTIONS(7770),
    [anon_sym_XmlPort] = ACTIONS(7770),
    [sym_procedure_keyword] = ACTIONS(7772),
    [sym_trigger_keyword] = ACTIONS(7772),
    [sym_var_keyword] = ACTIONS(7772),
    [sym_local_keyword] = ACTIONS(7772),
    [sym_internal_keyword] = ACTIONS(7772),
    [sym_protected_keyword] = ACTIONS(7772),
    [sym_event_keyword] = ACTIONS(7772),
    [sym_fields_keyword] = ACTIONS(7772),
    [sym_keys_keyword] = ACTIONS(7772),
    [sym_key_keyword] = ACTIONS(7757),
    [sym_fieldgroups_keyword] = ACTIONS(7772),
    [sym_actions_keyword] = ACTIONS(7772),
    [sym_layout_keyword] = ACTIONS(7772),
    [sym_dataset_keyword] = ACTIONS(7765),
    [sym_elements_keyword] = ACTIONS(7772),
    [sym_dataitem_keyword] = ACTIONS(7772),
    [sym_column_keyword] = ACTIONS(7772),
    [sym_filter_keyword] = ACTIONS(7772),
    [sym_labels_keyword] = ACTIONS(7772),
    [sym_rendering_keyword] = ACTIONS(7772),
    [sym_requestpage_keyword] = ACTIONS(7772),
    [sym_schema_keyword] = ACTIONS(7772),
    [sym_views_keyword] = ACTIONS(7772),
    [sym_quoted_identifier] = ACTIONS(7782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7775),
    [sym_preproc_open] = ACTIONS(7760),
    [sym_preproc_close] = ACTIONS(7775),
  },
  [STATE(4071)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(9885),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4072)] = {
    [sym__body_element] = STATE(4078),
    [sym_empty_statement] = STATE(4078),
    [sym_property] = STATE(4078),
    [sym_permissions_property] = STATE(4078),
    [sym_table_relation_property] = STATE(4078),
    [sym_fields_section] = STATE(4078),
    [sym_keys_section] = STATE(4078),
    [sym_fieldgroups_section] = STATE(4078),
    [sym_enum_value_declaration] = STATE(4078),
    [sym_labels_section] = STATE(4078),
    [sym_layout_section] = STATE(4078),
    [sym_modify_modification] = STATE(4078),
    [sym_actions_section] = STATE(4078),
    [sym_views_section] = STATE(4078),
    [sym_dataset_section] = STATE(4078),
    [sym_report_dataitem] = STATE(4078),
    [sym__report_body_element] = STATE(4078),
    [sym_preproc_conditional_report] = STATE(4078),
    [sym_report_column] = STATE(4078),
    [sym_requestpage_section] = STATE(4078),
    [sym_rendering_section] = STATE(4078),
    [sym_elements_section] = STATE(4078),
    [sym_schema_section] = STATE(4078),
    [sym_assembly_declaration] = STATE(4078),
    [sym_event_declaration] = STATE(4078),
    [sym_procedure] = STATE(4078),
    [sym_preproc_split_procedure] = STATE(4078),
    [sym_preproc_split_procedure_preamble] = STATE(4078),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4078),
    [sym_var_section] = STATE(4078),
    [sym_attribute_item] = STATE(4078),
    [sym_preproc_conditional] = STATE(4078),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(9885),
    [aux_sym_report_dataitem_repeat1] = STATE(4078),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4073)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_RBRACE] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5279),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token6] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_addafter_modification_token1] = ACTIONS(5279),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5279),
    [aux_sym_movelast_modification_token1] = ACTIONS(5279),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5279),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_area_keyword] = ACTIONS(5279),
    [sym_group_keyword] = ACTIONS(5279),
    [sym_repeater_keyword] = ACTIONS(5279),
    [sym_cuegroup_keyword] = ACTIONS(5279),
    [sym_fixed_keyword] = ACTIONS(5279),
    [sym_grid_keyword] = ACTIONS(5279),
    [sym_part_keyword] = ACTIONS(5279),
    [sym_systempart_keyword] = ACTIONS(5279),
    [sym_usercontrol_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
  },
  [STATE(4074)] = {
    [sym_preproc_conditional_permissions] = STATE(4074),
    [sym_tabledata_permission] = STATE(4891),
    [sym_preproc_if] = STATE(7982),
    [sym_codeunit_keyword] = STATE(11372),
    [sym_xmlport_keyword] = STATE(11372),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4074),
    [anon_sym_SEMI] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token1] = ACTIONS(9169),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9169),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_xmlport_element_token1] = ACTIONS(7785),
    [aux_sym_xmlport_element_token2] = ACTIONS(7785),
    [aux_sym_xmlport_element_token3] = ACTIONS(7785),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7785),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7795),
    [anon_sym_POUNDIF] = ACTIONS(7795),
    [anon_sym_POUNDIf] = ACTIONS(7795),
    [anon_sym_POUNDelif] = ACTIONS(7785),
    [anon_sym_POUNDELIF] = ACTIONS(7785),
    [anon_sym_POUNDElif] = ACTIONS(7785),
    [anon_sym_POUNDelse] = ACTIONS(7785),
    [anon_sym_POUNDELSE] = ACTIONS(7785),
    [anon_sym_POUNDElse] = ACTIONS(7785),
    [anon_sym_POUNDelse2] = ACTIONS(7785),
    [anon_sym_POUNDELSE2] = ACTIONS(7785),
    [anon_sym_POUNDElse2] = ACTIONS(7785),
    [anon_sym_POUNDendif] = ACTIONS(7785),
    [anon_sym_POUNDENDIF] = ACTIONS(7785),
    [anon_sym_POUNDEndif] = ACTIONS(7785),
    [anon_sym_POUNDendif2] = ACTIONS(7785),
    [anon_sym_POUNDENDIF2] = ACTIONS(7785),
    [anon_sym_POUNDEndif2] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9172),
    [sym_page_keyword] = ACTIONS(9169),
    [anon_sym_codeunit] = ACTIONS(7798),
    [anon_sym_CODEUNIT] = ACTIONS(7798),
    [anon_sym_Codeunit] = ACTIONS(7798),
    [anon_sym_CodeUnit] = ACTIONS(7798),
    [anon_sym_COdeunit] = ACTIONS(7798),
    [anon_sym_codeUnit] = ACTIONS(7798),
    [sym_report_keyword] = ACTIONS(9169),
    [sym_query_keyword] = ACTIONS(9169),
    [anon_sym_xmlport] = ACTIONS(7801),
    [anon_sym_XMLPORT] = ACTIONS(7801),
    [anon_sym_Xmlport] = ACTIONS(7801),
    [anon_sym_XMLport] = ACTIONS(7801),
    [anon_sym_XMLPort] = ACTIONS(7801),
    [anon_sym_XmlPort] = ACTIONS(7801),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7795),
    [sym_preproc_close] = ACTIONS(7785),
  },
  [STATE(4075)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(9848),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4076)] = {
    [sym_boolean] = STATE(3809),
    [sym_filter_value] = STATE(17883),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(3621),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(9134),
    [sym_member_expression] = STATE(8749),
    [sym_subscript_expression] = STATE(8749),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(3621),
    [sym_database_reference] = STATE(3744),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(3695),
    [sym_xmlport_keyword] = STATE(3695),
    [sym_enum_keyword] = STATE(3683),
    [aux_sym_filter_value_repeat1] = STATE(4087),
    [sym_identifier] = ACTIONS(9121),
    [anon_sym_DASH] = ACTIONS(9123),
    [aux_sym_boolean_token1] = ACTIONS(9125),
    [aux_sym_boolean_token2] = ACTIONS(9125),
    [sym_decimal] = ACTIONS(9127),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_DOT_DOT] = ACTIONS(9129),
    [aux_sym_filter_value_token1] = ACTIONS(9131),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9133),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(9133),
    [aux_sym_basic_type_token21] = ACTIONS(9133),
    [aux_sym_basic_type_token22] = ACTIONS(9133),
    [aux_sym_basic_type_token48] = ACTIONS(9133),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9133),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9135),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9137),
    [sym_date_literal] = ACTIONS(9127),
    [sym_time_literal] = ACTIONS(9127),
    [sym_biginteger_literal] = ACTIONS(9137),
    [sym_page_keyword] = ACTIONS(9135),
    [anon_sym_codeunit] = ACTIONS(9139),
    [anon_sym_CODEUNIT] = ACTIONS(9139),
    [anon_sym_Codeunit] = ACTIONS(9139),
    [anon_sym_CodeUnit] = ACTIONS(9139),
    [anon_sym_COdeunit] = ACTIONS(9139),
    [anon_sym_codeUnit] = ACTIONS(9139),
    [sym_report_keyword] = ACTIONS(9135),
    [sym_query_keyword] = ACTIONS(9135),
    [anon_sym_xmlport] = ACTIONS(9141),
    [anon_sym_XMLPORT] = ACTIONS(9141),
    [anon_sym_Xmlport] = ACTIONS(9141),
    [anon_sym_XMLport] = ACTIONS(9141),
    [anon_sym_XMLPort] = ACTIONS(9141),
    [anon_sym_XmlPort] = ACTIONS(9141),
    [anon_sym_enum] = ACTIONS(9143),
    [anon_sym_ENUM] = ACTIONS(9143),
    [anon_sym_Enum] = ACTIONS(9143),
    [anon_sym_eNUM] = ACTIONS(9143),
    [anon_sym_eNum] = ACTIONS(9143),
    [anon_sym_ENum] = ACTIONS(9143),
    [sym_quoted_identifier] = ACTIONS(9145),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9137),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9127),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4077)] = {
    [sym__body_element] = STATE(4071),
    [sym_empty_statement] = STATE(4071),
    [sym_property] = STATE(4071),
    [sym_permissions_property] = STATE(4071),
    [sym_table_relation_property] = STATE(4071),
    [sym_fields_section] = STATE(4071),
    [sym_keys_section] = STATE(4071),
    [sym_fieldgroups_section] = STATE(4071),
    [sym_enum_value_declaration] = STATE(4071),
    [sym_labels_section] = STATE(4071),
    [sym_layout_section] = STATE(4071),
    [sym_modify_modification] = STATE(4071),
    [sym_actions_section] = STATE(4071),
    [sym_views_section] = STATE(4071),
    [sym_dataset_section] = STATE(4071),
    [sym_report_dataitem] = STATE(4071),
    [sym__report_body_element] = STATE(4071),
    [sym_preproc_conditional_report] = STATE(4071),
    [sym_report_column] = STATE(4071),
    [sym_requestpage_section] = STATE(4071),
    [sym_rendering_section] = STATE(4071),
    [sym_elements_section] = STATE(4071),
    [sym_schema_section] = STATE(4071),
    [sym_assembly_declaration] = STATE(4071),
    [sym_event_declaration] = STATE(4071),
    [sym_procedure] = STATE(4071),
    [sym_preproc_split_procedure] = STATE(4071),
    [sym_preproc_split_procedure_preamble] = STATE(4071),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4071),
    [sym_var_section] = STATE(4071),
    [sym_attribute_item] = STATE(4071),
    [sym_preproc_conditional] = STATE(4071),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(9848),
    [aux_sym_report_dataitem_repeat1] = STATE(4071),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4078)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(9938),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4079)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_dataitem_keyword] = ACTIONS(5279),
    [sym_column_keyword] = ACTIONS(5279),
    [sym_filter_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
  },
  [STATE(4080)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(8127),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4081)] = {
    [sym__body_element] = STATE(4084),
    [sym_empty_statement] = STATE(4084),
    [sym_property] = STATE(4084),
    [sym_permissions_property] = STATE(4084),
    [sym_table_relation_property] = STATE(4084),
    [sym_fields_section] = STATE(4084),
    [sym_keys_section] = STATE(4084),
    [sym_fieldgroups_section] = STATE(4084),
    [sym_enum_value_declaration] = STATE(4084),
    [sym_labels_section] = STATE(4084),
    [sym_layout_section] = STATE(4084),
    [sym_modify_modification] = STATE(4084),
    [sym_actions_section] = STATE(4084),
    [sym_views_section] = STATE(4084),
    [sym_dataset_section] = STATE(4084),
    [sym_report_dataitem] = STATE(4084),
    [sym__report_body_element] = STATE(4084),
    [sym_preproc_conditional_report] = STATE(4084),
    [sym_report_column] = STATE(4084),
    [sym_requestpage_section] = STATE(4084),
    [sym_rendering_section] = STATE(4084),
    [sym_elements_section] = STATE(4084),
    [sym_schema_section] = STATE(4084),
    [sym_assembly_declaration] = STATE(4084),
    [sym_event_declaration] = STATE(4084),
    [sym_procedure] = STATE(4084),
    [sym_preproc_split_procedure] = STATE(4084),
    [sym_preproc_split_procedure_preamble] = STATE(4084),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4084),
    [sym_var_section] = STATE(4084),
    [sym_attribute_item] = STATE(4084),
    [sym_preproc_conditional] = STATE(4084),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(8127),
    [aux_sym_report_dataitem_repeat1] = STATE(4084),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4082)] = {
    [sym_argument_list] = STATE(7165),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_RBRACE] = ACTIONS(5405),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5405),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5405),
    [aux_sym_modify_modification_token1] = ACTIONS(5405),
    [aux_sym_xmlport_element_token1] = ACTIONS(5405),
    [aux_sym_xmlport_element_token2] = ACTIONS(5405),
    [aux_sym_xmlport_element_token3] = ACTIONS(5405),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5405),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5405),
    [sym_trigger_keyword] = ACTIONS(5405),
    [sym_var_keyword] = ACTIONS(5405),
    [sym_local_keyword] = ACTIONS(5405),
    [sym_internal_keyword] = ACTIONS(5405),
    [sym_protected_keyword] = ACTIONS(5405),
    [sym_event_keyword] = ACTIONS(5405),
    [sym_fields_keyword] = ACTIONS(5405),
    [sym_keys_keyword] = ACTIONS(5405),
    [sym_fieldgroups_keyword] = ACTIONS(5405),
    [sym_actions_keyword] = ACTIONS(5405),
    [sym_layout_keyword] = ACTIONS(5405),
    [sym_dataset_keyword] = ACTIONS(5405),
    [sym_elements_keyword] = ACTIONS(5405),
    [sym_labels_keyword] = ACTIONS(5405),
    [sym_rendering_keyword] = ACTIONS(5405),
    [sym_requestpage_keyword] = ACTIONS(5405),
    [sym_schema_keyword] = ACTIONS(5405),
    [sym_views_keyword] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
  },
  [STATE(4083)] = {
    [sym_boolean] = STATE(3809),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(3621),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(9134),
    [sym_member_expression] = STATE(8749),
    [sym_subscript_expression] = STATE(8749),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(3621),
    [sym_database_reference] = STATE(3744),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(3695),
    [sym_xmlport_keyword] = STATE(3695),
    [sym_enum_keyword] = STATE(3683),
    [aux_sym_filter_value_repeat1] = STATE(4083),
    [sym_identifier] = ACTIONS(9175),
    [anon_sym_DASH] = ACTIONS(9178),
    [aux_sym_boolean_token1] = ACTIONS(9181),
    [aux_sym_boolean_token2] = ACTIONS(9181),
    [sym_decimal] = ACTIONS(9184),
    [anon_sym_LPAREN] = ACTIONS(9187),
    [anon_sym_RPAREN] = ACTIONS(8421),
    [anon_sym_DOT_DOT] = ACTIONS(9190),
    [aux_sym_filter_value_token1] = ACTIONS(9193),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9196),
    [anon_sym_LBRACK] = ACTIONS(9199),
    [aux_sym_record_type_token1] = ACTIONS(9196),
    [aux_sym_basic_type_token21] = ACTIONS(9196),
    [aux_sym_basic_type_token22] = ACTIONS(9196),
    [aux_sym_basic_type_token48] = ACTIONS(9196),
    [anon_sym_not] = ACTIONS(9202),
    [anon_sym_NOT] = ACTIONS(9202),
    [anon_sym_Not] = ACTIONS(9202),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9196),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9205),
    [anon_sym_PLUS] = ACTIONS(9208),
    [sym_datetime_literal] = ACTIONS(9211),
    [sym_date_literal] = ACTIONS(9184),
    [sym_time_literal] = ACTIONS(9184),
    [sym_biginteger_literal] = ACTIONS(9211),
    [sym_page_keyword] = ACTIONS(9205),
    [anon_sym_codeunit] = ACTIONS(9214),
    [anon_sym_CODEUNIT] = ACTIONS(9214),
    [anon_sym_Codeunit] = ACTIONS(9214),
    [anon_sym_CodeUnit] = ACTIONS(9214),
    [anon_sym_COdeunit] = ACTIONS(9214),
    [anon_sym_codeUnit] = ACTIONS(9214),
    [sym_report_keyword] = ACTIONS(9205),
    [sym_query_keyword] = ACTIONS(9205),
    [anon_sym_xmlport] = ACTIONS(9217),
    [anon_sym_XMLPORT] = ACTIONS(9217),
    [anon_sym_Xmlport] = ACTIONS(9217),
    [anon_sym_XMLport] = ACTIONS(9217),
    [anon_sym_XMLPort] = ACTIONS(9217),
    [anon_sym_XmlPort] = ACTIONS(9217),
    [anon_sym_enum] = ACTIONS(9220),
    [anon_sym_ENUM] = ACTIONS(9220),
    [anon_sym_Enum] = ACTIONS(9220),
    [anon_sym_eNUM] = ACTIONS(9220),
    [anon_sym_eNum] = ACTIONS(9220),
    [anon_sym_ENum] = ACTIONS(9220),
    [sym_quoted_identifier] = ACTIONS(9223),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9211),
    [sym_verbatim_string] = ACTIONS(9226),
    [sym_integer] = ACTIONS(9184),
    [sym_continue_as_identifier] = ACTIONS(9226),
  },
  [STATE(4084)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(8116),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4085)] = {
    [sym__body_element] = STATE(4088),
    [sym_empty_statement] = STATE(4088),
    [sym_property] = STATE(4088),
    [sym_permissions_property] = STATE(4088),
    [sym_table_relation_property] = STATE(4088),
    [sym_fields_section] = STATE(4088),
    [sym_keys_section] = STATE(4088),
    [sym_fieldgroups_section] = STATE(4088),
    [sym_enum_value_declaration] = STATE(4088),
    [sym_labels_section] = STATE(4088),
    [sym_layout_section] = STATE(4088),
    [sym_modify_modification] = STATE(4088),
    [sym_actions_section] = STATE(4088),
    [sym_views_section] = STATE(4088),
    [sym_dataset_section] = STATE(4088),
    [sym_report_dataitem] = STATE(4088),
    [sym__report_body_element] = STATE(4088),
    [sym_preproc_conditional_report] = STATE(4088),
    [sym_report_column] = STATE(4088),
    [sym_requestpage_section] = STATE(4088),
    [sym_rendering_section] = STATE(4088),
    [sym_elements_section] = STATE(4088),
    [sym_schema_section] = STATE(4088),
    [sym_assembly_declaration] = STATE(4088),
    [sym_event_declaration] = STATE(4088),
    [sym_procedure] = STATE(4088),
    [sym_preproc_split_procedure] = STATE(4088),
    [sym_preproc_split_procedure_preamble] = STATE(4088),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4088),
    [sym_var_section] = STATE(4088),
    [sym_attribute_item] = STATE(4088),
    [sym_preproc_conditional] = STATE(4088),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(8116),
    [aux_sym_report_dataitem_repeat1] = STATE(4088),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4086)] = {
    [sym_boolean] = STATE(3809),
    [sym_filter_value] = STATE(17224),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(3621),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(9134),
    [sym_member_expression] = STATE(8749),
    [sym_subscript_expression] = STATE(8749),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(3621),
    [sym_database_reference] = STATE(3744),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(3695),
    [sym_xmlport_keyword] = STATE(3695),
    [sym_enum_keyword] = STATE(3683),
    [aux_sym_filter_value_repeat1] = STATE(4087),
    [sym_identifier] = ACTIONS(9121),
    [anon_sym_DASH] = ACTIONS(9123),
    [aux_sym_boolean_token1] = ACTIONS(9125),
    [aux_sym_boolean_token2] = ACTIONS(9125),
    [sym_decimal] = ACTIONS(9127),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_DOT_DOT] = ACTIONS(9129),
    [aux_sym_filter_value_token1] = ACTIONS(9131),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9133),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(9133),
    [aux_sym_basic_type_token21] = ACTIONS(9133),
    [aux_sym_basic_type_token22] = ACTIONS(9133),
    [aux_sym_basic_type_token48] = ACTIONS(9133),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9133),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9135),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9137),
    [sym_date_literal] = ACTIONS(9127),
    [sym_time_literal] = ACTIONS(9127),
    [sym_biginteger_literal] = ACTIONS(9137),
    [sym_page_keyword] = ACTIONS(9135),
    [anon_sym_codeunit] = ACTIONS(9139),
    [anon_sym_CODEUNIT] = ACTIONS(9139),
    [anon_sym_Codeunit] = ACTIONS(9139),
    [anon_sym_CodeUnit] = ACTIONS(9139),
    [anon_sym_COdeunit] = ACTIONS(9139),
    [anon_sym_codeUnit] = ACTIONS(9139),
    [sym_report_keyword] = ACTIONS(9135),
    [sym_query_keyword] = ACTIONS(9135),
    [anon_sym_xmlport] = ACTIONS(9141),
    [anon_sym_XMLPORT] = ACTIONS(9141),
    [anon_sym_Xmlport] = ACTIONS(9141),
    [anon_sym_XMLport] = ACTIONS(9141),
    [anon_sym_XMLPort] = ACTIONS(9141),
    [anon_sym_XmlPort] = ACTIONS(9141),
    [anon_sym_enum] = ACTIONS(9143),
    [anon_sym_ENUM] = ACTIONS(9143),
    [anon_sym_Enum] = ACTIONS(9143),
    [anon_sym_eNUM] = ACTIONS(9143),
    [anon_sym_eNum] = ACTIONS(9143),
    [anon_sym_ENum] = ACTIONS(9143),
    [sym_quoted_identifier] = ACTIONS(9145),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9137),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9127),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4087)] = {
    [sym_boolean] = STATE(3809),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(3621),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(9134),
    [sym_member_expression] = STATE(8749),
    [sym_subscript_expression] = STATE(8749),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(3621),
    [sym_database_reference] = STATE(3744),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(3695),
    [sym_xmlport_keyword] = STATE(3695),
    [sym_enum_keyword] = STATE(3683),
    [aux_sym_filter_value_repeat1] = STATE(4083),
    [sym_identifier] = ACTIONS(9121),
    [anon_sym_DASH] = ACTIONS(9123),
    [aux_sym_boolean_token1] = ACTIONS(9125),
    [aux_sym_boolean_token2] = ACTIONS(9125),
    [sym_decimal] = ACTIONS(9127),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9229),
    [anon_sym_DOT_DOT] = ACTIONS(9231),
    [aux_sym_filter_value_token1] = ACTIONS(9233),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9133),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(9133),
    [aux_sym_basic_type_token21] = ACTIONS(9133),
    [aux_sym_basic_type_token22] = ACTIONS(9133),
    [aux_sym_basic_type_token48] = ACTIONS(9133),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9133),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9135),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9137),
    [sym_date_literal] = ACTIONS(9127),
    [sym_time_literal] = ACTIONS(9127),
    [sym_biginteger_literal] = ACTIONS(9137),
    [sym_page_keyword] = ACTIONS(9135),
    [anon_sym_codeunit] = ACTIONS(9139),
    [anon_sym_CODEUNIT] = ACTIONS(9139),
    [anon_sym_Codeunit] = ACTIONS(9139),
    [anon_sym_CodeUnit] = ACTIONS(9139),
    [anon_sym_COdeunit] = ACTIONS(9139),
    [anon_sym_codeUnit] = ACTIONS(9139),
    [sym_report_keyword] = ACTIONS(9135),
    [sym_query_keyword] = ACTIONS(9135),
    [anon_sym_xmlport] = ACTIONS(9141),
    [anon_sym_XMLPORT] = ACTIONS(9141),
    [anon_sym_Xmlport] = ACTIONS(9141),
    [anon_sym_XMLport] = ACTIONS(9141),
    [anon_sym_XMLPort] = ACTIONS(9141),
    [anon_sym_XmlPort] = ACTIONS(9141),
    [anon_sym_enum] = ACTIONS(9143),
    [anon_sym_ENUM] = ACTIONS(9143),
    [anon_sym_Enum] = ACTIONS(9143),
    [anon_sym_eNUM] = ACTIONS(9143),
    [anon_sym_eNum] = ACTIONS(9143),
    [anon_sym_ENum] = ACTIONS(9143),
    [sym_quoted_identifier] = ACTIONS(9145),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9137),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9127),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4088)] = {
    [sym__body_element] = STATE(3810),
    [sym_empty_statement] = STATE(3810),
    [sym_property] = STATE(3810),
    [sym_permissions_property] = STATE(3810),
    [sym_table_relation_property] = STATE(3810),
    [sym_fields_section] = STATE(3810),
    [sym_keys_section] = STATE(3810),
    [sym_fieldgroups_section] = STATE(3810),
    [sym_enum_value_declaration] = STATE(3810),
    [sym_labels_section] = STATE(3810),
    [sym_layout_section] = STATE(3810),
    [sym_modify_modification] = STATE(3810),
    [sym_actions_section] = STATE(3810),
    [sym_views_section] = STATE(3810),
    [sym_dataset_section] = STATE(3810),
    [sym_report_dataitem] = STATE(3810),
    [sym__report_body_element] = STATE(3810),
    [sym_preproc_conditional_report] = STATE(3810),
    [sym_report_column] = STATE(3810),
    [sym_requestpage_section] = STATE(3810),
    [sym_rendering_section] = STATE(3810),
    [sym_elements_section] = STATE(3810),
    [sym_schema_section] = STATE(3810),
    [sym_assembly_declaration] = STATE(3810),
    [sym_event_declaration] = STATE(3810),
    [sym_procedure] = STATE(3810),
    [sym_preproc_split_procedure] = STATE(3810),
    [sym_preproc_split_procedure_preamble] = STATE(3810),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3810),
    [sym_var_section] = STATE(3810),
    [sym_attribute_item] = STATE(3810),
    [sym_preproc_conditional] = STATE(3810),
    [sym_preproc_if] = STATE(3548),
    [sym_preproc_endif] = STATE(8117),
    [aux_sym_report_dataitem_repeat1] = STATE(3810),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_dataitem_keyword] = ACTIONS(7606),
    [sym_column_keyword] = ACTIONS(7608),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4089)] = {
    [anon_sym_SEMI] = ACTIONS(9235),
    [aux_sym_where_condition_token1] = ACTIONS(9237),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9235),
    [anon_sym_LBRACK] = ACTIONS(9235),
    [aux_sym_basic_type_token6] = ACTIONS(9237),
    [aux_sym_basic_type_token22] = ACTIONS(9237),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9235),
    [aux_sym_addafter_modification_token1] = ACTIONS(9235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9235),
    [aux_sym_modify_modification_token1] = ACTIONS(9235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9235),
    [aux_sym_movelast_modification_token1] = ACTIONS(9235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9235),
    [aux_sym_separator_action_token1] = ACTIONS(9235),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9235),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9235),
    [anon_sym_POUNDif] = ACTIONS(9235),
    [anon_sym_POUNDIF] = ACTIONS(9235),
    [anon_sym_POUNDIf] = ACTIONS(9235),
    [anon_sym_POUNDelif] = ACTIONS(9235),
    [anon_sym_POUNDELIF] = ACTIONS(9235),
    [anon_sym_POUNDElif] = ACTIONS(9235),
    [anon_sym_POUNDelse] = ACTIONS(9235),
    [anon_sym_POUNDELSE] = ACTIONS(9235),
    [anon_sym_POUNDElse] = ACTIONS(9235),
    [anon_sym_POUNDelse2] = ACTIONS(9235),
    [anon_sym_POUNDELSE2] = ACTIONS(9235),
    [anon_sym_POUNDElse2] = ACTIONS(9235),
    [anon_sym_POUNDendif] = ACTIONS(9235),
    [anon_sym_POUNDENDIF] = ACTIONS(9235),
    [anon_sym_POUNDEndif] = ACTIONS(9235),
    [anon_sym_POUNDendif2] = ACTIONS(9235),
    [anon_sym_POUNDENDIF2] = ACTIONS(9235),
    [anon_sym_POUNDEndif2] = ACTIONS(9235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9235),
    [sym_trigger_keyword] = ACTIONS(9235),
    [sym_var_keyword] = ACTIONS(9235),
    [sym_local_keyword] = ACTIONS(9235),
    [sym_internal_keyword] = ACTIONS(9235),
    [sym_protected_keyword] = ACTIONS(9235),
    [sym_event_keyword] = ACTIONS(9235),
    [sym_fields_keyword] = ACTIONS(9235),
    [sym_keys_keyword] = ACTIONS(9235),
    [sym_fieldgroups_keyword] = ACTIONS(9235),
    [sym_actions_keyword] = ACTIONS(9235),
    [sym_layout_keyword] = ACTIONS(9235),
    [sym_area_keyword] = ACTIONS(9235),
    [sym_group_keyword] = ACTIONS(9235),
    [sym_repeater_keyword] = ACTIONS(9235),
    [sym_cuegroup_keyword] = ACTIONS(9235),
    [sym_fixed_keyword] = ACTIONS(9235),
    [sym_grid_keyword] = ACTIONS(9235),
    [sym_part_keyword] = ACTIONS(9235),
    [sym_systempart_keyword] = ACTIONS(9235),
    [sym_usercontrol_keyword] = ACTIONS(9235),
    [sym_dataset_keyword] = ACTIONS(9235),
    [sym_elements_keyword] = ACTIONS(9235),
    [sym_dataitem_keyword] = ACTIONS(9235),
    [sym_column_keyword] = ACTIONS(9235),
    [sym_filter_keyword] = ACTIONS(9235),
    [sym_labels_keyword] = ACTIONS(9235),
    [sym_rendering_keyword] = ACTIONS(9235),
    [sym_requestpage_keyword] = ACTIONS(9235),
    [sym_schema_keyword] = ACTIONS(9235),
    [sym_views_keyword] = ACTIONS(9235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9235),
    [sym_preproc_open] = ACTIONS(9235),
    [sym_preproc_close] = ACTIONS(9235),
  },
  [STATE(4090)] = {
    [anon_sym_SEMI] = ACTIONS(6190),
    [aux_sym_where_condition_token1] = ACTIONS(6188),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6190),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6190),
    [anon_sym_LBRACK] = ACTIONS(6190),
    [aux_sym_basic_type_token6] = ACTIONS(6188),
    [aux_sym_basic_type_token22] = ACTIONS(6188),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6190),
    [aux_sym_addafter_modification_token1] = ACTIONS(6190),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6190),
    [aux_sym_modify_modification_token1] = ACTIONS(6190),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6190),
    [aux_sym_movelast_modification_token1] = ACTIONS(6190),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6190),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6190),
    [aux_sym_separator_action_token1] = ACTIONS(6190),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6190),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6190),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6190),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6190),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6190),
    [anon_sym_POUNDif] = ACTIONS(6190),
    [anon_sym_POUNDIF] = ACTIONS(6190),
    [anon_sym_POUNDIf] = ACTIONS(6190),
    [anon_sym_POUNDelif] = ACTIONS(6190),
    [anon_sym_POUNDELIF] = ACTIONS(6190),
    [anon_sym_POUNDElif] = ACTIONS(6190),
    [anon_sym_POUNDelse] = ACTIONS(6190),
    [anon_sym_POUNDELSE] = ACTIONS(6190),
    [anon_sym_POUNDElse] = ACTIONS(6190),
    [anon_sym_POUNDelse2] = ACTIONS(6190),
    [anon_sym_POUNDELSE2] = ACTIONS(6190),
    [anon_sym_POUNDElse2] = ACTIONS(6190),
    [anon_sym_POUNDendif] = ACTIONS(6190),
    [anon_sym_POUNDENDIF] = ACTIONS(6190),
    [anon_sym_POUNDEndif] = ACTIONS(6190),
    [anon_sym_POUNDendif2] = ACTIONS(6190),
    [anon_sym_POUNDENDIF2] = ACTIONS(6190),
    [anon_sym_POUNDEndif2] = ACTIONS(6190),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6190),
    [sym_trigger_keyword] = ACTIONS(6190),
    [sym_var_keyword] = ACTIONS(6190),
    [sym_local_keyword] = ACTIONS(6190),
    [sym_internal_keyword] = ACTIONS(6190),
    [sym_protected_keyword] = ACTIONS(6190),
    [sym_event_keyword] = ACTIONS(6190),
    [sym_fields_keyword] = ACTIONS(6190),
    [sym_keys_keyword] = ACTIONS(6190),
    [sym_fieldgroups_keyword] = ACTIONS(6190),
    [sym_actions_keyword] = ACTIONS(6190),
    [sym_layout_keyword] = ACTIONS(6190),
    [sym_area_keyword] = ACTIONS(6190),
    [sym_group_keyword] = ACTIONS(6190),
    [sym_repeater_keyword] = ACTIONS(6190),
    [sym_cuegroup_keyword] = ACTIONS(6190),
    [sym_fixed_keyword] = ACTIONS(6190),
    [sym_grid_keyword] = ACTIONS(6190),
    [sym_part_keyword] = ACTIONS(6190),
    [sym_systempart_keyword] = ACTIONS(6190),
    [sym_usercontrol_keyword] = ACTIONS(6190),
    [sym_dataset_keyword] = ACTIONS(6190),
    [sym_elements_keyword] = ACTIONS(6190),
    [sym_dataitem_keyword] = ACTIONS(6190),
    [sym_column_keyword] = ACTIONS(6190),
    [sym_filter_keyword] = ACTIONS(6190),
    [sym_labels_keyword] = ACTIONS(6190),
    [sym_rendering_keyword] = ACTIONS(6190),
    [sym_requestpage_keyword] = ACTIONS(6190),
    [sym_schema_keyword] = ACTIONS(6190),
    [sym_views_keyword] = ACTIONS(6190),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6190),
    [sym_preproc_open] = ACTIONS(6190),
    [sym_preproc_close] = ACTIONS(6190),
  },
  [STATE(4091)] = {
    [anon_sym_SEMI] = ACTIONS(9239),
    [aux_sym_where_condition_token1] = ACTIONS(9241),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9239),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9239),
    [anon_sym_LBRACK] = ACTIONS(9239),
    [aux_sym_basic_type_token6] = ACTIONS(9241),
    [aux_sym_basic_type_token22] = ACTIONS(9241),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9239),
    [aux_sym_addafter_modification_token1] = ACTIONS(9239),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9239),
    [aux_sym_modify_modification_token1] = ACTIONS(9239),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9239),
    [aux_sym_movelast_modification_token1] = ACTIONS(9239),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9239),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9239),
    [aux_sym_separator_action_token1] = ACTIONS(9239),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9239),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9239),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9239),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9239),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9239),
    [anon_sym_POUNDif] = ACTIONS(9239),
    [anon_sym_POUNDIF] = ACTIONS(9239),
    [anon_sym_POUNDIf] = ACTIONS(9239),
    [anon_sym_POUNDelif] = ACTIONS(9239),
    [anon_sym_POUNDELIF] = ACTIONS(9239),
    [anon_sym_POUNDElif] = ACTIONS(9239),
    [anon_sym_POUNDelse] = ACTIONS(9239),
    [anon_sym_POUNDELSE] = ACTIONS(9239),
    [anon_sym_POUNDElse] = ACTIONS(9239),
    [anon_sym_POUNDelse2] = ACTIONS(9239),
    [anon_sym_POUNDELSE2] = ACTIONS(9239),
    [anon_sym_POUNDElse2] = ACTIONS(9239),
    [anon_sym_POUNDendif] = ACTIONS(9239),
    [anon_sym_POUNDENDIF] = ACTIONS(9239),
    [anon_sym_POUNDEndif] = ACTIONS(9239),
    [anon_sym_POUNDendif2] = ACTIONS(9239),
    [anon_sym_POUNDENDIF2] = ACTIONS(9239),
    [anon_sym_POUNDEndif2] = ACTIONS(9239),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9239),
    [sym_trigger_keyword] = ACTIONS(9239),
    [sym_var_keyword] = ACTIONS(9239),
    [sym_local_keyword] = ACTIONS(9239),
    [sym_internal_keyword] = ACTIONS(9239),
    [sym_protected_keyword] = ACTIONS(9239),
    [sym_event_keyword] = ACTIONS(9239),
    [sym_fields_keyword] = ACTIONS(9239),
    [sym_keys_keyword] = ACTIONS(9239),
    [sym_fieldgroups_keyword] = ACTIONS(9239),
    [sym_actions_keyword] = ACTIONS(9239),
    [sym_layout_keyword] = ACTIONS(9239),
    [sym_area_keyword] = ACTIONS(9239),
    [sym_group_keyword] = ACTIONS(9239),
    [sym_repeater_keyword] = ACTIONS(9239),
    [sym_cuegroup_keyword] = ACTIONS(9239),
    [sym_fixed_keyword] = ACTIONS(9239),
    [sym_grid_keyword] = ACTIONS(9239),
    [sym_part_keyword] = ACTIONS(9239),
    [sym_systempart_keyword] = ACTIONS(9239),
    [sym_usercontrol_keyword] = ACTIONS(9239),
    [sym_dataset_keyword] = ACTIONS(9239),
    [sym_elements_keyword] = ACTIONS(9239),
    [sym_dataitem_keyword] = ACTIONS(9239),
    [sym_column_keyword] = ACTIONS(9239),
    [sym_filter_keyword] = ACTIONS(9239),
    [sym_labels_keyword] = ACTIONS(9239),
    [sym_rendering_keyword] = ACTIONS(9239),
    [sym_requestpage_keyword] = ACTIONS(9239),
    [sym_schema_keyword] = ACTIONS(9239),
    [sym_views_keyword] = ACTIONS(9239),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9239),
    [sym_preproc_open] = ACTIONS(9239),
    [sym_preproc_close] = ACTIONS(9239),
  },
  [STATE(4092)] = {
    [anon_sym_SEMI] = ACTIONS(9243),
    [aux_sym_where_condition_token1] = ACTIONS(9245),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9243),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9243),
    [anon_sym_LBRACK] = ACTIONS(9243),
    [aux_sym_basic_type_token6] = ACTIONS(9245),
    [aux_sym_basic_type_token22] = ACTIONS(9245),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9243),
    [aux_sym_addafter_modification_token1] = ACTIONS(9243),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9243),
    [aux_sym_modify_modification_token1] = ACTIONS(9243),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9243),
    [aux_sym_movelast_modification_token1] = ACTIONS(9243),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9243),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9243),
    [aux_sym_separator_action_token1] = ACTIONS(9243),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9243),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9243),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9243),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9243),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9243),
    [anon_sym_POUNDif] = ACTIONS(9243),
    [anon_sym_POUNDIF] = ACTIONS(9243),
    [anon_sym_POUNDIf] = ACTIONS(9243),
    [anon_sym_POUNDelif] = ACTIONS(9243),
    [anon_sym_POUNDELIF] = ACTIONS(9243),
    [anon_sym_POUNDElif] = ACTIONS(9243),
    [anon_sym_POUNDelse] = ACTIONS(9243),
    [anon_sym_POUNDELSE] = ACTIONS(9243),
    [anon_sym_POUNDElse] = ACTIONS(9243),
    [anon_sym_POUNDelse2] = ACTIONS(9243),
    [anon_sym_POUNDELSE2] = ACTIONS(9243),
    [anon_sym_POUNDElse2] = ACTIONS(9243),
    [anon_sym_POUNDendif] = ACTIONS(9243),
    [anon_sym_POUNDENDIF] = ACTIONS(9243),
    [anon_sym_POUNDEndif] = ACTIONS(9243),
    [anon_sym_POUNDendif2] = ACTIONS(9243),
    [anon_sym_POUNDENDIF2] = ACTIONS(9243),
    [anon_sym_POUNDEndif2] = ACTIONS(9243),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9243),
    [sym_trigger_keyword] = ACTIONS(9243),
    [sym_var_keyword] = ACTIONS(9243),
    [sym_local_keyword] = ACTIONS(9243),
    [sym_internal_keyword] = ACTIONS(9243),
    [sym_protected_keyword] = ACTIONS(9243),
    [sym_event_keyword] = ACTIONS(9243),
    [sym_fields_keyword] = ACTIONS(9243),
    [sym_keys_keyword] = ACTIONS(9243),
    [sym_fieldgroups_keyword] = ACTIONS(9243),
    [sym_actions_keyword] = ACTIONS(9243),
    [sym_layout_keyword] = ACTIONS(9243),
    [sym_area_keyword] = ACTIONS(9243),
    [sym_group_keyword] = ACTIONS(9243),
    [sym_repeater_keyword] = ACTIONS(9243),
    [sym_cuegroup_keyword] = ACTIONS(9243),
    [sym_fixed_keyword] = ACTIONS(9243),
    [sym_grid_keyword] = ACTIONS(9243),
    [sym_part_keyword] = ACTIONS(9243),
    [sym_systempart_keyword] = ACTIONS(9243),
    [sym_usercontrol_keyword] = ACTIONS(9243),
    [sym_dataset_keyword] = ACTIONS(9243),
    [sym_elements_keyword] = ACTIONS(9243),
    [sym_dataitem_keyword] = ACTIONS(9243),
    [sym_column_keyword] = ACTIONS(9243),
    [sym_filter_keyword] = ACTIONS(9243),
    [sym_labels_keyword] = ACTIONS(9243),
    [sym_rendering_keyword] = ACTIONS(9243),
    [sym_requestpage_keyword] = ACTIONS(9243),
    [sym_schema_keyword] = ACTIONS(9243),
    [sym_views_keyword] = ACTIONS(9243),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9243),
    [sym_preproc_open] = ACTIONS(9243),
    [sym_preproc_close] = ACTIONS(9243),
  },
  [STATE(4093)] = {
    [anon_sym_SEMI] = ACTIONS(9247),
    [aux_sym_where_condition_token1] = ACTIONS(9249),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9247),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9247),
    [anon_sym_LBRACK] = ACTIONS(9247),
    [aux_sym_basic_type_token6] = ACTIONS(9249),
    [aux_sym_basic_type_token22] = ACTIONS(9249),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9247),
    [aux_sym_addafter_modification_token1] = ACTIONS(9247),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9247),
    [aux_sym_modify_modification_token1] = ACTIONS(9247),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9247),
    [aux_sym_movelast_modification_token1] = ACTIONS(9247),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9247),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9247),
    [aux_sym_separator_action_token1] = ACTIONS(9247),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9247),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9247),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9247),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9247),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9247),
    [anon_sym_POUNDif] = ACTIONS(9247),
    [anon_sym_POUNDIF] = ACTIONS(9247),
    [anon_sym_POUNDIf] = ACTIONS(9247),
    [anon_sym_POUNDelif] = ACTIONS(9247),
    [anon_sym_POUNDELIF] = ACTIONS(9247),
    [anon_sym_POUNDElif] = ACTIONS(9247),
    [anon_sym_POUNDelse] = ACTIONS(9247),
    [anon_sym_POUNDELSE] = ACTIONS(9247),
    [anon_sym_POUNDElse] = ACTIONS(9247),
    [anon_sym_POUNDelse2] = ACTIONS(9247),
    [anon_sym_POUNDELSE2] = ACTIONS(9247),
    [anon_sym_POUNDElse2] = ACTIONS(9247),
    [anon_sym_POUNDendif] = ACTIONS(9247),
    [anon_sym_POUNDENDIF] = ACTIONS(9247),
    [anon_sym_POUNDEndif] = ACTIONS(9247),
    [anon_sym_POUNDendif2] = ACTIONS(9247),
    [anon_sym_POUNDENDIF2] = ACTIONS(9247),
    [anon_sym_POUNDEndif2] = ACTIONS(9247),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9247),
    [sym_trigger_keyword] = ACTIONS(9247),
    [sym_var_keyword] = ACTIONS(9247),
    [sym_local_keyword] = ACTIONS(9247),
    [sym_internal_keyword] = ACTIONS(9247),
    [sym_protected_keyword] = ACTIONS(9247),
    [sym_event_keyword] = ACTIONS(9247),
    [sym_fields_keyword] = ACTIONS(9247),
    [sym_keys_keyword] = ACTIONS(9247),
    [sym_fieldgroups_keyword] = ACTIONS(9247),
    [sym_actions_keyword] = ACTIONS(9247),
    [sym_layout_keyword] = ACTIONS(9247),
    [sym_area_keyword] = ACTIONS(9247),
    [sym_group_keyword] = ACTIONS(9247),
    [sym_repeater_keyword] = ACTIONS(9247),
    [sym_cuegroup_keyword] = ACTIONS(9247),
    [sym_fixed_keyword] = ACTIONS(9247),
    [sym_grid_keyword] = ACTIONS(9247),
    [sym_part_keyword] = ACTIONS(9247),
    [sym_systempart_keyword] = ACTIONS(9247),
    [sym_usercontrol_keyword] = ACTIONS(9247),
    [sym_dataset_keyword] = ACTIONS(9247),
    [sym_elements_keyword] = ACTIONS(9247),
    [sym_dataitem_keyword] = ACTIONS(9247),
    [sym_column_keyword] = ACTIONS(9247),
    [sym_filter_keyword] = ACTIONS(9247),
    [sym_labels_keyword] = ACTIONS(9247),
    [sym_rendering_keyword] = ACTIONS(9247),
    [sym_requestpage_keyword] = ACTIONS(9247),
    [sym_schema_keyword] = ACTIONS(9247),
    [sym_views_keyword] = ACTIONS(9247),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9247),
    [sym_preproc_open] = ACTIONS(9247),
    [sym_preproc_close] = ACTIONS(9247),
  },
  [STATE(4094)] = {
    [anon_sym_SEMI] = ACTIONS(9251),
    [aux_sym_where_condition_token1] = ACTIONS(9253),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9251),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9251),
    [anon_sym_LBRACK] = ACTIONS(9251),
    [aux_sym_basic_type_token6] = ACTIONS(9253),
    [aux_sym_basic_type_token22] = ACTIONS(9253),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9251),
    [aux_sym_addafter_modification_token1] = ACTIONS(9251),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9251),
    [aux_sym_modify_modification_token1] = ACTIONS(9251),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9251),
    [aux_sym_movelast_modification_token1] = ACTIONS(9251),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9251),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9251),
    [aux_sym_separator_action_token1] = ACTIONS(9251),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9251),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9251),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9251),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9251),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9251),
    [anon_sym_POUNDif] = ACTIONS(9251),
    [anon_sym_POUNDIF] = ACTIONS(9251),
    [anon_sym_POUNDIf] = ACTIONS(9251),
    [anon_sym_POUNDelif] = ACTIONS(9251),
    [anon_sym_POUNDELIF] = ACTIONS(9251),
    [anon_sym_POUNDElif] = ACTIONS(9251),
    [anon_sym_POUNDelse] = ACTIONS(9251),
    [anon_sym_POUNDELSE] = ACTIONS(9251),
    [anon_sym_POUNDElse] = ACTIONS(9251),
    [anon_sym_POUNDelse2] = ACTIONS(9251),
    [anon_sym_POUNDELSE2] = ACTIONS(9251),
    [anon_sym_POUNDElse2] = ACTIONS(9251),
    [anon_sym_POUNDendif] = ACTIONS(9251),
    [anon_sym_POUNDENDIF] = ACTIONS(9251),
    [anon_sym_POUNDEndif] = ACTIONS(9251),
    [anon_sym_POUNDendif2] = ACTIONS(9251),
    [anon_sym_POUNDENDIF2] = ACTIONS(9251),
    [anon_sym_POUNDEndif2] = ACTIONS(9251),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9251),
    [sym_trigger_keyword] = ACTIONS(9251),
    [sym_var_keyword] = ACTIONS(9251),
    [sym_local_keyword] = ACTIONS(9251),
    [sym_internal_keyword] = ACTIONS(9251),
    [sym_protected_keyword] = ACTIONS(9251),
    [sym_event_keyword] = ACTIONS(9251),
    [sym_fields_keyword] = ACTIONS(9251),
    [sym_keys_keyword] = ACTIONS(9251),
    [sym_fieldgroups_keyword] = ACTIONS(9251),
    [sym_actions_keyword] = ACTIONS(9251),
    [sym_layout_keyword] = ACTIONS(9251),
    [sym_area_keyword] = ACTIONS(9251),
    [sym_group_keyword] = ACTIONS(9251),
    [sym_repeater_keyword] = ACTIONS(9251),
    [sym_cuegroup_keyword] = ACTIONS(9251),
    [sym_fixed_keyword] = ACTIONS(9251),
    [sym_grid_keyword] = ACTIONS(9251),
    [sym_part_keyword] = ACTIONS(9251),
    [sym_systempart_keyword] = ACTIONS(9251),
    [sym_usercontrol_keyword] = ACTIONS(9251),
    [sym_dataset_keyword] = ACTIONS(9251),
    [sym_elements_keyword] = ACTIONS(9251),
    [sym_dataitem_keyword] = ACTIONS(9251),
    [sym_column_keyword] = ACTIONS(9251),
    [sym_filter_keyword] = ACTIONS(9251),
    [sym_labels_keyword] = ACTIONS(9251),
    [sym_rendering_keyword] = ACTIONS(9251),
    [sym_requestpage_keyword] = ACTIONS(9251),
    [sym_schema_keyword] = ACTIONS(9251),
    [sym_views_keyword] = ACTIONS(9251),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9251),
    [sym_preproc_open] = ACTIONS(9251),
    [sym_preproc_close] = ACTIONS(9251),
  },
  [STATE(4095)] = {
    [anon_sym_SEMI] = ACTIONS(9255),
    [aux_sym_where_condition_token1] = ACTIONS(9257),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9255),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9255),
    [anon_sym_LBRACK] = ACTIONS(9255),
    [aux_sym_basic_type_token6] = ACTIONS(9257),
    [aux_sym_basic_type_token22] = ACTIONS(9257),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9255),
    [aux_sym_addafter_modification_token1] = ACTIONS(9255),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9255),
    [aux_sym_modify_modification_token1] = ACTIONS(9255),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9255),
    [aux_sym_movelast_modification_token1] = ACTIONS(9255),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9255),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9255),
    [aux_sym_separator_action_token1] = ACTIONS(9255),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9255),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9255),
    [anon_sym_POUNDif] = ACTIONS(9255),
    [anon_sym_POUNDIF] = ACTIONS(9255),
    [anon_sym_POUNDIf] = ACTIONS(9255),
    [anon_sym_POUNDelif] = ACTIONS(9255),
    [anon_sym_POUNDELIF] = ACTIONS(9255),
    [anon_sym_POUNDElif] = ACTIONS(9255),
    [anon_sym_POUNDelse] = ACTIONS(9255),
    [anon_sym_POUNDELSE] = ACTIONS(9255),
    [anon_sym_POUNDElse] = ACTIONS(9255),
    [anon_sym_POUNDelse2] = ACTIONS(9255),
    [anon_sym_POUNDELSE2] = ACTIONS(9255),
    [anon_sym_POUNDElse2] = ACTIONS(9255),
    [anon_sym_POUNDendif] = ACTIONS(9255),
    [anon_sym_POUNDENDIF] = ACTIONS(9255),
    [anon_sym_POUNDEndif] = ACTIONS(9255),
    [anon_sym_POUNDendif2] = ACTIONS(9255),
    [anon_sym_POUNDENDIF2] = ACTIONS(9255),
    [anon_sym_POUNDEndif2] = ACTIONS(9255),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9255),
    [sym_trigger_keyword] = ACTIONS(9255),
    [sym_var_keyword] = ACTIONS(9255),
    [sym_local_keyword] = ACTIONS(9255),
    [sym_internal_keyword] = ACTIONS(9255),
    [sym_protected_keyword] = ACTIONS(9255),
    [sym_event_keyword] = ACTIONS(9255),
    [sym_fields_keyword] = ACTIONS(9255),
    [sym_keys_keyword] = ACTIONS(9255),
    [sym_fieldgroups_keyword] = ACTIONS(9255),
    [sym_actions_keyword] = ACTIONS(9255),
    [sym_layout_keyword] = ACTIONS(9255),
    [sym_area_keyword] = ACTIONS(9255),
    [sym_group_keyword] = ACTIONS(9255),
    [sym_repeater_keyword] = ACTIONS(9255),
    [sym_cuegroup_keyword] = ACTIONS(9255),
    [sym_fixed_keyword] = ACTIONS(9255),
    [sym_grid_keyword] = ACTIONS(9255),
    [sym_part_keyword] = ACTIONS(9255),
    [sym_systempart_keyword] = ACTIONS(9255),
    [sym_usercontrol_keyword] = ACTIONS(9255),
    [sym_dataset_keyword] = ACTIONS(9255),
    [sym_elements_keyword] = ACTIONS(9255),
    [sym_dataitem_keyword] = ACTIONS(9255),
    [sym_column_keyword] = ACTIONS(9255),
    [sym_filter_keyword] = ACTIONS(9255),
    [sym_labels_keyword] = ACTIONS(9255),
    [sym_rendering_keyword] = ACTIONS(9255),
    [sym_requestpage_keyword] = ACTIONS(9255),
    [sym_schema_keyword] = ACTIONS(9255),
    [sym_views_keyword] = ACTIONS(9255),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9255),
    [sym_preproc_open] = ACTIONS(9255),
    [sym_preproc_close] = ACTIONS(9255),
  },
  [STATE(4096)] = {
    [anon_sym_SEMI] = ACTIONS(9259),
    [aux_sym_where_condition_token1] = ACTIONS(9261),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9259),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9259),
    [anon_sym_LBRACK] = ACTIONS(9259),
    [aux_sym_basic_type_token6] = ACTIONS(9261),
    [aux_sym_basic_type_token22] = ACTIONS(9261),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9259),
    [aux_sym_addafter_modification_token1] = ACTIONS(9259),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9259),
    [aux_sym_modify_modification_token1] = ACTIONS(9259),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9259),
    [aux_sym_movelast_modification_token1] = ACTIONS(9259),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9259),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9259),
    [aux_sym_separator_action_token1] = ACTIONS(9259),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9259),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9259),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9259),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9259),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9259),
    [anon_sym_POUNDif] = ACTIONS(9259),
    [anon_sym_POUNDIF] = ACTIONS(9259),
    [anon_sym_POUNDIf] = ACTIONS(9259),
    [anon_sym_POUNDelif] = ACTIONS(9259),
    [anon_sym_POUNDELIF] = ACTIONS(9259),
    [anon_sym_POUNDElif] = ACTIONS(9259),
    [anon_sym_POUNDelse] = ACTIONS(9259),
    [anon_sym_POUNDELSE] = ACTIONS(9259),
    [anon_sym_POUNDElse] = ACTIONS(9259),
    [anon_sym_POUNDelse2] = ACTIONS(9259),
    [anon_sym_POUNDELSE2] = ACTIONS(9259),
    [anon_sym_POUNDElse2] = ACTIONS(9259),
    [anon_sym_POUNDendif] = ACTIONS(9259),
    [anon_sym_POUNDENDIF] = ACTIONS(9259),
    [anon_sym_POUNDEndif] = ACTIONS(9259),
    [anon_sym_POUNDendif2] = ACTIONS(9259),
    [anon_sym_POUNDENDIF2] = ACTIONS(9259),
    [anon_sym_POUNDEndif2] = ACTIONS(9259),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9259),
    [sym_trigger_keyword] = ACTIONS(9259),
    [sym_var_keyword] = ACTIONS(9259),
    [sym_local_keyword] = ACTIONS(9259),
    [sym_internal_keyword] = ACTIONS(9259),
    [sym_protected_keyword] = ACTIONS(9259),
    [sym_event_keyword] = ACTIONS(9259),
    [sym_fields_keyword] = ACTIONS(9259),
    [sym_keys_keyword] = ACTIONS(9259),
    [sym_fieldgroups_keyword] = ACTIONS(9259),
    [sym_actions_keyword] = ACTIONS(9259),
    [sym_layout_keyword] = ACTIONS(9259),
    [sym_area_keyword] = ACTIONS(9259),
    [sym_group_keyword] = ACTIONS(9259),
    [sym_repeater_keyword] = ACTIONS(9259),
    [sym_cuegroup_keyword] = ACTIONS(9259),
    [sym_fixed_keyword] = ACTIONS(9259),
    [sym_grid_keyword] = ACTIONS(9259),
    [sym_part_keyword] = ACTIONS(9259),
    [sym_systempart_keyword] = ACTIONS(9259),
    [sym_usercontrol_keyword] = ACTIONS(9259),
    [sym_dataset_keyword] = ACTIONS(9259),
    [sym_elements_keyword] = ACTIONS(9259),
    [sym_dataitem_keyword] = ACTIONS(9259),
    [sym_column_keyword] = ACTIONS(9259),
    [sym_filter_keyword] = ACTIONS(9259),
    [sym_labels_keyword] = ACTIONS(9259),
    [sym_rendering_keyword] = ACTIONS(9259),
    [sym_requestpage_keyword] = ACTIONS(9259),
    [sym_schema_keyword] = ACTIONS(9259),
    [sym_views_keyword] = ACTIONS(9259),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9259),
    [sym_preproc_open] = ACTIONS(9259),
    [sym_preproc_close] = ACTIONS(9259),
  },
  [STATE(4097)] = {
    [anon_sym_SEMI] = ACTIONS(9255),
    [aux_sym_where_condition_token1] = ACTIONS(9257),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9255),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9255),
    [anon_sym_LBRACK] = ACTIONS(9255),
    [aux_sym_basic_type_token6] = ACTIONS(9257),
    [aux_sym_basic_type_token22] = ACTIONS(9257),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9255),
    [aux_sym_addafter_modification_token1] = ACTIONS(9255),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9255),
    [aux_sym_modify_modification_token1] = ACTIONS(9255),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9255),
    [aux_sym_movelast_modification_token1] = ACTIONS(9255),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9255),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9255),
    [aux_sym_separator_action_token1] = ACTIONS(9255),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9255),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9255),
    [anon_sym_POUNDif] = ACTIONS(9255),
    [anon_sym_POUNDIF] = ACTIONS(9255),
    [anon_sym_POUNDIf] = ACTIONS(9255),
    [anon_sym_POUNDelif] = ACTIONS(9255),
    [anon_sym_POUNDELIF] = ACTIONS(9255),
    [anon_sym_POUNDElif] = ACTIONS(9255),
    [anon_sym_POUNDelse] = ACTIONS(9255),
    [anon_sym_POUNDELSE] = ACTIONS(9255),
    [anon_sym_POUNDElse] = ACTIONS(9255),
    [anon_sym_POUNDelse2] = ACTIONS(9255),
    [anon_sym_POUNDELSE2] = ACTIONS(9255),
    [anon_sym_POUNDElse2] = ACTIONS(9255),
    [anon_sym_POUNDendif] = ACTIONS(9255),
    [anon_sym_POUNDENDIF] = ACTIONS(9255),
    [anon_sym_POUNDEndif] = ACTIONS(9255),
    [anon_sym_POUNDendif2] = ACTIONS(9255),
    [anon_sym_POUNDENDIF2] = ACTIONS(9255),
    [anon_sym_POUNDEndif2] = ACTIONS(9255),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9255),
    [sym_trigger_keyword] = ACTIONS(9255),
    [sym_var_keyword] = ACTIONS(9255),
    [sym_local_keyword] = ACTIONS(9255),
    [sym_internal_keyword] = ACTIONS(9255),
    [sym_protected_keyword] = ACTIONS(9255),
    [sym_event_keyword] = ACTIONS(9255),
    [sym_fields_keyword] = ACTIONS(9255),
    [sym_keys_keyword] = ACTIONS(9255),
    [sym_fieldgroups_keyword] = ACTIONS(9255),
    [sym_actions_keyword] = ACTIONS(9255),
    [sym_layout_keyword] = ACTIONS(9255),
    [sym_area_keyword] = ACTIONS(9255),
    [sym_group_keyword] = ACTIONS(9255),
    [sym_repeater_keyword] = ACTIONS(9255),
    [sym_cuegroup_keyword] = ACTIONS(9255),
    [sym_fixed_keyword] = ACTIONS(9255),
    [sym_grid_keyword] = ACTIONS(9255),
    [sym_part_keyword] = ACTIONS(9255),
    [sym_systempart_keyword] = ACTIONS(9255),
    [sym_usercontrol_keyword] = ACTIONS(9255),
    [sym_dataset_keyword] = ACTIONS(9255),
    [sym_elements_keyword] = ACTIONS(9255),
    [sym_dataitem_keyword] = ACTIONS(9255),
    [sym_column_keyword] = ACTIONS(9255),
    [sym_filter_keyword] = ACTIONS(9255),
    [sym_labels_keyword] = ACTIONS(9255),
    [sym_rendering_keyword] = ACTIONS(9255),
    [sym_requestpage_keyword] = ACTIONS(9255),
    [sym_schema_keyword] = ACTIONS(9255),
    [sym_views_keyword] = ACTIONS(9255),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9255),
    [sym_preproc_open] = ACTIONS(9255),
    [sym_preproc_close] = ACTIONS(9255),
  },
  [STATE(4098)] = {
    [anon_sym_SEMI] = ACTIONS(9263),
    [aux_sym_where_condition_token1] = ACTIONS(9265),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9263),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9263),
    [anon_sym_LBRACK] = ACTIONS(9263),
    [aux_sym_basic_type_token6] = ACTIONS(9265),
    [aux_sym_basic_type_token22] = ACTIONS(9265),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9263),
    [aux_sym_addafter_modification_token1] = ACTIONS(9263),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9263),
    [aux_sym_modify_modification_token1] = ACTIONS(9263),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9263),
    [aux_sym_movelast_modification_token1] = ACTIONS(9263),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9263),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9263),
    [aux_sym_separator_action_token1] = ACTIONS(9263),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9263),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9263),
    [anon_sym_POUNDif] = ACTIONS(9263),
    [anon_sym_POUNDIF] = ACTIONS(9263),
    [anon_sym_POUNDIf] = ACTIONS(9263),
    [anon_sym_POUNDelif] = ACTIONS(9263),
    [anon_sym_POUNDELIF] = ACTIONS(9263),
    [anon_sym_POUNDElif] = ACTIONS(9263),
    [anon_sym_POUNDelse] = ACTIONS(9263),
    [anon_sym_POUNDELSE] = ACTIONS(9263),
    [anon_sym_POUNDElse] = ACTIONS(9263),
    [anon_sym_POUNDelse2] = ACTIONS(9263),
    [anon_sym_POUNDELSE2] = ACTIONS(9263),
    [anon_sym_POUNDElse2] = ACTIONS(9263),
    [anon_sym_POUNDendif] = ACTIONS(9263),
    [anon_sym_POUNDENDIF] = ACTIONS(9263),
    [anon_sym_POUNDEndif] = ACTIONS(9263),
    [anon_sym_POUNDendif2] = ACTIONS(9263),
    [anon_sym_POUNDENDIF2] = ACTIONS(9263),
    [anon_sym_POUNDEndif2] = ACTIONS(9263),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9263),
    [sym_trigger_keyword] = ACTIONS(9263),
    [sym_var_keyword] = ACTIONS(9263),
    [sym_local_keyword] = ACTIONS(9263),
    [sym_internal_keyword] = ACTIONS(9263),
    [sym_protected_keyword] = ACTIONS(9263),
    [sym_event_keyword] = ACTIONS(9263),
    [sym_fields_keyword] = ACTIONS(9263),
    [sym_keys_keyword] = ACTIONS(9263),
    [sym_fieldgroups_keyword] = ACTIONS(9263),
    [sym_actions_keyword] = ACTIONS(9263),
    [sym_layout_keyword] = ACTIONS(9263),
    [sym_area_keyword] = ACTIONS(9263),
    [sym_group_keyword] = ACTIONS(9263),
    [sym_repeater_keyword] = ACTIONS(9263),
    [sym_cuegroup_keyword] = ACTIONS(9263),
    [sym_fixed_keyword] = ACTIONS(9263),
    [sym_grid_keyword] = ACTIONS(9263),
    [sym_part_keyword] = ACTIONS(9263),
    [sym_systempart_keyword] = ACTIONS(9263),
    [sym_usercontrol_keyword] = ACTIONS(9263),
    [sym_dataset_keyword] = ACTIONS(9263),
    [sym_elements_keyword] = ACTIONS(9263),
    [sym_dataitem_keyword] = ACTIONS(9263),
    [sym_column_keyword] = ACTIONS(9263),
    [sym_filter_keyword] = ACTIONS(9263),
    [sym_labels_keyword] = ACTIONS(9263),
    [sym_rendering_keyword] = ACTIONS(9263),
    [sym_requestpage_keyword] = ACTIONS(9263),
    [sym_schema_keyword] = ACTIONS(9263),
    [sym_views_keyword] = ACTIONS(9263),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9263),
    [sym_preproc_open] = ACTIONS(9263),
    [sym_preproc_close] = ACTIONS(9263),
  },
  [STATE(4099)] = {
    [anon_sym_SEMI] = ACTIONS(9263),
    [aux_sym_where_condition_token1] = ACTIONS(9265),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9263),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9263),
    [anon_sym_LBRACK] = ACTIONS(9263),
    [aux_sym_basic_type_token6] = ACTIONS(9265),
    [aux_sym_basic_type_token22] = ACTIONS(9265),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9263),
    [aux_sym_addafter_modification_token1] = ACTIONS(9263),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9263),
    [aux_sym_modify_modification_token1] = ACTIONS(9263),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9263),
    [aux_sym_movelast_modification_token1] = ACTIONS(9263),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9263),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9263),
    [aux_sym_separator_action_token1] = ACTIONS(9263),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9263),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9263),
    [anon_sym_POUNDif] = ACTIONS(9263),
    [anon_sym_POUNDIF] = ACTIONS(9263),
    [anon_sym_POUNDIf] = ACTIONS(9263),
    [anon_sym_POUNDelif] = ACTIONS(9263),
    [anon_sym_POUNDELIF] = ACTIONS(9263),
    [anon_sym_POUNDElif] = ACTIONS(9263),
    [anon_sym_POUNDelse] = ACTIONS(9263),
    [anon_sym_POUNDELSE] = ACTIONS(9263),
    [anon_sym_POUNDElse] = ACTIONS(9263),
    [anon_sym_POUNDelse2] = ACTIONS(9263),
    [anon_sym_POUNDELSE2] = ACTIONS(9263),
    [anon_sym_POUNDElse2] = ACTIONS(9263),
    [anon_sym_POUNDendif] = ACTIONS(9263),
    [anon_sym_POUNDENDIF] = ACTIONS(9263),
    [anon_sym_POUNDEndif] = ACTIONS(9263),
    [anon_sym_POUNDendif2] = ACTIONS(9263),
    [anon_sym_POUNDENDIF2] = ACTIONS(9263),
    [anon_sym_POUNDEndif2] = ACTIONS(9263),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9263),
    [sym_trigger_keyword] = ACTIONS(9263),
    [sym_var_keyword] = ACTIONS(9263),
    [sym_local_keyword] = ACTIONS(9263),
    [sym_internal_keyword] = ACTIONS(9263),
    [sym_protected_keyword] = ACTIONS(9263),
    [sym_event_keyword] = ACTIONS(9263),
    [sym_fields_keyword] = ACTIONS(9263),
    [sym_keys_keyword] = ACTIONS(9263),
    [sym_fieldgroups_keyword] = ACTIONS(9263),
    [sym_actions_keyword] = ACTIONS(9263),
    [sym_layout_keyword] = ACTIONS(9263),
    [sym_area_keyword] = ACTIONS(9263),
    [sym_group_keyword] = ACTIONS(9263),
    [sym_repeater_keyword] = ACTIONS(9263),
    [sym_cuegroup_keyword] = ACTIONS(9263),
    [sym_fixed_keyword] = ACTIONS(9263),
    [sym_grid_keyword] = ACTIONS(9263),
    [sym_part_keyword] = ACTIONS(9263),
    [sym_systempart_keyword] = ACTIONS(9263),
    [sym_usercontrol_keyword] = ACTIONS(9263),
    [sym_dataset_keyword] = ACTIONS(9263),
    [sym_elements_keyword] = ACTIONS(9263),
    [sym_dataitem_keyword] = ACTIONS(9263),
    [sym_column_keyword] = ACTIONS(9263),
    [sym_filter_keyword] = ACTIONS(9263),
    [sym_labels_keyword] = ACTIONS(9263),
    [sym_rendering_keyword] = ACTIONS(9263),
    [sym_requestpage_keyword] = ACTIONS(9263),
    [sym_schema_keyword] = ACTIONS(9263),
    [sym_views_keyword] = ACTIONS(9263),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9263),
    [sym_preproc_open] = ACTIONS(9263),
    [sym_preproc_close] = ACTIONS(9263),
  },
  [STATE(4100)] = {
    [anon_sym_SEMI] = ACTIONS(9267),
    [aux_sym_where_condition_token1] = ACTIONS(9269),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9267),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9267),
    [anon_sym_LBRACK] = ACTIONS(9267),
    [aux_sym_basic_type_token6] = ACTIONS(9269),
    [aux_sym_basic_type_token22] = ACTIONS(9269),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9267),
    [aux_sym_addafter_modification_token1] = ACTIONS(9267),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9267),
    [aux_sym_modify_modification_token1] = ACTIONS(9267),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9267),
    [aux_sym_movelast_modification_token1] = ACTIONS(9267),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9267),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9267),
    [aux_sym_separator_action_token1] = ACTIONS(9267),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9267),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9267),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9267),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9267),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9267),
    [anon_sym_POUNDif] = ACTIONS(9267),
    [anon_sym_POUNDIF] = ACTIONS(9267),
    [anon_sym_POUNDIf] = ACTIONS(9267),
    [anon_sym_POUNDelif] = ACTIONS(9267),
    [anon_sym_POUNDELIF] = ACTIONS(9267),
    [anon_sym_POUNDElif] = ACTIONS(9267),
    [anon_sym_POUNDelse] = ACTIONS(9267),
    [anon_sym_POUNDELSE] = ACTIONS(9267),
    [anon_sym_POUNDElse] = ACTIONS(9267),
    [anon_sym_POUNDelse2] = ACTIONS(9267),
    [anon_sym_POUNDELSE2] = ACTIONS(9267),
    [anon_sym_POUNDElse2] = ACTIONS(9267),
    [anon_sym_POUNDendif] = ACTIONS(9267),
    [anon_sym_POUNDENDIF] = ACTIONS(9267),
    [anon_sym_POUNDEndif] = ACTIONS(9267),
    [anon_sym_POUNDendif2] = ACTIONS(9267),
    [anon_sym_POUNDENDIF2] = ACTIONS(9267),
    [anon_sym_POUNDEndif2] = ACTIONS(9267),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9267),
    [sym_trigger_keyword] = ACTIONS(9267),
    [sym_var_keyword] = ACTIONS(9267),
    [sym_local_keyword] = ACTIONS(9267),
    [sym_internal_keyword] = ACTIONS(9267),
    [sym_protected_keyword] = ACTIONS(9267),
    [sym_event_keyword] = ACTIONS(9267),
    [sym_fields_keyword] = ACTIONS(9267),
    [sym_keys_keyword] = ACTIONS(9267),
    [sym_fieldgroups_keyword] = ACTIONS(9267),
    [sym_actions_keyword] = ACTIONS(9267),
    [sym_layout_keyword] = ACTIONS(9267),
    [sym_area_keyword] = ACTIONS(9267),
    [sym_group_keyword] = ACTIONS(9267),
    [sym_repeater_keyword] = ACTIONS(9267),
    [sym_cuegroup_keyword] = ACTIONS(9267),
    [sym_fixed_keyword] = ACTIONS(9267),
    [sym_grid_keyword] = ACTIONS(9267),
    [sym_part_keyword] = ACTIONS(9267),
    [sym_systempart_keyword] = ACTIONS(9267),
    [sym_usercontrol_keyword] = ACTIONS(9267),
    [sym_dataset_keyword] = ACTIONS(9267),
    [sym_elements_keyword] = ACTIONS(9267),
    [sym_dataitem_keyword] = ACTIONS(9267),
    [sym_column_keyword] = ACTIONS(9267),
    [sym_filter_keyword] = ACTIONS(9267),
    [sym_labels_keyword] = ACTIONS(9267),
    [sym_rendering_keyword] = ACTIONS(9267),
    [sym_requestpage_keyword] = ACTIONS(9267),
    [sym_schema_keyword] = ACTIONS(9267),
    [sym_views_keyword] = ACTIONS(9267),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9267),
    [sym_preproc_open] = ACTIONS(9267),
    [sym_preproc_close] = ACTIONS(9267),
  },
  [STATE(4101)] = {
    [anon_sym_SEMI] = ACTIONS(9263),
    [aux_sym_where_condition_token1] = ACTIONS(9265),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9263),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9263),
    [anon_sym_LBRACK] = ACTIONS(9263),
    [aux_sym_basic_type_token6] = ACTIONS(9265),
    [aux_sym_basic_type_token22] = ACTIONS(9265),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9263),
    [aux_sym_addafter_modification_token1] = ACTIONS(9263),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9263),
    [aux_sym_modify_modification_token1] = ACTIONS(9263),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9263),
    [aux_sym_movelast_modification_token1] = ACTIONS(9263),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9263),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9263),
    [aux_sym_separator_action_token1] = ACTIONS(9263),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9263),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9263),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9263),
    [anon_sym_POUNDif] = ACTIONS(9263),
    [anon_sym_POUNDIF] = ACTIONS(9263),
    [anon_sym_POUNDIf] = ACTIONS(9263),
    [anon_sym_POUNDelif] = ACTIONS(9263),
    [anon_sym_POUNDELIF] = ACTIONS(9263),
    [anon_sym_POUNDElif] = ACTIONS(9263),
    [anon_sym_POUNDelse] = ACTIONS(9263),
    [anon_sym_POUNDELSE] = ACTIONS(9263),
    [anon_sym_POUNDElse] = ACTIONS(9263),
    [anon_sym_POUNDelse2] = ACTIONS(9263),
    [anon_sym_POUNDELSE2] = ACTIONS(9263),
    [anon_sym_POUNDElse2] = ACTIONS(9263),
    [anon_sym_POUNDendif] = ACTIONS(9263),
    [anon_sym_POUNDENDIF] = ACTIONS(9263),
    [anon_sym_POUNDEndif] = ACTIONS(9263),
    [anon_sym_POUNDendif2] = ACTIONS(9263),
    [anon_sym_POUNDENDIF2] = ACTIONS(9263),
    [anon_sym_POUNDEndif2] = ACTIONS(9263),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9263),
    [sym_trigger_keyword] = ACTIONS(9263),
    [sym_var_keyword] = ACTIONS(9263),
    [sym_local_keyword] = ACTIONS(9263),
    [sym_internal_keyword] = ACTIONS(9263),
    [sym_protected_keyword] = ACTIONS(9263),
    [sym_event_keyword] = ACTIONS(9263),
    [sym_fields_keyword] = ACTIONS(9263),
    [sym_keys_keyword] = ACTIONS(9263),
    [sym_fieldgroups_keyword] = ACTIONS(9263),
    [sym_actions_keyword] = ACTIONS(9263),
    [sym_layout_keyword] = ACTIONS(9263),
    [sym_area_keyword] = ACTIONS(9263),
    [sym_group_keyword] = ACTIONS(9263),
    [sym_repeater_keyword] = ACTIONS(9263),
    [sym_cuegroup_keyword] = ACTIONS(9263),
    [sym_fixed_keyword] = ACTIONS(9263),
    [sym_grid_keyword] = ACTIONS(9263),
    [sym_part_keyword] = ACTIONS(9263),
    [sym_systempart_keyword] = ACTIONS(9263),
    [sym_usercontrol_keyword] = ACTIONS(9263),
    [sym_dataset_keyword] = ACTIONS(9263),
    [sym_elements_keyword] = ACTIONS(9263),
    [sym_dataitem_keyword] = ACTIONS(9263),
    [sym_column_keyword] = ACTIONS(9263),
    [sym_filter_keyword] = ACTIONS(9263),
    [sym_labels_keyword] = ACTIONS(9263),
    [sym_rendering_keyword] = ACTIONS(9263),
    [sym_requestpage_keyword] = ACTIONS(9263),
    [sym_schema_keyword] = ACTIONS(9263),
    [sym_views_keyword] = ACTIONS(9263),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9263),
    [sym_preproc_open] = ACTIONS(9263),
    [sym_preproc_close] = ACTIONS(9263),
  },
  [STATE(4102)] = {
    [anon_sym_SEMI] = ACTIONS(9271),
    [aux_sym_where_condition_token1] = ACTIONS(9273),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9271),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9271),
    [anon_sym_LBRACK] = ACTIONS(9271),
    [aux_sym_basic_type_token6] = ACTIONS(9273),
    [aux_sym_basic_type_token22] = ACTIONS(9273),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9271),
    [aux_sym_addafter_modification_token1] = ACTIONS(9271),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9271),
    [aux_sym_modify_modification_token1] = ACTIONS(9271),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9271),
    [aux_sym_movelast_modification_token1] = ACTIONS(9271),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9271),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9271),
    [aux_sym_separator_action_token1] = ACTIONS(9271),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9271),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9271),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9271),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9271),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9271),
    [anon_sym_POUNDif] = ACTIONS(9271),
    [anon_sym_POUNDIF] = ACTIONS(9271),
    [anon_sym_POUNDIf] = ACTIONS(9271),
    [anon_sym_POUNDelif] = ACTIONS(9271),
    [anon_sym_POUNDELIF] = ACTIONS(9271),
    [anon_sym_POUNDElif] = ACTIONS(9271),
    [anon_sym_POUNDelse] = ACTIONS(9271),
    [anon_sym_POUNDELSE] = ACTIONS(9271),
    [anon_sym_POUNDElse] = ACTIONS(9271),
    [anon_sym_POUNDelse2] = ACTIONS(9271),
    [anon_sym_POUNDELSE2] = ACTIONS(9271),
    [anon_sym_POUNDElse2] = ACTIONS(9271),
    [anon_sym_POUNDendif] = ACTIONS(9271),
    [anon_sym_POUNDENDIF] = ACTIONS(9271),
    [anon_sym_POUNDEndif] = ACTIONS(9271),
    [anon_sym_POUNDendif2] = ACTIONS(9271),
    [anon_sym_POUNDENDIF2] = ACTIONS(9271),
    [anon_sym_POUNDEndif2] = ACTIONS(9271),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9271),
    [sym_trigger_keyword] = ACTIONS(9271),
    [sym_var_keyword] = ACTIONS(9271),
    [sym_local_keyword] = ACTIONS(9271),
    [sym_internal_keyword] = ACTIONS(9271),
    [sym_protected_keyword] = ACTIONS(9271),
    [sym_event_keyword] = ACTIONS(9271),
    [sym_fields_keyword] = ACTIONS(9271),
    [sym_keys_keyword] = ACTIONS(9271),
    [sym_fieldgroups_keyword] = ACTIONS(9271),
    [sym_actions_keyword] = ACTIONS(9271),
    [sym_layout_keyword] = ACTIONS(9271),
    [sym_area_keyword] = ACTIONS(9271),
    [sym_group_keyword] = ACTIONS(9271),
    [sym_repeater_keyword] = ACTIONS(9271),
    [sym_cuegroup_keyword] = ACTIONS(9271),
    [sym_fixed_keyword] = ACTIONS(9271),
    [sym_grid_keyword] = ACTIONS(9271),
    [sym_part_keyword] = ACTIONS(9271),
    [sym_systempart_keyword] = ACTIONS(9271),
    [sym_usercontrol_keyword] = ACTIONS(9271),
    [sym_dataset_keyword] = ACTIONS(9271),
    [sym_elements_keyword] = ACTIONS(9271),
    [sym_dataitem_keyword] = ACTIONS(9271),
    [sym_column_keyword] = ACTIONS(9271),
    [sym_filter_keyword] = ACTIONS(9271),
    [sym_labels_keyword] = ACTIONS(9271),
    [sym_rendering_keyword] = ACTIONS(9271),
    [sym_requestpage_keyword] = ACTIONS(9271),
    [sym_schema_keyword] = ACTIONS(9271),
    [sym_views_keyword] = ACTIONS(9271),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9271),
    [sym_preproc_open] = ACTIONS(9271),
    [sym_preproc_close] = ACTIONS(9271),
  },
  [STATE(4103)] = {
    [anon_sym_SEMI] = ACTIONS(9275),
    [aux_sym_where_condition_token1] = ACTIONS(9277),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9275),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9275),
    [anon_sym_LBRACK] = ACTIONS(9275),
    [aux_sym_basic_type_token6] = ACTIONS(9277),
    [aux_sym_basic_type_token22] = ACTIONS(9277),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9275),
    [aux_sym_addafter_modification_token1] = ACTIONS(9275),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9275),
    [aux_sym_modify_modification_token1] = ACTIONS(9275),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9275),
    [aux_sym_movelast_modification_token1] = ACTIONS(9275),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9275),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9275),
    [aux_sym_separator_action_token1] = ACTIONS(9275),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9275),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9275),
    [anon_sym_POUNDif] = ACTIONS(9275),
    [anon_sym_POUNDIF] = ACTIONS(9275),
    [anon_sym_POUNDIf] = ACTIONS(9275),
    [anon_sym_POUNDelif] = ACTIONS(9275),
    [anon_sym_POUNDELIF] = ACTIONS(9275),
    [anon_sym_POUNDElif] = ACTIONS(9275),
    [anon_sym_POUNDelse] = ACTIONS(9275),
    [anon_sym_POUNDELSE] = ACTIONS(9275),
    [anon_sym_POUNDElse] = ACTIONS(9275),
    [anon_sym_POUNDelse2] = ACTIONS(9275),
    [anon_sym_POUNDELSE2] = ACTIONS(9275),
    [anon_sym_POUNDElse2] = ACTIONS(9275),
    [anon_sym_POUNDendif] = ACTIONS(9275),
    [anon_sym_POUNDENDIF] = ACTIONS(9275),
    [anon_sym_POUNDEndif] = ACTIONS(9275),
    [anon_sym_POUNDendif2] = ACTIONS(9275),
    [anon_sym_POUNDENDIF2] = ACTIONS(9275),
    [anon_sym_POUNDEndif2] = ACTIONS(9275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9275),
    [sym_trigger_keyword] = ACTIONS(9275),
    [sym_var_keyword] = ACTIONS(9275),
    [sym_local_keyword] = ACTIONS(9275),
    [sym_internal_keyword] = ACTIONS(9275),
    [sym_protected_keyword] = ACTIONS(9275),
    [sym_event_keyword] = ACTIONS(9275),
    [sym_fields_keyword] = ACTIONS(9275),
    [sym_keys_keyword] = ACTIONS(9275),
    [sym_fieldgroups_keyword] = ACTIONS(9275),
    [sym_actions_keyword] = ACTIONS(9275),
    [sym_layout_keyword] = ACTIONS(9275),
    [sym_area_keyword] = ACTIONS(9275),
    [sym_group_keyword] = ACTIONS(9275),
    [sym_repeater_keyword] = ACTIONS(9275),
    [sym_cuegroup_keyword] = ACTIONS(9275),
    [sym_fixed_keyword] = ACTIONS(9275),
    [sym_grid_keyword] = ACTIONS(9275),
    [sym_part_keyword] = ACTIONS(9275),
    [sym_systempart_keyword] = ACTIONS(9275),
    [sym_usercontrol_keyword] = ACTIONS(9275),
    [sym_dataset_keyword] = ACTIONS(9275),
    [sym_elements_keyword] = ACTIONS(9275),
    [sym_dataitem_keyword] = ACTIONS(9275),
    [sym_column_keyword] = ACTIONS(9275),
    [sym_filter_keyword] = ACTIONS(9275),
    [sym_labels_keyword] = ACTIONS(9275),
    [sym_rendering_keyword] = ACTIONS(9275),
    [sym_requestpage_keyword] = ACTIONS(9275),
    [sym_schema_keyword] = ACTIONS(9275),
    [sym_views_keyword] = ACTIONS(9275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9275),
    [sym_preproc_open] = ACTIONS(9275),
    [sym_preproc_close] = ACTIONS(9275),
  },
  [STATE(4104)] = {
    [anon_sym_SEMI] = ACTIONS(9279),
    [aux_sym_where_condition_token1] = ACTIONS(9281),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9279),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9279),
    [anon_sym_LBRACK] = ACTIONS(9279),
    [aux_sym_basic_type_token6] = ACTIONS(9281),
    [aux_sym_basic_type_token22] = ACTIONS(9281),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9279),
    [aux_sym_addafter_modification_token1] = ACTIONS(9279),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9279),
    [aux_sym_modify_modification_token1] = ACTIONS(9279),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9279),
    [aux_sym_movelast_modification_token1] = ACTIONS(9279),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9279),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9279),
    [aux_sym_separator_action_token1] = ACTIONS(9279),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9279),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9279),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9279),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9279),
    [anon_sym_POUNDif] = ACTIONS(9279),
    [anon_sym_POUNDIF] = ACTIONS(9279),
    [anon_sym_POUNDIf] = ACTIONS(9279),
    [anon_sym_POUNDelif] = ACTIONS(9279),
    [anon_sym_POUNDELIF] = ACTIONS(9279),
    [anon_sym_POUNDElif] = ACTIONS(9279),
    [anon_sym_POUNDelse] = ACTIONS(9279),
    [anon_sym_POUNDELSE] = ACTIONS(9279),
    [anon_sym_POUNDElse] = ACTIONS(9279),
    [anon_sym_POUNDelse2] = ACTIONS(9279),
    [anon_sym_POUNDELSE2] = ACTIONS(9279),
    [anon_sym_POUNDElse2] = ACTIONS(9279),
    [anon_sym_POUNDendif] = ACTIONS(9279),
    [anon_sym_POUNDENDIF] = ACTIONS(9279),
    [anon_sym_POUNDEndif] = ACTIONS(9279),
    [anon_sym_POUNDendif2] = ACTIONS(9279),
    [anon_sym_POUNDENDIF2] = ACTIONS(9279),
    [anon_sym_POUNDEndif2] = ACTIONS(9279),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9279),
    [sym_trigger_keyword] = ACTIONS(9279),
    [sym_var_keyword] = ACTIONS(9279),
    [sym_local_keyword] = ACTIONS(9279),
    [sym_internal_keyword] = ACTIONS(9279),
    [sym_protected_keyword] = ACTIONS(9279),
    [sym_event_keyword] = ACTIONS(9279),
    [sym_fields_keyword] = ACTIONS(9279),
    [sym_keys_keyword] = ACTIONS(9279),
    [sym_fieldgroups_keyword] = ACTIONS(9279),
    [sym_actions_keyword] = ACTIONS(9279),
    [sym_layout_keyword] = ACTIONS(9279),
    [sym_area_keyword] = ACTIONS(9279),
    [sym_group_keyword] = ACTIONS(9279),
    [sym_repeater_keyword] = ACTIONS(9279),
    [sym_cuegroup_keyword] = ACTIONS(9279),
    [sym_fixed_keyword] = ACTIONS(9279),
    [sym_grid_keyword] = ACTIONS(9279),
    [sym_part_keyword] = ACTIONS(9279),
    [sym_systempart_keyword] = ACTIONS(9279),
    [sym_usercontrol_keyword] = ACTIONS(9279),
    [sym_dataset_keyword] = ACTIONS(9279),
    [sym_elements_keyword] = ACTIONS(9279),
    [sym_dataitem_keyword] = ACTIONS(9279),
    [sym_column_keyword] = ACTIONS(9279),
    [sym_filter_keyword] = ACTIONS(9279),
    [sym_labels_keyword] = ACTIONS(9279),
    [sym_rendering_keyword] = ACTIONS(9279),
    [sym_requestpage_keyword] = ACTIONS(9279),
    [sym_schema_keyword] = ACTIONS(9279),
    [sym_views_keyword] = ACTIONS(9279),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9279),
    [sym_preproc_open] = ACTIONS(9279),
    [sym_preproc_close] = ACTIONS(9279),
  },
  [STATE(4105)] = {
    [anon_sym_SEMI] = ACTIONS(9283),
    [aux_sym_where_condition_token1] = ACTIONS(9285),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9283),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9283),
    [anon_sym_LBRACK] = ACTIONS(9283),
    [aux_sym_basic_type_token6] = ACTIONS(9285),
    [aux_sym_basic_type_token22] = ACTIONS(9285),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9283),
    [aux_sym_addafter_modification_token1] = ACTIONS(9283),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9283),
    [aux_sym_modify_modification_token1] = ACTIONS(9283),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9283),
    [aux_sym_movelast_modification_token1] = ACTIONS(9283),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9283),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9283),
    [aux_sym_separator_action_token1] = ACTIONS(9283),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9283),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9283),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9283),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9283),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9283),
    [anon_sym_POUNDif] = ACTIONS(9283),
    [anon_sym_POUNDIF] = ACTIONS(9283),
    [anon_sym_POUNDIf] = ACTIONS(9283),
    [anon_sym_POUNDelif] = ACTIONS(9283),
    [anon_sym_POUNDELIF] = ACTIONS(9283),
    [anon_sym_POUNDElif] = ACTIONS(9283),
    [anon_sym_POUNDelse] = ACTIONS(9283),
    [anon_sym_POUNDELSE] = ACTIONS(9283),
    [anon_sym_POUNDElse] = ACTIONS(9283),
    [anon_sym_POUNDelse2] = ACTIONS(9283),
    [anon_sym_POUNDELSE2] = ACTIONS(9283),
    [anon_sym_POUNDElse2] = ACTIONS(9283),
    [anon_sym_POUNDendif] = ACTIONS(9283),
    [anon_sym_POUNDENDIF] = ACTIONS(9283),
    [anon_sym_POUNDEndif] = ACTIONS(9283),
    [anon_sym_POUNDendif2] = ACTIONS(9283),
    [anon_sym_POUNDENDIF2] = ACTIONS(9283),
    [anon_sym_POUNDEndif2] = ACTIONS(9283),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9283),
    [sym_trigger_keyword] = ACTIONS(9283),
    [sym_var_keyword] = ACTIONS(9283),
    [sym_local_keyword] = ACTIONS(9283),
    [sym_internal_keyword] = ACTIONS(9283),
    [sym_protected_keyword] = ACTIONS(9283),
    [sym_event_keyword] = ACTIONS(9283),
    [sym_fields_keyword] = ACTIONS(9283),
    [sym_keys_keyword] = ACTIONS(9283),
    [sym_fieldgroups_keyword] = ACTIONS(9283),
    [sym_actions_keyword] = ACTIONS(9283),
    [sym_layout_keyword] = ACTIONS(9283),
    [sym_area_keyword] = ACTIONS(9283),
    [sym_group_keyword] = ACTIONS(9283),
    [sym_repeater_keyword] = ACTIONS(9283),
    [sym_cuegroup_keyword] = ACTIONS(9283),
    [sym_fixed_keyword] = ACTIONS(9283),
    [sym_grid_keyword] = ACTIONS(9283),
    [sym_part_keyword] = ACTIONS(9283),
    [sym_systempart_keyword] = ACTIONS(9283),
    [sym_usercontrol_keyword] = ACTIONS(9283),
    [sym_dataset_keyword] = ACTIONS(9283),
    [sym_elements_keyword] = ACTIONS(9283),
    [sym_dataitem_keyword] = ACTIONS(9283),
    [sym_column_keyword] = ACTIONS(9283),
    [sym_filter_keyword] = ACTIONS(9283),
    [sym_labels_keyword] = ACTIONS(9283),
    [sym_rendering_keyword] = ACTIONS(9283),
    [sym_requestpage_keyword] = ACTIONS(9283),
    [sym_schema_keyword] = ACTIONS(9283),
    [sym_views_keyword] = ACTIONS(9283),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9283),
    [sym_preproc_open] = ACTIONS(9283),
    [sym_preproc_close] = ACTIONS(9283),
  },
  [STATE(4106)] = {
    [anon_sym_SEMI] = ACTIONS(9255),
    [aux_sym_where_condition_token1] = ACTIONS(9257),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9255),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9255),
    [anon_sym_LBRACK] = ACTIONS(9255),
    [aux_sym_basic_type_token6] = ACTIONS(9257),
    [aux_sym_basic_type_token22] = ACTIONS(9257),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9255),
    [aux_sym_addafter_modification_token1] = ACTIONS(9255),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9255),
    [aux_sym_modify_modification_token1] = ACTIONS(9255),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9255),
    [aux_sym_movelast_modification_token1] = ACTIONS(9255),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9255),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9255),
    [aux_sym_separator_action_token1] = ACTIONS(9255),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9255),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9255),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9255),
    [anon_sym_POUNDif] = ACTIONS(9255),
    [anon_sym_POUNDIF] = ACTIONS(9255),
    [anon_sym_POUNDIf] = ACTIONS(9255),
    [anon_sym_POUNDelif] = ACTIONS(9255),
    [anon_sym_POUNDELIF] = ACTIONS(9255),
    [anon_sym_POUNDElif] = ACTIONS(9255),
    [anon_sym_POUNDelse] = ACTIONS(9255),
    [anon_sym_POUNDELSE] = ACTIONS(9255),
    [anon_sym_POUNDElse] = ACTIONS(9255),
    [anon_sym_POUNDelse2] = ACTIONS(9255),
    [anon_sym_POUNDELSE2] = ACTIONS(9255),
    [anon_sym_POUNDElse2] = ACTIONS(9255),
    [anon_sym_POUNDendif] = ACTIONS(9255),
    [anon_sym_POUNDENDIF] = ACTIONS(9255),
    [anon_sym_POUNDEndif] = ACTIONS(9255),
    [anon_sym_POUNDendif2] = ACTIONS(9255),
    [anon_sym_POUNDENDIF2] = ACTIONS(9255),
    [anon_sym_POUNDEndif2] = ACTIONS(9255),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9255),
    [sym_trigger_keyword] = ACTIONS(9255),
    [sym_var_keyword] = ACTIONS(9255),
    [sym_local_keyword] = ACTIONS(9255),
    [sym_internal_keyword] = ACTIONS(9255),
    [sym_protected_keyword] = ACTIONS(9255),
    [sym_event_keyword] = ACTIONS(9255),
    [sym_fields_keyword] = ACTIONS(9255),
    [sym_keys_keyword] = ACTIONS(9255),
    [sym_fieldgroups_keyword] = ACTIONS(9255),
    [sym_actions_keyword] = ACTIONS(9255),
    [sym_layout_keyword] = ACTIONS(9255),
    [sym_area_keyword] = ACTIONS(9255),
    [sym_group_keyword] = ACTIONS(9255),
    [sym_repeater_keyword] = ACTIONS(9255),
    [sym_cuegroup_keyword] = ACTIONS(9255),
    [sym_fixed_keyword] = ACTIONS(9255),
    [sym_grid_keyword] = ACTIONS(9255),
    [sym_part_keyword] = ACTIONS(9255),
    [sym_systempart_keyword] = ACTIONS(9255),
    [sym_usercontrol_keyword] = ACTIONS(9255),
    [sym_dataset_keyword] = ACTIONS(9255),
    [sym_elements_keyword] = ACTIONS(9255),
    [sym_dataitem_keyword] = ACTIONS(9255),
    [sym_column_keyword] = ACTIONS(9255),
    [sym_filter_keyword] = ACTIONS(9255),
    [sym_labels_keyword] = ACTIONS(9255),
    [sym_rendering_keyword] = ACTIONS(9255),
    [sym_requestpage_keyword] = ACTIONS(9255),
    [sym_schema_keyword] = ACTIONS(9255),
    [sym_views_keyword] = ACTIONS(9255),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9255),
    [sym_preproc_open] = ACTIONS(9255),
    [sym_preproc_close] = ACTIONS(9255),
  },
  [STATE(4107)] = {
    [anon_sym_SEMI] = ACTIONS(9287),
    [aux_sym_where_condition_token1] = ACTIONS(9289),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9287),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9287),
    [anon_sym_LBRACK] = ACTIONS(9287),
    [aux_sym_basic_type_token6] = ACTIONS(9289),
    [aux_sym_basic_type_token22] = ACTIONS(9289),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9287),
    [aux_sym_addafter_modification_token1] = ACTIONS(9287),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9287),
    [aux_sym_modify_modification_token1] = ACTIONS(9287),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9287),
    [aux_sym_movelast_modification_token1] = ACTIONS(9287),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9287),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9287),
    [aux_sym_separator_action_token1] = ACTIONS(9287),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9287),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9287),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9287),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9287),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9287),
    [anon_sym_POUNDif] = ACTIONS(9287),
    [anon_sym_POUNDIF] = ACTIONS(9287),
    [anon_sym_POUNDIf] = ACTIONS(9287),
    [anon_sym_POUNDelif] = ACTIONS(9287),
    [anon_sym_POUNDELIF] = ACTIONS(9287),
    [anon_sym_POUNDElif] = ACTIONS(9287),
    [anon_sym_POUNDelse] = ACTIONS(9287),
    [anon_sym_POUNDELSE] = ACTIONS(9287),
    [anon_sym_POUNDElse] = ACTIONS(9287),
    [anon_sym_POUNDelse2] = ACTIONS(9287),
    [anon_sym_POUNDELSE2] = ACTIONS(9287),
    [anon_sym_POUNDElse2] = ACTIONS(9287),
    [anon_sym_POUNDendif] = ACTIONS(9287),
    [anon_sym_POUNDENDIF] = ACTIONS(9287),
    [anon_sym_POUNDEndif] = ACTIONS(9287),
    [anon_sym_POUNDendif2] = ACTIONS(9287),
    [anon_sym_POUNDENDIF2] = ACTIONS(9287),
    [anon_sym_POUNDEndif2] = ACTIONS(9287),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9287),
    [sym_trigger_keyword] = ACTIONS(9287),
    [sym_var_keyword] = ACTIONS(9287),
    [sym_local_keyword] = ACTIONS(9287),
    [sym_internal_keyword] = ACTIONS(9287),
    [sym_protected_keyword] = ACTIONS(9287),
    [sym_event_keyword] = ACTIONS(9287),
    [sym_fields_keyword] = ACTIONS(9287),
    [sym_keys_keyword] = ACTIONS(9287),
    [sym_fieldgroups_keyword] = ACTIONS(9287),
    [sym_actions_keyword] = ACTIONS(9287),
    [sym_layout_keyword] = ACTIONS(9287),
    [sym_area_keyword] = ACTIONS(9287),
    [sym_group_keyword] = ACTIONS(9287),
    [sym_repeater_keyword] = ACTIONS(9287),
    [sym_cuegroup_keyword] = ACTIONS(9287),
    [sym_fixed_keyword] = ACTIONS(9287),
    [sym_grid_keyword] = ACTIONS(9287),
    [sym_part_keyword] = ACTIONS(9287),
    [sym_systempart_keyword] = ACTIONS(9287),
    [sym_usercontrol_keyword] = ACTIONS(9287),
    [sym_dataset_keyword] = ACTIONS(9287),
    [sym_elements_keyword] = ACTIONS(9287),
    [sym_dataitem_keyword] = ACTIONS(9287),
    [sym_column_keyword] = ACTIONS(9287),
    [sym_filter_keyword] = ACTIONS(9287),
    [sym_labels_keyword] = ACTIONS(9287),
    [sym_rendering_keyword] = ACTIONS(9287),
    [sym_requestpage_keyword] = ACTIONS(9287),
    [sym_schema_keyword] = ACTIONS(9287),
    [sym_views_keyword] = ACTIONS(9287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9287),
    [sym_preproc_open] = ACTIONS(9287),
    [sym_preproc_close] = ACTIONS(9287),
  },
  [STATE(4108)] = {
    [anon_sym_SEMI] = ACTIONS(9291),
    [aux_sym_where_condition_token1] = ACTIONS(9293),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9291),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9291),
    [anon_sym_LBRACK] = ACTIONS(9291),
    [aux_sym_basic_type_token6] = ACTIONS(9293),
    [aux_sym_basic_type_token22] = ACTIONS(9293),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9291),
    [aux_sym_addafter_modification_token1] = ACTIONS(9291),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9291),
    [aux_sym_modify_modification_token1] = ACTIONS(9291),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9291),
    [aux_sym_movelast_modification_token1] = ACTIONS(9291),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9291),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9291),
    [aux_sym_separator_action_token1] = ACTIONS(9291),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9291),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9291),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9291),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9291),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9291),
    [anon_sym_POUNDif] = ACTIONS(9291),
    [anon_sym_POUNDIF] = ACTIONS(9291),
    [anon_sym_POUNDIf] = ACTIONS(9291),
    [anon_sym_POUNDelif] = ACTIONS(9291),
    [anon_sym_POUNDELIF] = ACTIONS(9291),
    [anon_sym_POUNDElif] = ACTIONS(9291),
    [anon_sym_POUNDelse] = ACTIONS(9291),
    [anon_sym_POUNDELSE] = ACTIONS(9291),
    [anon_sym_POUNDElse] = ACTIONS(9291),
    [anon_sym_POUNDelse2] = ACTIONS(9291),
    [anon_sym_POUNDELSE2] = ACTIONS(9291),
    [anon_sym_POUNDElse2] = ACTIONS(9291),
    [anon_sym_POUNDendif] = ACTIONS(9291),
    [anon_sym_POUNDENDIF] = ACTIONS(9291),
    [anon_sym_POUNDEndif] = ACTIONS(9291),
    [anon_sym_POUNDendif2] = ACTIONS(9291),
    [anon_sym_POUNDENDIF2] = ACTIONS(9291),
    [anon_sym_POUNDEndif2] = ACTIONS(9291),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9291),
    [sym_trigger_keyword] = ACTIONS(9291),
    [sym_var_keyword] = ACTIONS(9291),
    [sym_local_keyword] = ACTIONS(9291),
    [sym_internal_keyword] = ACTIONS(9291),
    [sym_protected_keyword] = ACTIONS(9291),
    [sym_event_keyword] = ACTIONS(9291),
    [sym_fields_keyword] = ACTIONS(9291),
    [sym_keys_keyword] = ACTIONS(9291),
    [sym_fieldgroups_keyword] = ACTIONS(9291),
    [sym_actions_keyword] = ACTIONS(9291),
    [sym_layout_keyword] = ACTIONS(9291),
    [sym_area_keyword] = ACTIONS(9291),
    [sym_group_keyword] = ACTIONS(9291),
    [sym_repeater_keyword] = ACTIONS(9291),
    [sym_cuegroup_keyword] = ACTIONS(9291),
    [sym_fixed_keyword] = ACTIONS(9291),
    [sym_grid_keyword] = ACTIONS(9291),
    [sym_part_keyword] = ACTIONS(9291),
    [sym_systempart_keyword] = ACTIONS(9291),
    [sym_usercontrol_keyword] = ACTIONS(9291),
    [sym_dataset_keyword] = ACTIONS(9291),
    [sym_elements_keyword] = ACTIONS(9291),
    [sym_dataitem_keyword] = ACTIONS(9291),
    [sym_column_keyword] = ACTIONS(9291),
    [sym_filter_keyword] = ACTIONS(9291),
    [sym_labels_keyword] = ACTIONS(9291),
    [sym_rendering_keyword] = ACTIONS(9291),
    [sym_requestpage_keyword] = ACTIONS(9291),
    [sym_schema_keyword] = ACTIONS(9291),
    [sym_views_keyword] = ACTIONS(9291),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9291),
    [sym_preproc_open] = ACTIONS(9291),
    [sym_preproc_close] = ACTIONS(9291),
  },
  [STATE(4109)] = {
    [anon_sym_SEMI] = ACTIONS(6194),
    [aux_sym_where_condition_token1] = ACTIONS(6192),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6194),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6194),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [aux_sym_basic_type_token6] = ACTIONS(6192),
    [aux_sym_basic_type_token22] = ACTIONS(6192),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6194),
    [aux_sym_addafter_modification_token1] = ACTIONS(6194),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6194),
    [aux_sym_modify_modification_token1] = ACTIONS(6194),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6194),
    [aux_sym_movelast_modification_token1] = ACTIONS(6194),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6194),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6194),
    [aux_sym_separator_action_token1] = ACTIONS(6194),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6194),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6194),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6194),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6194),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6194),
    [anon_sym_POUNDif] = ACTIONS(6194),
    [anon_sym_POUNDIF] = ACTIONS(6194),
    [anon_sym_POUNDIf] = ACTIONS(6194),
    [anon_sym_POUNDelif] = ACTIONS(6194),
    [anon_sym_POUNDELIF] = ACTIONS(6194),
    [anon_sym_POUNDElif] = ACTIONS(6194),
    [anon_sym_POUNDelse] = ACTIONS(6194),
    [anon_sym_POUNDELSE] = ACTIONS(6194),
    [anon_sym_POUNDElse] = ACTIONS(6194),
    [anon_sym_POUNDelse2] = ACTIONS(6194),
    [anon_sym_POUNDELSE2] = ACTIONS(6194),
    [anon_sym_POUNDElse2] = ACTIONS(6194),
    [anon_sym_POUNDendif] = ACTIONS(6194),
    [anon_sym_POUNDENDIF] = ACTIONS(6194),
    [anon_sym_POUNDEndif] = ACTIONS(6194),
    [anon_sym_POUNDendif2] = ACTIONS(6194),
    [anon_sym_POUNDENDIF2] = ACTIONS(6194),
    [anon_sym_POUNDEndif2] = ACTIONS(6194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6194),
    [sym_trigger_keyword] = ACTIONS(6194),
    [sym_var_keyword] = ACTIONS(6194),
    [sym_local_keyword] = ACTIONS(6194),
    [sym_internal_keyword] = ACTIONS(6194),
    [sym_protected_keyword] = ACTIONS(6194),
    [sym_event_keyword] = ACTIONS(6194),
    [sym_fields_keyword] = ACTIONS(6194),
    [sym_keys_keyword] = ACTIONS(6194),
    [sym_fieldgroups_keyword] = ACTIONS(6194),
    [sym_actions_keyword] = ACTIONS(6194),
    [sym_layout_keyword] = ACTIONS(6194),
    [sym_area_keyword] = ACTIONS(6194),
    [sym_group_keyword] = ACTIONS(6194),
    [sym_repeater_keyword] = ACTIONS(6194),
    [sym_cuegroup_keyword] = ACTIONS(6194),
    [sym_fixed_keyword] = ACTIONS(6194),
    [sym_grid_keyword] = ACTIONS(6194),
    [sym_part_keyword] = ACTIONS(6194),
    [sym_systempart_keyword] = ACTIONS(6194),
    [sym_usercontrol_keyword] = ACTIONS(6194),
    [sym_dataset_keyword] = ACTIONS(6194),
    [sym_elements_keyword] = ACTIONS(6194),
    [sym_dataitem_keyword] = ACTIONS(6194),
    [sym_column_keyword] = ACTIONS(6194),
    [sym_filter_keyword] = ACTIONS(6194),
    [sym_labels_keyword] = ACTIONS(6194),
    [sym_rendering_keyword] = ACTIONS(6194),
    [sym_requestpage_keyword] = ACTIONS(6194),
    [sym_schema_keyword] = ACTIONS(6194),
    [sym_views_keyword] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6194),
    [sym_preproc_open] = ACTIONS(6194),
    [sym_preproc_close] = ACTIONS(6194),
  },
  [STATE(4110)] = {
    [anon_sym_SEMI] = ACTIONS(9295),
    [aux_sym_where_condition_token1] = ACTIONS(9297),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9295),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9295),
    [anon_sym_LBRACK] = ACTIONS(9295),
    [aux_sym_basic_type_token6] = ACTIONS(9297),
    [aux_sym_basic_type_token22] = ACTIONS(9297),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9295),
    [aux_sym_addafter_modification_token1] = ACTIONS(9295),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9295),
    [aux_sym_modify_modification_token1] = ACTIONS(9295),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9295),
    [aux_sym_movelast_modification_token1] = ACTIONS(9295),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9295),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9295),
    [aux_sym_separator_action_token1] = ACTIONS(9295),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9295),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9295),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9295),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9295),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9295),
    [anon_sym_POUNDif] = ACTIONS(9295),
    [anon_sym_POUNDIF] = ACTIONS(9295),
    [anon_sym_POUNDIf] = ACTIONS(9295),
    [anon_sym_POUNDelif] = ACTIONS(9295),
    [anon_sym_POUNDELIF] = ACTIONS(9295),
    [anon_sym_POUNDElif] = ACTIONS(9295),
    [anon_sym_POUNDelse] = ACTIONS(9295),
    [anon_sym_POUNDELSE] = ACTIONS(9295),
    [anon_sym_POUNDElse] = ACTIONS(9295),
    [anon_sym_POUNDelse2] = ACTIONS(9295),
    [anon_sym_POUNDELSE2] = ACTIONS(9295),
    [anon_sym_POUNDElse2] = ACTIONS(9295),
    [anon_sym_POUNDendif] = ACTIONS(9295),
    [anon_sym_POUNDENDIF] = ACTIONS(9295),
    [anon_sym_POUNDEndif] = ACTIONS(9295),
    [anon_sym_POUNDendif2] = ACTIONS(9295),
    [anon_sym_POUNDENDIF2] = ACTIONS(9295),
    [anon_sym_POUNDEndif2] = ACTIONS(9295),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9295),
    [sym_trigger_keyword] = ACTIONS(9295),
    [sym_var_keyword] = ACTIONS(9295),
    [sym_local_keyword] = ACTIONS(9295),
    [sym_internal_keyword] = ACTIONS(9295),
    [sym_protected_keyword] = ACTIONS(9295),
    [sym_event_keyword] = ACTIONS(9295),
    [sym_fields_keyword] = ACTIONS(9295),
    [sym_keys_keyword] = ACTIONS(9295),
    [sym_fieldgroups_keyword] = ACTIONS(9295),
    [sym_actions_keyword] = ACTIONS(9295),
    [sym_layout_keyword] = ACTIONS(9295),
    [sym_area_keyword] = ACTIONS(9295),
    [sym_group_keyword] = ACTIONS(9295),
    [sym_repeater_keyword] = ACTIONS(9295),
    [sym_cuegroup_keyword] = ACTIONS(9295),
    [sym_fixed_keyword] = ACTIONS(9295),
    [sym_grid_keyword] = ACTIONS(9295),
    [sym_part_keyword] = ACTIONS(9295),
    [sym_systempart_keyword] = ACTIONS(9295),
    [sym_usercontrol_keyword] = ACTIONS(9295),
    [sym_dataset_keyword] = ACTIONS(9295),
    [sym_elements_keyword] = ACTIONS(9295),
    [sym_dataitem_keyword] = ACTIONS(9295),
    [sym_column_keyword] = ACTIONS(9295),
    [sym_filter_keyword] = ACTIONS(9295),
    [sym_labels_keyword] = ACTIONS(9295),
    [sym_rendering_keyword] = ACTIONS(9295),
    [sym_requestpage_keyword] = ACTIONS(9295),
    [sym_schema_keyword] = ACTIONS(9295),
    [sym_views_keyword] = ACTIONS(9295),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9295),
    [sym_preproc_open] = ACTIONS(9295),
    [sym_preproc_close] = ACTIONS(9295),
  },
  [STATE(4111)] = {
    [sym_else_keyword] = STATE(742),
    [sym_identifier] = ACTIONS(9299),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(9302),
    [aux_sym_boolean_token1] = ACTIONS(9299),
    [aux_sym_boolean_token2] = ACTIONS(9299),
    [sym_decimal] = ACTIONS(9299),
    [anon_sym_LPAREN] = ACTIONS(9302),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9299),
    [anon_sym_LBRACK] = ACTIONS(9302),
    [aux_sym_record_type_token1] = ACTIONS(9299),
    [aux_sym_basic_type_token21] = ACTIONS(9299),
    [aux_sym_basic_type_token22] = ACTIONS(9299),
    [aux_sym_basic_type_token48] = ACTIONS(9299),
    [anon_sym_POUNDif] = ACTIONS(9302),
    [anon_sym_POUNDIF] = ACTIONS(9302),
    [anon_sym_POUNDIf] = ACTIONS(9302),
    [anon_sym_not] = ACTIONS(9299),
    [anon_sym_NOT] = ACTIONS(9299),
    [anon_sym_Not] = ACTIONS(9299),
    [anon_sym_POUNDelif] = ACTIONS(9302),
    [anon_sym_POUNDELIF] = ACTIONS(9302),
    [anon_sym_POUNDElif] = ACTIONS(9302),
    [anon_sym_POUNDelse] = ACTIONS(9302),
    [anon_sym_POUNDELSE] = ACTIONS(9302),
    [anon_sym_POUNDElse] = ACTIONS(9302),
    [anon_sym_POUNDelse2] = ACTIONS(9302),
    [anon_sym_POUNDELSE2] = ACTIONS(9302),
    [anon_sym_POUNDElse2] = ACTIONS(9302),
    [anon_sym_POUNDendif] = ACTIONS(9302),
    [anon_sym_POUNDENDIF] = ACTIONS(9302),
    [anon_sym_POUNDEndif] = ACTIONS(9302),
    [anon_sym_POUNDendif2] = ACTIONS(9302),
    [anon_sym_POUNDENDIF2] = ACTIONS(9302),
    [anon_sym_POUNDEndif2] = ACTIONS(9302),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9299),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9299),
    [anon_sym_PLUS] = ACTIONS(9302),
    [sym_datetime_literal] = ACTIONS(9302),
    [sym_date_literal] = ACTIONS(9299),
    [sym_time_literal] = ACTIONS(9299),
    [sym_biginteger_literal] = ACTIONS(9302),
    [anon_sym_else] = ACTIONS(9305),
    [anon_sym_ELSE] = ACTIONS(9305),
    [anon_sym_Else] = ACTIONS(9305),
    [sym_page_keyword] = ACTIONS(9299),
    [anon_sym_codeunit] = ACTIONS(9299),
    [anon_sym_CODEUNIT] = ACTIONS(9299),
    [anon_sym_Codeunit] = ACTIONS(9299),
    [anon_sym_CodeUnit] = ACTIONS(9299),
    [anon_sym_COdeunit] = ACTIONS(9299),
    [anon_sym_codeUnit] = ACTIONS(9299),
    [sym_report_keyword] = ACTIONS(9299),
    [sym_query_keyword] = ACTIONS(9299),
    [anon_sym_xmlport] = ACTIONS(9299),
    [anon_sym_XMLPORT] = ACTIONS(9299),
    [anon_sym_Xmlport] = ACTIONS(9299),
    [anon_sym_XMLport] = ACTIONS(9299),
    [anon_sym_XMLPort] = ACTIONS(9299),
    [anon_sym_XmlPort] = ACTIONS(9299),
    [anon_sym_enum] = ACTIONS(9299),
    [anon_sym_ENUM] = ACTIONS(9299),
    [anon_sym_Enum] = ACTIONS(9299),
    [anon_sym_eNUM] = ACTIONS(9299),
    [anon_sym_eNum] = ACTIONS(9299),
    [anon_sym_ENum] = ACTIONS(9299),
    [sym_quoted_identifier] = ACTIONS(9302),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9302),
    [sym_verbatim_string] = ACTIONS(9302),
    [sym_integer] = ACTIONS(9299),
    [sym_continue_as_identifier] = ACTIONS(9302),
    [sym_preproc_open] = ACTIONS(9302),
    [sym_preproc_close] = ACTIONS(9302),
  },
  [STATE(4112)] = {
    [sym_else_keyword] = STATE(743),
    [sym_identifier] = ACTIONS(9309),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(9312),
    [aux_sym_boolean_token1] = ACTIONS(9309),
    [aux_sym_boolean_token2] = ACTIONS(9309),
    [sym_decimal] = ACTIONS(9309),
    [anon_sym_LPAREN] = ACTIONS(9312),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9309),
    [anon_sym_LBRACK] = ACTIONS(9312),
    [aux_sym_record_type_token1] = ACTIONS(9309),
    [aux_sym_basic_type_token21] = ACTIONS(9309),
    [aux_sym_basic_type_token22] = ACTIONS(9309),
    [aux_sym_basic_type_token48] = ACTIONS(9309),
    [anon_sym_POUNDif] = ACTIONS(9312),
    [anon_sym_POUNDIF] = ACTIONS(9312),
    [anon_sym_POUNDIf] = ACTIONS(9312),
    [anon_sym_not] = ACTIONS(9309),
    [anon_sym_NOT] = ACTIONS(9309),
    [anon_sym_Not] = ACTIONS(9309),
    [anon_sym_POUNDelif] = ACTIONS(9312),
    [anon_sym_POUNDELIF] = ACTIONS(9312),
    [anon_sym_POUNDElif] = ACTIONS(9312),
    [anon_sym_POUNDelse] = ACTIONS(9312),
    [anon_sym_POUNDELSE] = ACTIONS(9312),
    [anon_sym_POUNDElse] = ACTIONS(9312),
    [anon_sym_POUNDelse2] = ACTIONS(9312),
    [anon_sym_POUNDELSE2] = ACTIONS(9312),
    [anon_sym_POUNDElse2] = ACTIONS(9312),
    [anon_sym_POUNDendif] = ACTIONS(9312),
    [anon_sym_POUNDENDIF] = ACTIONS(9312),
    [anon_sym_POUNDEndif] = ACTIONS(9312),
    [anon_sym_POUNDendif2] = ACTIONS(9312),
    [anon_sym_POUNDENDIF2] = ACTIONS(9312),
    [anon_sym_POUNDEndif2] = ACTIONS(9312),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9309),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9309),
    [anon_sym_PLUS] = ACTIONS(9312),
    [sym_datetime_literal] = ACTIONS(9312),
    [sym_date_literal] = ACTIONS(9309),
    [sym_time_literal] = ACTIONS(9309),
    [sym_biginteger_literal] = ACTIONS(9312),
    [anon_sym_else] = ACTIONS(9315),
    [anon_sym_ELSE] = ACTIONS(9315),
    [anon_sym_Else] = ACTIONS(9315),
    [sym_page_keyword] = ACTIONS(9309),
    [anon_sym_codeunit] = ACTIONS(9309),
    [anon_sym_CODEUNIT] = ACTIONS(9309),
    [anon_sym_Codeunit] = ACTIONS(9309),
    [anon_sym_CodeUnit] = ACTIONS(9309),
    [anon_sym_COdeunit] = ACTIONS(9309),
    [anon_sym_codeUnit] = ACTIONS(9309),
    [sym_report_keyword] = ACTIONS(9309),
    [sym_query_keyword] = ACTIONS(9309),
    [anon_sym_xmlport] = ACTIONS(9309),
    [anon_sym_XMLPORT] = ACTIONS(9309),
    [anon_sym_Xmlport] = ACTIONS(9309),
    [anon_sym_XMLport] = ACTIONS(9309),
    [anon_sym_XMLPort] = ACTIONS(9309),
    [anon_sym_XmlPort] = ACTIONS(9309),
    [anon_sym_enum] = ACTIONS(9309),
    [anon_sym_ENUM] = ACTIONS(9309),
    [anon_sym_Enum] = ACTIONS(9309),
    [anon_sym_eNUM] = ACTIONS(9309),
    [anon_sym_eNum] = ACTIONS(9309),
    [anon_sym_ENum] = ACTIONS(9309),
    [sym_quoted_identifier] = ACTIONS(9312),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9312),
    [sym_verbatim_string] = ACTIONS(9312),
    [sym_integer] = ACTIONS(9309),
    [sym_continue_as_identifier] = ACTIONS(9312),
    [sym_preproc_open] = ACTIONS(9312),
    [sym_preproc_close] = ACTIONS(9312),
  },
  [STATE(4113)] = {
    [anon_sym_SEMI] = ACTIONS(9319),
    [aux_sym_where_condition_token1] = ACTIONS(9321),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9319),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9319),
    [anon_sym_LBRACK] = ACTIONS(9319),
    [aux_sym_basic_type_token6] = ACTIONS(9321),
    [aux_sym_basic_type_token22] = ACTIONS(9321),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9319),
    [aux_sym_addafter_modification_token1] = ACTIONS(9319),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9319),
    [aux_sym_modify_modification_token1] = ACTIONS(9319),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9319),
    [aux_sym_movelast_modification_token1] = ACTIONS(9319),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9319),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9319),
    [aux_sym_separator_action_token1] = ACTIONS(9319),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9319),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9319),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9319),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9319),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9319),
    [anon_sym_POUNDif] = ACTIONS(9319),
    [anon_sym_POUNDIF] = ACTIONS(9319),
    [anon_sym_POUNDIf] = ACTIONS(9319),
    [anon_sym_POUNDelif] = ACTIONS(9319),
    [anon_sym_POUNDELIF] = ACTIONS(9319),
    [anon_sym_POUNDElif] = ACTIONS(9319),
    [anon_sym_POUNDelse] = ACTIONS(9319),
    [anon_sym_POUNDELSE] = ACTIONS(9319),
    [anon_sym_POUNDElse] = ACTIONS(9319),
    [anon_sym_POUNDelse2] = ACTIONS(9319),
    [anon_sym_POUNDELSE2] = ACTIONS(9319),
    [anon_sym_POUNDElse2] = ACTIONS(9319),
    [anon_sym_POUNDendif] = ACTIONS(9319),
    [anon_sym_POUNDENDIF] = ACTIONS(9319),
    [anon_sym_POUNDEndif] = ACTIONS(9319),
    [anon_sym_POUNDendif2] = ACTIONS(9319),
    [anon_sym_POUNDENDIF2] = ACTIONS(9319),
    [anon_sym_POUNDEndif2] = ACTIONS(9319),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9319),
    [sym_trigger_keyword] = ACTIONS(9319),
    [sym_var_keyword] = ACTIONS(9319),
    [sym_local_keyword] = ACTIONS(9319),
    [sym_internal_keyword] = ACTIONS(9319),
    [sym_protected_keyword] = ACTIONS(9319),
    [sym_event_keyword] = ACTIONS(9319),
    [sym_fields_keyword] = ACTIONS(9319),
    [sym_keys_keyword] = ACTIONS(9319),
    [sym_fieldgroups_keyword] = ACTIONS(9319),
    [sym_actions_keyword] = ACTIONS(9319),
    [sym_layout_keyword] = ACTIONS(9319),
    [sym_area_keyword] = ACTIONS(9319),
    [sym_group_keyword] = ACTIONS(9319),
    [sym_repeater_keyword] = ACTIONS(9319),
    [sym_cuegroup_keyword] = ACTIONS(9319),
    [sym_fixed_keyword] = ACTIONS(9319),
    [sym_grid_keyword] = ACTIONS(9319),
    [sym_part_keyword] = ACTIONS(9319),
    [sym_systempart_keyword] = ACTIONS(9319),
    [sym_usercontrol_keyword] = ACTIONS(9319),
    [sym_dataset_keyword] = ACTIONS(9319),
    [sym_elements_keyword] = ACTIONS(9319),
    [sym_dataitem_keyword] = ACTIONS(9319),
    [sym_column_keyword] = ACTIONS(9319),
    [sym_filter_keyword] = ACTIONS(9319),
    [sym_labels_keyword] = ACTIONS(9319),
    [sym_rendering_keyword] = ACTIONS(9319),
    [sym_requestpage_keyword] = ACTIONS(9319),
    [sym_schema_keyword] = ACTIONS(9319),
    [sym_views_keyword] = ACTIONS(9319),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9319),
    [sym_preproc_open] = ACTIONS(9319),
    [sym_preproc_close] = ACTIONS(9319),
  },
  [STATE(4114)] = {
    [anon_sym_SEMI] = ACTIONS(9323),
    [aux_sym_where_condition_token1] = ACTIONS(9325),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9323),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9323),
    [anon_sym_LBRACK] = ACTIONS(9323),
    [aux_sym_basic_type_token6] = ACTIONS(9325),
    [aux_sym_basic_type_token22] = ACTIONS(9325),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9323),
    [aux_sym_addafter_modification_token1] = ACTIONS(9323),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9323),
    [aux_sym_modify_modification_token1] = ACTIONS(9323),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9323),
    [aux_sym_movelast_modification_token1] = ACTIONS(9323),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9323),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9323),
    [aux_sym_separator_action_token1] = ACTIONS(9323),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9323),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9323),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9323),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9323),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9323),
    [anon_sym_POUNDif] = ACTIONS(9323),
    [anon_sym_POUNDIF] = ACTIONS(9323),
    [anon_sym_POUNDIf] = ACTIONS(9323),
    [anon_sym_POUNDelif] = ACTIONS(9323),
    [anon_sym_POUNDELIF] = ACTIONS(9323),
    [anon_sym_POUNDElif] = ACTIONS(9323),
    [anon_sym_POUNDelse] = ACTIONS(9323),
    [anon_sym_POUNDELSE] = ACTIONS(9323),
    [anon_sym_POUNDElse] = ACTIONS(9323),
    [anon_sym_POUNDelse2] = ACTIONS(9323),
    [anon_sym_POUNDELSE2] = ACTIONS(9323),
    [anon_sym_POUNDElse2] = ACTIONS(9323),
    [anon_sym_POUNDendif] = ACTIONS(9323),
    [anon_sym_POUNDENDIF] = ACTIONS(9323),
    [anon_sym_POUNDEndif] = ACTIONS(9323),
    [anon_sym_POUNDendif2] = ACTIONS(9323),
    [anon_sym_POUNDENDIF2] = ACTIONS(9323),
    [anon_sym_POUNDEndif2] = ACTIONS(9323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9323),
    [sym_trigger_keyword] = ACTIONS(9323),
    [sym_var_keyword] = ACTIONS(9323),
    [sym_local_keyword] = ACTIONS(9323),
    [sym_internal_keyword] = ACTIONS(9323),
    [sym_protected_keyword] = ACTIONS(9323),
    [sym_event_keyword] = ACTIONS(9323),
    [sym_fields_keyword] = ACTIONS(9323),
    [sym_keys_keyword] = ACTIONS(9323),
    [sym_fieldgroups_keyword] = ACTIONS(9323),
    [sym_actions_keyword] = ACTIONS(9323),
    [sym_layout_keyword] = ACTIONS(9323),
    [sym_area_keyword] = ACTIONS(9323),
    [sym_group_keyword] = ACTIONS(9323),
    [sym_repeater_keyword] = ACTIONS(9323),
    [sym_cuegroup_keyword] = ACTIONS(9323),
    [sym_fixed_keyword] = ACTIONS(9323),
    [sym_grid_keyword] = ACTIONS(9323),
    [sym_part_keyword] = ACTIONS(9323),
    [sym_systempart_keyword] = ACTIONS(9323),
    [sym_usercontrol_keyword] = ACTIONS(9323),
    [sym_dataset_keyword] = ACTIONS(9323),
    [sym_elements_keyword] = ACTIONS(9323),
    [sym_dataitem_keyword] = ACTIONS(9323),
    [sym_column_keyword] = ACTIONS(9323),
    [sym_filter_keyword] = ACTIONS(9323),
    [sym_labels_keyword] = ACTIONS(9323),
    [sym_rendering_keyword] = ACTIONS(9323),
    [sym_requestpage_keyword] = ACTIONS(9323),
    [sym_schema_keyword] = ACTIONS(9323),
    [sym_views_keyword] = ACTIONS(9323),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9323),
    [sym_preproc_open] = ACTIONS(9323),
    [sym_preproc_close] = ACTIONS(9323),
  },
  [STATE(4115)] = {
    [anon_sym_SEMI] = ACTIONS(9327),
    [aux_sym_where_condition_token1] = ACTIONS(9329),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9327),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9327),
    [anon_sym_LBRACK] = ACTIONS(9327),
    [aux_sym_basic_type_token6] = ACTIONS(9329),
    [aux_sym_basic_type_token22] = ACTIONS(9329),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9327),
    [aux_sym_addafter_modification_token1] = ACTIONS(9327),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9327),
    [aux_sym_modify_modification_token1] = ACTIONS(9327),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9327),
    [aux_sym_movelast_modification_token1] = ACTIONS(9327),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9327),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9327),
    [aux_sym_separator_action_token1] = ACTIONS(9327),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9327),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9327),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9327),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9327),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9327),
    [anon_sym_POUNDif] = ACTIONS(9327),
    [anon_sym_POUNDIF] = ACTIONS(9327),
    [anon_sym_POUNDIf] = ACTIONS(9327),
    [anon_sym_POUNDelif] = ACTIONS(9327),
    [anon_sym_POUNDELIF] = ACTIONS(9327),
    [anon_sym_POUNDElif] = ACTIONS(9327),
    [anon_sym_POUNDelse] = ACTIONS(9327),
    [anon_sym_POUNDELSE] = ACTIONS(9327),
    [anon_sym_POUNDElse] = ACTIONS(9327),
    [anon_sym_POUNDelse2] = ACTIONS(9327),
    [anon_sym_POUNDELSE2] = ACTIONS(9327),
    [anon_sym_POUNDElse2] = ACTIONS(9327),
    [anon_sym_POUNDendif] = ACTIONS(9327),
    [anon_sym_POUNDENDIF] = ACTIONS(9327),
    [anon_sym_POUNDEndif] = ACTIONS(9327),
    [anon_sym_POUNDendif2] = ACTIONS(9327),
    [anon_sym_POUNDENDIF2] = ACTIONS(9327),
    [anon_sym_POUNDEndif2] = ACTIONS(9327),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9327),
    [sym_trigger_keyword] = ACTIONS(9327),
    [sym_var_keyword] = ACTIONS(9327),
    [sym_local_keyword] = ACTIONS(9327),
    [sym_internal_keyword] = ACTIONS(9327),
    [sym_protected_keyword] = ACTIONS(9327),
    [sym_event_keyword] = ACTIONS(9327),
    [sym_fields_keyword] = ACTIONS(9327),
    [sym_keys_keyword] = ACTIONS(9327),
    [sym_fieldgroups_keyword] = ACTIONS(9327),
    [sym_actions_keyword] = ACTIONS(9327),
    [sym_layout_keyword] = ACTIONS(9327),
    [sym_area_keyword] = ACTIONS(9327),
    [sym_group_keyword] = ACTIONS(9327),
    [sym_repeater_keyword] = ACTIONS(9327),
    [sym_cuegroup_keyword] = ACTIONS(9327),
    [sym_fixed_keyword] = ACTIONS(9327),
    [sym_grid_keyword] = ACTIONS(9327),
    [sym_part_keyword] = ACTIONS(9327),
    [sym_systempart_keyword] = ACTIONS(9327),
    [sym_usercontrol_keyword] = ACTIONS(9327),
    [sym_dataset_keyword] = ACTIONS(9327),
    [sym_elements_keyword] = ACTIONS(9327),
    [sym_dataitem_keyword] = ACTIONS(9327),
    [sym_column_keyword] = ACTIONS(9327),
    [sym_filter_keyword] = ACTIONS(9327),
    [sym_labels_keyword] = ACTIONS(9327),
    [sym_rendering_keyword] = ACTIONS(9327),
    [sym_requestpage_keyword] = ACTIONS(9327),
    [sym_schema_keyword] = ACTIONS(9327),
    [sym_views_keyword] = ACTIONS(9327),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9327),
    [sym_preproc_open] = ACTIONS(9327),
    [sym_preproc_close] = ACTIONS(9327),
  },
  [STATE(4116)] = {
    [anon_sym_SEMI] = ACTIONS(9331),
    [aux_sym_where_condition_token1] = ACTIONS(9333),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9331),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9331),
    [anon_sym_LBRACK] = ACTIONS(9331),
    [aux_sym_basic_type_token6] = ACTIONS(9333),
    [aux_sym_basic_type_token22] = ACTIONS(9333),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9331),
    [aux_sym_addafter_modification_token1] = ACTIONS(9331),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9331),
    [aux_sym_modify_modification_token1] = ACTIONS(9331),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9331),
    [aux_sym_movelast_modification_token1] = ACTIONS(9331),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9331),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9331),
    [aux_sym_separator_action_token1] = ACTIONS(9331),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9331),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9331),
    [anon_sym_POUNDif] = ACTIONS(9331),
    [anon_sym_POUNDIF] = ACTIONS(9331),
    [anon_sym_POUNDIf] = ACTIONS(9331),
    [anon_sym_POUNDelif] = ACTIONS(9331),
    [anon_sym_POUNDELIF] = ACTIONS(9331),
    [anon_sym_POUNDElif] = ACTIONS(9331),
    [anon_sym_POUNDelse] = ACTIONS(9331),
    [anon_sym_POUNDELSE] = ACTIONS(9331),
    [anon_sym_POUNDElse] = ACTIONS(9331),
    [anon_sym_POUNDelse2] = ACTIONS(9331),
    [anon_sym_POUNDELSE2] = ACTIONS(9331),
    [anon_sym_POUNDElse2] = ACTIONS(9331),
    [anon_sym_POUNDendif] = ACTIONS(9331),
    [anon_sym_POUNDENDIF] = ACTIONS(9331),
    [anon_sym_POUNDEndif] = ACTIONS(9331),
    [anon_sym_POUNDendif2] = ACTIONS(9331),
    [anon_sym_POUNDENDIF2] = ACTIONS(9331),
    [anon_sym_POUNDEndif2] = ACTIONS(9331),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9331),
    [sym_trigger_keyword] = ACTIONS(9331),
    [sym_var_keyword] = ACTIONS(9331),
    [sym_local_keyword] = ACTIONS(9331),
    [sym_internal_keyword] = ACTIONS(9331),
    [sym_protected_keyword] = ACTIONS(9331),
    [sym_event_keyword] = ACTIONS(9331),
    [sym_fields_keyword] = ACTIONS(9331),
    [sym_keys_keyword] = ACTIONS(9331),
    [sym_fieldgroups_keyword] = ACTIONS(9331),
    [sym_actions_keyword] = ACTIONS(9331),
    [sym_layout_keyword] = ACTIONS(9331),
    [sym_area_keyword] = ACTIONS(9331),
    [sym_group_keyword] = ACTIONS(9331),
    [sym_repeater_keyword] = ACTIONS(9331),
    [sym_cuegroup_keyword] = ACTIONS(9331),
    [sym_fixed_keyword] = ACTIONS(9331),
    [sym_grid_keyword] = ACTIONS(9331),
    [sym_part_keyword] = ACTIONS(9331),
    [sym_systempart_keyword] = ACTIONS(9331),
    [sym_usercontrol_keyword] = ACTIONS(9331),
    [sym_dataset_keyword] = ACTIONS(9331),
    [sym_elements_keyword] = ACTIONS(9331),
    [sym_dataitem_keyword] = ACTIONS(9331),
    [sym_column_keyword] = ACTIONS(9331),
    [sym_filter_keyword] = ACTIONS(9331),
    [sym_labels_keyword] = ACTIONS(9331),
    [sym_rendering_keyword] = ACTIONS(9331),
    [sym_requestpage_keyword] = ACTIONS(9331),
    [sym_schema_keyword] = ACTIONS(9331),
    [sym_views_keyword] = ACTIONS(9331),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9331),
    [sym_preproc_open] = ACTIONS(9331),
    [sym_preproc_close] = ACTIONS(9331),
  },
  [STATE(4117)] = {
    [anon_sym_SEMI] = ACTIONS(9335),
    [aux_sym_where_condition_token1] = ACTIONS(9337),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9335),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9335),
    [anon_sym_LBRACK] = ACTIONS(9335),
    [aux_sym_basic_type_token6] = ACTIONS(9337),
    [aux_sym_basic_type_token22] = ACTIONS(9337),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9335),
    [aux_sym_addafter_modification_token1] = ACTIONS(9335),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9335),
    [aux_sym_modify_modification_token1] = ACTIONS(9335),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9335),
    [aux_sym_movelast_modification_token1] = ACTIONS(9335),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9335),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9335),
    [aux_sym_separator_action_token1] = ACTIONS(9335),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9335),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9335),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9335),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9335),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9335),
    [anon_sym_POUNDif] = ACTIONS(9335),
    [anon_sym_POUNDIF] = ACTIONS(9335),
    [anon_sym_POUNDIf] = ACTIONS(9335),
    [anon_sym_POUNDelif] = ACTIONS(9335),
    [anon_sym_POUNDELIF] = ACTIONS(9335),
    [anon_sym_POUNDElif] = ACTIONS(9335),
    [anon_sym_POUNDelse] = ACTIONS(9335),
    [anon_sym_POUNDELSE] = ACTIONS(9335),
    [anon_sym_POUNDElse] = ACTIONS(9335),
    [anon_sym_POUNDelse2] = ACTIONS(9335),
    [anon_sym_POUNDELSE2] = ACTIONS(9335),
    [anon_sym_POUNDElse2] = ACTIONS(9335),
    [anon_sym_POUNDendif] = ACTIONS(9335),
    [anon_sym_POUNDENDIF] = ACTIONS(9335),
    [anon_sym_POUNDEndif] = ACTIONS(9335),
    [anon_sym_POUNDendif2] = ACTIONS(9335),
    [anon_sym_POUNDENDIF2] = ACTIONS(9335),
    [anon_sym_POUNDEndif2] = ACTIONS(9335),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9335),
    [sym_trigger_keyword] = ACTIONS(9335),
    [sym_var_keyword] = ACTIONS(9335),
    [sym_local_keyword] = ACTIONS(9335),
    [sym_internal_keyword] = ACTIONS(9335),
    [sym_protected_keyword] = ACTIONS(9335),
    [sym_event_keyword] = ACTIONS(9335),
    [sym_fields_keyword] = ACTIONS(9335),
    [sym_keys_keyword] = ACTIONS(9335),
    [sym_fieldgroups_keyword] = ACTIONS(9335),
    [sym_actions_keyword] = ACTIONS(9335),
    [sym_layout_keyword] = ACTIONS(9335),
    [sym_area_keyword] = ACTIONS(9335),
    [sym_group_keyword] = ACTIONS(9335),
    [sym_repeater_keyword] = ACTIONS(9335),
    [sym_cuegroup_keyword] = ACTIONS(9335),
    [sym_fixed_keyword] = ACTIONS(9335),
    [sym_grid_keyword] = ACTIONS(9335),
    [sym_part_keyword] = ACTIONS(9335),
    [sym_systempart_keyword] = ACTIONS(9335),
    [sym_usercontrol_keyword] = ACTIONS(9335),
    [sym_dataset_keyword] = ACTIONS(9335),
    [sym_elements_keyword] = ACTIONS(9335),
    [sym_dataitem_keyword] = ACTIONS(9335),
    [sym_column_keyword] = ACTIONS(9335),
    [sym_filter_keyword] = ACTIONS(9335),
    [sym_labels_keyword] = ACTIONS(9335),
    [sym_rendering_keyword] = ACTIONS(9335),
    [sym_requestpage_keyword] = ACTIONS(9335),
    [sym_schema_keyword] = ACTIONS(9335),
    [sym_views_keyword] = ACTIONS(9335),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9335),
    [sym_preproc_open] = ACTIONS(9335),
    [sym_preproc_close] = ACTIONS(9335),
  },
  [STATE(4118)] = {
    [anon_sym_SEMI] = ACTIONS(9331),
    [aux_sym_where_condition_token1] = ACTIONS(9333),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9331),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9331),
    [anon_sym_LBRACK] = ACTIONS(9331),
    [aux_sym_basic_type_token6] = ACTIONS(9333),
    [aux_sym_basic_type_token22] = ACTIONS(9333),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9331),
    [aux_sym_addafter_modification_token1] = ACTIONS(9331),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9331),
    [aux_sym_modify_modification_token1] = ACTIONS(9331),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9331),
    [aux_sym_movelast_modification_token1] = ACTIONS(9331),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9331),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9331),
    [aux_sym_separator_action_token1] = ACTIONS(9331),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9331),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9331),
    [anon_sym_POUNDif] = ACTIONS(9331),
    [anon_sym_POUNDIF] = ACTIONS(9331),
    [anon_sym_POUNDIf] = ACTIONS(9331),
    [anon_sym_POUNDelif] = ACTIONS(9331),
    [anon_sym_POUNDELIF] = ACTIONS(9331),
    [anon_sym_POUNDElif] = ACTIONS(9331),
    [anon_sym_POUNDelse] = ACTIONS(9331),
    [anon_sym_POUNDELSE] = ACTIONS(9331),
    [anon_sym_POUNDElse] = ACTIONS(9331),
    [anon_sym_POUNDelse2] = ACTIONS(9331),
    [anon_sym_POUNDELSE2] = ACTIONS(9331),
    [anon_sym_POUNDElse2] = ACTIONS(9331),
    [anon_sym_POUNDendif] = ACTIONS(9331),
    [anon_sym_POUNDENDIF] = ACTIONS(9331),
    [anon_sym_POUNDEndif] = ACTIONS(9331),
    [anon_sym_POUNDendif2] = ACTIONS(9331),
    [anon_sym_POUNDENDIF2] = ACTIONS(9331),
    [anon_sym_POUNDEndif2] = ACTIONS(9331),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9331),
    [sym_trigger_keyword] = ACTIONS(9331),
    [sym_var_keyword] = ACTIONS(9331),
    [sym_local_keyword] = ACTIONS(9331),
    [sym_internal_keyword] = ACTIONS(9331),
    [sym_protected_keyword] = ACTIONS(9331),
    [sym_event_keyword] = ACTIONS(9331),
    [sym_fields_keyword] = ACTIONS(9331),
    [sym_keys_keyword] = ACTIONS(9331),
    [sym_fieldgroups_keyword] = ACTIONS(9331),
    [sym_actions_keyword] = ACTIONS(9331),
    [sym_layout_keyword] = ACTIONS(9331),
    [sym_area_keyword] = ACTIONS(9331),
    [sym_group_keyword] = ACTIONS(9331),
    [sym_repeater_keyword] = ACTIONS(9331),
    [sym_cuegroup_keyword] = ACTIONS(9331),
    [sym_fixed_keyword] = ACTIONS(9331),
    [sym_grid_keyword] = ACTIONS(9331),
    [sym_part_keyword] = ACTIONS(9331),
    [sym_systempart_keyword] = ACTIONS(9331),
    [sym_usercontrol_keyword] = ACTIONS(9331),
    [sym_dataset_keyword] = ACTIONS(9331),
    [sym_elements_keyword] = ACTIONS(9331),
    [sym_dataitem_keyword] = ACTIONS(9331),
    [sym_column_keyword] = ACTIONS(9331),
    [sym_filter_keyword] = ACTIONS(9331),
    [sym_labels_keyword] = ACTIONS(9331),
    [sym_rendering_keyword] = ACTIONS(9331),
    [sym_requestpage_keyword] = ACTIONS(9331),
    [sym_schema_keyword] = ACTIONS(9331),
    [sym_views_keyword] = ACTIONS(9331),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9331),
    [sym_preproc_open] = ACTIONS(9331),
    [sym_preproc_close] = ACTIONS(9331),
  },
  [STATE(4119)] = {
    [anon_sym_SEMI] = ACTIONS(9339),
    [aux_sym_where_condition_token1] = ACTIONS(9341),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9339),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9339),
    [anon_sym_LBRACK] = ACTIONS(9339),
    [aux_sym_basic_type_token6] = ACTIONS(9341),
    [aux_sym_basic_type_token22] = ACTIONS(9341),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9339),
    [aux_sym_addafter_modification_token1] = ACTIONS(9339),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9339),
    [aux_sym_modify_modification_token1] = ACTIONS(9339),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9339),
    [aux_sym_movelast_modification_token1] = ACTIONS(9339),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9339),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9339),
    [aux_sym_separator_action_token1] = ACTIONS(9339),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9339),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9339),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9339),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9339),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9339),
    [anon_sym_POUNDif] = ACTIONS(9339),
    [anon_sym_POUNDIF] = ACTIONS(9339),
    [anon_sym_POUNDIf] = ACTIONS(9339),
    [anon_sym_POUNDelif] = ACTIONS(9339),
    [anon_sym_POUNDELIF] = ACTIONS(9339),
    [anon_sym_POUNDElif] = ACTIONS(9339),
    [anon_sym_POUNDelse] = ACTIONS(9339),
    [anon_sym_POUNDELSE] = ACTIONS(9339),
    [anon_sym_POUNDElse] = ACTIONS(9339),
    [anon_sym_POUNDelse2] = ACTIONS(9339),
    [anon_sym_POUNDELSE2] = ACTIONS(9339),
    [anon_sym_POUNDElse2] = ACTIONS(9339),
    [anon_sym_POUNDendif] = ACTIONS(9339),
    [anon_sym_POUNDENDIF] = ACTIONS(9339),
    [anon_sym_POUNDEndif] = ACTIONS(9339),
    [anon_sym_POUNDendif2] = ACTIONS(9339),
    [anon_sym_POUNDENDIF2] = ACTIONS(9339),
    [anon_sym_POUNDEndif2] = ACTIONS(9339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9339),
    [sym_trigger_keyword] = ACTIONS(9339),
    [sym_var_keyword] = ACTIONS(9339),
    [sym_local_keyword] = ACTIONS(9339),
    [sym_internal_keyword] = ACTIONS(9339),
    [sym_protected_keyword] = ACTIONS(9339),
    [sym_event_keyword] = ACTIONS(9339),
    [sym_fields_keyword] = ACTIONS(9339),
    [sym_keys_keyword] = ACTIONS(9339),
    [sym_fieldgroups_keyword] = ACTIONS(9339),
    [sym_actions_keyword] = ACTIONS(9339),
    [sym_layout_keyword] = ACTIONS(9339),
    [sym_area_keyword] = ACTIONS(9339),
    [sym_group_keyword] = ACTIONS(9339),
    [sym_repeater_keyword] = ACTIONS(9339),
    [sym_cuegroup_keyword] = ACTIONS(9339),
    [sym_fixed_keyword] = ACTIONS(9339),
    [sym_grid_keyword] = ACTIONS(9339),
    [sym_part_keyword] = ACTIONS(9339),
    [sym_systempart_keyword] = ACTIONS(9339),
    [sym_usercontrol_keyword] = ACTIONS(9339),
    [sym_dataset_keyword] = ACTIONS(9339),
    [sym_elements_keyword] = ACTIONS(9339),
    [sym_dataitem_keyword] = ACTIONS(9339),
    [sym_column_keyword] = ACTIONS(9339),
    [sym_filter_keyword] = ACTIONS(9339),
    [sym_labels_keyword] = ACTIONS(9339),
    [sym_rendering_keyword] = ACTIONS(9339),
    [sym_requestpage_keyword] = ACTIONS(9339),
    [sym_schema_keyword] = ACTIONS(9339),
    [sym_views_keyword] = ACTIONS(9339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9339),
    [sym_preproc_open] = ACTIONS(9339),
    [sym_preproc_close] = ACTIONS(9339),
  },
  [STATE(4120)] = {
    [anon_sym_SEMI] = ACTIONS(9343),
    [aux_sym_where_condition_token1] = ACTIONS(9345),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9343),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9343),
    [anon_sym_LBRACK] = ACTIONS(9343),
    [aux_sym_basic_type_token6] = ACTIONS(9345),
    [aux_sym_basic_type_token22] = ACTIONS(9345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9343),
    [aux_sym_addafter_modification_token1] = ACTIONS(9343),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9343),
    [aux_sym_modify_modification_token1] = ACTIONS(9343),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9343),
    [aux_sym_movelast_modification_token1] = ACTIONS(9343),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9343),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9343),
    [aux_sym_separator_action_token1] = ACTIONS(9343),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9343),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9343),
    [anon_sym_POUNDif] = ACTIONS(9343),
    [anon_sym_POUNDIF] = ACTIONS(9343),
    [anon_sym_POUNDIf] = ACTIONS(9343),
    [anon_sym_POUNDelif] = ACTIONS(9343),
    [anon_sym_POUNDELIF] = ACTIONS(9343),
    [anon_sym_POUNDElif] = ACTIONS(9343),
    [anon_sym_POUNDelse] = ACTIONS(9343),
    [anon_sym_POUNDELSE] = ACTIONS(9343),
    [anon_sym_POUNDElse] = ACTIONS(9343),
    [anon_sym_POUNDelse2] = ACTIONS(9343),
    [anon_sym_POUNDELSE2] = ACTIONS(9343),
    [anon_sym_POUNDElse2] = ACTIONS(9343),
    [anon_sym_POUNDendif] = ACTIONS(9343),
    [anon_sym_POUNDENDIF] = ACTIONS(9343),
    [anon_sym_POUNDEndif] = ACTIONS(9343),
    [anon_sym_POUNDendif2] = ACTIONS(9343),
    [anon_sym_POUNDENDIF2] = ACTIONS(9343),
    [anon_sym_POUNDEndif2] = ACTIONS(9343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9343),
    [sym_trigger_keyword] = ACTIONS(9343),
    [sym_var_keyword] = ACTIONS(9343),
    [sym_local_keyword] = ACTIONS(9343),
    [sym_internal_keyword] = ACTIONS(9343),
    [sym_protected_keyword] = ACTIONS(9343),
    [sym_event_keyword] = ACTIONS(9343),
    [sym_fields_keyword] = ACTIONS(9343),
    [sym_keys_keyword] = ACTIONS(9343),
    [sym_fieldgroups_keyword] = ACTIONS(9343),
    [sym_actions_keyword] = ACTIONS(9343),
    [sym_layout_keyword] = ACTIONS(9343),
    [sym_area_keyword] = ACTIONS(9343),
    [sym_group_keyword] = ACTIONS(9343),
    [sym_repeater_keyword] = ACTIONS(9343),
    [sym_cuegroup_keyword] = ACTIONS(9343),
    [sym_fixed_keyword] = ACTIONS(9343),
    [sym_grid_keyword] = ACTIONS(9343),
    [sym_part_keyword] = ACTIONS(9343),
    [sym_systempart_keyword] = ACTIONS(9343),
    [sym_usercontrol_keyword] = ACTIONS(9343),
    [sym_dataset_keyword] = ACTIONS(9343),
    [sym_elements_keyword] = ACTIONS(9343),
    [sym_dataitem_keyword] = ACTIONS(9343),
    [sym_column_keyword] = ACTIONS(9343),
    [sym_filter_keyword] = ACTIONS(9343),
    [sym_labels_keyword] = ACTIONS(9343),
    [sym_rendering_keyword] = ACTIONS(9343),
    [sym_requestpage_keyword] = ACTIONS(9343),
    [sym_schema_keyword] = ACTIONS(9343),
    [sym_views_keyword] = ACTIONS(9343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9343),
    [sym_preproc_open] = ACTIONS(9343),
    [sym_preproc_close] = ACTIONS(9343),
  },
  [STATE(4121)] = {
    [anon_sym_SEMI] = ACTIONS(9347),
    [aux_sym_where_condition_token1] = ACTIONS(9349),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9347),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9347),
    [anon_sym_LBRACK] = ACTIONS(9347),
    [aux_sym_basic_type_token6] = ACTIONS(9349),
    [aux_sym_basic_type_token22] = ACTIONS(9349),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9347),
    [aux_sym_addafter_modification_token1] = ACTIONS(9347),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9347),
    [aux_sym_modify_modification_token1] = ACTIONS(9347),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9347),
    [aux_sym_movelast_modification_token1] = ACTIONS(9347),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9347),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9347),
    [aux_sym_separator_action_token1] = ACTIONS(9347),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9347),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9347),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9347),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9347),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9347),
    [anon_sym_POUNDif] = ACTIONS(9347),
    [anon_sym_POUNDIF] = ACTIONS(9347),
    [anon_sym_POUNDIf] = ACTIONS(9347),
    [anon_sym_POUNDelif] = ACTIONS(9347),
    [anon_sym_POUNDELIF] = ACTIONS(9347),
    [anon_sym_POUNDElif] = ACTIONS(9347),
    [anon_sym_POUNDelse] = ACTIONS(9347),
    [anon_sym_POUNDELSE] = ACTIONS(9347),
    [anon_sym_POUNDElse] = ACTIONS(9347),
    [anon_sym_POUNDelse2] = ACTIONS(9347),
    [anon_sym_POUNDELSE2] = ACTIONS(9347),
    [anon_sym_POUNDElse2] = ACTIONS(9347),
    [anon_sym_POUNDendif] = ACTIONS(9347),
    [anon_sym_POUNDENDIF] = ACTIONS(9347),
    [anon_sym_POUNDEndif] = ACTIONS(9347),
    [anon_sym_POUNDendif2] = ACTIONS(9347),
    [anon_sym_POUNDENDIF2] = ACTIONS(9347),
    [anon_sym_POUNDEndif2] = ACTIONS(9347),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9347),
    [sym_trigger_keyword] = ACTIONS(9347),
    [sym_var_keyword] = ACTIONS(9347),
    [sym_local_keyword] = ACTIONS(9347),
    [sym_internal_keyword] = ACTIONS(9347),
    [sym_protected_keyword] = ACTIONS(9347),
    [sym_event_keyword] = ACTIONS(9347),
    [sym_fields_keyword] = ACTIONS(9347),
    [sym_keys_keyword] = ACTIONS(9347),
    [sym_fieldgroups_keyword] = ACTIONS(9347),
    [sym_actions_keyword] = ACTIONS(9347),
    [sym_layout_keyword] = ACTIONS(9347),
    [sym_area_keyword] = ACTIONS(9347),
    [sym_group_keyword] = ACTIONS(9347),
    [sym_repeater_keyword] = ACTIONS(9347),
    [sym_cuegroup_keyword] = ACTIONS(9347),
    [sym_fixed_keyword] = ACTIONS(9347),
    [sym_grid_keyword] = ACTIONS(9347),
    [sym_part_keyword] = ACTIONS(9347),
    [sym_systempart_keyword] = ACTIONS(9347),
    [sym_usercontrol_keyword] = ACTIONS(9347),
    [sym_dataset_keyword] = ACTIONS(9347),
    [sym_elements_keyword] = ACTIONS(9347),
    [sym_dataitem_keyword] = ACTIONS(9347),
    [sym_column_keyword] = ACTIONS(9347),
    [sym_filter_keyword] = ACTIONS(9347),
    [sym_labels_keyword] = ACTIONS(9347),
    [sym_rendering_keyword] = ACTIONS(9347),
    [sym_requestpage_keyword] = ACTIONS(9347),
    [sym_schema_keyword] = ACTIONS(9347),
    [sym_views_keyword] = ACTIONS(9347),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9347),
    [sym_preproc_open] = ACTIONS(9347),
    [sym_preproc_close] = ACTIONS(9347),
  },
  [STATE(4122)] = {
    [anon_sym_SEMI] = ACTIONS(9351),
    [aux_sym_where_condition_token1] = ACTIONS(9353),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9351),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9351),
    [anon_sym_LBRACK] = ACTIONS(9351),
    [aux_sym_basic_type_token6] = ACTIONS(9353),
    [aux_sym_basic_type_token22] = ACTIONS(9353),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9351),
    [aux_sym_addafter_modification_token1] = ACTIONS(9351),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9351),
    [aux_sym_modify_modification_token1] = ACTIONS(9351),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9351),
    [aux_sym_movelast_modification_token1] = ACTIONS(9351),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9351),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9351),
    [aux_sym_separator_action_token1] = ACTIONS(9351),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9351),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9351),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9351),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9351),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9351),
    [anon_sym_POUNDif] = ACTIONS(9351),
    [anon_sym_POUNDIF] = ACTIONS(9351),
    [anon_sym_POUNDIf] = ACTIONS(9351),
    [anon_sym_POUNDelif] = ACTIONS(9351),
    [anon_sym_POUNDELIF] = ACTIONS(9351),
    [anon_sym_POUNDElif] = ACTIONS(9351),
    [anon_sym_POUNDelse] = ACTIONS(9351),
    [anon_sym_POUNDELSE] = ACTIONS(9351),
    [anon_sym_POUNDElse] = ACTIONS(9351),
    [anon_sym_POUNDelse2] = ACTIONS(9351),
    [anon_sym_POUNDELSE2] = ACTIONS(9351),
    [anon_sym_POUNDElse2] = ACTIONS(9351),
    [anon_sym_POUNDendif] = ACTIONS(9351),
    [anon_sym_POUNDENDIF] = ACTIONS(9351),
    [anon_sym_POUNDEndif] = ACTIONS(9351),
    [anon_sym_POUNDendif2] = ACTIONS(9351),
    [anon_sym_POUNDENDIF2] = ACTIONS(9351),
    [anon_sym_POUNDEndif2] = ACTIONS(9351),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9351),
    [sym_trigger_keyword] = ACTIONS(9351),
    [sym_var_keyword] = ACTIONS(9351),
    [sym_local_keyword] = ACTIONS(9351),
    [sym_internal_keyword] = ACTIONS(9351),
    [sym_protected_keyword] = ACTIONS(9351),
    [sym_event_keyword] = ACTIONS(9351),
    [sym_fields_keyword] = ACTIONS(9351),
    [sym_keys_keyword] = ACTIONS(9351),
    [sym_fieldgroups_keyword] = ACTIONS(9351),
    [sym_actions_keyword] = ACTIONS(9351),
    [sym_layout_keyword] = ACTIONS(9351),
    [sym_area_keyword] = ACTIONS(9351),
    [sym_group_keyword] = ACTIONS(9351),
    [sym_repeater_keyword] = ACTIONS(9351),
    [sym_cuegroup_keyword] = ACTIONS(9351),
    [sym_fixed_keyword] = ACTIONS(9351),
    [sym_grid_keyword] = ACTIONS(9351),
    [sym_part_keyword] = ACTIONS(9351),
    [sym_systempart_keyword] = ACTIONS(9351),
    [sym_usercontrol_keyword] = ACTIONS(9351),
    [sym_dataset_keyword] = ACTIONS(9351),
    [sym_elements_keyword] = ACTIONS(9351),
    [sym_dataitem_keyword] = ACTIONS(9351),
    [sym_column_keyword] = ACTIONS(9351),
    [sym_filter_keyword] = ACTIONS(9351),
    [sym_labels_keyword] = ACTIONS(9351),
    [sym_rendering_keyword] = ACTIONS(9351),
    [sym_requestpage_keyword] = ACTIONS(9351),
    [sym_schema_keyword] = ACTIONS(9351),
    [sym_views_keyword] = ACTIONS(9351),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9351),
    [sym_preproc_open] = ACTIONS(9351),
    [sym_preproc_close] = ACTIONS(9351),
  },
  [STATE(4123)] = {
    [anon_sym_SEMI] = ACTIONS(9355),
    [aux_sym_where_condition_token1] = ACTIONS(9357),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9355),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9355),
    [anon_sym_LBRACK] = ACTIONS(9355),
    [aux_sym_basic_type_token6] = ACTIONS(9357),
    [aux_sym_basic_type_token22] = ACTIONS(9357),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9355),
    [aux_sym_addafter_modification_token1] = ACTIONS(9355),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9355),
    [aux_sym_modify_modification_token1] = ACTIONS(9355),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9355),
    [aux_sym_movelast_modification_token1] = ACTIONS(9355),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9355),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9355),
    [aux_sym_separator_action_token1] = ACTIONS(9355),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9355),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9355),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9355),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9355),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9355),
    [anon_sym_POUNDif] = ACTIONS(9355),
    [anon_sym_POUNDIF] = ACTIONS(9355),
    [anon_sym_POUNDIf] = ACTIONS(9355),
    [anon_sym_POUNDelif] = ACTIONS(9355),
    [anon_sym_POUNDELIF] = ACTIONS(9355),
    [anon_sym_POUNDElif] = ACTIONS(9355),
    [anon_sym_POUNDelse] = ACTIONS(9355),
    [anon_sym_POUNDELSE] = ACTIONS(9355),
    [anon_sym_POUNDElse] = ACTIONS(9355),
    [anon_sym_POUNDelse2] = ACTIONS(9355),
    [anon_sym_POUNDELSE2] = ACTIONS(9355),
    [anon_sym_POUNDElse2] = ACTIONS(9355),
    [anon_sym_POUNDendif] = ACTIONS(9355),
    [anon_sym_POUNDENDIF] = ACTIONS(9355),
    [anon_sym_POUNDEndif] = ACTIONS(9355),
    [anon_sym_POUNDendif2] = ACTIONS(9355),
    [anon_sym_POUNDENDIF2] = ACTIONS(9355),
    [anon_sym_POUNDEndif2] = ACTIONS(9355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9355),
    [sym_trigger_keyword] = ACTIONS(9355),
    [sym_var_keyword] = ACTIONS(9355),
    [sym_local_keyword] = ACTIONS(9355),
    [sym_internal_keyword] = ACTIONS(9355),
    [sym_protected_keyword] = ACTIONS(9355),
    [sym_event_keyword] = ACTIONS(9355),
    [sym_fields_keyword] = ACTIONS(9355),
    [sym_keys_keyword] = ACTIONS(9355),
    [sym_fieldgroups_keyword] = ACTIONS(9355),
    [sym_actions_keyword] = ACTIONS(9355),
    [sym_layout_keyword] = ACTIONS(9355),
    [sym_area_keyword] = ACTIONS(9355),
    [sym_group_keyword] = ACTIONS(9355),
    [sym_repeater_keyword] = ACTIONS(9355),
    [sym_cuegroup_keyword] = ACTIONS(9355),
    [sym_fixed_keyword] = ACTIONS(9355),
    [sym_grid_keyword] = ACTIONS(9355),
    [sym_part_keyword] = ACTIONS(9355),
    [sym_systempart_keyword] = ACTIONS(9355),
    [sym_usercontrol_keyword] = ACTIONS(9355),
    [sym_dataset_keyword] = ACTIONS(9355),
    [sym_elements_keyword] = ACTIONS(9355),
    [sym_dataitem_keyword] = ACTIONS(9355),
    [sym_column_keyword] = ACTIONS(9355),
    [sym_filter_keyword] = ACTIONS(9355),
    [sym_labels_keyword] = ACTIONS(9355),
    [sym_rendering_keyword] = ACTIONS(9355),
    [sym_requestpage_keyword] = ACTIONS(9355),
    [sym_schema_keyword] = ACTIONS(9355),
    [sym_views_keyword] = ACTIONS(9355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9355),
    [sym_preproc_open] = ACTIONS(9355),
    [sym_preproc_close] = ACTIONS(9355),
  },
  [STATE(4124)] = {
    [anon_sym_SEMI] = ACTIONS(9359),
    [aux_sym_where_condition_token1] = ACTIONS(9361),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9359),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9359),
    [anon_sym_LBRACK] = ACTIONS(9359),
    [aux_sym_basic_type_token6] = ACTIONS(9361),
    [aux_sym_basic_type_token22] = ACTIONS(9361),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9359),
    [aux_sym_addafter_modification_token1] = ACTIONS(9359),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9359),
    [aux_sym_modify_modification_token1] = ACTIONS(9359),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9359),
    [aux_sym_movelast_modification_token1] = ACTIONS(9359),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9359),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9359),
    [aux_sym_separator_action_token1] = ACTIONS(9359),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9359),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9359),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9359),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9359),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9359),
    [anon_sym_POUNDif] = ACTIONS(9359),
    [anon_sym_POUNDIF] = ACTIONS(9359),
    [anon_sym_POUNDIf] = ACTIONS(9359),
    [anon_sym_POUNDelif] = ACTIONS(9359),
    [anon_sym_POUNDELIF] = ACTIONS(9359),
    [anon_sym_POUNDElif] = ACTIONS(9359),
    [anon_sym_POUNDelse] = ACTIONS(9359),
    [anon_sym_POUNDELSE] = ACTIONS(9359),
    [anon_sym_POUNDElse] = ACTIONS(9359),
    [anon_sym_POUNDelse2] = ACTIONS(9359),
    [anon_sym_POUNDELSE2] = ACTIONS(9359),
    [anon_sym_POUNDElse2] = ACTIONS(9359),
    [anon_sym_POUNDendif] = ACTIONS(9359),
    [anon_sym_POUNDENDIF] = ACTIONS(9359),
    [anon_sym_POUNDEndif] = ACTIONS(9359),
    [anon_sym_POUNDendif2] = ACTIONS(9359),
    [anon_sym_POUNDENDIF2] = ACTIONS(9359),
    [anon_sym_POUNDEndif2] = ACTIONS(9359),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9359),
    [sym_trigger_keyword] = ACTIONS(9359),
    [sym_var_keyword] = ACTIONS(9359),
    [sym_local_keyword] = ACTIONS(9359),
    [sym_internal_keyword] = ACTIONS(9359),
    [sym_protected_keyword] = ACTIONS(9359),
    [sym_event_keyword] = ACTIONS(9359),
    [sym_fields_keyword] = ACTIONS(9359),
    [sym_keys_keyword] = ACTIONS(9359),
    [sym_fieldgroups_keyword] = ACTIONS(9359),
    [sym_actions_keyword] = ACTIONS(9359),
    [sym_layout_keyword] = ACTIONS(9359),
    [sym_area_keyword] = ACTIONS(9359),
    [sym_group_keyword] = ACTIONS(9359),
    [sym_repeater_keyword] = ACTIONS(9359),
    [sym_cuegroup_keyword] = ACTIONS(9359),
    [sym_fixed_keyword] = ACTIONS(9359),
    [sym_grid_keyword] = ACTIONS(9359),
    [sym_part_keyword] = ACTIONS(9359),
    [sym_systempart_keyword] = ACTIONS(9359),
    [sym_usercontrol_keyword] = ACTIONS(9359),
    [sym_dataset_keyword] = ACTIONS(9359),
    [sym_elements_keyword] = ACTIONS(9359),
    [sym_dataitem_keyword] = ACTIONS(9359),
    [sym_column_keyword] = ACTIONS(9359),
    [sym_filter_keyword] = ACTIONS(9359),
    [sym_labels_keyword] = ACTIONS(9359),
    [sym_rendering_keyword] = ACTIONS(9359),
    [sym_requestpage_keyword] = ACTIONS(9359),
    [sym_schema_keyword] = ACTIONS(9359),
    [sym_views_keyword] = ACTIONS(9359),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9359),
    [sym_preproc_open] = ACTIONS(9359),
    [sym_preproc_close] = ACTIONS(9359),
  },
  [STATE(4125)] = {
    [anon_sym_SEMI] = ACTIONS(9363),
    [aux_sym_where_condition_token1] = ACTIONS(9365),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9363),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9363),
    [anon_sym_LBRACK] = ACTIONS(9363),
    [aux_sym_basic_type_token6] = ACTIONS(9365),
    [aux_sym_basic_type_token22] = ACTIONS(9365),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9363),
    [aux_sym_addafter_modification_token1] = ACTIONS(9363),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9363),
    [aux_sym_modify_modification_token1] = ACTIONS(9363),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9363),
    [aux_sym_movelast_modification_token1] = ACTIONS(9363),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9363),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9363),
    [aux_sym_separator_action_token1] = ACTIONS(9363),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9363),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9363),
    [anon_sym_POUNDif] = ACTIONS(9363),
    [anon_sym_POUNDIF] = ACTIONS(9363),
    [anon_sym_POUNDIf] = ACTIONS(9363),
    [anon_sym_POUNDelif] = ACTIONS(9363),
    [anon_sym_POUNDELIF] = ACTIONS(9363),
    [anon_sym_POUNDElif] = ACTIONS(9363),
    [anon_sym_POUNDelse] = ACTIONS(9363),
    [anon_sym_POUNDELSE] = ACTIONS(9363),
    [anon_sym_POUNDElse] = ACTIONS(9363),
    [anon_sym_POUNDelse2] = ACTIONS(9363),
    [anon_sym_POUNDELSE2] = ACTIONS(9363),
    [anon_sym_POUNDElse2] = ACTIONS(9363),
    [anon_sym_POUNDendif] = ACTIONS(9363),
    [anon_sym_POUNDENDIF] = ACTIONS(9363),
    [anon_sym_POUNDEndif] = ACTIONS(9363),
    [anon_sym_POUNDendif2] = ACTIONS(9363),
    [anon_sym_POUNDENDIF2] = ACTIONS(9363),
    [anon_sym_POUNDEndif2] = ACTIONS(9363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9363),
    [sym_trigger_keyword] = ACTIONS(9363),
    [sym_var_keyword] = ACTIONS(9363),
    [sym_local_keyword] = ACTIONS(9363),
    [sym_internal_keyword] = ACTIONS(9363),
    [sym_protected_keyword] = ACTIONS(9363),
    [sym_event_keyword] = ACTIONS(9363),
    [sym_fields_keyword] = ACTIONS(9363),
    [sym_keys_keyword] = ACTIONS(9363),
    [sym_fieldgroups_keyword] = ACTIONS(9363),
    [sym_actions_keyword] = ACTIONS(9363),
    [sym_layout_keyword] = ACTIONS(9363),
    [sym_area_keyword] = ACTIONS(9363),
    [sym_group_keyword] = ACTIONS(9363),
    [sym_repeater_keyword] = ACTIONS(9363),
    [sym_cuegroup_keyword] = ACTIONS(9363),
    [sym_fixed_keyword] = ACTIONS(9363),
    [sym_grid_keyword] = ACTIONS(9363),
    [sym_part_keyword] = ACTIONS(9363),
    [sym_systempart_keyword] = ACTIONS(9363),
    [sym_usercontrol_keyword] = ACTIONS(9363),
    [sym_dataset_keyword] = ACTIONS(9363),
    [sym_elements_keyword] = ACTIONS(9363),
    [sym_dataitem_keyword] = ACTIONS(9363),
    [sym_column_keyword] = ACTIONS(9363),
    [sym_filter_keyword] = ACTIONS(9363),
    [sym_labels_keyword] = ACTIONS(9363),
    [sym_rendering_keyword] = ACTIONS(9363),
    [sym_requestpage_keyword] = ACTIONS(9363),
    [sym_schema_keyword] = ACTIONS(9363),
    [sym_views_keyword] = ACTIONS(9363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9363),
    [sym_preproc_open] = ACTIONS(9363),
    [sym_preproc_close] = ACTIONS(9363),
  },
  [STATE(4126)] = {
    [anon_sym_SEMI] = ACTIONS(9367),
    [aux_sym_where_condition_token1] = ACTIONS(9369),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9367),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9367),
    [anon_sym_LBRACK] = ACTIONS(9367),
    [aux_sym_basic_type_token6] = ACTIONS(9369),
    [aux_sym_basic_type_token22] = ACTIONS(9369),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9367),
    [aux_sym_addafter_modification_token1] = ACTIONS(9367),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9367),
    [aux_sym_modify_modification_token1] = ACTIONS(9367),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9367),
    [aux_sym_movelast_modification_token1] = ACTIONS(9367),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9367),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9367),
    [aux_sym_separator_action_token1] = ACTIONS(9367),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9367),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9367),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9367),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9367),
    [anon_sym_POUNDif] = ACTIONS(9367),
    [anon_sym_POUNDIF] = ACTIONS(9367),
    [anon_sym_POUNDIf] = ACTIONS(9367),
    [anon_sym_POUNDelif] = ACTIONS(9367),
    [anon_sym_POUNDELIF] = ACTIONS(9367),
    [anon_sym_POUNDElif] = ACTIONS(9367),
    [anon_sym_POUNDelse] = ACTIONS(9367),
    [anon_sym_POUNDELSE] = ACTIONS(9367),
    [anon_sym_POUNDElse] = ACTIONS(9367),
    [anon_sym_POUNDelse2] = ACTIONS(9367),
    [anon_sym_POUNDELSE2] = ACTIONS(9367),
    [anon_sym_POUNDElse2] = ACTIONS(9367),
    [anon_sym_POUNDendif] = ACTIONS(9367),
    [anon_sym_POUNDENDIF] = ACTIONS(9367),
    [anon_sym_POUNDEndif] = ACTIONS(9367),
    [anon_sym_POUNDendif2] = ACTIONS(9367),
    [anon_sym_POUNDENDIF2] = ACTIONS(9367),
    [anon_sym_POUNDEndif2] = ACTIONS(9367),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9367),
    [sym_trigger_keyword] = ACTIONS(9367),
    [sym_var_keyword] = ACTIONS(9367),
    [sym_local_keyword] = ACTIONS(9367),
    [sym_internal_keyword] = ACTIONS(9367),
    [sym_protected_keyword] = ACTIONS(9367),
    [sym_event_keyword] = ACTIONS(9367),
    [sym_fields_keyword] = ACTIONS(9367),
    [sym_keys_keyword] = ACTIONS(9367),
    [sym_fieldgroups_keyword] = ACTIONS(9367),
    [sym_actions_keyword] = ACTIONS(9367),
    [sym_layout_keyword] = ACTIONS(9367),
    [sym_area_keyword] = ACTIONS(9367),
    [sym_group_keyword] = ACTIONS(9367),
    [sym_repeater_keyword] = ACTIONS(9367),
    [sym_cuegroup_keyword] = ACTIONS(9367),
    [sym_fixed_keyword] = ACTIONS(9367),
    [sym_grid_keyword] = ACTIONS(9367),
    [sym_part_keyword] = ACTIONS(9367),
    [sym_systempart_keyword] = ACTIONS(9367),
    [sym_usercontrol_keyword] = ACTIONS(9367),
    [sym_dataset_keyword] = ACTIONS(9367),
    [sym_elements_keyword] = ACTIONS(9367),
    [sym_dataitem_keyword] = ACTIONS(9367),
    [sym_column_keyword] = ACTIONS(9367),
    [sym_filter_keyword] = ACTIONS(9367),
    [sym_labels_keyword] = ACTIONS(9367),
    [sym_rendering_keyword] = ACTIONS(9367),
    [sym_requestpage_keyword] = ACTIONS(9367),
    [sym_schema_keyword] = ACTIONS(9367),
    [sym_views_keyword] = ACTIONS(9367),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9367),
    [sym_preproc_open] = ACTIONS(9367),
    [sym_preproc_close] = ACTIONS(9367),
  },
  [STATE(4127)] = {
    [anon_sym_SEMI] = ACTIONS(9363),
    [aux_sym_where_condition_token1] = ACTIONS(9365),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9363),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9363),
    [anon_sym_LBRACK] = ACTIONS(9363),
    [aux_sym_basic_type_token6] = ACTIONS(9365),
    [aux_sym_basic_type_token22] = ACTIONS(9365),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9363),
    [aux_sym_addafter_modification_token1] = ACTIONS(9363),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9363),
    [aux_sym_modify_modification_token1] = ACTIONS(9363),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9363),
    [aux_sym_movelast_modification_token1] = ACTIONS(9363),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9363),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9363),
    [aux_sym_separator_action_token1] = ACTIONS(9363),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9363),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9363),
    [anon_sym_POUNDif] = ACTIONS(9363),
    [anon_sym_POUNDIF] = ACTIONS(9363),
    [anon_sym_POUNDIf] = ACTIONS(9363),
    [anon_sym_POUNDelif] = ACTIONS(9363),
    [anon_sym_POUNDELIF] = ACTIONS(9363),
    [anon_sym_POUNDElif] = ACTIONS(9363),
    [anon_sym_POUNDelse] = ACTIONS(9363),
    [anon_sym_POUNDELSE] = ACTIONS(9363),
    [anon_sym_POUNDElse] = ACTIONS(9363),
    [anon_sym_POUNDelse2] = ACTIONS(9363),
    [anon_sym_POUNDELSE2] = ACTIONS(9363),
    [anon_sym_POUNDElse2] = ACTIONS(9363),
    [anon_sym_POUNDendif] = ACTIONS(9363),
    [anon_sym_POUNDENDIF] = ACTIONS(9363),
    [anon_sym_POUNDEndif] = ACTIONS(9363),
    [anon_sym_POUNDendif2] = ACTIONS(9363),
    [anon_sym_POUNDENDIF2] = ACTIONS(9363),
    [anon_sym_POUNDEndif2] = ACTIONS(9363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9363),
    [sym_trigger_keyword] = ACTIONS(9363),
    [sym_var_keyword] = ACTIONS(9363),
    [sym_local_keyword] = ACTIONS(9363),
    [sym_internal_keyword] = ACTIONS(9363),
    [sym_protected_keyword] = ACTIONS(9363),
    [sym_event_keyword] = ACTIONS(9363),
    [sym_fields_keyword] = ACTIONS(9363),
    [sym_keys_keyword] = ACTIONS(9363),
    [sym_fieldgroups_keyword] = ACTIONS(9363),
    [sym_actions_keyword] = ACTIONS(9363),
    [sym_layout_keyword] = ACTIONS(9363),
    [sym_area_keyword] = ACTIONS(9363),
    [sym_group_keyword] = ACTIONS(9363),
    [sym_repeater_keyword] = ACTIONS(9363),
    [sym_cuegroup_keyword] = ACTIONS(9363),
    [sym_fixed_keyword] = ACTIONS(9363),
    [sym_grid_keyword] = ACTIONS(9363),
    [sym_part_keyword] = ACTIONS(9363),
    [sym_systempart_keyword] = ACTIONS(9363),
    [sym_usercontrol_keyword] = ACTIONS(9363),
    [sym_dataset_keyword] = ACTIONS(9363),
    [sym_elements_keyword] = ACTIONS(9363),
    [sym_dataitem_keyword] = ACTIONS(9363),
    [sym_column_keyword] = ACTIONS(9363),
    [sym_filter_keyword] = ACTIONS(9363),
    [sym_labels_keyword] = ACTIONS(9363),
    [sym_rendering_keyword] = ACTIONS(9363),
    [sym_requestpage_keyword] = ACTIONS(9363),
    [sym_schema_keyword] = ACTIONS(9363),
    [sym_views_keyword] = ACTIONS(9363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9363),
    [sym_preproc_open] = ACTIONS(9363),
    [sym_preproc_close] = ACTIONS(9363),
  },
  [STATE(4128)] = {
    [anon_sym_SEMI] = ACTIONS(9371),
    [aux_sym_where_condition_token1] = ACTIONS(9373),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9371),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9371),
    [anon_sym_LBRACK] = ACTIONS(9371),
    [aux_sym_basic_type_token6] = ACTIONS(9373),
    [aux_sym_basic_type_token22] = ACTIONS(9373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9371),
    [aux_sym_addafter_modification_token1] = ACTIONS(9371),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9371),
    [aux_sym_modify_modification_token1] = ACTIONS(9371),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9371),
    [aux_sym_movelast_modification_token1] = ACTIONS(9371),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9371),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9371),
    [aux_sym_separator_action_token1] = ACTIONS(9371),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9371),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9371),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9371),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9371),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9371),
    [anon_sym_POUNDif] = ACTIONS(9371),
    [anon_sym_POUNDIF] = ACTIONS(9371),
    [anon_sym_POUNDIf] = ACTIONS(9371),
    [anon_sym_POUNDelif] = ACTIONS(9371),
    [anon_sym_POUNDELIF] = ACTIONS(9371),
    [anon_sym_POUNDElif] = ACTIONS(9371),
    [anon_sym_POUNDelse] = ACTIONS(9371),
    [anon_sym_POUNDELSE] = ACTIONS(9371),
    [anon_sym_POUNDElse] = ACTIONS(9371),
    [anon_sym_POUNDelse2] = ACTIONS(9371),
    [anon_sym_POUNDELSE2] = ACTIONS(9371),
    [anon_sym_POUNDElse2] = ACTIONS(9371),
    [anon_sym_POUNDendif] = ACTIONS(9371),
    [anon_sym_POUNDENDIF] = ACTIONS(9371),
    [anon_sym_POUNDEndif] = ACTIONS(9371),
    [anon_sym_POUNDendif2] = ACTIONS(9371),
    [anon_sym_POUNDENDIF2] = ACTIONS(9371),
    [anon_sym_POUNDEndif2] = ACTIONS(9371),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9371),
    [sym_trigger_keyword] = ACTIONS(9371),
    [sym_var_keyword] = ACTIONS(9371),
    [sym_local_keyword] = ACTIONS(9371),
    [sym_internal_keyword] = ACTIONS(9371),
    [sym_protected_keyword] = ACTIONS(9371),
    [sym_event_keyword] = ACTIONS(9371),
    [sym_fields_keyword] = ACTIONS(9371),
    [sym_keys_keyword] = ACTIONS(9371),
    [sym_fieldgroups_keyword] = ACTIONS(9371),
    [sym_actions_keyword] = ACTIONS(9371),
    [sym_layout_keyword] = ACTIONS(9371),
    [sym_area_keyword] = ACTIONS(9371),
    [sym_group_keyword] = ACTIONS(9371),
    [sym_repeater_keyword] = ACTIONS(9371),
    [sym_cuegroup_keyword] = ACTIONS(9371),
    [sym_fixed_keyword] = ACTIONS(9371),
    [sym_grid_keyword] = ACTIONS(9371),
    [sym_part_keyword] = ACTIONS(9371),
    [sym_systempart_keyword] = ACTIONS(9371),
    [sym_usercontrol_keyword] = ACTIONS(9371),
    [sym_dataset_keyword] = ACTIONS(9371),
    [sym_elements_keyword] = ACTIONS(9371),
    [sym_dataitem_keyword] = ACTIONS(9371),
    [sym_column_keyword] = ACTIONS(9371),
    [sym_filter_keyword] = ACTIONS(9371),
    [sym_labels_keyword] = ACTIONS(9371),
    [sym_rendering_keyword] = ACTIONS(9371),
    [sym_requestpage_keyword] = ACTIONS(9371),
    [sym_schema_keyword] = ACTIONS(9371),
    [sym_views_keyword] = ACTIONS(9371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9371),
    [sym_preproc_open] = ACTIONS(9371),
    [sym_preproc_close] = ACTIONS(9371),
  },
  [STATE(4129)] = {
    [anon_sym_SEMI] = ACTIONS(9375),
    [aux_sym_where_condition_token1] = ACTIONS(9377),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9375),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9375),
    [anon_sym_LBRACK] = ACTIONS(9375),
    [aux_sym_basic_type_token6] = ACTIONS(9377),
    [aux_sym_basic_type_token22] = ACTIONS(9377),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9375),
    [aux_sym_addafter_modification_token1] = ACTIONS(9375),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9375),
    [aux_sym_modify_modification_token1] = ACTIONS(9375),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9375),
    [aux_sym_movelast_modification_token1] = ACTIONS(9375),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9375),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9375),
    [aux_sym_separator_action_token1] = ACTIONS(9375),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9375),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9375),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9375),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9375),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9375),
    [anon_sym_POUNDif] = ACTIONS(9375),
    [anon_sym_POUNDIF] = ACTIONS(9375),
    [anon_sym_POUNDIf] = ACTIONS(9375),
    [anon_sym_POUNDelif] = ACTIONS(9375),
    [anon_sym_POUNDELIF] = ACTIONS(9375),
    [anon_sym_POUNDElif] = ACTIONS(9375),
    [anon_sym_POUNDelse] = ACTIONS(9375),
    [anon_sym_POUNDELSE] = ACTIONS(9375),
    [anon_sym_POUNDElse] = ACTIONS(9375),
    [anon_sym_POUNDelse2] = ACTIONS(9375),
    [anon_sym_POUNDELSE2] = ACTIONS(9375),
    [anon_sym_POUNDElse2] = ACTIONS(9375),
    [anon_sym_POUNDendif] = ACTIONS(9375),
    [anon_sym_POUNDENDIF] = ACTIONS(9375),
    [anon_sym_POUNDEndif] = ACTIONS(9375),
    [anon_sym_POUNDendif2] = ACTIONS(9375),
    [anon_sym_POUNDENDIF2] = ACTIONS(9375),
    [anon_sym_POUNDEndif2] = ACTIONS(9375),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9375),
    [sym_trigger_keyword] = ACTIONS(9375),
    [sym_var_keyword] = ACTIONS(9375),
    [sym_local_keyword] = ACTIONS(9375),
    [sym_internal_keyword] = ACTIONS(9375),
    [sym_protected_keyword] = ACTIONS(9375),
    [sym_event_keyword] = ACTIONS(9375),
    [sym_fields_keyword] = ACTIONS(9375),
    [sym_keys_keyword] = ACTIONS(9375),
    [sym_fieldgroups_keyword] = ACTIONS(9375),
    [sym_actions_keyword] = ACTIONS(9375),
    [sym_layout_keyword] = ACTIONS(9375),
    [sym_area_keyword] = ACTIONS(9375),
    [sym_group_keyword] = ACTIONS(9375),
    [sym_repeater_keyword] = ACTIONS(9375),
    [sym_cuegroup_keyword] = ACTIONS(9375),
    [sym_fixed_keyword] = ACTIONS(9375),
    [sym_grid_keyword] = ACTIONS(9375),
    [sym_part_keyword] = ACTIONS(9375),
    [sym_systempart_keyword] = ACTIONS(9375),
    [sym_usercontrol_keyword] = ACTIONS(9375),
    [sym_dataset_keyword] = ACTIONS(9375),
    [sym_elements_keyword] = ACTIONS(9375),
    [sym_dataitem_keyword] = ACTIONS(9375),
    [sym_column_keyword] = ACTIONS(9375),
    [sym_filter_keyword] = ACTIONS(9375),
    [sym_labels_keyword] = ACTIONS(9375),
    [sym_rendering_keyword] = ACTIONS(9375),
    [sym_requestpage_keyword] = ACTIONS(9375),
    [sym_schema_keyword] = ACTIONS(9375),
    [sym_views_keyword] = ACTIONS(9375),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9375),
    [sym_preproc_open] = ACTIONS(9375),
    [sym_preproc_close] = ACTIONS(9375),
  },
  [STATE(4130)] = {
    [anon_sym_SEMI] = ACTIONS(9363),
    [aux_sym_where_condition_token1] = ACTIONS(9365),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9363),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9363),
    [anon_sym_LBRACK] = ACTIONS(9363),
    [aux_sym_basic_type_token6] = ACTIONS(9365),
    [aux_sym_basic_type_token22] = ACTIONS(9365),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9363),
    [aux_sym_addafter_modification_token1] = ACTIONS(9363),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9363),
    [aux_sym_modify_modification_token1] = ACTIONS(9363),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9363),
    [aux_sym_movelast_modification_token1] = ACTIONS(9363),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9363),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9363),
    [aux_sym_separator_action_token1] = ACTIONS(9363),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9363),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9363),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9363),
    [anon_sym_POUNDif] = ACTIONS(9363),
    [anon_sym_POUNDIF] = ACTIONS(9363),
    [anon_sym_POUNDIf] = ACTIONS(9363),
    [anon_sym_POUNDelif] = ACTIONS(9363),
    [anon_sym_POUNDELIF] = ACTIONS(9363),
    [anon_sym_POUNDElif] = ACTIONS(9363),
    [anon_sym_POUNDelse] = ACTIONS(9363),
    [anon_sym_POUNDELSE] = ACTIONS(9363),
    [anon_sym_POUNDElse] = ACTIONS(9363),
    [anon_sym_POUNDelse2] = ACTIONS(9363),
    [anon_sym_POUNDELSE2] = ACTIONS(9363),
    [anon_sym_POUNDElse2] = ACTIONS(9363),
    [anon_sym_POUNDendif] = ACTIONS(9363),
    [anon_sym_POUNDENDIF] = ACTIONS(9363),
    [anon_sym_POUNDEndif] = ACTIONS(9363),
    [anon_sym_POUNDendif2] = ACTIONS(9363),
    [anon_sym_POUNDENDIF2] = ACTIONS(9363),
    [anon_sym_POUNDEndif2] = ACTIONS(9363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9363),
    [sym_trigger_keyword] = ACTIONS(9363),
    [sym_var_keyword] = ACTIONS(9363),
    [sym_local_keyword] = ACTIONS(9363),
    [sym_internal_keyword] = ACTIONS(9363),
    [sym_protected_keyword] = ACTIONS(9363),
    [sym_event_keyword] = ACTIONS(9363),
    [sym_fields_keyword] = ACTIONS(9363),
    [sym_keys_keyword] = ACTIONS(9363),
    [sym_fieldgroups_keyword] = ACTIONS(9363),
    [sym_actions_keyword] = ACTIONS(9363),
    [sym_layout_keyword] = ACTIONS(9363),
    [sym_area_keyword] = ACTIONS(9363),
    [sym_group_keyword] = ACTIONS(9363),
    [sym_repeater_keyword] = ACTIONS(9363),
    [sym_cuegroup_keyword] = ACTIONS(9363),
    [sym_fixed_keyword] = ACTIONS(9363),
    [sym_grid_keyword] = ACTIONS(9363),
    [sym_part_keyword] = ACTIONS(9363),
    [sym_systempart_keyword] = ACTIONS(9363),
    [sym_usercontrol_keyword] = ACTIONS(9363),
    [sym_dataset_keyword] = ACTIONS(9363),
    [sym_elements_keyword] = ACTIONS(9363),
    [sym_dataitem_keyword] = ACTIONS(9363),
    [sym_column_keyword] = ACTIONS(9363),
    [sym_filter_keyword] = ACTIONS(9363),
    [sym_labels_keyword] = ACTIONS(9363),
    [sym_rendering_keyword] = ACTIONS(9363),
    [sym_requestpage_keyword] = ACTIONS(9363),
    [sym_schema_keyword] = ACTIONS(9363),
    [sym_views_keyword] = ACTIONS(9363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9363),
    [sym_preproc_open] = ACTIONS(9363),
    [sym_preproc_close] = ACTIONS(9363),
  },
  [STATE(4131)] = {
    [anon_sym_SEMI] = ACTIONS(9367),
    [aux_sym_where_condition_token1] = ACTIONS(9369),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9367),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9367),
    [anon_sym_LBRACK] = ACTIONS(9367),
    [aux_sym_basic_type_token6] = ACTIONS(9369),
    [aux_sym_basic_type_token22] = ACTIONS(9369),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9367),
    [aux_sym_addafter_modification_token1] = ACTIONS(9367),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9367),
    [aux_sym_modify_modification_token1] = ACTIONS(9367),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9367),
    [aux_sym_movelast_modification_token1] = ACTIONS(9367),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9367),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9367),
    [aux_sym_separator_action_token1] = ACTIONS(9367),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9367),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9367),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9367),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9367),
    [anon_sym_POUNDif] = ACTIONS(9367),
    [anon_sym_POUNDIF] = ACTIONS(9367),
    [anon_sym_POUNDIf] = ACTIONS(9367),
    [anon_sym_POUNDelif] = ACTIONS(9367),
    [anon_sym_POUNDELIF] = ACTIONS(9367),
    [anon_sym_POUNDElif] = ACTIONS(9367),
    [anon_sym_POUNDelse] = ACTIONS(9367),
    [anon_sym_POUNDELSE] = ACTIONS(9367),
    [anon_sym_POUNDElse] = ACTIONS(9367),
    [anon_sym_POUNDelse2] = ACTIONS(9367),
    [anon_sym_POUNDELSE2] = ACTIONS(9367),
    [anon_sym_POUNDElse2] = ACTIONS(9367),
    [anon_sym_POUNDendif] = ACTIONS(9367),
    [anon_sym_POUNDENDIF] = ACTIONS(9367),
    [anon_sym_POUNDEndif] = ACTIONS(9367),
    [anon_sym_POUNDendif2] = ACTIONS(9367),
    [anon_sym_POUNDENDIF2] = ACTIONS(9367),
    [anon_sym_POUNDEndif2] = ACTIONS(9367),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9367),
    [sym_trigger_keyword] = ACTIONS(9367),
    [sym_var_keyword] = ACTIONS(9367),
    [sym_local_keyword] = ACTIONS(9367),
    [sym_internal_keyword] = ACTIONS(9367),
    [sym_protected_keyword] = ACTIONS(9367),
    [sym_event_keyword] = ACTIONS(9367),
    [sym_fields_keyword] = ACTIONS(9367),
    [sym_keys_keyword] = ACTIONS(9367),
    [sym_fieldgroups_keyword] = ACTIONS(9367),
    [sym_actions_keyword] = ACTIONS(9367),
    [sym_layout_keyword] = ACTIONS(9367),
    [sym_area_keyword] = ACTIONS(9367),
    [sym_group_keyword] = ACTIONS(9367),
    [sym_repeater_keyword] = ACTIONS(9367),
    [sym_cuegroup_keyword] = ACTIONS(9367),
    [sym_fixed_keyword] = ACTIONS(9367),
    [sym_grid_keyword] = ACTIONS(9367),
    [sym_part_keyword] = ACTIONS(9367),
    [sym_systempart_keyword] = ACTIONS(9367),
    [sym_usercontrol_keyword] = ACTIONS(9367),
    [sym_dataset_keyword] = ACTIONS(9367),
    [sym_elements_keyword] = ACTIONS(9367),
    [sym_dataitem_keyword] = ACTIONS(9367),
    [sym_column_keyword] = ACTIONS(9367),
    [sym_filter_keyword] = ACTIONS(9367),
    [sym_labels_keyword] = ACTIONS(9367),
    [sym_rendering_keyword] = ACTIONS(9367),
    [sym_requestpage_keyword] = ACTIONS(9367),
    [sym_schema_keyword] = ACTIONS(9367),
    [sym_views_keyword] = ACTIONS(9367),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9367),
    [sym_preproc_open] = ACTIONS(9367),
    [sym_preproc_close] = ACTIONS(9367),
  },
  [STATE(4132)] = {
    [anon_sym_SEMI] = ACTIONS(9379),
    [aux_sym_where_condition_token1] = ACTIONS(9381),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9379),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9379),
    [anon_sym_LBRACK] = ACTIONS(9379),
    [aux_sym_basic_type_token6] = ACTIONS(9381),
    [aux_sym_basic_type_token22] = ACTIONS(9381),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9379),
    [aux_sym_addafter_modification_token1] = ACTIONS(9379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9379),
    [aux_sym_modify_modification_token1] = ACTIONS(9379),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9379),
    [aux_sym_movelast_modification_token1] = ACTIONS(9379),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9379),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9379),
    [aux_sym_separator_action_token1] = ACTIONS(9379),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9379),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9379),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9379),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9379),
    [anon_sym_POUNDif] = ACTIONS(9379),
    [anon_sym_POUNDIF] = ACTIONS(9379),
    [anon_sym_POUNDIf] = ACTIONS(9379),
    [anon_sym_POUNDelif] = ACTIONS(9379),
    [anon_sym_POUNDELIF] = ACTIONS(9379),
    [anon_sym_POUNDElif] = ACTIONS(9379),
    [anon_sym_POUNDelse] = ACTIONS(9379),
    [anon_sym_POUNDELSE] = ACTIONS(9379),
    [anon_sym_POUNDElse] = ACTIONS(9379),
    [anon_sym_POUNDelse2] = ACTIONS(9379),
    [anon_sym_POUNDELSE2] = ACTIONS(9379),
    [anon_sym_POUNDElse2] = ACTIONS(9379),
    [anon_sym_POUNDendif] = ACTIONS(9379),
    [anon_sym_POUNDENDIF] = ACTIONS(9379),
    [anon_sym_POUNDEndif] = ACTIONS(9379),
    [anon_sym_POUNDendif2] = ACTIONS(9379),
    [anon_sym_POUNDENDIF2] = ACTIONS(9379),
    [anon_sym_POUNDEndif2] = ACTIONS(9379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9379),
    [sym_trigger_keyword] = ACTIONS(9379),
    [sym_var_keyword] = ACTIONS(9379),
    [sym_local_keyword] = ACTIONS(9379),
    [sym_internal_keyword] = ACTIONS(9379),
    [sym_protected_keyword] = ACTIONS(9379),
    [sym_event_keyword] = ACTIONS(9379),
    [sym_fields_keyword] = ACTIONS(9379),
    [sym_keys_keyword] = ACTIONS(9379),
    [sym_fieldgroups_keyword] = ACTIONS(9379),
    [sym_actions_keyword] = ACTIONS(9379),
    [sym_layout_keyword] = ACTIONS(9379),
    [sym_area_keyword] = ACTIONS(9379),
    [sym_group_keyword] = ACTIONS(9379),
    [sym_repeater_keyword] = ACTIONS(9379),
    [sym_cuegroup_keyword] = ACTIONS(9379),
    [sym_fixed_keyword] = ACTIONS(9379),
    [sym_grid_keyword] = ACTIONS(9379),
    [sym_part_keyword] = ACTIONS(9379),
    [sym_systempart_keyword] = ACTIONS(9379),
    [sym_usercontrol_keyword] = ACTIONS(9379),
    [sym_dataset_keyword] = ACTIONS(9379),
    [sym_elements_keyword] = ACTIONS(9379),
    [sym_dataitem_keyword] = ACTIONS(9379),
    [sym_column_keyword] = ACTIONS(9379),
    [sym_filter_keyword] = ACTIONS(9379),
    [sym_labels_keyword] = ACTIONS(9379),
    [sym_rendering_keyword] = ACTIONS(9379),
    [sym_requestpage_keyword] = ACTIONS(9379),
    [sym_schema_keyword] = ACTIONS(9379),
    [sym_views_keyword] = ACTIONS(9379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9379),
    [sym_preproc_open] = ACTIONS(9379),
    [sym_preproc_close] = ACTIONS(9379),
  },
  [STATE(4133)] = {
    [anon_sym_SEMI] = ACTIONS(9383),
    [aux_sym_where_condition_token1] = ACTIONS(9385),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9383),
    [anon_sym_LBRACK] = ACTIONS(9383),
    [aux_sym_basic_type_token6] = ACTIONS(9385),
    [aux_sym_basic_type_token22] = ACTIONS(9385),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9383),
    [aux_sym_addafter_modification_token1] = ACTIONS(9383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9383),
    [aux_sym_modify_modification_token1] = ACTIONS(9383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9383),
    [aux_sym_movelast_modification_token1] = ACTIONS(9383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9383),
    [aux_sym_separator_action_token1] = ACTIONS(9383),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9383),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9383),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9383),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9383),
    [anon_sym_POUNDif] = ACTIONS(9383),
    [anon_sym_POUNDIF] = ACTIONS(9383),
    [anon_sym_POUNDIf] = ACTIONS(9383),
    [anon_sym_POUNDelif] = ACTIONS(9383),
    [anon_sym_POUNDELIF] = ACTIONS(9383),
    [anon_sym_POUNDElif] = ACTIONS(9383),
    [anon_sym_POUNDelse] = ACTIONS(9383),
    [anon_sym_POUNDELSE] = ACTIONS(9383),
    [anon_sym_POUNDElse] = ACTIONS(9383),
    [anon_sym_POUNDelse2] = ACTIONS(9383),
    [anon_sym_POUNDELSE2] = ACTIONS(9383),
    [anon_sym_POUNDElse2] = ACTIONS(9383),
    [anon_sym_POUNDendif] = ACTIONS(9383),
    [anon_sym_POUNDENDIF] = ACTIONS(9383),
    [anon_sym_POUNDEndif] = ACTIONS(9383),
    [anon_sym_POUNDendif2] = ACTIONS(9383),
    [anon_sym_POUNDENDIF2] = ACTIONS(9383),
    [anon_sym_POUNDEndif2] = ACTIONS(9383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9383),
    [sym_trigger_keyword] = ACTIONS(9383),
    [sym_var_keyword] = ACTIONS(9383),
    [sym_local_keyword] = ACTIONS(9383),
    [sym_internal_keyword] = ACTIONS(9383),
    [sym_protected_keyword] = ACTIONS(9383),
    [sym_event_keyword] = ACTIONS(9383),
    [sym_fields_keyword] = ACTIONS(9383),
    [sym_keys_keyword] = ACTIONS(9383),
    [sym_fieldgroups_keyword] = ACTIONS(9383),
    [sym_actions_keyword] = ACTIONS(9383),
    [sym_layout_keyword] = ACTIONS(9383),
    [sym_area_keyword] = ACTIONS(9383),
    [sym_group_keyword] = ACTIONS(9383),
    [sym_repeater_keyword] = ACTIONS(9383),
    [sym_cuegroup_keyword] = ACTIONS(9383),
    [sym_fixed_keyword] = ACTIONS(9383),
    [sym_grid_keyword] = ACTIONS(9383),
    [sym_part_keyword] = ACTIONS(9383),
    [sym_systempart_keyword] = ACTIONS(9383),
    [sym_usercontrol_keyword] = ACTIONS(9383),
    [sym_dataset_keyword] = ACTIONS(9383),
    [sym_elements_keyword] = ACTIONS(9383),
    [sym_dataitem_keyword] = ACTIONS(9383),
    [sym_column_keyword] = ACTIONS(9383),
    [sym_filter_keyword] = ACTIONS(9383),
    [sym_labels_keyword] = ACTIONS(9383),
    [sym_rendering_keyword] = ACTIONS(9383),
    [sym_requestpage_keyword] = ACTIONS(9383),
    [sym_schema_keyword] = ACTIONS(9383),
    [sym_views_keyword] = ACTIONS(9383),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9383),
    [sym_preproc_open] = ACTIONS(9383),
    [sym_preproc_close] = ACTIONS(9383),
  },
  [STATE(4134)] = {
    [anon_sym_SEMI] = ACTIONS(9379),
    [aux_sym_where_condition_token1] = ACTIONS(9381),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9379),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9379),
    [anon_sym_LBRACK] = ACTIONS(9379),
    [aux_sym_basic_type_token6] = ACTIONS(9381),
    [aux_sym_basic_type_token22] = ACTIONS(9381),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9379),
    [aux_sym_addafter_modification_token1] = ACTIONS(9379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9379),
    [aux_sym_modify_modification_token1] = ACTIONS(9379),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9379),
    [aux_sym_movelast_modification_token1] = ACTIONS(9379),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9379),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9379),
    [aux_sym_separator_action_token1] = ACTIONS(9379),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9379),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9379),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9379),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9379),
    [anon_sym_POUNDif] = ACTIONS(9379),
    [anon_sym_POUNDIF] = ACTIONS(9379),
    [anon_sym_POUNDIf] = ACTIONS(9379),
    [anon_sym_POUNDelif] = ACTIONS(9379),
    [anon_sym_POUNDELIF] = ACTIONS(9379),
    [anon_sym_POUNDElif] = ACTIONS(9379),
    [anon_sym_POUNDelse] = ACTIONS(9379),
    [anon_sym_POUNDELSE] = ACTIONS(9379),
    [anon_sym_POUNDElse] = ACTIONS(9379),
    [anon_sym_POUNDelse2] = ACTIONS(9379),
    [anon_sym_POUNDELSE2] = ACTIONS(9379),
    [anon_sym_POUNDElse2] = ACTIONS(9379),
    [anon_sym_POUNDendif] = ACTIONS(9379),
    [anon_sym_POUNDENDIF] = ACTIONS(9379),
    [anon_sym_POUNDEndif] = ACTIONS(9379),
    [anon_sym_POUNDendif2] = ACTIONS(9379),
    [anon_sym_POUNDENDIF2] = ACTIONS(9379),
    [anon_sym_POUNDEndif2] = ACTIONS(9379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9379),
    [sym_trigger_keyword] = ACTIONS(9379),
    [sym_var_keyword] = ACTIONS(9379),
    [sym_local_keyword] = ACTIONS(9379),
    [sym_internal_keyword] = ACTIONS(9379),
    [sym_protected_keyword] = ACTIONS(9379),
    [sym_event_keyword] = ACTIONS(9379),
    [sym_fields_keyword] = ACTIONS(9379),
    [sym_keys_keyword] = ACTIONS(9379),
    [sym_fieldgroups_keyword] = ACTIONS(9379),
    [sym_actions_keyword] = ACTIONS(9379),
    [sym_layout_keyword] = ACTIONS(9379),
    [sym_area_keyword] = ACTIONS(9379),
    [sym_group_keyword] = ACTIONS(9379),
    [sym_repeater_keyword] = ACTIONS(9379),
    [sym_cuegroup_keyword] = ACTIONS(9379),
    [sym_fixed_keyword] = ACTIONS(9379),
    [sym_grid_keyword] = ACTIONS(9379),
    [sym_part_keyword] = ACTIONS(9379),
    [sym_systempart_keyword] = ACTIONS(9379),
    [sym_usercontrol_keyword] = ACTIONS(9379),
    [sym_dataset_keyword] = ACTIONS(9379),
    [sym_elements_keyword] = ACTIONS(9379),
    [sym_dataitem_keyword] = ACTIONS(9379),
    [sym_column_keyword] = ACTIONS(9379),
    [sym_filter_keyword] = ACTIONS(9379),
    [sym_labels_keyword] = ACTIONS(9379),
    [sym_rendering_keyword] = ACTIONS(9379),
    [sym_requestpage_keyword] = ACTIONS(9379),
    [sym_schema_keyword] = ACTIONS(9379),
    [sym_views_keyword] = ACTIONS(9379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9379),
    [sym_preproc_open] = ACTIONS(9379),
    [sym_preproc_close] = ACTIONS(9379),
  },
  [STATE(4135)] = {
    [anon_sym_SEMI] = ACTIONS(9387),
    [aux_sym_where_condition_token1] = ACTIONS(9389),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9387),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9387),
    [anon_sym_LBRACK] = ACTIONS(9387),
    [aux_sym_basic_type_token6] = ACTIONS(9389),
    [aux_sym_basic_type_token22] = ACTIONS(9389),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9387),
    [aux_sym_addafter_modification_token1] = ACTIONS(9387),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9387),
    [aux_sym_modify_modification_token1] = ACTIONS(9387),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9387),
    [aux_sym_movelast_modification_token1] = ACTIONS(9387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9387),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9387),
    [aux_sym_separator_action_token1] = ACTIONS(9387),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9387),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9387),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9387),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9387),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9387),
    [anon_sym_POUNDif] = ACTIONS(9387),
    [anon_sym_POUNDIF] = ACTIONS(9387),
    [anon_sym_POUNDIf] = ACTIONS(9387),
    [anon_sym_POUNDelif] = ACTIONS(9387),
    [anon_sym_POUNDELIF] = ACTIONS(9387),
    [anon_sym_POUNDElif] = ACTIONS(9387),
    [anon_sym_POUNDelse] = ACTIONS(9387),
    [anon_sym_POUNDELSE] = ACTIONS(9387),
    [anon_sym_POUNDElse] = ACTIONS(9387),
    [anon_sym_POUNDelse2] = ACTIONS(9387),
    [anon_sym_POUNDELSE2] = ACTIONS(9387),
    [anon_sym_POUNDElse2] = ACTIONS(9387),
    [anon_sym_POUNDendif] = ACTIONS(9387),
    [anon_sym_POUNDENDIF] = ACTIONS(9387),
    [anon_sym_POUNDEndif] = ACTIONS(9387),
    [anon_sym_POUNDendif2] = ACTIONS(9387),
    [anon_sym_POUNDENDIF2] = ACTIONS(9387),
    [anon_sym_POUNDEndif2] = ACTIONS(9387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9387),
    [sym_trigger_keyword] = ACTIONS(9387),
    [sym_var_keyword] = ACTIONS(9387),
    [sym_local_keyword] = ACTIONS(9387),
    [sym_internal_keyword] = ACTIONS(9387),
    [sym_protected_keyword] = ACTIONS(9387),
    [sym_event_keyword] = ACTIONS(9387),
    [sym_fields_keyword] = ACTIONS(9387),
    [sym_keys_keyword] = ACTIONS(9387),
    [sym_fieldgroups_keyword] = ACTIONS(9387),
    [sym_actions_keyword] = ACTIONS(9387),
    [sym_layout_keyword] = ACTIONS(9387),
    [sym_area_keyword] = ACTIONS(9387),
    [sym_group_keyword] = ACTIONS(9387),
    [sym_repeater_keyword] = ACTIONS(9387),
    [sym_cuegroup_keyword] = ACTIONS(9387),
    [sym_fixed_keyword] = ACTIONS(9387),
    [sym_grid_keyword] = ACTIONS(9387),
    [sym_part_keyword] = ACTIONS(9387),
    [sym_systempart_keyword] = ACTIONS(9387),
    [sym_usercontrol_keyword] = ACTIONS(9387),
    [sym_dataset_keyword] = ACTIONS(9387),
    [sym_elements_keyword] = ACTIONS(9387),
    [sym_dataitem_keyword] = ACTIONS(9387),
    [sym_column_keyword] = ACTIONS(9387),
    [sym_filter_keyword] = ACTIONS(9387),
    [sym_labels_keyword] = ACTIONS(9387),
    [sym_rendering_keyword] = ACTIONS(9387),
    [sym_requestpage_keyword] = ACTIONS(9387),
    [sym_schema_keyword] = ACTIONS(9387),
    [sym_views_keyword] = ACTIONS(9387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9387),
    [sym_preproc_open] = ACTIONS(9387),
    [sym_preproc_close] = ACTIONS(9387),
  },
  [STATE(4136)] = {
    [anon_sym_SEMI] = ACTIONS(9331),
    [aux_sym_where_condition_token1] = ACTIONS(9333),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9331),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9331),
    [anon_sym_LBRACK] = ACTIONS(9331),
    [aux_sym_basic_type_token6] = ACTIONS(9333),
    [aux_sym_basic_type_token22] = ACTIONS(9333),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9331),
    [aux_sym_addafter_modification_token1] = ACTIONS(9331),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9331),
    [aux_sym_modify_modification_token1] = ACTIONS(9331),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9331),
    [aux_sym_movelast_modification_token1] = ACTIONS(9331),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9331),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9331),
    [aux_sym_separator_action_token1] = ACTIONS(9331),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9331),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9331),
    [anon_sym_POUNDif] = ACTIONS(9331),
    [anon_sym_POUNDIF] = ACTIONS(9331),
    [anon_sym_POUNDIf] = ACTIONS(9331),
    [anon_sym_POUNDelif] = ACTIONS(9331),
    [anon_sym_POUNDELIF] = ACTIONS(9331),
    [anon_sym_POUNDElif] = ACTIONS(9331),
    [anon_sym_POUNDelse] = ACTIONS(9331),
    [anon_sym_POUNDELSE] = ACTIONS(9331),
    [anon_sym_POUNDElse] = ACTIONS(9331),
    [anon_sym_POUNDelse2] = ACTIONS(9331),
    [anon_sym_POUNDELSE2] = ACTIONS(9331),
    [anon_sym_POUNDElse2] = ACTIONS(9331),
    [anon_sym_POUNDendif] = ACTIONS(9331),
    [anon_sym_POUNDENDIF] = ACTIONS(9331),
    [anon_sym_POUNDEndif] = ACTIONS(9331),
    [anon_sym_POUNDendif2] = ACTIONS(9331),
    [anon_sym_POUNDENDIF2] = ACTIONS(9331),
    [anon_sym_POUNDEndif2] = ACTIONS(9331),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9331),
    [sym_trigger_keyword] = ACTIONS(9331),
    [sym_var_keyword] = ACTIONS(9331),
    [sym_local_keyword] = ACTIONS(9331),
    [sym_internal_keyword] = ACTIONS(9331),
    [sym_protected_keyword] = ACTIONS(9331),
    [sym_event_keyword] = ACTIONS(9331),
    [sym_fields_keyword] = ACTIONS(9331),
    [sym_keys_keyword] = ACTIONS(9331),
    [sym_fieldgroups_keyword] = ACTIONS(9331),
    [sym_actions_keyword] = ACTIONS(9331),
    [sym_layout_keyword] = ACTIONS(9331),
    [sym_area_keyword] = ACTIONS(9331),
    [sym_group_keyword] = ACTIONS(9331),
    [sym_repeater_keyword] = ACTIONS(9331),
    [sym_cuegroup_keyword] = ACTIONS(9331),
    [sym_fixed_keyword] = ACTIONS(9331),
    [sym_grid_keyword] = ACTIONS(9331),
    [sym_part_keyword] = ACTIONS(9331),
    [sym_systempart_keyword] = ACTIONS(9331),
    [sym_usercontrol_keyword] = ACTIONS(9331),
    [sym_dataset_keyword] = ACTIONS(9331),
    [sym_elements_keyword] = ACTIONS(9331),
    [sym_dataitem_keyword] = ACTIONS(9331),
    [sym_column_keyword] = ACTIONS(9331),
    [sym_filter_keyword] = ACTIONS(9331),
    [sym_labels_keyword] = ACTIONS(9331),
    [sym_rendering_keyword] = ACTIONS(9331),
    [sym_requestpage_keyword] = ACTIONS(9331),
    [sym_schema_keyword] = ACTIONS(9331),
    [sym_views_keyword] = ACTIONS(9331),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9331),
    [sym_preproc_open] = ACTIONS(9331),
    [sym_preproc_close] = ACTIONS(9331),
  },
  [STATE(4137)] = {
    [anon_sym_SEMI] = ACTIONS(9335),
    [aux_sym_where_condition_token1] = ACTIONS(9337),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9335),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9335),
    [anon_sym_LBRACK] = ACTIONS(9335),
    [aux_sym_basic_type_token6] = ACTIONS(9337),
    [aux_sym_basic_type_token22] = ACTIONS(9337),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9335),
    [aux_sym_addafter_modification_token1] = ACTIONS(9335),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9335),
    [aux_sym_modify_modification_token1] = ACTIONS(9335),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9335),
    [aux_sym_movelast_modification_token1] = ACTIONS(9335),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9335),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9335),
    [aux_sym_separator_action_token1] = ACTIONS(9335),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9335),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9335),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9335),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9335),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9335),
    [anon_sym_POUNDif] = ACTIONS(9335),
    [anon_sym_POUNDIF] = ACTIONS(9335),
    [anon_sym_POUNDIf] = ACTIONS(9335),
    [anon_sym_POUNDelif] = ACTIONS(9335),
    [anon_sym_POUNDELIF] = ACTIONS(9335),
    [anon_sym_POUNDElif] = ACTIONS(9335),
    [anon_sym_POUNDelse] = ACTIONS(9335),
    [anon_sym_POUNDELSE] = ACTIONS(9335),
    [anon_sym_POUNDElse] = ACTIONS(9335),
    [anon_sym_POUNDelse2] = ACTIONS(9335),
    [anon_sym_POUNDELSE2] = ACTIONS(9335),
    [anon_sym_POUNDElse2] = ACTIONS(9335),
    [anon_sym_POUNDendif] = ACTIONS(9335),
    [anon_sym_POUNDENDIF] = ACTIONS(9335),
    [anon_sym_POUNDEndif] = ACTIONS(9335),
    [anon_sym_POUNDendif2] = ACTIONS(9335),
    [anon_sym_POUNDENDIF2] = ACTIONS(9335),
    [anon_sym_POUNDEndif2] = ACTIONS(9335),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9335),
    [sym_trigger_keyword] = ACTIONS(9335),
    [sym_var_keyword] = ACTIONS(9335),
    [sym_local_keyword] = ACTIONS(9335),
    [sym_internal_keyword] = ACTIONS(9335),
    [sym_protected_keyword] = ACTIONS(9335),
    [sym_event_keyword] = ACTIONS(9335),
    [sym_fields_keyword] = ACTIONS(9335),
    [sym_keys_keyword] = ACTIONS(9335),
    [sym_fieldgroups_keyword] = ACTIONS(9335),
    [sym_actions_keyword] = ACTIONS(9335),
    [sym_layout_keyword] = ACTIONS(9335),
    [sym_area_keyword] = ACTIONS(9335),
    [sym_group_keyword] = ACTIONS(9335),
    [sym_repeater_keyword] = ACTIONS(9335),
    [sym_cuegroup_keyword] = ACTIONS(9335),
    [sym_fixed_keyword] = ACTIONS(9335),
    [sym_grid_keyword] = ACTIONS(9335),
    [sym_part_keyword] = ACTIONS(9335),
    [sym_systempart_keyword] = ACTIONS(9335),
    [sym_usercontrol_keyword] = ACTIONS(9335),
    [sym_dataset_keyword] = ACTIONS(9335),
    [sym_elements_keyword] = ACTIONS(9335),
    [sym_dataitem_keyword] = ACTIONS(9335),
    [sym_column_keyword] = ACTIONS(9335),
    [sym_filter_keyword] = ACTIONS(9335),
    [sym_labels_keyword] = ACTIONS(9335),
    [sym_rendering_keyword] = ACTIONS(9335),
    [sym_requestpage_keyword] = ACTIONS(9335),
    [sym_schema_keyword] = ACTIONS(9335),
    [sym_views_keyword] = ACTIONS(9335),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9335),
    [sym_preproc_open] = ACTIONS(9335),
    [sym_preproc_close] = ACTIONS(9335),
  },
  [STATE(4138)] = {
    [anon_sym_SEMI] = ACTIONS(9331),
    [aux_sym_where_condition_token1] = ACTIONS(9333),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9331),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9331),
    [anon_sym_LBRACK] = ACTIONS(9331),
    [aux_sym_basic_type_token6] = ACTIONS(9333),
    [aux_sym_basic_type_token22] = ACTIONS(9333),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9331),
    [aux_sym_addafter_modification_token1] = ACTIONS(9331),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9331),
    [aux_sym_modify_modification_token1] = ACTIONS(9331),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9331),
    [aux_sym_movelast_modification_token1] = ACTIONS(9331),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9331),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9331),
    [aux_sym_separator_action_token1] = ACTIONS(9331),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9331),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9331),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9331),
    [anon_sym_POUNDif] = ACTIONS(9331),
    [anon_sym_POUNDIF] = ACTIONS(9331),
    [anon_sym_POUNDIf] = ACTIONS(9331),
    [anon_sym_POUNDelif] = ACTIONS(9331),
    [anon_sym_POUNDELIF] = ACTIONS(9331),
    [anon_sym_POUNDElif] = ACTIONS(9331),
    [anon_sym_POUNDelse] = ACTIONS(9331),
    [anon_sym_POUNDELSE] = ACTIONS(9331),
    [anon_sym_POUNDElse] = ACTIONS(9331),
    [anon_sym_POUNDelse2] = ACTIONS(9331),
    [anon_sym_POUNDELSE2] = ACTIONS(9331),
    [anon_sym_POUNDElse2] = ACTIONS(9331),
    [anon_sym_POUNDendif] = ACTIONS(9331),
    [anon_sym_POUNDENDIF] = ACTIONS(9331),
    [anon_sym_POUNDEndif] = ACTIONS(9331),
    [anon_sym_POUNDendif2] = ACTIONS(9331),
    [anon_sym_POUNDENDIF2] = ACTIONS(9331),
    [anon_sym_POUNDEndif2] = ACTIONS(9331),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9331),
    [sym_trigger_keyword] = ACTIONS(9331),
    [sym_var_keyword] = ACTIONS(9331),
    [sym_local_keyword] = ACTIONS(9331),
    [sym_internal_keyword] = ACTIONS(9331),
    [sym_protected_keyword] = ACTIONS(9331),
    [sym_event_keyword] = ACTIONS(9331),
    [sym_fields_keyword] = ACTIONS(9331),
    [sym_keys_keyword] = ACTIONS(9331),
    [sym_fieldgroups_keyword] = ACTIONS(9331),
    [sym_actions_keyword] = ACTIONS(9331),
    [sym_layout_keyword] = ACTIONS(9331),
    [sym_area_keyword] = ACTIONS(9331),
    [sym_group_keyword] = ACTIONS(9331),
    [sym_repeater_keyword] = ACTIONS(9331),
    [sym_cuegroup_keyword] = ACTIONS(9331),
    [sym_fixed_keyword] = ACTIONS(9331),
    [sym_grid_keyword] = ACTIONS(9331),
    [sym_part_keyword] = ACTIONS(9331),
    [sym_systempart_keyword] = ACTIONS(9331),
    [sym_usercontrol_keyword] = ACTIONS(9331),
    [sym_dataset_keyword] = ACTIONS(9331),
    [sym_elements_keyword] = ACTIONS(9331),
    [sym_dataitem_keyword] = ACTIONS(9331),
    [sym_column_keyword] = ACTIONS(9331),
    [sym_filter_keyword] = ACTIONS(9331),
    [sym_labels_keyword] = ACTIONS(9331),
    [sym_rendering_keyword] = ACTIONS(9331),
    [sym_requestpage_keyword] = ACTIONS(9331),
    [sym_schema_keyword] = ACTIONS(9331),
    [sym_views_keyword] = ACTIONS(9331),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9331),
    [sym_preproc_open] = ACTIONS(9331),
    [sym_preproc_close] = ACTIONS(9331),
  },
  [STATE(4139)] = {
    [anon_sym_SEMI] = ACTIONS(9391),
    [aux_sym_where_condition_token1] = ACTIONS(9393),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9391),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9391),
    [anon_sym_LBRACK] = ACTIONS(9391),
    [aux_sym_basic_type_token6] = ACTIONS(9393),
    [aux_sym_basic_type_token22] = ACTIONS(9393),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9391),
    [aux_sym_addafter_modification_token1] = ACTIONS(9391),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9391),
    [aux_sym_modify_modification_token1] = ACTIONS(9391),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9391),
    [aux_sym_movelast_modification_token1] = ACTIONS(9391),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9391),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9391),
    [aux_sym_separator_action_token1] = ACTIONS(9391),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9391),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9391),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9391),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9391),
    [anon_sym_POUNDif] = ACTIONS(9391),
    [anon_sym_POUNDIF] = ACTIONS(9391),
    [anon_sym_POUNDIf] = ACTIONS(9391),
    [anon_sym_POUNDelif] = ACTIONS(9391),
    [anon_sym_POUNDELIF] = ACTIONS(9391),
    [anon_sym_POUNDElif] = ACTIONS(9391),
    [anon_sym_POUNDelse] = ACTIONS(9391),
    [anon_sym_POUNDELSE] = ACTIONS(9391),
    [anon_sym_POUNDElse] = ACTIONS(9391),
    [anon_sym_POUNDelse2] = ACTIONS(9391),
    [anon_sym_POUNDELSE2] = ACTIONS(9391),
    [anon_sym_POUNDElse2] = ACTIONS(9391),
    [anon_sym_POUNDendif] = ACTIONS(9391),
    [anon_sym_POUNDENDIF] = ACTIONS(9391),
    [anon_sym_POUNDEndif] = ACTIONS(9391),
    [anon_sym_POUNDendif2] = ACTIONS(9391),
    [anon_sym_POUNDENDIF2] = ACTIONS(9391),
    [anon_sym_POUNDEndif2] = ACTIONS(9391),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9391),
    [sym_trigger_keyword] = ACTIONS(9391),
    [sym_var_keyword] = ACTIONS(9391),
    [sym_local_keyword] = ACTIONS(9391),
    [sym_internal_keyword] = ACTIONS(9391),
    [sym_protected_keyword] = ACTIONS(9391),
    [sym_event_keyword] = ACTIONS(9391),
    [sym_fields_keyword] = ACTIONS(9391),
    [sym_keys_keyword] = ACTIONS(9391),
    [sym_fieldgroups_keyword] = ACTIONS(9391),
    [sym_actions_keyword] = ACTIONS(9391),
    [sym_layout_keyword] = ACTIONS(9391),
    [sym_area_keyword] = ACTIONS(9391),
    [sym_group_keyword] = ACTIONS(9391),
    [sym_repeater_keyword] = ACTIONS(9391),
    [sym_cuegroup_keyword] = ACTIONS(9391),
    [sym_fixed_keyword] = ACTIONS(9391),
    [sym_grid_keyword] = ACTIONS(9391),
    [sym_part_keyword] = ACTIONS(9391),
    [sym_systempart_keyword] = ACTIONS(9391),
    [sym_usercontrol_keyword] = ACTIONS(9391),
    [sym_dataset_keyword] = ACTIONS(9391),
    [sym_elements_keyword] = ACTIONS(9391),
    [sym_dataitem_keyword] = ACTIONS(9391),
    [sym_column_keyword] = ACTIONS(9391),
    [sym_filter_keyword] = ACTIONS(9391),
    [sym_labels_keyword] = ACTIONS(9391),
    [sym_rendering_keyword] = ACTIONS(9391),
    [sym_requestpage_keyword] = ACTIONS(9391),
    [sym_schema_keyword] = ACTIONS(9391),
    [sym_views_keyword] = ACTIONS(9391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9391),
    [sym_preproc_open] = ACTIONS(9391),
    [sym_preproc_close] = ACTIONS(9391),
  },
  [STATE(4140)] = {
    [anon_sym_SEMI] = ACTIONS(9343),
    [aux_sym_where_condition_token1] = ACTIONS(9345),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9343),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9343),
    [anon_sym_LBRACK] = ACTIONS(9343),
    [aux_sym_basic_type_token6] = ACTIONS(9345),
    [aux_sym_basic_type_token22] = ACTIONS(9345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9343),
    [aux_sym_addafter_modification_token1] = ACTIONS(9343),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9343),
    [aux_sym_modify_modification_token1] = ACTIONS(9343),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9343),
    [aux_sym_movelast_modification_token1] = ACTIONS(9343),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9343),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9343),
    [aux_sym_separator_action_token1] = ACTIONS(9343),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9343),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9343),
    [anon_sym_POUNDif] = ACTIONS(9343),
    [anon_sym_POUNDIF] = ACTIONS(9343),
    [anon_sym_POUNDIf] = ACTIONS(9343),
    [anon_sym_POUNDelif] = ACTIONS(9343),
    [anon_sym_POUNDELIF] = ACTIONS(9343),
    [anon_sym_POUNDElif] = ACTIONS(9343),
    [anon_sym_POUNDelse] = ACTIONS(9343),
    [anon_sym_POUNDELSE] = ACTIONS(9343),
    [anon_sym_POUNDElse] = ACTIONS(9343),
    [anon_sym_POUNDelse2] = ACTIONS(9343),
    [anon_sym_POUNDELSE2] = ACTIONS(9343),
    [anon_sym_POUNDElse2] = ACTIONS(9343),
    [anon_sym_POUNDendif] = ACTIONS(9343),
    [anon_sym_POUNDENDIF] = ACTIONS(9343),
    [anon_sym_POUNDEndif] = ACTIONS(9343),
    [anon_sym_POUNDendif2] = ACTIONS(9343),
    [anon_sym_POUNDENDIF2] = ACTIONS(9343),
    [anon_sym_POUNDEndif2] = ACTIONS(9343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9343),
    [sym_trigger_keyword] = ACTIONS(9343),
    [sym_var_keyword] = ACTIONS(9343),
    [sym_local_keyword] = ACTIONS(9343),
    [sym_internal_keyword] = ACTIONS(9343),
    [sym_protected_keyword] = ACTIONS(9343),
    [sym_event_keyword] = ACTIONS(9343),
    [sym_fields_keyword] = ACTIONS(9343),
    [sym_keys_keyword] = ACTIONS(9343),
    [sym_fieldgroups_keyword] = ACTIONS(9343),
    [sym_actions_keyword] = ACTIONS(9343),
    [sym_layout_keyword] = ACTIONS(9343),
    [sym_area_keyword] = ACTIONS(9343),
    [sym_group_keyword] = ACTIONS(9343),
    [sym_repeater_keyword] = ACTIONS(9343),
    [sym_cuegroup_keyword] = ACTIONS(9343),
    [sym_fixed_keyword] = ACTIONS(9343),
    [sym_grid_keyword] = ACTIONS(9343),
    [sym_part_keyword] = ACTIONS(9343),
    [sym_systempart_keyword] = ACTIONS(9343),
    [sym_usercontrol_keyword] = ACTIONS(9343),
    [sym_dataset_keyword] = ACTIONS(9343),
    [sym_elements_keyword] = ACTIONS(9343),
    [sym_dataitem_keyword] = ACTIONS(9343),
    [sym_column_keyword] = ACTIONS(9343),
    [sym_filter_keyword] = ACTIONS(9343),
    [sym_labels_keyword] = ACTIONS(9343),
    [sym_rendering_keyword] = ACTIONS(9343),
    [sym_requestpage_keyword] = ACTIONS(9343),
    [sym_schema_keyword] = ACTIONS(9343),
    [sym_views_keyword] = ACTIONS(9343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9343),
    [sym_preproc_open] = ACTIONS(9343),
    [sym_preproc_close] = ACTIONS(9343),
  },
  [STATE(4141)] = {
    [anon_sym_SEMI] = ACTIONS(9343),
    [aux_sym_where_condition_token1] = ACTIONS(9345),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9343),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9343),
    [anon_sym_LBRACK] = ACTIONS(9343),
    [aux_sym_basic_type_token6] = ACTIONS(9345),
    [aux_sym_basic_type_token22] = ACTIONS(9345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9343),
    [aux_sym_addafter_modification_token1] = ACTIONS(9343),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9343),
    [aux_sym_modify_modification_token1] = ACTIONS(9343),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9343),
    [aux_sym_movelast_modification_token1] = ACTIONS(9343),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9343),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9343),
    [aux_sym_separator_action_token1] = ACTIONS(9343),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9343),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9343),
    [anon_sym_POUNDif] = ACTIONS(9343),
    [anon_sym_POUNDIF] = ACTIONS(9343),
    [anon_sym_POUNDIf] = ACTIONS(9343),
    [anon_sym_POUNDelif] = ACTIONS(9343),
    [anon_sym_POUNDELIF] = ACTIONS(9343),
    [anon_sym_POUNDElif] = ACTIONS(9343),
    [anon_sym_POUNDelse] = ACTIONS(9343),
    [anon_sym_POUNDELSE] = ACTIONS(9343),
    [anon_sym_POUNDElse] = ACTIONS(9343),
    [anon_sym_POUNDelse2] = ACTIONS(9343),
    [anon_sym_POUNDELSE2] = ACTIONS(9343),
    [anon_sym_POUNDElse2] = ACTIONS(9343),
    [anon_sym_POUNDendif] = ACTIONS(9343),
    [anon_sym_POUNDENDIF] = ACTIONS(9343),
    [anon_sym_POUNDEndif] = ACTIONS(9343),
    [anon_sym_POUNDendif2] = ACTIONS(9343),
    [anon_sym_POUNDENDIF2] = ACTIONS(9343),
    [anon_sym_POUNDEndif2] = ACTIONS(9343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9343),
    [sym_trigger_keyword] = ACTIONS(9343),
    [sym_var_keyword] = ACTIONS(9343),
    [sym_local_keyword] = ACTIONS(9343),
    [sym_internal_keyword] = ACTIONS(9343),
    [sym_protected_keyword] = ACTIONS(9343),
    [sym_event_keyword] = ACTIONS(9343),
    [sym_fields_keyword] = ACTIONS(9343),
    [sym_keys_keyword] = ACTIONS(9343),
    [sym_fieldgroups_keyword] = ACTIONS(9343),
    [sym_actions_keyword] = ACTIONS(9343),
    [sym_layout_keyword] = ACTIONS(9343),
    [sym_area_keyword] = ACTIONS(9343),
    [sym_group_keyword] = ACTIONS(9343),
    [sym_repeater_keyword] = ACTIONS(9343),
    [sym_cuegroup_keyword] = ACTIONS(9343),
    [sym_fixed_keyword] = ACTIONS(9343),
    [sym_grid_keyword] = ACTIONS(9343),
    [sym_part_keyword] = ACTIONS(9343),
    [sym_systempart_keyword] = ACTIONS(9343),
    [sym_usercontrol_keyword] = ACTIONS(9343),
    [sym_dataset_keyword] = ACTIONS(9343),
    [sym_elements_keyword] = ACTIONS(9343),
    [sym_dataitem_keyword] = ACTIONS(9343),
    [sym_column_keyword] = ACTIONS(9343),
    [sym_filter_keyword] = ACTIONS(9343),
    [sym_labels_keyword] = ACTIONS(9343),
    [sym_rendering_keyword] = ACTIONS(9343),
    [sym_requestpage_keyword] = ACTIONS(9343),
    [sym_schema_keyword] = ACTIONS(9343),
    [sym_views_keyword] = ACTIONS(9343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9343),
    [sym_preproc_open] = ACTIONS(9343),
    [sym_preproc_close] = ACTIONS(9343),
  },
  [STATE(4142)] = {
    [anon_sym_SEMI] = ACTIONS(9359),
    [aux_sym_where_condition_token1] = ACTIONS(9361),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9359),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9359),
    [anon_sym_LBRACK] = ACTIONS(9359),
    [aux_sym_basic_type_token6] = ACTIONS(9361),
    [aux_sym_basic_type_token22] = ACTIONS(9361),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9359),
    [aux_sym_addafter_modification_token1] = ACTIONS(9359),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9359),
    [aux_sym_modify_modification_token1] = ACTIONS(9359),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9359),
    [aux_sym_movelast_modification_token1] = ACTIONS(9359),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9359),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9359),
    [aux_sym_separator_action_token1] = ACTIONS(9359),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9359),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9359),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9359),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9359),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9359),
    [anon_sym_POUNDif] = ACTIONS(9359),
    [anon_sym_POUNDIF] = ACTIONS(9359),
    [anon_sym_POUNDIf] = ACTIONS(9359),
    [anon_sym_POUNDelif] = ACTIONS(9359),
    [anon_sym_POUNDELIF] = ACTIONS(9359),
    [anon_sym_POUNDElif] = ACTIONS(9359),
    [anon_sym_POUNDelse] = ACTIONS(9359),
    [anon_sym_POUNDELSE] = ACTIONS(9359),
    [anon_sym_POUNDElse] = ACTIONS(9359),
    [anon_sym_POUNDelse2] = ACTIONS(9359),
    [anon_sym_POUNDELSE2] = ACTIONS(9359),
    [anon_sym_POUNDElse2] = ACTIONS(9359),
    [anon_sym_POUNDendif] = ACTIONS(9359),
    [anon_sym_POUNDENDIF] = ACTIONS(9359),
    [anon_sym_POUNDEndif] = ACTIONS(9359),
    [anon_sym_POUNDendif2] = ACTIONS(9359),
    [anon_sym_POUNDENDIF2] = ACTIONS(9359),
    [anon_sym_POUNDEndif2] = ACTIONS(9359),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9359),
    [sym_trigger_keyword] = ACTIONS(9359),
    [sym_var_keyword] = ACTIONS(9359),
    [sym_local_keyword] = ACTIONS(9359),
    [sym_internal_keyword] = ACTIONS(9359),
    [sym_protected_keyword] = ACTIONS(9359),
    [sym_event_keyword] = ACTIONS(9359),
    [sym_fields_keyword] = ACTIONS(9359),
    [sym_keys_keyword] = ACTIONS(9359),
    [sym_fieldgroups_keyword] = ACTIONS(9359),
    [sym_actions_keyword] = ACTIONS(9359),
    [sym_layout_keyword] = ACTIONS(9359),
    [sym_area_keyword] = ACTIONS(9359),
    [sym_group_keyword] = ACTIONS(9359),
    [sym_repeater_keyword] = ACTIONS(9359),
    [sym_cuegroup_keyword] = ACTIONS(9359),
    [sym_fixed_keyword] = ACTIONS(9359),
    [sym_grid_keyword] = ACTIONS(9359),
    [sym_part_keyword] = ACTIONS(9359),
    [sym_systempart_keyword] = ACTIONS(9359),
    [sym_usercontrol_keyword] = ACTIONS(9359),
    [sym_dataset_keyword] = ACTIONS(9359),
    [sym_elements_keyword] = ACTIONS(9359),
    [sym_dataitem_keyword] = ACTIONS(9359),
    [sym_column_keyword] = ACTIONS(9359),
    [sym_filter_keyword] = ACTIONS(9359),
    [sym_labels_keyword] = ACTIONS(9359),
    [sym_rendering_keyword] = ACTIONS(9359),
    [sym_requestpage_keyword] = ACTIONS(9359),
    [sym_schema_keyword] = ACTIONS(9359),
    [sym_views_keyword] = ACTIONS(9359),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9359),
    [sym_preproc_open] = ACTIONS(9359),
    [sym_preproc_close] = ACTIONS(9359),
  },
  [STATE(4143)] = {
    [anon_sym_SEMI] = ACTIONS(9343),
    [aux_sym_where_condition_token1] = ACTIONS(9345),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9343),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9343),
    [anon_sym_LBRACK] = ACTIONS(9343),
    [aux_sym_basic_type_token6] = ACTIONS(9345),
    [aux_sym_basic_type_token22] = ACTIONS(9345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9343),
    [aux_sym_addafter_modification_token1] = ACTIONS(9343),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9343),
    [aux_sym_modify_modification_token1] = ACTIONS(9343),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9343),
    [aux_sym_movelast_modification_token1] = ACTIONS(9343),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9343),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9343),
    [aux_sym_separator_action_token1] = ACTIONS(9343),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9343),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9343),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9343),
    [anon_sym_POUNDif] = ACTIONS(9343),
    [anon_sym_POUNDIF] = ACTIONS(9343),
    [anon_sym_POUNDIf] = ACTIONS(9343),
    [anon_sym_POUNDelif] = ACTIONS(9343),
    [anon_sym_POUNDELIF] = ACTIONS(9343),
    [anon_sym_POUNDElif] = ACTIONS(9343),
    [anon_sym_POUNDelse] = ACTIONS(9343),
    [anon_sym_POUNDELSE] = ACTIONS(9343),
    [anon_sym_POUNDElse] = ACTIONS(9343),
    [anon_sym_POUNDelse2] = ACTIONS(9343),
    [anon_sym_POUNDELSE2] = ACTIONS(9343),
    [anon_sym_POUNDElse2] = ACTIONS(9343),
    [anon_sym_POUNDendif] = ACTIONS(9343),
    [anon_sym_POUNDENDIF] = ACTIONS(9343),
    [anon_sym_POUNDEndif] = ACTIONS(9343),
    [anon_sym_POUNDendif2] = ACTIONS(9343),
    [anon_sym_POUNDENDIF2] = ACTIONS(9343),
    [anon_sym_POUNDEndif2] = ACTIONS(9343),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9343),
    [sym_trigger_keyword] = ACTIONS(9343),
    [sym_var_keyword] = ACTIONS(9343),
    [sym_local_keyword] = ACTIONS(9343),
    [sym_internal_keyword] = ACTIONS(9343),
    [sym_protected_keyword] = ACTIONS(9343),
    [sym_event_keyword] = ACTIONS(9343),
    [sym_fields_keyword] = ACTIONS(9343),
    [sym_keys_keyword] = ACTIONS(9343),
    [sym_fieldgroups_keyword] = ACTIONS(9343),
    [sym_actions_keyword] = ACTIONS(9343),
    [sym_layout_keyword] = ACTIONS(9343),
    [sym_area_keyword] = ACTIONS(9343),
    [sym_group_keyword] = ACTIONS(9343),
    [sym_repeater_keyword] = ACTIONS(9343),
    [sym_cuegroup_keyword] = ACTIONS(9343),
    [sym_fixed_keyword] = ACTIONS(9343),
    [sym_grid_keyword] = ACTIONS(9343),
    [sym_part_keyword] = ACTIONS(9343),
    [sym_systempart_keyword] = ACTIONS(9343),
    [sym_usercontrol_keyword] = ACTIONS(9343),
    [sym_dataset_keyword] = ACTIONS(9343),
    [sym_elements_keyword] = ACTIONS(9343),
    [sym_dataitem_keyword] = ACTIONS(9343),
    [sym_column_keyword] = ACTIONS(9343),
    [sym_filter_keyword] = ACTIONS(9343),
    [sym_labels_keyword] = ACTIONS(9343),
    [sym_rendering_keyword] = ACTIONS(9343),
    [sym_requestpage_keyword] = ACTIONS(9343),
    [sym_schema_keyword] = ACTIONS(9343),
    [sym_views_keyword] = ACTIONS(9343),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9343),
    [sym_preproc_open] = ACTIONS(9343),
    [sym_preproc_close] = ACTIONS(9343),
  },
  [STATE(4144)] = {
    [anon_sym_SEMI] = ACTIONS(9395),
    [aux_sym_where_condition_token1] = ACTIONS(9397),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9395),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9395),
    [anon_sym_LBRACK] = ACTIONS(9395),
    [aux_sym_basic_type_token6] = ACTIONS(9397),
    [aux_sym_basic_type_token22] = ACTIONS(9397),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9395),
    [aux_sym_addafter_modification_token1] = ACTIONS(9395),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9395),
    [aux_sym_modify_modification_token1] = ACTIONS(9395),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9395),
    [aux_sym_movelast_modification_token1] = ACTIONS(9395),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9395),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9395),
    [aux_sym_separator_action_token1] = ACTIONS(9395),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9395),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9395),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9395),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9395),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9395),
    [anon_sym_POUNDif] = ACTIONS(9395),
    [anon_sym_POUNDIF] = ACTIONS(9395),
    [anon_sym_POUNDIf] = ACTIONS(9395),
    [anon_sym_POUNDelif] = ACTIONS(9395),
    [anon_sym_POUNDELIF] = ACTIONS(9395),
    [anon_sym_POUNDElif] = ACTIONS(9395),
    [anon_sym_POUNDelse] = ACTIONS(9395),
    [anon_sym_POUNDELSE] = ACTIONS(9395),
    [anon_sym_POUNDElse] = ACTIONS(9395),
    [anon_sym_POUNDelse2] = ACTIONS(9395),
    [anon_sym_POUNDELSE2] = ACTIONS(9395),
    [anon_sym_POUNDElse2] = ACTIONS(9395),
    [anon_sym_POUNDendif] = ACTIONS(9395),
    [anon_sym_POUNDENDIF] = ACTIONS(9395),
    [anon_sym_POUNDEndif] = ACTIONS(9395),
    [anon_sym_POUNDendif2] = ACTIONS(9395),
    [anon_sym_POUNDENDIF2] = ACTIONS(9395),
    [anon_sym_POUNDEndif2] = ACTIONS(9395),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9395),
    [sym_trigger_keyword] = ACTIONS(9395),
    [sym_var_keyword] = ACTIONS(9395),
    [sym_local_keyword] = ACTIONS(9395),
    [sym_internal_keyword] = ACTIONS(9395),
    [sym_protected_keyword] = ACTIONS(9395),
    [sym_event_keyword] = ACTIONS(9395),
    [sym_fields_keyword] = ACTIONS(9395),
    [sym_keys_keyword] = ACTIONS(9395),
    [sym_fieldgroups_keyword] = ACTIONS(9395),
    [sym_actions_keyword] = ACTIONS(9395),
    [sym_layout_keyword] = ACTIONS(9395),
    [sym_area_keyword] = ACTIONS(9395),
    [sym_group_keyword] = ACTIONS(9395),
    [sym_repeater_keyword] = ACTIONS(9395),
    [sym_cuegroup_keyword] = ACTIONS(9395),
    [sym_fixed_keyword] = ACTIONS(9395),
    [sym_grid_keyword] = ACTIONS(9395),
    [sym_part_keyword] = ACTIONS(9395),
    [sym_systempart_keyword] = ACTIONS(9395),
    [sym_usercontrol_keyword] = ACTIONS(9395),
    [sym_dataset_keyword] = ACTIONS(9395),
    [sym_elements_keyword] = ACTIONS(9395),
    [sym_dataitem_keyword] = ACTIONS(9395),
    [sym_column_keyword] = ACTIONS(9395),
    [sym_filter_keyword] = ACTIONS(9395),
    [sym_labels_keyword] = ACTIONS(9395),
    [sym_rendering_keyword] = ACTIONS(9395),
    [sym_requestpage_keyword] = ACTIONS(9395),
    [sym_schema_keyword] = ACTIONS(9395),
    [sym_views_keyword] = ACTIONS(9395),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9395),
    [sym_preproc_open] = ACTIONS(9395),
    [sym_preproc_close] = ACTIONS(9395),
  },
  [STATE(4145)] = {
    [anon_sym_SEMI] = ACTIONS(9399),
    [aux_sym_where_condition_token1] = ACTIONS(9401),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9399),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9399),
    [anon_sym_LBRACK] = ACTIONS(9399),
    [aux_sym_basic_type_token6] = ACTIONS(9401),
    [aux_sym_basic_type_token22] = ACTIONS(9401),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9399),
    [aux_sym_addafter_modification_token1] = ACTIONS(9399),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9399),
    [aux_sym_modify_modification_token1] = ACTIONS(9399),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9399),
    [aux_sym_movelast_modification_token1] = ACTIONS(9399),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9399),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9399),
    [aux_sym_separator_action_token1] = ACTIONS(9399),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9399),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9399),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9399),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9399),
    [anon_sym_POUNDif] = ACTIONS(9399),
    [anon_sym_POUNDIF] = ACTIONS(9399),
    [anon_sym_POUNDIf] = ACTIONS(9399),
    [anon_sym_POUNDelif] = ACTIONS(9399),
    [anon_sym_POUNDELIF] = ACTIONS(9399),
    [anon_sym_POUNDElif] = ACTIONS(9399),
    [anon_sym_POUNDelse] = ACTIONS(9399),
    [anon_sym_POUNDELSE] = ACTIONS(9399),
    [anon_sym_POUNDElse] = ACTIONS(9399),
    [anon_sym_POUNDelse2] = ACTIONS(9399),
    [anon_sym_POUNDELSE2] = ACTIONS(9399),
    [anon_sym_POUNDElse2] = ACTIONS(9399),
    [anon_sym_POUNDendif] = ACTIONS(9399),
    [anon_sym_POUNDENDIF] = ACTIONS(9399),
    [anon_sym_POUNDEndif] = ACTIONS(9399),
    [anon_sym_POUNDendif2] = ACTIONS(9399),
    [anon_sym_POUNDENDIF2] = ACTIONS(9399),
    [anon_sym_POUNDEndif2] = ACTIONS(9399),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9399),
    [sym_trigger_keyword] = ACTIONS(9399),
    [sym_var_keyword] = ACTIONS(9399),
    [sym_local_keyword] = ACTIONS(9399),
    [sym_internal_keyword] = ACTIONS(9399),
    [sym_protected_keyword] = ACTIONS(9399),
    [sym_event_keyword] = ACTIONS(9399),
    [sym_fields_keyword] = ACTIONS(9399),
    [sym_keys_keyword] = ACTIONS(9399),
    [sym_fieldgroups_keyword] = ACTIONS(9399),
    [sym_actions_keyword] = ACTIONS(9399),
    [sym_layout_keyword] = ACTIONS(9399),
    [sym_area_keyword] = ACTIONS(9399),
    [sym_group_keyword] = ACTIONS(9399),
    [sym_repeater_keyword] = ACTIONS(9399),
    [sym_cuegroup_keyword] = ACTIONS(9399),
    [sym_fixed_keyword] = ACTIONS(9399),
    [sym_grid_keyword] = ACTIONS(9399),
    [sym_part_keyword] = ACTIONS(9399),
    [sym_systempart_keyword] = ACTIONS(9399),
    [sym_usercontrol_keyword] = ACTIONS(9399),
    [sym_dataset_keyword] = ACTIONS(9399),
    [sym_elements_keyword] = ACTIONS(9399),
    [sym_dataitem_keyword] = ACTIONS(9399),
    [sym_column_keyword] = ACTIONS(9399),
    [sym_filter_keyword] = ACTIONS(9399),
    [sym_labels_keyword] = ACTIONS(9399),
    [sym_rendering_keyword] = ACTIONS(9399),
    [sym_requestpage_keyword] = ACTIONS(9399),
    [sym_schema_keyword] = ACTIONS(9399),
    [sym_views_keyword] = ACTIONS(9399),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9399),
    [sym_preproc_open] = ACTIONS(9399),
    [sym_preproc_close] = ACTIONS(9399),
  },
  [STATE(4146)] = {
    [sym_else_keyword] = STATE(713),
    [sym_identifier] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5471),
    [anon_sym_DASH] = ACTIONS(5471),
    [aux_sym_boolean_token1] = ACTIONS(5469),
    [aux_sym_boolean_token2] = ACTIONS(5469),
    [sym_decimal] = ACTIONS(5469),
    [anon_sym_LPAREN] = ACTIONS(5471),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5469),
    [anon_sym_LBRACK] = ACTIONS(5471),
    [aux_sym_record_type_token1] = ACTIONS(5469),
    [aux_sym_basic_type_token21] = ACTIONS(5469),
    [aux_sym_basic_type_token22] = ACTIONS(5469),
    [aux_sym_basic_type_token48] = ACTIONS(5469),
    [anon_sym_POUNDif] = ACTIONS(5471),
    [anon_sym_POUNDIF] = ACTIONS(5471),
    [anon_sym_POUNDIf] = ACTIONS(5471),
    [anon_sym_not] = ACTIONS(5469),
    [anon_sym_NOT] = ACTIONS(5469),
    [anon_sym_Not] = ACTIONS(5469),
    [anon_sym_POUNDelif] = ACTIONS(5471),
    [anon_sym_POUNDELIF] = ACTIONS(5471),
    [anon_sym_POUNDElif] = ACTIONS(5471),
    [anon_sym_POUNDelse] = ACTIONS(5471),
    [anon_sym_POUNDELSE] = ACTIONS(5471),
    [anon_sym_POUNDElse] = ACTIONS(5471),
    [anon_sym_POUNDelse2] = ACTIONS(5471),
    [anon_sym_POUNDELSE2] = ACTIONS(5471),
    [anon_sym_POUNDElse2] = ACTIONS(5471),
    [anon_sym_POUNDendif] = ACTIONS(5471),
    [anon_sym_POUNDENDIF] = ACTIONS(5471),
    [anon_sym_POUNDEndif] = ACTIONS(5471),
    [anon_sym_POUNDendif2] = ACTIONS(5471),
    [anon_sym_POUNDENDIF2] = ACTIONS(5471),
    [anon_sym_POUNDEndif2] = ACTIONS(5471),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5469),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5469),
    [anon_sym_PLUS] = ACTIONS(5471),
    [sym_datetime_literal] = ACTIONS(5471),
    [sym_date_literal] = ACTIONS(5469),
    [sym_time_literal] = ACTIONS(5469),
    [sym_biginteger_literal] = ACTIONS(5471),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5469),
    [anon_sym_codeunit] = ACTIONS(5469),
    [anon_sym_CODEUNIT] = ACTIONS(5469),
    [anon_sym_Codeunit] = ACTIONS(5469),
    [anon_sym_CodeUnit] = ACTIONS(5469),
    [anon_sym_COdeunit] = ACTIONS(5469),
    [anon_sym_codeUnit] = ACTIONS(5469),
    [sym_report_keyword] = ACTIONS(5469),
    [sym_query_keyword] = ACTIONS(5469),
    [anon_sym_xmlport] = ACTIONS(5469),
    [anon_sym_XMLPORT] = ACTIONS(5469),
    [anon_sym_Xmlport] = ACTIONS(5469),
    [anon_sym_XMLport] = ACTIONS(5469),
    [anon_sym_XMLPort] = ACTIONS(5469),
    [anon_sym_XmlPort] = ACTIONS(5469),
    [anon_sym_enum] = ACTIONS(5469),
    [anon_sym_ENUM] = ACTIONS(5469),
    [anon_sym_Enum] = ACTIONS(5469),
    [anon_sym_eNUM] = ACTIONS(5469),
    [anon_sym_eNum] = ACTIONS(5469),
    [anon_sym_ENum] = ACTIONS(5469),
    [sym_quoted_identifier] = ACTIONS(5471),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5471),
    [sym_verbatim_string] = ACTIONS(5471),
    [sym_integer] = ACTIONS(5469),
    [sym_continue_as_identifier] = ACTIONS(5471),
    [sym_preproc_open] = ACTIONS(5471),
    [sym_preproc_close] = ACTIONS(5471),
  },
  [STATE(4147)] = {
    [sym_else_keyword] = STATE(715),
    [sym_identifier] = ACTIONS(5449),
    [anon_sym_SEMI] = ACTIONS(5451),
    [anon_sym_DASH] = ACTIONS(5451),
    [aux_sym_boolean_token1] = ACTIONS(5449),
    [aux_sym_boolean_token2] = ACTIONS(5449),
    [sym_decimal] = ACTIONS(5449),
    [anon_sym_LPAREN] = ACTIONS(5451),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5449),
    [anon_sym_LBRACK] = ACTIONS(5451),
    [aux_sym_record_type_token1] = ACTIONS(5449),
    [aux_sym_basic_type_token21] = ACTIONS(5449),
    [aux_sym_basic_type_token22] = ACTIONS(5449),
    [aux_sym_basic_type_token48] = ACTIONS(5449),
    [anon_sym_POUNDif] = ACTIONS(5451),
    [anon_sym_POUNDIF] = ACTIONS(5451),
    [anon_sym_POUNDIf] = ACTIONS(5451),
    [anon_sym_not] = ACTIONS(5449),
    [anon_sym_NOT] = ACTIONS(5449),
    [anon_sym_Not] = ACTIONS(5449),
    [anon_sym_POUNDelif] = ACTIONS(5451),
    [anon_sym_POUNDELIF] = ACTIONS(5451),
    [anon_sym_POUNDElif] = ACTIONS(5451),
    [anon_sym_POUNDelse] = ACTIONS(5451),
    [anon_sym_POUNDELSE] = ACTIONS(5451),
    [anon_sym_POUNDElse] = ACTIONS(5451),
    [anon_sym_POUNDelse2] = ACTIONS(5451),
    [anon_sym_POUNDELSE2] = ACTIONS(5451),
    [anon_sym_POUNDElse2] = ACTIONS(5451),
    [anon_sym_POUNDendif] = ACTIONS(5451),
    [anon_sym_POUNDENDIF] = ACTIONS(5451),
    [anon_sym_POUNDEndif] = ACTIONS(5451),
    [anon_sym_POUNDendif2] = ACTIONS(5451),
    [anon_sym_POUNDENDIF2] = ACTIONS(5451),
    [anon_sym_POUNDEndif2] = ACTIONS(5451),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5449),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5449),
    [anon_sym_PLUS] = ACTIONS(5451),
    [sym_datetime_literal] = ACTIONS(5451),
    [sym_date_literal] = ACTIONS(5449),
    [sym_time_literal] = ACTIONS(5449),
    [sym_biginteger_literal] = ACTIONS(5451),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5449),
    [anon_sym_codeunit] = ACTIONS(5449),
    [anon_sym_CODEUNIT] = ACTIONS(5449),
    [anon_sym_Codeunit] = ACTIONS(5449),
    [anon_sym_CodeUnit] = ACTIONS(5449),
    [anon_sym_COdeunit] = ACTIONS(5449),
    [anon_sym_codeUnit] = ACTIONS(5449),
    [sym_report_keyword] = ACTIONS(5449),
    [sym_query_keyword] = ACTIONS(5449),
    [anon_sym_xmlport] = ACTIONS(5449),
    [anon_sym_XMLPORT] = ACTIONS(5449),
    [anon_sym_Xmlport] = ACTIONS(5449),
    [anon_sym_XMLport] = ACTIONS(5449),
    [anon_sym_XMLPort] = ACTIONS(5449),
    [anon_sym_XmlPort] = ACTIONS(5449),
    [anon_sym_enum] = ACTIONS(5449),
    [anon_sym_ENUM] = ACTIONS(5449),
    [anon_sym_Enum] = ACTIONS(5449),
    [anon_sym_eNUM] = ACTIONS(5449),
    [anon_sym_eNum] = ACTIONS(5449),
    [anon_sym_ENum] = ACTIONS(5449),
    [sym_quoted_identifier] = ACTIONS(5451),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5451),
    [sym_verbatim_string] = ACTIONS(5451),
    [sym_integer] = ACTIONS(5449),
    [sym_continue_as_identifier] = ACTIONS(5451),
    [sym_preproc_open] = ACTIONS(5451),
    [sym_preproc_close] = ACTIONS(5451),
  },
  [STATE(4148)] = {
    [sym_else_keyword] = STATE(782),
    [sym_identifier] = ACTIONS(5477),
    [anon_sym_SEMI] = ACTIONS(5479),
    [anon_sym_DASH] = ACTIONS(5479),
    [aux_sym_boolean_token1] = ACTIONS(5477),
    [aux_sym_boolean_token2] = ACTIONS(5477),
    [sym_decimal] = ACTIONS(5477),
    [anon_sym_LPAREN] = ACTIONS(5479),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5477),
    [anon_sym_LBRACK] = ACTIONS(5479),
    [aux_sym_record_type_token1] = ACTIONS(5477),
    [aux_sym_basic_type_token21] = ACTIONS(5477),
    [aux_sym_basic_type_token22] = ACTIONS(5477),
    [aux_sym_basic_type_token48] = ACTIONS(5477),
    [anon_sym_POUNDif] = ACTIONS(5479),
    [anon_sym_POUNDIF] = ACTIONS(5479),
    [anon_sym_POUNDIf] = ACTIONS(5479),
    [anon_sym_not] = ACTIONS(5477),
    [anon_sym_NOT] = ACTIONS(5477),
    [anon_sym_Not] = ACTIONS(5477),
    [anon_sym_POUNDelif] = ACTIONS(5479),
    [anon_sym_POUNDELIF] = ACTIONS(5479),
    [anon_sym_POUNDElif] = ACTIONS(5479),
    [anon_sym_POUNDelse] = ACTIONS(5479),
    [anon_sym_POUNDELSE] = ACTIONS(5479),
    [anon_sym_POUNDElse] = ACTIONS(5479),
    [anon_sym_POUNDelse2] = ACTIONS(5479),
    [anon_sym_POUNDELSE2] = ACTIONS(5479),
    [anon_sym_POUNDElse2] = ACTIONS(5479),
    [anon_sym_POUNDendif] = ACTIONS(5479),
    [anon_sym_POUNDENDIF] = ACTIONS(5479),
    [anon_sym_POUNDEndif] = ACTIONS(5479),
    [anon_sym_POUNDendif2] = ACTIONS(5479),
    [anon_sym_POUNDENDIF2] = ACTIONS(5479),
    [anon_sym_POUNDEndif2] = ACTIONS(5479),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5477),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5477),
    [anon_sym_PLUS] = ACTIONS(5479),
    [sym_datetime_literal] = ACTIONS(5479),
    [sym_date_literal] = ACTIONS(5477),
    [sym_time_literal] = ACTIONS(5477),
    [sym_biginteger_literal] = ACTIONS(5479),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5477),
    [anon_sym_codeunit] = ACTIONS(5477),
    [anon_sym_CODEUNIT] = ACTIONS(5477),
    [anon_sym_Codeunit] = ACTIONS(5477),
    [anon_sym_CodeUnit] = ACTIONS(5477),
    [anon_sym_COdeunit] = ACTIONS(5477),
    [anon_sym_codeUnit] = ACTIONS(5477),
    [sym_report_keyword] = ACTIONS(5477),
    [sym_query_keyword] = ACTIONS(5477),
    [anon_sym_xmlport] = ACTIONS(5477),
    [anon_sym_XMLPORT] = ACTIONS(5477),
    [anon_sym_Xmlport] = ACTIONS(5477),
    [anon_sym_XMLport] = ACTIONS(5477),
    [anon_sym_XMLPort] = ACTIONS(5477),
    [anon_sym_XmlPort] = ACTIONS(5477),
    [anon_sym_enum] = ACTIONS(5477),
    [anon_sym_ENUM] = ACTIONS(5477),
    [anon_sym_Enum] = ACTIONS(5477),
    [anon_sym_eNUM] = ACTIONS(5477),
    [anon_sym_eNum] = ACTIONS(5477),
    [anon_sym_ENum] = ACTIONS(5477),
    [sym_quoted_identifier] = ACTIONS(5479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5479),
    [sym_verbatim_string] = ACTIONS(5479),
    [sym_integer] = ACTIONS(5477),
    [sym_continue_as_identifier] = ACTIONS(5479),
    [sym_preproc_open] = ACTIONS(5479),
    [sym_preproc_close] = ACTIONS(5479),
  },
  [STATE(4149)] = {
    [sym_else_keyword] = STATE(787),
    [sym_identifier] = ACTIONS(5441),
    [anon_sym_SEMI] = ACTIONS(5443),
    [anon_sym_DASH] = ACTIONS(5443),
    [aux_sym_boolean_token1] = ACTIONS(5441),
    [aux_sym_boolean_token2] = ACTIONS(5441),
    [sym_decimal] = ACTIONS(5441),
    [anon_sym_LPAREN] = ACTIONS(5443),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5441),
    [anon_sym_LBRACK] = ACTIONS(5443),
    [aux_sym_record_type_token1] = ACTIONS(5441),
    [aux_sym_basic_type_token21] = ACTIONS(5441),
    [aux_sym_basic_type_token22] = ACTIONS(5441),
    [aux_sym_basic_type_token48] = ACTIONS(5441),
    [anon_sym_POUNDif] = ACTIONS(5443),
    [anon_sym_POUNDIF] = ACTIONS(5443),
    [anon_sym_POUNDIf] = ACTIONS(5443),
    [anon_sym_not] = ACTIONS(5441),
    [anon_sym_NOT] = ACTIONS(5441),
    [anon_sym_Not] = ACTIONS(5441),
    [anon_sym_POUNDelif] = ACTIONS(5443),
    [anon_sym_POUNDELIF] = ACTIONS(5443),
    [anon_sym_POUNDElif] = ACTIONS(5443),
    [anon_sym_POUNDelse] = ACTIONS(5443),
    [anon_sym_POUNDELSE] = ACTIONS(5443),
    [anon_sym_POUNDElse] = ACTIONS(5443),
    [anon_sym_POUNDelse2] = ACTIONS(5443),
    [anon_sym_POUNDELSE2] = ACTIONS(5443),
    [anon_sym_POUNDElse2] = ACTIONS(5443),
    [anon_sym_POUNDendif] = ACTIONS(5443),
    [anon_sym_POUNDENDIF] = ACTIONS(5443),
    [anon_sym_POUNDEndif] = ACTIONS(5443),
    [anon_sym_POUNDendif2] = ACTIONS(5443),
    [anon_sym_POUNDENDIF2] = ACTIONS(5443),
    [anon_sym_POUNDEndif2] = ACTIONS(5443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5441),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5441),
    [anon_sym_PLUS] = ACTIONS(5443),
    [sym_datetime_literal] = ACTIONS(5443),
    [sym_date_literal] = ACTIONS(5441),
    [sym_time_literal] = ACTIONS(5441),
    [sym_biginteger_literal] = ACTIONS(5443),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5441),
    [anon_sym_codeunit] = ACTIONS(5441),
    [anon_sym_CODEUNIT] = ACTIONS(5441),
    [anon_sym_Codeunit] = ACTIONS(5441),
    [anon_sym_CodeUnit] = ACTIONS(5441),
    [anon_sym_COdeunit] = ACTIONS(5441),
    [anon_sym_codeUnit] = ACTIONS(5441),
    [sym_report_keyword] = ACTIONS(5441),
    [sym_query_keyword] = ACTIONS(5441),
    [anon_sym_xmlport] = ACTIONS(5441),
    [anon_sym_XMLPORT] = ACTIONS(5441),
    [anon_sym_Xmlport] = ACTIONS(5441),
    [anon_sym_XMLport] = ACTIONS(5441),
    [anon_sym_XMLPort] = ACTIONS(5441),
    [anon_sym_XmlPort] = ACTIONS(5441),
    [anon_sym_enum] = ACTIONS(5441),
    [anon_sym_ENUM] = ACTIONS(5441),
    [anon_sym_Enum] = ACTIONS(5441),
    [anon_sym_eNUM] = ACTIONS(5441),
    [anon_sym_eNum] = ACTIONS(5441),
    [anon_sym_ENum] = ACTIONS(5441),
    [sym_quoted_identifier] = ACTIONS(5443),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5443),
    [sym_verbatim_string] = ACTIONS(5443),
    [sym_integer] = ACTIONS(5441),
    [sym_continue_as_identifier] = ACTIONS(5443),
    [sym_preproc_open] = ACTIONS(5443),
    [sym_preproc_close] = ACTIONS(5443),
  },
  [STATE(4150)] = {
    [sym_else_keyword] = STATE(788),
    [sym_identifier] = ACTIONS(5431),
    [anon_sym_SEMI] = ACTIONS(5433),
    [anon_sym_DASH] = ACTIONS(5433),
    [aux_sym_boolean_token1] = ACTIONS(5431),
    [aux_sym_boolean_token2] = ACTIONS(5431),
    [sym_decimal] = ACTIONS(5431),
    [anon_sym_LPAREN] = ACTIONS(5433),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5431),
    [anon_sym_LBRACK] = ACTIONS(5433),
    [aux_sym_record_type_token1] = ACTIONS(5431),
    [aux_sym_basic_type_token21] = ACTIONS(5431),
    [aux_sym_basic_type_token22] = ACTIONS(5431),
    [aux_sym_basic_type_token48] = ACTIONS(5431),
    [anon_sym_POUNDif] = ACTIONS(5433),
    [anon_sym_POUNDIF] = ACTIONS(5433),
    [anon_sym_POUNDIf] = ACTIONS(5433),
    [anon_sym_not] = ACTIONS(5431),
    [anon_sym_NOT] = ACTIONS(5431),
    [anon_sym_Not] = ACTIONS(5431),
    [anon_sym_POUNDelif] = ACTIONS(5433),
    [anon_sym_POUNDELIF] = ACTIONS(5433),
    [anon_sym_POUNDElif] = ACTIONS(5433),
    [anon_sym_POUNDelse] = ACTIONS(5433),
    [anon_sym_POUNDELSE] = ACTIONS(5433),
    [anon_sym_POUNDElse] = ACTIONS(5433),
    [anon_sym_POUNDelse2] = ACTIONS(5433),
    [anon_sym_POUNDELSE2] = ACTIONS(5433),
    [anon_sym_POUNDElse2] = ACTIONS(5433),
    [anon_sym_POUNDendif] = ACTIONS(5433),
    [anon_sym_POUNDENDIF] = ACTIONS(5433),
    [anon_sym_POUNDEndif] = ACTIONS(5433),
    [anon_sym_POUNDendif2] = ACTIONS(5433),
    [anon_sym_POUNDENDIF2] = ACTIONS(5433),
    [anon_sym_POUNDEndif2] = ACTIONS(5433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5431),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5431),
    [anon_sym_PLUS] = ACTIONS(5433),
    [sym_datetime_literal] = ACTIONS(5433),
    [sym_date_literal] = ACTIONS(5431),
    [sym_time_literal] = ACTIONS(5431),
    [sym_biginteger_literal] = ACTIONS(5433),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5431),
    [anon_sym_codeunit] = ACTIONS(5431),
    [anon_sym_CODEUNIT] = ACTIONS(5431),
    [anon_sym_Codeunit] = ACTIONS(5431),
    [anon_sym_CodeUnit] = ACTIONS(5431),
    [anon_sym_COdeunit] = ACTIONS(5431),
    [anon_sym_codeUnit] = ACTIONS(5431),
    [sym_report_keyword] = ACTIONS(5431),
    [sym_query_keyword] = ACTIONS(5431),
    [anon_sym_xmlport] = ACTIONS(5431),
    [anon_sym_XMLPORT] = ACTIONS(5431),
    [anon_sym_Xmlport] = ACTIONS(5431),
    [anon_sym_XMLport] = ACTIONS(5431),
    [anon_sym_XMLPort] = ACTIONS(5431),
    [anon_sym_XmlPort] = ACTIONS(5431),
    [anon_sym_enum] = ACTIONS(5431),
    [anon_sym_ENUM] = ACTIONS(5431),
    [anon_sym_Enum] = ACTIONS(5431),
    [anon_sym_eNUM] = ACTIONS(5431),
    [anon_sym_eNum] = ACTIONS(5431),
    [anon_sym_ENum] = ACTIONS(5431),
    [sym_quoted_identifier] = ACTIONS(5433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5433),
    [sym_verbatim_string] = ACTIONS(5433),
    [sym_integer] = ACTIONS(5431),
    [sym_continue_as_identifier] = ACTIONS(5433),
    [sym_preproc_open] = ACTIONS(5433),
    [sym_preproc_close] = ACTIONS(5433),
  },
  [STATE(4151)] = {
    [sym_else_keyword] = STATE(406),
    [sym_identifier] = ACTIONS(5481),
    [anon_sym_SEMI] = ACTIONS(5483),
    [anon_sym_DASH] = ACTIONS(5483),
    [aux_sym_boolean_token1] = ACTIONS(5481),
    [aux_sym_boolean_token2] = ACTIONS(5481),
    [sym_decimal] = ACTIONS(5481),
    [anon_sym_LPAREN] = ACTIONS(5483),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5481),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [aux_sym_record_type_token1] = ACTIONS(5481),
    [aux_sym_basic_type_token21] = ACTIONS(5481),
    [aux_sym_basic_type_token22] = ACTIONS(5481),
    [aux_sym_basic_type_token48] = ACTIONS(5481),
    [anon_sym_POUNDif] = ACTIONS(5483),
    [anon_sym_POUNDIF] = ACTIONS(5483),
    [anon_sym_POUNDIf] = ACTIONS(5483),
    [anon_sym_not] = ACTIONS(5481),
    [anon_sym_NOT] = ACTIONS(5481),
    [anon_sym_Not] = ACTIONS(5481),
    [anon_sym_POUNDelif] = ACTIONS(5483),
    [anon_sym_POUNDELIF] = ACTIONS(5483),
    [anon_sym_POUNDElif] = ACTIONS(5483),
    [anon_sym_POUNDelse] = ACTIONS(5483),
    [anon_sym_POUNDELSE] = ACTIONS(5483),
    [anon_sym_POUNDElse] = ACTIONS(5483),
    [anon_sym_POUNDelse2] = ACTIONS(5483),
    [anon_sym_POUNDELSE2] = ACTIONS(5483),
    [anon_sym_POUNDElse2] = ACTIONS(5483),
    [anon_sym_POUNDendif] = ACTIONS(5483),
    [anon_sym_POUNDENDIF] = ACTIONS(5483),
    [anon_sym_POUNDEndif] = ACTIONS(5483),
    [anon_sym_POUNDendif2] = ACTIONS(5483),
    [anon_sym_POUNDENDIF2] = ACTIONS(5483),
    [anon_sym_POUNDEndif2] = ACTIONS(5483),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5481),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5481),
    [anon_sym_PLUS] = ACTIONS(5483),
    [sym_datetime_literal] = ACTIONS(5483),
    [sym_date_literal] = ACTIONS(5481),
    [sym_time_literal] = ACTIONS(5481),
    [sym_biginteger_literal] = ACTIONS(5483),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5481),
    [anon_sym_codeunit] = ACTIONS(5481),
    [anon_sym_CODEUNIT] = ACTIONS(5481),
    [anon_sym_Codeunit] = ACTIONS(5481),
    [anon_sym_CodeUnit] = ACTIONS(5481),
    [anon_sym_COdeunit] = ACTIONS(5481),
    [anon_sym_codeUnit] = ACTIONS(5481),
    [sym_report_keyword] = ACTIONS(5481),
    [sym_query_keyword] = ACTIONS(5481),
    [anon_sym_xmlport] = ACTIONS(5481),
    [anon_sym_XMLPORT] = ACTIONS(5481),
    [anon_sym_Xmlport] = ACTIONS(5481),
    [anon_sym_XMLport] = ACTIONS(5481),
    [anon_sym_XMLPort] = ACTIONS(5481),
    [anon_sym_XmlPort] = ACTIONS(5481),
    [anon_sym_enum] = ACTIONS(5481),
    [anon_sym_ENUM] = ACTIONS(5481),
    [anon_sym_Enum] = ACTIONS(5481),
    [anon_sym_eNUM] = ACTIONS(5481),
    [anon_sym_eNum] = ACTIONS(5481),
    [anon_sym_ENum] = ACTIONS(5481),
    [sym_quoted_identifier] = ACTIONS(5483),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5483),
    [sym_verbatim_string] = ACTIONS(5483),
    [sym_integer] = ACTIONS(5481),
    [sym_continue_as_identifier] = ACTIONS(5483),
    [sym_preproc_open] = ACTIONS(5483),
    [sym_preproc_close] = ACTIONS(5483),
  },
  [STATE(4152)] = {
    [sym_else_keyword] = STATE(411),
    [sym_identifier] = ACTIONS(5489),
    [anon_sym_SEMI] = ACTIONS(5491),
    [anon_sym_DASH] = ACTIONS(5491),
    [aux_sym_boolean_token1] = ACTIONS(5489),
    [aux_sym_boolean_token2] = ACTIONS(5489),
    [sym_decimal] = ACTIONS(5489),
    [anon_sym_LPAREN] = ACTIONS(5491),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5489),
    [anon_sym_LBRACK] = ACTIONS(5491),
    [aux_sym_record_type_token1] = ACTIONS(5489),
    [aux_sym_basic_type_token21] = ACTIONS(5489),
    [aux_sym_basic_type_token22] = ACTIONS(5489),
    [aux_sym_basic_type_token48] = ACTIONS(5489),
    [anon_sym_POUNDif] = ACTIONS(5491),
    [anon_sym_POUNDIF] = ACTIONS(5491),
    [anon_sym_POUNDIf] = ACTIONS(5491),
    [anon_sym_not] = ACTIONS(5489),
    [anon_sym_NOT] = ACTIONS(5489),
    [anon_sym_Not] = ACTIONS(5489),
    [anon_sym_POUNDelif] = ACTIONS(5491),
    [anon_sym_POUNDELIF] = ACTIONS(5491),
    [anon_sym_POUNDElif] = ACTIONS(5491),
    [anon_sym_POUNDelse] = ACTIONS(5491),
    [anon_sym_POUNDELSE] = ACTIONS(5491),
    [anon_sym_POUNDElse] = ACTIONS(5491),
    [anon_sym_POUNDelse2] = ACTIONS(5491),
    [anon_sym_POUNDELSE2] = ACTIONS(5491),
    [anon_sym_POUNDElse2] = ACTIONS(5491),
    [anon_sym_POUNDendif] = ACTIONS(5491),
    [anon_sym_POUNDENDIF] = ACTIONS(5491),
    [anon_sym_POUNDEndif] = ACTIONS(5491),
    [anon_sym_POUNDendif2] = ACTIONS(5491),
    [anon_sym_POUNDENDIF2] = ACTIONS(5491),
    [anon_sym_POUNDEndif2] = ACTIONS(5491),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5489),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5489),
    [anon_sym_PLUS] = ACTIONS(5491),
    [sym_datetime_literal] = ACTIONS(5491),
    [sym_date_literal] = ACTIONS(5489),
    [sym_time_literal] = ACTIONS(5489),
    [sym_biginteger_literal] = ACTIONS(5491),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5489),
    [anon_sym_codeunit] = ACTIONS(5489),
    [anon_sym_CODEUNIT] = ACTIONS(5489),
    [anon_sym_Codeunit] = ACTIONS(5489),
    [anon_sym_CodeUnit] = ACTIONS(5489),
    [anon_sym_COdeunit] = ACTIONS(5489),
    [anon_sym_codeUnit] = ACTIONS(5489),
    [sym_report_keyword] = ACTIONS(5489),
    [sym_query_keyword] = ACTIONS(5489),
    [anon_sym_xmlport] = ACTIONS(5489),
    [anon_sym_XMLPORT] = ACTIONS(5489),
    [anon_sym_Xmlport] = ACTIONS(5489),
    [anon_sym_XMLport] = ACTIONS(5489),
    [anon_sym_XMLPort] = ACTIONS(5489),
    [anon_sym_XmlPort] = ACTIONS(5489),
    [anon_sym_enum] = ACTIONS(5489),
    [anon_sym_ENUM] = ACTIONS(5489),
    [anon_sym_Enum] = ACTIONS(5489),
    [anon_sym_eNUM] = ACTIONS(5489),
    [anon_sym_eNum] = ACTIONS(5489),
    [anon_sym_ENum] = ACTIONS(5489),
    [sym_quoted_identifier] = ACTIONS(5491),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5491),
    [sym_verbatim_string] = ACTIONS(5491),
    [sym_integer] = ACTIONS(5489),
    [sym_continue_as_identifier] = ACTIONS(5491),
    [sym_preproc_open] = ACTIONS(5491),
    [sym_preproc_close] = ACTIONS(5491),
  },
  [STATE(4153)] = {
    [sym_else_keyword] = STATE(412),
    [sym_identifier] = ACTIONS(5437),
    [anon_sym_SEMI] = ACTIONS(5439),
    [anon_sym_DASH] = ACTIONS(5439),
    [aux_sym_boolean_token1] = ACTIONS(5437),
    [aux_sym_boolean_token2] = ACTIONS(5437),
    [sym_decimal] = ACTIONS(5437),
    [anon_sym_LPAREN] = ACTIONS(5439),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5437),
    [anon_sym_LBRACK] = ACTIONS(5439),
    [aux_sym_record_type_token1] = ACTIONS(5437),
    [aux_sym_basic_type_token21] = ACTIONS(5437),
    [aux_sym_basic_type_token22] = ACTIONS(5437),
    [aux_sym_basic_type_token48] = ACTIONS(5437),
    [anon_sym_POUNDif] = ACTIONS(5439),
    [anon_sym_POUNDIF] = ACTIONS(5439),
    [anon_sym_POUNDIf] = ACTIONS(5439),
    [anon_sym_not] = ACTIONS(5437),
    [anon_sym_NOT] = ACTIONS(5437),
    [anon_sym_Not] = ACTIONS(5437),
    [anon_sym_POUNDelif] = ACTIONS(5439),
    [anon_sym_POUNDELIF] = ACTIONS(5439),
    [anon_sym_POUNDElif] = ACTIONS(5439),
    [anon_sym_POUNDelse] = ACTIONS(5439),
    [anon_sym_POUNDELSE] = ACTIONS(5439),
    [anon_sym_POUNDElse] = ACTIONS(5439),
    [anon_sym_POUNDelse2] = ACTIONS(5439),
    [anon_sym_POUNDELSE2] = ACTIONS(5439),
    [anon_sym_POUNDElse2] = ACTIONS(5439),
    [anon_sym_POUNDendif] = ACTIONS(5439),
    [anon_sym_POUNDENDIF] = ACTIONS(5439),
    [anon_sym_POUNDEndif] = ACTIONS(5439),
    [anon_sym_POUNDendif2] = ACTIONS(5439),
    [anon_sym_POUNDENDIF2] = ACTIONS(5439),
    [anon_sym_POUNDEndif2] = ACTIONS(5439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5437),
    [anon_sym_PLUS] = ACTIONS(5439),
    [sym_datetime_literal] = ACTIONS(5439),
    [sym_date_literal] = ACTIONS(5437),
    [sym_time_literal] = ACTIONS(5437),
    [sym_biginteger_literal] = ACTIONS(5439),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5437),
    [anon_sym_codeunit] = ACTIONS(5437),
    [anon_sym_CODEUNIT] = ACTIONS(5437),
    [anon_sym_Codeunit] = ACTIONS(5437),
    [anon_sym_CodeUnit] = ACTIONS(5437),
    [anon_sym_COdeunit] = ACTIONS(5437),
    [anon_sym_codeUnit] = ACTIONS(5437),
    [sym_report_keyword] = ACTIONS(5437),
    [sym_query_keyword] = ACTIONS(5437),
    [anon_sym_xmlport] = ACTIONS(5437),
    [anon_sym_XMLPORT] = ACTIONS(5437),
    [anon_sym_Xmlport] = ACTIONS(5437),
    [anon_sym_XMLport] = ACTIONS(5437),
    [anon_sym_XMLPort] = ACTIONS(5437),
    [anon_sym_XmlPort] = ACTIONS(5437),
    [anon_sym_enum] = ACTIONS(5437),
    [anon_sym_ENUM] = ACTIONS(5437),
    [anon_sym_Enum] = ACTIONS(5437),
    [anon_sym_eNUM] = ACTIONS(5437),
    [anon_sym_eNum] = ACTIONS(5437),
    [anon_sym_ENum] = ACTIONS(5437),
    [sym_quoted_identifier] = ACTIONS(5439),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5439),
    [sym_verbatim_string] = ACTIONS(5439),
    [sym_integer] = ACTIONS(5437),
    [sym_continue_as_identifier] = ACTIONS(5439),
    [sym_preproc_open] = ACTIONS(5439),
    [sym_preproc_close] = ACTIONS(5439),
  },
  [STATE(4154)] = {
    [anon_sym_SEMI] = ACTIONS(9403),
    [aux_sym_where_condition_token1] = ACTIONS(9405),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9403),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9403),
    [anon_sym_LBRACK] = ACTIONS(9403),
    [aux_sym_basic_type_token6] = ACTIONS(9405),
    [aux_sym_basic_type_token22] = ACTIONS(9405),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9403),
    [aux_sym_addafter_modification_token1] = ACTIONS(9403),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9403),
    [aux_sym_modify_modification_token1] = ACTIONS(9403),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9403),
    [aux_sym_movelast_modification_token1] = ACTIONS(9403),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9403),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9403),
    [aux_sym_separator_action_token1] = ACTIONS(9403),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9403),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9403),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9403),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9403),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9403),
    [anon_sym_POUNDif] = ACTIONS(9403),
    [anon_sym_POUNDIF] = ACTIONS(9403),
    [anon_sym_POUNDIf] = ACTIONS(9403),
    [anon_sym_POUNDelif] = ACTIONS(9403),
    [anon_sym_POUNDELIF] = ACTIONS(9403),
    [anon_sym_POUNDElif] = ACTIONS(9403),
    [anon_sym_POUNDelse] = ACTIONS(9403),
    [anon_sym_POUNDELSE] = ACTIONS(9403),
    [anon_sym_POUNDElse] = ACTIONS(9403),
    [anon_sym_POUNDelse2] = ACTIONS(9403),
    [anon_sym_POUNDELSE2] = ACTIONS(9403),
    [anon_sym_POUNDElse2] = ACTIONS(9403),
    [anon_sym_POUNDendif] = ACTIONS(9403),
    [anon_sym_POUNDENDIF] = ACTIONS(9403),
    [anon_sym_POUNDEndif] = ACTIONS(9403),
    [anon_sym_POUNDendif2] = ACTIONS(9403),
    [anon_sym_POUNDENDIF2] = ACTIONS(9403),
    [anon_sym_POUNDEndif2] = ACTIONS(9403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9403),
    [sym_trigger_keyword] = ACTIONS(9403),
    [sym_var_keyword] = ACTIONS(9403),
    [sym_local_keyword] = ACTIONS(9403),
    [sym_internal_keyword] = ACTIONS(9403),
    [sym_protected_keyword] = ACTIONS(9403),
    [sym_event_keyword] = ACTIONS(9403),
    [sym_fields_keyword] = ACTIONS(9403),
    [sym_keys_keyword] = ACTIONS(9403),
    [sym_fieldgroups_keyword] = ACTIONS(9403),
    [sym_actions_keyword] = ACTIONS(9403),
    [sym_layout_keyword] = ACTIONS(9403),
    [sym_area_keyword] = ACTIONS(9403),
    [sym_group_keyword] = ACTIONS(9403),
    [sym_repeater_keyword] = ACTIONS(9403),
    [sym_cuegroup_keyword] = ACTIONS(9403),
    [sym_fixed_keyword] = ACTIONS(9403),
    [sym_grid_keyword] = ACTIONS(9403),
    [sym_part_keyword] = ACTIONS(9403),
    [sym_systempart_keyword] = ACTIONS(9403),
    [sym_usercontrol_keyword] = ACTIONS(9403),
    [sym_dataset_keyword] = ACTIONS(9403),
    [sym_elements_keyword] = ACTIONS(9403),
    [sym_dataitem_keyword] = ACTIONS(9403),
    [sym_column_keyword] = ACTIONS(9403),
    [sym_filter_keyword] = ACTIONS(9403),
    [sym_labels_keyword] = ACTIONS(9403),
    [sym_rendering_keyword] = ACTIONS(9403),
    [sym_requestpage_keyword] = ACTIONS(9403),
    [sym_schema_keyword] = ACTIONS(9403),
    [sym_views_keyword] = ACTIONS(9403),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9403),
    [sym_preproc_open] = ACTIONS(9403),
    [sym_preproc_close] = ACTIONS(9403),
  },
  [STATE(4155)] = {
    [aux_sym_option_member_list_repeat2] = STATE(4155),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(9407),
    [anon_sym_DASH] = ACTIONS(838),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [anon_sym_POUNDelif] = ACTIONS(838),
    [anon_sym_POUNDELIF] = ACTIONS(838),
    [anon_sym_POUNDElif] = ACTIONS(838),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [anon_sym_POUNDendif] = ACTIONS(838),
    [anon_sym_POUNDENDIF] = ACTIONS(838),
    [anon_sym_POUNDEndif] = ACTIONS(838),
    [anon_sym_POUNDendif2] = ACTIONS(838),
    [anon_sym_POUNDENDIF2] = ACTIONS(838),
    [anon_sym_POUNDEndif2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_var_keyword] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
    [sym_preproc_close] = ACTIONS(838),
    [sym_begin_keyword] = ACTIONS(838),
  },
  [STATE(4156)] = {
    [anon_sym_SEMI] = ACTIONS(9410),
    [aux_sym_where_condition_token1] = ACTIONS(9412),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9410),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9410),
    [anon_sym_LBRACK] = ACTIONS(9410),
    [aux_sym_basic_type_token6] = ACTIONS(9412),
    [aux_sym_basic_type_token22] = ACTIONS(9412),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9410),
    [aux_sym_addafter_modification_token1] = ACTIONS(9410),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9410),
    [aux_sym_modify_modification_token1] = ACTIONS(9410),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9410),
    [aux_sym_movelast_modification_token1] = ACTIONS(9410),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9410),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9410),
    [aux_sym_separator_action_token1] = ACTIONS(9410),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9410),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9410),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9410),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9410),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9410),
    [anon_sym_POUNDif] = ACTIONS(9410),
    [anon_sym_POUNDIF] = ACTIONS(9410),
    [anon_sym_POUNDIf] = ACTIONS(9410),
    [anon_sym_POUNDelif] = ACTIONS(9410),
    [anon_sym_POUNDELIF] = ACTIONS(9410),
    [anon_sym_POUNDElif] = ACTIONS(9410),
    [anon_sym_POUNDelse] = ACTIONS(9410),
    [anon_sym_POUNDELSE] = ACTIONS(9410),
    [anon_sym_POUNDElse] = ACTIONS(9410),
    [anon_sym_POUNDelse2] = ACTIONS(9410),
    [anon_sym_POUNDELSE2] = ACTIONS(9410),
    [anon_sym_POUNDElse2] = ACTIONS(9410),
    [anon_sym_POUNDendif] = ACTIONS(9410),
    [anon_sym_POUNDENDIF] = ACTIONS(9410),
    [anon_sym_POUNDEndif] = ACTIONS(9410),
    [anon_sym_POUNDendif2] = ACTIONS(9410),
    [anon_sym_POUNDENDIF2] = ACTIONS(9410),
    [anon_sym_POUNDEndif2] = ACTIONS(9410),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9410),
    [sym_trigger_keyword] = ACTIONS(9410),
    [sym_var_keyword] = ACTIONS(9410),
    [sym_local_keyword] = ACTIONS(9410),
    [sym_internal_keyword] = ACTIONS(9410),
    [sym_protected_keyword] = ACTIONS(9410),
    [sym_event_keyword] = ACTIONS(9410),
    [sym_fields_keyword] = ACTIONS(9410),
    [sym_keys_keyword] = ACTIONS(9410),
    [sym_fieldgroups_keyword] = ACTIONS(9410),
    [sym_actions_keyword] = ACTIONS(9410),
    [sym_layout_keyword] = ACTIONS(9410),
    [sym_area_keyword] = ACTIONS(9410),
    [sym_group_keyword] = ACTIONS(9410),
    [sym_repeater_keyword] = ACTIONS(9410),
    [sym_cuegroup_keyword] = ACTIONS(9410),
    [sym_fixed_keyword] = ACTIONS(9410),
    [sym_grid_keyword] = ACTIONS(9410),
    [sym_part_keyword] = ACTIONS(9410),
    [sym_systempart_keyword] = ACTIONS(9410),
    [sym_usercontrol_keyword] = ACTIONS(9410),
    [sym_dataset_keyword] = ACTIONS(9410),
    [sym_elements_keyword] = ACTIONS(9410),
    [sym_dataitem_keyword] = ACTIONS(9410),
    [sym_column_keyword] = ACTIONS(9410),
    [sym_filter_keyword] = ACTIONS(9410),
    [sym_labels_keyword] = ACTIONS(9410),
    [sym_rendering_keyword] = ACTIONS(9410),
    [sym_requestpage_keyword] = ACTIONS(9410),
    [sym_schema_keyword] = ACTIONS(9410),
    [sym_views_keyword] = ACTIONS(9410),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9410),
    [sym_preproc_open] = ACTIONS(9410),
    [sym_preproc_close] = ACTIONS(9410),
  },
  [STATE(4157)] = {
    [anon_sym_SEMI] = ACTIONS(9414),
    [aux_sym_where_condition_token1] = ACTIONS(9416),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9414),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9414),
    [anon_sym_LBRACK] = ACTIONS(9414),
    [aux_sym_basic_type_token6] = ACTIONS(9416),
    [aux_sym_basic_type_token22] = ACTIONS(9416),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9414),
    [aux_sym_addafter_modification_token1] = ACTIONS(9414),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9414),
    [aux_sym_modify_modification_token1] = ACTIONS(9414),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9414),
    [aux_sym_movelast_modification_token1] = ACTIONS(9414),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9414),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9414),
    [aux_sym_separator_action_token1] = ACTIONS(9414),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9414),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9414),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9414),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9414),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9414),
    [anon_sym_POUNDif] = ACTIONS(9414),
    [anon_sym_POUNDIF] = ACTIONS(9414),
    [anon_sym_POUNDIf] = ACTIONS(9414),
    [anon_sym_POUNDelif] = ACTIONS(9414),
    [anon_sym_POUNDELIF] = ACTIONS(9414),
    [anon_sym_POUNDElif] = ACTIONS(9414),
    [anon_sym_POUNDelse] = ACTIONS(9414),
    [anon_sym_POUNDELSE] = ACTIONS(9414),
    [anon_sym_POUNDElse] = ACTIONS(9414),
    [anon_sym_POUNDelse2] = ACTIONS(9414),
    [anon_sym_POUNDELSE2] = ACTIONS(9414),
    [anon_sym_POUNDElse2] = ACTIONS(9414),
    [anon_sym_POUNDendif] = ACTIONS(9414),
    [anon_sym_POUNDENDIF] = ACTIONS(9414),
    [anon_sym_POUNDEndif] = ACTIONS(9414),
    [anon_sym_POUNDendif2] = ACTIONS(9414),
    [anon_sym_POUNDENDIF2] = ACTIONS(9414),
    [anon_sym_POUNDEndif2] = ACTIONS(9414),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9414),
    [sym_trigger_keyword] = ACTIONS(9414),
    [sym_var_keyword] = ACTIONS(9414),
    [sym_local_keyword] = ACTIONS(9414),
    [sym_internal_keyword] = ACTIONS(9414),
    [sym_protected_keyword] = ACTIONS(9414),
    [sym_event_keyword] = ACTIONS(9414),
    [sym_fields_keyword] = ACTIONS(9414),
    [sym_keys_keyword] = ACTIONS(9414),
    [sym_fieldgroups_keyword] = ACTIONS(9414),
    [sym_actions_keyword] = ACTIONS(9414),
    [sym_layout_keyword] = ACTIONS(9414),
    [sym_area_keyword] = ACTIONS(9414),
    [sym_group_keyword] = ACTIONS(9414),
    [sym_repeater_keyword] = ACTIONS(9414),
    [sym_cuegroup_keyword] = ACTIONS(9414),
    [sym_fixed_keyword] = ACTIONS(9414),
    [sym_grid_keyword] = ACTIONS(9414),
    [sym_part_keyword] = ACTIONS(9414),
    [sym_systempart_keyword] = ACTIONS(9414),
    [sym_usercontrol_keyword] = ACTIONS(9414),
    [sym_dataset_keyword] = ACTIONS(9414),
    [sym_elements_keyword] = ACTIONS(9414),
    [sym_dataitem_keyword] = ACTIONS(9414),
    [sym_column_keyword] = ACTIONS(9414),
    [sym_filter_keyword] = ACTIONS(9414),
    [sym_labels_keyword] = ACTIONS(9414),
    [sym_rendering_keyword] = ACTIONS(9414),
    [sym_requestpage_keyword] = ACTIONS(9414),
    [sym_schema_keyword] = ACTIONS(9414),
    [sym_views_keyword] = ACTIONS(9414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9414),
    [sym_preproc_open] = ACTIONS(9414),
    [sym_preproc_close] = ACTIONS(9414),
  },
  [STATE(4158)] = {
    [anon_sym_SEMI] = ACTIONS(9418),
    [aux_sym_where_condition_token1] = ACTIONS(9420),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9418),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9418),
    [anon_sym_LBRACK] = ACTIONS(9418),
    [aux_sym_basic_type_token6] = ACTIONS(9420),
    [aux_sym_basic_type_token22] = ACTIONS(9420),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9418),
    [aux_sym_addafter_modification_token1] = ACTIONS(9418),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9418),
    [aux_sym_modify_modification_token1] = ACTIONS(9418),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9418),
    [aux_sym_movelast_modification_token1] = ACTIONS(9418),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9418),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9418),
    [aux_sym_separator_action_token1] = ACTIONS(9418),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9418),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9418),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9418),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9418),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9418),
    [anon_sym_POUNDif] = ACTIONS(9418),
    [anon_sym_POUNDIF] = ACTIONS(9418),
    [anon_sym_POUNDIf] = ACTIONS(9418),
    [anon_sym_POUNDelif] = ACTIONS(9418),
    [anon_sym_POUNDELIF] = ACTIONS(9418),
    [anon_sym_POUNDElif] = ACTIONS(9418),
    [anon_sym_POUNDelse] = ACTIONS(9418),
    [anon_sym_POUNDELSE] = ACTIONS(9418),
    [anon_sym_POUNDElse] = ACTIONS(9418),
    [anon_sym_POUNDelse2] = ACTIONS(9418),
    [anon_sym_POUNDELSE2] = ACTIONS(9418),
    [anon_sym_POUNDElse2] = ACTIONS(9418),
    [anon_sym_POUNDendif] = ACTIONS(9418),
    [anon_sym_POUNDENDIF] = ACTIONS(9418),
    [anon_sym_POUNDEndif] = ACTIONS(9418),
    [anon_sym_POUNDendif2] = ACTIONS(9418),
    [anon_sym_POUNDENDIF2] = ACTIONS(9418),
    [anon_sym_POUNDEndif2] = ACTIONS(9418),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9418),
    [sym_trigger_keyword] = ACTIONS(9418),
    [sym_var_keyword] = ACTIONS(9418),
    [sym_local_keyword] = ACTIONS(9418),
    [sym_internal_keyword] = ACTIONS(9418),
    [sym_protected_keyword] = ACTIONS(9418),
    [sym_event_keyword] = ACTIONS(9418),
    [sym_fields_keyword] = ACTIONS(9418),
    [sym_keys_keyword] = ACTIONS(9418),
    [sym_fieldgroups_keyword] = ACTIONS(9418),
    [sym_actions_keyword] = ACTIONS(9418),
    [sym_layout_keyword] = ACTIONS(9418),
    [sym_area_keyword] = ACTIONS(9418),
    [sym_group_keyword] = ACTIONS(9418),
    [sym_repeater_keyword] = ACTIONS(9418),
    [sym_cuegroup_keyword] = ACTIONS(9418),
    [sym_fixed_keyword] = ACTIONS(9418),
    [sym_grid_keyword] = ACTIONS(9418),
    [sym_part_keyword] = ACTIONS(9418),
    [sym_systempart_keyword] = ACTIONS(9418),
    [sym_usercontrol_keyword] = ACTIONS(9418),
    [sym_dataset_keyword] = ACTIONS(9418),
    [sym_elements_keyword] = ACTIONS(9418),
    [sym_dataitem_keyword] = ACTIONS(9418),
    [sym_column_keyword] = ACTIONS(9418),
    [sym_filter_keyword] = ACTIONS(9418),
    [sym_labels_keyword] = ACTIONS(9418),
    [sym_rendering_keyword] = ACTIONS(9418),
    [sym_requestpage_keyword] = ACTIONS(9418),
    [sym_schema_keyword] = ACTIONS(9418),
    [sym_views_keyword] = ACTIONS(9418),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9418),
    [sym_preproc_open] = ACTIONS(9418),
    [sym_preproc_close] = ACTIONS(9418),
  },
  [STATE(4159)] = {
    [anon_sym_SEMI] = ACTIONS(9422),
    [aux_sym_where_condition_token1] = ACTIONS(9424),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9422),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9422),
    [anon_sym_LBRACK] = ACTIONS(9422),
    [aux_sym_basic_type_token6] = ACTIONS(9424),
    [aux_sym_basic_type_token22] = ACTIONS(9424),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9422),
    [aux_sym_addafter_modification_token1] = ACTIONS(9422),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9422),
    [aux_sym_modify_modification_token1] = ACTIONS(9422),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9422),
    [aux_sym_movelast_modification_token1] = ACTIONS(9422),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9422),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9422),
    [aux_sym_separator_action_token1] = ACTIONS(9422),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9422),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9422),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9422),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9422),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9422),
    [anon_sym_POUNDif] = ACTIONS(9422),
    [anon_sym_POUNDIF] = ACTIONS(9422),
    [anon_sym_POUNDIf] = ACTIONS(9422),
    [anon_sym_POUNDelif] = ACTIONS(9422),
    [anon_sym_POUNDELIF] = ACTIONS(9422),
    [anon_sym_POUNDElif] = ACTIONS(9422),
    [anon_sym_POUNDelse] = ACTIONS(9422),
    [anon_sym_POUNDELSE] = ACTIONS(9422),
    [anon_sym_POUNDElse] = ACTIONS(9422),
    [anon_sym_POUNDelse2] = ACTIONS(9422),
    [anon_sym_POUNDELSE2] = ACTIONS(9422),
    [anon_sym_POUNDElse2] = ACTIONS(9422),
    [anon_sym_POUNDendif] = ACTIONS(9422),
    [anon_sym_POUNDENDIF] = ACTIONS(9422),
    [anon_sym_POUNDEndif] = ACTIONS(9422),
    [anon_sym_POUNDendif2] = ACTIONS(9422),
    [anon_sym_POUNDENDIF2] = ACTIONS(9422),
    [anon_sym_POUNDEndif2] = ACTIONS(9422),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9422),
    [sym_trigger_keyword] = ACTIONS(9422),
    [sym_var_keyword] = ACTIONS(9422),
    [sym_local_keyword] = ACTIONS(9422),
    [sym_internal_keyword] = ACTIONS(9422),
    [sym_protected_keyword] = ACTIONS(9422),
    [sym_event_keyword] = ACTIONS(9422),
    [sym_fields_keyword] = ACTIONS(9422),
    [sym_keys_keyword] = ACTIONS(9422),
    [sym_fieldgroups_keyword] = ACTIONS(9422),
    [sym_actions_keyword] = ACTIONS(9422),
    [sym_layout_keyword] = ACTIONS(9422),
    [sym_area_keyword] = ACTIONS(9422),
    [sym_group_keyword] = ACTIONS(9422),
    [sym_repeater_keyword] = ACTIONS(9422),
    [sym_cuegroup_keyword] = ACTIONS(9422),
    [sym_fixed_keyword] = ACTIONS(9422),
    [sym_grid_keyword] = ACTIONS(9422),
    [sym_part_keyword] = ACTIONS(9422),
    [sym_systempart_keyword] = ACTIONS(9422),
    [sym_usercontrol_keyword] = ACTIONS(9422),
    [sym_dataset_keyword] = ACTIONS(9422),
    [sym_elements_keyword] = ACTIONS(9422),
    [sym_dataitem_keyword] = ACTIONS(9422),
    [sym_column_keyword] = ACTIONS(9422),
    [sym_filter_keyword] = ACTIONS(9422),
    [sym_labels_keyword] = ACTIONS(9422),
    [sym_rendering_keyword] = ACTIONS(9422),
    [sym_requestpage_keyword] = ACTIONS(9422),
    [sym_schema_keyword] = ACTIONS(9422),
    [sym_views_keyword] = ACTIONS(9422),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9422),
    [sym_preproc_open] = ACTIONS(9422),
    [sym_preproc_close] = ACTIONS(9422),
  },
  [STATE(4160)] = {
    [anon_sym_SEMI] = ACTIONS(9426),
    [aux_sym_where_condition_token1] = ACTIONS(9428),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9426),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9426),
    [anon_sym_LBRACK] = ACTIONS(9426),
    [aux_sym_basic_type_token6] = ACTIONS(9428),
    [aux_sym_basic_type_token22] = ACTIONS(9428),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9426),
    [aux_sym_addafter_modification_token1] = ACTIONS(9426),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9426),
    [aux_sym_modify_modification_token1] = ACTIONS(9426),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9426),
    [aux_sym_movelast_modification_token1] = ACTIONS(9426),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9426),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9426),
    [aux_sym_separator_action_token1] = ACTIONS(9426),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9426),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9426),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9426),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9426),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9426),
    [anon_sym_POUNDif] = ACTIONS(9426),
    [anon_sym_POUNDIF] = ACTIONS(9426),
    [anon_sym_POUNDIf] = ACTIONS(9426),
    [anon_sym_POUNDelif] = ACTIONS(9426),
    [anon_sym_POUNDELIF] = ACTIONS(9426),
    [anon_sym_POUNDElif] = ACTIONS(9426),
    [anon_sym_POUNDelse] = ACTIONS(9426),
    [anon_sym_POUNDELSE] = ACTIONS(9426),
    [anon_sym_POUNDElse] = ACTIONS(9426),
    [anon_sym_POUNDelse2] = ACTIONS(9426),
    [anon_sym_POUNDELSE2] = ACTIONS(9426),
    [anon_sym_POUNDElse2] = ACTIONS(9426),
    [anon_sym_POUNDendif] = ACTIONS(9426),
    [anon_sym_POUNDENDIF] = ACTIONS(9426),
    [anon_sym_POUNDEndif] = ACTIONS(9426),
    [anon_sym_POUNDendif2] = ACTIONS(9426),
    [anon_sym_POUNDENDIF2] = ACTIONS(9426),
    [anon_sym_POUNDEndif2] = ACTIONS(9426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9426),
    [sym_trigger_keyword] = ACTIONS(9426),
    [sym_var_keyword] = ACTIONS(9426),
    [sym_local_keyword] = ACTIONS(9426),
    [sym_internal_keyword] = ACTIONS(9426),
    [sym_protected_keyword] = ACTIONS(9426),
    [sym_event_keyword] = ACTIONS(9426),
    [sym_fields_keyword] = ACTIONS(9426),
    [sym_keys_keyword] = ACTIONS(9426),
    [sym_fieldgroups_keyword] = ACTIONS(9426),
    [sym_actions_keyword] = ACTIONS(9426),
    [sym_layout_keyword] = ACTIONS(9426),
    [sym_area_keyword] = ACTIONS(9426),
    [sym_group_keyword] = ACTIONS(9426),
    [sym_repeater_keyword] = ACTIONS(9426),
    [sym_cuegroup_keyword] = ACTIONS(9426),
    [sym_fixed_keyword] = ACTIONS(9426),
    [sym_grid_keyword] = ACTIONS(9426),
    [sym_part_keyword] = ACTIONS(9426),
    [sym_systempart_keyword] = ACTIONS(9426),
    [sym_usercontrol_keyword] = ACTIONS(9426),
    [sym_dataset_keyword] = ACTIONS(9426),
    [sym_elements_keyword] = ACTIONS(9426),
    [sym_dataitem_keyword] = ACTIONS(9426),
    [sym_column_keyword] = ACTIONS(9426),
    [sym_filter_keyword] = ACTIONS(9426),
    [sym_labels_keyword] = ACTIONS(9426),
    [sym_rendering_keyword] = ACTIONS(9426),
    [sym_requestpage_keyword] = ACTIONS(9426),
    [sym_schema_keyword] = ACTIONS(9426),
    [sym_views_keyword] = ACTIONS(9426),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9426),
    [sym_preproc_open] = ACTIONS(9426),
    [sym_preproc_close] = ACTIONS(9426),
  },
  [STATE(4161)] = {
    [anon_sym_SEMI] = ACTIONS(9430),
    [aux_sym_where_condition_token1] = ACTIONS(9432),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9430),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9430),
    [anon_sym_LBRACK] = ACTIONS(9430),
    [aux_sym_basic_type_token6] = ACTIONS(9432),
    [aux_sym_basic_type_token22] = ACTIONS(9432),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9430),
    [aux_sym_addafter_modification_token1] = ACTIONS(9430),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9430),
    [aux_sym_modify_modification_token1] = ACTIONS(9430),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9430),
    [aux_sym_movelast_modification_token1] = ACTIONS(9430),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9430),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9430),
    [aux_sym_separator_action_token1] = ACTIONS(9430),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9430),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9430),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9430),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9430),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9430),
    [anon_sym_POUNDif] = ACTIONS(9430),
    [anon_sym_POUNDIF] = ACTIONS(9430),
    [anon_sym_POUNDIf] = ACTIONS(9430),
    [anon_sym_POUNDelif] = ACTIONS(9430),
    [anon_sym_POUNDELIF] = ACTIONS(9430),
    [anon_sym_POUNDElif] = ACTIONS(9430),
    [anon_sym_POUNDelse] = ACTIONS(9430),
    [anon_sym_POUNDELSE] = ACTIONS(9430),
    [anon_sym_POUNDElse] = ACTIONS(9430),
    [anon_sym_POUNDelse2] = ACTIONS(9430),
    [anon_sym_POUNDELSE2] = ACTIONS(9430),
    [anon_sym_POUNDElse2] = ACTIONS(9430),
    [anon_sym_POUNDendif] = ACTIONS(9430),
    [anon_sym_POUNDENDIF] = ACTIONS(9430),
    [anon_sym_POUNDEndif] = ACTIONS(9430),
    [anon_sym_POUNDendif2] = ACTIONS(9430),
    [anon_sym_POUNDENDIF2] = ACTIONS(9430),
    [anon_sym_POUNDEndif2] = ACTIONS(9430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9430),
    [sym_trigger_keyword] = ACTIONS(9430),
    [sym_var_keyword] = ACTIONS(9430),
    [sym_local_keyword] = ACTIONS(9430),
    [sym_internal_keyword] = ACTIONS(9430),
    [sym_protected_keyword] = ACTIONS(9430),
    [sym_event_keyword] = ACTIONS(9430),
    [sym_fields_keyword] = ACTIONS(9430),
    [sym_keys_keyword] = ACTIONS(9430),
    [sym_fieldgroups_keyword] = ACTIONS(9430),
    [sym_actions_keyword] = ACTIONS(9430),
    [sym_layout_keyword] = ACTIONS(9430),
    [sym_area_keyword] = ACTIONS(9430),
    [sym_group_keyword] = ACTIONS(9430),
    [sym_repeater_keyword] = ACTIONS(9430),
    [sym_cuegroup_keyword] = ACTIONS(9430),
    [sym_fixed_keyword] = ACTIONS(9430),
    [sym_grid_keyword] = ACTIONS(9430),
    [sym_part_keyword] = ACTIONS(9430),
    [sym_systempart_keyword] = ACTIONS(9430),
    [sym_usercontrol_keyword] = ACTIONS(9430),
    [sym_dataset_keyword] = ACTIONS(9430),
    [sym_elements_keyword] = ACTIONS(9430),
    [sym_dataitem_keyword] = ACTIONS(9430),
    [sym_column_keyword] = ACTIONS(9430),
    [sym_filter_keyword] = ACTIONS(9430),
    [sym_labels_keyword] = ACTIONS(9430),
    [sym_rendering_keyword] = ACTIONS(9430),
    [sym_requestpage_keyword] = ACTIONS(9430),
    [sym_schema_keyword] = ACTIONS(9430),
    [sym_views_keyword] = ACTIONS(9430),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9430),
    [sym_preproc_open] = ACTIONS(9430),
    [sym_preproc_close] = ACTIONS(9430),
  },
  [STATE(4162)] = {
    [anon_sym_SEMI] = ACTIONS(9434),
    [aux_sym_where_condition_token1] = ACTIONS(9436),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9434),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9434),
    [anon_sym_LBRACK] = ACTIONS(9434),
    [aux_sym_basic_type_token6] = ACTIONS(9436),
    [aux_sym_basic_type_token22] = ACTIONS(9436),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9434),
    [aux_sym_addafter_modification_token1] = ACTIONS(9434),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9434),
    [aux_sym_modify_modification_token1] = ACTIONS(9434),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9434),
    [aux_sym_movelast_modification_token1] = ACTIONS(9434),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9434),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9434),
    [aux_sym_separator_action_token1] = ACTIONS(9434),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9434),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9434),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9434),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9434),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9434),
    [anon_sym_POUNDif] = ACTIONS(9434),
    [anon_sym_POUNDIF] = ACTIONS(9434),
    [anon_sym_POUNDIf] = ACTIONS(9434),
    [anon_sym_POUNDelif] = ACTIONS(9434),
    [anon_sym_POUNDELIF] = ACTIONS(9434),
    [anon_sym_POUNDElif] = ACTIONS(9434),
    [anon_sym_POUNDelse] = ACTIONS(9434),
    [anon_sym_POUNDELSE] = ACTIONS(9434),
    [anon_sym_POUNDElse] = ACTIONS(9434),
    [anon_sym_POUNDelse2] = ACTIONS(9434),
    [anon_sym_POUNDELSE2] = ACTIONS(9434),
    [anon_sym_POUNDElse2] = ACTIONS(9434),
    [anon_sym_POUNDendif] = ACTIONS(9434),
    [anon_sym_POUNDENDIF] = ACTIONS(9434),
    [anon_sym_POUNDEndif] = ACTIONS(9434),
    [anon_sym_POUNDendif2] = ACTIONS(9434),
    [anon_sym_POUNDENDIF2] = ACTIONS(9434),
    [anon_sym_POUNDEndif2] = ACTIONS(9434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9434),
    [sym_trigger_keyword] = ACTIONS(9434),
    [sym_var_keyword] = ACTIONS(9434),
    [sym_local_keyword] = ACTIONS(9434),
    [sym_internal_keyword] = ACTIONS(9434),
    [sym_protected_keyword] = ACTIONS(9434),
    [sym_event_keyword] = ACTIONS(9434),
    [sym_fields_keyword] = ACTIONS(9434),
    [sym_keys_keyword] = ACTIONS(9434),
    [sym_fieldgroups_keyword] = ACTIONS(9434),
    [sym_actions_keyword] = ACTIONS(9434),
    [sym_layout_keyword] = ACTIONS(9434),
    [sym_area_keyword] = ACTIONS(9434),
    [sym_group_keyword] = ACTIONS(9434),
    [sym_repeater_keyword] = ACTIONS(9434),
    [sym_cuegroup_keyword] = ACTIONS(9434),
    [sym_fixed_keyword] = ACTIONS(9434),
    [sym_grid_keyword] = ACTIONS(9434),
    [sym_part_keyword] = ACTIONS(9434),
    [sym_systempart_keyword] = ACTIONS(9434),
    [sym_usercontrol_keyword] = ACTIONS(9434),
    [sym_dataset_keyword] = ACTIONS(9434),
    [sym_elements_keyword] = ACTIONS(9434),
    [sym_dataitem_keyword] = ACTIONS(9434),
    [sym_column_keyword] = ACTIONS(9434),
    [sym_filter_keyword] = ACTIONS(9434),
    [sym_labels_keyword] = ACTIONS(9434),
    [sym_rendering_keyword] = ACTIONS(9434),
    [sym_requestpage_keyword] = ACTIONS(9434),
    [sym_schema_keyword] = ACTIONS(9434),
    [sym_views_keyword] = ACTIONS(9434),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9434),
    [sym_preproc_open] = ACTIONS(9434),
    [sym_preproc_close] = ACTIONS(9434),
  },
  [STATE(4163)] = {
    [anon_sym_SEMI] = ACTIONS(9438),
    [aux_sym_where_condition_token1] = ACTIONS(9440),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9438),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9438),
    [anon_sym_LBRACK] = ACTIONS(9438),
    [aux_sym_basic_type_token6] = ACTIONS(9440),
    [aux_sym_basic_type_token22] = ACTIONS(9440),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9438),
    [aux_sym_addafter_modification_token1] = ACTIONS(9438),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9438),
    [aux_sym_modify_modification_token1] = ACTIONS(9438),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9438),
    [aux_sym_movelast_modification_token1] = ACTIONS(9438),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9438),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9438),
    [aux_sym_separator_action_token1] = ACTIONS(9438),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9438),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9438),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9438),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9438),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9438),
    [anon_sym_POUNDif] = ACTIONS(9438),
    [anon_sym_POUNDIF] = ACTIONS(9438),
    [anon_sym_POUNDIf] = ACTIONS(9438),
    [anon_sym_POUNDelif] = ACTIONS(9438),
    [anon_sym_POUNDELIF] = ACTIONS(9438),
    [anon_sym_POUNDElif] = ACTIONS(9438),
    [anon_sym_POUNDelse] = ACTIONS(9438),
    [anon_sym_POUNDELSE] = ACTIONS(9438),
    [anon_sym_POUNDElse] = ACTIONS(9438),
    [anon_sym_POUNDelse2] = ACTIONS(9438),
    [anon_sym_POUNDELSE2] = ACTIONS(9438),
    [anon_sym_POUNDElse2] = ACTIONS(9438),
    [anon_sym_POUNDendif] = ACTIONS(9438),
    [anon_sym_POUNDENDIF] = ACTIONS(9438),
    [anon_sym_POUNDEndif] = ACTIONS(9438),
    [anon_sym_POUNDendif2] = ACTIONS(9438),
    [anon_sym_POUNDENDIF2] = ACTIONS(9438),
    [anon_sym_POUNDEndif2] = ACTIONS(9438),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9438),
    [sym_trigger_keyword] = ACTIONS(9438),
    [sym_var_keyword] = ACTIONS(9438),
    [sym_local_keyword] = ACTIONS(9438),
    [sym_internal_keyword] = ACTIONS(9438),
    [sym_protected_keyword] = ACTIONS(9438),
    [sym_event_keyword] = ACTIONS(9438),
    [sym_fields_keyword] = ACTIONS(9438),
    [sym_keys_keyword] = ACTIONS(9438),
    [sym_fieldgroups_keyword] = ACTIONS(9438),
    [sym_actions_keyword] = ACTIONS(9438),
    [sym_layout_keyword] = ACTIONS(9438),
    [sym_area_keyword] = ACTIONS(9438),
    [sym_group_keyword] = ACTIONS(9438),
    [sym_repeater_keyword] = ACTIONS(9438),
    [sym_cuegroup_keyword] = ACTIONS(9438),
    [sym_fixed_keyword] = ACTIONS(9438),
    [sym_grid_keyword] = ACTIONS(9438),
    [sym_part_keyword] = ACTIONS(9438),
    [sym_systempart_keyword] = ACTIONS(9438),
    [sym_usercontrol_keyword] = ACTIONS(9438),
    [sym_dataset_keyword] = ACTIONS(9438),
    [sym_elements_keyword] = ACTIONS(9438),
    [sym_dataitem_keyword] = ACTIONS(9438),
    [sym_column_keyword] = ACTIONS(9438),
    [sym_filter_keyword] = ACTIONS(9438),
    [sym_labels_keyword] = ACTIONS(9438),
    [sym_rendering_keyword] = ACTIONS(9438),
    [sym_requestpage_keyword] = ACTIONS(9438),
    [sym_schema_keyword] = ACTIONS(9438),
    [sym_views_keyword] = ACTIONS(9438),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9438),
    [sym_preproc_open] = ACTIONS(9438),
    [sym_preproc_close] = ACTIONS(9438),
  },
  [STATE(4164)] = {
    [anon_sym_SEMI] = ACTIONS(9442),
    [aux_sym_where_condition_token1] = ACTIONS(9444),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9442),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9442),
    [anon_sym_LBRACK] = ACTIONS(9442),
    [aux_sym_basic_type_token6] = ACTIONS(9444),
    [aux_sym_basic_type_token22] = ACTIONS(9444),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9442),
    [aux_sym_addafter_modification_token1] = ACTIONS(9442),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9442),
    [aux_sym_modify_modification_token1] = ACTIONS(9442),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9442),
    [aux_sym_movelast_modification_token1] = ACTIONS(9442),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9442),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9442),
    [aux_sym_separator_action_token1] = ACTIONS(9442),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9442),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9442),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9442),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9442),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9442),
    [anon_sym_POUNDif] = ACTIONS(9442),
    [anon_sym_POUNDIF] = ACTIONS(9442),
    [anon_sym_POUNDIf] = ACTIONS(9442),
    [anon_sym_POUNDelif] = ACTIONS(9442),
    [anon_sym_POUNDELIF] = ACTIONS(9442),
    [anon_sym_POUNDElif] = ACTIONS(9442),
    [anon_sym_POUNDelse] = ACTIONS(9442),
    [anon_sym_POUNDELSE] = ACTIONS(9442),
    [anon_sym_POUNDElse] = ACTIONS(9442),
    [anon_sym_POUNDelse2] = ACTIONS(9442),
    [anon_sym_POUNDELSE2] = ACTIONS(9442),
    [anon_sym_POUNDElse2] = ACTIONS(9442),
    [anon_sym_POUNDendif] = ACTIONS(9442),
    [anon_sym_POUNDENDIF] = ACTIONS(9442),
    [anon_sym_POUNDEndif] = ACTIONS(9442),
    [anon_sym_POUNDendif2] = ACTIONS(9442),
    [anon_sym_POUNDENDIF2] = ACTIONS(9442),
    [anon_sym_POUNDEndif2] = ACTIONS(9442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9442),
    [sym_trigger_keyword] = ACTIONS(9442),
    [sym_var_keyword] = ACTIONS(9442),
    [sym_local_keyword] = ACTIONS(9442),
    [sym_internal_keyword] = ACTIONS(9442),
    [sym_protected_keyword] = ACTIONS(9442),
    [sym_event_keyword] = ACTIONS(9442),
    [sym_fields_keyword] = ACTIONS(9442),
    [sym_keys_keyword] = ACTIONS(9442),
    [sym_fieldgroups_keyword] = ACTIONS(9442),
    [sym_actions_keyword] = ACTIONS(9442),
    [sym_layout_keyword] = ACTIONS(9442),
    [sym_area_keyword] = ACTIONS(9442),
    [sym_group_keyword] = ACTIONS(9442),
    [sym_repeater_keyword] = ACTIONS(9442),
    [sym_cuegroup_keyword] = ACTIONS(9442),
    [sym_fixed_keyword] = ACTIONS(9442),
    [sym_grid_keyword] = ACTIONS(9442),
    [sym_part_keyword] = ACTIONS(9442),
    [sym_systempart_keyword] = ACTIONS(9442),
    [sym_usercontrol_keyword] = ACTIONS(9442),
    [sym_dataset_keyword] = ACTIONS(9442),
    [sym_elements_keyword] = ACTIONS(9442),
    [sym_dataitem_keyword] = ACTIONS(9442),
    [sym_column_keyword] = ACTIONS(9442),
    [sym_filter_keyword] = ACTIONS(9442),
    [sym_labels_keyword] = ACTIONS(9442),
    [sym_rendering_keyword] = ACTIONS(9442),
    [sym_requestpage_keyword] = ACTIONS(9442),
    [sym_schema_keyword] = ACTIONS(9442),
    [sym_views_keyword] = ACTIONS(9442),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9442),
    [sym_preproc_open] = ACTIONS(9442),
    [sym_preproc_close] = ACTIONS(9442),
  },
  [STATE(4165)] = {
    [anon_sym_SEMI] = ACTIONS(9446),
    [aux_sym_where_condition_token1] = ACTIONS(9448),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9446),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9446),
    [anon_sym_LBRACK] = ACTIONS(9446),
    [aux_sym_basic_type_token6] = ACTIONS(9448),
    [aux_sym_basic_type_token22] = ACTIONS(9448),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9446),
    [aux_sym_addafter_modification_token1] = ACTIONS(9446),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9446),
    [aux_sym_modify_modification_token1] = ACTIONS(9446),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9446),
    [aux_sym_movelast_modification_token1] = ACTIONS(9446),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9446),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9446),
    [aux_sym_separator_action_token1] = ACTIONS(9446),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9446),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9446),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9446),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9446),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9446),
    [anon_sym_POUNDif] = ACTIONS(9446),
    [anon_sym_POUNDIF] = ACTIONS(9446),
    [anon_sym_POUNDIf] = ACTIONS(9446),
    [anon_sym_POUNDelif] = ACTIONS(9446),
    [anon_sym_POUNDELIF] = ACTIONS(9446),
    [anon_sym_POUNDElif] = ACTIONS(9446),
    [anon_sym_POUNDelse] = ACTIONS(9446),
    [anon_sym_POUNDELSE] = ACTIONS(9446),
    [anon_sym_POUNDElse] = ACTIONS(9446),
    [anon_sym_POUNDelse2] = ACTIONS(9446),
    [anon_sym_POUNDELSE2] = ACTIONS(9446),
    [anon_sym_POUNDElse2] = ACTIONS(9446),
    [anon_sym_POUNDendif] = ACTIONS(9446),
    [anon_sym_POUNDENDIF] = ACTIONS(9446),
    [anon_sym_POUNDEndif] = ACTIONS(9446),
    [anon_sym_POUNDendif2] = ACTIONS(9446),
    [anon_sym_POUNDENDIF2] = ACTIONS(9446),
    [anon_sym_POUNDEndif2] = ACTIONS(9446),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9446),
    [sym_trigger_keyword] = ACTIONS(9446),
    [sym_var_keyword] = ACTIONS(9446),
    [sym_local_keyword] = ACTIONS(9446),
    [sym_internal_keyword] = ACTIONS(9446),
    [sym_protected_keyword] = ACTIONS(9446),
    [sym_event_keyword] = ACTIONS(9446),
    [sym_fields_keyword] = ACTIONS(9446),
    [sym_keys_keyword] = ACTIONS(9446),
    [sym_fieldgroups_keyword] = ACTIONS(9446),
    [sym_actions_keyword] = ACTIONS(9446),
    [sym_layout_keyword] = ACTIONS(9446),
    [sym_area_keyword] = ACTIONS(9446),
    [sym_group_keyword] = ACTIONS(9446),
    [sym_repeater_keyword] = ACTIONS(9446),
    [sym_cuegroup_keyword] = ACTIONS(9446),
    [sym_fixed_keyword] = ACTIONS(9446),
    [sym_grid_keyword] = ACTIONS(9446),
    [sym_part_keyword] = ACTIONS(9446),
    [sym_systempart_keyword] = ACTIONS(9446),
    [sym_usercontrol_keyword] = ACTIONS(9446),
    [sym_dataset_keyword] = ACTIONS(9446),
    [sym_elements_keyword] = ACTIONS(9446),
    [sym_dataitem_keyword] = ACTIONS(9446),
    [sym_column_keyword] = ACTIONS(9446),
    [sym_filter_keyword] = ACTIONS(9446),
    [sym_labels_keyword] = ACTIONS(9446),
    [sym_rendering_keyword] = ACTIONS(9446),
    [sym_requestpage_keyword] = ACTIONS(9446),
    [sym_schema_keyword] = ACTIONS(9446),
    [sym_views_keyword] = ACTIONS(9446),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9446),
    [sym_preproc_open] = ACTIONS(9446),
    [sym_preproc_close] = ACTIONS(9446),
  },
  [STATE(4166)] = {
    [anon_sym_SEMI] = ACTIONS(9442),
    [aux_sym_where_condition_token1] = ACTIONS(9444),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9442),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9442),
    [anon_sym_LBRACK] = ACTIONS(9442),
    [aux_sym_basic_type_token6] = ACTIONS(9444),
    [aux_sym_basic_type_token22] = ACTIONS(9444),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9442),
    [aux_sym_addafter_modification_token1] = ACTIONS(9442),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9442),
    [aux_sym_modify_modification_token1] = ACTIONS(9442),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9442),
    [aux_sym_movelast_modification_token1] = ACTIONS(9442),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9442),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9442),
    [aux_sym_separator_action_token1] = ACTIONS(9442),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9442),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9442),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9442),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9442),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9442),
    [anon_sym_POUNDif] = ACTIONS(9442),
    [anon_sym_POUNDIF] = ACTIONS(9442),
    [anon_sym_POUNDIf] = ACTIONS(9442),
    [anon_sym_POUNDelif] = ACTIONS(9442),
    [anon_sym_POUNDELIF] = ACTIONS(9442),
    [anon_sym_POUNDElif] = ACTIONS(9442),
    [anon_sym_POUNDelse] = ACTIONS(9442),
    [anon_sym_POUNDELSE] = ACTIONS(9442),
    [anon_sym_POUNDElse] = ACTIONS(9442),
    [anon_sym_POUNDelse2] = ACTIONS(9442),
    [anon_sym_POUNDELSE2] = ACTIONS(9442),
    [anon_sym_POUNDElse2] = ACTIONS(9442),
    [anon_sym_POUNDendif] = ACTIONS(9442),
    [anon_sym_POUNDENDIF] = ACTIONS(9442),
    [anon_sym_POUNDEndif] = ACTIONS(9442),
    [anon_sym_POUNDendif2] = ACTIONS(9442),
    [anon_sym_POUNDENDIF2] = ACTIONS(9442),
    [anon_sym_POUNDEndif2] = ACTIONS(9442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9442),
    [sym_trigger_keyword] = ACTIONS(9442),
    [sym_var_keyword] = ACTIONS(9442),
    [sym_local_keyword] = ACTIONS(9442),
    [sym_internal_keyword] = ACTIONS(9442),
    [sym_protected_keyword] = ACTIONS(9442),
    [sym_event_keyword] = ACTIONS(9442),
    [sym_fields_keyword] = ACTIONS(9442),
    [sym_keys_keyword] = ACTIONS(9442),
    [sym_fieldgroups_keyword] = ACTIONS(9442),
    [sym_actions_keyword] = ACTIONS(9442),
    [sym_layout_keyword] = ACTIONS(9442),
    [sym_area_keyword] = ACTIONS(9442),
    [sym_group_keyword] = ACTIONS(9442),
    [sym_repeater_keyword] = ACTIONS(9442),
    [sym_cuegroup_keyword] = ACTIONS(9442),
    [sym_fixed_keyword] = ACTIONS(9442),
    [sym_grid_keyword] = ACTIONS(9442),
    [sym_part_keyword] = ACTIONS(9442),
    [sym_systempart_keyword] = ACTIONS(9442),
    [sym_usercontrol_keyword] = ACTIONS(9442),
    [sym_dataset_keyword] = ACTIONS(9442),
    [sym_elements_keyword] = ACTIONS(9442),
    [sym_dataitem_keyword] = ACTIONS(9442),
    [sym_column_keyword] = ACTIONS(9442),
    [sym_filter_keyword] = ACTIONS(9442),
    [sym_labels_keyword] = ACTIONS(9442),
    [sym_rendering_keyword] = ACTIONS(9442),
    [sym_requestpage_keyword] = ACTIONS(9442),
    [sym_schema_keyword] = ACTIONS(9442),
    [sym_views_keyword] = ACTIONS(9442),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9442),
    [sym_preproc_open] = ACTIONS(9442),
    [sym_preproc_close] = ACTIONS(9442),
  },
  [STATE(4167)] = {
    [anon_sym_SEMI] = ACTIONS(9430),
    [aux_sym_where_condition_token1] = ACTIONS(9432),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9430),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9430),
    [anon_sym_LBRACK] = ACTIONS(9430),
    [aux_sym_basic_type_token6] = ACTIONS(9432),
    [aux_sym_basic_type_token22] = ACTIONS(9432),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9430),
    [aux_sym_addafter_modification_token1] = ACTIONS(9430),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9430),
    [aux_sym_modify_modification_token1] = ACTIONS(9430),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9430),
    [aux_sym_movelast_modification_token1] = ACTIONS(9430),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9430),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9430),
    [aux_sym_separator_action_token1] = ACTIONS(9430),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9430),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9430),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9430),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9430),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9430),
    [anon_sym_POUNDif] = ACTIONS(9430),
    [anon_sym_POUNDIF] = ACTIONS(9430),
    [anon_sym_POUNDIf] = ACTIONS(9430),
    [anon_sym_POUNDelif] = ACTIONS(9430),
    [anon_sym_POUNDELIF] = ACTIONS(9430),
    [anon_sym_POUNDElif] = ACTIONS(9430),
    [anon_sym_POUNDelse] = ACTIONS(9430),
    [anon_sym_POUNDELSE] = ACTIONS(9430),
    [anon_sym_POUNDElse] = ACTIONS(9430),
    [anon_sym_POUNDelse2] = ACTIONS(9430),
    [anon_sym_POUNDELSE2] = ACTIONS(9430),
    [anon_sym_POUNDElse2] = ACTIONS(9430),
    [anon_sym_POUNDendif] = ACTIONS(9430),
    [anon_sym_POUNDENDIF] = ACTIONS(9430),
    [anon_sym_POUNDEndif] = ACTIONS(9430),
    [anon_sym_POUNDendif2] = ACTIONS(9430),
    [anon_sym_POUNDENDIF2] = ACTIONS(9430),
    [anon_sym_POUNDEndif2] = ACTIONS(9430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9430),
    [sym_trigger_keyword] = ACTIONS(9430),
    [sym_var_keyword] = ACTIONS(9430),
    [sym_local_keyword] = ACTIONS(9430),
    [sym_internal_keyword] = ACTIONS(9430),
    [sym_protected_keyword] = ACTIONS(9430),
    [sym_event_keyword] = ACTIONS(9430),
    [sym_fields_keyword] = ACTIONS(9430),
    [sym_keys_keyword] = ACTIONS(9430),
    [sym_fieldgroups_keyword] = ACTIONS(9430),
    [sym_actions_keyword] = ACTIONS(9430),
    [sym_layout_keyword] = ACTIONS(9430),
    [sym_area_keyword] = ACTIONS(9430),
    [sym_group_keyword] = ACTIONS(9430),
    [sym_repeater_keyword] = ACTIONS(9430),
    [sym_cuegroup_keyword] = ACTIONS(9430),
    [sym_fixed_keyword] = ACTIONS(9430),
    [sym_grid_keyword] = ACTIONS(9430),
    [sym_part_keyword] = ACTIONS(9430),
    [sym_systempart_keyword] = ACTIONS(9430),
    [sym_usercontrol_keyword] = ACTIONS(9430),
    [sym_dataset_keyword] = ACTIONS(9430),
    [sym_elements_keyword] = ACTIONS(9430),
    [sym_dataitem_keyword] = ACTIONS(9430),
    [sym_column_keyword] = ACTIONS(9430),
    [sym_filter_keyword] = ACTIONS(9430),
    [sym_labels_keyword] = ACTIONS(9430),
    [sym_rendering_keyword] = ACTIONS(9430),
    [sym_requestpage_keyword] = ACTIONS(9430),
    [sym_schema_keyword] = ACTIONS(9430),
    [sym_views_keyword] = ACTIONS(9430),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9430),
    [sym_preproc_open] = ACTIONS(9430),
    [sym_preproc_close] = ACTIONS(9430),
  },
  [STATE(4168)] = {
    [anon_sym_SEMI] = ACTIONS(9450),
    [aux_sym_where_condition_token1] = ACTIONS(9452),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9450),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9450),
    [anon_sym_LBRACK] = ACTIONS(9450),
    [aux_sym_basic_type_token6] = ACTIONS(9452),
    [aux_sym_basic_type_token22] = ACTIONS(9452),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9450),
    [aux_sym_addafter_modification_token1] = ACTIONS(9450),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9450),
    [aux_sym_modify_modification_token1] = ACTIONS(9450),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9450),
    [aux_sym_movelast_modification_token1] = ACTIONS(9450),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9450),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9450),
    [aux_sym_separator_action_token1] = ACTIONS(9450),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9450),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9450),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9450),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9450),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9450),
    [anon_sym_POUNDif] = ACTIONS(9450),
    [anon_sym_POUNDIF] = ACTIONS(9450),
    [anon_sym_POUNDIf] = ACTIONS(9450),
    [anon_sym_POUNDelif] = ACTIONS(9450),
    [anon_sym_POUNDELIF] = ACTIONS(9450),
    [anon_sym_POUNDElif] = ACTIONS(9450),
    [anon_sym_POUNDelse] = ACTIONS(9450),
    [anon_sym_POUNDELSE] = ACTIONS(9450),
    [anon_sym_POUNDElse] = ACTIONS(9450),
    [anon_sym_POUNDelse2] = ACTIONS(9450),
    [anon_sym_POUNDELSE2] = ACTIONS(9450),
    [anon_sym_POUNDElse2] = ACTIONS(9450),
    [anon_sym_POUNDendif] = ACTIONS(9450),
    [anon_sym_POUNDENDIF] = ACTIONS(9450),
    [anon_sym_POUNDEndif] = ACTIONS(9450),
    [anon_sym_POUNDendif2] = ACTIONS(9450),
    [anon_sym_POUNDENDIF2] = ACTIONS(9450),
    [anon_sym_POUNDEndif2] = ACTIONS(9450),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9450),
    [sym_trigger_keyword] = ACTIONS(9450),
    [sym_var_keyword] = ACTIONS(9450),
    [sym_local_keyword] = ACTIONS(9450),
    [sym_internal_keyword] = ACTIONS(9450),
    [sym_protected_keyword] = ACTIONS(9450),
    [sym_event_keyword] = ACTIONS(9450),
    [sym_fields_keyword] = ACTIONS(9450),
    [sym_keys_keyword] = ACTIONS(9450),
    [sym_fieldgroups_keyword] = ACTIONS(9450),
    [sym_actions_keyword] = ACTIONS(9450),
    [sym_layout_keyword] = ACTIONS(9450),
    [sym_area_keyword] = ACTIONS(9450),
    [sym_group_keyword] = ACTIONS(9450),
    [sym_repeater_keyword] = ACTIONS(9450),
    [sym_cuegroup_keyword] = ACTIONS(9450),
    [sym_fixed_keyword] = ACTIONS(9450),
    [sym_grid_keyword] = ACTIONS(9450),
    [sym_part_keyword] = ACTIONS(9450),
    [sym_systempart_keyword] = ACTIONS(9450),
    [sym_usercontrol_keyword] = ACTIONS(9450),
    [sym_dataset_keyword] = ACTIONS(9450),
    [sym_elements_keyword] = ACTIONS(9450),
    [sym_dataitem_keyword] = ACTIONS(9450),
    [sym_column_keyword] = ACTIONS(9450),
    [sym_filter_keyword] = ACTIONS(9450),
    [sym_labels_keyword] = ACTIONS(9450),
    [sym_rendering_keyword] = ACTIONS(9450),
    [sym_requestpage_keyword] = ACTIONS(9450),
    [sym_schema_keyword] = ACTIONS(9450),
    [sym_views_keyword] = ACTIONS(9450),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9450),
    [sym_preproc_open] = ACTIONS(9450),
    [sym_preproc_close] = ACTIONS(9450),
  },
  [STATE(4169)] = {
    [anon_sym_SEMI] = ACTIONS(9454),
    [aux_sym_where_condition_token1] = ACTIONS(9456),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9454),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9454),
    [anon_sym_LBRACK] = ACTIONS(9454),
    [aux_sym_basic_type_token6] = ACTIONS(9456),
    [aux_sym_basic_type_token22] = ACTIONS(9456),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9454),
    [aux_sym_addafter_modification_token1] = ACTIONS(9454),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9454),
    [aux_sym_modify_modification_token1] = ACTIONS(9454),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9454),
    [aux_sym_movelast_modification_token1] = ACTIONS(9454),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9454),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9454),
    [aux_sym_separator_action_token1] = ACTIONS(9454),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9454),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9454),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9454),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9454),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9454),
    [anon_sym_POUNDif] = ACTIONS(9454),
    [anon_sym_POUNDIF] = ACTIONS(9454),
    [anon_sym_POUNDIf] = ACTIONS(9454),
    [anon_sym_POUNDelif] = ACTIONS(9454),
    [anon_sym_POUNDELIF] = ACTIONS(9454),
    [anon_sym_POUNDElif] = ACTIONS(9454),
    [anon_sym_POUNDelse] = ACTIONS(9454),
    [anon_sym_POUNDELSE] = ACTIONS(9454),
    [anon_sym_POUNDElse] = ACTIONS(9454),
    [anon_sym_POUNDelse2] = ACTIONS(9454),
    [anon_sym_POUNDELSE2] = ACTIONS(9454),
    [anon_sym_POUNDElse2] = ACTIONS(9454),
    [anon_sym_POUNDendif] = ACTIONS(9454),
    [anon_sym_POUNDENDIF] = ACTIONS(9454),
    [anon_sym_POUNDEndif] = ACTIONS(9454),
    [anon_sym_POUNDendif2] = ACTIONS(9454),
    [anon_sym_POUNDENDIF2] = ACTIONS(9454),
    [anon_sym_POUNDEndif2] = ACTIONS(9454),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9454),
    [sym_trigger_keyword] = ACTIONS(9454),
    [sym_var_keyword] = ACTIONS(9454),
    [sym_local_keyword] = ACTIONS(9454),
    [sym_internal_keyword] = ACTIONS(9454),
    [sym_protected_keyword] = ACTIONS(9454),
    [sym_event_keyword] = ACTIONS(9454),
    [sym_fields_keyword] = ACTIONS(9454),
    [sym_keys_keyword] = ACTIONS(9454),
    [sym_fieldgroups_keyword] = ACTIONS(9454),
    [sym_actions_keyword] = ACTIONS(9454),
    [sym_layout_keyword] = ACTIONS(9454),
    [sym_area_keyword] = ACTIONS(9454),
    [sym_group_keyword] = ACTIONS(9454),
    [sym_repeater_keyword] = ACTIONS(9454),
    [sym_cuegroup_keyword] = ACTIONS(9454),
    [sym_fixed_keyword] = ACTIONS(9454),
    [sym_grid_keyword] = ACTIONS(9454),
    [sym_part_keyword] = ACTIONS(9454),
    [sym_systempart_keyword] = ACTIONS(9454),
    [sym_usercontrol_keyword] = ACTIONS(9454),
    [sym_dataset_keyword] = ACTIONS(9454),
    [sym_elements_keyword] = ACTIONS(9454),
    [sym_dataitem_keyword] = ACTIONS(9454),
    [sym_column_keyword] = ACTIONS(9454),
    [sym_filter_keyword] = ACTIONS(9454),
    [sym_labels_keyword] = ACTIONS(9454),
    [sym_rendering_keyword] = ACTIONS(9454),
    [sym_requestpage_keyword] = ACTIONS(9454),
    [sym_schema_keyword] = ACTIONS(9454),
    [sym_views_keyword] = ACTIONS(9454),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9454),
    [sym_preproc_open] = ACTIONS(9454),
    [sym_preproc_close] = ACTIONS(9454),
  },
  [STATE(4170)] = {
    [anon_sym_SEMI] = ACTIONS(9458),
    [aux_sym_where_condition_token1] = ACTIONS(9460),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9458),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9458),
    [anon_sym_LBRACK] = ACTIONS(9458),
    [aux_sym_basic_type_token6] = ACTIONS(9460),
    [aux_sym_basic_type_token22] = ACTIONS(9460),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9458),
    [aux_sym_addafter_modification_token1] = ACTIONS(9458),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9458),
    [aux_sym_modify_modification_token1] = ACTIONS(9458),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9458),
    [aux_sym_movelast_modification_token1] = ACTIONS(9458),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9458),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9458),
    [aux_sym_separator_action_token1] = ACTIONS(9458),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9458),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9458),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9458),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9458),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9458),
    [anon_sym_POUNDif] = ACTIONS(9458),
    [anon_sym_POUNDIF] = ACTIONS(9458),
    [anon_sym_POUNDIf] = ACTIONS(9458),
    [anon_sym_POUNDelif] = ACTIONS(9458),
    [anon_sym_POUNDELIF] = ACTIONS(9458),
    [anon_sym_POUNDElif] = ACTIONS(9458),
    [anon_sym_POUNDelse] = ACTIONS(9458),
    [anon_sym_POUNDELSE] = ACTIONS(9458),
    [anon_sym_POUNDElse] = ACTIONS(9458),
    [anon_sym_POUNDelse2] = ACTIONS(9458),
    [anon_sym_POUNDELSE2] = ACTIONS(9458),
    [anon_sym_POUNDElse2] = ACTIONS(9458),
    [anon_sym_POUNDendif] = ACTIONS(9458),
    [anon_sym_POUNDENDIF] = ACTIONS(9458),
    [anon_sym_POUNDEndif] = ACTIONS(9458),
    [anon_sym_POUNDendif2] = ACTIONS(9458),
    [anon_sym_POUNDENDIF2] = ACTIONS(9458),
    [anon_sym_POUNDEndif2] = ACTIONS(9458),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9458),
    [sym_trigger_keyword] = ACTIONS(9458),
    [sym_var_keyword] = ACTIONS(9458),
    [sym_local_keyword] = ACTIONS(9458),
    [sym_internal_keyword] = ACTIONS(9458),
    [sym_protected_keyword] = ACTIONS(9458),
    [sym_event_keyword] = ACTIONS(9458),
    [sym_fields_keyword] = ACTIONS(9458),
    [sym_keys_keyword] = ACTIONS(9458),
    [sym_fieldgroups_keyword] = ACTIONS(9458),
    [sym_actions_keyword] = ACTIONS(9458),
    [sym_layout_keyword] = ACTIONS(9458),
    [sym_area_keyword] = ACTIONS(9458),
    [sym_group_keyword] = ACTIONS(9458),
    [sym_repeater_keyword] = ACTIONS(9458),
    [sym_cuegroup_keyword] = ACTIONS(9458),
    [sym_fixed_keyword] = ACTIONS(9458),
    [sym_grid_keyword] = ACTIONS(9458),
    [sym_part_keyword] = ACTIONS(9458),
    [sym_systempart_keyword] = ACTIONS(9458),
    [sym_usercontrol_keyword] = ACTIONS(9458),
    [sym_dataset_keyword] = ACTIONS(9458),
    [sym_elements_keyword] = ACTIONS(9458),
    [sym_dataitem_keyword] = ACTIONS(9458),
    [sym_column_keyword] = ACTIONS(9458),
    [sym_filter_keyword] = ACTIONS(9458),
    [sym_labels_keyword] = ACTIONS(9458),
    [sym_rendering_keyword] = ACTIONS(9458),
    [sym_requestpage_keyword] = ACTIONS(9458),
    [sym_schema_keyword] = ACTIONS(9458),
    [sym_views_keyword] = ACTIONS(9458),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9458),
    [sym_preproc_open] = ACTIONS(9458),
    [sym_preproc_close] = ACTIONS(9458),
  },
  [STATE(4171)] = {
    [anon_sym_SEMI] = ACTIONS(9462),
    [aux_sym_where_condition_token1] = ACTIONS(9464),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9462),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9462),
    [anon_sym_LBRACK] = ACTIONS(9462),
    [aux_sym_basic_type_token6] = ACTIONS(9464),
    [aux_sym_basic_type_token22] = ACTIONS(9464),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9462),
    [aux_sym_addafter_modification_token1] = ACTIONS(9462),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9462),
    [aux_sym_modify_modification_token1] = ACTIONS(9462),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9462),
    [aux_sym_movelast_modification_token1] = ACTIONS(9462),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9462),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9462),
    [aux_sym_separator_action_token1] = ACTIONS(9462),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9462),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9462),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9462),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9462),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9462),
    [anon_sym_POUNDif] = ACTIONS(9462),
    [anon_sym_POUNDIF] = ACTIONS(9462),
    [anon_sym_POUNDIf] = ACTIONS(9462),
    [anon_sym_POUNDelif] = ACTIONS(9462),
    [anon_sym_POUNDELIF] = ACTIONS(9462),
    [anon_sym_POUNDElif] = ACTIONS(9462),
    [anon_sym_POUNDelse] = ACTIONS(9462),
    [anon_sym_POUNDELSE] = ACTIONS(9462),
    [anon_sym_POUNDElse] = ACTIONS(9462),
    [anon_sym_POUNDelse2] = ACTIONS(9462),
    [anon_sym_POUNDELSE2] = ACTIONS(9462),
    [anon_sym_POUNDElse2] = ACTIONS(9462),
    [anon_sym_POUNDendif] = ACTIONS(9462),
    [anon_sym_POUNDENDIF] = ACTIONS(9462),
    [anon_sym_POUNDEndif] = ACTIONS(9462),
    [anon_sym_POUNDendif2] = ACTIONS(9462),
    [anon_sym_POUNDENDIF2] = ACTIONS(9462),
    [anon_sym_POUNDEndif2] = ACTIONS(9462),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9462),
    [sym_trigger_keyword] = ACTIONS(9462),
    [sym_var_keyword] = ACTIONS(9462),
    [sym_local_keyword] = ACTIONS(9462),
    [sym_internal_keyword] = ACTIONS(9462),
    [sym_protected_keyword] = ACTIONS(9462),
    [sym_event_keyword] = ACTIONS(9462),
    [sym_fields_keyword] = ACTIONS(9462),
    [sym_keys_keyword] = ACTIONS(9462),
    [sym_fieldgroups_keyword] = ACTIONS(9462),
    [sym_actions_keyword] = ACTIONS(9462),
    [sym_layout_keyword] = ACTIONS(9462),
    [sym_area_keyword] = ACTIONS(9462),
    [sym_group_keyword] = ACTIONS(9462),
    [sym_repeater_keyword] = ACTIONS(9462),
    [sym_cuegroup_keyword] = ACTIONS(9462),
    [sym_fixed_keyword] = ACTIONS(9462),
    [sym_grid_keyword] = ACTIONS(9462),
    [sym_part_keyword] = ACTIONS(9462),
    [sym_systempart_keyword] = ACTIONS(9462),
    [sym_usercontrol_keyword] = ACTIONS(9462),
    [sym_dataset_keyword] = ACTIONS(9462),
    [sym_elements_keyword] = ACTIONS(9462),
    [sym_dataitem_keyword] = ACTIONS(9462),
    [sym_column_keyword] = ACTIONS(9462),
    [sym_filter_keyword] = ACTIONS(9462),
    [sym_labels_keyword] = ACTIONS(9462),
    [sym_rendering_keyword] = ACTIONS(9462),
    [sym_requestpage_keyword] = ACTIONS(9462),
    [sym_schema_keyword] = ACTIONS(9462),
    [sym_views_keyword] = ACTIONS(9462),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9462),
    [sym_preproc_open] = ACTIONS(9462),
    [sym_preproc_close] = ACTIONS(9462),
  },
  [STATE(4172)] = {
    [anon_sym_SEMI] = ACTIONS(9466),
    [aux_sym_where_condition_token1] = ACTIONS(9468),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9466),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9466),
    [anon_sym_LBRACK] = ACTIONS(9466),
    [aux_sym_basic_type_token6] = ACTIONS(9468),
    [aux_sym_basic_type_token22] = ACTIONS(9468),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9466),
    [aux_sym_addafter_modification_token1] = ACTIONS(9466),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9466),
    [aux_sym_modify_modification_token1] = ACTIONS(9466),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9466),
    [aux_sym_movelast_modification_token1] = ACTIONS(9466),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9466),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9466),
    [aux_sym_separator_action_token1] = ACTIONS(9466),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9466),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9466),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9466),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9466),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9466),
    [anon_sym_POUNDif] = ACTIONS(9466),
    [anon_sym_POUNDIF] = ACTIONS(9466),
    [anon_sym_POUNDIf] = ACTIONS(9466),
    [anon_sym_POUNDelif] = ACTIONS(9466),
    [anon_sym_POUNDELIF] = ACTIONS(9466),
    [anon_sym_POUNDElif] = ACTIONS(9466),
    [anon_sym_POUNDelse] = ACTIONS(9466),
    [anon_sym_POUNDELSE] = ACTIONS(9466),
    [anon_sym_POUNDElse] = ACTIONS(9466),
    [anon_sym_POUNDelse2] = ACTIONS(9466),
    [anon_sym_POUNDELSE2] = ACTIONS(9466),
    [anon_sym_POUNDElse2] = ACTIONS(9466),
    [anon_sym_POUNDendif] = ACTIONS(9466),
    [anon_sym_POUNDENDIF] = ACTIONS(9466),
    [anon_sym_POUNDEndif] = ACTIONS(9466),
    [anon_sym_POUNDendif2] = ACTIONS(9466),
    [anon_sym_POUNDENDIF2] = ACTIONS(9466),
    [anon_sym_POUNDEndif2] = ACTIONS(9466),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9466),
    [sym_trigger_keyword] = ACTIONS(9466),
    [sym_var_keyword] = ACTIONS(9466),
    [sym_local_keyword] = ACTIONS(9466),
    [sym_internal_keyword] = ACTIONS(9466),
    [sym_protected_keyword] = ACTIONS(9466),
    [sym_event_keyword] = ACTIONS(9466),
    [sym_fields_keyword] = ACTIONS(9466),
    [sym_keys_keyword] = ACTIONS(9466),
    [sym_fieldgroups_keyword] = ACTIONS(9466),
    [sym_actions_keyword] = ACTIONS(9466),
    [sym_layout_keyword] = ACTIONS(9466),
    [sym_area_keyword] = ACTIONS(9466),
    [sym_group_keyword] = ACTIONS(9466),
    [sym_repeater_keyword] = ACTIONS(9466),
    [sym_cuegroup_keyword] = ACTIONS(9466),
    [sym_fixed_keyword] = ACTIONS(9466),
    [sym_grid_keyword] = ACTIONS(9466),
    [sym_part_keyword] = ACTIONS(9466),
    [sym_systempart_keyword] = ACTIONS(9466),
    [sym_usercontrol_keyword] = ACTIONS(9466),
    [sym_dataset_keyword] = ACTIONS(9466),
    [sym_elements_keyword] = ACTIONS(9466),
    [sym_dataitem_keyword] = ACTIONS(9466),
    [sym_column_keyword] = ACTIONS(9466),
    [sym_filter_keyword] = ACTIONS(9466),
    [sym_labels_keyword] = ACTIONS(9466),
    [sym_rendering_keyword] = ACTIONS(9466),
    [sym_requestpage_keyword] = ACTIONS(9466),
    [sym_schema_keyword] = ACTIONS(9466),
    [sym_views_keyword] = ACTIONS(9466),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9466),
    [sym_preproc_open] = ACTIONS(9466),
    [sym_preproc_close] = ACTIONS(9466),
  },
  [STATE(4173)] = {
    [anon_sym_SEMI] = ACTIONS(9470),
    [aux_sym_where_condition_token1] = ACTIONS(9472),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9470),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9470),
    [anon_sym_LBRACK] = ACTIONS(9470),
    [aux_sym_basic_type_token6] = ACTIONS(9472),
    [aux_sym_basic_type_token22] = ACTIONS(9472),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9470),
    [aux_sym_addafter_modification_token1] = ACTIONS(9470),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9470),
    [aux_sym_modify_modification_token1] = ACTIONS(9470),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9470),
    [aux_sym_movelast_modification_token1] = ACTIONS(9470),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9470),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9470),
    [aux_sym_separator_action_token1] = ACTIONS(9470),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9470),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9470),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9470),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9470),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9470),
    [anon_sym_POUNDif] = ACTIONS(9470),
    [anon_sym_POUNDIF] = ACTIONS(9470),
    [anon_sym_POUNDIf] = ACTIONS(9470),
    [anon_sym_POUNDelif] = ACTIONS(9470),
    [anon_sym_POUNDELIF] = ACTIONS(9470),
    [anon_sym_POUNDElif] = ACTIONS(9470),
    [anon_sym_POUNDelse] = ACTIONS(9470),
    [anon_sym_POUNDELSE] = ACTIONS(9470),
    [anon_sym_POUNDElse] = ACTIONS(9470),
    [anon_sym_POUNDelse2] = ACTIONS(9470),
    [anon_sym_POUNDELSE2] = ACTIONS(9470),
    [anon_sym_POUNDElse2] = ACTIONS(9470),
    [anon_sym_POUNDendif] = ACTIONS(9470),
    [anon_sym_POUNDENDIF] = ACTIONS(9470),
    [anon_sym_POUNDEndif] = ACTIONS(9470),
    [anon_sym_POUNDendif2] = ACTIONS(9470),
    [anon_sym_POUNDENDIF2] = ACTIONS(9470),
    [anon_sym_POUNDEndif2] = ACTIONS(9470),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9470),
    [sym_trigger_keyword] = ACTIONS(9470),
    [sym_var_keyword] = ACTIONS(9470),
    [sym_local_keyword] = ACTIONS(9470),
    [sym_internal_keyword] = ACTIONS(9470),
    [sym_protected_keyword] = ACTIONS(9470),
    [sym_event_keyword] = ACTIONS(9470),
    [sym_fields_keyword] = ACTIONS(9470),
    [sym_keys_keyword] = ACTIONS(9470),
    [sym_fieldgroups_keyword] = ACTIONS(9470),
    [sym_actions_keyword] = ACTIONS(9470),
    [sym_layout_keyword] = ACTIONS(9470),
    [sym_area_keyword] = ACTIONS(9470),
    [sym_group_keyword] = ACTIONS(9470),
    [sym_repeater_keyword] = ACTIONS(9470),
    [sym_cuegroup_keyword] = ACTIONS(9470),
    [sym_fixed_keyword] = ACTIONS(9470),
    [sym_grid_keyword] = ACTIONS(9470),
    [sym_part_keyword] = ACTIONS(9470),
    [sym_systempart_keyword] = ACTIONS(9470),
    [sym_usercontrol_keyword] = ACTIONS(9470),
    [sym_dataset_keyword] = ACTIONS(9470),
    [sym_elements_keyword] = ACTIONS(9470),
    [sym_dataitem_keyword] = ACTIONS(9470),
    [sym_column_keyword] = ACTIONS(9470),
    [sym_filter_keyword] = ACTIONS(9470),
    [sym_labels_keyword] = ACTIONS(9470),
    [sym_rendering_keyword] = ACTIONS(9470),
    [sym_requestpage_keyword] = ACTIONS(9470),
    [sym_schema_keyword] = ACTIONS(9470),
    [sym_views_keyword] = ACTIONS(9470),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9470),
    [sym_preproc_open] = ACTIONS(9470),
    [sym_preproc_close] = ACTIONS(9470),
  },
  [STATE(4174)] = {
    [anon_sym_SEMI] = ACTIONS(9474),
    [aux_sym_where_condition_token1] = ACTIONS(9476),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9474),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9474),
    [anon_sym_LBRACK] = ACTIONS(9474),
    [aux_sym_basic_type_token6] = ACTIONS(9476),
    [aux_sym_basic_type_token22] = ACTIONS(9476),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9474),
    [aux_sym_addafter_modification_token1] = ACTIONS(9474),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9474),
    [aux_sym_modify_modification_token1] = ACTIONS(9474),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9474),
    [aux_sym_movelast_modification_token1] = ACTIONS(9474),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9474),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9474),
    [aux_sym_separator_action_token1] = ACTIONS(9474),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9474),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9474),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9474),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9474),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9474),
    [anon_sym_POUNDif] = ACTIONS(9474),
    [anon_sym_POUNDIF] = ACTIONS(9474),
    [anon_sym_POUNDIf] = ACTIONS(9474),
    [anon_sym_POUNDelif] = ACTIONS(9474),
    [anon_sym_POUNDELIF] = ACTIONS(9474),
    [anon_sym_POUNDElif] = ACTIONS(9474),
    [anon_sym_POUNDelse] = ACTIONS(9474),
    [anon_sym_POUNDELSE] = ACTIONS(9474),
    [anon_sym_POUNDElse] = ACTIONS(9474),
    [anon_sym_POUNDelse2] = ACTIONS(9474),
    [anon_sym_POUNDELSE2] = ACTIONS(9474),
    [anon_sym_POUNDElse2] = ACTIONS(9474),
    [anon_sym_POUNDendif] = ACTIONS(9474),
    [anon_sym_POUNDENDIF] = ACTIONS(9474),
    [anon_sym_POUNDEndif] = ACTIONS(9474),
    [anon_sym_POUNDendif2] = ACTIONS(9474),
    [anon_sym_POUNDENDIF2] = ACTIONS(9474),
    [anon_sym_POUNDEndif2] = ACTIONS(9474),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9474),
    [sym_trigger_keyword] = ACTIONS(9474),
    [sym_var_keyword] = ACTIONS(9474),
    [sym_local_keyword] = ACTIONS(9474),
    [sym_internal_keyword] = ACTIONS(9474),
    [sym_protected_keyword] = ACTIONS(9474),
    [sym_event_keyword] = ACTIONS(9474),
    [sym_fields_keyword] = ACTIONS(9474),
    [sym_keys_keyword] = ACTIONS(9474),
    [sym_fieldgroups_keyword] = ACTIONS(9474),
    [sym_actions_keyword] = ACTIONS(9474),
    [sym_layout_keyword] = ACTIONS(9474),
    [sym_area_keyword] = ACTIONS(9474),
    [sym_group_keyword] = ACTIONS(9474),
    [sym_repeater_keyword] = ACTIONS(9474),
    [sym_cuegroup_keyword] = ACTIONS(9474),
    [sym_fixed_keyword] = ACTIONS(9474),
    [sym_grid_keyword] = ACTIONS(9474),
    [sym_part_keyword] = ACTIONS(9474),
    [sym_systempart_keyword] = ACTIONS(9474),
    [sym_usercontrol_keyword] = ACTIONS(9474),
    [sym_dataset_keyword] = ACTIONS(9474),
    [sym_elements_keyword] = ACTIONS(9474),
    [sym_dataitem_keyword] = ACTIONS(9474),
    [sym_column_keyword] = ACTIONS(9474),
    [sym_filter_keyword] = ACTIONS(9474),
    [sym_labels_keyword] = ACTIONS(9474),
    [sym_rendering_keyword] = ACTIONS(9474),
    [sym_requestpage_keyword] = ACTIONS(9474),
    [sym_schema_keyword] = ACTIONS(9474),
    [sym_views_keyword] = ACTIONS(9474),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9474),
    [sym_preproc_open] = ACTIONS(9474),
    [sym_preproc_close] = ACTIONS(9474),
  },
  [STATE(4175)] = {
    [anon_sym_SEMI] = ACTIONS(9470),
    [aux_sym_where_condition_token1] = ACTIONS(9472),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9470),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9470),
    [anon_sym_LBRACK] = ACTIONS(9470),
    [aux_sym_basic_type_token6] = ACTIONS(9472),
    [aux_sym_basic_type_token22] = ACTIONS(9472),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9470),
    [aux_sym_addafter_modification_token1] = ACTIONS(9470),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9470),
    [aux_sym_modify_modification_token1] = ACTIONS(9470),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9470),
    [aux_sym_movelast_modification_token1] = ACTIONS(9470),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9470),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9470),
    [aux_sym_separator_action_token1] = ACTIONS(9470),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9470),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9470),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9470),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9470),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9470),
    [anon_sym_POUNDif] = ACTIONS(9470),
    [anon_sym_POUNDIF] = ACTIONS(9470),
    [anon_sym_POUNDIf] = ACTIONS(9470),
    [anon_sym_POUNDelif] = ACTIONS(9470),
    [anon_sym_POUNDELIF] = ACTIONS(9470),
    [anon_sym_POUNDElif] = ACTIONS(9470),
    [anon_sym_POUNDelse] = ACTIONS(9470),
    [anon_sym_POUNDELSE] = ACTIONS(9470),
    [anon_sym_POUNDElse] = ACTIONS(9470),
    [anon_sym_POUNDelse2] = ACTIONS(9470),
    [anon_sym_POUNDELSE2] = ACTIONS(9470),
    [anon_sym_POUNDElse2] = ACTIONS(9470),
    [anon_sym_POUNDendif] = ACTIONS(9470),
    [anon_sym_POUNDENDIF] = ACTIONS(9470),
    [anon_sym_POUNDEndif] = ACTIONS(9470),
    [anon_sym_POUNDendif2] = ACTIONS(9470),
    [anon_sym_POUNDENDIF2] = ACTIONS(9470),
    [anon_sym_POUNDEndif2] = ACTIONS(9470),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9470),
    [sym_trigger_keyword] = ACTIONS(9470),
    [sym_var_keyword] = ACTIONS(9470),
    [sym_local_keyword] = ACTIONS(9470),
    [sym_internal_keyword] = ACTIONS(9470),
    [sym_protected_keyword] = ACTIONS(9470),
    [sym_event_keyword] = ACTIONS(9470),
    [sym_fields_keyword] = ACTIONS(9470),
    [sym_keys_keyword] = ACTIONS(9470),
    [sym_fieldgroups_keyword] = ACTIONS(9470),
    [sym_actions_keyword] = ACTIONS(9470),
    [sym_layout_keyword] = ACTIONS(9470),
    [sym_area_keyword] = ACTIONS(9470),
    [sym_group_keyword] = ACTIONS(9470),
    [sym_repeater_keyword] = ACTIONS(9470),
    [sym_cuegroup_keyword] = ACTIONS(9470),
    [sym_fixed_keyword] = ACTIONS(9470),
    [sym_grid_keyword] = ACTIONS(9470),
    [sym_part_keyword] = ACTIONS(9470),
    [sym_systempart_keyword] = ACTIONS(9470),
    [sym_usercontrol_keyword] = ACTIONS(9470),
    [sym_dataset_keyword] = ACTIONS(9470),
    [sym_elements_keyword] = ACTIONS(9470),
    [sym_dataitem_keyword] = ACTIONS(9470),
    [sym_column_keyword] = ACTIONS(9470),
    [sym_filter_keyword] = ACTIONS(9470),
    [sym_labels_keyword] = ACTIONS(9470),
    [sym_rendering_keyword] = ACTIONS(9470),
    [sym_requestpage_keyword] = ACTIONS(9470),
    [sym_schema_keyword] = ACTIONS(9470),
    [sym_views_keyword] = ACTIONS(9470),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9470),
    [sym_preproc_open] = ACTIONS(9470),
    [sym_preproc_close] = ACTIONS(9470),
  },
  [STATE(4176)] = {
    [anon_sym_SEMI] = ACTIONS(9414),
    [aux_sym_where_condition_token1] = ACTIONS(9416),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9414),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9414),
    [anon_sym_LBRACK] = ACTIONS(9414),
    [aux_sym_basic_type_token6] = ACTIONS(9416),
    [aux_sym_basic_type_token22] = ACTIONS(9416),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9414),
    [aux_sym_addafter_modification_token1] = ACTIONS(9414),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9414),
    [aux_sym_modify_modification_token1] = ACTIONS(9414),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9414),
    [aux_sym_movelast_modification_token1] = ACTIONS(9414),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9414),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9414),
    [aux_sym_separator_action_token1] = ACTIONS(9414),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9414),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9414),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9414),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9414),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9414),
    [anon_sym_POUNDif] = ACTIONS(9414),
    [anon_sym_POUNDIF] = ACTIONS(9414),
    [anon_sym_POUNDIf] = ACTIONS(9414),
    [anon_sym_POUNDelif] = ACTIONS(9414),
    [anon_sym_POUNDELIF] = ACTIONS(9414),
    [anon_sym_POUNDElif] = ACTIONS(9414),
    [anon_sym_POUNDelse] = ACTIONS(9414),
    [anon_sym_POUNDELSE] = ACTIONS(9414),
    [anon_sym_POUNDElse] = ACTIONS(9414),
    [anon_sym_POUNDelse2] = ACTIONS(9414),
    [anon_sym_POUNDELSE2] = ACTIONS(9414),
    [anon_sym_POUNDElse2] = ACTIONS(9414),
    [anon_sym_POUNDendif] = ACTIONS(9414),
    [anon_sym_POUNDENDIF] = ACTIONS(9414),
    [anon_sym_POUNDEndif] = ACTIONS(9414),
    [anon_sym_POUNDendif2] = ACTIONS(9414),
    [anon_sym_POUNDENDIF2] = ACTIONS(9414),
    [anon_sym_POUNDEndif2] = ACTIONS(9414),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9414),
    [sym_trigger_keyword] = ACTIONS(9414),
    [sym_var_keyword] = ACTIONS(9414),
    [sym_local_keyword] = ACTIONS(9414),
    [sym_internal_keyword] = ACTIONS(9414),
    [sym_protected_keyword] = ACTIONS(9414),
    [sym_event_keyword] = ACTIONS(9414),
    [sym_fields_keyword] = ACTIONS(9414),
    [sym_keys_keyword] = ACTIONS(9414),
    [sym_fieldgroups_keyword] = ACTIONS(9414),
    [sym_actions_keyword] = ACTIONS(9414),
    [sym_layout_keyword] = ACTIONS(9414),
    [sym_area_keyword] = ACTIONS(9414),
    [sym_group_keyword] = ACTIONS(9414),
    [sym_repeater_keyword] = ACTIONS(9414),
    [sym_cuegroup_keyword] = ACTIONS(9414),
    [sym_fixed_keyword] = ACTIONS(9414),
    [sym_grid_keyword] = ACTIONS(9414),
    [sym_part_keyword] = ACTIONS(9414),
    [sym_systempart_keyword] = ACTIONS(9414),
    [sym_usercontrol_keyword] = ACTIONS(9414),
    [sym_dataset_keyword] = ACTIONS(9414),
    [sym_elements_keyword] = ACTIONS(9414),
    [sym_dataitem_keyword] = ACTIONS(9414),
    [sym_column_keyword] = ACTIONS(9414),
    [sym_filter_keyword] = ACTIONS(9414),
    [sym_labels_keyword] = ACTIONS(9414),
    [sym_rendering_keyword] = ACTIONS(9414),
    [sym_requestpage_keyword] = ACTIONS(9414),
    [sym_schema_keyword] = ACTIONS(9414),
    [sym_views_keyword] = ACTIONS(9414),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9414),
    [sym_preproc_open] = ACTIONS(9414),
    [sym_preproc_close] = ACTIONS(9414),
  },
  [STATE(4177)] = {
    [anon_sym_SEMI] = ACTIONS(9418),
    [aux_sym_where_condition_token1] = ACTIONS(9420),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9418),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9418),
    [anon_sym_LBRACK] = ACTIONS(9418),
    [aux_sym_basic_type_token6] = ACTIONS(9420),
    [aux_sym_basic_type_token22] = ACTIONS(9420),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9418),
    [aux_sym_addafter_modification_token1] = ACTIONS(9418),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9418),
    [aux_sym_modify_modification_token1] = ACTIONS(9418),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9418),
    [aux_sym_movelast_modification_token1] = ACTIONS(9418),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9418),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9418),
    [aux_sym_separator_action_token1] = ACTIONS(9418),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9418),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9418),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9418),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9418),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9418),
    [anon_sym_POUNDif] = ACTIONS(9418),
    [anon_sym_POUNDIF] = ACTIONS(9418),
    [anon_sym_POUNDIf] = ACTIONS(9418),
    [anon_sym_POUNDelif] = ACTIONS(9418),
    [anon_sym_POUNDELIF] = ACTIONS(9418),
    [anon_sym_POUNDElif] = ACTIONS(9418),
    [anon_sym_POUNDelse] = ACTIONS(9418),
    [anon_sym_POUNDELSE] = ACTIONS(9418),
    [anon_sym_POUNDElse] = ACTIONS(9418),
    [anon_sym_POUNDelse2] = ACTIONS(9418),
    [anon_sym_POUNDELSE2] = ACTIONS(9418),
    [anon_sym_POUNDElse2] = ACTIONS(9418),
    [anon_sym_POUNDendif] = ACTIONS(9418),
    [anon_sym_POUNDENDIF] = ACTIONS(9418),
    [anon_sym_POUNDEndif] = ACTIONS(9418),
    [anon_sym_POUNDendif2] = ACTIONS(9418),
    [anon_sym_POUNDENDIF2] = ACTIONS(9418),
    [anon_sym_POUNDEndif2] = ACTIONS(9418),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9418),
    [sym_trigger_keyword] = ACTIONS(9418),
    [sym_var_keyword] = ACTIONS(9418),
    [sym_local_keyword] = ACTIONS(9418),
    [sym_internal_keyword] = ACTIONS(9418),
    [sym_protected_keyword] = ACTIONS(9418),
    [sym_event_keyword] = ACTIONS(9418),
    [sym_fields_keyword] = ACTIONS(9418),
    [sym_keys_keyword] = ACTIONS(9418),
    [sym_fieldgroups_keyword] = ACTIONS(9418),
    [sym_actions_keyword] = ACTIONS(9418),
    [sym_layout_keyword] = ACTIONS(9418),
    [sym_area_keyword] = ACTIONS(9418),
    [sym_group_keyword] = ACTIONS(9418),
    [sym_repeater_keyword] = ACTIONS(9418),
    [sym_cuegroup_keyword] = ACTIONS(9418),
    [sym_fixed_keyword] = ACTIONS(9418),
    [sym_grid_keyword] = ACTIONS(9418),
    [sym_part_keyword] = ACTIONS(9418),
    [sym_systempart_keyword] = ACTIONS(9418),
    [sym_usercontrol_keyword] = ACTIONS(9418),
    [sym_dataset_keyword] = ACTIONS(9418),
    [sym_elements_keyword] = ACTIONS(9418),
    [sym_dataitem_keyword] = ACTIONS(9418),
    [sym_column_keyword] = ACTIONS(9418),
    [sym_filter_keyword] = ACTIONS(9418),
    [sym_labels_keyword] = ACTIONS(9418),
    [sym_rendering_keyword] = ACTIONS(9418),
    [sym_requestpage_keyword] = ACTIONS(9418),
    [sym_schema_keyword] = ACTIONS(9418),
    [sym_views_keyword] = ACTIONS(9418),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9418),
    [sym_preproc_open] = ACTIONS(9418),
    [sym_preproc_close] = ACTIONS(9418),
  },
  [STATE(4178)] = {
    [anon_sym_SEMI] = ACTIONS(9422),
    [aux_sym_where_condition_token1] = ACTIONS(9424),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9422),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9422),
    [anon_sym_LBRACK] = ACTIONS(9422),
    [aux_sym_basic_type_token6] = ACTIONS(9424),
    [aux_sym_basic_type_token22] = ACTIONS(9424),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9422),
    [aux_sym_addafter_modification_token1] = ACTIONS(9422),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9422),
    [aux_sym_modify_modification_token1] = ACTIONS(9422),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9422),
    [aux_sym_movelast_modification_token1] = ACTIONS(9422),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9422),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9422),
    [aux_sym_separator_action_token1] = ACTIONS(9422),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9422),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9422),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9422),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9422),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9422),
    [anon_sym_POUNDif] = ACTIONS(9422),
    [anon_sym_POUNDIF] = ACTIONS(9422),
    [anon_sym_POUNDIf] = ACTIONS(9422),
    [anon_sym_POUNDelif] = ACTIONS(9422),
    [anon_sym_POUNDELIF] = ACTIONS(9422),
    [anon_sym_POUNDElif] = ACTIONS(9422),
    [anon_sym_POUNDelse] = ACTIONS(9422),
    [anon_sym_POUNDELSE] = ACTIONS(9422),
    [anon_sym_POUNDElse] = ACTIONS(9422),
    [anon_sym_POUNDelse2] = ACTIONS(9422),
    [anon_sym_POUNDELSE2] = ACTIONS(9422),
    [anon_sym_POUNDElse2] = ACTIONS(9422),
    [anon_sym_POUNDendif] = ACTIONS(9422),
    [anon_sym_POUNDENDIF] = ACTIONS(9422),
    [anon_sym_POUNDEndif] = ACTIONS(9422),
    [anon_sym_POUNDendif2] = ACTIONS(9422),
    [anon_sym_POUNDENDIF2] = ACTIONS(9422),
    [anon_sym_POUNDEndif2] = ACTIONS(9422),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9422),
    [sym_trigger_keyword] = ACTIONS(9422),
    [sym_var_keyword] = ACTIONS(9422),
    [sym_local_keyword] = ACTIONS(9422),
    [sym_internal_keyword] = ACTIONS(9422),
    [sym_protected_keyword] = ACTIONS(9422),
    [sym_event_keyword] = ACTIONS(9422),
    [sym_fields_keyword] = ACTIONS(9422),
    [sym_keys_keyword] = ACTIONS(9422),
    [sym_fieldgroups_keyword] = ACTIONS(9422),
    [sym_actions_keyword] = ACTIONS(9422),
    [sym_layout_keyword] = ACTIONS(9422),
    [sym_area_keyword] = ACTIONS(9422),
    [sym_group_keyword] = ACTIONS(9422),
    [sym_repeater_keyword] = ACTIONS(9422),
    [sym_cuegroup_keyword] = ACTIONS(9422),
    [sym_fixed_keyword] = ACTIONS(9422),
    [sym_grid_keyword] = ACTIONS(9422),
    [sym_part_keyword] = ACTIONS(9422),
    [sym_systempart_keyword] = ACTIONS(9422),
    [sym_usercontrol_keyword] = ACTIONS(9422),
    [sym_dataset_keyword] = ACTIONS(9422),
    [sym_elements_keyword] = ACTIONS(9422),
    [sym_dataitem_keyword] = ACTIONS(9422),
    [sym_column_keyword] = ACTIONS(9422),
    [sym_filter_keyword] = ACTIONS(9422),
    [sym_labels_keyword] = ACTIONS(9422),
    [sym_rendering_keyword] = ACTIONS(9422),
    [sym_requestpage_keyword] = ACTIONS(9422),
    [sym_schema_keyword] = ACTIONS(9422),
    [sym_views_keyword] = ACTIONS(9422),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9422),
    [sym_preproc_open] = ACTIONS(9422),
    [sym_preproc_close] = ACTIONS(9422),
  },
  [STATE(4179)] = {
    [anon_sym_SEMI] = ACTIONS(9478),
    [aux_sym_where_condition_token1] = ACTIONS(9480),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9478),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9478),
    [anon_sym_LBRACK] = ACTIONS(9478),
    [aux_sym_basic_type_token6] = ACTIONS(9480),
    [aux_sym_basic_type_token22] = ACTIONS(9480),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9478),
    [aux_sym_addafter_modification_token1] = ACTIONS(9478),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9478),
    [aux_sym_modify_modification_token1] = ACTIONS(9478),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9478),
    [aux_sym_movelast_modification_token1] = ACTIONS(9478),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9478),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9478),
    [aux_sym_separator_action_token1] = ACTIONS(9478),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9478),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9478),
    [anon_sym_POUNDif] = ACTIONS(9478),
    [anon_sym_POUNDIF] = ACTIONS(9478),
    [anon_sym_POUNDIf] = ACTIONS(9478),
    [anon_sym_POUNDelif] = ACTIONS(9478),
    [anon_sym_POUNDELIF] = ACTIONS(9478),
    [anon_sym_POUNDElif] = ACTIONS(9478),
    [anon_sym_POUNDelse] = ACTIONS(9478),
    [anon_sym_POUNDELSE] = ACTIONS(9478),
    [anon_sym_POUNDElse] = ACTIONS(9478),
    [anon_sym_POUNDelse2] = ACTIONS(9478),
    [anon_sym_POUNDELSE2] = ACTIONS(9478),
    [anon_sym_POUNDElse2] = ACTIONS(9478),
    [anon_sym_POUNDendif] = ACTIONS(9478),
    [anon_sym_POUNDENDIF] = ACTIONS(9478),
    [anon_sym_POUNDEndif] = ACTIONS(9478),
    [anon_sym_POUNDendif2] = ACTIONS(9478),
    [anon_sym_POUNDENDIF2] = ACTIONS(9478),
    [anon_sym_POUNDEndif2] = ACTIONS(9478),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9478),
    [sym_trigger_keyword] = ACTIONS(9478),
    [sym_var_keyword] = ACTIONS(9478),
    [sym_local_keyword] = ACTIONS(9478),
    [sym_internal_keyword] = ACTIONS(9478),
    [sym_protected_keyword] = ACTIONS(9478),
    [sym_event_keyword] = ACTIONS(9478),
    [sym_fields_keyword] = ACTIONS(9478),
    [sym_keys_keyword] = ACTIONS(9478),
    [sym_fieldgroups_keyword] = ACTIONS(9478),
    [sym_actions_keyword] = ACTIONS(9478),
    [sym_layout_keyword] = ACTIONS(9478),
    [sym_area_keyword] = ACTIONS(9478),
    [sym_group_keyword] = ACTIONS(9478),
    [sym_repeater_keyword] = ACTIONS(9478),
    [sym_cuegroup_keyword] = ACTIONS(9478),
    [sym_fixed_keyword] = ACTIONS(9478),
    [sym_grid_keyword] = ACTIONS(9478),
    [sym_part_keyword] = ACTIONS(9478),
    [sym_systempart_keyword] = ACTIONS(9478),
    [sym_usercontrol_keyword] = ACTIONS(9478),
    [sym_dataset_keyword] = ACTIONS(9478),
    [sym_elements_keyword] = ACTIONS(9478),
    [sym_dataitem_keyword] = ACTIONS(9478),
    [sym_column_keyword] = ACTIONS(9478),
    [sym_filter_keyword] = ACTIONS(9478),
    [sym_labels_keyword] = ACTIONS(9478),
    [sym_rendering_keyword] = ACTIONS(9478),
    [sym_requestpage_keyword] = ACTIONS(9478),
    [sym_schema_keyword] = ACTIONS(9478),
    [sym_views_keyword] = ACTIONS(9478),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9478),
    [sym_preproc_open] = ACTIONS(9478),
    [sym_preproc_close] = ACTIONS(9478),
  },
  [STATE(4180)] = {
    [anon_sym_SEMI] = ACTIONS(9482),
    [aux_sym_where_condition_token1] = ACTIONS(9484),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9482),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9482),
    [anon_sym_LBRACK] = ACTIONS(9482),
    [aux_sym_basic_type_token6] = ACTIONS(9484),
    [aux_sym_basic_type_token22] = ACTIONS(9484),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9482),
    [aux_sym_addafter_modification_token1] = ACTIONS(9482),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9482),
    [aux_sym_modify_modification_token1] = ACTIONS(9482),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9482),
    [aux_sym_movelast_modification_token1] = ACTIONS(9482),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9482),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9482),
    [aux_sym_separator_action_token1] = ACTIONS(9482),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9482),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9482),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9482),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9482),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9482),
    [anon_sym_POUNDif] = ACTIONS(9482),
    [anon_sym_POUNDIF] = ACTIONS(9482),
    [anon_sym_POUNDIf] = ACTIONS(9482),
    [anon_sym_POUNDelif] = ACTIONS(9482),
    [anon_sym_POUNDELIF] = ACTIONS(9482),
    [anon_sym_POUNDElif] = ACTIONS(9482),
    [anon_sym_POUNDelse] = ACTIONS(9482),
    [anon_sym_POUNDELSE] = ACTIONS(9482),
    [anon_sym_POUNDElse] = ACTIONS(9482),
    [anon_sym_POUNDelse2] = ACTIONS(9482),
    [anon_sym_POUNDELSE2] = ACTIONS(9482),
    [anon_sym_POUNDElse2] = ACTIONS(9482),
    [anon_sym_POUNDendif] = ACTIONS(9482),
    [anon_sym_POUNDENDIF] = ACTIONS(9482),
    [anon_sym_POUNDEndif] = ACTIONS(9482),
    [anon_sym_POUNDendif2] = ACTIONS(9482),
    [anon_sym_POUNDENDIF2] = ACTIONS(9482),
    [anon_sym_POUNDEndif2] = ACTIONS(9482),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9482),
    [sym_trigger_keyword] = ACTIONS(9482),
    [sym_var_keyword] = ACTIONS(9482),
    [sym_local_keyword] = ACTIONS(9482),
    [sym_internal_keyword] = ACTIONS(9482),
    [sym_protected_keyword] = ACTIONS(9482),
    [sym_event_keyword] = ACTIONS(9482),
    [sym_fields_keyword] = ACTIONS(9482),
    [sym_keys_keyword] = ACTIONS(9482),
    [sym_fieldgroups_keyword] = ACTIONS(9482),
    [sym_actions_keyword] = ACTIONS(9482),
    [sym_layout_keyword] = ACTIONS(9482),
    [sym_area_keyword] = ACTIONS(9482),
    [sym_group_keyword] = ACTIONS(9482),
    [sym_repeater_keyword] = ACTIONS(9482),
    [sym_cuegroup_keyword] = ACTIONS(9482),
    [sym_fixed_keyword] = ACTIONS(9482),
    [sym_grid_keyword] = ACTIONS(9482),
    [sym_part_keyword] = ACTIONS(9482),
    [sym_systempart_keyword] = ACTIONS(9482),
    [sym_usercontrol_keyword] = ACTIONS(9482),
    [sym_dataset_keyword] = ACTIONS(9482),
    [sym_elements_keyword] = ACTIONS(9482),
    [sym_dataitem_keyword] = ACTIONS(9482),
    [sym_column_keyword] = ACTIONS(9482),
    [sym_filter_keyword] = ACTIONS(9482),
    [sym_labels_keyword] = ACTIONS(9482),
    [sym_rendering_keyword] = ACTIONS(9482),
    [sym_requestpage_keyword] = ACTIONS(9482),
    [sym_schema_keyword] = ACTIONS(9482),
    [sym_views_keyword] = ACTIONS(9482),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9482),
    [sym_preproc_open] = ACTIONS(9482),
    [sym_preproc_close] = ACTIONS(9482),
  },
  [STATE(4181)] = {
    [anon_sym_SEMI] = ACTIONS(9478),
    [aux_sym_where_condition_token1] = ACTIONS(9480),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9478),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9478),
    [anon_sym_LBRACK] = ACTIONS(9478),
    [aux_sym_basic_type_token6] = ACTIONS(9480),
    [aux_sym_basic_type_token22] = ACTIONS(9480),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9478),
    [aux_sym_addafter_modification_token1] = ACTIONS(9478),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9478),
    [aux_sym_modify_modification_token1] = ACTIONS(9478),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9478),
    [aux_sym_movelast_modification_token1] = ACTIONS(9478),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9478),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9478),
    [aux_sym_separator_action_token1] = ACTIONS(9478),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9478),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9478),
    [anon_sym_POUNDif] = ACTIONS(9478),
    [anon_sym_POUNDIF] = ACTIONS(9478),
    [anon_sym_POUNDIf] = ACTIONS(9478),
    [anon_sym_POUNDelif] = ACTIONS(9478),
    [anon_sym_POUNDELIF] = ACTIONS(9478),
    [anon_sym_POUNDElif] = ACTIONS(9478),
    [anon_sym_POUNDelse] = ACTIONS(9478),
    [anon_sym_POUNDELSE] = ACTIONS(9478),
    [anon_sym_POUNDElse] = ACTIONS(9478),
    [anon_sym_POUNDelse2] = ACTIONS(9478),
    [anon_sym_POUNDELSE2] = ACTIONS(9478),
    [anon_sym_POUNDElse2] = ACTIONS(9478),
    [anon_sym_POUNDendif] = ACTIONS(9478),
    [anon_sym_POUNDENDIF] = ACTIONS(9478),
    [anon_sym_POUNDEndif] = ACTIONS(9478),
    [anon_sym_POUNDendif2] = ACTIONS(9478),
    [anon_sym_POUNDENDIF2] = ACTIONS(9478),
    [anon_sym_POUNDEndif2] = ACTIONS(9478),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9478),
    [sym_trigger_keyword] = ACTIONS(9478),
    [sym_var_keyword] = ACTIONS(9478),
    [sym_local_keyword] = ACTIONS(9478),
    [sym_internal_keyword] = ACTIONS(9478),
    [sym_protected_keyword] = ACTIONS(9478),
    [sym_event_keyword] = ACTIONS(9478),
    [sym_fields_keyword] = ACTIONS(9478),
    [sym_keys_keyword] = ACTIONS(9478),
    [sym_fieldgroups_keyword] = ACTIONS(9478),
    [sym_actions_keyword] = ACTIONS(9478),
    [sym_layout_keyword] = ACTIONS(9478),
    [sym_area_keyword] = ACTIONS(9478),
    [sym_group_keyword] = ACTIONS(9478),
    [sym_repeater_keyword] = ACTIONS(9478),
    [sym_cuegroup_keyword] = ACTIONS(9478),
    [sym_fixed_keyword] = ACTIONS(9478),
    [sym_grid_keyword] = ACTIONS(9478),
    [sym_part_keyword] = ACTIONS(9478),
    [sym_systempart_keyword] = ACTIONS(9478),
    [sym_usercontrol_keyword] = ACTIONS(9478),
    [sym_dataset_keyword] = ACTIONS(9478),
    [sym_elements_keyword] = ACTIONS(9478),
    [sym_dataitem_keyword] = ACTIONS(9478),
    [sym_column_keyword] = ACTIONS(9478),
    [sym_filter_keyword] = ACTIONS(9478),
    [sym_labels_keyword] = ACTIONS(9478),
    [sym_rendering_keyword] = ACTIONS(9478),
    [sym_requestpage_keyword] = ACTIONS(9478),
    [sym_schema_keyword] = ACTIONS(9478),
    [sym_views_keyword] = ACTIONS(9478),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9478),
    [sym_preproc_open] = ACTIONS(9478),
    [sym_preproc_close] = ACTIONS(9478),
  },
  [STATE(4182)] = {
    [anon_sym_SEMI] = ACTIONS(9486),
    [aux_sym_where_condition_token1] = ACTIONS(9488),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9486),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9486),
    [anon_sym_LBRACK] = ACTIONS(9486),
    [aux_sym_basic_type_token6] = ACTIONS(9488),
    [aux_sym_basic_type_token22] = ACTIONS(9488),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9486),
    [aux_sym_addafter_modification_token1] = ACTIONS(9486),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9486),
    [aux_sym_modify_modification_token1] = ACTIONS(9486),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9486),
    [aux_sym_movelast_modification_token1] = ACTIONS(9486),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9486),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9486),
    [aux_sym_separator_action_token1] = ACTIONS(9486),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9486),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9486),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9486),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9486),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9486),
    [anon_sym_POUNDif] = ACTIONS(9486),
    [anon_sym_POUNDIF] = ACTIONS(9486),
    [anon_sym_POUNDIf] = ACTIONS(9486),
    [anon_sym_POUNDelif] = ACTIONS(9486),
    [anon_sym_POUNDELIF] = ACTIONS(9486),
    [anon_sym_POUNDElif] = ACTIONS(9486),
    [anon_sym_POUNDelse] = ACTIONS(9486),
    [anon_sym_POUNDELSE] = ACTIONS(9486),
    [anon_sym_POUNDElse] = ACTIONS(9486),
    [anon_sym_POUNDelse2] = ACTIONS(9486),
    [anon_sym_POUNDELSE2] = ACTIONS(9486),
    [anon_sym_POUNDElse2] = ACTIONS(9486),
    [anon_sym_POUNDendif] = ACTIONS(9486),
    [anon_sym_POUNDENDIF] = ACTIONS(9486),
    [anon_sym_POUNDEndif] = ACTIONS(9486),
    [anon_sym_POUNDendif2] = ACTIONS(9486),
    [anon_sym_POUNDENDIF2] = ACTIONS(9486),
    [anon_sym_POUNDEndif2] = ACTIONS(9486),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9486),
    [sym_trigger_keyword] = ACTIONS(9486),
    [sym_var_keyword] = ACTIONS(9486),
    [sym_local_keyword] = ACTIONS(9486),
    [sym_internal_keyword] = ACTIONS(9486),
    [sym_protected_keyword] = ACTIONS(9486),
    [sym_event_keyword] = ACTIONS(9486),
    [sym_fields_keyword] = ACTIONS(9486),
    [sym_keys_keyword] = ACTIONS(9486),
    [sym_fieldgroups_keyword] = ACTIONS(9486),
    [sym_actions_keyword] = ACTIONS(9486),
    [sym_layout_keyword] = ACTIONS(9486),
    [sym_area_keyword] = ACTIONS(9486),
    [sym_group_keyword] = ACTIONS(9486),
    [sym_repeater_keyword] = ACTIONS(9486),
    [sym_cuegroup_keyword] = ACTIONS(9486),
    [sym_fixed_keyword] = ACTIONS(9486),
    [sym_grid_keyword] = ACTIONS(9486),
    [sym_part_keyword] = ACTIONS(9486),
    [sym_systempart_keyword] = ACTIONS(9486),
    [sym_usercontrol_keyword] = ACTIONS(9486),
    [sym_dataset_keyword] = ACTIONS(9486),
    [sym_elements_keyword] = ACTIONS(9486),
    [sym_dataitem_keyword] = ACTIONS(9486),
    [sym_column_keyword] = ACTIONS(9486),
    [sym_filter_keyword] = ACTIONS(9486),
    [sym_labels_keyword] = ACTIONS(9486),
    [sym_rendering_keyword] = ACTIONS(9486),
    [sym_requestpage_keyword] = ACTIONS(9486),
    [sym_schema_keyword] = ACTIONS(9486),
    [sym_views_keyword] = ACTIONS(9486),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9486),
    [sym_preproc_open] = ACTIONS(9486),
    [sym_preproc_close] = ACTIONS(9486),
  },
  [STATE(4183)] = {
    [anon_sym_SEMI] = ACTIONS(9426),
    [aux_sym_where_condition_token1] = ACTIONS(9428),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9426),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9426),
    [anon_sym_LBRACK] = ACTIONS(9426),
    [aux_sym_basic_type_token6] = ACTIONS(9428),
    [aux_sym_basic_type_token22] = ACTIONS(9428),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9426),
    [aux_sym_addafter_modification_token1] = ACTIONS(9426),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9426),
    [aux_sym_modify_modification_token1] = ACTIONS(9426),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9426),
    [aux_sym_movelast_modification_token1] = ACTIONS(9426),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9426),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9426),
    [aux_sym_separator_action_token1] = ACTIONS(9426),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9426),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9426),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9426),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9426),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9426),
    [anon_sym_POUNDif] = ACTIONS(9426),
    [anon_sym_POUNDIF] = ACTIONS(9426),
    [anon_sym_POUNDIf] = ACTIONS(9426),
    [anon_sym_POUNDelif] = ACTIONS(9426),
    [anon_sym_POUNDELIF] = ACTIONS(9426),
    [anon_sym_POUNDElif] = ACTIONS(9426),
    [anon_sym_POUNDelse] = ACTIONS(9426),
    [anon_sym_POUNDELSE] = ACTIONS(9426),
    [anon_sym_POUNDElse] = ACTIONS(9426),
    [anon_sym_POUNDelse2] = ACTIONS(9426),
    [anon_sym_POUNDELSE2] = ACTIONS(9426),
    [anon_sym_POUNDElse2] = ACTIONS(9426),
    [anon_sym_POUNDendif] = ACTIONS(9426),
    [anon_sym_POUNDENDIF] = ACTIONS(9426),
    [anon_sym_POUNDEndif] = ACTIONS(9426),
    [anon_sym_POUNDendif2] = ACTIONS(9426),
    [anon_sym_POUNDENDIF2] = ACTIONS(9426),
    [anon_sym_POUNDEndif2] = ACTIONS(9426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9426),
    [sym_trigger_keyword] = ACTIONS(9426),
    [sym_var_keyword] = ACTIONS(9426),
    [sym_local_keyword] = ACTIONS(9426),
    [sym_internal_keyword] = ACTIONS(9426),
    [sym_protected_keyword] = ACTIONS(9426),
    [sym_event_keyword] = ACTIONS(9426),
    [sym_fields_keyword] = ACTIONS(9426),
    [sym_keys_keyword] = ACTIONS(9426),
    [sym_fieldgroups_keyword] = ACTIONS(9426),
    [sym_actions_keyword] = ACTIONS(9426),
    [sym_layout_keyword] = ACTIONS(9426),
    [sym_area_keyword] = ACTIONS(9426),
    [sym_group_keyword] = ACTIONS(9426),
    [sym_repeater_keyword] = ACTIONS(9426),
    [sym_cuegroup_keyword] = ACTIONS(9426),
    [sym_fixed_keyword] = ACTIONS(9426),
    [sym_grid_keyword] = ACTIONS(9426),
    [sym_part_keyword] = ACTIONS(9426),
    [sym_systempart_keyword] = ACTIONS(9426),
    [sym_usercontrol_keyword] = ACTIONS(9426),
    [sym_dataset_keyword] = ACTIONS(9426),
    [sym_elements_keyword] = ACTIONS(9426),
    [sym_dataitem_keyword] = ACTIONS(9426),
    [sym_column_keyword] = ACTIONS(9426),
    [sym_filter_keyword] = ACTIONS(9426),
    [sym_labels_keyword] = ACTIONS(9426),
    [sym_rendering_keyword] = ACTIONS(9426),
    [sym_requestpage_keyword] = ACTIONS(9426),
    [sym_schema_keyword] = ACTIONS(9426),
    [sym_views_keyword] = ACTIONS(9426),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9426),
    [sym_preproc_open] = ACTIONS(9426),
    [sym_preproc_close] = ACTIONS(9426),
  },
  [STATE(4184)] = {
    [anon_sym_SEMI] = ACTIONS(9478),
    [aux_sym_where_condition_token1] = ACTIONS(9480),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9478),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9478),
    [anon_sym_LBRACK] = ACTIONS(9478),
    [aux_sym_basic_type_token6] = ACTIONS(9480),
    [aux_sym_basic_type_token22] = ACTIONS(9480),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9478),
    [aux_sym_addafter_modification_token1] = ACTIONS(9478),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9478),
    [aux_sym_modify_modification_token1] = ACTIONS(9478),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9478),
    [aux_sym_movelast_modification_token1] = ACTIONS(9478),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9478),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9478),
    [aux_sym_separator_action_token1] = ACTIONS(9478),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9478),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9478),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9478),
    [anon_sym_POUNDif] = ACTIONS(9478),
    [anon_sym_POUNDIF] = ACTIONS(9478),
    [anon_sym_POUNDIf] = ACTIONS(9478),
    [anon_sym_POUNDelif] = ACTIONS(9478),
    [anon_sym_POUNDELIF] = ACTIONS(9478),
    [anon_sym_POUNDElif] = ACTIONS(9478),
    [anon_sym_POUNDelse] = ACTIONS(9478),
    [anon_sym_POUNDELSE] = ACTIONS(9478),
    [anon_sym_POUNDElse] = ACTIONS(9478),
    [anon_sym_POUNDelse2] = ACTIONS(9478),
    [anon_sym_POUNDELSE2] = ACTIONS(9478),
    [anon_sym_POUNDElse2] = ACTIONS(9478),
    [anon_sym_POUNDendif] = ACTIONS(9478),
    [anon_sym_POUNDENDIF] = ACTIONS(9478),
    [anon_sym_POUNDEndif] = ACTIONS(9478),
    [anon_sym_POUNDendif2] = ACTIONS(9478),
    [anon_sym_POUNDENDIF2] = ACTIONS(9478),
    [anon_sym_POUNDEndif2] = ACTIONS(9478),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9478),
    [sym_trigger_keyword] = ACTIONS(9478),
    [sym_var_keyword] = ACTIONS(9478),
    [sym_local_keyword] = ACTIONS(9478),
    [sym_internal_keyword] = ACTIONS(9478),
    [sym_protected_keyword] = ACTIONS(9478),
    [sym_event_keyword] = ACTIONS(9478),
    [sym_fields_keyword] = ACTIONS(9478),
    [sym_keys_keyword] = ACTIONS(9478),
    [sym_fieldgroups_keyword] = ACTIONS(9478),
    [sym_actions_keyword] = ACTIONS(9478),
    [sym_layout_keyword] = ACTIONS(9478),
    [sym_area_keyword] = ACTIONS(9478),
    [sym_group_keyword] = ACTIONS(9478),
    [sym_repeater_keyword] = ACTIONS(9478),
    [sym_cuegroup_keyword] = ACTIONS(9478),
    [sym_fixed_keyword] = ACTIONS(9478),
    [sym_grid_keyword] = ACTIONS(9478),
    [sym_part_keyword] = ACTIONS(9478),
    [sym_systempart_keyword] = ACTIONS(9478),
    [sym_usercontrol_keyword] = ACTIONS(9478),
    [sym_dataset_keyword] = ACTIONS(9478),
    [sym_elements_keyword] = ACTIONS(9478),
    [sym_dataitem_keyword] = ACTIONS(9478),
    [sym_column_keyword] = ACTIONS(9478),
    [sym_filter_keyword] = ACTIONS(9478),
    [sym_labels_keyword] = ACTIONS(9478),
    [sym_rendering_keyword] = ACTIONS(9478),
    [sym_requestpage_keyword] = ACTIONS(9478),
    [sym_schema_keyword] = ACTIONS(9478),
    [sym_views_keyword] = ACTIONS(9478),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9478),
    [sym_preproc_open] = ACTIONS(9478),
    [sym_preproc_close] = ACTIONS(9478),
  },
  [STATE(4185)] = {
    [anon_sym_SEMI] = ACTIONS(9482),
    [aux_sym_where_condition_token1] = ACTIONS(9484),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9482),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9482),
    [anon_sym_LBRACK] = ACTIONS(9482),
    [aux_sym_basic_type_token6] = ACTIONS(9484),
    [aux_sym_basic_type_token22] = ACTIONS(9484),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9482),
    [aux_sym_addafter_modification_token1] = ACTIONS(9482),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9482),
    [aux_sym_modify_modification_token1] = ACTIONS(9482),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9482),
    [aux_sym_movelast_modification_token1] = ACTIONS(9482),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9482),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9482),
    [aux_sym_separator_action_token1] = ACTIONS(9482),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9482),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9482),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9482),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9482),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9482),
    [anon_sym_POUNDif] = ACTIONS(9482),
    [anon_sym_POUNDIF] = ACTIONS(9482),
    [anon_sym_POUNDIf] = ACTIONS(9482),
    [anon_sym_POUNDelif] = ACTIONS(9482),
    [anon_sym_POUNDELIF] = ACTIONS(9482),
    [anon_sym_POUNDElif] = ACTIONS(9482),
    [anon_sym_POUNDelse] = ACTIONS(9482),
    [anon_sym_POUNDELSE] = ACTIONS(9482),
    [anon_sym_POUNDElse] = ACTIONS(9482),
    [anon_sym_POUNDelse2] = ACTIONS(9482),
    [anon_sym_POUNDELSE2] = ACTIONS(9482),
    [anon_sym_POUNDElse2] = ACTIONS(9482),
    [anon_sym_POUNDendif] = ACTIONS(9482),
    [anon_sym_POUNDENDIF] = ACTIONS(9482),
    [anon_sym_POUNDEndif] = ACTIONS(9482),
    [anon_sym_POUNDendif2] = ACTIONS(9482),
    [anon_sym_POUNDENDIF2] = ACTIONS(9482),
    [anon_sym_POUNDEndif2] = ACTIONS(9482),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9482),
    [sym_trigger_keyword] = ACTIONS(9482),
    [sym_var_keyword] = ACTIONS(9482),
    [sym_local_keyword] = ACTIONS(9482),
    [sym_internal_keyword] = ACTIONS(9482),
    [sym_protected_keyword] = ACTIONS(9482),
    [sym_event_keyword] = ACTIONS(9482),
    [sym_fields_keyword] = ACTIONS(9482),
    [sym_keys_keyword] = ACTIONS(9482),
    [sym_fieldgroups_keyword] = ACTIONS(9482),
    [sym_actions_keyword] = ACTIONS(9482),
    [sym_layout_keyword] = ACTIONS(9482),
    [sym_area_keyword] = ACTIONS(9482),
    [sym_group_keyword] = ACTIONS(9482),
    [sym_repeater_keyword] = ACTIONS(9482),
    [sym_cuegroup_keyword] = ACTIONS(9482),
    [sym_fixed_keyword] = ACTIONS(9482),
    [sym_grid_keyword] = ACTIONS(9482),
    [sym_part_keyword] = ACTIONS(9482),
    [sym_systempart_keyword] = ACTIONS(9482),
    [sym_usercontrol_keyword] = ACTIONS(9482),
    [sym_dataset_keyword] = ACTIONS(9482),
    [sym_elements_keyword] = ACTIONS(9482),
    [sym_dataitem_keyword] = ACTIONS(9482),
    [sym_column_keyword] = ACTIONS(9482),
    [sym_filter_keyword] = ACTIONS(9482),
    [sym_labels_keyword] = ACTIONS(9482),
    [sym_rendering_keyword] = ACTIONS(9482),
    [sym_requestpage_keyword] = ACTIONS(9482),
    [sym_schema_keyword] = ACTIONS(9482),
    [sym_views_keyword] = ACTIONS(9482),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9482),
    [sym_preproc_open] = ACTIONS(9482),
    [sym_preproc_close] = ACTIONS(9482),
  },
  [STATE(4186)] = {
    [anon_sym_SEMI] = ACTIONS(9490),
    [aux_sym_where_condition_token1] = ACTIONS(9492),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9490),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9490),
    [anon_sym_LBRACK] = ACTIONS(9490),
    [aux_sym_basic_type_token6] = ACTIONS(9492),
    [aux_sym_basic_type_token22] = ACTIONS(9492),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9490),
    [aux_sym_addafter_modification_token1] = ACTIONS(9490),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9490),
    [aux_sym_modify_modification_token1] = ACTIONS(9490),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9490),
    [aux_sym_movelast_modification_token1] = ACTIONS(9490),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9490),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9490),
    [aux_sym_separator_action_token1] = ACTIONS(9490),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9490),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9490),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9490),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9490),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9490),
    [anon_sym_POUNDif] = ACTIONS(9490),
    [anon_sym_POUNDIF] = ACTIONS(9490),
    [anon_sym_POUNDIf] = ACTIONS(9490),
    [anon_sym_POUNDelif] = ACTIONS(9490),
    [anon_sym_POUNDELIF] = ACTIONS(9490),
    [anon_sym_POUNDElif] = ACTIONS(9490),
    [anon_sym_POUNDelse] = ACTIONS(9490),
    [anon_sym_POUNDELSE] = ACTIONS(9490),
    [anon_sym_POUNDElse] = ACTIONS(9490),
    [anon_sym_POUNDelse2] = ACTIONS(9490),
    [anon_sym_POUNDELSE2] = ACTIONS(9490),
    [anon_sym_POUNDElse2] = ACTIONS(9490),
    [anon_sym_POUNDendif] = ACTIONS(9490),
    [anon_sym_POUNDENDIF] = ACTIONS(9490),
    [anon_sym_POUNDEndif] = ACTIONS(9490),
    [anon_sym_POUNDendif2] = ACTIONS(9490),
    [anon_sym_POUNDENDIF2] = ACTIONS(9490),
    [anon_sym_POUNDEndif2] = ACTIONS(9490),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9490),
    [sym_trigger_keyword] = ACTIONS(9490),
    [sym_var_keyword] = ACTIONS(9490),
    [sym_local_keyword] = ACTIONS(9490),
    [sym_internal_keyword] = ACTIONS(9490),
    [sym_protected_keyword] = ACTIONS(9490),
    [sym_event_keyword] = ACTIONS(9490),
    [sym_fields_keyword] = ACTIONS(9490),
    [sym_keys_keyword] = ACTIONS(9490),
    [sym_fieldgroups_keyword] = ACTIONS(9490),
    [sym_actions_keyword] = ACTIONS(9490),
    [sym_layout_keyword] = ACTIONS(9490),
    [sym_area_keyword] = ACTIONS(9490),
    [sym_group_keyword] = ACTIONS(9490),
    [sym_repeater_keyword] = ACTIONS(9490),
    [sym_cuegroup_keyword] = ACTIONS(9490),
    [sym_fixed_keyword] = ACTIONS(9490),
    [sym_grid_keyword] = ACTIONS(9490),
    [sym_part_keyword] = ACTIONS(9490),
    [sym_systempart_keyword] = ACTIONS(9490),
    [sym_usercontrol_keyword] = ACTIONS(9490),
    [sym_dataset_keyword] = ACTIONS(9490),
    [sym_elements_keyword] = ACTIONS(9490),
    [sym_dataitem_keyword] = ACTIONS(9490),
    [sym_column_keyword] = ACTIONS(9490),
    [sym_filter_keyword] = ACTIONS(9490),
    [sym_labels_keyword] = ACTIONS(9490),
    [sym_rendering_keyword] = ACTIONS(9490),
    [sym_requestpage_keyword] = ACTIONS(9490),
    [sym_schema_keyword] = ACTIONS(9490),
    [sym_views_keyword] = ACTIONS(9490),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9490),
    [sym_preproc_open] = ACTIONS(9490),
    [sym_preproc_close] = ACTIONS(9490),
  },
  [STATE(4187)] = {
    [anon_sym_SEMI] = ACTIONS(9494),
    [aux_sym_where_condition_token1] = ACTIONS(9496),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9494),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9494),
    [anon_sym_LBRACK] = ACTIONS(9494),
    [aux_sym_basic_type_token6] = ACTIONS(9496),
    [aux_sym_basic_type_token22] = ACTIONS(9496),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9494),
    [aux_sym_addafter_modification_token1] = ACTIONS(9494),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9494),
    [aux_sym_modify_modification_token1] = ACTIONS(9494),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9494),
    [aux_sym_movelast_modification_token1] = ACTIONS(9494),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9494),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9494),
    [aux_sym_separator_action_token1] = ACTIONS(9494),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9494),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9494),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9494),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9494),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9494),
    [anon_sym_POUNDif] = ACTIONS(9494),
    [anon_sym_POUNDIF] = ACTIONS(9494),
    [anon_sym_POUNDIf] = ACTIONS(9494),
    [anon_sym_POUNDelif] = ACTIONS(9494),
    [anon_sym_POUNDELIF] = ACTIONS(9494),
    [anon_sym_POUNDElif] = ACTIONS(9494),
    [anon_sym_POUNDelse] = ACTIONS(9494),
    [anon_sym_POUNDELSE] = ACTIONS(9494),
    [anon_sym_POUNDElse] = ACTIONS(9494),
    [anon_sym_POUNDelse2] = ACTIONS(9494),
    [anon_sym_POUNDELSE2] = ACTIONS(9494),
    [anon_sym_POUNDElse2] = ACTIONS(9494),
    [anon_sym_POUNDendif] = ACTIONS(9494),
    [anon_sym_POUNDENDIF] = ACTIONS(9494),
    [anon_sym_POUNDEndif] = ACTIONS(9494),
    [anon_sym_POUNDendif2] = ACTIONS(9494),
    [anon_sym_POUNDENDIF2] = ACTIONS(9494),
    [anon_sym_POUNDEndif2] = ACTIONS(9494),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9494),
    [sym_trigger_keyword] = ACTIONS(9494),
    [sym_var_keyword] = ACTIONS(9494),
    [sym_local_keyword] = ACTIONS(9494),
    [sym_internal_keyword] = ACTIONS(9494),
    [sym_protected_keyword] = ACTIONS(9494),
    [sym_event_keyword] = ACTIONS(9494),
    [sym_fields_keyword] = ACTIONS(9494),
    [sym_keys_keyword] = ACTIONS(9494),
    [sym_fieldgroups_keyword] = ACTIONS(9494),
    [sym_actions_keyword] = ACTIONS(9494),
    [sym_layout_keyword] = ACTIONS(9494),
    [sym_area_keyword] = ACTIONS(9494),
    [sym_group_keyword] = ACTIONS(9494),
    [sym_repeater_keyword] = ACTIONS(9494),
    [sym_cuegroup_keyword] = ACTIONS(9494),
    [sym_fixed_keyword] = ACTIONS(9494),
    [sym_grid_keyword] = ACTIONS(9494),
    [sym_part_keyword] = ACTIONS(9494),
    [sym_systempart_keyword] = ACTIONS(9494),
    [sym_usercontrol_keyword] = ACTIONS(9494),
    [sym_dataset_keyword] = ACTIONS(9494),
    [sym_elements_keyword] = ACTIONS(9494),
    [sym_dataitem_keyword] = ACTIONS(9494),
    [sym_column_keyword] = ACTIONS(9494),
    [sym_filter_keyword] = ACTIONS(9494),
    [sym_labels_keyword] = ACTIONS(9494),
    [sym_rendering_keyword] = ACTIONS(9494),
    [sym_requestpage_keyword] = ACTIONS(9494),
    [sym_schema_keyword] = ACTIONS(9494),
    [sym_views_keyword] = ACTIONS(9494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9494),
    [sym_preproc_open] = ACTIONS(9494),
    [sym_preproc_close] = ACTIONS(9494),
  },
  [STATE(4188)] = {
    [anon_sym_SEMI] = ACTIONS(9490),
    [aux_sym_where_condition_token1] = ACTIONS(9492),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9490),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9490),
    [anon_sym_LBRACK] = ACTIONS(9490),
    [aux_sym_basic_type_token6] = ACTIONS(9492),
    [aux_sym_basic_type_token22] = ACTIONS(9492),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9490),
    [aux_sym_addafter_modification_token1] = ACTIONS(9490),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9490),
    [aux_sym_modify_modification_token1] = ACTIONS(9490),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9490),
    [aux_sym_movelast_modification_token1] = ACTIONS(9490),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9490),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9490),
    [aux_sym_separator_action_token1] = ACTIONS(9490),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9490),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9490),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9490),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9490),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9490),
    [anon_sym_POUNDif] = ACTIONS(9490),
    [anon_sym_POUNDIF] = ACTIONS(9490),
    [anon_sym_POUNDIf] = ACTIONS(9490),
    [anon_sym_POUNDelif] = ACTIONS(9490),
    [anon_sym_POUNDELIF] = ACTIONS(9490),
    [anon_sym_POUNDElif] = ACTIONS(9490),
    [anon_sym_POUNDelse] = ACTIONS(9490),
    [anon_sym_POUNDELSE] = ACTIONS(9490),
    [anon_sym_POUNDElse] = ACTIONS(9490),
    [anon_sym_POUNDelse2] = ACTIONS(9490),
    [anon_sym_POUNDELSE2] = ACTIONS(9490),
    [anon_sym_POUNDElse2] = ACTIONS(9490),
    [anon_sym_POUNDendif] = ACTIONS(9490),
    [anon_sym_POUNDENDIF] = ACTIONS(9490),
    [anon_sym_POUNDEndif] = ACTIONS(9490),
    [anon_sym_POUNDendif2] = ACTIONS(9490),
    [anon_sym_POUNDENDIF2] = ACTIONS(9490),
    [anon_sym_POUNDEndif2] = ACTIONS(9490),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9490),
    [sym_trigger_keyword] = ACTIONS(9490),
    [sym_var_keyword] = ACTIONS(9490),
    [sym_local_keyword] = ACTIONS(9490),
    [sym_internal_keyword] = ACTIONS(9490),
    [sym_protected_keyword] = ACTIONS(9490),
    [sym_event_keyword] = ACTIONS(9490),
    [sym_fields_keyword] = ACTIONS(9490),
    [sym_keys_keyword] = ACTIONS(9490),
    [sym_fieldgroups_keyword] = ACTIONS(9490),
    [sym_actions_keyword] = ACTIONS(9490),
    [sym_layout_keyword] = ACTIONS(9490),
    [sym_area_keyword] = ACTIONS(9490),
    [sym_group_keyword] = ACTIONS(9490),
    [sym_repeater_keyword] = ACTIONS(9490),
    [sym_cuegroup_keyword] = ACTIONS(9490),
    [sym_fixed_keyword] = ACTIONS(9490),
    [sym_grid_keyword] = ACTIONS(9490),
    [sym_part_keyword] = ACTIONS(9490),
    [sym_systempart_keyword] = ACTIONS(9490),
    [sym_usercontrol_keyword] = ACTIONS(9490),
    [sym_dataset_keyword] = ACTIONS(9490),
    [sym_elements_keyword] = ACTIONS(9490),
    [sym_dataitem_keyword] = ACTIONS(9490),
    [sym_column_keyword] = ACTIONS(9490),
    [sym_filter_keyword] = ACTIONS(9490),
    [sym_labels_keyword] = ACTIONS(9490),
    [sym_rendering_keyword] = ACTIONS(9490),
    [sym_requestpage_keyword] = ACTIONS(9490),
    [sym_schema_keyword] = ACTIONS(9490),
    [sym_views_keyword] = ACTIONS(9490),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9490),
    [sym_preproc_open] = ACTIONS(9490),
    [sym_preproc_close] = ACTIONS(9490),
  },
  [STATE(4189)] = {
    [sym_boolean] = STATE(8851),
    [sym_attribute_argument_list] = STATE(17272),
    [sym__attribute_argument] = STATE(15595),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8661),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8661),
    [sym_database_reference] = STATE(8839),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9498),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9500),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(9502),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9504),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9506),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4190)] = {
    [anon_sym_SEMI] = ACTIONS(9508),
    [aux_sym_where_condition_token1] = ACTIONS(9510),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9508),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9508),
    [anon_sym_LBRACK] = ACTIONS(9508),
    [aux_sym_basic_type_token6] = ACTIONS(9510),
    [aux_sym_basic_type_token22] = ACTIONS(9510),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9508),
    [aux_sym_addafter_modification_token1] = ACTIONS(9508),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9508),
    [aux_sym_modify_modification_token1] = ACTIONS(9508),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9508),
    [aux_sym_movelast_modification_token1] = ACTIONS(9508),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9508),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9508),
    [aux_sym_separator_action_token1] = ACTIONS(9508),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9508),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9508),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9508),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9508),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9508),
    [anon_sym_POUNDif] = ACTIONS(9508),
    [anon_sym_POUNDIF] = ACTIONS(9508),
    [anon_sym_POUNDIf] = ACTIONS(9508),
    [anon_sym_POUNDelif] = ACTIONS(9508),
    [anon_sym_POUNDELIF] = ACTIONS(9508),
    [anon_sym_POUNDElif] = ACTIONS(9508),
    [anon_sym_POUNDelse] = ACTIONS(9508),
    [anon_sym_POUNDELSE] = ACTIONS(9508),
    [anon_sym_POUNDElse] = ACTIONS(9508),
    [anon_sym_POUNDelse2] = ACTIONS(9508),
    [anon_sym_POUNDELSE2] = ACTIONS(9508),
    [anon_sym_POUNDElse2] = ACTIONS(9508),
    [anon_sym_POUNDendif] = ACTIONS(9508),
    [anon_sym_POUNDENDIF] = ACTIONS(9508),
    [anon_sym_POUNDEndif] = ACTIONS(9508),
    [anon_sym_POUNDendif2] = ACTIONS(9508),
    [anon_sym_POUNDENDIF2] = ACTIONS(9508),
    [anon_sym_POUNDEndif2] = ACTIONS(9508),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9508),
    [sym_trigger_keyword] = ACTIONS(9508),
    [sym_var_keyword] = ACTIONS(9508),
    [sym_local_keyword] = ACTIONS(9508),
    [sym_internal_keyword] = ACTIONS(9508),
    [sym_protected_keyword] = ACTIONS(9508),
    [sym_event_keyword] = ACTIONS(9508),
    [sym_fields_keyword] = ACTIONS(9508),
    [sym_keys_keyword] = ACTIONS(9508),
    [sym_fieldgroups_keyword] = ACTIONS(9508),
    [sym_actions_keyword] = ACTIONS(9508),
    [sym_layout_keyword] = ACTIONS(9508),
    [sym_area_keyword] = ACTIONS(9508),
    [sym_group_keyword] = ACTIONS(9508),
    [sym_repeater_keyword] = ACTIONS(9508),
    [sym_cuegroup_keyword] = ACTIONS(9508),
    [sym_fixed_keyword] = ACTIONS(9508),
    [sym_grid_keyword] = ACTIONS(9508),
    [sym_part_keyword] = ACTIONS(9508),
    [sym_systempart_keyword] = ACTIONS(9508),
    [sym_usercontrol_keyword] = ACTIONS(9508),
    [sym_dataset_keyword] = ACTIONS(9508),
    [sym_elements_keyword] = ACTIONS(9508),
    [sym_dataitem_keyword] = ACTIONS(9508),
    [sym_column_keyword] = ACTIONS(9508),
    [sym_filter_keyword] = ACTIONS(9508),
    [sym_labels_keyword] = ACTIONS(9508),
    [sym_rendering_keyword] = ACTIONS(9508),
    [sym_requestpage_keyword] = ACTIONS(9508),
    [sym_schema_keyword] = ACTIONS(9508),
    [sym_views_keyword] = ACTIONS(9508),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9508),
    [sym_preproc_open] = ACTIONS(9508),
    [sym_preproc_close] = ACTIONS(9508),
  },
  [STATE(4191)] = {
    [anon_sym_SEMI] = ACTIONS(9512),
    [aux_sym_where_condition_token1] = ACTIONS(9514),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9512),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9512),
    [anon_sym_LBRACK] = ACTIONS(9512),
    [aux_sym_basic_type_token6] = ACTIONS(9514),
    [aux_sym_basic_type_token22] = ACTIONS(9514),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9512),
    [aux_sym_addafter_modification_token1] = ACTIONS(9512),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9512),
    [aux_sym_modify_modification_token1] = ACTIONS(9512),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9512),
    [aux_sym_movelast_modification_token1] = ACTIONS(9512),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9512),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9512),
    [aux_sym_separator_action_token1] = ACTIONS(9512),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9512),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9512),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9512),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9512),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9512),
    [anon_sym_POUNDif] = ACTIONS(9512),
    [anon_sym_POUNDIF] = ACTIONS(9512),
    [anon_sym_POUNDIf] = ACTIONS(9512),
    [anon_sym_POUNDelif] = ACTIONS(9512),
    [anon_sym_POUNDELIF] = ACTIONS(9512),
    [anon_sym_POUNDElif] = ACTIONS(9512),
    [anon_sym_POUNDelse] = ACTIONS(9512),
    [anon_sym_POUNDELSE] = ACTIONS(9512),
    [anon_sym_POUNDElse] = ACTIONS(9512),
    [anon_sym_POUNDelse2] = ACTIONS(9512),
    [anon_sym_POUNDELSE2] = ACTIONS(9512),
    [anon_sym_POUNDElse2] = ACTIONS(9512),
    [anon_sym_POUNDendif] = ACTIONS(9512),
    [anon_sym_POUNDENDIF] = ACTIONS(9512),
    [anon_sym_POUNDEndif] = ACTIONS(9512),
    [anon_sym_POUNDendif2] = ACTIONS(9512),
    [anon_sym_POUNDENDIF2] = ACTIONS(9512),
    [anon_sym_POUNDEndif2] = ACTIONS(9512),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9512),
    [sym_trigger_keyword] = ACTIONS(9512),
    [sym_var_keyword] = ACTIONS(9512),
    [sym_local_keyword] = ACTIONS(9512),
    [sym_internal_keyword] = ACTIONS(9512),
    [sym_protected_keyword] = ACTIONS(9512),
    [sym_event_keyword] = ACTIONS(9512),
    [sym_fields_keyword] = ACTIONS(9512),
    [sym_keys_keyword] = ACTIONS(9512),
    [sym_fieldgroups_keyword] = ACTIONS(9512),
    [sym_actions_keyword] = ACTIONS(9512),
    [sym_layout_keyword] = ACTIONS(9512),
    [sym_area_keyword] = ACTIONS(9512),
    [sym_group_keyword] = ACTIONS(9512),
    [sym_repeater_keyword] = ACTIONS(9512),
    [sym_cuegroup_keyword] = ACTIONS(9512),
    [sym_fixed_keyword] = ACTIONS(9512),
    [sym_grid_keyword] = ACTIONS(9512),
    [sym_part_keyword] = ACTIONS(9512),
    [sym_systempart_keyword] = ACTIONS(9512),
    [sym_usercontrol_keyword] = ACTIONS(9512),
    [sym_dataset_keyword] = ACTIONS(9512),
    [sym_elements_keyword] = ACTIONS(9512),
    [sym_dataitem_keyword] = ACTIONS(9512),
    [sym_column_keyword] = ACTIONS(9512),
    [sym_filter_keyword] = ACTIONS(9512),
    [sym_labels_keyword] = ACTIONS(9512),
    [sym_rendering_keyword] = ACTIONS(9512),
    [sym_requestpage_keyword] = ACTIONS(9512),
    [sym_schema_keyword] = ACTIONS(9512),
    [sym_views_keyword] = ACTIONS(9512),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9512),
    [sym_preproc_open] = ACTIONS(9512),
    [sym_preproc_close] = ACTIONS(9512),
  },
  [STATE(4192)] = {
    [anon_sym_SEMI] = ACTIONS(9516),
    [aux_sym_where_condition_token1] = ACTIONS(9518),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9516),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9516),
    [anon_sym_LBRACK] = ACTIONS(9516),
    [aux_sym_basic_type_token6] = ACTIONS(9518),
    [aux_sym_basic_type_token22] = ACTIONS(9518),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9516),
    [aux_sym_addafter_modification_token1] = ACTIONS(9516),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9516),
    [aux_sym_modify_modification_token1] = ACTIONS(9516),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9516),
    [aux_sym_movelast_modification_token1] = ACTIONS(9516),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9516),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9516),
    [aux_sym_separator_action_token1] = ACTIONS(9516),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9516),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9516),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9516),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9516),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9516),
    [anon_sym_POUNDif] = ACTIONS(9516),
    [anon_sym_POUNDIF] = ACTIONS(9516),
    [anon_sym_POUNDIf] = ACTIONS(9516),
    [anon_sym_POUNDelif] = ACTIONS(9516),
    [anon_sym_POUNDELIF] = ACTIONS(9516),
    [anon_sym_POUNDElif] = ACTIONS(9516),
    [anon_sym_POUNDelse] = ACTIONS(9516),
    [anon_sym_POUNDELSE] = ACTIONS(9516),
    [anon_sym_POUNDElse] = ACTIONS(9516),
    [anon_sym_POUNDelse2] = ACTIONS(9516),
    [anon_sym_POUNDELSE2] = ACTIONS(9516),
    [anon_sym_POUNDElse2] = ACTIONS(9516),
    [anon_sym_POUNDendif] = ACTIONS(9516),
    [anon_sym_POUNDENDIF] = ACTIONS(9516),
    [anon_sym_POUNDEndif] = ACTIONS(9516),
    [anon_sym_POUNDendif2] = ACTIONS(9516),
    [anon_sym_POUNDENDIF2] = ACTIONS(9516),
    [anon_sym_POUNDEndif2] = ACTIONS(9516),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9516),
    [sym_trigger_keyword] = ACTIONS(9516),
    [sym_var_keyword] = ACTIONS(9516),
    [sym_local_keyword] = ACTIONS(9516),
    [sym_internal_keyword] = ACTIONS(9516),
    [sym_protected_keyword] = ACTIONS(9516),
    [sym_event_keyword] = ACTIONS(9516),
    [sym_fields_keyword] = ACTIONS(9516),
    [sym_keys_keyword] = ACTIONS(9516),
    [sym_fieldgroups_keyword] = ACTIONS(9516),
    [sym_actions_keyword] = ACTIONS(9516),
    [sym_layout_keyword] = ACTIONS(9516),
    [sym_area_keyword] = ACTIONS(9516),
    [sym_group_keyword] = ACTIONS(9516),
    [sym_repeater_keyword] = ACTIONS(9516),
    [sym_cuegroup_keyword] = ACTIONS(9516),
    [sym_fixed_keyword] = ACTIONS(9516),
    [sym_grid_keyword] = ACTIONS(9516),
    [sym_part_keyword] = ACTIONS(9516),
    [sym_systempart_keyword] = ACTIONS(9516),
    [sym_usercontrol_keyword] = ACTIONS(9516),
    [sym_dataset_keyword] = ACTIONS(9516),
    [sym_elements_keyword] = ACTIONS(9516),
    [sym_dataitem_keyword] = ACTIONS(9516),
    [sym_column_keyword] = ACTIONS(9516),
    [sym_filter_keyword] = ACTIONS(9516),
    [sym_labels_keyword] = ACTIONS(9516),
    [sym_rendering_keyword] = ACTIONS(9516),
    [sym_requestpage_keyword] = ACTIONS(9516),
    [sym_schema_keyword] = ACTIONS(9516),
    [sym_views_keyword] = ACTIONS(9516),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9516),
    [sym_preproc_open] = ACTIONS(9516),
    [sym_preproc_close] = ACTIONS(9516),
  },
  [STATE(4193)] = {
    [anon_sym_SEMI] = ACTIONS(9520),
    [aux_sym_where_condition_token1] = ACTIONS(9522),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9520),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9520),
    [anon_sym_LBRACK] = ACTIONS(9520),
    [aux_sym_basic_type_token6] = ACTIONS(9522),
    [aux_sym_basic_type_token22] = ACTIONS(9522),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9520),
    [aux_sym_addafter_modification_token1] = ACTIONS(9520),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9520),
    [aux_sym_modify_modification_token1] = ACTIONS(9520),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9520),
    [aux_sym_movelast_modification_token1] = ACTIONS(9520),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9520),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9520),
    [aux_sym_separator_action_token1] = ACTIONS(9520),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9520),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9520),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9520),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9520),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9520),
    [anon_sym_POUNDif] = ACTIONS(9520),
    [anon_sym_POUNDIF] = ACTIONS(9520),
    [anon_sym_POUNDIf] = ACTIONS(9520),
    [anon_sym_POUNDelif] = ACTIONS(9520),
    [anon_sym_POUNDELIF] = ACTIONS(9520),
    [anon_sym_POUNDElif] = ACTIONS(9520),
    [anon_sym_POUNDelse] = ACTIONS(9520),
    [anon_sym_POUNDELSE] = ACTIONS(9520),
    [anon_sym_POUNDElse] = ACTIONS(9520),
    [anon_sym_POUNDelse2] = ACTIONS(9520),
    [anon_sym_POUNDELSE2] = ACTIONS(9520),
    [anon_sym_POUNDElse2] = ACTIONS(9520),
    [anon_sym_POUNDendif] = ACTIONS(9520),
    [anon_sym_POUNDENDIF] = ACTIONS(9520),
    [anon_sym_POUNDEndif] = ACTIONS(9520),
    [anon_sym_POUNDendif2] = ACTIONS(9520),
    [anon_sym_POUNDENDIF2] = ACTIONS(9520),
    [anon_sym_POUNDEndif2] = ACTIONS(9520),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9520),
    [sym_trigger_keyword] = ACTIONS(9520),
    [sym_var_keyword] = ACTIONS(9520),
    [sym_local_keyword] = ACTIONS(9520),
    [sym_internal_keyword] = ACTIONS(9520),
    [sym_protected_keyword] = ACTIONS(9520),
    [sym_event_keyword] = ACTIONS(9520),
    [sym_fields_keyword] = ACTIONS(9520),
    [sym_keys_keyword] = ACTIONS(9520),
    [sym_fieldgroups_keyword] = ACTIONS(9520),
    [sym_actions_keyword] = ACTIONS(9520),
    [sym_layout_keyword] = ACTIONS(9520),
    [sym_area_keyword] = ACTIONS(9520),
    [sym_group_keyword] = ACTIONS(9520),
    [sym_repeater_keyword] = ACTIONS(9520),
    [sym_cuegroup_keyword] = ACTIONS(9520),
    [sym_fixed_keyword] = ACTIONS(9520),
    [sym_grid_keyword] = ACTIONS(9520),
    [sym_part_keyword] = ACTIONS(9520),
    [sym_systempart_keyword] = ACTIONS(9520),
    [sym_usercontrol_keyword] = ACTIONS(9520),
    [sym_dataset_keyword] = ACTIONS(9520),
    [sym_elements_keyword] = ACTIONS(9520),
    [sym_dataitem_keyword] = ACTIONS(9520),
    [sym_column_keyword] = ACTIONS(9520),
    [sym_filter_keyword] = ACTIONS(9520),
    [sym_labels_keyword] = ACTIONS(9520),
    [sym_rendering_keyword] = ACTIONS(9520),
    [sym_requestpage_keyword] = ACTIONS(9520),
    [sym_schema_keyword] = ACTIONS(9520),
    [sym_views_keyword] = ACTIONS(9520),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9520),
    [sym_preproc_open] = ACTIONS(9520),
    [sym_preproc_close] = ACTIONS(9520),
  },
  [STATE(4194)] = {
    [anon_sym_SEMI] = ACTIONS(9524),
    [aux_sym_where_condition_token1] = ACTIONS(9526),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9524),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9524),
    [anon_sym_LBRACK] = ACTIONS(9524),
    [aux_sym_basic_type_token6] = ACTIONS(9526),
    [aux_sym_basic_type_token22] = ACTIONS(9526),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9524),
    [aux_sym_addafter_modification_token1] = ACTIONS(9524),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9524),
    [aux_sym_modify_modification_token1] = ACTIONS(9524),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9524),
    [aux_sym_movelast_modification_token1] = ACTIONS(9524),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9524),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9524),
    [aux_sym_separator_action_token1] = ACTIONS(9524),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9524),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9524),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9524),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9524),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9524),
    [anon_sym_POUNDif] = ACTIONS(9524),
    [anon_sym_POUNDIF] = ACTIONS(9524),
    [anon_sym_POUNDIf] = ACTIONS(9524),
    [anon_sym_POUNDelif] = ACTIONS(9524),
    [anon_sym_POUNDELIF] = ACTIONS(9524),
    [anon_sym_POUNDElif] = ACTIONS(9524),
    [anon_sym_POUNDelse] = ACTIONS(9524),
    [anon_sym_POUNDELSE] = ACTIONS(9524),
    [anon_sym_POUNDElse] = ACTIONS(9524),
    [anon_sym_POUNDelse2] = ACTIONS(9524),
    [anon_sym_POUNDELSE2] = ACTIONS(9524),
    [anon_sym_POUNDElse2] = ACTIONS(9524),
    [anon_sym_POUNDendif] = ACTIONS(9524),
    [anon_sym_POUNDENDIF] = ACTIONS(9524),
    [anon_sym_POUNDEndif] = ACTIONS(9524),
    [anon_sym_POUNDendif2] = ACTIONS(9524),
    [anon_sym_POUNDENDIF2] = ACTIONS(9524),
    [anon_sym_POUNDEndif2] = ACTIONS(9524),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9524),
    [sym_trigger_keyword] = ACTIONS(9524),
    [sym_var_keyword] = ACTIONS(9524),
    [sym_local_keyword] = ACTIONS(9524),
    [sym_internal_keyword] = ACTIONS(9524),
    [sym_protected_keyword] = ACTIONS(9524),
    [sym_event_keyword] = ACTIONS(9524),
    [sym_fields_keyword] = ACTIONS(9524),
    [sym_keys_keyword] = ACTIONS(9524),
    [sym_fieldgroups_keyword] = ACTIONS(9524),
    [sym_actions_keyword] = ACTIONS(9524),
    [sym_layout_keyword] = ACTIONS(9524),
    [sym_area_keyword] = ACTIONS(9524),
    [sym_group_keyword] = ACTIONS(9524),
    [sym_repeater_keyword] = ACTIONS(9524),
    [sym_cuegroup_keyword] = ACTIONS(9524),
    [sym_fixed_keyword] = ACTIONS(9524),
    [sym_grid_keyword] = ACTIONS(9524),
    [sym_part_keyword] = ACTIONS(9524),
    [sym_systempart_keyword] = ACTIONS(9524),
    [sym_usercontrol_keyword] = ACTIONS(9524),
    [sym_dataset_keyword] = ACTIONS(9524),
    [sym_elements_keyword] = ACTIONS(9524),
    [sym_dataitem_keyword] = ACTIONS(9524),
    [sym_column_keyword] = ACTIONS(9524),
    [sym_filter_keyword] = ACTIONS(9524),
    [sym_labels_keyword] = ACTIONS(9524),
    [sym_rendering_keyword] = ACTIONS(9524),
    [sym_requestpage_keyword] = ACTIONS(9524),
    [sym_schema_keyword] = ACTIONS(9524),
    [sym_views_keyword] = ACTIONS(9524),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9524),
    [sym_preproc_open] = ACTIONS(9524),
    [sym_preproc_close] = ACTIONS(9524),
  },
  [STATE(4195)] = {
    [anon_sym_SEMI] = ACTIONS(9528),
    [aux_sym_where_condition_token1] = ACTIONS(9530),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9528),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9528),
    [anon_sym_LBRACK] = ACTIONS(9528),
    [aux_sym_basic_type_token6] = ACTIONS(9530),
    [aux_sym_basic_type_token22] = ACTIONS(9530),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9528),
    [aux_sym_addafter_modification_token1] = ACTIONS(9528),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9528),
    [aux_sym_modify_modification_token1] = ACTIONS(9528),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9528),
    [aux_sym_movelast_modification_token1] = ACTIONS(9528),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9528),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9528),
    [aux_sym_separator_action_token1] = ACTIONS(9528),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9528),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9528),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9528),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9528),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9528),
    [anon_sym_POUNDif] = ACTIONS(9528),
    [anon_sym_POUNDIF] = ACTIONS(9528),
    [anon_sym_POUNDIf] = ACTIONS(9528),
    [anon_sym_POUNDelif] = ACTIONS(9528),
    [anon_sym_POUNDELIF] = ACTIONS(9528),
    [anon_sym_POUNDElif] = ACTIONS(9528),
    [anon_sym_POUNDelse] = ACTIONS(9528),
    [anon_sym_POUNDELSE] = ACTIONS(9528),
    [anon_sym_POUNDElse] = ACTIONS(9528),
    [anon_sym_POUNDelse2] = ACTIONS(9528),
    [anon_sym_POUNDELSE2] = ACTIONS(9528),
    [anon_sym_POUNDElse2] = ACTIONS(9528),
    [anon_sym_POUNDendif] = ACTIONS(9528),
    [anon_sym_POUNDENDIF] = ACTIONS(9528),
    [anon_sym_POUNDEndif] = ACTIONS(9528),
    [anon_sym_POUNDendif2] = ACTIONS(9528),
    [anon_sym_POUNDENDIF2] = ACTIONS(9528),
    [anon_sym_POUNDEndif2] = ACTIONS(9528),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9528),
    [sym_trigger_keyword] = ACTIONS(9528),
    [sym_var_keyword] = ACTIONS(9528),
    [sym_local_keyword] = ACTIONS(9528),
    [sym_internal_keyword] = ACTIONS(9528),
    [sym_protected_keyword] = ACTIONS(9528),
    [sym_event_keyword] = ACTIONS(9528),
    [sym_fields_keyword] = ACTIONS(9528),
    [sym_keys_keyword] = ACTIONS(9528),
    [sym_fieldgroups_keyword] = ACTIONS(9528),
    [sym_actions_keyword] = ACTIONS(9528),
    [sym_layout_keyword] = ACTIONS(9528),
    [sym_area_keyword] = ACTIONS(9528),
    [sym_group_keyword] = ACTIONS(9528),
    [sym_repeater_keyword] = ACTIONS(9528),
    [sym_cuegroup_keyword] = ACTIONS(9528),
    [sym_fixed_keyword] = ACTIONS(9528),
    [sym_grid_keyword] = ACTIONS(9528),
    [sym_part_keyword] = ACTIONS(9528),
    [sym_systempart_keyword] = ACTIONS(9528),
    [sym_usercontrol_keyword] = ACTIONS(9528),
    [sym_dataset_keyword] = ACTIONS(9528),
    [sym_elements_keyword] = ACTIONS(9528),
    [sym_dataitem_keyword] = ACTIONS(9528),
    [sym_column_keyword] = ACTIONS(9528),
    [sym_filter_keyword] = ACTIONS(9528),
    [sym_labels_keyword] = ACTIONS(9528),
    [sym_rendering_keyword] = ACTIONS(9528),
    [sym_requestpage_keyword] = ACTIONS(9528),
    [sym_schema_keyword] = ACTIONS(9528),
    [sym_views_keyword] = ACTIONS(9528),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9528),
    [sym_preproc_open] = ACTIONS(9528),
    [sym_preproc_close] = ACTIONS(9528),
  },
  [STATE(4196)] = {
    [anon_sym_SEMI] = ACTIONS(9532),
    [aux_sym_where_condition_token1] = ACTIONS(9534),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9532),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9532),
    [anon_sym_LBRACK] = ACTIONS(9532),
    [aux_sym_basic_type_token6] = ACTIONS(9534),
    [aux_sym_basic_type_token22] = ACTIONS(9534),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9532),
    [aux_sym_addafter_modification_token1] = ACTIONS(9532),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9532),
    [aux_sym_modify_modification_token1] = ACTIONS(9532),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9532),
    [aux_sym_movelast_modification_token1] = ACTIONS(9532),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9532),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9532),
    [aux_sym_separator_action_token1] = ACTIONS(9532),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9532),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9532),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9532),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9532),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9532),
    [anon_sym_POUNDif] = ACTIONS(9532),
    [anon_sym_POUNDIF] = ACTIONS(9532),
    [anon_sym_POUNDIf] = ACTIONS(9532),
    [anon_sym_POUNDelif] = ACTIONS(9532),
    [anon_sym_POUNDELIF] = ACTIONS(9532),
    [anon_sym_POUNDElif] = ACTIONS(9532),
    [anon_sym_POUNDelse] = ACTIONS(9532),
    [anon_sym_POUNDELSE] = ACTIONS(9532),
    [anon_sym_POUNDElse] = ACTIONS(9532),
    [anon_sym_POUNDelse2] = ACTIONS(9532),
    [anon_sym_POUNDELSE2] = ACTIONS(9532),
    [anon_sym_POUNDElse2] = ACTIONS(9532),
    [anon_sym_POUNDendif] = ACTIONS(9532),
    [anon_sym_POUNDENDIF] = ACTIONS(9532),
    [anon_sym_POUNDEndif] = ACTIONS(9532),
    [anon_sym_POUNDendif2] = ACTIONS(9532),
    [anon_sym_POUNDENDIF2] = ACTIONS(9532),
    [anon_sym_POUNDEndif2] = ACTIONS(9532),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9532),
    [sym_trigger_keyword] = ACTIONS(9532),
    [sym_var_keyword] = ACTIONS(9532),
    [sym_local_keyword] = ACTIONS(9532),
    [sym_internal_keyword] = ACTIONS(9532),
    [sym_protected_keyword] = ACTIONS(9532),
    [sym_event_keyword] = ACTIONS(9532),
    [sym_fields_keyword] = ACTIONS(9532),
    [sym_keys_keyword] = ACTIONS(9532),
    [sym_fieldgroups_keyword] = ACTIONS(9532),
    [sym_actions_keyword] = ACTIONS(9532),
    [sym_layout_keyword] = ACTIONS(9532),
    [sym_area_keyword] = ACTIONS(9532),
    [sym_group_keyword] = ACTIONS(9532),
    [sym_repeater_keyword] = ACTIONS(9532),
    [sym_cuegroup_keyword] = ACTIONS(9532),
    [sym_fixed_keyword] = ACTIONS(9532),
    [sym_grid_keyword] = ACTIONS(9532),
    [sym_part_keyword] = ACTIONS(9532),
    [sym_systempart_keyword] = ACTIONS(9532),
    [sym_usercontrol_keyword] = ACTIONS(9532),
    [sym_dataset_keyword] = ACTIONS(9532),
    [sym_elements_keyword] = ACTIONS(9532),
    [sym_dataitem_keyword] = ACTIONS(9532),
    [sym_column_keyword] = ACTIONS(9532),
    [sym_filter_keyword] = ACTIONS(9532),
    [sym_labels_keyword] = ACTIONS(9532),
    [sym_rendering_keyword] = ACTIONS(9532),
    [sym_requestpage_keyword] = ACTIONS(9532),
    [sym_schema_keyword] = ACTIONS(9532),
    [sym_views_keyword] = ACTIONS(9532),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9532),
    [sym_preproc_open] = ACTIONS(9532),
    [sym_preproc_close] = ACTIONS(9532),
  },
  [STATE(4197)] = {
    [anon_sym_SEMI] = ACTIONS(9536),
    [aux_sym_where_condition_token1] = ACTIONS(9538),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9536),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9536),
    [anon_sym_LBRACK] = ACTIONS(9536),
    [aux_sym_basic_type_token6] = ACTIONS(9538),
    [aux_sym_basic_type_token22] = ACTIONS(9538),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9536),
    [aux_sym_addafter_modification_token1] = ACTIONS(9536),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9536),
    [aux_sym_modify_modification_token1] = ACTIONS(9536),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9536),
    [aux_sym_movelast_modification_token1] = ACTIONS(9536),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9536),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9536),
    [aux_sym_separator_action_token1] = ACTIONS(9536),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9536),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9536),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9536),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9536),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9536),
    [anon_sym_POUNDif] = ACTIONS(9536),
    [anon_sym_POUNDIF] = ACTIONS(9536),
    [anon_sym_POUNDIf] = ACTIONS(9536),
    [anon_sym_POUNDelif] = ACTIONS(9536),
    [anon_sym_POUNDELIF] = ACTIONS(9536),
    [anon_sym_POUNDElif] = ACTIONS(9536),
    [anon_sym_POUNDelse] = ACTIONS(9536),
    [anon_sym_POUNDELSE] = ACTIONS(9536),
    [anon_sym_POUNDElse] = ACTIONS(9536),
    [anon_sym_POUNDelse2] = ACTIONS(9536),
    [anon_sym_POUNDELSE2] = ACTIONS(9536),
    [anon_sym_POUNDElse2] = ACTIONS(9536),
    [anon_sym_POUNDendif] = ACTIONS(9536),
    [anon_sym_POUNDENDIF] = ACTIONS(9536),
    [anon_sym_POUNDEndif] = ACTIONS(9536),
    [anon_sym_POUNDendif2] = ACTIONS(9536),
    [anon_sym_POUNDENDIF2] = ACTIONS(9536),
    [anon_sym_POUNDEndif2] = ACTIONS(9536),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9536),
    [sym_trigger_keyword] = ACTIONS(9536),
    [sym_var_keyword] = ACTIONS(9536),
    [sym_local_keyword] = ACTIONS(9536),
    [sym_internal_keyword] = ACTIONS(9536),
    [sym_protected_keyword] = ACTIONS(9536),
    [sym_event_keyword] = ACTIONS(9536),
    [sym_fields_keyword] = ACTIONS(9536),
    [sym_keys_keyword] = ACTIONS(9536),
    [sym_fieldgroups_keyword] = ACTIONS(9536),
    [sym_actions_keyword] = ACTIONS(9536),
    [sym_layout_keyword] = ACTIONS(9536),
    [sym_area_keyword] = ACTIONS(9536),
    [sym_group_keyword] = ACTIONS(9536),
    [sym_repeater_keyword] = ACTIONS(9536),
    [sym_cuegroup_keyword] = ACTIONS(9536),
    [sym_fixed_keyword] = ACTIONS(9536),
    [sym_grid_keyword] = ACTIONS(9536),
    [sym_part_keyword] = ACTIONS(9536),
    [sym_systempart_keyword] = ACTIONS(9536),
    [sym_usercontrol_keyword] = ACTIONS(9536),
    [sym_dataset_keyword] = ACTIONS(9536),
    [sym_elements_keyword] = ACTIONS(9536),
    [sym_dataitem_keyword] = ACTIONS(9536),
    [sym_column_keyword] = ACTIONS(9536),
    [sym_filter_keyword] = ACTIONS(9536),
    [sym_labels_keyword] = ACTIONS(9536),
    [sym_rendering_keyword] = ACTIONS(9536),
    [sym_requestpage_keyword] = ACTIONS(9536),
    [sym_schema_keyword] = ACTIONS(9536),
    [sym_views_keyword] = ACTIONS(9536),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9536),
    [sym_preproc_open] = ACTIONS(9536),
    [sym_preproc_close] = ACTIONS(9536),
  },
  [STATE(4198)] = {
    [anon_sym_SEMI] = ACTIONS(9540),
    [aux_sym_where_condition_token1] = ACTIONS(9542),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9540),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9540),
    [anon_sym_LBRACK] = ACTIONS(9540),
    [aux_sym_basic_type_token6] = ACTIONS(9542),
    [aux_sym_basic_type_token22] = ACTIONS(9542),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9540),
    [aux_sym_addafter_modification_token1] = ACTIONS(9540),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9540),
    [aux_sym_modify_modification_token1] = ACTIONS(9540),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9540),
    [aux_sym_movelast_modification_token1] = ACTIONS(9540),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9540),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9540),
    [aux_sym_separator_action_token1] = ACTIONS(9540),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9540),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9540),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9540),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9540),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9540),
    [anon_sym_POUNDif] = ACTIONS(9540),
    [anon_sym_POUNDIF] = ACTIONS(9540),
    [anon_sym_POUNDIf] = ACTIONS(9540),
    [anon_sym_POUNDelif] = ACTIONS(9540),
    [anon_sym_POUNDELIF] = ACTIONS(9540),
    [anon_sym_POUNDElif] = ACTIONS(9540),
    [anon_sym_POUNDelse] = ACTIONS(9540),
    [anon_sym_POUNDELSE] = ACTIONS(9540),
    [anon_sym_POUNDElse] = ACTIONS(9540),
    [anon_sym_POUNDelse2] = ACTIONS(9540),
    [anon_sym_POUNDELSE2] = ACTIONS(9540),
    [anon_sym_POUNDElse2] = ACTIONS(9540),
    [anon_sym_POUNDendif] = ACTIONS(9540),
    [anon_sym_POUNDENDIF] = ACTIONS(9540),
    [anon_sym_POUNDEndif] = ACTIONS(9540),
    [anon_sym_POUNDendif2] = ACTIONS(9540),
    [anon_sym_POUNDENDIF2] = ACTIONS(9540),
    [anon_sym_POUNDEndif2] = ACTIONS(9540),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9540),
    [sym_trigger_keyword] = ACTIONS(9540),
    [sym_var_keyword] = ACTIONS(9540),
    [sym_local_keyword] = ACTIONS(9540),
    [sym_internal_keyword] = ACTIONS(9540),
    [sym_protected_keyword] = ACTIONS(9540),
    [sym_event_keyword] = ACTIONS(9540),
    [sym_fields_keyword] = ACTIONS(9540),
    [sym_keys_keyword] = ACTIONS(9540),
    [sym_fieldgroups_keyword] = ACTIONS(9540),
    [sym_actions_keyword] = ACTIONS(9540),
    [sym_layout_keyword] = ACTIONS(9540),
    [sym_area_keyword] = ACTIONS(9540),
    [sym_group_keyword] = ACTIONS(9540),
    [sym_repeater_keyword] = ACTIONS(9540),
    [sym_cuegroup_keyword] = ACTIONS(9540),
    [sym_fixed_keyword] = ACTIONS(9540),
    [sym_grid_keyword] = ACTIONS(9540),
    [sym_part_keyword] = ACTIONS(9540),
    [sym_systempart_keyword] = ACTIONS(9540),
    [sym_usercontrol_keyword] = ACTIONS(9540),
    [sym_dataset_keyword] = ACTIONS(9540),
    [sym_elements_keyword] = ACTIONS(9540),
    [sym_dataitem_keyword] = ACTIONS(9540),
    [sym_column_keyword] = ACTIONS(9540),
    [sym_filter_keyword] = ACTIONS(9540),
    [sym_labels_keyword] = ACTIONS(9540),
    [sym_rendering_keyword] = ACTIONS(9540),
    [sym_requestpage_keyword] = ACTIONS(9540),
    [sym_schema_keyword] = ACTIONS(9540),
    [sym_views_keyword] = ACTIONS(9540),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9540),
    [sym_preproc_open] = ACTIONS(9540),
    [sym_preproc_close] = ACTIONS(9540),
  },
  [STATE(4199)] = {
    [anon_sym_SEMI] = ACTIONS(9544),
    [aux_sym_where_condition_token1] = ACTIONS(9546),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9544),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9544),
    [anon_sym_LBRACK] = ACTIONS(9544),
    [aux_sym_basic_type_token6] = ACTIONS(9546),
    [aux_sym_basic_type_token22] = ACTIONS(9546),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9544),
    [aux_sym_addafter_modification_token1] = ACTIONS(9544),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9544),
    [aux_sym_modify_modification_token1] = ACTIONS(9544),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9544),
    [aux_sym_movelast_modification_token1] = ACTIONS(9544),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9544),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9544),
    [aux_sym_separator_action_token1] = ACTIONS(9544),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9544),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9544),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9544),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9544),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9544),
    [anon_sym_POUNDif] = ACTIONS(9544),
    [anon_sym_POUNDIF] = ACTIONS(9544),
    [anon_sym_POUNDIf] = ACTIONS(9544),
    [anon_sym_POUNDelif] = ACTIONS(9544),
    [anon_sym_POUNDELIF] = ACTIONS(9544),
    [anon_sym_POUNDElif] = ACTIONS(9544),
    [anon_sym_POUNDelse] = ACTIONS(9544),
    [anon_sym_POUNDELSE] = ACTIONS(9544),
    [anon_sym_POUNDElse] = ACTIONS(9544),
    [anon_sym_POUNDelse2] = ACTIONS(9544),
    [anon_sym_POUNDELSE2] = ACTIONS(9544),
    [anon_sym_POUNDElse2] = ACTIONS(9544),
    [anon_sym_POUNDendif] = ACTIONS(9544),
    [anon_sym_POUNDENDIF] = ACTIONS(9544),
    [anon_sym_POUNDEndif] = ACTIONS(9544),
    [anon_sym_POUNDendif2] = ACTIONS(9544),
    [anon_sym_POUNDENDIF2] = ACTIONS(9544),
    [anon_sym_POUNDEndif2] = ACTIONS(9544),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9544),
    [sym_trigger_keyword] = ACTIONS(9544),
    [sym_var_keyword] = ACTIONS(9544),
    [sym_local_keyword] = ACTIONS(9544),
    [sym_internal_keyword] = ACTIONS(9544),
    [sym_protected_keyword] = ACTIONS(9544),
    [sym_event_keyword] = ACTIONS(9544),
    [sym_fields_keyword] = ACTIONS(9544),
    [sym_keys_keyword] = ACTIONS(9544),
    [sym_fieldgroups_keyword] = ACTIONS(9544),
    [sym_actions_keyword] = ACTIONS(9544),
    [sym_layout_keyword] = ACTIONS(9544),
    [sym_area_keyword] = ACTIONS(9544),
    [sym_group_keyword] = ACTIONS(9544),
    [sym_repeater_keyword] = ACTIONS(9544),
    [sym_cuegroup_keyword] = ACTIONS(9544),
    [sym_fixed_keyword] = ACTIONS(9544),
    [sym_grid_keyword] = ACTIONS(9544),
    [sym_part_keyword] = ACTIONS(9544),
    [sym_systempart_keyword] = ACTIONS(9544),
    [sym_usercontrol_keyword] = ACTIONS(9544),
    [sym_dataset_keyword] = ACTIONS(9544),
    [sym_elements_keyword] = ACTIONS(9544),
    [sym_dataitem_keyword] = ACTIONS(9544),
    [sym_column_keyword] = ACTIONS(9544),
    [sym_filter_keyword] = ACTIONS(9544),
    [sym_labels_keyword] = ACTIONS(9544),
    [sym_rendering_keyword] = ACTIONS(9544),
    [sym_requestpage_keyword] = ACTIONS(9544),
    [sym_schema_keyword] = ACTIONS(9544),
    [sym_views_keyword] = ACTIONS(9544),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9544),
    [sym_preproc_open] = ACTIONS(9544),
    [sym_preproc_close] = ACTIONS(9544),
  },
  [STATE(4200)] = {
    [anon_sym_SEMI] = ACTIONS(9508),
    [aux_sym_where_condition_token1] = ACTIONS(9510),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9508),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9508),
    [anon_sym_LBRACK] = ACTIONS(9508),
    [aux_sym_basic_type_token6] = ACTIONS(9510),
    [aux_sym_basic_type_token22] = ACTIONS(9510),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9508),
    [aux_sym_addafter_modification_token1] = ACTIONS(9508),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9508),
    [aux_sym_modify_modification_token1] = ACTIONS(9508),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9508),
    [aux_sym_movelast_modification_token1] = ACTIONS(9508),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9508),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9508),
    [aux_sym_separator_action_token1] = ACTIONS(9508),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9508),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9508),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9508),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9508),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9508),
    [anon_sym_POUNDif] = ACTIONS(9508),
    [anon_sym_POUNDIF] = ACTIONS(9508),
    [anon_sym_POUNDIf] = ACTIONS(9508),
    [anon_sym_POUNDelif] = ACTIONS(9508),
    [anon_sym_POUNDELIF] = ACTIONS(9508),
    [anon_sym_POUNDElif] = ACTIONS(9508),
    [anon_sym_POUNDelse] = ACTIONS(9508),
    [anon_sym_POUNDELSE] = ACTIONS(9508),
    [anon_sym_POUNDElse] = ACTIONS(9508),
    [anon_sym_POUNDelse2] = ACTIONS(9508),
    [anon_sym_POUNDELSE2] = ACTIONS(9508),
    [anon_sym_POUNDElse2] = ACTIONS(9508),
    [anon_sym_POUNDendif] = ACTIONS(9508),
    [anon_sym_POUNDENDIF] = ACTIONS(9508),
    [anon_sym_POUNDEndif] = ACTIONS(9508),
    [anon_sym_POUNDendif2] = ACTIONS(9508),
    [anon_sym_POUNDENDIF2] = ACTIONS(9508),
    [anon_sym_POUNDEndif2] = ACTIONS(9508),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9508),
    [sym_trigger_keyword] = ACTIONS(9508),
    [sym_var_keyword] = ACTIONS(9508),
    [sym_local_keyword] = ACTIONS(9508),
    [sym_internal_keyword] = ACTIONS(9508),
    [sym_protected_keyword] = ACTIONS(9508),
    [sym_event_keyword] = ACTIONS(9508),
    [sym_fields_keyword] = ACTIONS(9508),
    [sym_keys_keyword] = ACTIONS(9508),
    [sym_fieldgroups_keyword] = ACTIONS(9508),
    [sym_actions_keyword] = ACTIONS(9508),
    [sym_layout_keyword] = ACTIONS(9508),
    [sym_area_keyword] = ACTIONS(9508),
    [sym_group_keyword] = ACTIONS(9508),
    [sym_repeater_keyword] = ACTIONS(9508),
    [sym_cuegroup_keyword] = ACTIONS(9508),
    [sym_fixed_keyword] = ACTIONS(9508),
    [sym_grid_keyword] = ACTIONS(9508),
    [sym_part_keyword] = ACTIONS(9508),
    [sym_systempart_keyword] = ACTIONS(9508),
    [sym_usercontrol_keyword] = ACTIONS(9508),
    [sym_dataset_keyword] = ACTIONS(9508),
    [sym_elements_keyword] = ACTIONS(9508),
    [sym_dataitem_keyword] = ACTIONS(9508),
    [sym_column_keyword] = ACTIONS(9508),
    [sym_filter_keyword] = ACTIONS(9508),
    [sym_labels_keyword] = ACTIONS(9508),
    [sym_rendering_keyword] = ACTIONS(9508),
    [sym_requestpage_keyword] = ACTIONS(9508),
    [sym_schema_keyword] = ACTIONS(9508),
    [sym_views_keyword] = ACTIONS(9508),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9508),
    [sym_preproc_open] = ACTIONS(9508),
    [sym_preproc_close] = ACTIONS(9508),
  },
  [STATE(4201)] = {
    [anon_sym_SEMI] = ACTIONS(9548),
    [aux_sym_where_condition_token1] = ACTIONS(9550),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9548),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9548),
    [anon_sym_LBRACK] = ACTIONS(9548),
    [aux_sym_basic_type_token6] = ACTIONS(9550),
    [aux_sym_basic_type_token22] = ACTIONS(9550),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9548),
    [aux_sym_addafter_modification_token1] = ACTIONS(9548),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9548),
    [aux_sym_modify_modification_token1] = ACTIONS(9548),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9548),
    [aux_sym_movelast_modification_token1] = ACTIONS(9548),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9548),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9548),
    [aux_sym_separator_action_token1] = ACTIONS(9548),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9548),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9548),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9548),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9548),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9548),
    [anon_sym_POUNDif] = ACTIONS(9548),
    [anon_sym_POUNDIF] = ACTIONS(9548),
    [anon_sym_POUNDIf] = ACTIONS(9548),
    [anon_sym_POUNDelif] = ACTIONS(9548),
    [anon_sym_POUNDELIF] = ACTIONS(9548),
    [anon_sym_POUNDElif] = ACTIONS(9548),
    [anon_sym_POUNDelse] = ACTIONS(9548),
    [anon_sym_POUNDELSE] = ACTIONS(9548),
    [anon_sym_POUNDElse] = ACTIONS(9548),
    [anon_sym_POUNDelse2] = ACTIONS(9548),
    [anon_sym_POUNDELSE2] = ACTIONS(9548),
    [anon_sym_POUNDElse2] = ACTIONS(9548),
    [anon_sym_POUNDendif] = ACTIONS(9548),
    [anon_sym_POUNDENDIF] = ACTIONS(9548),
    [anon_sym_POUNDEndif] = ACTIONS(9548),
    [anon_sym_POUNDendif2] = ACTIONS(9548),
    [anon_sym_POUNDENDIF2] = ACTIONS(9548),
    [anon_sym_POUNDEndif2] = ACTIONS(9548),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9548),
    [sym_trigger_keyword] = ACTIONS(9548),
    [sym_var_keyword] = ACTIONS(9548),
    [sym_local_keyword] = ACTIONS(9548),
    [sym_internal_keyword] = ACTIONS(9548),
    [sym_protected_keyword] = ACTIONS(9548),
    [sym_event_keyword] = ACTIONS(9548),
    [sym_fields_keyword] = ACTIONS(9548),
    [sym_keys_keyword] = ACTIONS(9548),
    [sym_fieldgroups_keyword] = ACTIONS(9548),
    [sym_actions_keyword] = ACTIONS(9548),
    [sym_layout_keyword] = ACTIONS(9548),
    [sym_area_keyword] = ACTIONS(9548),
    [sym_group_keyword] = ACTIONS(9548),
    [sym_repeater_keyword] = ACTIONS(9548),
    [sym_cuegroup_keyword] = ACTIONS(9548),
    [sym_fixed_keyword] = ACTIONS(9548),
    [sym_grid_keyword] = ACTIONS(9548),
    [sym_part_keyword] = ACTIONS(9548),
    [sym_systempart_keyword] = ACTIONS(9548),
    [sym_usercontrol_keyword] = ACTIONS(9548),
    [sym_dataset_keyword] = ACTIONS(9548),
    [sym_elements_keyword] = ACTIONS(9548),
    [sym_dataitem_keyword] = ACTIONS(9548),
    [sym_column_keyword] = ACTIONS(9548),
    [sym_filter_keyword] = ACTIONS(9548),
    [sym_labels_keyword] = ACTIONS(9548),
    [sym_rendering_keyword] = ACTIONS(9548),
    [sym_requestpage_keyword] = ACTIONS(9548),
    [sym_schema_keyword] = ACTIONS(9548),
    [sym_views_keyword] = ACTIONS(9548),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9548),
    [sym_preproc_open] = ACTIONS(9548),
    [sym_preproc_close] = ACTIONS(9548),
  },
  [STATE(4202)] = {
    [anon_sym_SEMI] = ACTIONS(9552),
    [aux_sym_where_condition_token1] = ACTIONS(9554),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9552),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9552),
    [anon_sym_LBRACK] = ACTIONS(9552),
    [aux_sym_basic_type_token6] = ACTIONS(9554),
    [aux_sym_basic_type_token22] = ACTIONS(9554),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9552),
    [aux_sym_addafter_modification_token1] = ACTIONS(9552),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9552),
    [aux_sym_modify_modification_token1] = ACTIONS(9552),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9552),
    [aux_sym_movelast_modification_token1] = ACTIONS(9552),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9552),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9552),
    [aux_sym_separator_action_token1] = ACTIONS(9552),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9552),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9552),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9552),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9552),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9552),
    [anon_sym_POUNDif] = ACTIONS(9552),
    [anon_sym_POUNDIF] = ACTIONS(9552),
    [anon_sym_POUNDIf] = ACTIONS(9552),
    [anon_sym_POUNDelif] = ACTIONS(9552),
    [anon_sym_POUNDELIF] = ACTIONS(9552),
    [anon_sym_POUNDElif] = ACTIONS(9552),
    [anon_sym_POUNDelse] = ACTIONS(9552),
    [anon_sym_POUNDELSE] = ACTIONS(9552),
    [anon_sym_POUNDElse] = ACTIONS(9552),
    [anon_sym_POUNDelse2] = ACTIONS(9552),
    [anon_sym_POUNDELSE2] = ACTIONS(9552),
    [anon_sym_POUNDElse2] = ACTIONS(9552),
    [anon_sym_POUNDendif] = ACTIONS(9552),
    [anon_sym_POUNDENDIF] = ACTIONS(9552),
    [anon_sym_POUNDEndif] = ACTIONS(9552),
    [anon_sym_POUNDendif2] = ACTIONS(9552),
    [anon_sym_POUNDENDIF2] = ACTIONS(9552),
    [anon_sym_POUNDEndif2] = ACTIONS(9552),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9552),
    [sym_trigger_keyword] = ACTIONS(9552),
    [sym_var_keyword] = ACTIONS(9552),
    [sym_local_keyword] = ACTIONS(9552),
    [sym_internal_keyword] = ACTIONS(9552),
    [sym_protected_keyword] = ACTIONS(9552),
    [sym_event_keyword] = ACTIONS(9552),
    [sym_fields_keyword] = ACTIONS(9552),
    [sym_keys_keyword] = ACTIONS(9552),
    [sym_fieldgroups_keyword] = ACTIONS(9552),
    [sym_actions_keyword] = ACTIONS(9552),
    [sym_layout_keyword] = ACTIONS(9552),
    [sym_area_keyword] = ACTIONS(9552),
    [sym_group_keyword] = ACTIONS(9552),
    [sym_repeater_keyword] = ACTIONS(9552),
    [sym_cuegroup_keyword] = ACTIONS(9552),
    [sym_fixed_keyword] = ACTIONS(9552),
    [sym_grid_keyword] = ACTIONS(9552),
    [sym_part_keyword] = ACTIONS(9552),
    [sym_systempart_keyword] = ACTIONS(9552),
    [sym_usercontrol_keyword] = ACTIONS(9552),
    [sym_dataset_keyword] = ACTIONS(9552),
    [sym_elements_keyword] = ACTIONS(9552),
    [sym_dataitem_keyword] = ACTIONS(9552),
    [sym_column_keyword] = ACTIONS(9552),
    [sym_filter_keyword] = ACTIONS(9552),
    [sym_labels_keyword] = ACTIONS(9552),
    [sym_rendering_keyword] = ACTIONS(9552),
    [sym_requestpage_keyword] = ACTIONS(9552),
    [sym_schema_keyword] = ACTIONS(9552),
    [sym_views_keyword] = ACTIONS(9552),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9552),
    [sym_preproc_open] = ACTIONS(9552),
    [sym_preproc_close] = ACTIONS(9552),
  },
  [STATE(4203)] = {
    [anon_sym_SEMI] = ACTIONS(9556),
    [aux_sym_where_condition_token1] = ACTIONS(9558),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9556),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9556),
    [anon_sym_LBRACK] = ACTIONS(9556),
    [aux_sym_basic_type_token6] = ACTIONS(9558),
    [aux_sym_basic_type_token22] = ACTIONS(9558),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9556),
    [aux_sym_addafter_modification_token1] = ACTIONS(9556),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9556),
    [aux_sym_modify_modification_token1] = ACTIONS(9556),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9556),
    [aux_sym_movelast_modification_token1] = ACTIONS(9556),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9556),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9556),
    [aux_sym_separator_action_token1] = ACTIONS(9556),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9556),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9556),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9556),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9556),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9556),
    [anon_sym_POUNDif] = ACTIONS(9556),
    [anon_sym_POUNDIF] = ACTIONS(9556),
    [anon_sym_POUNDIf] = ACTIONS(9556),
    [anon_sym_POUNDelif] = ACTIONS(9556),
    [anon_sym_POUNDELIF] = ACTIONS(9556),
    [anon_sym_POUNDElif] = ACTIONS(9556),
    [anon_sym_POUNDelse] = ACTIONS(9556),
    [anon_sym_POUNDELSE] = ACTIONS(9556),
    [anon_sym_POUNDElse] = ACTIONS(9556),
    [anon_sym_POUNDelse2] = ACTIONS(9556),
    [anon_sym_POUNDELSE2] = ACTIONS(9556),
    [anon_sym_POUNDElse2] = ACTIONS(9556),
    [anon_sym_POUNDendif] = ACTIONS(9556),
    [anon_sym_POUNDENDIF] = ACTIONS(9556),
    [anon_sym_POUNDEndif] = ACTIONS(9556),
    [anon_sym_POUNDendif2] = ACTIONS(9556),
    [anon_sym_POUNDENDIF2] = ACTIONS(9556),
    [anon_sym_POUNDEndif2] = ACTIONS(9556),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9556),
    [sym_trigger_keyword] = ACTIONS(9556),
    [sym_var_keyword] = ACTIONS(9556),
    [sym_local_keyword] = ACTIONS(9556),
    [sym_internal_keyword] = ACTIONS(9556),
    [sym_protected_keyword] = ACTIONS(9556),
    [sym_event_keyword] = ACTIONS(9556),
    [sym_fields_keyword] = ACTIONS(9556),
    [sym_keys_keyword] = ACTIONS(9556),
    [sym_fieldgroups_keyword] = ACTIONS(9556),
    [sym_actions_keyword] = ACTIONS(9556),
    [sym_layout_keyword] = ACTIONS(9556),
    [sym_area_keyword] = ACTIONS(9556),
    [sym_group_keyword] = ACTIONS(9556),
    [sym_repeater_keyword] = ACTIONS(9556),
    [sym_cuegroup_keyword] = ACTIONS(9556),
    [sym_fixed_keyword] = ACTIONS(9556),
    [sym_grid_keyword] = ACTIONS(9556),
    [sym_part_keyword] = ACTIONS(9556),
    [sym_systempart_keyword] = ACTIONS(9556),
    [sym_usercontrol_keyword] = ACTIONS(9556),
    [sym_dataset_keyword] = ACTIONS(9556),
    [sym_elements_keyword] = ACTIONS(9556),
    [sym_dataitem_keyword] = ACTIONS(9556),
    [sym_column_keyword] = ACTIONS(9556),
    [sym_filter_keyword] = ACTIONS(9556),
    [sym_labels_keyword] = ACTIONS(9556),
    [sym_rendering_keyword] = ACTIONS(9556),
    [sym_requestpage_keyword] = ACTIONS(9556),
    [sym_schema_keyword] = ACTIONS(9556),
    [sym_views_keyword] = ACTIONS(9556),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9556),
    [sym_preproc_open] = ACTIONS(9556),
    [sym_preproc_close] = ACTIONS(9556),
  },
  [STATE(4204)] = {
    [anon_sym_SEMI] = ACTIONS(9560),
    [aux_sym_where_condition_token1] = ACTIONS(9562),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9560),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9560),
    [anon_sym_LBRACK] = ACTIONS(9560),
    [aux_sym_basic_type_token6] = ACTIONS(9562),
    [aux_sym_basic_type_token22] = ACTIONS(9562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9560),
    [aux_sym_addafter_modification_token1] = ACTIONS(9560),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9560),
    [aux_sym_modify_modification_token1] = ACTIONS(9560),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9560),
    [aux_sym_movelast_modification_token1] = ACTIONS(9560),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9560),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9560),
    [aux_sym_separator_action_token1] = ACTIONS(9560),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9560),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9560),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9560),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9560),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9560),
    [anon_sym_POUNDif] = ACTIONS(9560),
    [anon_sym_POUNDIF] = ACTIONS(9560),
    [anon_sym_POUNDIf] = ACTIONS(9560),
    [anon_sym_POUNDelif] = ACTIONS(9560),
    [anon_sym_POUNDELIF] = ACTIONS(9560),
    [anon_sym_POUNDElif] = ACTIONS(9560),
    [anon_sym_POUNDelse] = ACTIONS(9560),
    [anon_sym_POUNDELSE] = ACTIONS(9560),
    [anon_sym_POUNDElse] = ACTIONS(9560),
    [anon_sym_POUNDelse2] = ACTIONS(9560),
    [anon_sym_POUNDELSE2] = ACTIONS(9560),
    [anon_sym_POUNDElse2] = ACTIONS(9560),
    [anon_sym_POUNDendif] = ACTIONS(9560),
    [anon_sym_POUNDENDIF] = ACTIONS(9560),
    [anon_sym_POUNDEndif] = ACTIONS(9560),
    [anon_sym_POUNDendif2] = ACTIONS(9560),
    [anon_sym_POUNDENDIF2] = ACTIONS(9560),
    [anon_sym_POUNDEndif2] = ACTIONS(9560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9560),
    [sym_trigger_keyword] = ACTIONS(9560),
    [sym_var_keyword] = ACTIONS(9560),
    [sym_local_keyword] = ACTIONS(9560),
    [sym_internal_keyword] = ACTIONS(9560),
    [sym_protected_keyword] = ACTIONS(9560),
    [sym_event_keyword] = ACTIONS(9560),
    [sym_fields_keyword] = ACTIONS(9560),
    [sym_keys_keyword] = ACTIONS(9560),
    [sym_fieldgroups_keyword] = ACTIONS(9560),
    [sym_actions_keyword] = ACTIONS(9560),
    [sym_layout_keyword] = ACTIONS(9560),
    [sym_area_keyword] = ACTIONS(9560),
    [sym_group_keyword] = ACTIONS(9560),
    [sym_repeater_keyword] = ACTIONS(9560),
    [sym_cuegroup_keyword] = ACTIONS(9560),
    [sym_fixed_keyword] = ACTIONS(9560),
    [sym_grid_keyword] = ACTIONS(9560),
    [sym_part_keyword] = ACTIONS(9560),
    [sym_systempart_keyword] = ACTIONS(9560),
    [sym_usercontrol_keyword] = ACTIONS(9560),
    [sym_dataset_keyword] = ACTIONS(9560),
    [sym_elements_keyword] = ACTIONS(9560),
    [sym_dataitem_keyword] = ACTIONS(9560),
    [sym_column_keyword] = ACTIONS(9560),
    [sym_filter_keyword] = ACTIONS(9560),
    [sym_labels_keyword] = ACTIONS(9560),
    [sym_rendering_keyword] = ACTIONS(9560),
    [sym_requestpage_keyword] = ACTIONS(9560),
    [sym_schema_keyword] = ACTIONS(9560),
    [sym_views_keyword] = ACTIONS(9560),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9560),
    [sym_preproc_open] = ACTIONS(9560),
    [sym_preproc_close] = ACTIONS(9560),
  },
  [STATE(4205)] = {
    [anon_sym_SEMI] = ACTIONS(9564),
    [aux_sym_where_condition_token1] = ACTIONS(9566),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9564),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9564),
    [anon_sym_LBRACK] = ACTIONS(9564),
    [aux_sym_basic_type_token6] = ACTIONS(9566),
    [aux_sym_basic_type_token22] = ACTIONS(9566),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9564),
    [aux_sym_addafter_modification_token1] = ACTIONS(9564),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9564),
    [aux_sym_modify_modification_token1] = ACTIONS(9564),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9564),
    [aux_sym_movelast_modification_token1] = ACTIONS(9564),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9564),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9564),
    [aux_sym_separator_action_token1] = ACTIONS(9564),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9564),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9564),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9564),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9564),
    [anon_sym_POUNDif] = ACTIONS(9564),
    [anon_sym_POUNDIF] = ACTIONS(9564),
    [anon_sym_POUNDIf] = ACTIONS(9564),
    [anon_sym_POUNDelif] = ACTIONS(9564),
    [anon_sym_POUNDELIF] = ACTIONS(9564),
    [anon_sym_POUNDElif] = ACTIONS(9564),
    [anon_sym_POUNDelse] = ACTIONS(9564),
    [anon_sym_POUNDELSE] = ACTIONS(9564),
    [anon_sym_POUNDElse] = ACTIONS(9564),
    [anon_sym_POUNDelse2] = ACTIONS(9564),
    [anon_sym_POUNDELSE2] = ACTIONS(9564),
    [anon_sym_POUNDElse2] = ACTIONS(9564),
    [anon_sym_POUNDendif] = ACTIONS(9564),
    [anon_sym_POUNDENDIF] = ACTIONS(9564),
    [anon_sym_POUNDEndif] = ACTIONS(9564),
    [anon_sym_POUNDendif2] = ACTIONS(9564),
    [anon_sym_POUNDENDIF2] = ACTIONS(9564),
    [anon_sym_POUNDEndif2] = ACTIONS(9564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9564),
    [sym_trigger_keyword] = ACTIONS(9564),
    [sym_var_keyword] = ACTIONS(9564),
    [sym_local_keyword] = ACTIONS(9564),
    [sym_internal_keyword] = ACTIONS(9564),
    [sym_protected_keyword] = ACTIONS(9564),
    [sym_event_keyword] = ACTIONS(9564),
    [sym_fields_keyword] = ACTIONS(9564),
    [sym_keys_keyword] = ACTIONS(9564),
    [sym_fieldgroups_keyword] = ACTIONS(9564),
    [sym_actions_keyword] = ACTIONS(9564),
    [sym_layout_keyword] = ACTIONS(9564),
    [sym_area_keyword] = ACTIONS(9564),
    [sym_group_keyword] = ACTIONS(9564),
    [sym_repeater_keyword] = ACTIONS(9564),
    [sym_cuegroup_keyword] = ACTIONS(9564),
    [sym_fixed_keyword] = ACTIONS(9564),
    [sym_grid_keyword] = ACTIONS(9564),
    [sym_part_keyword] = ACTIONS(9564),
    [sym_systempart_keyword] = ACTIONS(9564),
    [sym_usercontrol_keyword] = ACTIONS(9564),
    [sym_dataset_keyword] = ACTIONS(9564),
    [sym_elements_keyword] = ACTIONS(9564),
    [sym_dataitem_keyword] = ACTIONS(9564),
    [sym_column_keyword] = ACTIONS(9564),
    [sym_filter_keyword] = ACTIONS(9564),
    [sym_labels_keyword] = ACTIONS(9564),
    [sym_rendering_keyword] = ACTIONS(9564),
    [sym_requestpage_keyword] = ACTIONS(9564),
    [sym_schema_keyword] = ACTIONS(9564),
    [sym_views_keyword] = ACTIONS(9564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9564),
    [sym_preproc_open] = ACTIONS(9564),
    [sym_preproc_close] = ACTIONS(9564),
  },
  [STATE(4206)] = {
    [anon_sym_SEMI] = ACTIONS(9560),
    [aux_sym_where_condition_token1] = ACTIONS(9562),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9560),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9560),
    [anon_sym_LBRACK] = ACTIONS(9560),
    [aux_sym_basic_type_token6] = ACTIONS(9562),
    [aux_sym_basic_type_token22] = ACTIONS(9562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9560),
    [aux_sym_addafter_modification_token1] = ACTIONS(9560),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9560),
    [aux_sym_modify_modification_token1] = ACTIONS(9560),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9560),
    [aux_sym_movelast_modification_token1] = ACTIONS(9560),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9560),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9560),
    [aux_sym_separator_action_token1] = ACTIONS(9560),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9560),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9560),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9560),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9560),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9560),
    [anon_sym_POUNDif] = ACTIONS(9560),
    [anon_sym_POUNDIF] = ACTIONS(9560),
    [anon_sym_POUNDIf] = ACTIONS(9560),
    [anon_sym_POUNDelif] = ACTIONS(9560),
    [anon_sym_POUNDELIF] = ACTIONS(9560),
    [anon_sym_POUNDElif] = ACTIONS(9560),
    [anon_sym_POUNDelse] = ACTIONS(9560),
    [anon_sym_POUNDELSE] = ACTIONS(9560),
    [anon_sym_POUNDElse] = ACTIONS(9560),
    [anon_sym_POUNDelse2] = ACTIONS(9560),
    [anon_sym_POUNDELSE2] = ACTIONS(9560),
    [anon_sym_POUNDElse2] = ACTIONS(9560),
    [anon_sym_POUNDendif] = ACTIONS(9560),
    [anon_sym_POUNDENDIF] = ACTIONS(9560),
    [anon_sym_POUNDEndif] = ACTIONS(9560),
    [anon_sym_POUNDendif2] = ACTIONS(9560),
    [anon_sym_POUNDENDIF2] = ACTIONS(9560),
    [anon_sym_POUNDEndif2] = ACTIONS(9560),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9560),
    [sym_trigger_keyword] = ACTIONS(9560),
    [sym_var_keyword] = ACTIONS(9560),
    [sym_local_keyword] = ACTIONS(9560),
    [sym_internal_keyword] = ACTIONS(9560),
    [sym_protected_keyword] = ACTIONS(9560),
    [sym_event_keyword] = ACTIONS(9560),
    [sym_fields_keyword] = ACTIONS(9560),
    [sym_keys_keyword] = ACTIONS(9560),
    [sym_fieldgroups_keyword] = ACTIONS(9560),
    [sym_actions_keyword] = ACTIONS(9560),
    [sym_layout_keyword] = ACTIONS(9560),
    [sym_area_keyword] = ACTIONS(9560),
    [sym_group_keyword] = ACTIONS(9560),
    [sym_repeater_keyword] = ACTIONS(9560),
    [sym_cuegroup_keyword] = ACTIONS(9560),
    [sym_fixed_keyword] = ACTIONS(9560),
    [sym_grid_keyword] = ACTIONS(9560),
    [sym_part_keyword] = ACTIONS(9560),
    [sym_systempart_keyword] = ACTIONS(9560),
    [sym_usercontrol_keyword] = ACTIONS(9560),
    [sym_dataset_keyword] = ACTIONS(9560),
    [sym_elements_keyword] = ACTIONS(9560),
    [sym_dataitem_keyword] = ACTIONS(9560),
    [sym_column_keyword] = ACTIONS(9560),
    [sym_filter_keyword] = ACTIONS(9560),
    [sym_labels_keyword] = ACTIONS(9560),
    [sym_rendering_keyword] = ACTIONS(9560),
    [sym_requestpage_keyword] = ACTIONS(9560),
    [sym_schema_keyword] = ACTIONS(9560),
    [sym_views_keyword] = ACTIONS(9560),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9560),
    [sym_preproc_open] = ACTIONS(9560),
    [sym_preproc_close] = ACTIONS(9560),
  },
  [STATE(4207)] = {
    [anon_sym_SEMI] = ACTIONS(9548),
    [aux_sym_where_condition_token1] = ACTIONS(9550),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9548),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9548),
    [anon_sym_LBRACK] = ACTIONS(9548),
    [aux_sym_basic_type_token6] = ACTIONS(9550),
    [aux_sym_basic_type_token22] = ACTIONS(9550),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9548),
    [aux_sym_addafter_modification_token1] = ACTIONS(9548),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9548),
    [aux_sym_modify_modification_token1] = ACTIONS(9548),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9548),
    [aux_sym_movelast_modification_token1] = ACTIONS(9548),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9548),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9548),
    [aux_sym_separator_action_token1] = ACTIONS(9548),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9548),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9548),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9548),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9548),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9548),
    [anon_sym_POUNDif] = ACTIONS(9548),
    [anon_sym_POUNDIF] = ACTIONS(9548),
    [anon_sym_POUNDIf] = ACTIONS(9548),
    [anon_sym_POUNDelif] = ACTIONS(9548),
    [anon_sym_POUNDELIF] = ACTIONS(9548),
    [anon_sym_POUNDElif] = ACTIONS(9548),
    [anon_sym_POUNDelse] = ACTIONS(9548),
    [anon_sym_POUNDELSE] = ACTIONS(9548),
    [anon_sym_POUNDElse] = ACTIONS(9548),
    [anon_sym_POUNDelse2] = ACTIONS(9548),
    [anon_sym_POUNDELSE2] = ACTIONS(9548),
    [anon_sym_POUNDElse2] = ACTIONS(9548),
    [anon_sym_POUNDendif] = ACTIONS(9548),
    [anon_sym_POUNDENDIF] = ACTIONS(9548),
    [anon_sym_POUNDEndif] = ACTIONS(9548),
    [anon_sym_POUNDendif2] = ACTIONS(9548),
    [anon_sym_POUNDENDIF2] = ACTIONS(9548),
    [anon_sym_POUNDEndif2] = ACTIONS(9548),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9548),
    [sym_trigger_keyword] = ACTIONS(9548),
    [sym_var_keyword] = ACTIONS(9548),
    [sym_local_keyword] = ACTIONS(9548),
    [sym_internal_keyword] = ACTIONS(9548),
    [sym_protected_keyword] = ACTIONS(9548),
    [sym_event_keyword] = ACTIONS(9548),
    [sym_fields_keyword] = ACTIONS(9548),
    [sym_keys_keyword] = ACTIONS(9548),
    [sym_fieldgroups_keyword] = ACTIONS(9548),
    [sym_actions_keyword] = ACTIONS(9548),
    [sym_layout_keyword] = ACTIONS(9548),
    [sym_area_keyword] = ACTIONS(9548),
    [sym_group_keyword] = ACTIONS(9548),
    [sym_repeater_keyword] = ACTIONS(9548),
    [sym_cuegroup_keyword] = ACTIONS(9548),
    [sym_fixed_keyword] = ACTIONS(9548),
    [sym_grid_keyword] = ACTIONS(9548),
    [sym_part_keyword] = ACTIONS(9548),
    [sym_systempart_keyword] = ACTIONS(9548),
    [sym_usercontrol_keyword] = ACTIONS(9548),
    [sym_dataset_keyword] = ACTIONS(9548),
    [sym_elements_keyword] = ACTIONS(9548),
    [sym_dataitem_keyword] = ACTIONS(9548),
    [sym_column_keyword] = ACTIONS(9548),
    [sym_filter_keyword] = ACTIONS(9548),
    [sym_labels_keyword] = ACTIONS(9548),
    [sym_rendering_keyword] = ACTIONS(9548),
    [sym_requestpage_keyword] = ACTIONS(9548),
    [sym_schema_keyword] = ACTIONS(9548),
    [sym_views_keyword] = ACTIONS(9548),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9548),
    [sym_preproc_open] = ACTIONS(9548),
    [sym_preproc_close] = ACTIONS(9548),
  },
  [STATE(4208)] = {
    [anon_sym_SEMI] = ACTIONS(9568),
    [aux_sym_where_condition_token1] = ACTIONS(9570),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9568),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9568),
    [anon_sym_LBRACK] = ACTIONS(9568),
    [aux_sym_basic_type_token6] = ACTIONS(9570),
    [aux_sym_basic_type_token22] = ACTIONS(9570),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9568),
    [aux_sym_addafter_modification_token1] = ACTIONS(9568),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9568),
    [aux_sym_modify_modification_token1] = ACTIONS(9568),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9568),
    [aux_sym_movelast_modification_token1] = ACTIONS(9568),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9568),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9568),
    [aux_sym_separator_action_token1] = ACTIONS(9568),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9568),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9568),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9568),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9568),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9568),
    [anon_sym_POUNDif] = ACTIONS(9568),
    [anon_sym_POUNDIF] = ACTIONS(9568),
    [anon_sym_POUNDIf] = ACTIONS(9568),
    [anon_sym_POUNDelif] = ACTIONS(9568),
    [anon_sym_POUNDELIF] = ACTIONS(9568),
    [anon_sym_POUNDElif] = ACTIONS(9568),
    [anon_sym_POUNDelse] = ACTIONS(9568),
    [anon_sym_POUNDELSE] = ACTIONS(9568),
    [anon_sym_POUNDElse] = ACTIONS(9568),
    [anon_sym_POUNDelse2] = ACTIONS(9568),
    [anon_sym_POUNDELSE2] = ACTIONS(9568),
    [anon_sym_POUNDElse2] = ACTIONS(9568),
    [anon_sym_POUNDendif] = ACTIONS(9568),
    [anon_sym_POUNDENDIF] = ACTIONS(9568),
    [anon_sym_POUNDEndif] = ACTIONS(9568),
    [anon_sym_POUNDendif2] = ACTIONS(9568),
    [anon_sym_POUNDENDIF2] = ACTIONS(9568),
    [anon_sym_POUNDEndif2] = ACTIONS(9568),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9568),
    [sym_trigger_keyword] = ACTIONS(9568),
    [sym_var_keyword] = ACTIONS(9568),
    [sym_local_keyword] = ACTIONS(9568),
    [sym_internal_keyword] = ACTIONS(9568),
    [sym_protected_keyword] = ACTIONS(9568),
    [sym_event_keyword] = ACTIONS(9568),
    [sym_fields_keyword] = ACTIONS(9568),
    [sym_keys_keyword] = ACTIONS(9568),
    [sym_fieldgroups_keyword] = ACTIONS(9568),
    [sym_actions_keyword] = ACTIONS(9568),
    [sym_layout_keyword] = ACTIONS(9568),
    [sym_area_keyword] = ACTIONS(9568),
    [sym_group_keyword] = ACTIONS(9568),
    [sym_repeater_keyword] = ACTIONS(9568),
    [sym_cuegroup_keyword] = ACTIONS(9568),
    [sym_fixed_keyword] = ACTIONS(9568),
    [sym_grid_keyword] = ACTIONS(9568),
    [sym_part_keyword] = ACTIONS(9568),
    [sym_systempart_keyword] = ACTIONS(9568),
    [sym_usercontrol_keyword] = ACTIONS(9568),
    [sym_dataset_keyword] = ACTIONS(9568),
    [sym_elements_keyword] = ACTIONS(9568),
    [sym_dataitem_keyword] = ACTIONS(9568),
    [sym_column_keyword] = ACTIONS(9568),
    [sym_filter_keyword] = ACTIONS(9568),
    [sym_labels_keyword] = ACTIONS(9568),
    [sym_rendering_keyword] = ACTIONS(9568),
    [sym_requestpage_keyword] = ACTIONS(9568),
    [sym_schema_keyword] = ACTIONS(9568),
    [sym_views_keyword] = ACTIONS(9568),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9568),
    [sym_preproc_open] = ACTIONS(9568),
    [sym_preproc_close] = ACTIONS(9568),
  },
  [STATE(4209)] = {
    [anon_sym_SEMI] = ACTIONS(9572),
    [aux_sym_where_condition_token1] = ACTIONS(9574),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9572),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9572),
    [anon_sym_LBRACK] = ACTIONS(9572),
    [aux_sym_basic_type_token6] = ACTIONS(9574),
    [aux_sym_basic_type_token22] = ACTIONS(9574),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9572),
    [aux_sym_addafter_modification_token1] = ACTIONS(9572),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9572),
    [aux_sym_modify_modification_token1] = ACTIONS(9572),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9572),
    [aux_sym_movelast_modification_token1] = ACTIONS(9572),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9572),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9572),
    [aux_sym_separator_action_token1] = ACTIONS(9572),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9572),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9572),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9572),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9572),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9572),
    [anon_sym_POUNDif] = ACTIONS(9572),
    [anon_sym_POUNDIF] = ACTIONS(9572),
    [anon_sym_POUNDIf] = ACTIONS(9572),
    [anon_sym_POUNDelif] = ACTIONS(9572),
    [anon_sym_POUNDELIF] = ACTIONS(9572),
    [anon_sym_POUNDElif] = ACTIONS(9572),
    [anon_sym_POUNDelse] = ACTIONS(9572),
    [anon_sym_POUNDELSE] = ACTIONS(9572),
    [anon_sym_POUNDElse] = ACTIONS(9572),
    [anon_sym_POUNDelse2] = ACTIONS(9572),
    [anon_sym_POUNDELSE2] = ACTIONS(9572),
    [anon_sym_POUNDElse2] = ACTIONS(9572),
    [anon_sym_POUNDendif] = ACTIONS(9572),
    [anon_sym_POUNDENDIF] = ACTIONS(9572),
    [anon_sym_POUNDEndif] = ACTIONS(9572),
    [anon_sym_POUNDendif2] = ACTIONS(9572),
    [anon_sym_POUNDENDIF2] = ACTIONS(9572),
    [anon_sym_POUNDEndif2] = ACTIONS(9572),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9572),
    [sym_trigger_keyword] = ACTIONS(9572),
    [sym_var_keyword] = ACTIONS(9572),
    [sym_local_keyword] = ACTIONS(9572),
    [sym_internal_keyword] = ACTIONS(9572),
    [sym_protected_keyword] = ACTIONS(9572),
    [sym_event_keyword] = ACTIONS(9572),
    [sym_fields_keyword] = ACTIONS(9572),
    [sym_keys_keyword] = ACTIONS(9572),
    [sym_fieldgroups_keyword] = ACTIONS(9572),
    [sym_actions_keyword] = ACTIONS(9572),
    [sym_layout_keyword] = ACTIONS(9572),
    [sym_area_keyword] = ACTIONS(9572),
    [sym_group_keyword] = ACTIONS(9572),
    [sym_repeater_keyword] = ACTIONS(9572),
    [sym_cuegroup_keyword] = ACTIONS(9572),
    [sym_fixed_keyword] = ACTIONS(9572),
    [sym_grid_keyword] = ACTIONS(9572),
    [sym_part_keyword] = ACTIONS(9572),
    [sym_systempart_keyword] = ACTIONS(9572),
    [sym_usercontrol_keyword] = ACTIONS(9572),
    [sym_dataset_keyword] = ACTIONS(9572),
    [sym_elements_keyword] = ACTIONS(9572),
    [sym_dataitem_keyword] = ACTIONS(9572),
    [sym_column_keyword] = ACTIONS(9572),
    [sym_filter_keyword] = ACTIONS(9572),
    [sym_labels_keyword] = ACTIONS(9572),
    [sym_rendering_keyword] = ACTIONS(9572),
    [sym_requestpage_keyword] = ACTIONS(9572),
    [sym_schema_keyword] = ACTIONS(9572),
    [sym_views_keyword] = ACTIONS(9572),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9572),
    [sym_preproc_open] = ACTIONS(9572),
    [sym_preproc_close] = ACTIONS(9572),
  },
  [STATE(4210)] = {
    [anon_sym_SEMI] = ACTIONS(9576),
    [aux_sym_where_condition_token1] = ACTIONS(9578),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9576),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9576),
    [anon_sym_LBRACK] = ACTIONS(9576),
    [aux_sym_basic_type_token6] = ACTIONS(9578),
    [aux_sym_basic_type_token22] = ACTIONS(9578),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9576),
    [aux_sym_addafter_modification_token1] = ACTIONS(9576),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9576),
    [aux_sym_modify_modification_token1] = ACTIONS(9576),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9576),
    [aux_sym_movelast_modification_token1] = ACTIONS(9576),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9576),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9576),
    [aux_sym_separator_action_token1] = ACTIONS(9576),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9576),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9576),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9576),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9576),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9576),
    [anon_sym_POUNDif] = ACTIONS(9576),
    [anon_sym_POUNDIF] = ACTIONS(9576),
    [anon_sym_POUNDIf] = ACTIONS(9576),
    [anon_sym_POUNDelif] = ACTIONS(9576),
    [anon_sym_POUNDELIF] = ACTIONS(9576),
    [anon_sym_POUNDElif] = ACTIONS(9576),
    [anon_sym_POUNDelse] = ACTIONS(9576),
    [anon_sym_POUNDELSE] = ACTIONS(9576),
    [anon_sym_POUNDElse] = ACTIONS(9576),
    [anon_sym_POUNDelse2] = ACTIONS(9576),
    [anon_sym_POUNDELSE2] = ACTIONS(9576),
    [anon_sym_POUNDElse2] = ACTIONS(9576),
    [anon_sym_POUNDendif] = ACTIONS(9576),
    [anon_sym_POUNDENDIF] = ACTIONS(9576),
    [anon_sym_POUNDEndif] = ACTIONS(9576),
    [anon_sym_POUNDendif2] = ACTIONS(9576),
    [anon_sym_POUNDENDIF2] = ACTIONS(9576),
    [anon_sym_POUNDEndif2] = ACTIONS(9576),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9576),
    [sym_trigger_keyword] = ACTIONS(9576),
    [sym_var_keyword] = ACTIONS(9576),
    [sym_local_keyword] = ACTIONS(9576),
    [sym_internal_keyword] = ACTIONS(9576),
    [sym_protected_keyword] = ACTIONS(9576),
    [sym_event_keyword] = ACTIONS(9576),
    [sym_fields_keyword] = ACTIONS(9576),
    [sym_keys_keyword] = ACTIONS(9576),
    [sym_fieldgroups_keyword] = ACTIONS(9576),
    [sym_actions_keyword] = ACTIONS(9576),
    [sym_layout_keyword] = ACTIONS(9576),
    [sym_area_keyword] = ACTIONS(9576),
    [sym_group_keyword] = ACTIONS(9576),
    [sym_repeater_keyword] = ACTIONS(9576),
    [sym_cuegroup_keyword] = ACTIONS(9576),
    [sym_fixed_keyword] = ACTIONS(9576),
    [sym_grid_keyword] = ACTIONS(9576),
    [sym_part_keyword] = ACTIONS(9576),
    [sym_systempart_keyword] = ACTIONS(9576),
    [sym_usercontrol_keyword] = ACTIONS(9576),
    [sym_dataset_keyword] = ACTIONS(9576),
    [sym_elements_keyword] = ACTIONS(9576),
    [sym_dataitem_keyword] = ACTIONS(9576),
    [sym_column_keyword] = ACTIONS(9576),
    [sym_filter_keyword] = ACTIONS(9576),
    [sym_labels_keyword] = ACTIONS(9576),
    [sym_rendering_keyword] = ACTIONS(9576),
    [sym_requestpage_keyword] = ACTIONS(9576),
    [sym_schema_keyword] = ACTIONS(9576),
    [sym_views_keyword] = ACTIONS(9576),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9576),
    [sym_preproc_open] = ACTIONS(9576),
    [sym_preproc_close] = ACTIONS(9576),
  },
  [STATE(4211)] = {
    [anon_sym_SEMI] = ACTIONS(9580),
    [aux_sym_where_condition_token1] = ACTIONS(9582),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9580),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9580),
    [anon_sym_LBRACK] = ACTIONS(9580),
    [aux_sym_basic_type_token6] = ACTIONS(9582),
    [aux_sym_basic_type_token22] = ACTIONS(9582),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9580),
    [aux_sym_addafter_modification_token1] = ACTIONS(9580),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9580),
    [aux_sym_modify_modification_token1] = ACTIONS(9580),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9580),
    [aux_sym_movelast_modification_token1] = ACTIONS(9580),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9580),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9580),
    [aux_sym_separator_action_token1] = ACTIONS(9580),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9580),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9580),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9580),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9580),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9580),
    [anon_sym_POUNDif] = ACTIONS(9580),
    [anon_sym_POUNDIF] = ACTIONS(9580),
    [anon_sym_POUNDIf] = ACTIONS(9580),
    [anon_sym_POUNDelif] = ACTIONS(9580),
    [anon_sym_POUNDELIF] = ACTIONS(9580),
    [anon_sym_POUNDElif] = ACTIONS(9580),
    [anon_sym_POUNDelse] = ACTIONS(9580),
    [anon_sym_POUNDELSE] = ACTIONS(9580),
    [anon_sym_POUNDElse] = ACTIONS(9580),
    [anon_sym_POUNDelse2] = ACTIONS(9580),
    [anon_sym_POUNDELSE2] = ACTIONS(9580),
    [anon_sym_POUNDElse2] = ACTIONS(9580),
    [anon_sym_POUNDendif] = ACTIONS(9580),
    [anon_sym_POUNDENDIF] = ACTIONS(9580),
    [anon_sym_POUNDEndif] = ACTIONS(9580),
    [anon_sym_POUNDendif2] = ACTIONS(9580),
    [anon_sym_POUNDENDIF2] = ACTIONS(9580),
    [anon_sym_POUNDEndif2] = ACTIONS(9580),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9580),
    [sym_trigger_keyword] = ACTIONS(9580),
    [sym_var_keyword] = ACTIONS(9580),
    [sym_local_keyword] = ACTIONS(9580),
    [sym_internal_keyword] = ACTIONS(9580),
    [sym_protected_keyword] = ACTIONS(9580),
    [sym_event_keyword] = ACTIONS(9580),
    [sym_fields_keyword] = ACTIONS(9580),
    [sym_keys_keyword] = ACTIONS(9580),
    [sym_fieldgroups_keyword] = ACTIONS(9580),
    [sym_actions_keyword] = ACTIONS(9580),
    [sym_layout_keyword] = ACTIONS(9580),
    [sym_area_keyword] = ACTIONS(9580),
    [sym_group_keyword] = ACTIONS(9580),
    [sym_repeater_keyword] = ACTIONS(9580),
    [sym_cuegroup_keyword] = ACTIONS(9580),
    [sym_fixed_keyword] = ACTIONS(9580),
    [sym_grid_keyword] = ACTIONS(9580),
    [sym_part_keyword] = ACTIONS(9580),
    [sym_systempart_keyword] = ACTIONS(9580),
    [sym_usercontrol_keyword] = ACTIONS(9580),
    [sym_dataset_keyword] = ACTIONS(9580),
    [sym_elements_keyword] = ACTIONS(9580),
    [sym_dataitem_keyword] = ACTIONS(9580),
    [sym_column_keyword] = ACTIONS(9580),
    [sym_filter_keyword] = ACTIONS(9580),
    [sym_labels_keyword] = ACTIONS(9580),
    [sym_rendering_keyword] = ACTIONS(9580),
    [sym_requestpage_keyword] = ACTIONS(9580),
    [sym_schema_keyword] = ACTIONS(9580),
    [sym_views_keyword] = ACTIONS(9580),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9580),
    [sym_preproc_open] = ACTIONS(9580),
    [sym_preproc_close] = ACTIONS(9580),
  },
  [STATE(4212)] = {
    [anon_sym_SEMI] = ACTIONS(9584),
    [aux_sym_where_condition_token1] = ACTIONS(9586),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9584),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9584),
    [anon_sym_LBRACK] = ACTIONS(9584),
    [aux_sym_basic_type_token6] = ACTIONS(9586),
    [aux_sym_basic_type_token22] = ACTIONS(9586),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9584),
    [aux_sym_addafter_modification_token1] = ACTIONS(9584),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9584),
    [aux_sym_modify_modification_token1] = ACTIONS(9584),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9584),
    [aux_sym_movelast_modification_token1] = ACTIONS(9584),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9584),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9584),
    [aux_sym_separator_action_token1] = ACTIONS(9584),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9584),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9584),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9584),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9584),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9584),
    [anon_sym_POUNDif] = ACTIONS(9584),
    [anon_sym_POUNDIF] = ACTIONS(9584),
    [anon_sym_POUNDIf] = ACTIONS(9584),
    [anon_sym_POUNDelif] = ACTIONS(9584),
    [anon_sym_POUNDELIF] = ACTIONS(9584),
    [anon_sym_POUNDElif] = ACTIONS(9584),
    [anon_sym_POUNDelse] = ACTIONS(9584),
    [anon_sym_POUNDELSE] = ACTIONS(9584),
    [anon_sym_POUNDElse] = ACTIONS(9584),
    [anon_sym_POUNDelse2] = ACTIONS(9584),
    [anon_sym_POUNDELSE2] = ACTIONS(9584),
    [anon_sym_POUNDElse2] = ACTIONS(9584),
    [anon_sym_POUNDendif] = ACTIONS(9584),
    [anon_sym_POUNDENDIF] = ACTIONS(9584),
    [anon_sym_POUNDEndif] = ACTIONS(9584),
    [anon_sym_POUNDendif2] = ACTIONS(9584),
    [anon_sym_POUNDENDIF2] = ACTIONS(9584),
    [anon_sym_POUNDEndif2] = ACTIONS(9584),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9584),
    [sym_trigger_keyword] = ACTIONS(9584),
    [sym_var_keyword] = ACTIONS(9584),
    [sym_local_keyword] = ACTIONS(9584),
    [sym_internal_keyword] = ACTIONS(9584),
    [sym_protected_keyword] = ACTIONS(9584),
    [sym_event_keyword] = ACTIONS(9584),
    [sym_fields_keyword] = ACTIONS(9584),
    [sym_keys_keyword] = ACTIONS(9584),
    [sym_fieldgroups_keyword] = ACTIONS(9584),
    [sym_actions_keyword] = ACTIONS(9584),
    [sym_layout_keyword] = ACTIONS(9584),
    [sym_area_keyword] = ACTIONS(9584),
    [sym_group_keyword] = ACTIONS(9584),
    [sym_repeater_keyword] = ACTIONS(9584),
    [sym_cuegroup_keyword] = ACTIONS(9584),
    [sym_fixed_keyword] = ACTIONS(9584),
    [sym_grid_keyword] = ACTIONS(9584),
    [sym_part_keyword] = ACTIONS(9584),
    [sym_systempart_keyword] = ACTIONS(9584),
    [sym_usercontrol_keyword] = ACTIONS(9584),
    [sym_dataset_keyword] = ACTIONS(9584),
    [sym_elements_keyword] = ACTIONS(9584),
    [sym_dataitem_keyword] = ACTIONS(9584),
    [sym_column_keyword] = ACTIONS(9584),
    [sym_filter_keyword] = ACTIONS(9584),
    [sym_labels_keyword] = ACTIONS(9584),
    [sym_rendering_keyword] = ACTIONS(9584),
    [sym_requestpage_keyword] = ACTIONS(9584),
    [sym_schema_keyword] = ACTIONS(9584),
    [sym_views_keyword] = ACTIONS(9584),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9584),
    [sym_preproc_open] = ACTIONS(9584),
    [sym_preproc_close] = ACTIONS(9584),
  },
  [STATE(4213)] = {
    [anon_sym_SEMI] = ACTIONS(9588),
    [aux_sym_where_condition_token1] = ACTIONS(9590),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9588),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9588),
    [anon_sym_LBRACK] = ACTIONS(9588),
    [aux_sym_basic_type_token6] = ACTIONS(9590),
    [aux_sym_basic_type_token22] = ACTIONS(9590),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9588),
    [aux_sym_addafter_modification_token1] = ACTIONS(9588),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9588),
    [aux_sym_modify_modification_token1] = ACTIONS(9588),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9588),
    [aux_sym_movelast_modification_token1] = ACTIONS(9588),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9588),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9588),
    [aux_sym_separator_action_token1] = ACTIONS(9588),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9588),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9588),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9588),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9588),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9588),
    [anon_sym_POUNDif] = ACTIONS(9588),
    [anon_sym_POUNDIF] = ACTIONS(9588),
    [anon_sym_POUNDIf] = ACTIONS(9588),
    [anon_sym_POUNDelif] = ACTIONS(9588),
    [anon_sym_POUNDELIF] = ACTIONS(9588),
    [anon_sym_POUNDElif] = ACTIONS(9588),
    [anon_sym_POUNDelse] = ACTIONS(9588),
    [anon_sym_POUNDELSE] = ACTIONS(9588),
    [anon_sym_POUNDElse] = ACTIONS(9588),
    [anon_sym_POUNDelse2] = ACTIONS(9588),
    [anon_sym_POUNDELSE2] = ACTIONS(9588),
    [anon_sym_POUNDElse2] = ACTIONS(9588),
    [anon_sym_POUNDendif] = ACTIONS(9588),
    [anon_sym_POUNDENDIF] = ACTIONS(9588),
    [anon_sym_POUNDEndif] = ACTIONS(9588),
    [anon_sym_POUNDendif2] = ACTIONS(9588),
    [anon_sym_POUNDENDIF2] = ACTIONS(9588),
    [anon_sym_POUNDEndif2] = ACTIONS(9588),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9588),
    [sym_trigger_keyword] = ACTIONS(9588),
    [sym_var_keyword] = ACTIONS(9588),
    [sym_local_keyword] = ACTIONS(9588),
    [sym_internal_keyword] = ACTIONS(9588),
    [sym_protected_keyword] = ACTIONS(9588),
    [sym_event_keyword] = ACTIONS(9588),
    [sym_fields_keyword] = ACTIONS(9588),
    [sym_keys_keyword] = ACTIONS(9588),
    [sym_fieldgroups_keyword] = ACTIONS(9588),
    [sym_actions_keyword] = ACTIONS(9588),
    [sym_layout_keyword] = ACTIONS(9588),
    [sym_area_keyword] = ACTIONS(9588),
    [sym_group_keyword] = ACTIONS(9588),
    [sym_repeater_keyword] = ACTIONS(9588),
    [sym_cuegroup_keyword] = ACTIONS(9588),
    [sym_fixed_keyword] = ACTIONS(9588),
    [sym_grid_keyword] = ACTIONS(9588),
    [sym_part_keyword] = ACTIONS(9588),
    [sym_systempart_keyword] = ACTIONS(9588),
    [sym_usercontrol_keyword] = ACTIONS(9588),
    [sym_dataset_keyword] = ACTIONS(9588),
    [sym_elements_keyword] = ACTIONS(9588),
    [sym_dataitem_keyword] = ACTIONS(9588),
    [sym_column_keyword] = ACTIONS(9588),
    [sym_filter_keyword] = ACTIONS(9588),
    [sym_labels_keyword] = ACTIONS(9588),
    [sym_rendering_keyword] = ACTIONS(9588),
    [sym_requestpage_keyword] = ACTIONS(9588),
    [sym_schema_keyword] = ACTIONS(9588),
    [sym_views_keyword] = ACTIONS(9588),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9588),
    [sym_preproc_open] = ACTIONS(9588),
    [sym_preproc_close] = ACTIONS(9588),
  },
  [STATE(4214)] = {
    [anon_sym_SEMI] = ACTIONS(9592),
    [aux_sym_where_condition_token1] = ACTIONS(9594),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9592),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9592),
    [anon_sym_LBRACK] = ACTIONS(9592),
    [aux_sym_basic_type_token6] = ACTIONS(9594),
    [aux_sym_basic_type_token22] = ACTIONS(9594),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9592),
    [aux_sym_addafter_modification_token1] = ACTIONS(9592),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9592),
    [aux_sym_modify_modification_token1] = ACTIONS(9592),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9592),
    [aux_sym_movelast_modification_token1] = ACTIONS(9592),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9592),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9592),
    [aux_sym_separator_action_token1] = ACTIONS(9592),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9592),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9592),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9592),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9592),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9592),
    [anon_sym_POUNDif] = ACTIONS(9592),
    [anon_sym_POUNDIF] = ACTIONS(9592),
    [anon_sym_POUNDIf] = ACTIONS(9592),
    [anon_sym_POUNDelif] = ACTIONS(9592),
    [anon_sym_POUNDELIF] = ACTIONS(9592),
    [anon_sym_POUNDElif] = ACTIONS(9592),
    [anon_sym_POUNDelse] = ACTIONS(9592),
    [anon_sym_POUNDELSE] = ACTIONS(9592),
    [anon_sym_POUNDElse] = ACTIONS(9592),
    [anon_sym_POUNDelse2] = ACTIONS(9592),
    [anon_sym_POUNDELSE2] = ACTIONS(9592),
    [anon_sym_POUNDElse2] = ACTIONS(9592),
    [anon_sym_POUNDendif] = ACTIONS(9592),
    [anon_sym_POUNDENDIF] = ACTIONS(9592),
    [anon_sym_POUNDEndif] = ACTIONS(9592),
    [anon_sym_POUNDendif2] = ACTIONS(9592),
    [anon_sym_POUNDENDIF2] = ACTIONS(9592),
    [anon_sym_POUNDEndif2] = ACTIONS(9592),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9592),
    [sym_trigger_keyword] = ACTIONS(9592),
    [sym_var_keyword] = ACTIONS(9592),
    [sym_local_keyword] = ACTIONS(9592),
    [sym_internal_keyword] = ACTIONS(9592),
    [sym_protected_keyword] = ACTIONS(9592),
    [sym_event_keyword] = ACTIONS(9592),
    [sym_fields_keyword] = ACTIONS(9592),
    [sym_keys_keyword] = ACTIONS(9592),
    [sym_fieldgroups_keyword] = ACTIONS(9592),
    [sym_actions_keyword] = ACTIONS(9592),
    [sym_layout_keyword] = ACTIONS(9592),
    [sym_area_keyword] = ACTIONS(9592),
    [sym_group_keyword] = ACTIONS(9592),
    [sym_repeater_keyword] = ACTIONS(9592),
    [sym_cuegroup_keyword] = ACTIONS(9592),
    [sym_fixed_keyword] = ACTIONS(9592),
    [sym_grid_keyword] = ACTIONS(9592),
    [sym_part_keyword] = ACTIONS(9592),
    [sym_systempart_keyword] = ACTIONS(9592),
    [sym_usercontrol_keyword] = ACTIONS(9592),
    [sym_dataset_keyword] = ACTIONS(9592),
    [sym_elements_keyword] = ACTIONS(9592),
    [sym_dataitem_keyword] = ACTIONS(9592),
    [sym_column_keyword] = ACTIONS(9592),
    [sym_filter_keyword] = ACTIONS(9592),
    [sym_labels_keyword] = ACTIONS(9592),
    [sym_rendering_keyword] = ACTIONS(9592),
    [sym_requestpage_keyword] = ACTIONS(9592),
    [sym_schema_keyword] = ACTIONS(9592),
    [sym_views_keyword] = ACTIONS(9592),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9592),
    [sym_preproc_open] = ACTIONS(9592),
    [sym_preproc_close] = ACTIONS(9592),
  },
  [STATE(4215)] = {
    [anon_sym_SEMI] = ACTIONS(9596),
    [aux_sym_where_condition_token1] = ACTIONS(9598),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9596),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9596),
    [anon_sym_LBRACK] = ACTIONS(9596),
    [aux_sym_basic_type_token6] = ACTIONS(9598),
    [aux_sym_basic_type_token22] = ACTIONS(9598),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9596),
    [aux_sym_addafter_modification_token1] = ACTIONS(9596),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9596),
    [aux_sym_modify_modification_token1] = ACTIONS(9596),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9596),
    [aux_sym_movelast_modification_token1] = ACTIONS(9596),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9596),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9596),
    [aux_sym_separator_action_token1] = ACTIONS(9596),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9596),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9596),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9596),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9596),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9596),
    [anon_sym_POUNDif] = ACTIONS(9596),
    [anon_sym_POUNDIF] = ACTIONS(9596),
    [anon_sym_POUNDIf] = ACTIONS(9596),
    [anon_sym_POUNDelif] = ACTIONS(9596),
    [anon_sym_POUNDELIF] = ACTIONS(9596),
    [anon_sym_POUNDElif] = ACTIONS(9596),
    [anon_sym_POUNDelse] = ACTIONS(9596),
    [anon_sym_POUNDELSE] = ACTIONS(9596),
    [anon_sym_POUNDElse] = ACTIONS(9596),
    [anon_sym_POUNDelse2] = ACTIONS(9596),
    [anon_sym_POUNDELSE2] = ACTIONS(9596),
    [anon_sym_POUNDElse2] = ACTIONS(9596),
    [anon_sym_POUNDendif] = ACTIONS(9596),
    [anon_sym_POUNDENDIF] = ACTIONS(9596),
    [anon_sym_POUNDEndif] = ACTIONS(9596),
    [anon_sym_POUNDendif2] = ACTIONS(9596),
    [anon_sym_POUNDENDIF2] = ACTIONS(9596),
    [anon_sym_POUNDEndif2] = ACTIONS(9596),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9596),
    [sym_trigger_keyword] = ACTIONS(9596),
    [sym_var_keyword] = ACTIONS(9596),
    [sym_local_keyword] = ACTIONS(9596),
    [sym_internal_keyword] = ACTIONS(9596),
    [sym_protected_keyword] = ACTIONS(9596),
    [sym_event_keyword] = ACTIONS(9596),
    [sym_fields_keyword] = ACTIONS(9596),
    [sym_keys_keyword] = ACTIONS(9596),
    [sym_fieldgroups_keyword] = ACTIONS(9596),
    [sym_actions_keyword] = ACTIONS(9596),
    [sym_layout_keyword] = ACTIONS(9596),
    [sym_area_keyword] = ACTIONS(9596),
    [sym_group_keyword] = ACTIONS(9596),
    [sym_repeater_keyword] = ACTIONS(9596),
    [sym_cuegroup_keyword] = ACTIONS(9596),
    [sym_fixed_keyword] = ACTIONS(9596),
    [sym_grid_keyword] = ACTIONS(9596),
    [sym_part_keyword] = ACTIONS(9596),
    [sym_systempart_keyword] = ACTIONS(9596),
    [sym_usercontrol_keyword] = ACTIONS(9596),
    [sym_dataset_keyword] = ACTIONS(9596),
    [sym_elements_keyword] = ACTIONS(9596),
    [sym_dataitem_keyword] = ACTIONS(9596),
    [sym_column_keyword] = ACTIONS(9596),
    [sym_filter_keyword] = ACTIONS(9596),
    [sym_labels_keyword] = ACTIONS(9596),
    [sym_rendering_keyword] = ACTIONS(9596),
    [sym_requestpage_keyword] = ACTIONS(9596),
    [sym_schema_keyword] = ACTIONS(9596),
    [sym_views_keyword] = ACTIONS(9596),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9596),
    [sym_preproc_open] = ACTIONS(9596),
    [sym_preproc_close] = ACTIONS(9596),
  },
  [STATE(4216)] = {
    [anon_sym_SEMI] = ACTIONS(9600),
    [aux_sym_where_condition_token1] = ACTIONS(9602),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9600),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9600),
    [anon_sym_LBRACK] = ACTIONS(9600),
    [aux_sym_basic_type_token6] = ACTIONS(9602),
    [aux_sym_basic_type_token22] = ACTIONS(9602),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9600),
    [aux_sym_addafter_modification_token1] = ACTIONS(9600),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9600),
    [aux_sym_modify_modification_token1] = ACTIONS(9600),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9600),
    [aux_sym_movelast_modification_token1] = ACTIONS(9600),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9600),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9600),
    [aux_sym_separator_action_token1] = ACTIONS(9600),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9600),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9600),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9600),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9600),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9600),
    [anon_sym_POUNDif] = ACTIONS(9600),
    [anon_sym_POUNDIF] = ACTIONS(9600),
    [anon_sym_POUNDIf] = ACTIONS(9600),
    [anon_sym_POUNDelif] = ACTIONS(9600),
    [anon_sym_POUNDELIF] = ACTIONS(9600),
    [anon_sym_POUNDElif] = ACTIONS(9600),
    [anon_sym_POUNDelse] = ACTIONS(9600),
    [anon_sym_POUNDELSE] = ACTIONS(9600),
    [anon_sym_POUNDElse] = ACTIONS(9600),
    [anon_sym_POUNDelse2] = ACTIONS(9600),
    [anon_sym_POUNDELSE2] = ACTIONS(9600),
    [anon_sym_POUNDElse2] = ACTIONS(9600),
    [anon_sym_POUNDendif] = ACTIONS(9600),
    [anon_sym_POUNDENDIF] = ACTIONS(9600),
    [anon_sym_POUNDEndif] = ACTIONS(9600),
    [anon_sym_POUNDendif2] = ACTIONS(9600),
    [anon_sym_POUNDENDIF2] = ACTIONS(9600),
    [anon_sym_POUNDEndif2] = ACTIONS(9600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9600),
    [sym_trigger_keyword] = ACTIONS(9600),
    [sym_var_keyword] = ACTIONS(9600),
    [sym_local_keyword] = ACTIONS(9600),
    [sym_internal_keyword] = ACTIONS(9600),
    [sym_protected_keyword] = ACTIONS(9600),
    [sym_event_keyword] = ACTIONS(9600),
    [sym_fields_keyword] = ACTIONS(9600),
    [sym_keys_keyword] = ACTIONS(9600),
    [sym_fieldgroups_keyword] = ACTIONS(9600),
    [sym_actions_keyword] = ACTIONS(9600),
    [sym_layout_keyword] = ACTIONS(9600),
    [sym_area_keyword] = ACTIONS(9600),
    [sym_group_keyword] = ACTIONS(9600),
    [sym_repeater_keyword] = ACTIONS(9600),
    [sym_cuegroup_keyword] = ACTIONS(9600),
    [sym_fixed_keyword] = ACTIONS(9600),
    [sym_grid_keyword] = ACTIONS(9600),
    [sym_part_keyword] = ACTIONS(9600),
    [sym_systempart_keyword] = ACTIONS(9600),
    [sym_usercontrol_keyword] = ACTIONS(9600),
    [sym_dataset_keyword] = ACTIONS(9600),
    [sym_elements_keyword] = ACTIONS(9600),
    [sym_dataitem_keyword] = ACTIONS(9600),
    [sym_column_keyword] = ACTIONS(9600),
    [sym_filter_keyword] = ACTIONS(9600),
    [sym_labels_keyword] = ACTIONS(9600),
    [sym_rendering_keyword] = ACTIONS(9600),
    [sym_requestpage_keyword] = ACTIONS(9600),
    [sym_schema_keyword] = ACTIONS(9600),
    [sym_views_keyword] = ACTIONS(9600),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9600),
    [sym_preproc_open] = ACTIONS(9600),
    [sym_preproc_close] = ACTIONS(9600),
  },
  [STATE(4217)] = {
    [anon_sym_SEMI] = ACTIONS(9604),
    [aux_sym_where_condition_token1] = ACTIONS(9606),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9604),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9604),
    [anon_sym_LBRACK] = ACTIONS(9604),
    [aux_sym_basic_type_token6] = ACTIONS(9606),
    [aux_sym_basic_type_token22] = ACTIONS(9606),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9604),
    [aux_sym_addafter_modification_token1] = ACTIONS(9604),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9604),
    [aux_sym_modify_modification_token1] = ACTIONS(9604),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9604),
    [aux_sym_movelast_modification_token1] = ACTIONS(9604),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9604),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9604),
    [aux_sym_separator_action_token1] = ACTIONS(9604),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9604),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9604),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9604),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9604),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9604),
    [anon_sym_POUNDif] = ACTIONS(9604),
    [anon_sym_POUNDIF] = ACTIONS(9604),
    [anon_sym_POUNDIf] = ACTIONS(9604),
    [anon_sym_POUNDelif] = ACTIONS(9604),
    [anon_sym_POUNDELIF] = ACTIONS(9604),
    [anon_sym_POUNDElif] = ACTIONS(9604),
    [anon_sym_POUNDelse] = ACTIONS(9604),
    [anon_sym_POUNDELSE] = ACTIONS(9604),
    [anon_sym_POUNDElse] = ACTIONS(9604),
    [anon_sym_POUNDelse2] = ACTIONS(9604),
    [anon_sym_POUNDELSE2] = ACTIONS(9604),
    [anon_sym_POUNDElse2] = ACTIONS(9604),
    [anon_sym_POUNDendif] = ACTIONS(9604),
    [anon_sym_POUNDENDIF] = ACTIONS(9604),
    [anon_sym_POUNDEndif] = ACTIONS(9604),
    [anon_sym_POUNDendif2] = ACTIONS(9604),
    [anon_sym_POUNDENDIF2] = ACTIONS(9604),
    [anon_sym_POUNDEndif2] = ACTIONS(9604),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9604),
    [sym_trigger_keyword] = ACTIONS(9604),
    [sym_var_keyword] = ACTIONS(9604),
    [sym_local_keyword] = ACTIONS(9604),
    [sym_internal_keyword] = ACTIONS(9604),
    [sym_protected_keyword] = ACTIONS(9604),
    [sym_event_keyword] = ACTIONS(9604),
    [sym_fields_keyword] = ACTIONS(9604),
    [sym_keys_keyword] = ACTIONS(9604),
    [sym_fieldgroups_keyword] = ACTIONS(9604),
    [sym_actions_keyword] = ACTIONS(9604),
    [sym_layout_keyword] = ACTIONS(9604),
    [sym_area_keyword] = ACTIONS(9604),
    [sym_group_keyword] = ACTIONS(9604),
    [sym_repeater_keyword] = ACTIONS(9604),
    [sym_cuegroup_keyword] = ACTIONS(9604),
    [sym_fixed_keyword] = ACTIONS(9604),
    [sym_grid_keyword] = ACTIONS(9604),
    [sym_part_keyword] = ACTIONS(9604),
    [sym_systempart_keyword] = ACTIONS(9604),
    [sym_usercontrol_keyword] = ACTIONS(9604),
    [sym_dataset_keyword] = ACTIONS(9604),
    [sym_elements_keyword] = ACTIONS(9604),
    [sym_dataitem_keyword] = ACTIONS(9604),
    [sym_column_keyword] = ACTIONS(9604),
    [sym_filter_keyword] = ACTIONS(9604),
    [sym_labels_keyword] = ACTIONS(9604),
    [sym_rendering_keyword] = ACTIONS(9604),
    [sym_requestpage_keyword] = ACTIONS(9604),
    [sym_schema_keyword] = ACTIONS(9604),
    [sym_views_keyword] = ACTIONS(9604),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9604),
    [sym_preproc_open] = ACTIONS(9604),
    [sym_preproc_close] = ACTIONS(9604),
  },
  [STATE(4218)] = {
    [anon_sym_SEMI] = ACTIONS(9608),
    [aux_sym_where_condition_token1] = ACTIONS(9610),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9608),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9608),
    [anon_sym_LBRACK] = ACTIONS(9608),
    [aux_sym_basic_type_token6] = ACTIONS(9610),
    [aux_sym_basic_type_token22] = ACTIONS(9610),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9608),
    [aux_sym_addafter_modification_token1] = ACTIONS(9608),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9608),
    [aux_sym_modify_modification_token1] = ACTIONS(9608),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9608),
    [aux_sym_movelast_modification_token1] = ACTIONS(9608),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9608),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9608),
    [aux_sym_separator_action_token1] = ACTIONS(9608),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9608),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9608),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9608),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9608),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9608),
    [anon_sym_POUNDif] = ACTIONS(9608),
    [anon_sym_POUNDIF] = ACTIONS(9608),
    [anon_sym_POUNDIf] = ACTIONS(9608),
    [anon_sym_POUNDelif] = ACTIONS(9608),
    [anon_sym_POUNDELIF] = ACTIONS(9608),
    [anon_sym_POUNDElif] = ACTIONS(9608),
    [anon_sym_POUNDelse] = ACTIONS(9608),
    [anon_sym_POUNDELSE] = ACTIONS(9608),
    [anon_sym_POUNDElse] = ACTIONS(9608),
    [anon_sym_POUNDelse2] = ACTIONS(9608),
    [anon_sym_POUNDELSE2] = ACTIONS(9608),
    [anon_sym_POUNDElse2] = ACTIONS(9608),
    [anon_sym_POUNDendif] = ACTIONS(9608),
    [anon_sym_POUNDENDIF] = ACTIONS(9608),
    [anon_sym_POUNDEndif] = ACTIONS(9608),
    [anon_sym_POUNDendif2] = ACTIONS(9608),
    [anon_sym_POUNDENDIF2] = ACTIONS(9608),
    [anon_sym_POUNDEndif2] = ACTIONS(9608),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9608),
    [sym_trigger_keyword] = ACTIONS(9608),
    [sym_var_keyword] = ACTIONS(9608),
    [sym_local_keyword] = ACTIONS(9608),
    [sym_internal_keyword] = ACTIONS(9608),
    [sym_protected_keyword] = ACTIONS(9608),
    [sym_event_keyword] = ACTIONS(9608),
    [sym_fields_keyword] = ACTIONS(9608),
    [sym_keys_keyword] = ACTIONS(9608),
    [sym_fieldgroups_keyword] = ACTIONS(9608),
    [sym_actions_keyword] = ACTIONS(9608),
    [sym_layout_keyword] = ACTIONS(9608),
    [sym_area_keyword] = ACTIONS(9608),
    [sym_group_keyword] = ACTIONS(9608),
    [sym_repeater_keyword] = ACTIONS(9608),
    [sym_cuegroup_keyword] = ACTIONS(9608),
    [sym_fixed_keyword] = ACTIONS(9608),
    [sym_grid_keyword] = ACTIONS(9608),
    [sym_part_keyword] = ACTIONS(9608),
    [sym_systempart_keyword] = ACTIONS(9608),
    [sym_usercontrol_keyword] = ACTIONS(9608),
    [sym_dataset_keyword] = ACTIONS(9608),
    [sym_elements_keyword] = ACTIONS(9608),
    [sym_dataitem_keyword] = ACTIONS(9608),
    [sym_column_keyword] = ACTIONS(9608),
    [sym_filter_keyword] = ACTIONS(9608),
    [sym_labels_keyword] = ACTIONS(9608),
    [sym_rendering_keyword] = ACTIONS(9608),
    [sym_requestpage_keyword] = ACTIONS(9608),
    [sym_schema_keyword] = ACTIONS(9608),
    [sym_views_keyword] = ACTIONS(9608),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9608),
    [sym_preproc_open] = ACTIONS(9608),
    [sym_preproc_close] = ACTIONS(9608),
  },
  [STATE(4219)] = {
    [anon_sym_SEMI] = ACTIONS(9612),
    [aux_sym_where_condition_token1] = ACTIONS(9614),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9612),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9612),
    [anon_sym_LBRACK] = ACTIONS(9612),
    [aux_sym_basic_type_token6] = ACTIONS(9614),
    [aux_sym_basic_type_token22] = ACTIONS(9614),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9612),
    [aux_sym_addafter_modification_token1] = ACTIONS(9612),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9612),
    [aux_sym_modify_modification_token1] = ACTIONS(9612),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9612),
    [aux_sym_movelast_modification_token1] = ACTIONS(9612),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9612),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9612),
    [aux_sym_separator_action_token1] = ACTIONS(9612),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9612),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9612),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9612),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9612),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9612),
    [anon_sym_POUNDif] = ACTIONS(9612),
    [anon_sym_POUNDIF] = ACTIONS(9612),
    [anon_sym_POUNDIf] = ACTIONS(9612),
    [anon_sym_POUNDelif] = ACTIONS(9612),
    [anon_sym_POUNDELIF] = ACTIONS(9612),
    [anon_sym_POUNDElif] = ACTIONS(9612),
    [anon_sym_POUNDelse] = ACTIONS(9612),
    [anon_sym_POUNDELSE] = ACTIONS(9612),
    [anon_sym_POUNDElse] = ACTIONS(9612),
    [anon_sym_POUNDelse2] = ACTIONS(9612),
    [anon_sym_POUNDELSE2] = ACTIONS(9612),
    [anon_sym_POUNDElse2] = ACTIONS(9612),
    [anon_sym_POUNDendif] = ACTIONS(9612),
    [anon_sym_POUNDENDIF] = ACTIONS(9612),
    [anon_sym_POUNDEndif] = ACTIONS(9612),
    [anon_sym_POUNDendif2] = ACTIONS(9612),
    [anon_sym_POUNDENDIF2] = ACTIONS(9612),
    [anon_sym_POUNDEndif2] = ACTIONS(9612),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9612),
    [sym_trigger_keyword] = ACTIONS(9612),
    [sym_var_keyword] = ACTIONS(9612),
    [sym_local_keyword] = ACTIONS(9612),
    [sym_internal_keyword] = ACTIONS(9612),
    [sym_protected_keyword] = ACTIONS(9612),
    [sym_event_keyword] = ACTIONS(9612),
    [sym_fields_keyword] = ACTIONS(9612),
    [sym_keys_keyword] = ACTIONS(9612),
    [sym_fieldgroups_keyword] = ACTIONS(9612),
    [sym_actions_keyword] = ACTIONS(9612),
    [sym_layout_keyword] = ACTIONS(9612),
    [sym_area_keyword] = ACTIONS(9612),
    [sym_group_keyword] = ACTIONS(9612),
    [sym_repeater_keyword] = ACTIONS(9612),
    [sym_cuegroup_keyword] = ACTIONS(9612),
    [sym_fixed_keyword] = ACTIONS(9612),
    [sym_grid_keyword] = ACTIONS(9612),
    [sym_part_keyword] = ACTIONS(9612),
    [sym_systempart_keyword] = ACTIONS(9612),
    [sym_usercontrol_keyword] = ACTIONS(9612),
    [sym_dataset_keyword] = ACTIONS(9612),
    [sym_elements_keyword] = ACTIONS(9612),
    [sym_dataitem_keyword] = ACTIONS(9612),
    [sym_column_keyword] = ACTIONS(9612),
    [sym_filter_keyword] = ACTIONS(9612),
    [sym_labels_keyword] = ACTIONS(9612),
    [sym_rendering_keyword] = ACTIONS(9612),
    [sym_requestpage_keyword] = ACTIONS(9612),
    [sym_schema_keyword] = ACTIONS(9612),
    [sym_views_keyword] = ACTIONS(9612),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9612),
    [sym_preproc_open] = ACTIONS(9612),
    [sym_preproc_close] = ACTIONS(9612),
  },
  [STATE(4220)] = {
    [anon_sym_SEMI] = ACTIONS(9616),
    [aux_sym_where_condition_token1] = ACTIONS(9618),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9616),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9616),
    [anon_sym_LBRACK] = ACTIONS(9616),
    [aux_sym_basic_type_token6] = ACTIONS(9618),
    [aux_sym_basic_type_token22] = ACTIONS(9618),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9616),
    [aux_sym_addafter_modification_token1] = ACTIONS(9616),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9616),
    [aux_sym_modify_modification_token1] = ACTIONS(9616),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9616),
    [aux_sym_movelast_modification_token1] = ACTIONS(9616),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9616),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9616),
    [aux_sym_separator_action_token1] = ACTIONS(9616),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9616),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9616),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9616),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9616),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9616),
    [anon_sym_POUNDif] = ACTIONS(9616),
    [anon_sym_POUNDIF] = ACTIONS(9616),
    [anon_sym_POUNDIf] = ACTIONS(9616),
    [anon_sym_POUNDelif] = ACTIONS(9616),
    [anon_sym_POUNDELIF] = ACTIONS(9616),
    [anon_sym_POUNDElif] = ACTIONS(9616),
    [anon_sym_POUNDelse] = ACTIONS(9616),
    [anon_sym_POUNDELSE] = ACTIONS(9616),
    [anon_sym_POUNDElse] = ACTIONS(9616),
    [anon_sym_POUNDelse2] = ACTIONS(9616),
    [anon_sym_POUNDELSE2] = ACTIONS(9616),
    [anon_sym_POUNDElse2] = ACTIONS(9616),
    [anon_sym_POUNDendif] = ACTIONS(9616),
    [anon_sym_POUNDENDIF] = ACTIONS(9616),
    [anon_sym_POUNDEndif] = ACTIONS(9616),
    [anon_sym_POUNDendif2] = ACTIONS(9616),
    [anon_sym_POUNDENDIF2] = ACTIONS(9616),
    [anon_sym_POUNDEndif2] = ACTIONS(9616),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9616),
    [sym_trigger_keyword] = ACTIONS(9616),
    [sym_var_keyword] = ACTIONS(9616),
    [sym_local_keyword] = ACTIONS(9616),
    [sym_internal_keyword] = ACTIONS(9616),
    [sym_protected_keyword] = ACTIONS(9616),
    [sym_event_keyword] = ACTIONS(9616),
    [sym_fields_keyword] = ACTIONS(9616),
    [sym_keys_keyword] = ACTIONS(9616),
    [sym_fieldgroups_keyword] = ACTIONS(9616),
    [sym_actions_keyword] = ACTIONS(9616),
    [sym_layout_keyword] = ACTIONS(9616),
    [sym_area_keyword] = ACTIONS(9616),
    [sym_group_keyword] = ACTIONS(9616),
    [sym_repeater_keyword] = ACTIONS(9616),
    [sym_cuegroup_keyword] = ACTIONS(9616),
    [sym_fixed_keyword] = ACTIONS(9616),
    [sym_grid_keyword] = ACTIONS(9616),
    [sym_part_keyword] = ACTIONS(9616),
    [sym_systempart_keyword] = ACTIONS(9616),
    [sym_usercontrol_keyword] = ACTIONS(9616),
    [sym_dataset_keyword] = ACTIONS(9616),
    [sym_elements_keyword] = ACTIONS(9616),
    [sym_dataitem_keyword] = ACTIONS(9616),
    [sym_column_keyword] = ACTIONS(9616),
    [sym_filter_keyword] = ACTIONS(9616),
    [sym_labels_keyword] = ACTIONS(9616),
    [sym_rendering_keyword] = ACTIONS(9616),
    [sym_requestpage_keyword] = ACTIONS(9616),
    [sym_schema_keyword] = ACTIONS(9616),
    [sym_views_keyword] = ACTIONS(9616),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9616),
    [sym_preproc_open] = ACTIONS(9616),
    [sym_preproc_close] = ACTIONS(9616),
  },
  [STATE(4221)] = {
    [anon_sym_SEMI] = ACTIONS(9620),
    [aux_sym_where_condition_token1] = ACTIONS(9622),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9620),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9620),
    [anon_sym_LBRACK] = ACTIONS(9620),
    [aux_sym_basic_type_token6] = ACTIONS(9622),
    [aux_sym_basic_type_token22] = ACTIONS(9622),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9620),
    [aux_sym_addafter_modification_token1] = ACTIONS(9620),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9620),
    [aux_sym_modify_modification_token1] = ACTIONS(9620),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9620),
    [aux_sym_movelast_modification_token1] = ACTIONS(9620),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9620),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9620),
    [aux_sym_separator_action_token1] = ACTIONS(9620),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9620),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9620),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9620),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9620),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9620),
    [anon_sym_POUNDif] = ACTIONS(9620),
    [anon_sym_POUNDIF] = ACTIONS(9620),
    [anon_sym_POUNDIf] = ACTIONS(9620),
    [anon_sym_POUNDelif] = ACTIONS(9620),
    [anon_sym_POUNDELIF] = ACTIONS(9620),
    [anon_sym_POUNDElif] = ACTIONS(9620),
    [anon_sym_POUNDelse] = ACTIONS(9620),
    [anon_sym_POUNDELSE] = ACTIONS(9620),
    [anon_sym_POUNDElse] = ACTIONS(9620),
    [anon_sym_POUNDelse2] = ACTIONS(9620),
    [anon_sym_POUNDELSE2] = ACTIONS(9620),
    [anon_sym_POUNDElse2] = ACTIONS(9620),
    [anon_sym_POUNDendif] = ACTIONS(9620),
    [anon_sym_POUNDENDIF] = ACTIONS(9620),
    [anon_sym_POUNDEndif] = ACTIONS(9620),
    [anon_sym_POUNDendif2] = ACTIONS(9620),
    [anon_sym_POUNDENDIF2] = ACTIONS(9620),
    [anon_sym_POUNDEndif2] = ACTIONS(9620),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9620),
    [sym_trigger_keyword] = ACTIONS(9620),
    [sym_var_keyword] = ACTIONS(9620),
    [sym_local_keyword] = ACTIONS(9620),
    [sym_internal_keyword] = ACTIONS(9620),
    [sym_protected_keyword] = ACTIONS(9620),
    [sym_event_keyword] = ACTIONS(9620),
    [sym_fields_keyword] = ACTIONS(9620),
    [sym_keys_keyword] = ACTIONS(9620),
    [sym_fieldgroups_keyword] = ACTIONS(9620),
    [sym_actions_keyword] = ACTIONS(9620),
    [sym_layout_keyword] = ACTIONS(9620),
    [sym_area_keyword] = ACTIONS(9620),
    [sym_group_keyword] = ACTIONS(9620),
    [sym_repeater_keyword] = ACTIONS(9620),
    [sym_cuegroup_keyword] = ACTIONS(9620),
    [sym_fixed_keyword] = ACTIONS(9620),
    [sym_grid_keyword] = ACTIONS(9620),
    [sym_part_keyword] = ACTIONS(9620),
    [sym_systempart_keyword] = ACTIONS(9620),
    [sym_usercontrol_keyword] = ACTIONS(9620),
    [sym_dataset_keyword] = ACTIONS(9620),
    [sym_elements_keyword] = ACTIONS(9620),
    [sym_dataitem_keyword] = ACTIONS(9620),
    [sym_column_keyword] = ACTIONS(9620),
    [sym_filter_keyword] = ACTIONS(9620),
    [sym_labels_keyword] = ACTIONS(9620),
    [sym_rendering_keyword] = ACTIONS(9620),
    [sym_requestpage_keyword] = ACTIONS(9620),
    [sym_schema_keyword] = ACTIONS(9620),
    [sym_views_keyword] = ACTIONS(9620),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9620),
    [sym_preproc_open] = ACTIONS(9620),
    [sym_preproc_close] = ACTIONS(9620),
  },
  [STATE(4222)] = {
    [sym_boolean] = STATE(11132),
    [sym_option_member] = STATE(11042),
    [sym_keyword_identifier] = STATE(11132),
    [sym_codeunit_keyword] = STATE(11155),
    [sym_xmlport_keyword] = STATE(11155),
    [sym_enum_keyword] = STATE(11155),
    [sym_keyword_as_identifier] = STATE(11132),
    [aux_sym_option_member_list_repeat2] = STATE(5326),
    [sym_identifier] = ACTIONS(9149),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(9624),
    [anon_sym_DASH] = ACTIONS(9153),
    [aux_sym_boolean_token1] = ACTIONS(9155),
    [aux_sym_boolean_token2] = ACTIONS(9155),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9157),
    [aux_sym_record_type_token1] = ACTIONS(9157),
    [aux_sym_basic_type_token21] = ACTIONS(9157),
    [aux_sym_basic_type_token22] = ACTIONS(9159),
    [aux_sym_basic_type_token48] = ACTIONS(9157),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDelif] = ACTIONS(600),
    [anon_sym_POUNDELIF] = ACTIONS(600),
    [anon_sym_POUNDElif] = ACTIONS(600),
    [anon_sym_POUNDelse] = ACTIONS(600),
    [anon_sym_POUNDELSE] = ACTIONS(600),
    [anon_sym_POUNDElse] = ACTIONS(600),
    [anon_sym_POUNDelse2] = ACTIONS(600),
    [anon_sym_POUNDELSE2] = ACTIONS(600),
    [anon_sym_POUNDElse2] = ACTIONS(600),
    [anon_sym_POUNDendif] = ACTIONS(600),
    [anon_sym_POUNDENDIF] = ACTIONS(600),
    [anon_sym_POUNDEndif] = ACTIONS(600),
    [anon_sym_POUNDendif2] = ACTIONS(600),
    [anon_sym_POUNDENDIF2] = ACTIONS(600),
    [anon_sym_POUNDEndif2] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9157),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(9157),
    [anon_sym_codeunit] = ACTIONS(9161),
    [anon_sym_CODEUNIT] = ACTIONS(9161),
    [anon_sym_Codeunit] = ACTIONS(9161),
    [anon_sym_CodeUnit] = ACTIONS(9161),
    [anon_sym_COdeunit] = ACTIONS(9161),
    [anon_sym_codeUnit] = ACTIONS(9161),
    [sym_report_keyword] = ACTIONS(9157),
    [sym_query_keyword] = ACTIONS(9157),
    [anon_sym_xmlport] = ACTIONS(9163),
    [anon_sym_XMLPORT] = ACTIONS(9163),
    [anon_sym_Xmlport] = ACTIONS(9163),
    [anon_sym_XMLport] = ACTIONS(9163),
    [anon_sym_XMLPort] = ACTIONS(9163),
    [anon_sym_XmlPort] = ACTIONS(9163),
    [anon_sym_enum] = ACTIONS(9165),
    [anon_sym_ENUM] = ACTIONS(9165),
    [anon_sym_Enum] = ACTIONS(9165),
    [anon_sym_eNUM] = ACTIONS(9165),
    [anon_sym_eNum] = ACTIONS(9165),
    [anon_sym_ENum] = ACTIONS(9165),
    [sym_local_keyword] = ACTIONS(9149),
    [sym_internal_keyword] = ACTIONS(9149),
    [sym_protected_keyword] = ACTIONS(9149),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(9167),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9167),
    [sym_integer] = ACTIONS(9167),
    [sym_preproc_close] = ACTIONS(600),
  },
  [STATE(4223)] = {
    [anon_sym_SEMI] = ACTIONS(9626),
    [aux_sym_where_condition_token1] = ACTIONS(9628),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9626),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9626),
    [anon_sym_LBRACK] = ACTIONS(9626),
    [aux_sym_basic_type_token6] = ACTIONS(9628),
    [aux_sym_basic_type_token22] = ACTIONS(9628),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9626),
    [aux_sym_addafter_modification_token1] = ACTIONS(9626),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9626),
    [aux_sym_modify_modification_token1] = ACTIONS(9626),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9626),
    [aux_sym_movelast_modification_token1] = ACTIONS(9626),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9626),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9626),
    [aux_sym_separator_action_token1] = ACTIONS(9626),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9626),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9626),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9626),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9626),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9626),
    [anon_sym_POUNDif] = ACTIONS(9626),
    [anon_sym_POUNDIF] = ACTIONS(9626),
    [anon_sym_POUNDIf] = ACTIONS(9626),
    [anon_sym_POUNDelif] = ACTIONS(9626),
    [anon_sym_POUNDELIF] = ACTIONS(9626),
    [anon_sym_POUNDElif] = ACTIONS(9626),
    [anon_sym_POUNDelse] = ACTIONS(9626),
    [anon_sym_POUNDELSE] = ACTIONS(9626),
    [anon_sym_POUNDElse] = ACTIONS(9626),
    [anon_sym_POUNDelse2] = ACTIONS(9626),
    [anon_sym_POUNDELSE2] = ACTIONS(9626),
    [anon_sym_POUNDElse2] = ACTIONS(9626),
    [anon_sym_POUNDendif] = ACTIONS(9626),
    [anon_sym_POUNDENDIF] = ACTIONS(9626),
    [anon_sym_POUNDEndif] = ACTIONS(9626),
    [anon_sym_POUNDendif2] = ACTIONS(9626),
    [anon_sym_POUNDENDIF2] = ACTIONS(9626),
    [anon_sym_POUNDEndif2] = ACTIONS(9626),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9626),
    [sym_trigger_keyword] = ACTIONS(9626),
    [sym_var_keyword] = ACTIONS(9626),
    [sym_local_keyword] = ACTIONS(9626),
    [sym_internal_keyword] = ACTIONS(9626),
    [sym_protected_keyword] = ACTIONS(9626),
    [sym_event_keyword] = ACTIONS(9626),
    [sym_fields_keyword] = ACTIONS(9626),
    [sym_keys_keyword] = ACTIONS(9626),
    [sym_fieldgroups_keyword] = ACTIONS(9626),
    [sym_actions_keyword] = ACTIONS(9626),
    [sym_layout_keyword] = ACTIONS(9626),
    [sym_area_keyword] = ACTIONS(9626),
    [sym_group_keyword] = ACTIONS(9626),
    [sym_repeater_keyword] = ACTIONS(9626),
    [sym_cuegroup_keyword] = ACTIONS(9626),
    [sym_fixed_keyword] = ACTIONS(9626),
    [sym_grid_keyword] = ACTIONS(9626),
    [sym_part_keyword] = ACTIONS(9626),
    [sym_systempart_keyword] = ACTIONS(9626),
    [sym_usercontrol_keyword] = ACTIONS(9626),
    [sym_dataset_keyword] = ACTIONS(9626),
    [sym_elements_keyword] = ACTIONS(9626),
    [sym_dataitem_keyword] = ACTIONS(9626),
    [sym_column_keyword] = ACTIONS(9626),
    [sym_filter_keyword] = ACTIONS(9626),
    [sym_labels_keyword] = ACTIONS(9626),
    [sym_rendering_keyword] = ACTIONS(9626),
    [sym_requestpage_keyword] = ACTIONS(9626),
    [sym_schema_keyword] = ACTIONS(9626),
    [sym_views_keyword] = ACTIONS(9626),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9626),
    [sym_preproc_open] = ACTIONS(9626),
    [sym_preproc_close] = ACTIONS(9626),
  },
  [STATE(4224)] = {
    [anon_sym_SEMI] = ACTIONS(9630),
    [aux_sym_where_condition_token1] = ACTIONS(9632),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9630),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9630),
    [anon_sym_LBRACK] = ACTIONS(9630),
    [aux_sym_basic_type_token6] = ACTIONS(9632),
    [aux_sym_basic_type_token22] = ACTIONS(9632),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9630),
    [aux_sym_addafter_modification_token1] = ACTIONS(9630),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9630),
    [aux_sym_modify_modification_token1] = ACTIONS(9630),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9630),
    [aux_sym_movelast_modification_token1] = ACTIONS(9630),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9630),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9630),
    [aux_sym_separator_action_token1] = ACTIONS(9630),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9630),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9630),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9630),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9630),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9630),
    [anon_sym_POUNDif] = ACTIONS(9630),
    [anon_sym_POUNDIF] = ACTIONS(9630),
    [anon_sym_POUNDIf] = ACTIONS(9630),
    [anon_sym_POUNDelif] = ACTIONS(9630),
    [anon_sym_POUNDELIF] = ACTIONS(9630),
    [anon_sym_POUNDElif] = ACTIONS(9630),
    [anon_sym_POUNDelse] = ACTIONS(9630),
    [anon_sym_POUNDELSE] = ACTIONS(9630),
    [anon_sym_POUNDElse] = ACTIONS(9630),
    [anon_sym_POUNDelse2] = ACTIONS(9630),
    [anon_sym_POUNDELSE2] = ACTIONS(9630),
    [anon_sym_POUNDElse2] = ACTIONS(9630),
    [anon_sym_POUNDendif] = ACTIONS(9630),
    [anon_sym_POUNDENDIF] = ACTIONS(9630),
    [anon_sym_POUNDEndif] = ACTIONS(9630),
    [anon_sym_POUNDendif2] = ACTIONS(9630),
    [anon_sym_POUNDENDIF2] = ACTIONS(9630),
    [anon_sym_POUNDEndif2] = ACTIONS(9630),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9630),
    [sym_trigger_keyword] = ACTIONS(9630),
    [sym_var_keyword] = ACTIONS(9630),
    [sym_local_keyword] = ACTIONS(9630),
    [sym_internal_keyword] = ACTIONS(9630),
    [sym_protected_keyword] = ACTIONS(9630),
    [sym_event_keyword] = ACTIONS(9630),
    [sym_fields_keyword] = ACTIONS(9630),
    [sym_keys_keyword] = ACTIONS(9630),
    [sym_fieldgroups_keyword] = ACTIONS(9630),
    [sym_actions_keyword] = ACTIONS(9630),
    [sym_layout_keyword] = ACTIONS(9630),
    [sym_area_keyword] = ACTIONS(9630),
    [sym_group_keyword] = ACTIONS(9630),
    [sym_repeater_keyword] = ACTIONS(9630),
    [sym_cuegroup_keyword] = ACTIONS(9630),
    [sym_fixed_keyword] = ACTIONS(9630),
    [sym_grid_keyword] = ACTIONS(9630),
    [sym_part_keyword] = ACTIONS(9630),
    [sym_systempart_keyword] = ACTIONS(9630),
    [sym_usercontrol_keyword] = ACTIONS(9630),
    [sym_dataset_keyword] = ACTIONS(9630),
    [sym_elements_keyword] = ACTIONS(9630),
    [sym_dataitem_keyword] = ACTIONS(9630),
    [sym_column_keyword] = ACTIONS(9630),
    [sym_filter_keyword] = ACTIONS(9630),
    [sym_labels_keyword] = ACTIONS(9630),
    [sym_rendering_keyword] = ACTIONS(9630),
    [sym_requestpage_keyword] = ACTIONS(9630),
    [sym_schema_keyword] = ACTIONS(9630),
    [sym_views_keyword] = ACTIONS(9630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9630),
    [sym_preproc_open] = ACTIONS(9630),
    [sym_preproc_close] = ACTIONS(9630),
  },
  [STATE(4225)] = {
    [anon_sym_SEMI] = ACTIONS(9634),
    [aux_sym_where_condition_token1] = ACTIONS(9636),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9634),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9634),
    [anon_sym_LBRACK] = ACTIONS(9634),
    [aux_sym_basic_type_token6] = ACTIONS(9636),
    [aux_sym_basic_type_token22] = ACTIONS(9636),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9634),
    [aux_sym_addafter_modification_token1] = ACTIONS(9634),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9634),
    [aux_sym_modify_modification_token1] = ACTIONS(9634),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9634),
    [aux_sym_movelast_modification_token1] = ACTIONS(9634),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9634),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9634),
    [aux_sym_separator_action_token1] = ACTIONS(9634),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9634),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9634),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9634),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9634),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9634),
    [anon_sym_POUNDif] = ACTIONS(9634),
    [anon_sym_POUNDIF] = ACTIONS(9634),
    [anon_sym_POUNDIf] = ACTIONS(9634),
    [anon_sym_POUNDelif] = ACTIONS(9634),
    [anon_sym_POUNDELIF] = ACTIONS(9634),
    [anon_sym_POUNDElif] = ACTIONS(9634),
    [anon_sym_POUNDelse] = ACTIONS(9634),
    [anon_sym_POUNDELSE] = ACTIONS(9634),
    [anon_sym_POUNDElse] = ACTIONS(9634),
    [anon_sym_POUNDelse2] = ACTIONS(9634),
    [anon_sym_POUNDELSE2] = ACTIONS(9634),
    [anon_sym_POUNDElse2] = ACTIONS(9634),
    [anon_sym_POUNDendif] = ACTIONS(9634),
    [anon_sym_POUNDENDIF] = ACTIONS(9634),
    [anon_sym_POUNDEndif] = ACTIONS(9634),
    [anon_sym_POUNDendif2] = ACTIONS(9634),
    [anon_sym_POUNDENDIF2] = ACTIONS(9634),
    [anon_sym_POUNDEndif2] = ACTIONS(9634),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9634),
    [sym_trigger_keyword] = ACTIONS(9634),
    [sym_var_keyword] = ACTIONS(9634),
    [sym_local_keyword] = ACTIONS(9634),
    [sym_internal_keyword] = ACTIONS(9634),
    [sym_protected_keyword] = ACTIONS(9634),
    [sym_event_keyword] = ACTIONS(9634),
    [sym_fields_keyword] = ACTIONS(9634),
    [sym_keys_keyword] = ACTIONS(9634),
    [sym_fieldgroups_keyword] = ACTIONS(9634),
    [sym_actions_keyword] = ACTIONS(9634),
    [sym_layout_keyword] = ACTIONS(9634),
    [sym_area_keyword] = ACTIONS(9634),
    [sym_group_keyword] = ACTIONS(9634),
    [sym_repeater_keyword] = ACTIONS(9634),
    [sym_cuegroup_keyword] = ACTIONS(9634),
    [sym_fixed_keyword] = ACTIONS(9634),
    [sym_grid_keyword] = ACTIONS(9634),
    [sym_part_keyword] = ACTIONS(9634),
    [sym_systempart_keyword] = ACTIONS(9634),
    [sym_usercontrol_keyword] = ACTIONS(9634),
    [sym_dataset_keyword] = ACTIONS(9634),
    [sym_elements_keyword] = ACTIONS(9634),
    [sym_dataitem_keyword] = ACTIONS(9634),
    [sym_column_keyword] = ACTIONS(9634),
    [sym_filter_keyword] = ACTIONS(9634),
    [sym_labels_keyword] = ACTIONS(9634),
    [sym_rendering_keyword] = ACTIONS(9634),
    [sym_requestpage_keyword] = ACTIONS(9634),
    [sym_schema_keyword] = ACTIONS(9634),
    [sym_views_keyword] = ACTIONS(9634),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9634),
    [sym_preproc_open] = ACTIONS(9634),
    [sym_preproc_close] = ACTIONS(9634),
  },
  [STATE(4226)] = {
    [anon_sym_SEMI] = ACTIONS(9638),
    [aux_sym_where_condition_token1] = ACTIONS(9640),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9638),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9638),
    [anon_sym_LBRACK] = ACTIONS(9638),
    [aux_sym_basic_type_token6] = ACTIONS(9640),
    [aux_sym_basic_type_token22] = ACTIONS(9640),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9638),
    [aux_sym_addafter_modification_token1] = ACTIONS(9638),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9638),
    [aux_sym_modify_modification_token1] = ACTIONS(9638),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9638),
    [aux_sym_movelast_modification_token1] = ACTIONS(9638),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9638),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9638),
    [aux_sym_separator_action_token1] = ACTIONS(9638),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9638),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9638),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9638),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9638),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9638),
    [anon_sym_POUNDif] = ACTIONS(9638),
    [anon_sym_POUNDIF] = ACTIONS(9638),
    [anon_sym_POUNDIf] = ACTIONS(9638),
    [anon_sym_POUNDelif] = ACTIONS(9638),
    [anon_sym_POUNDELIF] = ACTIONS(9638),
    [anon_sym_POUNDElif] = ACTIONS(9638),
    [anon_sym_POUNDelse] = ACTIONS(9638),
    [anon_sym_POUNDELSE] = ACTIONS(9638),
    [anon_sym_POUNDElse] = ACTIONS(9638),
    [anon_sym_POUNDelse2] = ACTIONS(9638),
    [anon_sym_POUNDELSE2] = ACTIONS(9638),
    [anon_sym_POUNDElse2] = ACTIONS(9638),
    [anon_sym_POUNDendif] = ACTIONS(9638),
    [anon_sym_POUNDENDIF] = ACTIONS(9638),
    [anon_sym_POUNDEndif] = ACTIONS(9638),
    [anon_sym_POUNDendif2] = ACTIONS(9638),
    [anon_sym_POUNDENDIF2] = ACTIONS(9638),
    [anon_sym_POUNDEndif2] = ACTIONS(9638),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9638),
    [sym_trigger_keyword] = ACTIONS(9638),
    [sym_var_keyword] = ACTIONS(9638),
    [sym_local_keyword] = ACTIONS(9638),
    [sym_internal_keyword] = ACTIONS(9638),
    [sym_protected_keyword] = ACTIONS(9638),
    [sym_event_keyword] = ACTIONS(9638),
    [sym_fields_keyword] = ACTIONS(9638),
    [sym_keys_keyword] = ACTIONS(9638),
    [sym_fieldgroups_keyword] = ACTIONS(9638),
    [sym_actions_keyword] = ACTIONS(9638),
    [sym_layout_keyword] = ACTIONS(9638),
    [sym_area_keyword] = ACTIONS(9638),
    [sym_group_keyword] = ACTIONS(9638),
    [sym_repeater_keyword] = ACTIONS(9638),
    [sym_cuegroup_keyword] = ACTIONS(9638),
    [sym_fixed_keyword] = ACTIONS(9638),
    [sym_grid_keyword] = ACTIONS(9638),
    [sym_part_keyword] = ACTIONS(9638),
    [sym_systempart_keyword] = ACTIONS(9638),
    [sym_usercontrol_keyword] = ACTIONS(9638),
    [sym_dataset_keyword] = ACTIONS(9638),
    [sym_elements_keyword] = ACTIONS(9638),
    [sym_dataitem_keyword] = ACTIONS(9638),
    [sym_column_keyword] = ACTIONS(9638),
    [sym_filter_keyword] = ACTIONS(9638),
    [sym_labels_keyword] = ACTIONS(9638),
    [sym_rendering_keyword] = ACTIONS(9638),
    [sym_requestpage_keyword] = ACTIONS(9638),
    [sym_schema_keyword] = ACTIONS(9638),
    [sym_views_keyword] = ACTIONS(9638),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9638),
    [sym_preproc_open] = ACTIONS(9638),
    [sym_preproc_close] = ACTIONS(9638),
  },
  [STATE(4227)] = {
    [anon_sym_SEMI] = ACTIONS(9642),
    [aux_sym_where_condition_token1] = ACTIONS(9644),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9642),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9642),
    [anon_sym_LBRACK] = ACTIONS(9642),
    [aux_sym_basic_type_token6] = ACTIONS(9644),
    [aux_sym_basic_type_token22] = ACTIONS(9644),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9642),
    [aux_sym_addafter_modification_token1] = ACTIONS(9642),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9642),
    [aux_sym_modify_modification_token1] = ACTIONS(9642),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9642),
    [aux_sym_movelast_modification_token1] = ACTIONS(9642),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9642),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9642),
    [aux_sym_separator_action_token1] = ACTIONS(9642),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9642),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9642),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9642),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9642),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9642),
    [anon_sym_POUNDif] = ACTIONS(9642),
    [anon_sym_POUNDIF] = ACTIONS(9642),
    [anon_sym_POUNDIf] = ACTIONS(9642),
    [anon_sym_POUNDelif] = ACTIONS(9642),
    [anon_sym_POUNDELIF] = ACTIONS(9642),
    [anon_sym_POUNDElif] = ACTIONS(9642),
    [anon_sym_POUNDelse] = ACTIONS(9642),
    [anon_sym_POUNDELSE] = ACTIONS(9642),
    [anon_sym_POUNDElse] = ACTIONS(9642),
    [anon_sym_POUNDelse2] = ACTIONS(9642),
    [anon_sym_POUNDELSE2] = ACTIONS(9642),
    [anon_sym_POUNDElse2] = ACTIONS(9642),
    [anon_sym_POUNDendif] = ACTIONS(9642),
    [anon_sym_POUNDENDIF] = ACTIONS(9642),
    [anon_sym_POUNDEndif] = ACTIONS(9642),
    [anon_sym_POUNDendif2] = ACTIONS(9642),
    [anon_sym_POUNDENDIF2] = ACTIONS(9642),
    [anon_sym_POUNDEndif2] = ACTIONS(9642),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9642),
    [sym_trigger_keyword] = ACTIONS(9642),
    [sym_var_keyword] = ACTIONS(9642),
    [sym_local_keyword] = ACTIONS(9642),
    [sym_internal_keyword] = ACTIONS(9642),
    [sym_protected_keyword] = ACTIONS(9642),
    [sym_event_keyword] = ACTIONS(9642),
    [sym_fields_keyword] = ACTIONS(9642),
    [sym_keys_keyword] = ACTIONS(9642),
    [sym_fieldgroups_keyword] = ACTIONS(9642),
    [sym_actions_keyword] = ACTIONS(9642),
    [sym_layout_keyword] = ACTIONS(9642),
    [sym_area_keyword] = ACTIONS(9642),
    [sym_group_keyword] = ACTIONS(9642),
    [sym_repeater_keyword] = ACTIONS(9642),
    [sym_cuegroup_keyword] = ACTIONS(9642),
    [sym_fixed_keyword] = ACTIONS(9642),
    [sym_grid_keyword] = ACTIONS(9642),
    [sym_part_keyword] = ACTIONS(9642),
    [sym_systempart_keyword] = ACTIONS(9642),
    [sym_usercontrol_keyword] = ACTIONS(9642),
    [sym_dataset_keyword] = ACTIONS(9642),
    [sym_elements_keyword] = ACTIONS(9642),
    [sym_dataitem_keyword] = ACTIONS(9642),
    [sym_column_keyword] = ACTIONS(9642),
    [sym_filter_keyword] = ACTIONS(9642),
    [sym_labels_keyword] = ACTIONS(9642),
    [sym_rendering_keyword] = ACTIONS(9642),
    [sym_requestpage_keyword] = ACTIONS(9642),
    [sym_schema_keyword] = ACTIONS(9642),
    [sym_views_keyword] = ACTIONS(9642),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9642),
    [sym_preproc_open] = ACTIONS(9642),
    [sym_preproc_close] = ACTIONS(9642),
  },
  [STATE(4228)] = {
    [sym_identifier] = ACTIONS(8383),
    [anon_sym_SEMI] = ACTIONS(8379),
    [anon_sym_COMMA] = ACTIONS(9646),
    [aux_sym_where_condition_token1] = ACTIONS(8383),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8383),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8383),
    [anon_sym_LBRACK] = ACTIONS(8379),
    [aux_sym_basic_type_token22] = ACTIONS(8383),
    [aux_sym_basic_type_token53] = ACTIONS(8383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8383),
    [aux_sym_modify_modification_token1] = ACTIONS(8383),
    [aux_sym_separator_action_token1] = ACTIONS(8383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8383),
    [aux_sym_type_declaration_token1] = ACTIONS(8383),
    [anon_sym_POUNDif] = ACTIONS(8379),
    [anon_sym_POUNDIF] = ACTIONS(8379),
    [anon_sym_POUNDIf] = ACTIONS(8379),
    [anon_sym_POUNDelif] = ACTIONS(8379),
    [anon_sym_POUNDELIF] = ACTIONS(8379),
    [anon_sym_POUNDElif] = ACTIONS(8379),
    [anon_sym_POUNDelse] = ACTIONS(8379),
    [anon_sym_POUNDELSE] = ACTIONS(8379),
    [anon_sym_POUNDElse] = ACTIONS(8379),
    [anon_sym_POUNDelse2] = ACTIONS(8379),
    [anon_sym_POUNDELSE2] = ACTIONS(8379),
    [anon_sym_POUNDElse2] = ACTIONS(8379),
    [anon_sym_POUNDendif] = ACTIONS(8379),
    [anon_sym_POUNDENDIF] = ACTIONS(8379),
    [anon_sym_POUNDEndif] = ACTIONS(8379),
    [anon_sym_POUNDendif2] = ACTIONS(8379),
    [anon_sym_POUNDENDIF2] = ACTIONS(8379),
    [anon_sym_POUNDEndif2] = ACTIONS(8379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8383),
    [sym_page_keyword] = ACTIONS(8383),
    [anon_sym_codeunit] = ACTIONS(8383),
    [anon_sym_CODEUNIT] = ACTIONS(8383),
    [anon_sym_Codeunit] = ACTIONS(8383),
    [anon_sym_CodeUnit] = ACTIONS(8383),
    [anon_sym_COdeunit] = ACTIONS(8383),
    [anon_sym_codeUnit] = ACTIONS(8383),
    [sym_report_keyword] = ACTIONS(8383),
    [sym_query_keyword] = ACTIONS(8383),
    [anon_sym_xmlport] = ACTIONS(8383),
    [anon_sym_XMLPORT] = ACTIONS(8383),
    [anon_sym_Xmlport] = ACTIONS(8383),
    [anon_sym_XMLport] = ACTIONS(8383),
    [anon_sym_XMLPort] = ACTIONS(8383),
    [anon_sym_XmlPort] = ACTIONS(8383),
    [sym_procedure_keyword] = ACTIONS(8383),
    [sym_trigger_keyword] = ACTIONS(8383),
    [sym_var_keyword] = ACTIONS(8383),
    [sym_local_keyword] = ACTIONS(8383),
    [sym_internal_keyword] = ACTIONS(8383),
    [sym_protected_keyword] = ACTIONS(8383),
    [sym_event_keyword] = ACTIONS(8383),
    [sym_fields_keyword] = ACTIONS(8383),
    [sym_keys_keyword] = ACTIONS(8383),
    [sym_key_keyword] = ACTIONS(8383),
    [sym_fieldgroups_keyword] = ACTIONS(8383),
    [sym_actions_keyword] = ACTIONS(8383),
    [sym_layout_keyword] = ACTIONS(8383),
    [sym_dataset_keyword] = ACTIONS(8383),
    [sym_elements_keyword] = ACTIONS(8383),
    [sym_labels_keyword] = ACTIONS(8383),
    [sym_rendering_keyword] = ACTIONS(8383),
    [sym_requestpage_keyword] = ACTIONS(8383),
    [sym_schema_keyword] = ACTIONS(8383),
    [sym_views_keyword] = ACTIONS(8383),
    [sym_quoted_identifier] = ACTIONS(8379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8379),
    [sym_preproc_open] = ACTIONS(8379),
    [sym_preproc_close] = ACTIONS(8379),
    [sym_var_attribute_open] = ACTIONS(8379),
  },
  [STATE(4229)] = {
    [anon_sym_SEMI] = ACTIONS(9648),
    [aux_sym_where_condition_token1] = ACTIONS(9650),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9648),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9648),
    [anon_sym_LBRACK] = ACTIONS(9648),
    [aux_sym_basic_type_token6] = ACTIONS(9650),
    [aux_sym_basic_type_token22] = ACTIONS(9650),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9648),
    [aux_sym_addafter_modification_token1] = ACTIONS(9648),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9648),
    [aux_sym_modify_modification_token1] = ACTIONS(9648),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9648),
    [aux_sym_movelast_modification_token1] = ACTIONS(9648),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9648),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9648),
    [aux_sym_separator_action_token1] = ACTIONS(9648),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9648),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9648),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9648),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9648),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9648),
    [anon_sym_POUNDif] = ACTIONS(9648),
    [anon_sym_POUNDIF] = ACTIONS(9648),
    [anon_sym_POUNDIf] = ACTIONS(9648),
    [anon_sym_POUNDelif] = ACTIONS(9648),
    [anon_sym_POUNDELIF] = ACTIONS(9648),
    [anon_sym_POUNDElif] = ACTIONS(9648),
    [anon_sym_POUNDelse] = ACTIONS(9648),
    [anon_sym_POUNDELSE] = ACTIONS(9648),
    [anon_sym_POUNDElse] = ACTIONS(9648),
    [anon_sym_POUNDelse2] = ACTIONS(9648),
    [anon_sym_POUNDELSE2] = ACTIONS(9648),
    [anon_sym_POUNDElse2] = ACTIONS(9648),
    [anon_sym_POUNDendif] = ACTIONS(9648),
    [anon_sym_POUNDENDIF] = ACTIONS(9648),
    [anon_sym_POUNDEndif] = ACTIONS(9648),
    [anon_sym_POUNDendif2] = ACTIONS(9648),
    [anon_sym_POUNDENDIF2] = ACTIONS(9648),
    [anon_sym_POUNDEndif2] = ACTIONS(9648),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9648),
    [sym_trigger_keyword] = ACTIONS(9648),
    [sym_var_keyword] = ACTIONS(9648),
    [sym_local_keyword] = ACTIONS(9648),
    [sym_internal_keyword] = ACTIONS(9648),
    [sym_protected_keyword] = ACTIONS(9648),
    [sym_event_keyword] = ACTIONS(9648),
    [sym_fields_keyword] = ACTIONS(9648),
    [sym_keys_keyword] = ACTIONS(9648),
    [sym_fieldgroups_keyword] = ACTIONS(9648),
    [sym_actions_keyword] = ACTIONS(9648),
    [sym_layout_keyword] = ACTIONS(9648),
    [sym_area_keyword] = ACTIONS(9648),
    [sym_group_keyword] = ACTIONS(9648),
    [sym_repeater_keyword] = ACTIONS(9648),
    [sym_cuegroup_keyword] = ACTIONS(9648),
    [sym_fixed_keyword] = ACTIONS(9648),
    [sym_grid_keyword] = ACTIONS(9648),
    [sym_part_keyword] = ACTIONS(9648),
    [sym_systempart_keyword] = ACTIONS(9648),
    [sym_usercontrol_keyword] = ACTIONS(9648),
    [sym_dataset_keyword] = ACTIONS(9648),
    [sym_elements_keyword] = ACTIONS(9648),
    [sym_dataitem_keyword] = ACTIONS(9648),
    [sym_column_keyword] = ACTIONS(9648),
    [sym_filter_keyword] = ACTIONS(9648),
    [sym_labels_keyword] = ACTIONS(9648),
    [sym_rendering_keyword] = ACTIONS(9648),
    [sym_requestpage_keyword] = ACTIONS(9648),
    [sym_schema_keyword] = ACTIONS(9648),
    [sym_views_keyword] = ACTIONS(9648),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9648),
    [sym_preproc_open] = ACTIONS(9648),
    [sym_preproc_close] = ACTIONS(9648),
  },
  [STATE(4230)] = {
    [anon_sym_SEMI] = ACTIONS(9648),
    [aux_sym_where_condition_token1] = ACTIONS(9650),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9648),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9648),
    [anon_sym_LBRACK] = ACTIONS(9648),
    [aux_sym_basic_type_token6] = ACTIONS(9650),
    [aux_sym_basic_type_token22] = ACTIONS(9650),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9648),
    [aux_sym_addafter_modification_token1] = ACTIONS(9648),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9648),
    [aux_sym_modify_modification_token1] = ACTIONS(9648),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9648),
    [aux_sym_movelast_modification_token1] = ACTIONS(9648),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9648),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9648),
    [aux_sym_separator_action_token1] = ACTIONS(9648),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9648),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9648),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9648),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9648),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9648),
    [anon_sym_POUNDif] = ACTIONS(9648),
    [anon_sym_POUNDIF] = ACTIONS(9648),
    [anon_sym_POUNDIf] = ACTIONS(9648),
    [anon_sym_POUNDelif] = ACTIONS(9648),
    [anon_sym_POUNDELIF] = ACTIONS(9648),
    [anon_sym_POUNDElif] = ACTIONS(9648),
    [anon_sym_POUNDelse] = ACTIONS(9648),
    [anon_sym_POUNDELSE] = ACTIONS(9648),
    [anon_sym_POUNDElse] = ACTIONS(9648),
    [anon_sym_POUNDelse2] = ACTIONS(9648),
    [anon_sym_POUNDELSE2] = ACTIONS(9648),
    [anon_sym_POUNDElse2] = ACTIONS(9648),
    [anon_sym_POUNDendif] = ACTIONS(9648),
    [anon_sym_POUNDENDIF] = ACTIONS(9648),
    [anon_sym_POUNDEndif] = ACTIONS(9648),
    [anon_sym_POUNDendif2] = ACTIONS(9648),
    [anon_sym_POUNDENDIF2] = ACTIONS(9648),
    [anon_sym_POUNDEndif2] = ACTIONS(9648),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9648),
    [sym_trigger_keyword] = ACTIONS(9648),
    [sym_var_keyword] = ACTIONS(9648),
    [sym_local_keyword] = ACTIONS(9648),
    [sym_internal_keyword] = ACTIONS(9648),
    [sym_protected_keyword] = ACTIONS(9648),
    [sym_event_keyword] = ACTIONS(9648),
    [sym_fields_keyword] = ACTIONS(9648),
    [sym_keys_keyword] = ACTIONS(9648),
    [sym_fieldgroups_keyword] = ACTIONS(9648),
    [sym_actions_keyword] = ACTIONS(9648),
    [sym_layout_keyword] = ACTIONS(9648),
    [sym_area_keyword] = ACTIONS(9648),
    [sym_group_keyword] = ACTIONS(9648),
    [sym_repeater_keyword] = ACTIONS(9648),
    [sym_cuegroup_keyword] = ACTIONS(9648),
    [sym_fixed_keyword] = ACTIONS(9648),
    [sym_grid_keyword] = ACTIONS(9648),
    [sym_part_keyword] = ACTIONS(9648),
    [sym_systempart_keyword] = ACTIONS(9648),
    [sym_usercontrol_keyword] = ACTIONS(9648),
    [sym_dataset_keyword] = ACTIONS(9648),
    [sym_elements_keyword] = ACTIONS(9648),
    [sym_dataitem_keyword] = ACTIONS(9648),
    [sym_column_keyword] = ACTIONS(9648),
    [sym_filter_keyword] = ACTIONS(9648),
    [sym_labels_keyword] = ACTIONS(9648),
    [sym_rendering_keyword] = ACTIONS(9648),
    [sym_requestpage_keyword] = ACTIONS(9648),
    [sym_schema_keyword] = ACTIONS(9648),
    [sym_views_keyword] = ACTIONS(9648),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9648),
    [sym_preproc_open] = ACTIONS(9648),
    [sym_preproc_close] = ACTIONS(9648),
  },
  [STATE(4231)] = {
    [anon_sym_SEMI] = ACTIONS(9652),
    [aux_sym_where_condition_token1] = ACTIONS(9654),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9652),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9652),
    [anon_sym_LBRACK] = ACTIONS(9652),
    [aux_sym_basic_type_token6] = ACTIONS(9654),
    [aux_sym_basic_type_token22] = ACTIONS(9654),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9652),
    [aux_sym_addafter_modification_token1] = ACTIONS(9652),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9652),
    [aux_sym_modify_modification_token1] = ACTIONS(9652),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9652),
    [aux_sym_movelast_modification_token1] = ACTIONS(9652),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9652),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9652),
    [aux_sym_separator_action_token1] = ACTIONS(9652),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9652),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9652),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9652),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9652),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9652),
    [anon_sym_POUNDif] = ACTIONS(9652),
    [anon_sym_POUNDIF] = ACTIONS(9652),
    [anon_sym_POUNDIf] = ACTIONS(9652),
    [anon_sym_POUNDelif] = ACTIONS(9652),
    [anon_sym_POUNDELIF] = ACTIONS(9652),
    [anon_sym_POUNDElif] = ACTIONS(9652),
    [anon_sym_POUNDelse] = ACTIONS(9652),
    [anon_sym_POUNDELSE] = ACTIONS(9652),
    [anon_sym_POUNDElse] = ACTIONS(9652),
    [anon_sym_POUNDelse2] = ACTIONS(9652),
    [anon_sym_POUNDELSE2] = ACTIONS(9652),
    [anon_sym_POUNDElse2] = ACTIONS(9652),
    [anon_sym_POUNDendif] = ACTIONS(9652),
    [anon_sym_POUNDENDIF] = ACTIONS(9652),
    [anon_sym_POUNDEndif] = ACTIONS(9652),
    [anon_sym_POUNDendif2] = ACTIONS(9652),
    [anon_sym_POUNDENDIF2] = ACTIONS(9652),
    [anon_sym_POUNDEndif2] = ACTIONS(9652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9652),
    [sym_trigger_keyword] = ACTIONS(9652),
    [sym_var_keyword] = ACTIONS(9652),
    [sym_local_keyword] = ACTIONS(9652),
    [sym_internal_keyword] = ACTIONS(9652),
    [sym_protected_keyword] = ACTIONS(9652),
    [sym_event_keyword] = ACTIONS(9652),
    [sym_fields_keyword] = ACTIONS(9652),
    [sym_keys_keyword] = ACTIONS(9652),
    [sym_fieldgroups_keyword] = ACTIONS(9652),
    [sym_actions_keyword] = ACTIONS(9652),
    [sym_layout_keyword] = ACTIONS(9652),
    [sym_area_keyword] = ACTIONS(9652),
    [sym_group_keyword] = ACTIONS(9652),
    [sym_repeater_keyword] = ACTIONS(9652),
    [sym_cuegroup_keyword] = ACTIONS(9652),
    [sym_fixed_keyword] = ACTIONS(9652),
    [sym_grid_keyword] = ACTIONS(9652),
    [sym_part_keyword] = ACTIONS(9652),
    [sym_systempart_keyword] = ACTIONS(9652),
    [sym_usercontrol_keyword] = ACTIONS(9652),
    [sym_dataset_keyword] = ACTIONS(9652),
    [sym_elements_keyword] = ACTIONS(9652),
    [sym_dataitem_keyword] = ACTIONS(9652),
    [sym_column_keyword] = ACTIONS(9652),
    [sym_filter_keyword] = ACTIONS(9652),
    [sym_labels_keyword] = ACTIONS(9652),
    [sym_rendering_keyword] = ACTIONS(9652),
    [sym_requestpage_keyword] = ACTIONS(9652),
    [sym_schema_keyword] = ACTIONS(9652),
    [sym_views_keyword] = ACTIONS(9652),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9652),
    [sym_preproc_open] = ACTIONS(9652),
    [sym_preproc_close] = ACTIONS(9652),
  },
  [STATE(4232)] = {
    [anon_sym_SEMI] = ACTIONS(9652),
    [aux_sym_where_condition_token1] = ACTIONS(9654),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9652),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9652),
    [anon_sym_LBRACK] = ACTIONS(9652),
    [aux_sym_basic_type_token6] = ACTIONS(9654),
    [aux_sym_basic_type_token22] = ACTIONS(9654),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9652),
    [aux_sym_addafter_modification_token1] = ACTIONS(9652),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9652),
    [aux_sym_modify_modification_token1] = ACTIONS(9652),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9652),
    [aux_sym_movelast_modification_token1] = ACTIONS(9652),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9652),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9652),
    [aux_sym_separator_action_token1] = ACTIONS(9652),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9652),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9652),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9652),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9652),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9652),
    [anon_sym_POUNDif] = ACTIONS(9652),
    [anon_sym_POUNDIF] = ACTIONS(9652),
    [anon_sym_POUNDIf] = ACTIONS(9652),
    [anon_sym_POUNDelif] = ACTIONS(9652),
    [anon_sym_POUNDELIF] = ACTIONS(9652),
    [anon_sym_POUNDElif] = ACTIONS(9652),
    [anon_sym_POUNDelse] = ACTIONS(9652),
    [anon_sym_POUNDELSE] = ACTIONS(9652),
    [anon_sym_POUNDElse] = ACTIONS(9652),
    [anon_sym_POUNDelse2] = ACTIONS(9652),
    [anon_sym_POUNDELSE2] = ACTIONS(9652),
    [anon_sym_POUNDElse2] = ACTIONS(9652),
    [anon_sym_POUNDendif] = ACTIONS(9652),
    [anon_sym_POUNDENDIF] = ACTIONS(9652),
    [anon_sym_POUNDEndif] = ACTIONS(9652),
    [anon_sym_POUNDendif2] = ACTIONS(9652),
    [anon_sym_POUNDENDIF2] = ACTIONS(9652),
    [anon_sym_POUNDEndif2] = ACTIONS(9652),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9652),
    [sym_trigger_keyword] = ACTIONS(9652),
    [sym_var_keyword] = ACTIONS(9652),
    [sym_local_keyword] = ACTIONS(9652),
    [sym_internal_keyword] = ACTIONS(9652),
    [sym_protected_keyword] = ACTIONS(9652),
    [sym_event_keyword] = ACTIONS(9652),
    [sym_fields_keyword] = ACTIONS(9652),
    [sym_keys_keyword] = ACTIONS(9652),
    [sym_fieldgroups_keyword] = ACTIONS(9652),
    [sym_actions_keyword] = ACTIONS(9652),
    [sym_layout_keyword] = ACTIONS(9652),
    [sym_area_keyword] = ACTIONS(9652),
    [sym_group_keyword] = ACTIONS(9652),
    [sym_repeater_keyword] = ACTIONS(9652),
    [sym_cuegroup_keyword] = ACTIONS(9652),
    [sym_fixed_keyword] = ACTIONS(9652),
    [sym_grid_keyword] = ACTIONS(9652),
    [sym_part_keyword] = ACTIONS(9652),
    [sym_systempart_keyword] = ACTIONS(9652),
    [sym_usercontrol_keyword] = ACTIONS(9652),
    [sym_dataset_keyword] = ACTIONS(9652),
    [sym_elements_keyword] = ACTIONS(9652),
    [sym_dataitem_keyword] = ACTIONS(9652),
    [sym_column_keyword] = ACTIONS(9652),
    [sym_filter_keyword] = ACTIONS(9652),
    [sym_labels_keyword] = ACTIONS(9652),
    [sym_rendering_keyword] = ACTIONS(9652),
    [sym_requestpage_keyword] = ACTIONS(9652),
    [sym_schema_keyword] = ACTIONS(9652),
    [sym_views_keyword] = ACTIONS(9652),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9652),
    [sym_preproc_open] = ACTIONS(9652),
    [sym_preproc_close] = ACTIONS(9652),
  },
  [STATE(4233)] = {
    [anon_sym_SEMI] = ACTIONS(9620),
    [aux_sym_where_condition_token1] = ACTIONS(9622),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9620),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9620),
    [anon_sym_LBRACK] = ACTIONS(9620),
    [aux_sym_basic_type_token6] = ACTIONS(9622),
    [aux_sym_basic_type_token22] = ACTIONS(9622),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9620),
    [aux_sym_addafter_modification_token1] = ACTIONS(9620),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9620),
    [aux_sym_modify_modification_token1] = ACTIONS(9620),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9620),
    [aux_sym_movelast_modification_token1] = ACTIONS(9620),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9620),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9620),
    [aux_sym_separator_action_token1] = ACTIONS(9620),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9620),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9620),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9620),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9620),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9620),
    [anon_sym_POUNDif] = ACTIONS(9620),
    [anon_sym_POUNDIF] = ACTIONS(9620),
    [anon_sym_POUNDIf] = ACTIONS(9620),
    [anon_sym_POUNDelif] = ACTIONS(9620),
    [anon_sym_POUNDELIF] = ACTIONS(9620),
    [anon_sym_POUNDElif] = ACTIONS(9620),
    [anon_sym_POUNDelse] = ACTIONS(9620),
    [anon_sym_POUNDELSE] = ACTIONS(9620),
    [anon_sym_POUNDElse] = ACTIONS(9620),
    [anon_sym_POUNDelse2] = ACTIONS(9620),
    [anon_sym_POUNDELSE2] = ACTIONS(9620),
    [anon_sym_POUNDElse2] = ACTIONS(9620),
    [anon_sym_POUNDendif] = ACTIONS(9620),
    [anon_sym_POUNDENDIF] = ACTIONS(9620),
    [anon_sym_POUNDEndif] = ACTIONS(9620),
    [anon_sym_POUNDendif2] = ACTIONS(9620),
    [anon_sym_POUNDENDIF2] = ACTIONS(9620),
    [anon_sym_POUNDEndif2] = ACTIONS(9620),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9620),
    [sym_trigger_keyword] = ACTIONS(9620),
    [sym_var_keyword] = ACTIONS(9620),
    [sym_local_keyword] = ACTIONS(9620),
    [sym_internal_keyword] = ACTIONS(9620),
    [sym_protected_keyword] = ACTIONS(9620),
    [sym_event_keyword] = ACTIONS(9620),
    [sym_fields_keyword] = ACTIONS(9620),
    [sym_keys_keyword] = ACTIONS(9620),
    [sym_fieldgroups_keyword] = ACTIONS(9620),
    [sym_actions_keyword] = ACTIONS(9620),
    [sym_layout_keyword] = ACTIONS(9620),
    [sym_area_keyword] = ACTIONS(9620),
    [sym_group_keyword] = ACTIONS(9620),
    [sym_repeater_keyword] = ACTIONS(9620),
    [sym_cuegroup_keyword] = ACTIONS(9620),
    [sym_fixed_keyword] = ACTIONS(9620),
    [sym_grid_keyword] = ACTIONS(9620),
    [sym_part_keyword] = ACTIONS(9620),
    [sym_systempart_keyword] = ACTIONS(9620),
    [sym_usercontrol_keyword] = ACTIONS(9620),
    [sym_dataset_keyword] = ACTIONS(9620),
    [sym_elements_keyword] = ACTIONS(9620),
    [sym_dataitem_keyword] = ACTIONS(9620),
    [sym_column_keyword] = ACTIONS(9620),
    [sym_filter_keyword] = ACTIONS(9620),
    [sym_labels_keyword] = ACTIONS(9620),
    [sym_rendering_keyword] = ACTIONS(9620),
    [sym_requestpage_keyword] = ACTIONS(9620),
    [sym_schema_keyword] = ACTIONS(9620),
    [sym_views_keyword] = ACTIONS(9620),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9620),
    [sym_preproc_open] = ACTIONS(9620),
    [sym_preproc_close] = ACTIONS(9620),
  },
  [STATE(4234)] = {
    [anon_sym_SEMI] = ACTIONS(9656),
    [aux_sym_where_condition_token1] = ACTIONS(9658),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9656),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9656),
    [anon_sym_LBRACK] = ACTIONS(9656),
    [aux_sym_basic_type_token6] = ACTIONS(9658),
    [aux_sym_basic_type_token22] = ACTIONS(9658),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9656),
    [aux_sym_addafter_modification_token1] = ACTIONS(9656),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9656),
    [aux_sym_modify_modification_token1] = ACTIONS(9656),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9656),
    [aux_sym_movelast_modification_token1] = ACTIONS(9656),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9656),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9656),
    [aux_sym_separator_action_token1] = ACTIONS(9656),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9656),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9656),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9656),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9656),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9656),
    [anon_sym_POUNDif] = ACTIONS(9656),
    [anon_sym_POUNDIF] = ACTIONS(9656),
    [anon_sym_POUNDIf] = ACTIONS(9656),
    [anon_sym_POUNDelif] = ACTIONS(9656),
    [anon_sym_POUNDELIF] = ACTIONS(9656),
    [anon_sym_POUNDElif] = ACTIONS(9656),
    [anon_sym_POUNDelse] = ACTIONS(9656),
    [anon_sym_POUNDELSE] = ACTIONS(9656),
    [anon_sym_POUNDElse] = ACTIONS(9656),
    [anon_sym_POUNDelse2] = ACTIONS(9656),
    [anon_sym_POUNDELSE2] = ACTIONS(9656),
    [anon_sym_POUNDElse2] = ACTIONS(9656),
    [anon_sym_POUNDendif] = ACTIONS(9656),
    [anon_sym_POUNDENDIF] = ACTIONS(9656),
    [anon_sym_POUNDEndif] = ACTIONS(9656),
    [anon_sym_POUNDendif2] = ACTIONS(9656),
    [anon_sym_POUNDENDIF2] = ACTIONS(9656),
    [anon_sym_POUNDEndif2] = ACTIONS(9656),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9656),
    [sym_trigger_keyword] = ACTIONS(9656),
    [sym_var_keyword] = ACTIONS(9656),
    [sym_local_keyword] = ACTIONS(9656),
    [sym_internal_keyword] = ACTIONS(9656),
    [sym_protected_keyword] = ACTIONS(9656),
    [sym_event_keyword] = ACTIONS(9656),
    [sym_fields_keyword] = ACTIONS(9656),
    [sym_keys_keyword] = ACTIONS(9656),
    [sym_fieldgroups_keyword] = ACTIONS(9656),
    [sym_actions_keyword] = ACTIONS(9656),
    [sym_layout_keyword] = ACTIONS(9656),
    [sym_area_keyword] = ACTIONS(9656),
    [sym_group_keyword] = ACTIONS(9656),
    [sym_repeater_keyword] = ACTIONS(9656),
    [sym_cuegroup_keyword] = ACTIONS(9656),
    [sym_fixed_keyword] = ACTIONS(9656),
    [sym_grid_keyword] = ACTIONS(9656),
    [sym_part_keyword] = ACTIONS(9656),
    [sym_systempart_keyword] = ACTIONS(9656),
    [sym_usercontrol_keyword] = ACTIONS(9656),
    [sym_dataset_keyword] = ACTIONS(9656),
    [sym_elements_keyword] = ACTIONS(9656),
    [sym_dataitem_keyword] = ACTIONS(9656),
    [sym_column_keyword] = ACTIONS(9656),
    [sym_filter_keyword] = ACTIONS(9656),
    [sym_labels_keyword] = ACTIONS(9656),
    [sym_rendering_keyword] = ACTIONS(9656),
    [sym_requestpage_keyword] = ACTIONS(9656),
    [sym_schema_keyword] = ACTIONS(9656),
    [sym_views_keyword] = ACTIONS(9656),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9656),
    [sym_preproc_open] = ACTIONS(9656),
    [sym_preproc_close] = ACTIONS(9656),
  },
  [STATE(4235)] = {
    [anon_sym_SEMI] = ACTIONS(9656),
    [aux_sym_where_condition_token1] = ACTIONS(9658),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9656),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9656),
    [anon_sym_LBRACK] = ACTIONS(9656),
    [aux_sym_basic_type_token6] = ACTIONS(9658),
    [aux_sym_basic_type_token22] = ACTIONS(9658),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9656),
    [aux_sym_addafter_modification_token1] = ACTIONS(9656),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9656),
    [aux_sym_modify_modification_token1] = ACTIONS(9656),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9656),
    [aux_sym_movelast_modification_token1] = ACTIONS(9656),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9656),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9656),
    [aux_sym_separator_action_token1] = ACTIONS(9656),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9656),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9656),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9656),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9656),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9656),
    [anon_sym_POUNDif] = ACTIONS(9656),
    [anon_sym_POUNDIF] = ACTIONS(9656),
    [anon_sym_POUNDIf] = ACTIONS(9656),
    [anon_sym_POUNDelif] = ACTIONS(9656),
    [anon_sym_POUNDELIF] = ACTIONS(9656),
    [anon_sym_POUNDElif] = ACTIONS(9656),
    [anon_sym_POUNDelse] = ACTIONS(9656),
    [anon_sym_POUNDELSE] = ACTIONS(9656),
    [anon_sym_POUNDElse] = ACTIONS(9656),
    [anon_sym_POUNDelse2] = ACTIONS(9656),
    [anon_sym_POUNDELSE2] = ACTIONS(9656),
    [anon_sym_POUNDElse2] = ACTIONS(9656),
    [anon_sym_POUNDendif] = ACTIONS(9656),
    [anon_sym_POUNDENDIF] = ACTIONS(9656),
    [anon_sym_POUNDEndif] = ACTIONS(9656),
    [anon_sym_POUNDendif2] = ACTIONS(9656),
    [anon_sym_POUNDENDIF2] = ACTIONS(9656),
    [anon_sym_POUNDEndif2] = ACTIONS(9656),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9656),
    [sym_trigger_keyword] = ACTIONS(9656),
    [sym_var_keyword] = ACTIONS(9656),
    [sym_local_keyword] = ACTIONS(9656),
    [sym_internal_keyword] = ACTIONS(9656),
    [sym_protected_keyword] = ACTIONS(9656),
    [sym_event_keyword] = ACTIONS(9656),
    [sym_fields_keyword] = ACTIONS(9656),
    [sym_keys_keyword] = ACTIONS(9656),
    [sym_fieldgroups_keyword] = ACTIONS(9656),
    [sym_actions_keyword] = ACTIONS(9656),
    [sym_layout_keyword] = ACTIONS(9656),
    [sym_area_keyword] = ACTIONS(9656),
    [sym_group_keyword] = ACTIONS(9656),
    [sym_repeater_keyword] = ACTIONS(9656),
    [sym_cuegroup_keyword] = ACTIONS(9656),
    [sym_fixed_keyword] = ACTIONS(9656),
    [sym_grid_keyword] = ACTIONS(9656),
    [sym_part_keyword] = ACTIONS(9656),
    [sym_systempart_keyword] = ACTIONS(9656),
    [sym_usercontrol_keyword] = ACTIONS(9656),
    [sym_dataset_keyword] = ACTIONS(9656),
    [sym_elements_keyword] = ACTIONS(9656),
    [sym_dataitem_keyword] = ACTIONS(9656),
    [sym_column_keyword] = ACTIONS(9656),
    [sym_filter_keyword] = ACTIONS(9656),
    [sym_labels_keyword] = ACTIONS(9656),
    [sym_rendering_keyword] = ACTIONS(9656),
    [sym_requestpage_keyword] = ACTIONS(9656),
    [sym_schema_keyword] = ACTIONS(9656),
    [sym_views_keyword] = ACTIONS(9656),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9656),
    [sym_preproc_open] = ACTIONS(9656),
    [sym_preproc_close] = ACTIONS(9656),
  },
  [STATE(4236)] = {
    [sym_else_keyword] = STATE(742),
    [sym_identifier] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5487),
    [anon_sym_DASH] = ACTIONS(5487),
    [aux_sym_boolean_token1] = ACTIONS(5485),
    [aux_sym_boolean_token2] = ACTIONS(5485),
    [sym_decimal] = ACTIONS(5485),
    [anon_sym_LPAREN] = ACTIONS(5487),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [aux_sym_record_type_token1] = ACTIONS(5485),
    [aux_sym_basic_type_token21] = ACTIONS(5485),
    [aux_sym_basic_type_token22] = ACTIONS(5485),
    [aux_sym_basic_type_token48] = ACTIONS(5485),
    [anon_sym_POUNDif] = ACTIONS(5487),
    [anon_sym_POUNDIF] = ACTIONS(5487),
    [anon_sym_POUNDIf] = ACTIONS(5487),
    [anon_sym_not] = ACTIONS(5485),
    [anon_sym_NOT] = ACTIONS(5485),
    [anon_sym_Not] = ACTIONS(5485),
    [anon_sym_POUNDelif] = ACTIONS(5487),
    [anon_sym_POUNDELIF] = ACTIONS(5487),
    [anon_sym_POUNDElif] = ACTIONS(5487),
    [anon_sym_POUNDelse] = ACTIONS(5487),
    [anon_sym_POUNDELSE] = ACTIONS(5487),
    [anon_sym_POUNDElse] = ACTIONS(5487),
    [anon_sym_POUNDelse2] = ACTIONS(5487),
    [anon_sym_POUNDELSE2] = ACTIONS(5487),
    [anon_sym_POUNDElse2] = ACTIONS(5487),
    [anon_sym_POUNDendif] = ACTIONS(5487),
    [anon_sym_POUNDENDIF] = ACTIONS(5487),
    [anon_sym_POUNDEndif] = ACTIONS(5487),
    [anon_sym_POUNDendif2] = ACTIONS(5487),
    [anon_sym_POUNDENDIF2] = ACTIONS(5487),
    [anon_sym_POUNDEndif2] = ACTIONS(5487),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5485),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5485),
    [anon_sym_PLUS] = ACTIONS(5487),
    [sym_datetime_literal] = ACTIONS(5487),
    [sym_date_literal] = ACTIONS(5485),
    [sym_time_literal] = ACTIONS(5485),
    [sym_biginteger_literal] = ACTIONS(5487),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5485),
    [anon_sym_codeunit] = ACTIONS(5485),
    [anon_sym_CODEUNIT] = ACTIONS(5485),
    [anon_sym_Codeunit] = ACTIONS(5485),
    [anon_sym_CodeUnit] = ACTIONS(5485),
    [anon_sym_COdeunit] = ACTIONS(5485),
    [anon_sym_codeUnit] = ACTIONS(5485),
    [sym_report_keyword] = ACTIONS(5485),
    [sym_query_keyword] = ACTIONS(5485),
    [anon_sym_xmlport] = ACTIONS(5485),
    [anon_sym_XMLPORT] = ACTIONS(5485),
    [anon_sym_Xmlport] = ACTIONS(5485),
    [anon_sym_XMLport] = ACTIONS(5485),
    [anon_sym_XMLPort] = ACTIONS(5485),
    [anon_sym_XmlPort] = ACTIONS(5485),
    [anon_sym_enum] = ACTIONS(5485),
    [anon_sym_ENUM] = ACTIONS(5485),
    [anon_sym_Enum] = ACTIONS(5485),
    [anon_sym_eNUM] = ACTIONS(5485),
    [anon_sym_eNum] = ACTIONS(5485),
    [anon_sym_ENum] = ACTIONS(5485),
    [sym_quoted_identifier] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5487),
    [sym_verbatim_string] = ACTIONS(5487),
    [sym_integer] = ACTIONS(5485),
    [sym_continue_as_identifier] = ACTIONS(5487),
    [sym_preproc_open] = ACTIONS(5487),
    [sym_preproc_close] = ACTIONS(5487),
  },
  [STATE(4237)] = {
    [sym_else_keyword] = STATE(743),
    [sym_identifier] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5455),
    [anon_sym_DASH] = ACTIONS(5455),
    [aux_sym_boolean_token1] = ACTIONS(5453),
    [aux_sym_boolean_token2] = ACTIONS(5453),
    [sym_decimal] = ACTIONS(5453),
    [anon_sym_LPAREN] = ACTIONS(5455),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [aux_sym_record_type_token1] = ACTIONS(5453),
    [aux_sym_basic_type_token21] = ACTIONS(5453),
    [aux_sym_basic_type_token22] = ACTIONS(5453),
    [aux_sym_basic_type_token48] = ACTIONS(5453),
    [anon_sym_POUNDif] = ACTIONS(5455),
    [anon_sym_POUNDIF] = ACTIONS(5455),
    [anon_sym_POUNDIf] = ACTIONS(5455),
    [anon_sym_not] = ACTIONS(5453),
    [anon_sym_NOT] = ACTIONS(5453),
    [anon_sym_Not] = ACTIONS(5453),
    [anon_sym_POUNDelif] = ACTIONS(5455),
    [anon_sym_POUNDELIF] = ACTIONS(5455),
    [anon_sym_POUNDElif] = ACTIONS(5455),
    [anon_sym_POUNDelse] = ACTIONS(5455),
    [anon_sym_POUNDELSE] = ACTIONS(5455),
    [anon_sym_POUNDElse] = ACTIONS(5455),
    [anon_sym_POUNDelse2] = ACTIONS(5455),
    [anon_sym_POUNDELSE2] = ACTIONS(5455),
    [anon_sym_POUNDElse2] = ACTIONS(5455),
    [anon_sym_POUNDendif] = ACTIONS(5455),
    [anon_sym_POUNDENDIF] = ACTIONS(5455),
    [anon_sym_POUNDEndif] = ACTIONS(5455),
    [anon_sym_POUNDendif2] = ACTIONS(5455),
    [anon_sym_POUNDENDIF2] = ACTIONS(5455),
    [anon_sym_POUNDEndif2] = ACTIONS(5455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5453),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5453),
    [anon_sym_PLUS] = ACTIONS(5455),
    [sym_datetime_literal] = ACTIONS(5455),
    [sym_date_literal] = ACTIONS(5453),
    [sym_time_literal] = ACTIONS(5453),
    [sym_biginteger_literal] = ACTIONS(5455),
    [anon_sym_else] = ACTIONS(5435),
    [anon_sym_ELSE] = ACTIONS(5435),
    [anon_sym_Else] = ACTIONS(5435),
    [sym_page_keyword] = ACTIONS(5453),
    [anon_sym_codeunit] = ACTIONS(5453),
    [anon_sym_CODEUNIT] = ACTIONS(5453),
    [anon_sym_Codeunit] = ACTIONS(5453),
    [anon_sym_CodeUnit] = ACTIONS(5453),
    [anon_sym_COdeunit] = ACTIONS(5453),
    [anon_sym_codeUnit] = ACTIONS(5453),
    [sym_report_keyword] = ACTIONS(5453),
    [sym_query_keyword] = ACTIONS(5453),
    [anon_sym_xmlport] = ACTIONS(5453),
    [anon_sym_XMLPORT] = ACTIONS(5453),
    [anon_sym_Xmlport] = ACTIONS(5453),
    [anon_sym_XMLport] = ACTIONS(5453),
    [anon_sym_XMLPort] = ACTIONS(5453),
    [anon_sym_XmlPort] = ACTIONS(5453),
    [anon_sym_enum] = ACTIONS(5453),
    [anon_sym_ENUM] = ACTIONS(5453),
    [anon_sym_Enum] = ACTIONS(5453),
    [anon_sym_eNUM] = ACTIONS(5453),
    [anon_sym_eNum] = ACTIONS(5453),
    [anon_sym_ENum] = ACTIONS(5453),
    [sym_quoted_identifier] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5455),
    [sym_verbatim_string] = ACTIONS(5455),
    [sym_integer] = ACTIONS(5453),
    [sym_continue_as_identifier] = ACTIONS(5455),
    [sym_preproc_open] = ACTIONS(5455),
    [sym_preproc_close] = ACTIONS(5455),
  },
  [STATE(4238)] = {
    [sym_preproc_conditional_permissions] = STATE(4251),
    [sym_tabledata_permission] = STATE(4942),
    [sym_preproc_if] = STATE(7979),
    [sym_codeunit_keyword] = STATE(11356),
    [sym_xmlport_keyword] = STATE(11356),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4251),
    [anon_sym_SEMI] = ACTIONS(7846),
    [anon_sym_RBRACE] = ACTIONS(7846),
    [aux_sym_where_condition_token1] = ACTIONS(7848),
    [aux_sym_tabledata_permission_token1] = ACTIONS(9660),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4093),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7846),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7846),
    [anon_sym_LBRACK] = ACTIONS(7846),
    [aux_sym_basic_type_token6] = ACTIONS(7848),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7846),
    [aux_sym_addafter_modification_token1] = ACTIONS(7846),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7846),
    [aux_sym_modify_modification_token1] = ACTIONS(7846),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7846),
    [aux_sym_movelast_modification_token1] = ACTIONS(7846),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7846),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7846),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7846),
    [anon_sym_POUNDif] = ACTIONS(7852),
    [anon_sym_POUNDIF] = ACTIONS(7852),
    [anon_sym_POUNDIf] = ACTIONS(7852),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4093),
    [sym_page_keyword] = ACTIONS(9660),
    [anon_sym_codeunit] = ACTIONS(7855),
    [anon_sym_CODEUNIT] = ACTIONS(7855),
    [anon_sym_Codeunit] = ACTIONS(7855),
    [anon_sym_CodeUnit] = ACTIONS(7855),
    [anon_sym_COdeunit] = ACTIONS(7855),
    [anon_sym_codeUnit] = ACTIONS(7855),
    [sym_report_keyword] = ACTIONS(9660),
    [sym_query_keyword] = ACTIONS(9660),
    [anon_sym_xmlport] = ACTIONS(7857),
    [anon_sym_XMLPORT] = ACTIONS(7857),
    [anon_sym_Xmlport] = ACTIONS(7857),
    [anon_sym_XMLport] = ACTIONS(7857),
    [anon_sym_XMLPort] = ACTIONS(7857),
    [anon_sym_XmlPort] = ACTIONS(7857),
    [sym_procedure_keyword] = ACTIONS(7846),
    [sym_trigger_keyword] = ACTIONS(7846),
    [sym_var_keyword] = ACTIONS(7846),
    [sym_local_keyword] = ACTIONS(7846),
    [sym_internal_keyword] = ACTIONS(7846),
    [sym_protected_keyword] = ACTIONS(7846),
    [sym_event_keyword] = ACTIONS(7846),
    [sym_fields_keyword] = ACTIONS(7846),
    [sym_keys_keyword] = ACTIONS(7846),
    [sym_fieldgroups_keyword] = ACTIONS(7846),
    [sym_actions_keyword] = ACTIONS(7846),
    [sym_layout_keyword] = ACTIONS(7846),
    [sym_area_keyword] = ACTIONS(7846),
    [sym_group_keyword] = ACTIONS(7846),
    [sym_repeater_keyword] = ACTIONS(7846),
    [sym_cuegroup_keyword] = ACTIONS(7846),
    [sym_fixed_keyword] = ACTIONS(7846),
    [sym_grid_keyword] = ACTIONS(7846),
    [sym_part_keyword] = ACTIONS(7846),
    [sym_systempart_keyword] = ACTIONS(7846),
    [sym_usercontrol_keyword] = ACTIONS(7846),
    [sym_dataset_keyword] = ACTIONS(7846),
    [sym_elements_keyword] = ACTIONS(7846),
    [sym_labels_keyword] = ACTIONS(7846),
    [sym_rendering_keyword] = ACTIONS(7846),
    [sym_requestpage_keyword] = ACTIONS(7846),
    [sym_schema_keyword] = ACTIONS(7846),
    [sym_views_keyword] = ACTIONS(7846),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7846),
    [sym_preproc_open] = ACTIONS(7852),
  },
  [STATE(4239)] = {
    [anon_sym_SEMI] = ACTIONS(9662),
    [aux_sym_where_condition_token1] = ACTIONS(6118),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6122),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6122),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_basic_type_token6] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6122),
    [aux_sym_addafter_modification_token1] = ACTIONS(6122),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6122),
    [aux_sym_modify_modification_token1] = ACTIONS(6122),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6122),
    [aux_sym_movelast_modification_token1] = ACTIONS(6122),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6122),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6122),
    [aux_sym_separator_action_token1] = ACTIONS(6122),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6122),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6122),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6122),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6122),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6122),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_POUNDelif] = ACTIONS(6122),
    [anon_sym_POUNDELIF] = ACTIONS(6122),
    [anon_sym_POUNDElif] = ACTIONS(6122),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [anon_sym_POUNDendif] = ACTIONS(6122),
    [anon_sym_POUNDENDIF] = ACTIONS(6122),
    [anon_sym_POUNDEndif] = ACTIONS(6122),
    [anon_sym_POUNDendif2] = ACTIONS(6122),
    [anon_sym_POUNDENDIF2] = ACTIONS(6122),
    [anon_sym_POUNDEndif2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6122),
    [sym_trigger_keyword] = ACTIONS(6122),
    [sym_var_keyword] = ACTIONS(6122),
    [sym_local_keyword] = ACTIONS(6122),
    [sym_internal_keyword] = ACTIONS(6122),
    [sym_protected_keyword] = ACTIONS(6122),
    [sym_event_keyword] = ACTIONS(6122),
    [sym_fields_keyword] = ACTIONS(6122),
    [sym_keys_keyword] = ACTIONS(6122),
    [sym_fieldgroups_keyword] = ACTIONS(6122),
    [sym_actions_keyword] = ACTIONS(6122),
    [sym_layout_keyword] = ACTIONS(6122),
    [sym_area_keyword] = ACTIONS(6122),
    [sym_group_keyword] = ACTIONS(6122),
    [sym_repeater_keyword] = ACTIONS(6122),
    [sym_cuegroup_keyword] = ACTIONS(6122),
    [sym_fixed_keyword] = ACTIONS(6122),
    [sym_grid_keyword] = ACTIONS(6122),
    [sym_part_keyword] = ACTIONS(6122),
    [sym_systempart_keyword] = ACTIONS(6122),
    [sym_usercontrol_keyword] = ACTIONS(6122),
    [sym_dataset_keyword] = ACTIONS(6122),
    [sym_elements_keyword] = ACTIONS(6122),
    [sym_dataitem_keyword] = ACTIONS(6122),
    [sym_column_keyword] = ACTIONS(6122),
    [sym_filter_keyword] = ACTIONS(6122),
    [sym_labels_keyword] = ACTIONS(6122),
    [sym_rendering_keyword] = ACTIONS(6122),
    [sym_requestpage_keyword] = ACTIONS(6122),
    [sym_schema_keyword] = ACTIONS(6122),
    [sym_views_keyword] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_preproc_close] = ACTIONS(6122),
  },
  [STATE(4240)] = {
    [anon_sym_SEMI] = ACTIONS(6122),
    [aux_sym_where_condition_token1] = ACTIONS(6118),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6122),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6122),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_basic_type_token6] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6122),
    [aux_sym_addafter_modification_token1] = ACTIONS(6122),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6122),
    [aux_sym_modify_modification_token1] = ACTIONS(6122),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6122),
    [aux_sym_movelast_modification_token1] = ACTIONS(6122),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6122),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6122),
    [aux_sym_separator_action_token1] = ACTIONS(6122),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6122),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6122),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6122),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6122),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6122),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_POUNDelif] = ACTIONS(6122),
    [anon_sym_POUNDELIF] = ACTIONS(6122),
    [anon_sym_POUNDElif] = ACTIONS(6122),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [anon_sym_POUNDendif] = ACTIONS(6122),
    [anon_sym_POUNDENDIF] = ACTIONS(6122),
    [anon_sym_POUNDEndif] = ACTIONS(6122),
    [anon_sym_POUNDendif2] = ACTIONS(6122),
    [anon_sym_POUNDENDIF2] = ACTIONS(6122),
    [anon_sym_POUNDEndif2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6122),
    [sym_trigger_keyword] = ACTIONS(6122),
    [sym_var_keyword] = ACTIONS(6122),
    [sym_local_keyword] = ACTIONS(6122),
    [sym_internal_keyword] = ACTIONS(6122),
    [sym_protected_keyword] = ACTIONS(6122),
    [sym_event_keyword] = ACTIONS(6122),
    [sym_fields_keyword] = ACTIONS(6122),
    [sym_keys_keyword] = ACTIONS(6122),
    [sym_fieldgroups_keyword] = ACTIONS(6122),
    [sym_actions_keyword] = ACTIONS(6122),
    [sym_layout_keyword] = ACTIONS(6122),
    [sym_area_keyword] = ACTIONS(6122),
    [sym_group_keyword] = ACTIONS(6122),
    [sym_repeater_keyword] = ACTIONS(6122),
    [sym_cuegroup_keyword] = ACTIONS(6122),
    [sym_fixed_keyword] = ACTIONS(6122),
    [sym_grid_keyword] = ACTIONS(6122),
    [sym_part_keyword] = ACTIONS(6122),
    [sym_systempart_keyword] = ACTIONS(6122),
    [sym_usercontrol_keyword] = ACTIONS(6122),
    [sym_dataset_keyword] = ACTIONS(6122),
    [sym_elements_keyword] = ACTIONS(6122),
    [sym_dataitem_keyword] = ACTIONS(6122),
    [sym_column_keyword] = ACTIONS(6122),
    [sym_filter_keyword] = ACTIONS(6122),
    [sym_labels_keyword] = ACTIONS(6122),
    [sym_rendering_keyword] = ACTIONS(6122),
    [sym_requestpage_keyword] = ACTIONS(6122),
    [sym_schema_keyword] = ACTIONS(6122),
    [sym_views_keyword] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_preproc_close] = ACTIONS(6122),
  },
  [STATE(4241)] = {
    [sym_boolean] = STATE(7585),
    [sym_assignment_expression] = STATE(7585),
    [sym__expression] = STATE(7585),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7585),
    [sym_multiplicative_expression] = STATE(7585),
    [sym_additive_expression] = STATE(7585),
    [sym_comparison_expression] = STATE(7585),
    [sym_logical_expression] = STATE(7585),
    [sym_ternary_expression] = STATE(7585),
    [sym_unary_expression] = STATE(7585),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7585),
    [sym_list_literal] = STATE(7585),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7585),
    [sym__literal_value] = STATE(7585),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9664),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(8203),
    [anon_sym_DOT_DOT] = ACTIONS(8203),
    [aux_sym_filter_value_token1] = ACTIONS(8198),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9666),
    [sym_date_literal] = ACTIONS(9664),
    [sym_time_literal] = ACTIONS(9664),
    [sym_biginteger_literal] = ACTIONS(9666),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9666),
    [sym_verbatim_string] = ACTIONS(9666),
    [sym_integer] = ACTIONS(9668),
    [sym_continue_as_identifier] = ACTIONS(9666),
  },
  [STATE(4242)] = {
    [anon_sym_SEMI] = ACTIONS(6126),
    [aux_sym_where_condition_token1] = ACTIONS(6124),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6126),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6126),
    [anon_sym_LBRACK] = ACTIONS(6126),
    [aux_sym_basic_type_token6] = ACTIONS(6124),
    [aux_sym_basic_type_token22] = ACTIONS(6124),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6126),
    [aux_sym_addafter_modification_token1] = ACTIONS(6126),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6126),
    [aux_sym_modify_modification_token1] = ACTIONS(6126),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6126),
    [aux_sym_movelast_modification_token1] = ACTIONS(6126),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6126),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6126),
    [aux_sym_separator_action_token1] = ACTIONS(6126),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6126),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6126),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6126),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6126),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6126),
    [anon_sym_POUNDif] = ACTIONS(6126),
    [anon_sym_POUNDIF] = ACTIONS(6126),
    [anon_sym_POUNDIf] = ACTIONS(6126),
    [anon_sym_POUNDelif] = ACTIONS(6126),
    [anon_sym_POUNDELIF] = ACTIONS(6126),
    [anon_sym_POUNDElif] = ACTIONS(6126),
    [anon_sym_POUNDelse] = ACTIONS(6126),
    [anon_sym_POUNDELSE] = ACTIONS(6126),
    [anon_sym_POUNDElse] = ACTIONS(6126),
    [anon_sym_POUNDelse2] = ACTIONS(6126),
    [anon_sym_POUNDELSE2] = ACTIONS(6126),
    [anon_sym_POUNDElse2] = ACTIONS(6126),
    [anon_sym_POUNDendif] = ACTIONS(6126),
    [anon_sym_POUNDENDIF] = ACTIONS(6126),
    [anon_sym_POUNDEndif] = ACTIONS(6126),
    [anon_sym_POUNDendif2] = ACTIONS(6126),
    [anon_sym_POUNDENDIF2] = ACTIONS(6126),
    [anon_sym_POUNDEndif2] = ACTIONS(6126),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6126),
    [sym_trigger_keyword] = ACTIONS(6126),
    [sym_var_keyword] = ACTIONS(6126),
    [sym_local_keyword] = ACTIONS(6126),
    [sym_internal_keyword] = ACTIONS(6126),
    [sym_protected_keyword] = ACTIONS(6126),
    [sym_event_keyword] = ACTIONS(6126),
    [sym_fields_keyword] = ACTIONS(6126),
    [sym_keys_keyword] = ACTIONS(6126),
    [sym_fieldgroups_keyword] = ACTIONS(6126),
    [sym_actions_keyword] = ACTIONS(6126),
    [sym_layout_keyword] = ACTIONS(6126),
    [sym_area_keyword] = ACTIONS(6126),
    [sym_group_keyword] = ACTIONS(6126),
    [sym_repeater_keyword] = ACTIONS(6126),
    [sym_cuegroup_keyword] = ACTIONS(6126),
    [sym_fixed_keyword] = ACTIONS(6126),
    [sym_grid_keyword] = ACTIONS(6126),
    [sym_part_keyword] = ACTIONS(6126),
    [sym_systempart_keyword] = ACTIONS(6126),
    [sym_usercontrol_keyword] = ACTIONS(6126),
    [sym_dataset_keyword] = ACTIONS(6126),
    [sym_elements_keyword] = ACTIONS(6126),
    [sym_dataitem_keyword] = ACTIONS(6126),
    [sym_column_keyword] = ACTIONS(6126),
    [sym_filter_keyword] = ACTIONS(6126),
    [sym_labels_keyword] = ACTIONS(6126),
    [sym_rendering_keyword] = ACTIONS(6126),
    [sym_requestpage_keyword] = ACTIONS(6126),
    [sym_schema_keyword] = ACTIONS(6126),
    [sym_views_keyword] = ACTIONS(6126),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6126),
    [sym_preproc_open] = ACTIONS(6126),
    [sym_preproc_close] = ACTIONS(6126),
  },
  [STATE(4243)] = {
    [anon_sym_SEMI] = ACTIONS(9670),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5965),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5965),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5965),
    [aux_sym_addafter_modification_token1] = ACTIONS(5965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5965),
    [aux_sym_modify_modification_token1] = ACTIONS(5965),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5965),
    [aux_sym_movelast_modification_token1] = ACTIONS(5965),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5965),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5965),
    [aux_sym_separator_action_token1] = ACTIONS(5965),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5965),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5965),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5965),
    [sym_trigger_keyword] = ACTIONS(5965),
    [sym_var_keyword] = ACTIONS(5965),
    [sym_local_keyword] = ACTIONS(5965),
    [sym_internal_keyword] = ACTIONS(5965),
    [sym_protected_keyword] = ACTIONS(5965),
    [sym_event_keyword] = ACTIONS(5965),
    [sym_fields_keyword] = ACTIONS(5965),
    [sym_keys_keyword] = ACTIONS(5965),
    [sym_fieldgroups_keyword] = ACTIONS(5965),
    [sym_actions_keyword] = ACTIONS(5965),
    [sym_layout_keyword] = ACTIONS(5965),
    [sym_area_keyword] = ACTIONS(5965),
    [sym_group_keyword] = ACTIONS(5965),
    [sym_repeater_keyword] = ACTIONS(5965),
    [sym_cuegroup_keyword] = ACTIONS(5965),
    [sym_fixed_keyword] = ACTIONS(5965),
    [sym_grid_keyword] = ACTIONS(5965),
    [sym_part_keyword] = ACTIONS(5965),
    [sym_systempart_keyword] = ACTIONS(5965),
    [sym_usercontrol_keyword] = ACTIONS(5965),
    [sym_dataset_keyword] = ACTIONS(5965),
    [sym_elements_keyword] = ACTIONS(5965),
    [sym_dataitem_keyword] = ACTIONS(5965),
    [sym_column_keyword] = ACTIONS(5965),
    [sym_filter_keyword] = ACTIONS(5965),
    [sym_labels_keyword] = ACTIONS(5965),
    [sym_rendering_keyword] = ACTIONS(5965),
    [sym_requestpage_keyword] = ACTIONS(5965),
    [sym_schema_keyword] = ACTIONS(5965),
    [sym_views_keyword] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(4244)] = {
    [anon_sym_SEMI] = ACTIONS(9672),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5965),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5965),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5965),
    [aux_sym_addafter_modification_token1] = ACTIONS(5965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5965),
    [aux_sym_modify_modification_token1] = ACTIONS(5965),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5965),
    [aux_sym_movelast_modification_token1] = ACTIONS(5965),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5965),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5965),
    [aux_sym_separator_action_token1] = ACTIONS(5965),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5965),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5965),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5965),
    [sym_trigger_keyword] = ACTIONS(5965),
    [sym_var_keyword] = ACTIONS(5965),
    [sym_local_keyword] = ACTIONS(5965),
    [sym_internal_keyword] = ACTIONS(5965),
    [sym_protected_keyword] = ACTIONS(5965),
    [sym_event_keyword] = ACTIONS(5965),
    [sym_fields_keyword] = ACTIONS(5965),
    [sym_keys_keyword] = ACTIONS(5965),
    [sym_fieldgroups_keyword] = ACTIONS(5965),
    [sym_actions_keyword] = ACTIONS(5965),
    [sym_layout_keyword] = ACTIONS(5965),
    [sym_area_keyword] = ACTIONS(5965),
    [sym_group_keyword] = ACTIONS(5965),
    [sym_repeater_keyword] = ACTIONS(5965),
    [sym_cuegroup_keyword] = ACTIONS(5965),
    [sym_fixed_keyword] = ACTIONS(5965),
    [sym_grid_keyword] = ACTIONS(5965),
    [sym_part_keyword] = ACTIONS(5965),
    [sym_systempart_keyword] = ACTIONS(5965),
    [sym_usercontrol_keyword] = ACTIONS(5965),
    [sym_dataset_keyword] = ACTIONS(5965),
    [sym_elements_keyword] = ACTIONS(5965),
    [sym_dataitem_keyword] = ACTIONS(5965),
    [sym_column_keyword] = ACTIONS(5965),
    [sym_filter_keyword] = ACTIONS(5965),
    [sym_labels_keyword] = ACTIONS(5965),
    [sym_rendering_keyword] = ACTIONS(5965),
    [sym_requestpage_keyword] = ACTIONS(5965),
    [sym_schema_keyword] = ACTIONS(5965),
    [sym_views_keyword] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(4245)] = {
    [anon_sym_SEMI] = ACTIONS(5965),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5965),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5965),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5965),
    [aux_sym_addafter_modification_token1] = ACTIONS(5965),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5965),
    [aux_sym_modify_modification_token1] = ACTIONS(5965),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5965),
    [aux_sym_movelast_modification_token1] = ACTIONS(5965),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5965),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5965),
    [aux_sym_separator_action_token1] = ACTIONS(5965),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5965),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5965),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5965),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5965),
    [sym_trigger_keyword] = ACTIONS(5965),
    [sym_var_keyword] = ACTIONS(5965),
    [sym_local_keyword] = ACTIONS(5965),
    [sym_internal_keyword] = ACTIONS(5965),
    [sym_protected_keyword] = ACTIONS(5965),
    [sym_event_keyword] = ACTIONS(5965),
    [sym_fields_keyword] = ACTIONS(5965),
    [sym_keys_keyword] = ACTIONS(5965),
    [sym_fieldgroups_keyword] = ACTIONS(5965),
    [sym_actions_keyword] = ACTIONS(5965),
    [sym_layout_keyword] = ACTIONS(5965),
    [sym_area_keyword] = ACTIONS(5965),
    [sym_group_keyword] = ACTIONS(5965),
    [sym_repeater_keyword] = ACTIONS(5965),
    [sym_cuegroup_keyword] = ACTIONS(5965),
    [sym_fixed_keyword] = ACTIONS(5965),
    [sym_grid_keyword] = ACTIONS(5965),
    [sym_part_keyword] = ACTIONS(5965),
    [sym_systempart_keyword] = ACTIONS(5965),
    [sym_usercontrol_keyword] = ACTIONS(5965),
    [sym_dataset_keyword] = ACTIONS(5965),
    [sym_elements_keyword] = ACTIONS(5965),
    [sym_dataitem_keyword] = ACTIONS(5965),
    [sym_column_keyword] = ACTIONS(5965),
    [sym_filter_keyword] = ACTIONS(5965),
    [sym_labels_keyword] = ACTIONS(5965),
    [sym_rendering_keyword] = ACTIONS(5965),
    [sym_requestpage_keyword] = ACTIONS(5965),
    [sym_schema_keyword] = ACTIONS(5965),
    [sym_views_keyword] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
  },
  [STATE(4246)] = {
    [anon_sym_SEMI] = ACTIONS(3786),
    [anon_sym_DOT] = ACTIONS(3784),
    [anon_sym_RBRACE] = ACTIONS(3786),
    [anon_sym_EQ] = ACTIONS(3786),
    [anon_sym_DASH] = ACTIONS(3784),
    [anon_sym_LPAREN] = ACTIONS(3786),
    [aux_sym_where_clause_token1] = ACTIONS(3786),
    [anon_sym_DOT_DOT] = ACTIONS(3786),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3786),
    [anon_sym_STAR] = ACTIONS(3784),
    [anon_sym_LBRACK] = ACTIONS(3786),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3786),
    [aux_sym_modify_modification_token1] = ACTIONS(3786),
    [aux_sym_xmlport_element_token1] = ACTIONS(3786),
    [aux_sym_xmlport_element_token2] = ACTIONS(3786),
    [aux_sym_xmlport_element_token3] = ACTIONS(3786),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(3786),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(3786),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3784),
    [anon_sym_COLON_COLON] = ACTIONS(3786),
    [anon_sym_POUNDif] = ACTIONS(3786),
    [anon_sym_POUNDIF] = ACTIONS(3786),
    [anon_sym_POUNDIf] = ACTIONS(3786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3786),
    [aux_sym__expression_token1] = ACTIONS(3786),
    [aux_sym__expression_token2] = ACTIONS(3786),
    [anon_sym_SLASH] = ACTIONS(3784),
    [anon_sym_div] = ACTIONS(3786),
    [anon_sym_DIV] = ACTIONS(3786),
    [anon_sym_Div] = ACTIONS(3786),
    [anon_sym_mod] = ACTIONS(3784),
    [anon_sym_MOD] = ACTIONS(3784),
    [anon_sym_Mod] = ACTIONS(3784),
    [anon_sym_PLUS] = ACTIONS(3784),
    [anon_sym_GT_EQ] = ACTIONS(3786),
    [anon_sym_LT_EQ] = ACTIONS(3786),
    [anon_sym_GT] = ACTIONS(3784),
    [anon_sym_LT] = ACTIONS(3784),
    [anon_sym_LT_GT] = ACTIONS(3786),
    [anon_sym_and] = ACTIONS(3786),
    [anon_sym_AND] = ACTIONS(3786),
    [anon_sym_And] = ACTIONS(3786),
    [anon_sym_or] = ACTIONS(3786),
    [anon_sym_OR] = ACTIONS(3786),
    [anon_sym_Or] = ACTIONS(3786),
    [anon_sym_xor] = ACTIONS(3786),
    [anon_sym_XOR] = ACTIONS(3786),
    [anon_sym_Xor] = ACTIONS(3786),
    [anon_sym_QMARK] = ACTIONS(3786),
    [anon_sym_in] = ACTIONS(3784),
    [anon_sym_IN] = ACTIONS(3784),
    [anon_sym_In] = ACTIONS(3784),
    [sym_procedure_keyword] = ACTIONS(3786),
    [sym_trigger_keyword] = ACTIONS(3786),
    [sym_var_keyword] = ACTIONS(3786),
    [sym_local_keyword] = ACTIONS(3786),
    [sym_internal_keyword] = ACTIONS(3786),
    [sym_protected_keyword] = ACTIONS(3786),
    [sym_event_keyword] = ACTIONS(3786),
    [sym_fields_keyword] = ACTIONS(3786),
    [sym_keys_keyword] = ACTIONS(3786),
    [sym_fieldgroups_keyword] = ACTIONS(3786),
    [sym_actions_keyword] = ACTIONS(3786),
    [sym_layout_keyword] = ACTIONS(3786),
    [sym_dataset_keyword] = ACTIONS(3786),
    [sym_elements_keyword] = ACTIONS(3786),
    [sym_labels_keyword] = ACTIONS(3786),
    [sym_rendering_keyword] = ACTIONS(3786),
    [sym_requestpage_keyword] = ACTIONS(3786),
    [sym_schema_keyword] = ACTIONS(3786),
    [sym_views_keyword] = ACTIONS(3786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3786),
    [sym_preproc_open] = ACTIONS(3786),
  },
  [STATE(4247)] = {
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3663),
    [anon_sym_RBRACE] = ACTIONS(3564),
    [anon_sym_EQ] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3665),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3665),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3564),
    [aux_sym_modify_modification_token1] = ACTIONS(3564),
    [aux_sym_xmlport_element_token1] = ACTIONS(3564),
    [aux_sym_xmlport_element_token2] = ACTIONS(3564),
    [aux_sym_xmlport_element_token3] = ACTIONS(3564),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(3564),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(3564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3665),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3665),
    [aux_sym__expression_token1] = ACTIONS(3665),
    [aux_sym__expression_token2] = ACTIONS(3665),
    [anon_sym_SLASH] = ACTIONS(3663),
    [anon_sym_div] = ACTIONS(3665),
    [anon_sym_DIV] = ACTIONS(3665),
    [anon_sym_Div] = ACTIONS(3665),
    [anon_sym_mod] = ACTIONS(3663),
    [anon_sym_MOD] = ACTIONS(3663),
    [anon_sym_Mod] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(3663),
    [anon_sym_GT_EQ] = ACTIONS(3665),
    [anon_sym_LT_EQ] = ACTIONS(3665),
    [anon_sym_GT] = ACTIONS(3663),
    [anon_sym_LT] = ACTIONS(3663),
    [anon_sym_LT_GT] = ACTIONS(3665),
    [anon_sym_and] = ACTIONS(3665),
    [anon_sym_AND] = ACTIONS(3665),
    [anon_sym_And] = ACTIONS(3665),
    [anon_sym_or] = ACTIONS(3665),
    [anon_sym_OR] = ACTIONS(3665),
    [anon_sym_Or] = ACTIONS(3665),
    [anon_sym_xor] = ACTIONS(3665),
    [anon_sym_XOR] = ACTIONS(3665),
    [anon_sym_Xor] = ACTIONS(3665),
    [anon_sym_QMARK] = ACTIONS(3665),
    [anon_sym_in] = ACTIONS(3663),
    [anon_sym_IN] = ACTIONS(3663),
    [anon_sym_In] = ACTIONS(3663),
    [sym_procedure_keyword] = ACTIONS(3564),
    [sym_trigger_keyword] = ACTIONS(3564),
    [sym_var_keyword] = ACTIONS(3564),
    [sym_local_keyword] = ACTIONS(3564),
    [sym_internal_keyword] = ACTIONS(3564),
    [sym_protected_keyword] = ACTIONS(3564),
    [sym_event_keyword] = ACTIONS(3564),
    [sym_fields_keyword] = ACTIONS(3564),
    [sym_keys_keyword] = ACTIONS(3564),
    [sym_fieldgroups_keyword] = ACTIONS(3564),
    [sym_actions_keyword] = ACTIONS(3564),
    [sym_layout_keyword] = ACTIONS(3564),
    [sym_dataset_keyword] = ACTIONS(3564),
    [sym_elements_keyword] = ACTIONS(3564),
    [sym_labels_keyword] = ACTIONS(3564),
    [sym_rendering_keyword] = ACTIONS(3564),
    [sym_requestpage_keyword] = ACTIONS(3564),
    [sym_schema_keyword] = ACTIONS(3564),
    [sym_views_keyword] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
  },
  [STATE(4248)] = {
    [anon_sym_SEMI] = ACTIONS(5937),
    [aux_sym_where_condition_token1] = ACTIONS(5935),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5937),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5937),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_basic_type_token6] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5937),
    [aux_sym_addafter_modification_token1] = ACTIONS(5937),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5937),
    [aux_sym_modify_modification_token1] = ACTIONS(5937),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5937),
    [aux_sym_movelast_modification_token1] = ACTIONS(5937),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5937),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5937),
    [aux_sym_separator_action_token1] = ACTIONS(5937),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5937),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5937),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5937),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5937),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5937),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5937),
    [sym_trigger_keyword] = ACTIONS(5937),
    [sym_var_keyword] = ACTIONS(5937),
    [sym_local_keyword] = ACTIONS(5937),
    [sym_internal_keyword] = ACTIONS(5937),
    [sym_protected_keyword] = ACTIONS(5937),
    [sym_event_keyword] = ACTIONS(5937),
    [sym_fields_keyword] = ACTIONS(5937),
    [sym_keys_keyword] = ACTIONS(5937),
    [sym_fieldgroups_keyword] = ACTIONS(5937),
    [sym_actions_keyword] = ACTIONS(5937),
    [sym_layout_keyword] = ACTIONS(5937),
    [sym_area_keyword] = ACTIONS(5937),
    [sym_group_keyword] = ACTIONS(5937),
    [sym_repeater_keyword] = ACTIONS(5937),
    [sym_cuegroup_keyword] = ACTIONS(5937),
    [sym_fixed_keyword] = ACTIONS(5937),
    [sym_grid_keyword] = ACTIONS(5937),
    [sym_part_keyword] = ACTIONS(5937),
    [sym_systempart_keyword] = ACTIONS(5937),
    [sym_usercontrol_keyword] = ACTIONS(5937),
    [sym_dataset_keyword] = ACTIONS(5937),
    [sym_elements_keyword] = ACTIONS(5937),
    [sym_dataitem_keyword] = ACTIONS(5937),
    [sym_column_keyword] = ACTIONS(5937),
    [sym_filter_keyword] = ACTIONS(5937),
    [sym_labels_keyword] = ACTIONS(5937),
    [sym_rendering_keyword] = ACTIONS(5937),
    [sym_requestpage_keyword] = ACTIONS(5937),
    [sym_schema_keyword] = ACTIONS(5937),
    [sym_views_keyword] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
  },
  [STATE(4249)] = {
    [anon_sym_SEMI] = ACTIONS(5937),
    [aux_sym_where_condition_token1] = ACTIONS(5935),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5937),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5937),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_basic_type_token6] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5937),
    [aux_sym_addafter_modification_token1] = ACTIONS(5937),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5937),
    [aux_sym_modify_modification_token1] = ACTIONS(5937),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5937),
    [aux_sym_movelast_modification_token1] = ACTIONS(5937),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5937),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5937),
    [aux_sym_separator_action_token1] = ACTIONS(5937),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5937),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5937),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5937),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5937),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5937),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5937),
    [sym_trigger_keyword] = ACTIONS(5937),
    [sym_var_keyword] = ACTIONS(5937),
    [sym_local_keyword] = ACTIONS(5937),
    [sym_internal_keyword] = ACTIONS(5937),
    [sym_protected_keyword] = ACTIONS(5937),
    [sym_event_keyword] = ACTIONS(5937),
    [sym_fields_keyword] = ACTIONS(5937),
    [sym_keys_keyword] = ACTIONS(5937),
    [sym_fieldgroups_keyword] = ACTIONS(5937),
    [sym_actions_keyword] = ACTIONS(5937),
    [sym_layout_keyword] = ACTIONS(5937),
    [sym_area_keyword] = ACTIONS(5937),
    [sym_group_keyword] = ACTIONS(5937),
    [sym_repeater_keyword] = ACTIONS(5937),
    [sym_cuegroup_keyword] = ACTIONS(5937),
    [sym_fixed_keyword] = ACTIONS(5937),
    [sym_grid_keyword] = ACTIONS(5937),
    [sym_part_keyword] = ACTIONS(5937),
    [sym_systempart_keyword] = ACTIONS(5937),
    [sym_usercontrol_keyword] = ACTIONS(5937),
    [sym_dataset_keyword] = ACTIONS(5937),
    [sym_elements_keyword] = ACTIONS(5937),
    [sym_dataitem_keyword] = ACTIONS(5937),
    [sym_column_keyword] = ACTIONS(5937),
    [sym_filter_keyword] = ACTIONS(5937),
    [sym_labels_keyword] = ACTIONS(5937),
    [sym_rendering_keyword] = ACTIONS(5937),
    [sym_requestpage_keyword] = ACTIONS(5937),
    [sym_schema_keyword] = ACTIONS(5937),
    [sym_views_keyword] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
  },
  [STATE(4250)] = {
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_RBRACE] = ACTIONS(3564),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3564),
    [aux_sym_modify_modification_token1] = ACTIONS(3564),
    [aux_sym_xmlport_element_token1] = ACTIONS(3564),
    [aux_sym_xmlport_element_token2] = ACTIONS(3564),
    [aux_sym_xmlport_element_token3] = ACTIONS(3564),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(3564),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(3564),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDif] = ACTIONS(3564),
    [anon_sym_POUNDIF] = ACTIONS(3564),
    [anon_sym_POUNDIf] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3564),
    [anon_sym_DIV] = ACTIONS(3564),
    [anon_sym_Div] = ACTIONS(3564),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3564),
    [anon_sym_AND] = ACTIONS(3564),
    [anon_sym_And] = ACTIONS(3564),
    [anon_sym_or] = ACTIONS(3564),
    [anon_sym_OR] = ACTIONS(3564),
    [anon_sym_Or] = ACTIONS(3564),
    [anon_sym_xor] = ACTIONS(3564),
    [anon_sym_XOR] = ACTIONS(3564),
    [anon_sym_Xor] = ACTIONS(3564),
    [anon_sym_QMARK] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_procedure_keyword] = ACTIONS(3564),
    [sym_trigger_keyword] = ACTIONS(3564),
    [sym_var_keyword] = ACTIONS(3564),
    [sym_local_keyword] = ACTIONS(3564),
    [sym_internal_keyword] = ACTIONS(3564),
    [sym_protected_keyword] = ACTIONS(3564),
    [sym_event_keyword] = ACTIONS(3564),
    [sym_fields_keyword] = ACTIONS(3564),
    [sym_keys_keyword] = ACTIONS(3564),
    [sym_fieldgroups_keyword] = ACTIONS(3564),
    [sym_actions_keyword] = ACTIONS(3564),
    [sym_layout_keyword] = ACTIONS(3564),
    [sym_dataset_keyword] = ACTIONS(3564),
    [sym_elements_keyword] = ACTIONS(3564),
    [sym_labels_keyword] = ACTIONS(3564),
    [sym_rendering_keyword] = ACTIONS(3564),
    [sym_requestpage_keyword] = ACTIONS(3564),
    [sym_schema_keyword] = ACTIONS(3564),
    [sym_views_keyword] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3564),
    [sym_preproc_open] = ACTIONS(3564),
  },
  [STATE(4251)] = {
    [sym_preproc_conditional_permissions] = STATE(4251),
    [sym_tabledata_permission] = STATE(4942),
    [sym_preproc_if] = STATE(7979),
    [sym_codeunit_keyword] = STATE(11356),
    [sym_xmlport_keyword] = STATE(11356),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4251),
    [anon_sym_SEMI] = ACTIONS(7785),
    [anon_sym_RBRACE] = ACTIONS(7785),
    [aux_sym_where_condition_token1] = ACTIONS(7787),
    [aux_sym_tabledata_permission_token1] = ACTIONS(9674),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9677),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7785),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7785),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_basic_type_token6] = ACTIONS(7787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_addafter_modification_token1] = ACTIONS(7785),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7785),
    [aux_sym_movelast_modification_token1] = ACTIONS(7785),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7785),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7795),
    [anon_sym_POUNDIF] = ACTIONS(7795),
    [anon_sym_POUNDIf] = ACTIONS(7795),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9677),
    [sym_page_keyword] = ACTIONS(9674),
    [anon_sym_codeunit] = ACTIONS(7798),
    [anon_sym_CODEUNIT] = ACTIONS(7798),
    [anon_sym_Codeunit] = ACTIONS(7798),
    [anon_sym_CodeUnit] = ACTIONS(7798),
    [anon_sym_COdeunit] = ACTIONS(7798),
    [anon_sym_codeUnit] = ACTIONS(7798),
    [sym_report_keyword] = ACTIONS(9674),
    [sym_query_keyword] = ACTIONS(9674),
    [anon_sym_xmlport] = ACTIONS(7801),
    [anon_sym_XMLPORT] = ACTIONS(7801),
    [anon_sym_Xmlport] = ACTIONS(7801),
    [anon_sym_XMLport] = ACTIONS(7801),
    [anon_sym_XMLPort] = ACTIONS(7801),
    [anon_sym_XmlPort] = ACTIONS(7801),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_area_keyword] = ACTIONS(7785),
    [sym_group_keyword] = ACTIONS(7785),
    [sym_repeater_keyword] = ACTIONS(7785),
    [sym_cuegroup_keyword] = ACTIONS(7785),
    [sym_fixed_keyword] = ACTIONS(7785),
    [sym_grid_keyword] = ACTIONS(7785),
    [sym_part_keyword] = ACTIONS(7785),
    [sym_systempart_keyword] = ACTIONS(7785),
    [sym_usercontrol_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7795),
  },
  [STATE(4252)] = {
    [anon_sym_SEMI] = ACTIONS(9680),
    [aux_sym_where_condition_token1] = ACTIONS(9682),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9680),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9680),
    [anon_sym_LBRACK] = ACTIONS(9680),
    [aux_sym_basic_type_token6] = ACTIONS(9682),
    [aux_sym_basic_type_token22] = ACTIONS(9682),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9680),
    [aux_sym_addafter_modification_token1] = ACTIONS(9680),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9680),
    [aux_sym_modify_modification_token1] = ACTIONS(9680),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9680),
    [aux_sym_movelast_modification_token1] = ACTIONS(9680),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9680),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9680),
    [aux_sym_separator_action_token1] = ACTIONS(9680),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9680),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9680),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9680),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9680),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9680),
    [anon_sym_POUNDif] = ACTIONS(9680),
    [anon_sym_POUNDIF] = ACTIONS(9680),
    [anon_sym_POUNDIf] = ACTIONS(9680),
    [anon_sym_POUNDelif] = ACTIONS(9680),
    [anon_sym_POUNDELIF] = ACTIONS(9680),
    [anon_sym_POUNDElif] = ACTIONS(9680),
    [anon_sym_POUNDelse] = ACTIONS(9680),
    [anon_sym_POUNDELSE] = ACTIONS(9680),
    [anon_sym_POUNDElse] = ACTIONS(9680),
    [anon_sym_POUNDelse2] = ACTIONS(9680),
    [anon_sym_POUNDELSE2] = ACTIONS(9680),
    [anon_sym_POUNDElse2] = ACTIONS(9680),
    [anon_sym_POUNDendif] = ACTIONS(9680),
    [anon_sym_POUNDENDIF] = ACTIONS(9680),
    [anon_sym_POUNDEndif] = ACTIONS(9680),
    [anon_sym_POUNDendif2] = ACTIONS(9680),
    [anon_sym_POUNDENDIF2] = ACTIONS(9680),
    [anon_sym_POUNDEndif2] = ACTIONS(9680),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9680),
    [sym_trigger_keyword] = ACTIONS(9680),
    [sym_var_keyword] = ACTIONS(9680),
    [sym_local_keyword] = ACTIONS(9680),
    [sym_internal_keyword] = ACTIONS(9680),
    [sym_protected_keyword] = ACTIONS(9680),
    [sym_event_keyword] = ACTIONS(9680),
    [sym_fields_keyword] = ACTIONS(9680),
    [sym_keys_keyword] = ACTIONS(9680),
    [sym_fieldgroups_keyword] = ACTIONS(9680),
    [sym_actions_keyword] = ACTIONS(9680),
    [sym_layout_keyword] = ACTIONS(9680),
    [sym_area_keyword] = ACTIONS(9680),
    [sym_group_keyword] = ACTIONS(9680),
    [sym_repeater_keyword] = ACTIONS(9680),
    [sym_cuegroup_keyword] = ACTIONS(9680),
    [sym_fixed_keyword] = ACTIONS(9680),
    [sym_grid_keyword] = ACTIONS(9680),
    [sym_part_keyword] = ACTIONS(9680),
    [sym_systempart_keyword] = ACTIONS(9680),
    [sym_usercontrol_keyword] = ACTIONS(9680),
    [sym_dataset_keyword] = ACTIONS(9680),
    [sym_elements_keyword] = ACTIONS(9680),
    [sym_dataitem_keyword] = ACTIONS(9680),
    [sym_column_keyword] = ACTIONS(9680),
    [sym_filter_keyword] = ACTIONS(9680),
    [sym_labels_keyword] = ACTIONS(9680),
    [sym_rendering_keyword] = ACTIONS(9680),
    [sym_requestpage_keyword] = ACTIONS(9680),
    [sym_schema_keyword] = ACTIONS(9680),
    [sym_views_keyword] = ACTIONS(9680),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9680),
    [sym_preproc_open] = ACTIONS(9680),
    [sym_preproc_close] = ACTIONS(9680),
  },
  [STATE(4253)] = {
    [anon_sym_SEMI] = ACTIONS(9684),
    [aux_sym_where_condition_token1] = ACTIONS(9686),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9684),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9684),
    [anon_sym_LBRACK] = ACTIONS(9684),
    [aux_sym_basic_type_token6] = ACTIONS(9686),
    [aux_sym_basic_type_token22] = ACTIONS(9686),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9684),
    [aux_sym_addafter_modification_token1] = ACTIONS(9684),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9684),
    [aux_sym_modify_modification_token1] = ACTIONS(9684),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9684),
    [aux_sym_movelast_modification_token1] = ACTIONS(9684),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9684),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9684),
    [aux_sym_separator_action_token1] = ACTIONS(9684),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9684),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9684),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9684),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9684),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9684),
    [anon_sym_POUNDif] = ACTIONS(9684),
    [anon_sym_POUNDIF] = ACTIONS(9684),
    [anon_sym_POUNDIf] = ACTIONS(9684),
    [anon_sym_POUNDelif] = ACTIONS(9684),
    [anon_sym_POUNDELIF] = ACTIONS(9684),
    [anon_sym_POUNDElif] = ACTIONS(9684),
    [anon_sym_POUNDelse] = ACTIONS(9684),
    [anon_sym_POUNDELSE] = ACTIONS(9684),
    [anon_sym_POUNDElse] = ACTIONS(9684),
    [anon_sym_POUNDelse2] = ACTIONS(9684),
    [anon_sym_POUNDELSE2] = ACTIONS(9684),
    [anon_sym_POUNDElse2] = ACTIONS(9684),
    [anon_sym_POUNDendif] = ACTIONS(9684),
    [anon_sym_POUNDENDIF] = ACTIONS(9684),
    [anon_sym_POUNDEndif] = ACTIONS(9684),
    [anon_sym_POUNDendif2] = ACTIONS(9684),
    [anon_sym_POUNDENDIF2] = ACTIONS(9684),
    [anon_sym_POUNDEndif2] = ACTIONS(9684),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9684),
    [sym_trigger_keyword] = ACTIONS(9684),
    [sym_var_keyword] = ACTIONS(9684),
    [sym_local_keyword] = ACTIONS(9684),
    [sym_internal_keyword] = ACTIONS(9684),
    [sym_protected_keyword] = ACTIONS(9684),
    [sym_event_keyword] = ACTIONS(9684),
    [sym_fields_keyword] = ACTIONS(9684),
    [sym_keys_keyword] = ACTIONS(9684),
    [sym_fieldgroups_keyword] = ACTIONS(9684),
    [sym_actions_keyword] = ACTIONS(9684),
    [sym_layout_keyword] = ACTIONS(9684),
    [sym_area_keyword] = ACTIONS(9684),
    [sym_group_keyword] = ACTIONS(9684),
    [sym_repeater_keyword] = ACTIONS(9684),
    [sym_cuegroup_keyword] = ACTIONS(9684),
    [sym_fixed_keyword] = ACTIONS(9684),
    [sym_grid_keyword] = ACTIONS(9684),
    [sym_part_keyword] = ACTIONS(9684),
    [sym_systempart_keyword] = ACTIONS(9684),
    [sym_usercontrol_keyword] = ACTIONS(9684),
    [sym_dataset_keyword] = ACTIONS(9684),
    [sym_elements_keyword] = ACTIONS(9684),
    [sym_dataitem_keyword] = ACTIONS(9684),
    [sym_column_keyword] = ACTIONS(9684),
    [sym_filter_keyword] = ACTIONS(9684),
    [sym_labels_keyword] = ACTIONS(9684),
    [sym_rendering_keyword] = ACTIONS(9684),
    [sym_requestpage_keyword] = ACTIONS(9684),
    [sym_schema_keyword] = ACTIONS(9684),
    [sym_views_keyword] = ACTIONS(9684),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9684),
    [sym_preproc_open] = ACTIONS(9684),
    [sym_preproc_close] = ACTIONS(9684),
  },
  [STATE(4254)] = {
    [anon_sym_SEMI] = ACTIONS(9688),
    [aux_sym_where_condition_token1] = ACTIONS(9690),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9688),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9688),
    [anon_sym_LBRACK] = ACTIONS(9688),
    [aux_sym_basic_type_token6] = ACTIONS(9690),
    [aux_sym_basic_type_token22] = ACTIONS(9690),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9688),
    [aux_sym_addafter_modification_token1] = ACTIONS(9688),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9688),
    [aux_sym_modify_modification_token1] = ACTIONS(9688),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9688),
    [aux_sym_movelast_modification_token1] = ACTIONS(9688),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9688),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9688),
    [aux_sym_separator_action_token1] = ACTIONS(9688),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9688),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9688),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9688),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9688),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9688),
    [anon_sym_POUNDif] = ACTIONS(9688),
    [anon_sym_POUNDIF] = ACTIONS(9688),
    [anon_sym_POUNDIf] = ACTIONS(9688),
    [anon_sym_POUNDelif] = ACTIONS(9688),
    [anon_sym_POUNDELIF] = ACTIONS(9688),
    [anon_sym_POUNDElif] = ACTIONS(9688),
    [anon_sym_POUNDelse] = ACTIONS(9688),
    [anon_sym_POUNDELSE] = ACTIONS(9688),
    [anon_sym_POUNDElse] = ACTIONS(9688),
    [anon_sym_POUNDelse2] = ACTIONS(9688),
    [anon_sym_POUNDELSE2] = ACTIONS(9688),
    [anon_sym_POUNDElse2] = ACTIONS(9688),
    [anon_sym_POUNDendif] = ACTIONS(9688),
    [anon_sym_POUNDENDIF] = ACTIONS(9688),
    [anon_sym_POUNDEndif] = ACTIONS(9688),
    [anon_sym_POUNDendif2] = ACTIONS(9688),
    [anon_sym_POUNDENDIF2] = ACTIONS(9688),
    [anon_sym_POUNDEndif2] = ACTIONS(9688),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9688),
    [sym_trigger_keyword] = ACTIONS(9688),
    [sym_var_keyword] = ACTIONS(9688),
    [sym_local_keyword] = ACTIONS(9688),
    [sym_internal_keyword] = ACTIONS(9688),
    [sym_protected_keyword] = ACTIONS(9688),
    [sym_event_keyword] = ACTIONS(9688),
    [sym_fields_keyword] = ACTIONS(9688),
    [sym_keys_keyword] = ACTIONS(9688),
    [sym_fieldgroups_keyword] = ACTIONS(9688),
    [sym_actions_keyword] = ACTIONS(9688),
    [sym_layout_keyword] = ACTIONS(9688),
    [sym_area_keyword] = ACTIONS(9688),
    [sym_group_keyword] = ACTIONS(9688),
    [sym_repeater_keyword] = ACTIONS(9688),
    [sym_cuegroup_keyword] = ACTIONS(9688),
    [sym_fixed_keyword] = ACTIONS(9688),
    [sym_grid_keyword] = ACTIONS(9688),
    [sym_part_keyword] = ACTIONS(9688),
    [sym_systempart_keyword] = ACTIONS(9688),
    [sym_usercontrol_keyword] = ACTIONS(9688),
    [sym_dataset_keyword] = ACTIONS(9688),
    [sym_elements_keyword] = ACTIONS(9688),
    [sym_dataitem_keyword] = ACTIONS(9688),
    [sym_column_keyword] = ACTIONS(9688),
    [sym_filter_keyword] = ACTIONS(9688),
    [sym_labels_keyword] = ACTIONS(9688),
    [sym_rendering_keyword] = ACTIONS(9688),
    [sym_requestpage_keyword] = ACTIONS(9688),
    [sym_schema_keyword] = ACTIONS(9688),
    [sym_views_keyword] = ACTIONS(9688),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9688),
    [sym_preproc_open] = ACTIONS(9688),
    [sym_preproc_close] = ACTIONS(9688),
  },
  [STATE(4255)] = {
    [anon_sym_SEMI] = ACTIONS(9692),
    [aux_sym_where_condition_token1] = ACTIONS(9694),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9692),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9692),
    [anon_sym_LBRACK] = ACTIONS(9692),
    [aux_sym_basic_type_token6] = ACTIONS(9694),
    [aux_sym_basic_type_token22] = ACTIONS(9694),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9692),
    [aux_sym_addafter_modification_token1] = ACTIONS(9692),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9692),
    [aux_sym_modify_modification_token1] = ACTIONS(9692),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9692),
    [aux_sym_movelast_modification_token1] = ACTIONS(9692),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9692),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9692),
    [aux_sym_separator_action_token1] = ACTIONS(9692),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9692),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9692),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9692),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9692),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9692),
    [anon_sym_POUNDif] = ACTIONS(9692),
    [anon_sym_POUNDIF] = ACTIONS(9692),
    [anon_sym_POUNDIf] = ACTIONS(9692),
    [anon_sym_POUNDelif] = ACTIONS(9692),
    [anon_sym_POUNDELIF] = ACTIONS(9692),
    [anon_sym_POUNDElif] = ACTIONS(9692),
    [anon_sym_POUNDelse] = ACTIONS(9692),
    [anon_sym_POUNDELSE] = ACTIONS(9692),
    [anon_sym_POUNDElse] = ACTIONS(9692),
    [anon_sym_POUNDelse2] = ACTIONS(9692),
    [anon_sym_POUNDELSE2] = ACTIONS(9692),
    [anon_sym_POUNDElse2] = ACTIONS(9692),
    [anon_sym_POUNDendif] = ACTIONS(9692),
    [anon_sym_POUNDENDIF] = ACTIONS(9692),
    [anon_sym_POUNDEndif] = ACTIONS(9692),
    [anon_sym_POUNDendif2] = ACTIONS(9692),
    [anon_sym_POUNDENDIF2] = ACTIONS(9692),
    [anon_sym_POUNDEndif2] = ACTIONS(9692),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9692),
    [sym_trigger_keyword] = ACTIONS(9692),
    [sym_var_keyword] = ACTIONS(9692),
    [sym_local_keyword] = ACTIONS(9692),
    [sym_internal_keyword] = ACTIONS(9692),
    [sym_protected_keyword] = ACTIONS(9692),
    [sym_event_keyword] = ACTIONS(9692),
    [sym_fields_keyword] = ACTIONS(9692),
    [sym_keys_keyword] = ACTIONS(9692),
    [sym_fieldgroups_keyword] = ACTIONS(9692),
    [sym_actions_keyword] = ACTIONS(9692),
    [sym_layout_keyword] = ACTIONS(9692),
    [sym_area_keyword] = ACTIONS(9692),
    [sym_group_keyword] = ACTIONS(9692),
    [sym_repeater_keyword] = ACTIONS(9692),
    [sym_cuegroup_keyword] = ACTIONS(9692),
    [sym_fixed_keyword] = ACTIONS(9692),
    [sym_grid_keyword] = ACTIONS(9692),
    [sym_part_keyword] = ACTIONS(9692),
    [sym_systempart_keyword] = ACTIONS(9692),
    [sym_usercontrol_keyword] = ACTIONS(9692),
    [sym_dataset_keyword] = ACTIONS(9692),
    [sym_elements_keyword] = ACTIONS(9692),
    [sym_dataitem_keyword] = ACTIONS(9692),
    [sym_column_keyword] = ACTIONS(9692),
    [sym_filter_keyword] = ACTIONS(9692),
    [sym_labels_keyword] = ACTIONS(9692),
    [sym_rendering_keyword] = ACTIONS(9692),
    [sym_requestpage_keyword] = ACTIONS(9692),
    [sym_schema_keyword] = ACTIONS(9692),
    [sym_views_keyword] = ACTIONS(9692),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9692),
    [sym_preproc_open] = ACTIONS(9692),
    [sym_preproc_close] = ACTIONS(9692),
  },
  [STATE(4256)] = {
    [anon_sym_SEMI] = ACTIONS(9696),
    [aux_sym_where_condition_token1] = ACTIONS(9698),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9696),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9696),
    [anon_sym_LBRACK] = ACTIONS(9696),
    [aux_sym_basic_type_token6] = ACTIONS(9698),
    [aux_sym_basic_type_token22] = ACTIONS(9698),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9696),
    [aux_sym_addafter_modification_token1] = ACTIONS(9696),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9696),
    [aux_sym_modify_modification_token1] = ACTIONS(9696),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9696),
    [aux_sym_movelast_modification_token1] = ACTIONS(9696),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9696),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9696),
    [aux_sym_separator_action_token1] = ACTIONS(9696),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9696),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9696),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9696),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9696),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9696),
    [anon_sym_POUNDif] = ACTIONS(9696),
    [anon_sym_POUNDIF] = ACTIONS(9696),
    [anon_sym_POUNDIf] = ACTIONS(9696),
    [anon_sym_POUNDelif] = ACTIONS(9696),
    [anon_sym_POUNDELIF] = ACTIONS(9696),
    [anon_sym_POUNDElif] = ACTIONS(9696),
    [anon_sym_POUNDelse] = ACTIONS(9696),
    [anon_sym_POUNDELSE] = ACTIONS(9696),
    [anon_sym_POUNDElse] = ACTIONS(9696),
    [anon_sym_POUNDelse2] = ACTIONS(9696),
    [anon_sym_POUNDELSE2] = ACTIONS(9696),
    [anon_sym_POUNDElse2] = ACTIONS(9696),
    [anon_sym_POUNDendif] = ACTIONS(9696),
    [anon_sym_POUNDENDIF] = ACTIONS(9696),
    [anon_sym_POUNDEndif] = ACTIONS(9696),
    [anon_sym_POUNDendif2] = ACTIONS(9696),
    [anon_sym_POUNDENDIF2] = ACTIONS(9696),
    [anon_sym_POUNDEndif2] = ACTIONS(9696),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9696),
    [sym_trigger_keyword] = ACTIONS(9696),
    [sym_var_keyword] = ACTIONS(9696),
    [sym_local_keyword] = ACTIONS(9696),
    [sym_internal_keyword] = ACTIONS(9696),
    [sym_protected_keyword] = ACTIONS(9696),
    [sym_event_keyword] = ACTIONS(9696),
    [sym_fields_keyword] = ACTIONS(9696),
    [sym_keys_keyword] = ACTIONS(9696),
    [sym_fieldgroups_keyword] = ACTIONS(9696),
    [sym_actions_keyword] = ACTIONS(9696),
    [sym_layout_keyword] = ACTIONS(9696),
    [sym_area_keyword] = ACTIONS(9696),
    [sym_group_keyword] = ACTIONS(9696),
    [sym_repeater_keyword] = ACTIONS(9696),
    [sym_cuegroup_keyword] = ACTIONS(9696),
    [sym_fixed_keyword] = ACTIONS(9696),
    [sym_grid_keyword] = ACTIONS(9696),
    [sym_part_keyword] = ACTIONS(9696),
    [sym_systempart_keyword] = ACTIONS(9696),
    [sym_usercontrol_keyword] = ACTIONS(9696),
    [sym_dataset_keyword] = ACTIONS(9696),
    [sym_elements_keyword] = ACTIONS(9696),
    [sym_dataitem_keyword] = ACTIONS(9696),
    [sym_column_keyword] = ACTIONS(9696),
    [sym_filter_keyword] = ACTIONS(9696),
    [sym_labels_keyword] = ACTIONS(9696),
    [sym_rendering_keyword] = ACTIONS(9696),
    [sym_requestpage_keyword] = ACTIONS(9696),
    [sym_schema_keyword] = ACTIONS(9696),
    [sym_views_keyword] = ACTIONS(9696),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9696),
    [sym_preproc_open] = ACTIONS(9696),
    [sym_preproc_close] = ACTIONS(9696),
  },
  [STATE(4257)] = {
    [anon_sym_SEMI] = ACTIONS(9700),
    [aux_sym_where_condition_token1] = ACTIONS(9702),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9700),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9700),
    [anon_sym_LBRACK] = ACTIONS(9700),
    [aux_sym_basic_type_token6] = ACTIONS(9702),
    [aux_sym_basic_type_token22] = ACTIONS(9702),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9700),
    [aux_sym_addafter_modification_token1] = ACTIONS(9700),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9700),
    [aux_sym_modify_modification_token1] = ACTIONS(9700),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9700),
    [aux_sym_movelast_modification_token1] = ACTIONS(9700),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9700),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9700),
    [aux_sym_separator_action_token1] = ACTIONS(9700),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9700),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9700),
    [anon_sym_POUNDif] = ACTIONS(9700),
    [anon_sym_POUNDIF] = ACTIONS(9700),
    [anon_sym_POUNDIf] = ACTIONS(9700),
    [anon_sym_POUNDelif] = ACTIONS(9700),
    [anon_sym_POUNDELIF] = ACTIONS(9700),
    [anon_sym_POUNDElif] = ACTIONS(9700),
    [anon_sym_POUNDelse] = ACTIONS(9700),
    [anon_sym_POUNDELSE] = ACTIONS(9700),
    [anon_sym_POUNDElse] = ACTIONS(9700),
    [anon_sym_POUNDelse2] = ACTIONS(9700),
    [anon_sym_POUNDELSE2] = ACTIONS(9700),
    [anon_sym_POUNDElse2] = ACTIONS(9700),
    [anon_sym_POUNDendif] = ACTIONS(9700),
    [anon_sym_POUNDENDIF] = ACTIONS(9700),
    [anon_sym_POUNDEndif] = ACTIONS(9700),
    [anon_sym_POUNDendif2] = ACTIONS(9700),
    [anon_sym_POUNDENDIF2] = ACTIONS(9700),
    [anon_sym_POUNDEndif2] = ACTIONS(9700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9700),
    [sym_trigger_keyword] = ACTIONS(9700),
    [sym_var_keyword] = ACTIONS(9700),
    [sym_local_keyword] = ACTIONS(9700),
    [sym_internal_keyword] = ACTIONS(9700),
    [sym_protected_keyword] = ACTIONS(9700),
    [sym_event_keyword] = ACTIONS(9700),
    [sym_fields_keyword] = ACTIONS(9700),
    [sym_keys_keyword] = ACTIONS(9700),
    [sym_fieldgroups_keyword] = ACTIONS(9700),
    [sym_actions_keyword] = ACTIONS(9700),
    [sym_layout_keyword] = ACTIONS(9700),
    [sym_area_keyword] = ACTIONS(9700),
    [sym_group_keyword] = ACTIONS(9700),
    [sym_repeater_keyword] = ACTIONS(9700),
    [sym_cuegroup_keyword] = ACTIONS(9700),
    [sym_fixed_keyword] = ACTIONS(9700),
    [sym_grid_keyword] = ACTIONS(9700),
    [sym_part_keyword] = ACTIONS(9700),
    [sym_systempart_keyword] = ACTIONS(9700),
    [sym_usercontrol_keyword] = ACTIONS(9700),
    [sym_dataset_keyword] = ACTIONS(9700),
    [sym_elements_keyword] = ACTIONS(9700),
    [sym_dataitem_keyword] = ACTIONS(9700),
    [sym_column_keyword] = ACTIONS(9700),
    [sym_filter_keyword] = ACTIONS(9700),
    [sym_labels_keyword] = ACTIONS(9700),
    [sym_rendering_keyword] = ACTIONS(9700),
    [sym_requestpage_keyword] = ACTIONS(9700),
    [sym_schema_keyword] = ACTIONS(9700),
    [sym_views_keyword] = ACTIONS(9700),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9700),
    [sym_preproc_open] = ACTIONS(9700),
    [sym_preproc_close] = ACTIONS(9700),
  },
  [STATE(4258)] = {
    [anon_sym_SEMI] = ACTIONS(9700),
    [aux_sym_where_condition_token1] = ACTIONS(9702),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9700),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9700),
    [anon_sym_LBRACK] = ACTIONS(9700),
    [aux_sym_basic_type_token6] = ACTIONS(9702),
    [aux_sym_basic_type_token22] = ACTIONS(9702),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9700),
    [aux_sym_addafter_modification_token1] = ACTIONS(9700),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9700),
    [aux_sym_modify_modification_token1] = ACTIONS(9700),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9700),
    [aux_sym_movelast_modification_token1] = ACTIONS(9700),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9700),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9700),
    [aux_sym_separator_action_token1] = ACTIONS(9700),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9700),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9700),
    [anon_sym_POUNDif] = ACTIONS(9700),
    [anon_sym_POUNDIF] = ACTIONS(9700),
    [anon_sym_POUNDIf] = ACTIONS(9700),
    [anon_sym_POUNDelif] = ACTIONS(9700),
    [anon_sym_POUNDELIF] = ACTIONS(9700),
    [anon_sym_POUNDElif] = ACTIONS(9700),
    [anon_sym_POUNDelse] = ACTIONS(9700),
    [anon_sym_POUNDELSE] = ACTIONS(9700),
    [anon_sym_POUNDElse] = ACTIONS(9700),
    [anon_sym_POUNDelse2] = ACTIONS(9700),
    [anon_sym_POUNDELSE2] = ACTIONS(9700),
    [anon_sym_POUNDElse2] = ACTIONS(9700),
    [anon_sym_POUNDendif] = ACTIONS(9700),
    [anon_sym_POUNDENDIF] = ACTIONS(9700),
    [anon_sym_POUNDEndif] = ACTIONS(9700),
    [anon_sym_POUNDendif2] = ACTIONS(9700),
    [anon_sym_POUNDENDIF2] = ACTIONS(9700),
    [anon_sym_POUNDEndif2] = ACTIONS(9700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9700),
    [sym_trigger_keyword] = ACTIONS(9700),
    [sym_var_keyword] = ACTIONS(9700),
    [sym_local_keyword] = ACTIONS(9700),
    [sym_internal_keyword] = ACTIONS(9700),
    [sym_protected_keyword] = ACTIONS(9700),
    [sym_event_keyword] = ACTIONS(9700),
    [sym_fields_keyword] = ACTIONS(9700),
    [sym_keys_keyword] = ACTIONS(9700),
    [sym_fieldgroups_keyword] = ACTIONS(9700),
    [sym_actions_keyword] = ACTIONS(9700),
    [sym_layout_keyword] = ACTIONS(9700),
    [sym_area_keyword] = ACTIONS(9700),
    [sym_group_keyword] = ACTIONS(9700),
    [sym_repeater_keyword] = ACTIONS(9700),
    [sym_cuegroup_keyword] = ACTIONS(9700),
    [sym_fixed_keyword] = ACTIONS(9700),
    [sym_grid_keyword] = ACTIONS(9700),
    [sym_part_keyword] = ACTIONS(9700),
    [sym_systempart_keyword] = ACTIONS(9700),
    [sym_usercontrol_keyword] = ACTIONS(9700),
    [sym_dataset_keyword] = ACTIONS(9700),
    [sym_elements_keyword] = ACTIONS(9700),
    [sym_dataitem_keyword] = ACTIONS(9700),
    [sym_column_keyword] = ACTIONS(9700),
    [sym_filter_keyword] = ACTIONS(9700),
    [sym_labels_keyword] = ACTIONS(9700),
    [sym_rendering_keyword] = ACTIONS(9700),
    [sym_requestpage_keyword] = ACTIONS(9700),
    [sym_schema_keyword] = ACTIONS(9700),
    [sym_views_keyword] = ACTIONS(9700),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9700),
    [sym_preproc_open] = ACTIONS(9700),
    [sym_preproc_close] = ACTIONS(9700),
  },
  [STATE(4259)] = {
    [anon_sym_SEMI] = ACTIONS(9700),
    [aux_sym_where_condition_token1] = ACTIONS(9702),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9700),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9700),
    [anon_sym_LBRACK] = ACTIONS(9700),
    [aux_sym_basic_type_token6] = ACTIONS(9702),
    [aux_sym_basic_type_token22] = ACTIONS(9702),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9700),
    [aux_sym_addafter_modification_token1] = ACTIONS(9700),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9700),
    [aux_sym_modify_modification_token1] = ACTIONS(9700),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9700),
    [aux_sym_movelast_modification_token1] = ACTIONS(9700),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9700),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9700),
    [aux_sym_separator_action_token1] = ACTIONS(9700),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9700),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9700),
    [anon_sym_POUNDif] = ACTIONS(9700),
    [anon_sym_POUNDIF] = ACTIONS(9700),
    [anon_sym_POUNDIf] = ACTIONS(9700),
    [anon_sym_POUNDelif] = ACTIONS(9700),
    [anon_sym_POUNDELIF] = ACTIONS(9700),
    [anon_sym_POUNDElif] = ACTIONS(9700),
    [anon_sym_POUNDelse] = ACTIONS(9700),
    [anon_sym_POUNDELSE] = ACTIONS(9700),
    [anon_sym_POUNDElse] = ACTIONS(9700),
    [anon_sym_POUNDelse2] = ACTIONS(9700),
    [anon_sym_POUNDELSE2] = ACTIONS(9700),
    [anon_sym_POUNDElse2] = ACTIONS(9700),
    [anon_sym_POUNDendif] = ACTIONS(9700),
    [anon_sym_POUNDENDIF] = ACTIONS(9700),
    [anon_sym_POUNDEndif] = ACTIONS(9700),
    [anon_sym_POUNDendif2] = ACTIONS(9700),
    [anon_sym_POUNDENDIF2] = ACTIONS(9700),
    [anon_sym_POUNDEndif2] = ACTIONS(9700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9700),
    [sym_trigger_keyword] = ACTIONS(9700),
    [sym_var_keyword] = ACTIONS(9700),
    [sym_local_keyword] = ACTIONS(9700),
    [sym_internal_keyword] = ACTIONS(9700),
    [sym_protected_keyword] = ACTIONS(9700),
    [sym_event_keyword] = ACTIONS(9700),
    [sym_fields_keyword] = ACTIONS(9700),
    [sym_keys_keyword] = ACTIONS(9700),
    [sym_fieldgroups_keyword] = ACTIONS(9700),
    [sym_actions_keyword] = ACTIONS(9700),
    [sym_layout_keyword] = ACTIONS(9700),
    [sym_area_keyword] = ACTIONS(9700),
    [sym_group_keyword] = ACTIONS(9700),
    [sym_repeater_keyword] = ACTIONS(9700),
    [sym_cuegroup_keyword] = ACTIONS(9700),
    [sym_fixed_keyword] = ACTIONS(9700),
    [sym_grid_keyword] = ACTIONS(9700),
    [sym_part_keyword] = ACTIONS(9700),
    [sym_systempart_keyword] = ACTIONS(9700),
    [sym_usercontrol_keyword] = ACTIONS(9700),
    [sym_dataset_keyword] = ACTIONS(9700),
    [sym_elements_keyword] = ACTIONS(9700),
    [sym_dataitem_keyword] = ACTIONS(9700),
    [sym_column_keyword] = ACTIONS(9700),
    [sym_filter_keyword] = ACTIONS(9700),
    [sym_labels_keyword] = ACTIONS(9700),
    [sym_rendering_keyword] = ACTIONS(9700),
    [sym_requestpage_keyword] = ACTIONS(9700),
    [sym_schema_keyword] = ACTIONS(9700),
    [sym_views_keyword] = ACTIONS(9700),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9700),
    [sym_preproc_open] = ACTIONS(9700),
    [sym_preproc_close] = ACTIONS(9700),
  },
  [STATE(4260)] = {
    [anon_sym_SEMI] = ACTIONS(9700),
    [aux_sym_where_condition_token1] = ACTIONS(9702),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9700),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9700),
    [anon_sym_LBRACK] = ACTIONS(9700),
    [aux_sym_basic_type_token6] = ACTIONS(9702),
    [aux_sym_basic_type_token22] = ACTIONS(9702),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9700),
    [aux_sym_addafter_modification_token1] = ACTIONS(9700),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9700),
    [aux_sym_modify_modification_token1] = ACTIONS(9700),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9700),
    [aux_sym_movelast_modification_token1] = ACTIONS(9700),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9700),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9700),
    [aux_sym_separator_action_token1] = ACTIONS(9700),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9700),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9700),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9700),
    [anon_sym_POUNDif] = ACTIONS(9700),
    [anon_sym_POUNDIF] = ACTIONS(9700),
    [anon_sym_POUNDIf] = ACTIONS(9700),
    [anon_sym_POUNDelif] = ACTIONS(9700),
    [anon_sym_POUNDELIF] = ACTIONS(9700),
    [anon_sym_POUNDElif] = ACTIONS(9700),
    [anon_sym_POUNDelse] = ACTIONS(9700),
    [anon_sym_POUNDELSE] = ACTIONS(9700),
    [anon_sym_POUNDElse] = ACTIONS(9700),
    [anon_sym_POUNDelse2] = ACTIONS(9700),
    [anon_sym_POUNDELSE2] = ACTIONS(9700),
    [anon_sym_POUNDElse2] = ACTIONS(9700),
    [anon_sym_POUNDendif] = ACTIONS(9700),
    [anon_sym_POUNDENDIF] = ACTIONS(9700),
    [anon_sym_POUNDEndif] = ACTIONS(9700),
    [anon_sym_POUNDendif2] = ACTIONS(9700),
    [anon_sym_POUNDENDIF2] = ACTIONS(9700),
    [anon_sym_POUNDEndif2] = ACTIONS(9700),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9700),
    [sym_trigger_keyword] = ACTIONS(9700),
    [sym_var_keyword] = ACTIONS(9700),
    [sym_local_keyword] = ACTIONS(9700),
    [sym_internal_keyword] = ACTIONS(9700),
    [sym_protected_keyword] = ACTIONS(9700),
    [sym_event_keyword] = ACTIONS(9700),
    [sym_fields_keyword] = ACTIONS(9700),
    [sym_keys_keyword] = ACTIONS(9700),
    [sym_fieldgroups_keyword] = ACTIONS(9700),
    [sym_actions_keyword] = ACTIONS(9700),
    [sym_layout_keyword] = ACTIONS(9700),
    [sym_area_keyword] = ACTIONS(9700),
    [sym_group_keyword] = ACTIONS(9700),
    [sym_repeater_keyword] = ACTIONS(9700),
    [sym_cuegroup_keyword] = ACTIONS(9700),
    [sym_fixed_keyword] = ACTIONS(9700),
    [sym_grid_keyword] = ACTIONS(9700),
    [sym_part_keyword] = ACTIONS(9700),
    [sym_systempart_keyword] = ACTIONS(9700),
    [sym_usercontrol_keyword] = ACTIONS(9700),
    [sym_dataset_keyword] = ACTIONS(9700),
    [sym_elements_keyword] = ACTIONS(9700),
    [sym_dataitem_keyword] = ACTIONS(9700),
    [sym_column_keyword] = ACTIONS(9700),
    [sym_filter_keyword] = ACTIONS(9700),
    [sym_labels_keyword] = ACTIONS(9700),
    [sym_rendering_keyword] = ACTIONS(9700),
    [sym_requestpage_keyword] = ACTIONS(9700),
    [sym_schema_keyword] = ACTIONS(9700),
    [sym_views_keyword] = ACTIONS(9700),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9700),
    [sym_preproc_open] = ACTIONS(9700),
    [sym_preproc_close] = ACTIONS(9700),
  },
  [STATE(4261)] = {
    [anon_sym_SEMI] = ACTIONS(9704),
    [aux_sym_where_condition_token1] = ACTIONS(9706),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9704),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9704),
    [anon_sym_LBRACK] = ACTIONS(9704),
    [aux_sym_basic_type_token6] = ACTIONS(9706),
    [aux_sym_basic_type_token22] = ACTIONS(9706),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9704),
    [aux_sym_addafter_modification_token1] = ACTIONS(9704),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9704),
    [aux_sym_modify_modification_token1] = ACTIONS(9704),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9704),
    [aux_sym_movelast_modification_token1] = ACTIONS(9704),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9704),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9704),
    [aux_sym_separator_action_token1] = ACTIONS(9704),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9704),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9704),
    [anon_sym_POUNDif] = ACTIONS(9704),
    [anon_sym_POUNDIF] = ACTIONS(9704),
    [anon_sym_POUNDIf] = ACTIONS(9704),
    [anon_sym_POUNDelif] = ACTIONS(9704),
    [anon_sym_POUNDELIF] = ACTIONS(9704),
    [anon_sym_POUNDElif] = ACTIONS(9704),
    [anon_sym_POUNDelse] = ACTIONS(9704),
    [anon_sym_POUNDELSE] = ACTIONS(9704),
    [anon_sym_POUNDElse] = ACTIONS(9704),
    [anon_sym_POUNDelse2] = ACTIONS(9704),
    [anon_sym_POUNDELSE2] = ACTIONS(9704),
    [anon_sym_POUNDElse2] = ACTIONS(9704),
    [anon_sym_POUNDendif] = ACTIONS(9704),
    [anon_sym_POUNDENDIF] = ACTIONS(9704),
    [anon_sym_POUNDEndif] = ACTIONS(9704),
    [anon_sym_POUNDendif2] = ACTIONS(9704),
    [anon_sym_POUNDENDIF2] = ACTIONS(9704),
    [anon_sym_POUNDEndif2] = ACTIONS(9704),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9704),
    [sym_trigger_keyword] = ACTIONS(9704),
    [sym_var_keyword] = ACTIONS(9704),
    [sym_local_keyword] = ACTIONS(9704),
    [sym_internal_keyword] = ACTIONS(9704),
    [sym_protected_keyword] = ACTIONS(9704),
    [sym_event_keyword] = ACTIONS(9704),
    [sym_fields_keyword] = ACTIONS(9704),
    [sym_keys_keyword] = ACTIONS(9704),
    [sym_fieldgroups_keyword] = ACTIONS(9704),
    [sym_actions_keyword] = ACTIONS(9704),
    [sym_layout_keyword] = ACTIONS(9704),
    [sym_area_keyword] = ACTIONS(9704),
    [sym_group_keyword] = ACTIONS(9704),
    [sym_repeater_keyword] = ACTIONS(9704),
    [sym_cuegroup_keyword] = ACTIONS(9704),
    [sym_fixed_keyword] = ACTIONS(9704),
    [sym_grid_keyword] = ACTIONS(9704),
    [sym_part_keyword] = ACTIONS(9704),
    [sym_systempart_keyword] = ACTIONS(9704),
    [sym_usercontrol_keyword] = ACTIONS(9704),
    [sym_dataset_keyword] = ACTIONS(9704),
    [sym_elements_keyword] = ACTIONS(9704),
    [sym_dataitem_keyword] = ACTIONS(9704),
    [sym_column_keyword] = ACTIONS(9704),
    [sym_filter_keyword] = ACTIONS(9704),
    [sym_labels_keyword] = ACTIONS(9704),
    [sym_rendering_keyword] = ACTIONS(9704),
    [sym_requestpage_keyword] = ACTIONS(9704),
    [sym_schema_keyword] = ACTIONS(9704),
    [sym_views_keyword] = ACTIONS(9704),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9704),
    [sym_preproc_open] = ACTIONS(9704),
    [sym_preproc_close] = ACTIONS(9704),
  },
  [STATE(4262)] = {
    [anon_sym_SEMI] = ACTIONS(9704),
    [aux_sym_where_condition_token1] = ACTIONS(9706),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9704),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9704),
    [anon_sym_LBRACK] = ACTIONS(9704),
    [aux_sym_basic_type_token6] = ACTIONS(9706),
    [aux_sym_basic_type_token22] = ACTIONS(9706),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9704),
    [aux_sym_addafter_modification_token1] = ACTIONS(9704),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9704),
    [aux_sym_modify_modification_token1] = ACTIONS(9704),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9704),
    [aux_sym_movelast_modification_token1] = ACTIONS(9704),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9704),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9704),
    [aux_sym_separator_action_token1] = ACTIONS(9704),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9704),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9704),
    [anon_sym_POUNDif] = ACTIONS(9704),
    [anon_sym_POUNDIF] = ACTIONS(9704),
    [anon_sym_POUNDIf] = ACTIONS(9704),
    [anon_sym_POUNDelif] = ACTIONS(9704),
    [anon_sym_POUNDELIF] = ACTIONS(9704),
    [anon_sym_POUNDElif] = ACTIONS(9704),
    [anon_sym_POUNDelse] = ACTIONS(9704),
    [anon_sym_POUNDELSE] = ACTIONS(9704),
    [anon_sym_POUNDElse] = ACTIONS(9704),
    [anon_sym_POUNDelse2] = ACTIONS(9704),
    [anon_sym_POUNDELSE2] = ACTIONS(9704),
    [anon_sym_POUNDElse2] = ACTIONS(9704),
    [anon_sym_POUNDendif] = ACTIONS(9704),
    [anon_sym_POUNDENDIF] = ACTIONS(9704),
    [anon_sym_POUNDEndif] = ACTIONS(9704),
    [anon_sym_POUNDendif2] = ACTIONS(9704),
    [anon_sym_POUNDENDIF2] = ACTIONS(9704),
    [anon_sym_POUNDEndif2] = ACTIONS(9704),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9704),
    [sym_trigger_keyword] = ACTIONS(9704),
    [sym_var_keyword] = ACTIONS(9704),
    [sym_local_keyword] = ACTIONS(9704),
    [sym_internal_keyword] = ACTIONS(9704),
    [sym_protected_keyword] = ACTIONS(9704),
    [sym_event_keyword] = ACTIONS(9704),
    [sym_fields_keyword] = ACTIONS(9704),
    [sym_keys_keyword] = ACTIONS(9704),
    [sym_fieldgroups_keyword] = ACTIONS(9704),
    [sym_actions_keyword] = ACTIONS(9704),
    [sym_layout_keyword] = ACTIONS(9704),
    [sym_area_keyword] = ACTIONS(9704),
    [sym_group_keyword] = ACTIONS(9704),
    [sym_repeater_keyword] = ACTIONS(9704),
    [sym_cuegroup_keyword] = ACTIONS(9704),
    [sym_fixed_keyword] = ACTIONS(9704),
    [sym_grid_keyword] = ACTIONS(9704),
    [sym_part_keyword] = ACTIONS(9704),
    [sym_systempart_keyword] = ACTIONS(9704),
    [sym_usercontrol_keyword] = ACTIONS(9704),
    [sym_dataset_keyword] = ACTIONS(9704),
    [sym_elements_keyword] = ACTIONS(9704),
    [sym_dataitem_keyword] = ACTIONS(9704),
    [sym_column_keyword] = ACTIONS(9704),
    [sym_filter_keyword] = ACTIONS(9704),
    [sym_labels_keyword] = ACTIONS(9704),
    [sym_rendering_keyword] = ACTIONS(9704),
    [sym_requestpage_keyword] = ACTIONS(9704),
    [sym_schema_keyword] = ACTIONS(9704),
    [sym_views_keyword] = ACTIONS(9704),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9704),
    [sym_preproc_open] = ACTIONS(9704),
    [sym_preproc_close] = ACTIONS(9704),
  },
  [STATE(4263)] = {
    [anon_sym_SEMI] = ACTIONS(9704),
    [aux_sym_where_condition_token1] = ACTIONS(9706),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9704),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9704),
    [anon_sym_LBRACK] = ACTIONS(9704),
    [aux_sym_basic_type_token6] = ACTIONS(9706),
    [aux_sym_basic_type_token22] = ACTIONS(9706),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9704),
    [aux_sym_addafter_modification_token1] = ACTIONS(9704),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9704),
    [aux_sym_modify_modification_token1] = ACTIONS(9704),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9704),
    [aux_sym_movelast_modification_token1] = ACTIONS(9704),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9704),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9704),
    [aux_sym_separator_action_token1] = ACTIONS(9704),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9704),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9704),
    [anon_sym_POUNDif] = ACTIONS(9704),
    [anon_sym_POUNDIF] = ACTIONS(9704),
    [anon_sym_POUNDIf] = ACTIONS(9704),
    [anon_sym_POUNDelif] = ACTIONS(9704),
    [anon_sym_POUNDELIF] = ACTIONS(9704),
    [anon_sym_POUNDElif] = ACTIONS(9704),
    [anon_sym_POUNDelse] = ACTIONS(9704),
    [anon_sym_POUNDELSE] = ACTIONS(9704),
    [anon_sym_POUNDElse] = ACTIONS(9704),
    [anon_sym_POUNDelse2] = ACTIONS(9704),
    [anon_sym_POUNDELSE2] = ACTIONS(9704),
    [anon_sym_POUNDElse2] = ACTIONS(9704),
    [anon_sym_POUNDendif] = ACTIONS(9704),
    [anon_sym_POUNDENDIF] = ACTIONS(9704),
    [anon_sym_POUNDEndif] = ACTIONS(9704),
    [anon_sym_POUNDendif2] = ACTIONS(9704),
    [anon_sym_POUNDENDIF2] = ACTIONS(9704),
    [anon_sym_POUNDEndif2] = ACTIONS(9704),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9704),
    [sym_trigger_keyword] = ACTIONS(9704),
    [sym_var_keyword] = ACTIONS(9704),
    [sym_local_keyword] = ACTIONS(9704),
    [sym_internal_keyword] = ACTIONS(9704),
    [sym_protected_keyword] = ACTIONS(9704),
    [sym_event_keyword] = ACTIONS(9704),
    [sym_fields_keyword] = ACTIONS(9704),
    [sym_keys_keyword] = ACTIONS(9704),
    [sym_fieldgroups_keyword] = ACTIONS(9704),
    [sym_actions_keyword] = ACTIONS(9704),
    [sym_layout_keyword] = ACTIONS(9704),
    [sym_area_keyword] = ACTIONS(9704),
    [sym_group_keyword] = ACTIONS(9704),
    [sym_repeater_keyword] = ACTIONS(9704),
    [sym_cuegroup_keyword] = ACTIONS(9704),
    [sym_fixed_keyword] = ACTIONS(9704),
    [sym_grid_keyword] = ACTIONS(9704),
    [sym_part_keyword] = ACTIONS(9704),
    [sym_systempart_keyword] = ACTIONS(9704),
    [sym_usercontrol_keyword] = ACTIONS(9704),
    [sym_dataset_keyword] = ACTIONS(9704),
    [sym_elements_keyword] = ACTIONS(9704),
    [sym_dataitem_keyword] = ACTIONS(9704),
    [sym_column_keyword] = ACTIONS(9704),
    [sym_filter_keyword] = ACTIONS(9704),
    [sym_labels_keyword] = ACTIONS(9704),
    [sym_rendering_keyword] = ACTIONS(9704),
    [sym_requestpage_keyword] = ACTIONS(9704),
    [sym_schema_keyword] = ACTIONS(9704),
    [sym_views_keyword] = ACTIONS(9704),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9704),
    [sym_preproc_open] = ACTIONS(9704),
    [sym_preproc_close] = ACTIONS(9704),
  },
  [STATE(4264)] = {
    [anon_sym_SEMI] = ACTIONS(9704),
    [aux_sym_where_condition_token1] = ACTIONS(9706),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9704),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9704),
    [anon_sym_LBRACK] = ACTIONS(9704),
    [aux_sym_basic_type_token6] = ACTIONS(9706),
    [aux_sym_basic_type_token22] = ACTIONS(9706),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9704),
    [aux_sym_addafter_modification_token1] = ACTIONS(9704),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9704),
    [aux_sym_modify_modification_token1] = ACTIONS(9704),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9704),
    [aux_sym_movelast_modification_token1] = ACTIONS(9704),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9704),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9704),
    [aux_sym_separator_action_token1] = ACTIONS(9704),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9704),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9704),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9704),
    [anon_sym_POUNDif] = ACTIONS(9704),
    [anon_sym_POUNDIF] = ACTIONS(9704),
    [anon_sym_POUNDIf] = ACTIONS(9704),
    [anon_sym_POUNDelif] = ACTIONS(9704),
    [anon_sym_POUNDELIF] = ACTIONS(9704),
    [anon_sym_POUNDElif] = ACTIONS(9704),
    [anon_sym_POUNDelse] = ACTIONS(9704),
    [anon_sym_POUNDELSE] = ACTIONS(9704),
    [anon_sym_POUNDElse] = ACTIONS(9704),
    [anon_sym_POUNDelse2] = ACTIONS(9704),
    [anon_sym_POUNDELSE2] = ACTIONS(9704),
    [anon_sym_POUNDElse2] = ACTIONS(9704),
    [anon_sym_POUNDendif] = ACTIONS(9704),
    [anon_sym_POUNDENDIF] = ACTIONS(9704),
    [anon_sym_POUNDEndif] = ACTIONS(9704),
    [anon_sym_POUNDendif2] = ACTIONS(9704),
    [anon_sym_POUNDENDIF2] = ACTIONS(9704),
    [anon_sym_POUNDEndif2] = ACTIONS(9704),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9704),
    [sym_trigger_keyword] = ACTIONS(9704),
    [sym_var_keyword] = ACTIONS(9704),
    [sym_local_keyword] = ACTIONS(9704),
    [sym_internal_keyword] = ACTIONS(9704),
    [sym_protected_keyword] = ACTIONS(9704),
    [sym_event_keyword] = ACTIONS(9704),
    [sym_fields_keyword] = ACTIONS(9704),
    [sym_keys_keyword] = ACTIONS(9704),
    [sym_fieldgroups_keyword] = ACTIONS(9704),
    [sym_actions_keyword] = ACTIONS(9704),
    [sym_layout_keyword] = ACTIONS(9704),
    [sym_area_keyword] = ACTIONS(9704),
    [sym_group_keyword] = ACTIONS(9704),
    [sym_repeater_keyword] = ACTIONS(9704),
    [sym_cuegroup_keyword] = ACTIONS(9704),
    [sym_fixed_keyword] = ACTIONS(9704),
    [sym_grid_keyword] = ACTIONS(9704),
    [sym_part_keyword] = ACTIONS(9704),
    [sym_systempart_keyword] = ACTIONS(9704),
    [sym_usercontrol_keyword] = ACTIONS(9704),
    [sym_dataset_keyword] = ACTIONS(9704),
    [sym_elements_keyword] = ACTIONS(9704),
    [sym_dataitem_keyword] = ACTIONS(9704),
    [sym_column_keyword] = ACTIONS(9704),
    [sym_filter_keyword] = ACTIONS(9704),
    [sym_labels_keyword] = ACTIONS(9704),
    [sym_rendering_keyword] = ACTIONS(9704),
    [sym_requestpage_keyword] = ACTIONS(9704),
    [sym_schema_keyword] = ACTIONS(9704),
    [sym_views_keyword] = ACTIONS(9704),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9704),
    [sym_preproc_open] = ACTIONS(9704),
    [sym_preproc_close] = ACTIONS(9704),
  },
  [STATE(4265)] = {
    [anon_sym_SEMI] = ACTIONS(9708),
    [aux_sym_where_condition_token1] = ACTIONS(9710),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9708),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9708),
    [anon_sym_LBRACK] = ACTIONS(9708),
    [aux_sym_basic_type_token6] = ACTIONS(9710),
    [aux_sym_basic_type_token22] = ACTIONS(9710),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9708),
    [aux_sym_addafter_modification_token1] = ACTIONS(9708),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9708),
    [aux_sym_modify_modification_token1] = ACTIONS(9708),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9708),
    [aux_sym_movelast_modification_token1] = ACTIONS(9708),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9708),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9708),
    [aux_sym_separator_action_token1] = ACTIONS(9708),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9708),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9708),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9708),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9708),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9708),
    [anon_sym_POUNDif] = ACTIONS(9708),
    [anon_sym_POUNDIF] = ACTIONS(9708),
    [anon_sym_POUNDIf] = ACTIONS(9708),
    [anon_sym_POUNDelif] = ACTIONS(9708),
    [anon_sym_POUNDELIF] = ACTIONS(9708),
    [anon_sym_POUNDElif] = ACTIONS(9708),
    [anon_sym_POUNDelse] = ACTIONS(9708),
    [anon_sym_POUNDELSE] = ACTIONS(9708),
    [anon_sym_POUNDElse] = ACTIONS(9708),
    [anon_sym_POUNDelse2] = ACTIONS(9708),
    [anon_sym_POUNDELSE2] = ACTIONS(9708),
    [anon_sym_POUNDElse2] = ACTIONS(9708),
    [anon_sym_POUNDendif] = ACTIONS(9708),
    [anon_sym_POUNDENDIF] = ACTIONS(9708),
    [anon_sym_POUNDEndif] = ACTIONS(9708),
    [anon_sym_POUNDendif2] = ACTIONS(9708),
    [anon_sym_POUNDENDIF2] = ACTIONS(9708),
    [anon_sym_POUNDEndif2] = ACTIONS(9708),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9708),
    [sym_trigger_keyword] = ACTIONS(9708),
    [sym_var_keyword] = ACTIONS(9708),
    [sym_local_keyword] = ACTIONS(9708),
    [sym_internal_keyword] = ACTIONS(9708),
    [sym_protected_keyword] = ACTIONS(9708),
    [sym_event_keyword] = ACTIONS(9708),
    [sym_fields_keyword] = ACTIONS(9708),
    [sym_keys_keyword] = ACTIONS(9708),
    [sym_fieldgroups_keyword] = ACTIONS(9708),
    [sym_actions_keyword] = ACTIONS(9708),
    [sym_layout_keyword] = ACTIONS(9708),
    [sym_area_keyword] = ACTIONS(9708),
    [sym_group_keyword] = ACTIONS(9708),
    [sym_repeater_keyword] = ACTIONS(9708),
    [sym_cuegroup_keyword] = ACTIONS(9708),
    [sym_fixed_keyword] = ACTIONS(9708),
    [sym_grid_keyword] = ACTIONS(9708),
    [sym_part_keyword] = ACTIONS(9708),
    [sym_systempart_keyword] = ACTIONS(9708),
    [sym_usercontrol_keyword] = ACTIONS(9708),
    [sym_dataset_keyword] = ACTIONS(9708),
    [sym_elements_keyword] = ACTIONS(9708),
    [sym_dataitem_keyword] = ACTIONS(9708),
    [sym_column_keyword] = ACTIONS(9708),
    [sym_filter_keyword] = ACTIONS(9708),
    [sym_labels_keyword] = ACTIONS(9708),
    [sym_rendering_keyword] = ACTIONS(9708),
    [sym_requestpage_keyword] = ACTIONS(9708),
    [sym_schema_keyword] = ACTIONS(9708),
    [sym_views_keyword] = ACTIONS(9708),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9708),
    [sym_preproc_open] = ACTIONS(9708),
    [sym_preproc_close] = ACTIONS(9708),
  },
  [STATE(4266)] = {
    [anon_sym_SEMI] = ACTIONS(6138),
    [aux_sym_where_condition_token1] = ACTIONS(6136),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6138),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6138),
    [anon_sym_LBRACK] = ACTIONS(6138),
    [aux_sym_basic_type_token6] = ACTIONS(6136),
    [aux_sym_basic_type_token22] = ACTIONS(6136),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6138),
    [aux_sym_addafter_modification_token1] = ACTIONS(6138),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6138),
    [aux_sym_modify_modification_token1] = ACTIONS(6138),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6138),
    [aux_sym_movelast_modification_token1] = ACTIONS(6138),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6138),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6138),
    [aux_sym_separator_action_token1] = ACTIONS(6138),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6138),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6138),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6138),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6138),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6138),
    [anon_sym_POUNDif] = ACTIONS(6138),
    [anon_sym_POUNDIF] = ACTIONS(6138),
    [anon_sym_POUNDIf] = ACTIONS(6138),
    [anon_sym_POUNDelif] = ACTIONS(6138),
    [anon_sym_POUNDELIF] = ACTIONS(6138),
    [anon_sym_POUNDElif] = ACTIONS(6138),
    [anon_sym_POUNDelse] = ACTIONS(6138),
    [anon_sym_POUNDELSE] = ACTIONS(6138),
    [anon_sym_POUNDElse] = ACTIONS(6138),
    [anon_sym_POUNDelse2] = ACTIONS(6138),
    [anon_sym_POUNDELSE2] = ACTIONS(6138),
    [anon_sym_POUNDElse2] = ACTIONS(6138),
    [anon_sym_POUNDendif] = ACTIONS(6138),
    [anon_sym_POUNDENDIF] = ACTIONS(6138),
    [anon_sym_POUNDEndif] = ACTIONS(6138),
    [anon_sym_POUNDendif2] = ACTIONS(6138),
    [anon_sym_POUNDENDIF2] = ACTIONS(6138),
    [anon_sym_POUNDEndif2] = ACTIONS(6138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6138),
    [sym_trigger_keyword] = ACTIONS(6138),
    [sym_var_keyword] = ACTIONS(6138),
    [sym_local_keyword] = ACTIONS(6138),
    [sym_internal_keyword] = ACTIONS(6138),
    [sym_protected_keyword] = ACTIONS(6138),
    [sym_event_keyword] = ACTIONS(6138),
    [sym_fields_keyword] = ACTIONS(6138),
    [sym_keys_keyword] = ACTIONS(6138),
    [sym_fieldgroups_keyword] = ACTIONS(6138),
    [sym_actions_keyword] = ACTIONS(6138),
    [sym_layout_keyword] = ACTIONS(6138),
    [sym_area_keyword] = ACTIONS(6138),
    [sym_group_keyword] = ACTIONS(6138),
    [sym_repeater_keyword] = ACTIONS(6138),
    [sym_cuegroup_keyword] = ACTIONS(6138),
    [sym_fixed_keyword] = ACTIONS(6138),
    [sym_grid_keyword] = ACTIONS(6138),
    [sym_part_keyword] = ACTIONS(6138),
    [sym_systempart_keyword] = ACTIONS(6138),
    [sym_usercontrol_keyword] = ACTIONS(6138),
    [sym_dataset_keyword] = ACTIONS(6138),
    [sym_elements_keyword] = ACTIONS(6138),
    [sym_dataitem_keyword] = ACTIONS(6138),
    [sym_column_keyword] = ACTIONS(6138),
    [sym_filter_keyword] = ACTIONS(6138),
    [sym_labels_keyword] = ACTIONS(6138),
    [sym_rendering_keyword] = ACTIONS(6138),
    [sym_requestpage_keyword] = ACTIONS(6138),
    [sym_schema_keyword] = ACTIONS(6138),
    [sym_views_keyword] = ACTIONS(6138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6138),
    [sym_preproc_open] = ACTIONS(6138),
    [sym_preproc_close] = ACTIONS(6138),
  },
  [STATE(4267)] = {
    [anon_sym_SEMI] = ACTIONS(9708),
    [aux_sym_where_condition_token1] = ACTIONS(9710),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9708),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9708),
    [anon_sym_LBRACK] = ACTIONS(9708),
    [aux_sym_basic_type_token6] = ACTIONS(9710),
    [aux_sym_basic_type_token22] = ACTIONS(9710),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9708),
    [aux_sym_addafter_modification_token1] = ACTIONS(9708),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9708),
    [aux_sym_modify_modification_token1] = ACTIONS(9708),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9708),
    [aux_sym_movelast_modification_token1] = ACTIONS(9708),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9708),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9708),
    [aux_sym_separator_action_token1] = ACTIONS(9708),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9708),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9708),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9708),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9708),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9708),
    [anon_sym_POUNDif] = ACTIONS(9708),
    [anon_sym_POUNDIF] = ACTIONS(9708),
    [anon_sym_POUNDIf] = ACTIONS(9708),
    [anon_sym_POUNDelif] = ACTIONS(9708),
    [anon_sym_POUNDELIF] = ACTIONS(9708),
    [anon_sym_POUNDElif] = ACTIONS(9708),
    [anon_sym_POUNDelse] = ACTIONS(9708),
    [anon_sym_POUNDELSE] = ACTIONS(9708),
    [anon_sym_POUNDElse] = ACTIONS(9708),
    [anon_sym_POUNDelse2] = ACTIONS(9708),
    [anon_sym_POUNDELSE2] = ACTIONS(9708),
    [anon_sym_POUNDElse2] = ACTIONS(9708),
    [anon_sym_POUNDendif] = ACTIONS(9708),
    [anon_sym_POUNDENDIF] = ACTIONS(9708),
    [anon_sym_POUNDEndif] = ACTIONS(9708),
    [anon_sym_POUNDendif2] = ACTIONS(9708),
    [anon_sym_POUNDENDIF2] = ACTIONS(9708),
    [anon_sym_POUNDEndif2] = ACTIONS(9708),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9708),
    [sym_trigger_keyword] = ACTIONS(9708),
    [sym_var_keyword] = ACTIONS(9708),
    [sym_local_keyword] = ACTIONS(9708),
    [sym_internal_keyword] = ACTIONS(9708),
    [sym_protected_keyword] = ACTIONS(9708),
    [sym_event_keyword] = ACTIONS(9708),
    [sym_fields_keyword] = ACTIONS(9708),
    [sym_keys_keyword] = ACTIONS(9708),
    [sym_fieldgroups_keyword] = ACTIONS(9708),
    [sym_actions_keyword] = ACTIONS(9708),
    [sym_layout_keyword] = ACTIONS(9708),
    [sym_area_keyword] = ACTIONS(9708),
    [sym_group_keyword] = ACTIONS(9708),
    [sym_repeater_keyword] = ACTIONS(9708),
    [sym_cuegroup_keyword] = ACTIONS(9708),
    [sym_fixed_keyword] = ACTIONS(9708),
    [sym_grid_keyword] = ACTIONS(9708),
    [sym_part_keyword] = ACTIONS(9708),
    [sym_systempart_keyword] = ACTIONS(9708),
    [sym_usercontrol_keyword] = ACTIONS(9708),
    [sym_dataset_keyword] = ACTIONS(9708),
    [sym_elements_keyword] = ACTIONS(9708),
    [sym_dataitem_keyword] = ACTIONS(9708),
    [sym_column_keyword] = ACTIONS(9708),
    [sym_filter_keyword] = ACTIONS(9708),
    [sym_labels_keyword] = ACTIONS(9708),
    [sym_rendering_keyword] = ACTIONS(9708),
    [sym_requestpage_keyword] = ACTIONS(9708),
    [sym_schema_keyword] = ACTIONS(9708),
    [sym_views_keyword] = ACTIONS(9708),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9708),
    [sym_preproc_open] = ACTIONS(9708),
    [sym_preproc_close] = ACTIONS(9708),
  },
  [STATE(4268)] = {
    [anon_sym_SEMI] = ACTIONS(6142),
    [aux_sym_where_condition_token1] = ACTIONS(6140),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6142),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6142),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [aux_sym_basic_type_token6] = ACTIONS(6140),
    [aux_sym_basic_type_token22] = ACTIONS(6140),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6142),
    [aux_sym_addafter_modification_token1] = ACTIONS(6142),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6142),
    [aux_sym_modify_modification_token1] = ACTIONS(6142),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6142),
    [aux_sym_movelast_modification_token1] = ACTIONS(6142),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6142),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6142),
    [aux_sym_separator_action_token1] = ACTIONS(6142),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6142),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6142),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6142),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6142),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6142),
    [anon_sym_POUNDif] = ACTIONS(6142),
    [anon_sym_POUNDIF] = ACTIONS(6142),
    [anon_sym_POUNDIf] = ACTIONS(6142),
    [anon_sym_POUNDelif] = ACTIONS(6142),
    [anon_sym_POUNDELIF] = ACTIONS(6142),
    [anon_sym_POUNDElif] = ACTIONS(6142),
    [anon_sym_POUNDelse] = ACTIONS(6142),
    [anon_sym_POUNDELSE] = ACTIONS(6142),
    [anon_sym_POUNDElse] = ACTIONS(6142),
    [anon_sym_POUNDelse2] = ACTIONS(6142),
    [anon_sym_POUNDELSE2] = ACTIONS(6142),
    [anon_sym_POUNDElse2] = ACTIONS(6142),
    [anon_sym_POUNDendif] = ACTIONS(6142),
    [anon_sym_POUNDENDIF] = ACTIONS(6142),
    [anon_sym_POUNDEndif] = ACTIONS(6142),
    [anon_sym_POUNDendif2] = ACTIONS(6142),
    [anon_sym_POUNDENDIF2] = ACTIONS(6142),
    [anon_sym_POUNDEndif2] = ACTIONS(6142),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6142),
    [sym_trigger_keyword] = ACTIONS(6142),
    [sym_var_keyword] = ACTIONS(6142),
    [sym_local_keyword] = ACTIONS(6142),
    [sym_internal_keyword] = ACTIONS(6142),
    [sym_protected_keyword] = ACTIONS(6142),
    [sym_event_keyword] = ACTIONS(6142),
    [sym_fields_keyword] = ACTIONS(6142),
    [sym_keys_keyword] = ACTIONS(6142),
    [sym_fieldgroups_keyword] = ACTIONS(6142),
    [sym_actions_keyword] = ACTIONS(6142),
    [sym_layout_keyword] = ACTIONS(6142),
    [sym_area_keyword] = ACTIONS(6142),
    [sym_group_keyword] = ACTIONS(6142),
    [sym_repeater_keyword] = ACTIONS(6142),
    [sym_cuegroup_keyword] = ACTIONS(6142),
    [sym_fixed_keyword] = ACTIONS(6142),
    [sym_grid_keyword] = ACTIONS(6142),
    [sym_part_keyword] = ACTIONS(6142),
    [sym_systempart_keyword] = ACTIONS(6142),
    [sym_usercontrol_keyword] = ACTIONS(6142),
    [sym_dataset_keyword] = ACTIONS(6142),
    [sym_elements_keyword] = ACTIONS(6142),
    [sym_dataitem_keyword] = ACTIONS(6142),
    [sym_column_keyword] = ACTIONS(6142),
    [sym_filter_keyword] = ACTIONS(6142),
    [sym_labels_keyword] = ACTIONS(6142),
    [sym_rendering_keyword] = ACTIONS(6142),
    [sym_requestpage_keyword] = ACTIONS(6142),
    [sym_schema_keyword] = ACTIONS(6142),
    [sym_views_keyword] = ACTIONS(6142),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6142),
    [sym_preproc_open] = ACTIONS(6142),
    [sym_preproc_close] = ACTIONS(6142),
  },
  [STATE(4269)] = {
    [anon_sym_SEMI] = ACTIONS(6146),
    [aux_sym_where_condition_token1] = ACTIONS(6144),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6146),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6146),
    [anon_sym_LBRACK] = ACTIONS(6146),
    [aux_sym_basic_type_token6] = ACTIONS(6144),
    [aux_sym_basic_type_token22] = ACTIONS(6144),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6146),
    [aux_sym_addafter_modification_token1] = ACTIONS(6146),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6146),
    [aux_sym_modify_modification_token1] = ACTIONS(6146),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6146),
    [aux_sym_movelast_modification_token1] = ACTIONS(6146),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6146),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6146),
    [aux_sym_separator_action_token1] = ACTIONS(6146),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6146),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6146),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6146),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6146),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6146),
    [anon_sym_POUNDif] = ACTIONS(6146),
    [anon_sym_POUNDIF] = ACTIONS(6146),
    [anon_sym_POUNDIf] = ACTIONS(6146),
    [anon_sym_POUNDelif] = ACTIONS(6146),
    [anon_sym_POUNDELIF] = ACTIONS(6146),
    [anon_sym_POUNDElif] = ACTIONS(6146),
    [anon_sym_POUNDelse] = ACTIONS(6146),
    [anon_sym_POUNDELSE] = ACTIONS(6146),
    [anon_sym_POUNDElse] = ACTIONS(6146),
    [anon_sym_POUNDelse2] = ACTIONS(6146),
    [anon_sym_POUNDELSE2] = ACTIONS(6146),
    [anon_sym_POUNDElse2] = ACTIONS(6146),
    [anon_sym_POUNDendif] = ACTIONS(6146),
    [anon_sym_POUNDENDIF] = ACTIONS(6146),
    [anon_sym_POUNDEndif] = ACTIONS(6146),
    [anon_sym_POUNDendif2] = ACTIONS(6146),
    [anon_sym_POUNDENDIF2] = ACTIONS(6146),
    [anon_sym_POUNDEndif2] = ACTIONS(6146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6146),
    [sym_trigger_keyword] = ACTIONS(6146),
    [sym_var_keyword] = ACTIONS(6146),
    [sym_local_keyword] = ACTIONS(6146),
    [sym_internal_keyword] = ACTIONS(6146),
    [sym_protected_keyword] = ACTIONS(6146),
    [sym_event_keyword] = ACTIONS(6146),
    [sym_fields_keyword] = ACTIONS(6146),
    [sym_keys_keyword] = ACTIONS(6146),
    [sym_fieldgroups_keyword] = ACTIONS(6146),
    [sym_actions_keyword] = ACTIONS(6146),
    [sym_layout_keyword] = ACTIONS(6146),
    [sym_area_keyword] = ACTIONS(6146),
    [sym_group_keyword] = ACTIONS(6146),
    [sym_repeater_keyword] = ACTIONS(6146),
    [sym_cuegroup_keyword] = ACTIONS(6146),
    [sym_fixed_keyword] = ACTIONS(6146),
    [sym_grid_keyword] = ACTIONS(6146),
    [sym_part_keyword] = ACTIONS(6146),
    [sym_systempart_keyword] = ACTIONS(6146),
    [sym_usercontrol_keyword] = ACTIONS(6146),
    [sym_dataset_keyword] = ACTIONS(6146),
    [sym_elements_keyword] = ACTIONS(6146),
    [sym_dataitem_keyword] = ACTIONS(6146),
    [sym_column_keyword] = ACTIONS(6146),
    [sym_filter_keyword] = ACTIONS(6146),
    [sym_labels_keyword] = ACTIONS(6146),
    [sym_rendering_keyword] = ACTIONS(6146),
    [sym_requestpage_keyword] = ACTIONS(6146),
    [sym_schema_keyword] = ACTIONS(6146),
    [sym_views_keyword] = ACTIONS(6146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6146),
    [sym_preproc_open] = ACTIONS(6146),
    [sym_preproc_close] = ACTIONS(6146),
  },
  [STATE(4270)] = {
    [anon_sym_SEMI] = ACTIONS(6150),
    [aux_sym_where_condition_token1] = ACTIONS(6148),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6150),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6150),
    [anon_sym_LBRACK] = ACTIONS(6150),
    [aux_sym_basic_type_token6] = ACTIONS(6148),
    [aux_sym_basic_type_token22] = ACTIONS(6148),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6150),
    [aux_sym_addafter_modification_token1] = ACTIONS(6150),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6150),
    [aux_sym_modify_modification_token1] = ACTIONS(6150),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6150),
    [aux_sym_movelast_modification_token1] = ACTIONS(6150),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6150),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6150),
    [aux_sym_separator_action_token1] = ACTIONS(6150),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6150),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6150),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6150),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6150),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6150),
    [anon_sym_POUNDif] = ACTIONS(6150),
    [anon_sym_POUNDIF] = ACTIONS(6150),
    [anon_sym_POUNDIf] = ACTIONS(6150),
    [anon_sym_POUNDelif] = ACTIONS(6150),
    [anon_sym_POUNDELIF] = ACTIONS(6150),
    [anon_sym_POUNDElif] = ACTIONS(6150),
    [anon_sym_POUNDelse] = ACTIONS(6150),
    [anon_sym_POUNDELSE] = ACTIONS(6150),
    [anon_sym_POUNDElse] = ACTIONS(6150),
    [anon_sym_POUNDelse2] = ACTIONS(6150),
    [anon_sym_POUNDELSE2] = ACTIONS(6150),
    [anon_sym_POUNDElse2] = ACTIONS(6150),
    [anon_sym_POUNDendif] = ACTIONS(6150),
    [anon_sym_POUNDENDIF] = ACTIONS(6150),
    [anon_sym_POUNDEndif] = ACTIONS(6150),
    [anon_sym_POUNDendif2] = ACTIONS(6150),
    [anon_sym_POUNDENDIF2] = ACTIONS(6150),
    [anon_sym_POUNDEndif2] = ACTIONS(6150),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6150),
    [sym_trigger_keyword] = ACTIONS(6150),
    [sym_var_keyword] = ACTIONS(6150),
    [sym_local_keyword] = ACTIONS(6150),
    [sym_internal_keyword] = ACTIONS(6150),
    [sym_protected_keyword] = ACTIONS(6150),
    [sym_event_keyword] = ACTIONS(6150),
    [sym_fields_keyword] = ACTIONS(6150),
    [sym_keys_keyword] = ACTIONS(6150),
    [sym_fieldgroups_keyword] = ACTIONS(6150),
    [sym_actions_keyword] = ACTIONS(6150),
    [sym_layout_keyword] = ACTIONS(6150),
    [sym_area_keyword] = ACTIONS(6150),
    [sym_group_keyword] = ACTIONS(6150),
    [sym_repeater_keyword] = ACTIONS(6150),
    [sym_cuegroup_keyword] = ACTIONS(6150),
    [sym_fixed_keyword] = ACTIONS(6150),
    [sym_grid_keyword] = ACTIONS(6150),
    [sym_part_keyword] = ACTIONS(6150),
    [sym_systempart_keyword] = ACTIONS(6150),
    [sym_usercontrol_keyword] = ACTIONS(6150),
    [sym_dataset_keyword] = ACTIONS(6150),
    [sym_elements_keyword] = ACTIONS(6150),
    [sym_dataitem_keyword] = ACTIONS(6150),
    [sym_column_keyword] = ACTIONS(6150),
    [sym_filter_keyword] = ACTIONS(6150),
    [sym_labels_keyword] = ACTIONS(6150),
    [sym_rendering_keyword] = ACTIONS(6150),
    [sym_requestpage_keyword] = ACTIONS(6150),
    [sym_schema_keyword] = ACTIONS(6150),
    [sym_views_keyword] = ACTIONS(6150),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6150),
    [sym_preproc_open] = ACTIONS(6150),
    [sym_preproc_close] = ACTIONS(6150),
  },
  [STATE(4271)] = {
    [anon_sym_SEMI] = ACTIONS(9275),
    [aux_sym_where_condition_token1] = ACTIONS(9277),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9275),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9275),
    [anon_sym_LBRACK] = ACTIONS(9275),
    [aux_sym_basic_type_token6] = ACTIONS(9277),
    [aux_sym_basic_type_token22] = ACTIONS(9277),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9275),
    [aux_sym_addafter_modification_token1] = ACTIONS(9275),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9275),
    [aux_sym_modify_modification_token1] = ACTIONS(9275),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9275),
    [aux_sym_movelast_modification_token1] = ACTIONS(9275),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9275),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9275),
    [aux_sym_separator_action_token1] = ACTIONS(9275),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9275),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9275),
    [anon_sym_POUNDif] = ACTIONS(9275),
    [anon_sym_POUNDIF] = ACTIONS(9275),
    [anon_sym_POUNDIf] = ACTIONS(9275),
    [anon_sym_POUNDelif] = ACTIONS(9275),
    [anon_sym_POUNDELIF] = ACTIONS(9275),
    [anon_sym_POUNDElif] = ACTIONS(9275),
    [anon_sym_POUNDelse] = ACTIONS(9275),
    [anon_sym_POUNDELSE] = ACTIONS(9275),
    [anon_sym_POUNDElse] = ACTIONS(9275),
    [anon_sym_POUNDelse2] = ACTIONS(9275),
    [anon_sym_POUNDELSE2] = ACTIONS(9275),
    [anon_sym_POUNDElse2] = ACTIONS(9275),
    [anon_sym_POUNDendif] = ACTIONS(9275),
    [anon_sym_POUNDENDIF] = ACTIONS(9275),
    [anon_sym_POUNDEndif] = ACTIONS(9275),
    [anon_sym_POUNDendif2] = ACTIONS(9275),
    [anon_sym_POUNDENDIF2] = ACTIONS(9275),
    [anon_sym_POUNDEndif2] = ACTIONS(9275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9275),
    [sym_trigger_keyword] = ACTIONS(9275),
    [sym_var_keyword] = ACTIONS(9275),
    [sym_local_keyword] = ACTIONS(9275),
    [sym_internal_keyword] = ACTIONS(9275),
    [sym_protected_keyword] = ACTIONS(9275),
    [sym_event_keyword] = ACTIONS(9275),
    [sym_fields_keyword] = ACTIONS(9275),
    [sym_keys_keyword] = ACTIONS(9275),
    [sym_fieldgroups_keyword] = ACTIONS(9275),
    [sym_actions_keyword] = ACTIONS(9275),
    [sym_layout_keyword] = ACTIONS(9275),
    [sym_area_keyword] = ACTIONS(9275),
    [sym_group_keyword] = ACTIONS(9275),
    [sym_repeater_keyword] = ACTIONS(9275),
    [sym_cuegroup_keyword] = ACTIONS(9275),
    [sym_fixed_keyword] = ACTIONS(9275),
    [sym_grid_keyword] = ACTIONS(9275),
    [sym_part_keyword] = ACTIONS(9275),
    [sym_systempart_keyword] = ACTIONS(9275),
    [sym_usercontrol_keyword] = ACTIONS(9275),
    [sym_dataset_keyword] = ACTIONS(9275),
    [sym_elements_keyword] = ACTIONS(9275),
    [sym_dataitem_keyword] = ACTIONS(9275),
    [sym_column_keyword] = ACTIONS(9275),
    [sym_filter_keyword] = ACTIONS(9275),
    [sym_labels_keyword] = ACTIONS(9275),
    [sym_rendering_keyword] = ACTIONS(9275),
    [sym_requestpage_keyword] = ACTIONS(9275),
    [sym_schema_keyword] = ACTIONS(9275),
    [sym_views_keyword] = ACTIONS(9275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9275),
    [sym_preproc_open] = ACTIONS(9275),
    [sym_preproc_close] = ACTIONS(9275),
  },
  [STATE(4272)] = {
    [anon_sym_SEMI] = ACTIONS(9712),
    [aux_sym_where_condition_token1] = ACTIONS(9714),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9712),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9712),
    [anon_sym_LBRACK] = ACTIONS(9712),
    [aux_sym_basic_type_token6] = ACTIONS(9714),
    [aux_sym_basic_type_token22] = ACTIONS(9714),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9712),
    [aux_sym_addafter_modification_token1] = ACTIONS(9712),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9712),
    [aux_sym_modify_modification_token1] = ACTIONS(9712),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9712),
    [aux_sym_movelast_modification_token1] = ACTIONS(9712),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9712),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9712),
    [aux_sym_separator_action_token1] = ACTIONS(9712),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9712),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9712),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9712),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9712),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9712),
    [anon_sym_POUNDif] = ACTIONS(9712),
    [anon_sym_POUNDIF] = ACTIONS(9712),
    [anon_sym_POUNDIf] = ACTIONS(9712),
    [anon_sym_POUNDelif] = ACTIONS(9712),
    [anon_sym_POUNDELIF] = ACTIONS(9712),
    [anon_sym_POUNDElif] = ACTIONS(9712),
    [anon_sym_POUNDelse] = ACTIONS(9712),
    [anon_sym_POUNDELSE] = ACTIONS(9712),
    [anon_sym_POUNDElse] = ACTIONS(9712),
    [anon_sym_POUNDelse2] = ACTIONS(9712),
    [anon_sym_POUNDELSE2] = ACTIONS(9712),
    [anon_sym_POUNDElse2] = ACTIONS(9712),
    [anon_sym_POUNDendif] = ACTIONS(9712),
    [anon_sym_POUNDENDIF] = ACTIONS(9712),
    [anon_sym_POUNDEndif] = ACTIONS(9712),
    [anon_sym_POUNDendif2] = ACTIONS(9712),
    [anon_sym_POUNDENDIF2] = ACTIONS(9712),
    [anon_sym_POUNDEndif2] = ACTIONS(9712),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9712),
    [sym_trigger_keyword] = ACTIONS(9712),
    [sym_var_keyword] = ACTIONS(9712),
    [sym_local_keyword] = ACTIONS(9712),
    [sym_internal_keyword] = ACTIONS(9712),
    [sym_protected_keyword] = ACTIONS(9712),
    [sym_event_keyword] = ACTIONS(9712),
    [sym_fields_keyword] = ACTIONS(9712),
    [sym_keys_keyword] = ACTIONS(9712),
    [sym_fieldgroups_keyword] = ACTIONS(9712),
    [sym_actions_keyword] = ACTIONS(9712),
    [sym_layout_keyword] = ACTIONS(9712),
    [sym_area_keyword] = ACTIONS(9712),
    [sym_group_keyword] = ACTIONS(9712),
    [sym_repeater_keyword] = ACTIONS(9712),
    [sym_cuegroup_keyword] = ACTIONS(9712),
    [sym_fixed_keyword] = ACTIONS(9712),
    [sym_grid_keyword] = ACTIONS(9712),
    [sym_part_keyword] = ACTIONS(9712),
    [sym_systempart_keyword] = ACTIONS(9712),
    [sym_usercontrol_keyword] = ACTIONS(9712),
    [sym_dataset_keyword] = ACTIONS(9712),
    [sym_elements_keyword] = ACTIONS(9712),
    [sym_dataitem_keyword] = ACTIONS(9712),
    [sym_column_keyword] = ACTIONS(9712),
    [sym_filter_keyword] = ACTIONS(9712),
    [sym_labels_keyword] = ACTIONS(9712),
    [sym_rendering_keyword] = ACTIONS(9712),
    [sym_requestpage_keyword] = ACTIONS(9712),
    [sym_schema_keyword] = ACTIONS(9712),
    [sym_views_keyword] = ACTIONS(9712),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9712),
    [sym_preproc_open] = ACTIONS(9712),
    [sym_preproc_close] = ACTIONS(9712),
  },
  [STATE(4273)] = {
    [anon_sym_SEMI] = ACTIONS(9712),
    [aux_sym_where_condition_token1] = ACTIONS(9714),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9712),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9712),
    [anon_sym_LBRACK] = ACTIONS(9712),
    [aux_sym_basic_type_token6] = ACTIONS(9714),
    [aux_sym_basic_type_token22] = ACTIONS(9714),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9712),
    [aux_sym_addafter_modification_token1] = ACTIONS(9712),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9712),
    [aux_sym_modify_modification_token1] = ACTIONS(9712),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9712),
    [aux_sym_movelast_modification_token1] = ACTIONS(9712),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9712),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9712),
    [aux_sym_separator_action_token1] = ACTIONS(9712),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9712),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9712),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9712),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9712),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9712),
    [anon_sym_POUNDif] = ACTIONS(9712),
    [anon_sym_POUNDIF] = ACTIONS(9712),
    [anon_sym_POUNDIf] = ACTIONS(9712),
    [anon_sym_POUNDelif] = ACTIONS(9712),
    [anon_sym_POUNDELIF] = ACTIONS(9712),
    [anon_sym_POUNDElif] = ACTIONS(9712),
    [anon_sym_POUNDelse] = ACTIONS(9712),
    [anon_sym_POUNDELSE] = ACTIONS(9712),
    [anon_sym_POUNDElse] = ACTIONS(9712),
    [anon_sym_POUNDelse2] = ACTIONS(9712),
    [anon_sym_POUNDELSE2] = ACTIONS(9712),
    [anon_sym_POUNDElse2] = ACTIONS(9712),
    [anon_sym_POUNDendif] = ACTIONS(9712),
    [anon_sym_POUNDENDIF] = ACTIONS(9712),
    [anon_sym_POUNDEndif] = ACTIONS(9712),
    [anon_sym_POUNDendif2] = ACTIONS(9712),
    [anon_sym_POUNDENDIF2] = ACTIONS(9712),
    [anon_sym_POUNDEndif2] = ACTIONS(9712),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9712),
    [sym_trigger_keyword] = ACTIONS(9712),
    [sym_var_keyword] = ACTIONS(9712),
    [sym_local_keyword] = ACTIONS(9712),
    [sym_internal_keyword] = ACTIONS(9712),
    [sym_protected_keyword] = ACTIONS(9712),
    [sym_event_keyword] = ACTIONS(9712),
    [sym_fields_keyword] = ACTIONS(9712),
    [sym_keys_keyword] = ACTIONS(9712),
    [sym_fieldgroups_keyword] = ACTIONS(9712),
    [sym_actions_keyword] = ACTIONS(9712),
    [sym_layout_keyword] = ACTIONS(9712),
    [sym_area_keyword] = ACTIONS(9712),
    [sym_group_keyword] = ACTIONS(9712),
    [sym_repeater_keyword] = ACTIONS(9712),
    [sym_cuegroup_keyword] = ACTIONS(9712),
    [sym_fixed_keyword] = ACTIONS(9712),
    [sym_grid_keyword] = ACTIONS(9712),
    [sym_part_keyword] = ACTIONS(9712),
    [sym_systempart_keyword] = ACTIONS(9712),
    [sym_usercontrol_keyword] = ACTIONS(9712),
    [sym_dataset_keyword] = ACTIONS(9712),
    [sym_elements_keyword] = ACTIONS(9712),
    [sym_dataitem_keyword] = ACTIONS(9712),
    [sym_column_keyword] = ACTIONS(9712),
    [sym_filter_keyword] = ACTIONS(9712),
    [sym_labels_keyword] = ACTIONS(9712),
    [sym_rendering_keyword] = ACTIONS(9712),
    [sym_requestpage_keyword] = ACTIONS(9712),
    [sym_schema_keyword] = ACTIONS(9712),
    [sym_views_keyword] = ACTIONS(9712),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9712),
    [sym_preproc_open] = ACTIONS(9712),
    [sym_preproc_close] = ACTIONS(9712),
  },
  [STATE(4274)] = {
    [anon_sym_SEMI] = ACTIONS(9716),
    [aux_sym_where_condition_token1] = ACTIONS(9718),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9716),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9716),
    [anon_sym_LBRACK] = ACTIONS(9716),
    [aux_sym_basic_type_token6] = ACTIONS(9718),
    [aux_sym_basic_type_token22] = ACTIONS(9718),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9716),
    [aux_sym_addafter_modification_token1] = ACTIONS(9716),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9716),
    [aux_sym_modify_modification_token1] = ACTIONS(9716),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9716),
    [aux_sym_movelast_modification_token1] = ACTIONS(9716),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9716),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9716),
    [aux_sym_separator_action_token1] = ACTIONS(9716),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9716),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9716),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9716),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9716),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9716),
    [anon_sym_POUNDif] = ACTIONS(9716),
    [anon_sym_POUNDIF] = ACTIONS(9716),
    [anon_sym_POUNDIf] = ACTIONS(9716),
    [anon_sym_POUNDelif] = ACTIONS(9716),
    [anon_sym_POUNDELIF] = ACTIONS(9716),
    [anon_sym_POUNDElif] = ACTIONS(9716),
    [anon_sym_POUNDelse] = ACTIONS(9716),
    [anon_sym_POUNDELSE] = ACTIONS(9716),
    [anon_sym_POUNDElse] = ACTIONS(9716),
    [anon_sym_POUNDelse2] = ACTIONS(9716),
    [anon_sym_POUNDELSE2] = ACTIONS(9716),
    [anon_sym_POUNDElse2] = ACTIONS(9716),
    [anon_sym_POUNDendif] = ACTIONS(9716),
    [anon_sym_POUNDENDIF] = ACTIONS(9716),
    [anon_sym_POUNDEndif] = ACTIONS(9716),
    [anon_sym_POUNDendif2] = ACTIONS(9716),
    [anon_sym_POUNDENDIF2] = ACTIONS(9716),
    [anon_sym_POUNDEndif2] = ACTIONS(9716),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9716),
    [sym_trigger_keyword] = ACTIONS(9716),
    [sym_var_keyword] = ACTIONS(9716),
    [sym_local_keyword] = ACTIONS(9716),
    [sym_internal_keyword] = ACTIONS(9716),
    [sym_protected_keyword] = ACTIONS(9716),
    [sym_event_keyword] = ACTIONS(9716),
    [sym_fields_keyword] = ACTIONS(9716),
    [sym_keys_keyword] = ACTIONS(9716),
    [sym_fieldgroups_keyword] = ACTIONS(9716),
    [sym_actions_keyword] = ACTIONS(9716),
    [sym_layout_keyword] = ACTIONS(9716),
    [sym_area_keyword] = ACTIONS(9716),
    [sym_group_keyword] = ACTIONS(9716),
    [sym_repeater_keyword] = ACTIONS(9716),
    [sym_cuegroup_keyword] = ACTIONS(9716),
    [sym_fixed_keyword] = ACTIONS(9716),
    [sym_grid_keyword] = ACTIONS(9716),
    [sym_part_keyword] = ACTIONS(9716),
    [sym_systempart_keyword] = ACTIONS(9716),
    [sym_usercontrol_keyword] = ACTIONS(9716),
    [sym_dataset_keyword] = ACTIONS(9716),
    [sym_elements_keyword] = ACTIONS(9716),
    [sym_dataitem_keyword] = ACTIONS(9716),
    [sym_column_keyword] = ACTIONS(9716),
    [sym_filter_keyword] = ACTIONS(9716),
    [sym_labels_keyword] = ACTIONS(9716),
    [sym_rendering_keyword] = ACTIONS(9716),
    [sym_requestpage_keyword] = ACTIONS(9716),
    [sym_schema_keyword] = ACTIONS(9716),
    [sym_views_keyword] = ACTIONS(9716),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9716),
    [sym_preproc_open] = ACTIONS(9716),
    [sym_preproc_close] = ACTIONS(9716),
  },
  [STATE(4275)] = {
    [anon_sym_SEMI] = ACTIONS(9720),
    [aux_sym_where_condition_token1] = ACTIONS(9722),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9720),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9720),
    [anon_sym_LBRACK] = ACTIONS(9720),
    [aux_sym_basic_type_token6] = ACTIONS(9722),
    [aux_sym_basic_type_token22] = ACTIONS(9722),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9720),
    [aux_sym_addafter_modification_token1] = ACTIONS(9720),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9720),
    [aux_sym_modify_modification_token1] = ACTIONS(9720),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9720),
    [aux_sym_movelast_modification_token1] = ACTIONS(9720),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9720),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9720),
    [aux_sym_separator_action_token1] = ACTIONS(9720),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9720),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9720),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9720),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9720),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9720),
    [anon_sym_POUNDif] = ACTIONS(9720),
    [anon_sym_POUNDIF] = ACTIONS(9720),
    [anon_sym_POUNDIf] = ACTIONS(9720),
    [anon_sym_POUNDelif] = ACTIONS(9720),
    [anon_sym_POUNDELIF] = ACTIONS(9720),
    [anon_sym_POUNDElif] = ACTIONS(9720),
    [anon_sym_POUNDelse] = ACTIONS(9720),
    [anon_sym_POUNDELSE] = ACTIONS(9720),
    [anon_sym_POUNDElse] = ACTIONS(9720),
    [anon_sym_POUNDelse2] = ACTIONS(9720),
    [anon_sym_POUNDELSE2] = ACTIONS(9720),
    [anon_sym_POUNDElse2] = ACTIONS(9720),
    [anon_sym_POUNDendif] = ACTIONS(9720),
    [anon_sym_POUNDENDIF] = ACTIONS(9720),
    [anon_sym_POUNDEndif] = ACTIONS(9720),
    [anon_sym_POUNDendif2] = ACTIONS(9720),
    [anon_sym_POUNDENDIF2] = ACTIONS(9720),
    [anon_sym_POUNDEndif2] = ACTIONS(9720),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9720),
    [sym_trigger_keyword] = ACTIONS(9720),
    [sym_var_keyword] = ACTIONS(9720),
    [sym_local_keyword] = ACTIONS(9720),
    [sym_internal_keyword] = ACTIONS(9720),
    [sym_protected_keyword] = ACTIONS(9720),
    [sym_event_keyword] = ACTIONS(9720),
    [sym_fields_keyword] = ACTIONS(9720),
    [sym_keys_keyword] = ACTIONS(9720),
    [sym_fieldgroups_keyword] = ACTIONS(9720),
    [sym_actions_keyword] = ACTIONS(9720),
    [sym_layout_keyword] = ACTIONS(9720),
    [sym_area_keyword] = ACTIONS(9720),
    [sym_group_keyword] = ACTIONS(9720),
    [sym_repeater_keyword] = ACTIONS(9720),
    [sym_cuegroup_keyword] = ACTIONS(9720),
    [sym_fixed_keyword] = ACTIONS(9720),
    [sym_grid_keyword] = ACTIONS(9720),
    [sym_part_keyword] = ACTIONS(9720),
    [sym_systempart_keyword] = ACTIONS(9720),
    [sym_usercontrol_keyword] = ACTIONS(9720),
    [sym_dataset_keyword] = ACTIONS(9720),
    [sym_elements_keyword] = ACTIONS(9720),
    [sym_dataitem_keyword] = ACTIONS(9720),
    [sym_column_keyword] = ACTIONS(9720),
    [sym_filter_keyword] = ACTIONS(9720),
    [sym_labels_keyword] = ACTIONS(9720),
    [sym_rendering_keyword] = ACTIONS(9720),
    [sym_requestpage_keyword] = ACTIONS(9720),
    [sym_schema_keyword] = ACTIONS(9720),
    [sym_views_keyword] = ACTIONS(9720),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9720),
    [sym_preproc_open] = ACTIONS(9720),
    [sym_preproc_close] = ACTIONS(9720),
  },
  [STATE(4276)] = {
    [sym_identifier] = ACTIONS(3562),
    [anon_sym_SEMI] = ACTIONS(3564),
    [anon_sym_DOT] = ACTIONS(3562),
    [anon_sym_LBRACE] = ACTIONS(3564),
    [aux_sym_interface_declaration_token1] = ACTIONS(3562),
    [anon_sym_EQ] = ACTIONS(3564),
    [anon_sym_COMMA] = ACTIONS(3564),
    [anon_sym_DASH] = ACTIONS(3562),
    [anon_sym_LPAREN] = ACTIONS(3564),
    [aux_sym_where_clause_token1] = ACTIONS(3564),
    [aux_sym_where_condition_token1] = ACTIONS(3562),
    [anon_sym_DOT_DOT] = ACTIONS(3564),
    [anon_sym_STAR] = ACTIONS(3562),
    [anon_sym_LBRACK] = ACTIONS(3564),
    [aux_sym_basic_type_token22] = ACTIONS(3562),
    [aux_sym_basic_type_token53] = ACTIONS(3562),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3562),
    [aux_sym_separator_action_token1] = ACTIONS(3562),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3562),
    [aux_sym_type_declaration_token1] = ACTIONS(3562),
    [anon_sym_COLON_COLON] = ACTIONS(3564),
    [anon_sym_POUNDelif] = ACTIONS(3564),
    [anon_sym_POUNDELIF] = ACTIONS(3564),
    [anon_sym_POUNDElif] = ACTIONS(3564),
    [anon_sym_POUNDelse] = ACTIONS(3564),
    [anon_sym_POUNDELSE] = ACTIONS(3564),
    [anon_sym_POUNDElse] = ACTIONS(3564),
    [anon_sym_POUNDelse2] = ACTIONS(3564),
    [anon_sym_POUNDELSE2] = ACTIONS(3564),
    [anon_sym_POUNDElse2] = ACTIONS(3564),
    [anon_sym_POUNDendif] = ACTIONS(3564),
    [anon_sym_POUNDENDIF] = ACTIONS(3564),
    [anon_sym_POUNDEndif] = ACTIONS(3564),
    [anon_sym_POUNDendif2] = ACTIONS(3564),
    [anon_sym_POUNDENDIF2] = ACTIONS(3564),
    [anon_sym_POUNDEndif2] = ACTIONS(3564),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3564),
    [aux_sym__expression_token1] = ACTIONS(3564),
    [aux_sym__expression_token2] = ACTIONS(3564),
    [anon_sym_SLASH] = ACTIONS(3562),
    [anon_sym_div] = ACTIONS(3562),
    [anon_sym_DIV] = ACTIONS(3562),
    [anon_sym_Div] = ACTIONS(3562),
    [anon_sym_mod] = ACTIONS(3562),
    [anon_sym_MOD] = ACTIONS(3562),
    [anon_sym_Mod] = ACTIONS(3562),
    [anon_sym_PLUS] = ACTIONS(3562),
    [anon_sym_GT_EQ] = ACTIONS(3564),
    [anon_sym_LT_EQ] = ACTIONS(3564),
    [anon_sym_GT] = ACTIONS(3562),
    [anon_sym_LT] = ACTIONS(3562),
    [anon_sym_LT_GT] = ACTIONS(3564),
    [anon_sym_and] = ACTIONS(3562),
    [anon_sym_AND] = ACTIONS(3562),
    [anon_sym_And] = ACTIONS(3562),
    [anon_sym_or] = ACTIONS(3562),
    [anon_sym_OR] = ACTIONS(3562),
    [anon_sym_Or] = ACTIONS(3562),
    [anon_sym_xor] = ACTIONS(3562),
    [anon_sym_XOR] = ACTIONS(3562),
    [anon_sym_Xor] = ACTIONS(3562),
    [anon_sym_QMARK] = ACTIONS(3564),
    [anon_sym_in] = ACTIONS(3562),
    [anon_sym_IN] = ACTIONS(3562),
    [anon_sym_In] = ACTIONS(3562),
    [sym_table_keyword] = ACTIONS(3562),
    [sym_implements_keyword] = ACTIONS(3562),
    [sym_extends_keyword] = ACTIONS(3562),
    [sym_temporary_keyword] = ACTIONS(3562),
    [sym_key_keyword] = ACTIONS(3562),
    [sym_dataset_keyword] = ACTIONS(3562),
    [sym_quoted_identifier] = ACTIONS(3564),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_close] = ACTIONS(3564),
  },
  [STATE(4277)] = {
    [anon_sym_SEMI] = ACTIONS(9724),
    [aux_sym_where_condition_token1] = ACTIONS(9726),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9724),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9724),
    [anon_sym_LBRACK] = ACTIONS(9724),
    [aux_sym_basic_type_token6] = ACTIONS(9726),
    [aux_sym_basic_type_token22] = ACTIONS(9726),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9724),
    [aux_sym_addafter_modification_token1] = ACTIONS(9724),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9724),
    [aux_sym_modify_modification_token1] = ACTIONS(9724),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9724),
    [aux_sym_movelast_modification_token1] = ACTIONS(9724),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9724),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9724),
    [aux_sym_separator_action_token1] = ACTIONS(9724),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9724),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9724),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9724),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9724),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9724),
    [anon_sym_POUNDif] = ACTIONS(9724),
    [anon_sym_POUNDIF] = ACTIONS(9724),
    [anon_sym_POUNDIf] = ACTIONS(9724),
    [anon_sym_POUNDelif] = ACTIONS(9724),
    [anon_sym_POUNDELIF] = ACTIONS(9724),
    [anon_sym_POUNDElif] = ACTIONS(9724),
    [anon_sym_POUNDelse] = ACTIONS(9724),
    [anon_sym_POUNDELSE] = ACTIONS(9724),
    [anon_sym_POUNDElse] = ACTIONS(9724),
    [anon_sym_POUNDelse2] = ACTIONS(9724),
    [anon_sym_POUNDELSE2] = ACTIONS(9724),
    [anon_sym_POUNDElse2] = ACTIONS(9724),
    [anon_sym_POUNDendif] = ACTIONS(9724),
    [anon_sym_POUNDENDIF] = ACTIONS(9724),
    [anon_sym_POUNDEndif] = ACTIONS(9724),
    [anon_sym_POUNDendif2] = ACTIONS(9724),
    [anon_sym_POUNDENDIF2] = ACTIONS(9724),
    [anon_sym_POUNDEndif2] = ACTIONS(9724),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9724),
    [sym_trigger_keyword] = ACTIONS(9724),
    [sym_var_keyword] = ACTIONS(9724),
    [sym_local_keyword] = ACTIONS(9724),
    [sym_internal_keyword] = ACTIONS(9724),
    [sym_protected_keyword] = ACTIONS(9724),
    [sym_event_keyword] = ACTIONS(9724),
    [sym_fields_keyword] = ACTIONS(9724),
    [sym_keys_keyword] = ACTIONS(9724),
    [sym_fieldgroups_keyword] = ACTIONS(9724),
    [sym_actions_keyword] = ACTIONS(9724),
    [sym_layout_keyword] = ACTIONS(9724),
    [sym_area_keyword] = ACTIONS(9724),
    [sym_group_keyword] = ACTIONS(9724),
    [sym_repeater_keyword] = ACTIONS(9724),
    [sym_cuegroup_keyword] = ACTIONS(9724),
    [sym_fixed_keyword] = ACTIONS(9724),
    [sym_grid_keyword] = ACTIONS(9724),
    [sym_part_keyword] = ACTIONS(9724),
    [sym_systempart_keyword] = ACTIONS(9724),
    [sym_usercontrol_keyword] = ACTIONS(9724),
    [sym_dataset_keyword] = ACTIONS(9724),
    [sym_elements_keyword] = ACTIONS(9724),
    [sym_dataitem_keyword] = ACTIONS(9724),
    [sym_column_keyword] = ACTIONS(9724),
    [sym_filter_keyword] = ACTIONS(9724),
    [sym_labels_keyword] = ACTIONS(9724),
    [sym_rendering_keyword] = ACTIONS(9724),
    [sym_requestpage_keyword] = ACTIONS(9724),
    [sym_schema_keyword] = ACTIONS(9724),
    [sym_views_keyword] = ACTIONS(9724),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9724),
    [sym_preproc_open] = ACTIONS(9724),
    [sym_preproc_close] = ACTIONS(9724),
  },
  [STATE(4278)] = {
    [sym_identifier] = ACTIONS(8335),
    [anon_sym_SEMI] = ACTIONS(8333),
    [anon_sym_COMMA] = ACTIONS(8333),
    [aux_sym_where_condition_token1] = ACTIONS(8335),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8335),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8335),
    [anon_sym_LBRACK] = ACTIONS(8333),
    [aux_sym_basic_type_token22] = ACTIONS(8335),
    [aux_sym_basic_type_token53] = ACTIONS(8335),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8335),
    [aux_sym_modify_modification_token1] = ACTIONS(8335),
    [aux_sym_separator_action_token1] = ACTIONS(8335),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8335),
    [aux_sym_type_declaration_token1] = ACTIONS(8335),
    [anon_sym_POUNDif] = ACTIONS(8333),
    [anon_sym_POUNDIF] = ACTIONS(8333),
    [anon_sym_POUNDIf] = ACTIONS(8333),
    [anon_sym_POUNDelif] = ACTIONS(8333),
    [anon_sym_POUNDELIF] = ACTIONS(8333),
    [anon_sym_POUNDElif] = ACTIONS(8333),
    [anon_sym_POUNDelse] = ACTIONS(8333),
    [anon_sym_POUNDELSE] = ACTIONS(8333),
    [anon_sym_POUNDElse] = ACTIONS(8333),
    [anon_sym_POUNDelse2] = ACTIONS(8333),
    [anon_sym_POUNDELSE2] = ACTIONS(8333),
    [anon_sym_POUNDElse2] = ACTIONS(8333),
    [anon_sym_POUNDendif] = ACTIONS(8333),
    [anon_sym_POUNDENDIF] = ACTIONS(8333),
    [anon_sym_POUNDEndif] = ACTIONS(8333),
    [anon_sym_POUNDendif2] = ACTIONS(8333),
    [anon_sym_POUNDENDIF2] = ACTIONS(8333),
    [anon_sym_POUNDEndif2] = ACTIONS(8333),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8335),
    [sym_page_keyword] = ACTIONS(8335),
    [anon_sym_codeunit] = ACTIONS(8335),
    [anon_sym_CODEUNIT] = ACTIONS(8335),
    [anon_sym_Codeunit] = ACTIONS(8335),
    [anon_sym_CodeUnit] = ACTIONS(8335),
    [anon_sym_COdeunit] = ACTIONS(8335),
    [anon_sym_codeUnit] = ACTIONS(8335),
    [sym_report_keyword] = ACTIONS(8335),
    [sym_query_keyword] = ACTIONS(8335),
    [anon_sym_xmlport] = ACTIONS(8335),
    [anon_sym_XMLPORT] = ACTIONS(8335),
    [anon_sym_Xmlport] = ACTIONS(8335),
    [anon_sym_XMLport] = ACTIONS(8335),
    [anon_sym_XMLPort] = ACTIONS(8335),
    [anon_sym_XmlPort] = ACTIONS(8335),
    [sym_procedure_keyword] = ACTIONS(8335),
    [sym_trigger_keyword] = ACTIONS(8335),
    [sym_var_keyword] = ACTIONS(8335),
    [sym_local_keyword] = ACTIONS(8335),
    [sym_internal_keyword] = ACTIONS(8335),
    [sym_protected_keyword] = ACTIONS(8335),
    [sym_event_keyword] = ACTIONS(8335),
    [sym_fields_keyword] = ACTIONS(8335),
    [sym_keys_keyword] = ACTIONS(8335),
    [sym_key_keyword] = ACTIONS(8335),
    [sym_fieldgroups_keyword] = ACTIONS(8335),
    [sym_actions_keyword] = ACTIONS(8335),
    [sym_layout_keyword] = ACTIONS(8335),
    [sym_dataset_keyword] = ACTIONS(8335),
    [sym_elements_keyword] = ACTIONS(8335),
    [sym_labels_keyword] = ACTIONS(8335),
    [sym_rendering_keyword] = ACTIONS(8335),
    [sym_requestpage_keyword] = ACTIONS(8335),
    [sym_schema_keyword] = ACTIONS(8335),
    [sym_views_keyword] = ACTIONS(8335),
    [sym_quoted_identifier] = ACTIONS(8333),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8333),
    [sym_preproc_open] = ACTIONS(8333),
    [sym_preproc_close] = ACTIONS(8333),
    [sym_var_attribute_open] = ACTIONS(8333),
  },
  [STATE(4279)] = {
    [anon_sym_SEMI] = ACTIONS(9724),
    [aux_sym_where_condition_token1] = ACTIONS(9726),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9724),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9724),
    [anon_sym_LBRACK] = ACTIONS(9724),
    [aux_sym_basic_type_token6] = ACTIONS(9726),
    [aux_sym_basic_type_token22] = ACTIONS(9726),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9724),
    [aux_sym_addafter_modification_token1] = ACTIONS(9724),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9724),
    [aux_sym_modify_modification_token1] = ACTIONS(9724),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9724),
    [aux_sym_movelast_modification_token1] = ACTIONS(9724),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9724),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9724),
    [aux_sym_separator_action_token1] = ACTIONS(9724),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9724),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9724),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9724),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9724),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9724),
    [anon_sym_POUNDif] = ACTIONS(9724),
    [anon_sym_POUNDIF] = ACTIONS(9724),
    [anon_sym_POUNDIf] = ACTIONS(9724),
    [anon_sym_POUNDelif] = ACTIONS(9724),
    [anon_sym_POUNDELIF] = ACTIONS(9724),
    [anon_sym_POUNDElif] = ACTIONS(9724),
    [anon_sym_POUNDelse] = ACTIONS(9724),
    [anon_sym_POUNDELSE] = ACTIONS(9724),
    [anon_sym_POUNDElse] = ACTIONS(9724),
    [anon_sym_POUNDelse2] = ACTIONS(9724),
    [anon_sym_POUNDELSE2] = ACTIONS(9724),
    [anon_sym_POUNDElse2] = ACTIONS(9724),
    [anon_sym_POUNDendif] = ACTIONS(9724),
    [anon_sym_POUNDENDIF] = ACTIONS(9724),
    [anon_sym_POUNDEndif] = ACTIONS(9724),
    [anon_sym_POUNDendif2] = ACTIONS(9724),
    [anon_sym_POUNDENDIF2] = ACTIONS(9724),
    [anon_sym_POUNDEndif2] = ACTIONS(9724),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9724),
    [sym_trigger_keyword] = ACTIONS(9724),
    [sym_var_keyword] = ACTIONS(9724),
    [sym_local_keyword] = ACTIONS(9724),
    [sym_internal_keyword] = ACTIONS(9724),
    [sym_protected_keyword] = ACTIONS(9724),
    [sym_event_keyword] = ACTIONS(9724),
    [sym_fields_keyword] = ACTIONS(9724),
    [sym_keys_keyword] = ACTIONS(9724),
    [sym_fieldgroups_keyword] = ACTIONS(9724),
    [sym_actions_keyword] = ACTIONS(9724),
    [sym_layout_keyword] = ACTIONS(9724),
    [sym_area_keyword] = ACTIONS(9724),
    [sym_group_keyword] = ACTIONS(9724),
    [sym_repeater_keyword] = ACTIONS(9724),
    [sym_cuegroup_keyword] = ACTIONS(9724),
    [sym_fixed_keyword] = ACTIONS(9724),
    [sym_grid_keyword] = ACTIONS(9724),
    [sym_part_keyword] = ACTIONS(9724),
    [sym_systempart_keyword] = ACTIONS(9724),
    [sym_usercontrol_keyword] = ACTIONS(9724),
    [sym_dataset_keyword] = ACTIONS(9724),
    [sym_elements_keyword] = ACTIONS(9724),
    [sym_dataitem_keyword] = ACTIONS(9724),
    [sym_column_keyword] = ACTIONS(9724),
    [sym_filter_keyword] = ACTIONS(9724),
    [sym_labels_keyword] = ACTIONS(9724),
    [sym_rendering_keyword] = ACTIONS(9724),
    [sym_requestpage_keyword] = ACTIONS(9724),
    [sym_schema_keyword] = ACTIONS(9724),
    [sym_views_keyword] = ACTIONS(9724),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9724),
    [sym_preproc_open] = ACTIONS(9724),
    [sym_preproc_close] = ACTIONS(9724),
  },
  [STATE(4280)] = {
    [anon_sym_SEMI] = ACTIONS(9728),
    [aux_sym_where_condition_token1] = ACTIONS(9730),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9728),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9728),
    [anon_sym_LBRACK] = ACTIONS(9728),
    [aux_sym_basic_type_token6] = ACTIONS(9730),
    [aux_sym_basic_type_token22] = ACTIONS(9730),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9728),
    [aux_sym_addafter_modification_token1] = ACTIONS(9728),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9728),
    [aux_sym_modify_modification_token1] = ACTIONS(9728),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9728),
    [aux_sym_movelast_modification_token1] = ACTIONS(9728),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9728),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9728),
    [aux_sym_separator_action_token1] = ACTIONS(9728),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9728),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9728),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9728),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9728),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9728),
    [anon_sym_POUNDif] = ACTIONS(9728),
    [anon_sym_POUNDIF] = ACTIONS(9728),
    [anon_sym_POUNDIf] = ACTIONS(9728),
    [anon_sym_POUNDelif] = ACTIONS(9728),
    [anon_sym_POUNDELIF] = ACTIONS(9728),
    [anon_sym_POUNDElif] = ACTIONS(9728),
    [anon_sym_POUNDelse] = ACTIONS(9728),
    [anon_sym_POUNDELSE] = ACTIONS(9728),
    [anon_sym_POUNDElse] = ACTIONS(9728),
    [anon_sym_POUNDelse2] = ACTIONS(9728),
    [anon_sym_POUNDELSE2] = ACTIONS(9728),
    [anon_sym_POUNDElse2] = ACTIONS(9728),
    [anon_sym_POUNDendif] = ACTIONS(9728),
    [anon_sym_POUNDENDIF] = ACTIONS(9728),
    [anon_sym_POUNDEndif] = ACTIONS(9728),
    [anon_sym_POUNDendif2] = ACTIONS(9728),
    [anon_sym_POUNDENDIF2] = ACTIONS(9728),
    [anon_sym_POUNDEndif2] = ACTIONS(9728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9728),
    [sym_trigger_keyword] = ACTIONS(9728),
    [sym_var_keyword] = ACTIONS(9728),
    [sym_local_keyword] = ACTIONS(9728),
    [sym_internal_keyword] = ACTIONS(9728),
    [sym_protected_keyword] = ACTIONS(9728),
    [sym_event_keyword] = ACTIONS(9728),
    [sym_fields_keyword] = ACTIONS(9728),
    [sym_keys_keyword] = ACTIONS(9728),
    [sym_fieldgroups_keyword] = ACTIONS(9728),
    [sym_actions_keyword] = ACTIONS(9728),
    [sym_layout_keyword] = ACTIONS(9728),
    [sym_area_keyword] = ACTIONS(9728),
    [sym_group_keyword] = ACTIONS(9728),
    [sym_repeater_keyword] = ACTIONS(9728),
    [sym_cuegroup_keyword] = ACTIONS(9728),
    [sym_fixed_keyword] = ACTIONS(9728),
    [sym_grid_keyword] = ACTIONS(9728),
    [sym_part_keyword] = ACTIONS(9728),
    [sym_systempart_keyword] = ACTIONS(9728),
    [sym_usercontrol_keyword] = ACTIONS(9728),
    [sym_dataset_keyword] = ACTIONS(9728),
    [sym_elements_keyword] = ACTIONS(9728),
    [sym_dataitem_keyword] = ACTIONS(9728),
    [sym_column_keyword] = ACTIONS(9728),
    [sym_filter_keyword] = ACTIONS(9728),
    [sym_labels_keyword] = ACTIONS(9728),
    [sym_rendering_keyword] = ACTIONS(9728),
    [sym_requestpage_keyword] = ACTIONS(9728),
    [sym_schema_keyword] = ACTIONS(9728),
    [sym_views_keyword] = ACTIONS(9728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9728),
    [sym_preproc_open] = ACTIONS(9728),
    [sym_preproc_close] = ACTIONS(9728),
  },
  [STATE(4281)] = {
    [anon_sym_SEMI] = ACTIONS(9728),
    [aux_sym_where_condition_token1] = ACTIONS(9730),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9728),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9728),
    [anon_sym_LBRACK] = ACTIONS(9728),
    [aux_sym_basic_type_token6] = ACTIONS(9730),
    [aux_sym_basic_type_token22] = ACTIONS(9730),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9728),
    [aux_sym_addafter_modification_token1] = ACTIONS(9728),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9728),
    [aux_sym_modify_modification_token1] = ACTIONS(9728),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9728),
    [aux_sym_movelast_modification_token1] = ACTIONS(9728),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9728),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9728),
    [aux_sym_separator_action_token1] = ACTIONS(9728),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9728),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9728),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9728),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9728),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9728),
    [anon_sym_POUNDif] = ACTIONS(9728),
    [anon_sym_POUNDIF] = ACTIONS(9728),
    [anon_sym_POUNDIf] = ACTIONS(9728),
    [anon_sym_POUNDelif] = ACTIONS(9728),
    [anon_sym_POUNDELIF] = ACTIONS(9728),
    [anon_sym_POUNDElif] = ACTIONS(9728),
    [anon_sym_POUNDelse] = ACTIONS(9728),
    [anon_sym_POUNDELSE] = ACTIONS(9728),
    [anon_sym_POUNDElse] = ACTIONS(9728),
    [anon_sym_POUNDelse2] = ACTIONS(9728),
    [anon_sym_POUNDELSE2] = ACTIONS(9728),
    [anon_sym_POUNDElse2] = ACTIONS(9728),
    [anon_sym_POUNDendif] = ACTIONS(9728),
    [anon_sym_POUNDENDIF] = ACTIONS(9728),
    [anon_sym_POUNDEndif] = ACTIONS(9728),
    [anon_sym_POUNDendif2] = ACTIONS(9728),
    [anon_sym_POUNDENDIF2] = ACTIONS(9728),
    [anon_sym_POUNDEndif2] = ACTIONS(9728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9728),
    [sym_trigger_keyword] = ACTIONS(9728),
    [sym_var_keyword] = ACTIONS(9728),
    [sym_local_keyword] = ACTIONS(9728),
    [sym_internal_keyword] = ACTIONS(9728),
    [sym_protected_keyword] = ACTIONS(9728),
    [sym_event_keyword] = ACTIONS(9728),
    [sym_fields_keyword] = ACTIONS(9728),
    [sym_keys_keyword] = ACTIONS(9728),
    [sym_fieldgroups_keyword] = ACTIONS(9728),
    [sym_actions_keyword] = ACTIONS(9728),
    [sym_layout_keyword] = ACTIONS(9728),
    [sym_area_keyword] = ACTIONS(9728),
    [sym_group_keyword] = ACTIONS(9728),
    [sym_repeater_keyword] = ACTIONS(9728),
    [sym_cuegroup_keyword] = ACTIONS(9728),
    [sym_fixed_keyword] = ACTIONS(9728),
    [sym_grid_keyword] = ACTIONS(9728),
    [sym_part_keyword] = ACTIONS(9728),
    [sym_systempart_keyword] = ACTIONS(9728),
    [sym_usercontrol_keyword] = ACTIONS(9728),
    [sym_dataset_keyword] = ACTIONS(9728),
    [sym_elements_keyword] = ACTIONS(9728),
    [sym_dataitem_keyword] = ACTIONS(9728),
    [sym_column_keyword] = ACTIONS(9728),
    [sym_filter_keyword] = ACTIONS(9728),
    [sym_labels_keyword] = ACTIONS(9728),
    [sym_rendering_keyword] = ACTIONS(9728),
    [sym_requestpage_keyword] = ACTIONS(9728),
    [sym_schema_keyword] = ACTIONS(9728),
    [sym_views_keyword] = ACTIONS(9728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9728),
    [sym_preproc_open] = ACTIONS(9728),
    [sym_preproc_close] = ACTIONS(9728),
  },
  [STATE(4282)] = {
    [anon_sym_SEMI] = ACTIONS(9732),
    [aux_sym_where_condition_token1] = ACTIONS(9734),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9732),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9732),
    [anon_sym_LBRACK] = ACTIONS(9732),
    [aux_sym_basic_type_token6] = ACTIONS(9734),
    [aux_sym_basic_type_token22] = ACTIONS(9734),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9732),
    [aux_sym_addafter_modification_token1] = ACTIONS(9732),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9732),
    [aux_sym_modify_modification_token1] = ACTIONS(9732),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9732),
    [aux_sym_movelast_modification_token1] = ACTIONS(9732),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9732),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9732),
    [aux_sym_separator_action_token1] = ACTIONS(9732),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9732),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9732),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9732),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9732),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9732),
    [anon_sym_POUNDif] = ACTIONS(9732),
    [anon_sym_POUNDIF] = ACTIONS(9732),
    [anon_sym_POUNDIf] = ACTIONS(9732),
    [anon_sym_POUNDelif] = ACTIONS(9732),
    [anon_sym_POUNDELIF] = ACTIONS(9732),
    [anon_sym_POUNDElif] = ACTIONS(9732),
    [anon_sym_POUNDelse] = ACTIONS(9732),
    [anon_sym_POUNDELSE] = ACTIONS(9732),
    [anon_sym_POUNDElse] = ACTIONS(9732),
    [anon_sym_POUNDelse2] = ACTIONS(9732),
    [anon_sym_POUNDELSE2] = ACTIONS(9732),
    [anon_sym_POUNDElse2] = ACTIONS(9732),
    [anon_sym_POUNDendif] = ACTIONS(9732),
    [anon_sym_POUNDENDIF] = ACTIONS(9732),
    [anon_sym_POUNDEndif] = ACTIONS(9732),
    [anon_sym_POUNDendif2] = ACTIONS(9732),
    [anon_sym_POUNDENDIF2] = ACTIONS(9732),
    [anon_sym_POUNDEndif2] = ACTIONS(9732),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9732),
    [sym_trigger_keyword] = ACTIONS(9732),
    [sym_var_keyword] = ACTIONS(9732),
    [sym_local_keyword] = ACTIONS(9732),
    [sym_internal_keyword] = ACTIONS(9732),
    [sym_protected_keyword] = ACTIONS(9732),
    [sym_event_keyword] = ACTIONS(9732),
    [sym_fields_keyword] = ACTIONS(9732),
    [sym_keys_keyword] = ACTIONS(9732),
    [sym_fieldgroups_keyword] = ACTIONS(9732),
    [sym_actions_keyword] = ACTIONS(9732),
    [sym_layout_keyword] = ACTIONS(9732),
    [sym_area_keyword] = ACTIONS(9732),
    [sym_group_keyword] = ACTIONS(9732),
    [sym_repeater_keyword] = ACTIONS(9732),
    [sym_cuegroup_keyword] = ACTIONS(9732),
    [sym_fixed_keyword] = ACTIONS(9732),
    [sym_grid_keyword] = ACTIONS(9732),
    [sym_part_keyword] = ACTIONS(9732),
    [sym_systempart_keyword] = ACTIONS(9732),
    [sym_usercontrol_keyword] = ACTIONS(9732),
    [sym_dataset_keyword] = ACTIONS(9732),
    [sym_elements_keyword] = ACTIONS(9732),
    [sym_dataitem_keyword] = ACTIONS(9732),
    [sym_column_keyword] = ACTIONS(9732),
    [sym_filter_keyword] = ACTIONS(9732),
    [sym_labels_keyword] = ACTIONS(9732),
    [sym_rendering_keyword] = ACTIONS(9732),
    [sym_requestpage_keyword] = ACTIONS(9732),
    [sym_schema_keyword] = ACTIONS(9732),
    [sym_views_keyword] = ACTIONS(9732),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9732),
    [sym_preproc_open] = ACTIONS(9732),
    [sym_preproc_close] = ACTIONS(9732),
  },
  [STATE(4283)] = {
    [anon_sym_SEMI] = ACTIONS(6154),
    [aux_sym_where_condition_token1] = ACTIONS(6152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6154),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6154),
    [anon_sym_LBRACK] = ACTIONS(6154),
    [aux_sym_basic_type_token6] = ACTIONS(6152),
    [aux_sym_basic_type_token22] = ACTIONS(6152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6154),
    [aux_sym_addafter_modification_token1] = ACTIONS(6154),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6154),
    [aux_sym_modify_modification_token1] = ACTIONS(6154),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6154),
    [aux_sym_movelast_modification_token1] = ACTIONS(6154),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6154),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6154),
    [aux_sym_separator_action_token1] = ACTIONS(6154),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6154),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6154),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6154),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6154),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6154),
    [anon_sym_POUNDif] = ACTIONS(6154),
    [anon_sym_POUNDIF] = ACTIONS(6154),
    [anon_sym_POUNDIf] = ACTIONS(6154),
    [anon_sym_POUNDelif] = ACTIONS(6154),
    [anon_sym_POUNDELIF] = ACTIONS(6154),
    [anon_sym_POUNDElif] = ACTIONS(6154),
    [anon_sym_POUNDelse] = ACTIONS(6154),
    [anon_sym_POUNDELSE] = ACTIONS(6154),
    [anon_sym_POUNDElse] = ACTIONS(6154),
    [anon_sym_POUNDelse2] = ACTIONS(6154),
    [anon_sym_POUNDELSE2] = ACTIONS(6154),
    [anon_sym_POUNDElse2] = ACTIONS(6154),
    [anon_sym_POUNDendif] = ACTIONS(6154),
    [anon_sym_POUNDENDIF] = ACTIONS(6154),
    [anon_sym_POUNDEndif] = ACTIONS(6154),
    [anon_sym_POUNDendif2] = ACTIONS(6154),
    [anon_sym_POUNDENDIF2] = ACTIONS(6154),
    [anon_sym_POUNDEndif2] = ACTIONS(6154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6154),
    [sym_trigger_keyword] = ACTIONS(6154),
    [sym_var_keyword] = ACTIONS(6154),
    [sym_local_keyword] = ACTIONS(6154),
    [sym_internal_keyword] = ACTIONS(6154),
    [sym_protected_keyword] = ACTIONS(6154),
    [sym_event_keyword] = ACTIONS(6154),
    [sym_fields_keyword] = ACTIONS(6154),
    [sym_keys_keyword] = ACTIONS(6154),
    [sym_fieldgroups_keyword] = ACTIONS(6154),
    [sym_actions_keyword] = ACTIONS(6154),
    [sym_layout_keyword] = ACTIONS(6154),
    [sym_area_keyword] = ACTIONS(6154),
    [sym_group_keyword] = ACTIONS(6154),
    [sym_repeater_keyword] = ACTIONS(6154),
    [sym_cuegroup_keyword] = ACTIONS(6154),
    [sym_fixed_keyword] = ACTIONS(6154),
    [sym_grid_keyword] = ACTIONS(6154),
    [sym_part_keyword] = ACTIONS(6154),
    [sym_systempart_keyword] = ACTIONS(6154),
    [sym_usercontrol_keyword] = ACTIONS(6154),
    [sym_dataset_keyword] = ACTIONS(6154),
    [sym_elements_keyword] = ACTIONS(6154),
    [sym_dataitem_keyword] = ACTIONS(6154),
    [sym_column_keyword] = ACTIONS(6154),
    [sym_filter_keyword] = ACTIONS(6154),
    [sym_labels_keyword] = ACTIONS(6154),
    [sym_rendering_keyword] = ACTIONS(6154),
    [sym_requestpage_keyword] = ACTIONS(6154),
    [sym_schema_keyword] = ACTIONS(6154),
    [sym_views_keyword] = ACTIONS(6154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6154),
    [sym_preproc_open] = ACTIONS(6154),
    [sym_preproc_close] = ACTIONS(6154),
  },
  [STATE(4284)] = {
    [anon_sym_SEMI] = ACTIONS(6158),
    [aux_sym_where_condition_token1] = ACTIONS(6156),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6158),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6158),
    [anon_sym_LBRACK] = ACTIONS(6158),
    [aux_sym_basic_type_token6] = ACTIONS(6156),
    [aux_sym_basic_type_token22] = ACTIONS(6156),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6158),
    [aux_sym_addafter_modification_token1] = ACTIONS(6158),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6158),
    [aux_sym_modify_modification_token1] = ACTIONS(6158),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6158),
    [aux_sym_movelast_modification_token1] = ACTIONS(6158),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6158),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6158),
    [aux_sym_separator_action_token1] = ACTIONS(6158),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6158),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6158),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6158),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6158),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6158),
    [anon_sym_POUNDif] = ACTIONS(6158),
    [anon_sym_POUNDIF] = ACTIONS(6158),
    [anon_sym_POUNDIf] = ACTIONS(6158),
    [anon_sym_POUNDelif] = ACTIONS(6158),
    [anon_sym_POUNDELIF] = ACTIONS(6158),
    [anon_sym_POUNDElif] = ACTIONS(6158),
    [anon_sym_POUNDelse] = ACTIONS(6158),
    [anon_sym_POUNDELSE] = ACTIONS(6158),
    [anon_sym_POUNDElse] = ACTIONS(6158),
    [anon_sym_POUNDelse2] = ACTIONS(6158),
    [anon_sym_POUNDELSE2] = ACTIONS(6158),
    [anon_sym_POUNDElse2] = ACTIONS(6158),
    [anon_sym_POUNDendif] = ACTIONS(6158),
    [anon_sym_POUNDENDIF] = ACTIONS(6158),
    [anon_sym_POUNDEndif] = ACTIONS(6158),
    [anon_sym_POUNDendif2] = ACTIONS(6158),
    [anon_sym_POUNDENDIF2] = ACTIONS(6158),
    [anon_sym_POUNDEndif2] = ACTIONS(6158),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6158),
    [sym_trigger_keyword] = ACTIONS(6158),
    [sym_var_keyword] = ACTIONS(6158),
    [sym_local_keyword] = ACTIONS(6158),
    [sym_internal_keyword] = ACTIONS(6158),
    [sym_protected_keyword] = ACTIONS(6158),
    [sym_event_keyword] = ACTIONS(6158),
    [sym_fields_keyword] = ACTIONS(6158),
    [sym_keys_keyword] = ACTIONS(6158),
    [sym_fieldgroups_keyword] = ACTIONS(6158),
    [sym_actions_keyword] = ACTIONS(6158),
    [sym_layout_keyword] = ACTIONS(6158),
    [sym_area_keyword] = ACTIONS(6158),
    [sym_group_keyword] = ACTIONS(6158),
    [sym_repeater_keyword] = ACTIONS(6158),
    [sym_cuegroup_keyword] = ACTIONS(6158),
    [sym_fixed_keyword] = ACTIONS(6158),
    [sym_grid_keyword] = ACTIONS(6158),
    [sym_part_keyword] = ACTIONS(6158),
    [sym_systempart_keyword] = ACTIONS(6158),
    [sym_usercontrol_keyword] = ACTIONS(6158),
    [sym_dataset_keyword] = ACTIONS(6158),
    [sym_elements_keyword] = ACTIONS(6158),
    [sym_dataitem_keyword] = ACTIONS(6158),
    [sym_column_keyword] = ACTIONS(6158),
    [sym_filter_keyword] = ACTIONS(6158),
    [sym_labels_keyword] = ACTIONS(6158),
    [sym_rendering_keyword] = ACTIONS(6158),
    [sym_requestpage_keyword] = ACTIONS(6158),
    [sym_schema_keyword] = ACTIONS(6158),
    [sym_views_keyword] = ACTIONS(6158),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6158),
    [sym_preproc_open] = ACTIONS(6158),
    [sym_preproc_close] = ACTIONS(6158),
  },
  [STATE(4285)] = {
    [anon_sym_SEMI] = ACTIONS(6162),
    [aux_sym_where_condition_token1] = ACTIONS(6160),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6162),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6162),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [aux_sym_basic_type_token6] = ACTIONS(6160),
    [aux_sym_basic_type_token22] = ACTIONS(6160),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6162),
    [aux_sym_addafter_modification_token1] = ACTIONS(6162),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6162),
    [aux_sym_modify_modification_token1] = ACTIONS(6162),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6162),
    [aux_sym_movelast_modification_token1] = ACTIONS(6162),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6162),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6162),
    [aux_sym_separator_action_token1] = ACTIONS(6162),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6162),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6162),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6162),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6162),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6162),
    [anon_sym_POUNDif] = ACTIONS(6162),
    [anon_sym_POUNDIF] = ACTIONS(6162),
    [anon_sym_POUNDIf] = ACTIONS(6162),
    [anon_sym_POUNDelif] = ACTIONS(6162),
    [anon_sym_POUNDELIF] = ACTIONS(6162),
    [anon_sym_POUNDElif] = ACTIONS(6162),
    [anon_sym_POUNDelse] = ACTIONS(6162),
    [anon_sym_POUNDELSE] = ACTIONS(6162),
    [anon_sym_POUNDElse] = ACTIONS(6162),
    [anon_sym_POUNDelse2] = ACTIONS(6162),
    [anon_sym_POUNDELSE2] = ACTIONS(6162),
    [anon_sym_POUNDElse2] = ACTIONS(6162),
    [anon_sym_POUNDendif] = ACTIONS(6162),
    [anon_sym_POUNDENDIF] = ACTIONS(6162),
    [anon_sym_POUNDEndif] = ACTIONS(6162),
    [anon_sym_POUNDendif2] = ACTIONS(6162),
    [anon_sym_POUNDENDIF2] = ACTIONS(6162),
    [anon_sym_POUNDEndif2] = ACTIONS(6162),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6162),
    [sym_trigger_keyword] = ACTIONS(6162),
    [sym_var_keyword] = ACTIONS(6162),
    [sym_local_keyword] = ACTIONS(6162),
    [sym_internal_keyword] = ACTIONS(6162),
    [sym_protected_keyword] = ACTIONS(6162),
    [sym_event_keyword] = ACTIONS(6162),
    [sym_fields_keyword] = ACTIONS(6162),
    [sym_keys_keyword] = ACTIONS(6162),
    [sym_fieldgroups_keyword] = ACTIONS(6162),
    [sym_actions_keyword] = ACTIONS(6162),
    [sym_layout_keyword] = ACTIONS(6162),
    [sym_area_keyword] = ACTIONS(6162),
    [sym_group_keyword] = ACTIONS(6162),
    [sym_repeater_keyword] = ACTIONS(6162),
    [sym_cuegroup_keyword] = ACTIONS(6162),
    [sym_fixed_keyword] = ACTIONS(6162),
    [sym_grid_keyword] = ACTIONS(6162),
    [sym_part_keyword] = ACTIONS(6162),
    [sym_systempart_keyword] = ACTIONS(6162),
    [sym_usercontrol_keyword] = ACTIONS(6162),
    [sym_dataset_keyword] = ACTIONS(6162),
    [sym_elements_keyword] = ACTIONS(6162),
    [sym_dataitem_keyword] = ACTIONS(6162),
    [sym_column_keyword] = ACTIONS(6162),
    [sym_filter_keyword] = ACTIONS(6162),
    [sym_labels_keyword] = ACTIONS(6162),
    [sym_rendering_keyword] = ACTIONS(6162),
    [sym_requestpage_keyword] = ACTIONS(6162),
    [sym_schema_keyword] = ACTIONS(6162),
    [sym_views_keyword] = ACTIONS(6162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6162),
    [sym_preproc_open] = ACTIONS(6162),
    [sym_preproc_close] = ACTIONS(6162),
  },
  [STATE(4286)] = {
    [anon_sym_SEMI] = ACTIONS(6166),
    [aux_sym_where_condition_token1] = ACTIONS(6164),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6166),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6166),
    [anon_sym_LBRACK] = ACTIONS(6166),
    [aux_sym_basic_type_token6] = ACTIONS(6164),
    [aux_sym_basic_type_token22] = ACTIONS(6164),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6166),
    [aux_sym_addafter_modification_token1] = ACTIONS(6166),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6166),
    [aux_sym_modify_modification_token1] = ACTIONS(6166),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6166),
    [aux_sym_movelast_modification_token1] = ACTIONS(6166),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6166),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6166),
    [aux_sym_separator_action_token1] = ACTIONS(6166),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6166),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6166),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6166),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6166),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6166),
    [anon_sym_POUNDif] = ACTIONS(6166),
    [anon_sym_POUNDIF] = ACTIONS(6166),
    [anon_sym_POUNDIf] = ACTIONS(6166),
    [anon_sym_POUNDelif] = ACTIONS(6166),
    [anon_sym_POUNDELIF] = ACTIONS(6166),
    [anon_sym_POUNDElif] = ACTIONS(6166),
    [anon_sym_POUNDelse] = ACTIONS(6166),
    [anon_sym_POUNDELSE] = ACTIONS(6166),
    [anon_sym_POUNDElse] = ACTIONS(6166),
    [anon_sym_POUNDelse2] = ACTIONS(6166),
    [anon_sym_POUNDELSE2] = ACTIONS(6166),
    [anon_sym_POUNDElse2] = ACTIONS(6166),
    [anon_sym_POUNDendif] = ACTIONS(6166),
    [anon_sym_POUNDENDIF] = ACTIONS(6166),
    [anon_sym_POUNDEndif] = ACTIONS(6166),
    [anon_sym_POUNDendif2] = ACTIONS(6166),
    [anon_sym_POUNDENDIF2] = ACTIONS(6166),
    [anon_sym_POUNDEndif2] = ACTIONS(6166),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6166),
    [sym_trigger_keyword] = ACTIONS(6166),
    [sym_var_keyword] = ACTIONS(6166),
    [sym_local_keyword] = ACTIONS(6166),
    [sym_internal_keyword] = ACTIONS(6166),
    [sym_protected_keyword] = ACTIONS(6166),
    [sym_event_keyword] = ACTIONS(6166),
    [sym_fields_keyword] = ACTIONS(6166),
    [sym_keys_keyword] = ACTIONS(6166),
    [sym_fieldgroups_keyword] = ACTIONS(6166),
    [sym_actions_keyword] = ACTIONS(6166),
    [sym_layout_keyword] = ACTIONS(6166),
    [sym_area_keyword] = ACTIONS(6166),
    [sym_group_keyword] = ACTIONS(6166),
    [sym_repeater_keyword] = ACTIONS(6166),
    [sym_cuegroup_keyword] = ACTIONS(6166),
    [sym_fixed_keyword] = ACTIONS(6166),
    [sym_grid_keyword] = ACTIONS(6166),
    [sym_part_keyword] = ACTIONS(6166),
    [sym_systempart_keyword] = ACTIONS(6166),
    [sym_usercontrol_keyword] = ACTIONS(6166),
    [sym_dataset_keyword] = ACTIONS(6166),
    [sym_elements_keyword] = ACTIONS(6166),
    [sym_dataitem_keyword] = ACTIONS(6166),
    [sym_column_keyword] = ACTIONS(6166),
    [sym_filter_keyword] = ACTIONS(6166),
    [sym_labels_keyword] = ACTIONS(6166),
    [sym_rendering_keyword] = ACTIONS(6166),
    [sym_requestpage_keyword] = ACTIONS(6166),
    [sym_schema_keyword] = ACTIONS(6166),
    [sym_views_keyword] = ACTIONS(6166),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6166),
    [sym_preproc_open] = ACTIONS(6166),
    [sym_preproc_close] = ACTIONS(6166),
  },
  [STATE(4287)] = {
    [anon_sym_SEMI] = ACTIONS(6170),
    [aux_sym_where_condition_token1] = ACTIONS(6168),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6170),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6170),
    [anon_sym_LBRACK] = ACTIONS(6170),
    [aux_sym_basic_type_token6] = ACTIONS(6168),
    [aux_sym_basic_type_token22] = ACTIONS(6168),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6170),
    [aux_sym_addafter_modification_token1] = ACTIONS(6170),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6170),
    [aux_sym_modify_modification_token1] = ACTIONS(6170),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6170),
    [aux_sym_movelast_modification_token1] = ACTIONS(6170),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6170),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6170),
    [aux_sym_separator_action_token1] = ACTIONS(6170),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6170),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6170),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6170),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6170),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6170),
    [anon_sym_POUNDif] = ACTIONS(6170),
    [anon_sym_POUNDIF] = ACTIONS(6170),
    [anon_sym_POUNDIf] = ACTIONS(6170),
    [anon_sym_POUNDelif] = ACTIONS(6170),
    [anon_sym_POUNDELIF] = ACTIONS(6170),
    [anon_sym_POUNDElif] = ACTIONS(6170),
    [anon_sym_POUNDelse] = ACTIONS(6170),
    [anon_sym_POUNDELSE] = ACTIONS(6170),
    [anon_sym_POUNDElse] = ACTIONS(6170),
    [anon_sym_POUNDelse2] = ACTIONS(6170),
    [anon_sym_POUNDELSE2] = ACTIONS(6170),
    [anon_sym_POUNDElse2] = ACTIONS(6170),
    [anon_sym_POUNDendif] = ACTIONS(6170),
    [anon_sym_POUNDENDIF] = ACTIONS(6170),
    [anon_sym_POUNDEndif] = ACTIONS(6170),
    [anon_sym_POUNDendif2] = ACTIONS(6170),
    [anon_sym_POUNDENDIF2] = ACTIONS(6170),
    [anon_sym_POUNDEndif2] = ACTIONS(6170),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6170),
    [sym_trigger_keyword] = ACTIONS(6170),
    [sym_var_keyword] = ACTIONS(6170),
    [sym_local_keyword] = ACTIONS(6170),
    [sym_internal_keyword] = ACTIONS(6170),
    [sym_protected_keyword] = ACTIONS(6170),
    [sym_event_keyword] = ACTIONS(6170),
    [sym_fields_keyword] = ACTIONS(6170),
    [sym_keys_keyword] = ACTIONS(6170),
    [sym_fieldgroups_keyword] = ACTIONS(6170),
    [sym_actions_keyword] = ACTIONS(6170),
    [sym_layout_keyword] = ACTIONS(6170),
    [sym_area_keyword] = ACTIONS(6170),
    [sym_group_keyword] = ACTIONS(6170),
    [sym_repeater_keyword] = ACTIONS(6170),
    [sym_cuegroup_keyword] = ACTIONS(6170),
    [sym_fixed_keyword] = ACTIONS(6170),
    [sym_grid_keyword] = ACTIONS(6170),
    [sym_part_keyword] = ACTIONS(6170),
    [sym_systempart_keyword] = ACTIONS(6170),
    [sym_usercontrol_keyword] = ACTIONS(6170),
    [sym_dataset_keyword] = ACTIONS(6170),
    [sym_elements_keyword] = ACTIONS(6170),
    [sym_dataitem_keyword] = ACTIONS(6170),
    [sym_column_keyword] = ACTIONS(6170),
    [sym_filter_keyword] = ACTIONS(6170),
    [sym_labels_keyword] = ACTIONS(6170),
    [sym_rendering_keyword] = ACTIONS(6170),
    [sym_requestpage_keyword] = ACTIONS(6170),
    [sym_schema_keyword] = ACTIONS(6170),
    [sym_views_keyword] = ACTIONS(6170),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6170),
    [sym_preproc_open] = ACTIONS(6170),
    [sym_preproc_close] = ACTIONS(6170),
  },
  [STATE(4288)] = {
    [anon_sym_SEMI] = ACTIONS(6174),
    [aux_sym_where_condition_token1] = ACTIONS(6172),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6174),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6174),
    [anon_sym_LBRACK] = ACTIONS(6174),
    [aux_sym_basic_type_token6] = ACTIONS(6172),
    [aux_sym_basic_type_token22] = ACTIONS(6172),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6174),
    [aux_sym_addafter_modification_token1] = ACTIONS(6174),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6174),
    [aux_sym_modify_modification_token1] = ACTIONS(6174),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6174),
    [aux_sym_movelast_modification_token1] = ACTIONS(6174),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6174),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6174),
    [aux_sym_separator_action_token1] = ACTIONS(6174),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6174),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6174),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6174),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6174),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6174),
    [anon_sym_POUNDif] = ACTIONS(6174),
    [anon_sym_POUNDIF] = ACTIONS(6174),
    [anon_sym_POUNDIf] = ACTIONS(6174),
    [anon_sym_POUNDelif] = ACTIONS(6174),
    [anon_sym_POUNDELIF] = ACTIONS(6174),
    [anon_sym_POUNDElif] = ACTIONS(6174),
    [anon_sym_POUNDelse] = ACTIONS(6174),
    [anon_sym_POUNDELSE] = ACTIONS(6174),
    [anon_sym_POUNDElse] = ACTIONS(6174),
    [anon_sym_POUNDelse2] = ACTIONS(6174),
    [anon_sym_POUNDELSE2] = ACTIONS(6174),
    [anon_sym_POUNDElse2] = ACTIONS(6174),
    [anon_sym_POUNDendif] = ACTIONS(6174),
    [anon_sym_POUNDENDIF] = ACTIONS(6174),
    [anon_sym_POUNDEndif] = ACTIONS(6174),
    [anon_sym_POUNDendif2] = ACTIONS(6174),
    [anon_sym_POUNDENDIF2] = ACTIONS(6174),
    [anon_sym_POUNDEndif2] = ACTIONS(6174),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6174),
    [sym_trigger_keyword] = ACTIONS(6174),
    [sym_var_keyword] = ACTIONS(6174),
    [sym_local_keyword] = ACTIONS(6174),
    [sym_internal_keyword] = ACTIONS(6174),
    [sym_protected_keyword] = ACTIONS(6174),
    [sym_event_keyword] = ACTIONS(6174),
    [sym_fields_keyword] = ACTIONS(6174),
    [sym_keys_keyword] = ACTIONS(6174),
    [sym_fieldgroups_keyword] = ACTIONS(6174),
    [sym_actions_keyword] = ACTIONS(6174),
    [sym_layout_keyword] = ACTIONS(6174),
    [sym_area_keyword] = ACTIONS(6174),
    [sym_group_keyword] = ACTIONS(6174),
    [sym_repeater_keyword] = ACTIONS(6174),
    [sym_cuegroup_keyword] = ACTIONS(6174),
    [sym_fixed_keyword] = ACTIONS(6174),
    [sym_grid_keyword] = ACTIONS(6174),
    [sym_part_keyword] = ACTIONS(6174),
    [sym_systempart_keyword] = ACTIONS(6174),
    [sym_usercontrol_keyword] = ACTIONS(6174),
    [sym_dataset_keyword] = ACTIONS(6174),
    [sym_elements_keyword] = ACTIONS(6174),
    [sym_dataitem_keyword] = ACTIONS(6174),
    [sym_column_keyword] = ACTIONS(6174),
    [sym_filter_keyword] = ACTIONS(6174),
    [sym_labels_keyword] = ACTIONS(6174),
    [sym_rendering_keyword] = ACTIONS(6174),
    [sym_requestpage_keyword] = ACTIONS(6174),
    [sym_schema_keyword] = ACTIONS(6174),
    [sym_views_keyword] = ACTIONS(6174),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6174),
    [sym_preproc_open] = ACTIONS(6174),
    [sym_preproc_close] = ACTIONS(6174),
  },
  [STATE(4289)] = {
    [anon_sym_SEMI] = ACTIONS(9275),
    [aux_sym_where_condition_token1] = ACTIONS(9277),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9275),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9275),
    [anon_sym_LBRACK] = ACTIONS(9275),
    [aux_sym_basic_type_token6] = ACTIONS(9277),
    [aux_sym_basic_type_token22] = ACTIONS(9277),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9275),
    [aux_sym_addafter_modification_token1] = ACTIONS(9275),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9275),
    [aux_sym_modify_modification_token1] = ACTIONS(9275),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9275),
    [aux_sym_movelast_modification_token1] = ACTIONS(9275),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9275),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9275),
    [aux_sym_separator_action_token1] = ACTIONS(9275),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9275),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9275),
    [anon_sym_POUNDif] = ACTIONS(9275),
    [anon_sym_POUNDIF] = ACTIONS(9275),
    [anon_sym_POUNDIf] = ACTIONS(9275),
    [anon_sym_POUNDelif] = ACTIONS(9275),
    [anon_sym_POUNDELIF] = ACTIONS(9275),
    [anon_sym_POUNDElif] = ACTIONS(9275),
    [anon_sym_POUNDelse] = ACTIONS(9275),
    [anon_sym_POUNDELSE] = ACTIONS(9275),
    [anon_sym_POUNDElse] = ACTIONS(9275),
    [anon_sym_POUNDelse2] = ACTIONS(9275),
    [anon_sym_POUNDELSE2] = ACTIONS(9275),
    [anon_sym_POUNDElse2] = ACTIONS(9275),
    [anon_sym_POUNDendif] = ACTIONS(9275),
    [anon_sym_POUNDENDIF] = ACTIONS(9275),
    [anon_sym_POUNDEndif] = ACTIONS(9275),
    [anon_sym_POUNDendif2] = ACTIONS(9275),
    [anon_sym_POUNDENDIF2] = ACTIONS(9275),
    [anon_sym_POUNDEndif2] = ACTIONS(9275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9275),
    [sym_trigger_keyword] = ACTIONS(9275),
    [sym_var_keyword] = ACTIONS(9275),
    [sym_local_keyword] = ACTIONS(9275),
    [sym_internal_keyword] = ACTIONS(9275),
    [sym_protected_keyword] = ACTIONS(9275),
    [sym_event_keyword] = ACTIONS(9275),
    [sym_fields_keyword] = ACTIONS(9275),
    [sym_keys_keyword] = ACTIONS(9275),
    [sym_fieldgroups_keyword] = ACTIONS(9275),
    [sym_actions_keyword] = ACTIONS(9275),
    [sym_layout_keyword] = ACTIONS(9275),
    [sym_area_keyword] = ACTIONS(9275),
    [sym_group_keyword] = ACTIONS(9275),
    [sym_repeater_keyword] = ACTIONS(9275),
    [sym_cuegroup_keyword] = ACTIONS(9275),
    [sym_fixed_keyword] = ACTIONS(9275),
    [sym_grid_keyword] = ACTIONS(9275),
    [sym_part_keyword] = ACTIONS(9275),
    [sym_systempart_keyword] = ACTIONS(9275),
    [sym_usercontrol_keyword] = ACTIONS(9275),
    [sym_dataset_keyword] = ACTIONS(9275),
    [sym_elements_keyword] = ACTIONS(9275),
    [sym_dataitem_keyword] = ACTIONS(9275),
    [sym_column_keyword] = ACTIONS(9275),
    [sym_filter_keyword] = ACTIONS(9275),
    [sym_labels_keyword] = ACTIONS(9275),
    [sym_rendering_keyword] = ACTIONS(9275),
    [sym_requestpage_keyword] = ACTIONS(9275),
    [sym_schema_keyword] = ACTIONS(9275),
    [sym_views_keyword] = ACTIONS(9275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9275),
    [sym_preproc_open] = ACTIONS(9275),
    [sym_preproc_close] = ACTIONS(9275),
  },
  [STATE(4290)] = {
    [anon_sym_SEMI] = ACTIONS(9351),
    [aux_sym_where_condition_token1] = ACTIONS(9353),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9351),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9351),
    [anon_sym_LBRACK] = ACTIONS(9351),
    [aux_sym_basic_type_token6] = ACTIONS(9353),
    [aux_sym_basic_type_token22] = ACTIONS(9353),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9351),
    [aux_sym_addafter_modification_token1] = ACTIONS(9351),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9351),
    [aux_sym_modify_modification_token1] = ACTIONS(9351),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9351),
    [aux_sym_movelast_modification_token1] = ACTIONS(9351),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9351),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9351),
    [aux_sym_separator_action_token1] = ACTIONS(9351),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9351),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9351),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9351),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9351),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9351),
    [anon_sym_POUNDif] = ACTIONS(9351),
    [anon_sym_POUNDIF] = ACTIONS(9351),
    [anon_sym_POUNDIf] = ACTIONS(9351),
    [anon_sym_POUNDelif] = ACTIONS(9351),
    [anon_sym_POUNDELIF] = ACTIONS(9351),
    [anon_sym_POUNDElif] = ACTIONS(9351),
    [anon_sym_POUNDelse] = ACTIONS(9351),
    [anon_sym_POUNDELSE] = ACTIONS(9351),
    [anon_sym_POUNDElse] = ACTIONS(9351),
    [anon_sym_POUNDelse2] = ACTIONS(9351),
    [anon_sym_POUNDELSE2] = ACTIONS(9351),
    [anon_sym_POUNDElse2] = ACTIONS(9351),
    [anon_sym_POUNDendif] = ACTIONS(9351),
    [anon_sym_POUNDENDIF] = ACTIONS(9351),
    [anon_sym_POUNDEndif] = ACTIONS(9351),
    [anon_sym_POUNDendif2] = ACTIONS(9351),
    [anon_sym_POUNDENDIF2] = ACTIONS(9351),
    [anon_sym_POUNDEndif2] = ACTIONS(9351),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9351),
    [sym_trigger_keyword] = ACTIONS(9351),
    [sym_var_keyword] = ACTIONS(9351),
    [sym_local_keyword] = ACTIONS(9351),
    [sym_internal_keyword] = ACTIONS(9351),
    [sym_protected_keyword] = ACTIONS(9351),
    [sym_event_keyword] = ACTIONS(9351),
    [sym_fields_keyword] = ACTIONS(9351),
    [sym_keys_keyword] = ACTIONS(9351),
    [sym_fieldgroups_keyword] = ACTIONS(9351),
    [sym_actions_keyword] = ACTIONS(9351),
    [sym_layout_keyword] = ACTIONS(9351),
    [sym_area_keyword] = ACTIONS(9351),
    [sym_group_keyword] = ACTIONS(9351),
    [sym_repeater_keyword] = ACTIONS(9351),
    [sym_cuegroup_keyword] = ACTIONS(9351),
    [sym_fixed_keyword] = ACTIONS(9351),
    [sym_grid_keyword] = ACTIONS(9351),
    [sym_part_keyword] = ACTIONS(9351),
    [sym_systempart_keyword] = ACTIONS(9351),
    [sym_usercontrol_keyword] = ACTIONS(9351),
    [sym_dataset_keyword] = ACTIONS(9351),
    [sym_elements_keyword] = ACTIONS(9351),
    [sym_dataitem_keyword] = ACTIONS(9351),
    [sym_column_keyword] = ACTIONS(9351),
    [sym_filter_keyword] = ACTIONS(9351),
    [sym_labels_keyword] = ACTIONS(9351),
    [sym_rendering_keyword] = ACTIONS(9351),
    [sym_requestpage_keyword] = ACTIONS(9351),
    [sym_schema_keyword] = ACTIONS(9351),
    [sym_views_keyword] = ACTIONS(9351),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9351),
    [sym_preproc_open] = ACTIONS(9351),
    [sym_preproc_close] = ACTIONS(9351),
  },
  [STATE(4291)] = {
    [anon_sym_SEMI] = ACTIONS(9235),
    [aux_sym_where_condition_token1] = ACTIONS(9237),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9235),
    [anon_sym_LBRACK] = ACTIONS(9235),
    [aux_sym_basic_type_token6] = ACTIONS(9237),
    [aux_sym_basic_type_token22] = ACTIONS(9237),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9235),
    [aux_sym_addafter_modification_token1] = ACTIONS(9235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9235),
    [aux_sym_modify_modification_token1] = ACTIONS(9235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9235),
    [aux_sym_movelast_modification_token1] = ACTIONS(9235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9235),
    [aux_sym_separator_action_token1] = ACTIONS(9235),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9235),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9235),
    [anon_sym_POUNDif] = ACTIONS(9235),
    [anon_sym_POUNDIF] = ACTIONS(9235),
    [anon_sym_POUNDIf] = ACTIONS(9235),
    [anon_sym_POUNDelif] = ACTIONS(9235),
    [anon_sym_POUNDELIF] = ACTIONS(9235),
    [anon_sym_POUNDElif] = ACTIONS(9235),
    [anon_sym_POUNDelse] = ACTIONS(9235),
    [anon_sym_POUNDELSE] = ACTIONS(9235),
    [anon_sym_POUNDElse] = ACTIONS(9235),
    [anon_sym_POUNDelse2] = ACTIONS(9235),
    [anon_sym_POUNDELSE2] = ACTIONS(9235),
    [anon_sym_POUNDElse2] = ACTIONS(9235),
    [anon_sym_POUNDendif] = ACTIONS(9235),
    [anon_sym_POUNDENDIF] = ACTIONS(9235),
    [anon_sym_POUNDEndif] = ACTIONS(9235),
    [anon_sym_POUNDendif2] = ACTIONS(9235),
    [anon_sym_POUNDENDIF2] = ACTIONS(9235),
    [anon_sym_POUNDEndif2] = ACTIONS(9235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9235),
    [sym_trigger_keyword] = ACTIONS(9235),
    [sym_var_keyword] = ACTIONS(9235),
    [sym_local_keyword] = ACTIONS(9235),
    [sym_internal_keyword] = ACTIONS(9235),
    [sym_protected_keyword] = ACTIONS(9235),
    [sym_event_keyword] = ACTIONS(9235),
    [sym_fields_keyword] = ACTIONS(9235),
    [sym_keys_keyword] = ACTIONS(9235),
    [sym_fieldgroups_keyword] = ACTIONS(9235),
    [sym_actions_keyword] = ACTIONS(9235),
    [sym_layout_keyword] = ACTIONS(9235),
    [sym_area_keyword] = ACTIONS(9235),
    [sym_group_keyword] = ACTIONS(9235),
    [sym_repeater_keyword] = ACTIONS(9235),
    [sym_cuegroup_keyword] = ACTIONS(9235),
    [sym_fixed_keyword] = ACTIONS(9235),
    [sym_grid_keyword] = ACTIONS(9235),
    [sym_part_keyword] = ACTIONS(9235),
    [sym_systempart_keyword] = ACTIONS(9235),
    [sym_usercontrol_keyword] = ACTIONS(9235),
    [sym_dataset_keyword] = ACTIONS(9235),
    [sym_elements_keyword] = ACTIONS(9235),
    [sym_dataitem_keyword] = ACTIONS(9235),
    [sym_column_keyword] = ACTIONS(9235),
    [sym_filter_keyword] = ACTIONS(9235),
    [sym_labels_keyword] = ACTIONS(9235),
    [sym_rendering_keyword] = ACTIONS(9235),
    [sym_requestpage_keyword] = ACTIONS(9235),
    [sym_schema_keyword] = ACTIONS(9235),
    [sym_views_keyword] = ACTIONS(9235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9235),
    [sym_preproc_open] = ACTIONS(9235),
    [sym_preproc_close] = ACTIONS(9235),
  },
  [STATE(4292)] = {
    [anon_sym_SEMI] = ACTIONS(9235),
    [aux_sym_where_condition_token1] = ACTIONS(9237),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9235),
    [anon_sym_LBRACK] = ACTIONS(9235),
    [aux_sym_basic_type_token6] = ACTIONS(9237),
    [aux_sym_basic_type_token22] = ACTIONS(9237),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9235),
    [aux_sym_addafter_modification_token1] = ACTIONS(9235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9235),
    [aux_sym_modify_modification_token1] = ACTIONS(9235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9235),
    [aux_sym_movelast_modification_token1] = ACTIONS(9235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9235),
    [aux_sym_separator_action_token1] = ACTIONS(9235),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9235),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9235),
    [anon_sym_POUNDif] = ACTIONS(9235),
    [anon_sym_POUNDIF] = ACTIONS(9235),
    [anon_sym_POUNDIf] = ACTIONS(9235),
    [anon_sym_POUNDelif] = ACTIONS(9235),
    [anon_sym_POUNDELIF] = ACTIONS(9235),
    [anon_sym_POUNDElif] = ACTIONS(9235),
    [anon_sym_POUNDelse] = ACTIONS(9235),
    [anon_sym_POUNDELSE] = ACTIONS(9235),
    [anon_sym_POUNDElse] = ACTIONS(9235),
    [anon_sym_POUNDelse2] = ACTIONS(9235),
    [anon_sym_POUNDELSE2] = ACTIONS(9235),
    [anon_sym_POUNDElse2] = ACTIONS(9235),
    [anon_sym_POUNDendif] = ACTIONS(9235),
    [anon_sym_POUNDENDIF] = ACTIONS(9235),
    [anon_sym_POUNDEndif] = ACTIONS(9235),
    [anon_sym_POUNDendif2] = ACTIONS(9235),
    [anon_sym_POUNDENDIF2] = ACTIONS(9235),
    [anon_sym_POUNDEndif2] = ACTIONS(9235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9235),
    [sym_trigger_keyword] = ACTIONS(9235),
    [sym_var_keyword] = ACTIONS(9235),
    [sym_local_keyword] = ACTIONS(9235),
    [sym_internal_keyword] = ACTIONS(9235),
    [sym_protected_keyword] = ACTIONS(9235),
    [sym_event_keyword] = ACTIONS(9235),
    [sym_fields_keyword] = ACTIONS(9235),
    [sym_keys_keyword] = ACTIONS(9235),
    [sym_fieldgroups_keyword] = ACTIONS(9235),
    [sym_actions_keyword] = ACTIONS(9235),
    [sym_layout_keyword] = ACTIONS(9235),
    [sym_area_keyword] = ACTIONS(9235),
    [sym_group_keyword] = ACTIONS(9235),
    [sym_repeater_keyword] = ACTIONS(9235),
    [sym_cuegroup_keyword] = ACTIONS(9235),
    [sym_fixed_keyword] = ACTIONS(9235),
    [sym_grid_keyword] = ACTIONS(9235),
    [sym_part_keyword] = ACTIONS(9235),
    [sym_systempart_keyword] = ACTIONS(9235),
    [sym_usercontrol_keyword] = ACTIONS(9235),
    [sym_dataset_keyword] = ACTIONS(9235),
    [sym_elements_keyword] = ACTIONS(9235),
    [sym_dataitem_keyword] = ACTIONS(9235),
    [sym_column_keyword] = ACTIONS(9235),
    [sym_filter_keyword] = ACTIONS(9235),
    [sym_labels_keyword] = ACTIONS(9235),
    [sym_rendering_keyword] = ACTIONS(9235),
    [sym_requestpage_keyword] = ACTIONS(9235),
    [sym_schema_keyword] = ACTIONS(9235),
    [sym_views_keyword] = ACTIONS(9235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9235),
    [sym_preproc_open] = ACTIONS(9235),
    [sym_preproc_close] = ACTIONS(9235),
  },
  [STATE(4293)] = {
    [anon_sym_SEMI] = ACTIONS(9235),
    [aux_sym_where_condition_token1] = ACTIONS(9237),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9235),
    [anon_sym_LBRACK] = ACTIONS(9235),
    [aux_sym_basic_type_token6] = ACTIONS(9237),
    [aux_sym_basic_type_token22] = ACTIONS(9237),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9235),
    [aux_sym_addafter_modification_token1] = ACTIONS(9235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9235),
    [aux_sym_modify_modification_token1] = ACTIONS(9235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9235),
    [aux_sym_movelast_modification_token1] = ACTIONS(9235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9235),
    [aux_sym_separator_action_token1] = ACTIONS(9235),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9235),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9235),
    [anon_sym_POUNDif] = ACTIONS(9235),
    [anon_sym_POUNDIF] = ACTIONS(9235),
    [anon_sym_POUNDIf] = ACTIONS(9235),
    [anon_sym_POUNDelif] = ACTIONS(9235),
    [anon_sym_POUNDELIF] = ACTIONS(9235),
    [anon_sym_POUNDElif] = ACTIONS(9235),
    [anon_sym_POUNDelse] = ACTIONS(9235),
    [anon_sym_POUNDELSE] = ACTIONS(9235),
    [anon_sym_POUNDElse] = ACTIONS(9235),
    [anon_sym_POUNDelse2] = ACTIONS(9235),
    [anon_sym_POUNDELSE2] = ACTIONS(9235),
    [anon_sym_POUNDElse2] = ACTIONS(9235),
    [anon_sym_POUNDendif] = ACTIONS(9235),
    [anon_sym_POUNDENDIF] = ACTIONS(9235),
    [anon_sym_POUNDEndif] = ACTIONS(9235),
    [anon_sym_POUNDendif2] = ACTIONS(9235),
    [anon_sym_POUNDENDIF2] = ACTIONS(9235),
    [anon_sym_POUNDEndif2] = ACTIONS(9235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9235),
    [sym_trigger_keyword] = ACTIONS(9235),
    [sym_var_keyword] = ACTIONS(9235),
    [sym_local_keyword] = ACTIONS(9235),
    [sym_internal_keyword] = ACTIONS(9235),
    [sym_protected_keyword] = ACTIONS(9235),
    [sym_event_keyword] = ACTIONS(9235),
    [sym_fields_keyword] = ACTIONS(9235),
    [sym_keys_keyword] = ACTIONS(9235),
    [sym_fieldgroups_keyword] = ACTIONS(9235),
    [sym_actions_keyword] = ACTIONS(9235),
    [sym_layout_keyword] = ACTIONS(9235),
    [sym_area_keyword] = ACTIONS(9235),
    [sym_group_keyword] = ACTIONS(9235),
    [sym_repeater_keyword] = ACTIONS(9235),
    [sym_cuegroup_keyword] = ACTIONS(9235),
    [sym_fixed_keyword] = ACTIONS(9235),
    [sym_grid_keyword] = ACTIONS(9235),
    [sym_part_keyword] = ACTIONS(9235),
    [sym_systempart_keyword] = ACTIONS(9235),
    [sym_usercontrol_keyword] = ACTIONS(9235),
    [sym_dataset_keyword] = ACTIONS(9235),
    [sym_elements_keyword] = ACTIONS(9235),
    [sym_dataitem_keyword] = ACTIONS(9235),
    [sym_column_keyword] = ACTIONS(9235),
    [sym_filter_keyword] = ACTIONS(9235),
    [sym_labels_keyword] = ACTIONS(9235),
    [sym_rendering_keyword] = ACTIONS(9235),
    [sym_requestpage_keyword] = ACTIONS(9235),
    [sym_schema_keyword] = ACTIONS(9235),
    [sym_views_keyword] = ACTIONS(9235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9235),
    [sym_preproc_open] = ACTIONS(9235),
    [sym_preproc_close] = ACTIONS(9235),
  },
  [STATE(4294)] = {
    [anon_sym_SEMI] = ACTIONS(9275),
    [aux_sym_where_condition_token1] = ACTIONS(9277),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9275),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9275),
    [anon_sym_LBRACK] = ACTIONS(9275),
    [aux_sym_basic_type_token6] = ACTIONS(9277),
    [aux_sym_basic_type_token22] = ACTIONS(9277),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9275),
    [aux_sym_addafter_modification_token1] = ACTIONS(9275),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9275),
    [aux_sym_modify_modification_token1] = ACTIONS(9275),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9275),
    [aux_sym_movelast_modification_token1] = ACTIONS(9275),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9275),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9275),
    [aux_sym_separator_action_token1] = ACTIONS(9275),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9275),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9275),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9275),
    [anon_sym_POUNDif] = ACTIONS(9275),
    [anon_sym_POUNDIF] = ACTIONS(9275),
    [anon_sym_POUNDIf] = ACTIONS(9275),
    [anon_sym_POUNDelif] = ACTIONS(9275),
    [anon_sym_POUNDELIF] = ACTIONS(9275),
    [anon_sym_POUNDElif] = ACTIONS(9275),
    [anon_sym_POUNDelse] = ACTIONS(9275),
    [anon_sym_POUNDELSE] = ACTIONS(9275),
    [anon_sym_POUNDElse] = ACTIONS(9275),
    [anon_sym_POUNDelse2] = ACTIONS(9275),
    [anon_sym_POUNDELSE2] = ACTIONS(9275),
    [anon_sym_POUNDElse2] = ACTIONS(9275),
    [anon_sym_POUNDendif] = ACTIONS(9275),
    [anon_sym_POUNDENDIF] = ACTIONS(9275),
    [anon_sym_POUNDEndif] = ACTIONS(9275),
    [anon_sym_POUNDendif2] = ACTIONS(9275),
    [anon_sym_POUNDENDIF2] = ACTIONS(9275),
    [anon_sym_POUNDEndif2] = ACTIONS(9275),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9275),
    [sym_trigger_keyword] = ACTIONS(9275),
    [sym_var_keyword] = ACTIONS(9275),
    [sym_local_keyword] = ACTIONS(9275),
    [sym_internal_keyword] = ACTIONS(9275),
    [sym_protected_keyword] = ACTIONS(9275),
    [sym_event_keyword] = ACTIONS(9275),
    [sym_fields_keyword] = ACTIONS(9275),
    [sym_keys_keyword] = ACTIONS(9275),
    [sym_fieldgroups_keyword] = ACTIONS(9275),
    [sym_actions_keyword] = ACTIONS(9275),
    [sym_layout_keyword] = ACTIONS(9275),
    [sym_area_keyword] = ACTIONS(9275),
    [sym_group_keyword] = ACTIONS(9275),
    [sym_repeater_keyword] = ACTIONS(9275),
    [sym_cuegroup_keyword] = ACTIONS(9275),
    [sym_fixed_keyword] = ACTIONS(9275),
    [sym_grid_keyword] = ACTIONS(9275),
    [sym_part_keyword] = ACTIONS(9275),
    [sym_systempart_keyword] = ACTIONS(9275),
    [sym_usercontrol_keyword] = ACTIONS(9275),
    [sym_dataset_keyword] = ACTIONS(9275),
    [sym_elements_keyword] = ACTIONS(9275),
    [sym_dataitem_keyword] = ACTIONS(9275),
    [sym_column_keyword] = ACTIONS(9275),
    [sym_filter_keyword] = ACTIONS(9275),
    [sym_labels_keyword] = ACTIONS(9275),
    [sym_rendering_keyword] = ACTIONS(9275),
    [sym_requestpage_keyword] = ACTIONS(9275),
    [sym_schema_keyword] = ACTIONS(9275),
    [sym_views_keyword] = ACTIONS(9275),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9275),
    [sym_preproc_open] = ACTIONS(9275),
    [sym_preproc_close] = ACTIONS(9275),
  },
  [STATE(4295)] = {
    [anon_sym_SEMI] = ACTIONS(6178),
    [aux_sym_where_condition_token1] = ACTIONS(6176),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6178),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6178),
    [anon_sym_LBRACK] = ACTIONS(6178),
    [aux_sym_basic_type_token6] = ACTIONS(6176),
    [aux_sym_basic_type_token22] = ACTIONS(6176),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6178),
    [aux_sym_addafter_modification_token1] = ACTIONS(6178),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6178),
    [aux_sym_modify_modification_token1] = ACTIONS(6178),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6178),
    [aux_sym_movelast_modification_token1] = ACTIONS(6178),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6178),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6178),
    [aux_sym_separator_action_token1] = ACTIONS(6178),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6178),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6178),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6178),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6178),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6178),
    [anon_sym_POUNDif] = ACTIONS(6178),
    [anon_sym_POUNDIF] = ACTIONS(6178),
    [anon_sym_POUNDIf] = ACTIONS(6178),
    [anon_sym_POUNDelif] = ACTIONS(6178),
    [anon_sym_POUNDELIF] = ACTIONS(6178),
    [anon_sym_POUNDElif] = ACTIONS(6178),
    [anon_sym_POUNDelse] = ACTIONS(6178),
    [anon_sym_POUNDELSE] = ACTIONS(6178),
    [anon_sym_POUNDElse] = ACTIONS(6178),
    [anon_sym_POUNDelse2] = ACTIONS(6178),
    [anon_sym_POUNDELSE2] = ACTIONS(6178),
    [anon_sym_POUNDElse2] = ACTIONS(6178),
    [anon_sym_POUNDendif] = ACTIONS(6178),
    [anon_sym_POUNDENDIF] = ACTIONS(6178),
    [anon_sym_POUNDEndif] = ACTIONS(6178),
    [anon_sym_POUNDendif2] = ACTIONS(6178),
    [anon_sym_POUNDENDIF2] = ACTIONS(6178),
    [anon_sym_POUNDEndif2] = ACTIONS(6178),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6178),
    [sym_trigger_keyword] = ACTIONS(6178),
    [sym_var_keyword] = ACTIONS(6178),
    [sym_local_keyword] = ACTIONS(6178),
    [sym_internal_keyword] = ACTIONS(6178),
    [sym_protected_keyword] = ACTIONS(6178),
    [sym_event_keyword] = ACTIONS(6178),
    [sym_fields_keyword] = ACTIONS(6178),
    [sym_keys_keyword] = ACTIONS(6178),
    [sym_fieldgroups_keyword] = ACTIONS(6178),
    [sym_actions_keyword] = ACTIONS(6178),
    [sym_layout_keyword] = ACTIONS(6178),
    [sym_area_keyword] = ACTIONS(6178),
    [sym_group_keyword] = ACTIONS(6178),
    [sym_repeater_keyword] = ACTIONS(6178),
    [sym_cuegroup_keyword] = ACTIONS(6178),
    [sym_fixed_keyword] = ACTIONS(6178),
    [sym_grid_keyword] = ACTIONS(6178),
    [sym_part_keyword] = ACTIONS(6178),
    [sym_systempart_keyword] = ACTIONS(6178),
    [sym_usercontrol_keyword] = ACTIONS(6178),
    [sym_dataset_keyword] = ACTIONS(6178),
    [sym_elements_keyword] = ACTIONS(6178),
    [sym_dataitem_keyword] = ACTIONS(6178),
    [sym_column_keyword] = ACTIONS(6178),
    [sym_filter_keyword] = ACTIONS(6178),
    [sym_labels_keyword] = ACTIONS(6178),
    [sym_rendering_keyword] = ACTIONS(6178),
    [sym_requestpage_keyword] = ACTIONS(6178),
    [sym_schema_keyword] = ACTIONS(6178),
    [sym_views_keyword] = ACTIONS(6178),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6178),
    [sym_preproc_open] = ACTIONS(6178),
    [sym_preproc_close] = ACTIONS(6178),
  },
  [STATE(4296)] = {
    [anon_sym_SEMI] = ACTIONS(6182),
    [aux_sym_where_condition_token1] = ACTIONS(6180),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6182),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6182),
    [anon_sym_LBRACK] = ACTIONS(6182),
    [aux_sym_basic_type_token6] = ACTIONS(6180),
    [aux_sym_basic_type_token22] = ACTIONS(6180),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6182),
    [aux_sym_addafter_modification_token1] = ACTIONS(6182),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6182),
    [aux_sym_modify_modification_token1] = ACTIONS(6182),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6182),
    [aux_sym_movelast_modification_token1] = ACTIONS(6182),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6182),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6182),
    [aux_sym_separator_action_token1] = ACTIONS(6182),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6182),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6182),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6182),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6182),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6182),
    [anon_sym_POUNDif] = ACTIONS(6182),
    [anon_sym_POUNDIF] = ACTIONS(6182),
    [anon_sym_POUNDIf] = ACTIONS(6182),
    [anon_sym_POUNDelif] = ACTIONS(6182),
    [anon_sym_POUNDELIF] = ACTIONS(6182),
    [anon_sym_POUNDElif] = ACTIONS(6182),
    [anon_sym_POUNDelse] = ACTIONS(6182),
    [anon_sym_POUNDELSE] = ACTIONS(6182),
    [anon_sym_POUNDElse] = ACTIONS(6182),
    [anon_sym_POUNDelse2] = ACTIONS(6182),
    [anon_sym_POUNDELSE2] = ACTIONS(6182),
    [anon_sym_POUNDElse2] = ACTIONS(6182),
    [anon_sym_POUNDendif] = ACTIONS(6182),
    [anon_sym_POUNDENDIF] = ACTIONS(6182),
    [anon_sym_POUNDEndif] = ACTIONS(6182),
    [anon_sym_POUNDendif2] = ACTIONS(6182),
    [anon_sym_POUNDENDIF2] = ACTIONS(6182),
    [anon_sym_POUNDEndif2] = ACTIONS(6182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6182),
    [sym_trigger_keyword] = ACTIONS(6182),
    [sym_var_keyword] = ACTIONS(6182),
    [sym_local_keyword] = ACTIONS(6182),
    [sym_internal_keyword] = ACTIONS(6182),
    [sym_protected_keyword] = ACTIONS(6182),
    [sym_event_keyword] = ACTIONS(6182),
    [sym_fields_keyword] = ACTIONS(6182),
    [sym_keys_keyword] = ACTIONS(6182),
    [sym_fieldgroups_keyword] = ACTIONS(6182),
    [sym_actions_keyword] = ACTIONS(6182),
    [sym_layout_keyword] = ACTIONS(6182),
    [sym_area_keyword] = ACTIONS(6182),
    [sym_group_keyword] = ACTIONS(6182),
    [sym_repeater_keyword] = ACTIONS(6182),
    [sym_cuegroup_keyword] = ACTIONS(6182),
    [sym_fixed_keyword] = ACTIONS(6182),
    [sym_grid_keyword] = ACTIONS(6182),
    [sym_part_keyword] = ACTIONS(6182),
    [sym_systempart_keyword] = ACTIONS(6182),
    [sym_usercontrol_keyword] = ACTIONS(6182),
    [sym_dataset_keyword] = ACTIONS(6182),
    [sym_elements_keyword] = ACTIONS(6182),
    [sym_dataitem_keyword] = ACTIONS(6182),
    [sym_column_keyword] = ACTIONS(6182),
    [sym_filter_keyword] = ACTIONS(6182),
    [sym_labels_keyword] = ACTIONS(6182),
    [sym_rendering_keyword] = ACTIONS(6182),
    [sym_requestpage_keyword] = ACTIONS(6182),
    [sym_schema_keyword] = ACTIONS(6182),
    [sym_views_keyword] = ACTIONS(6182),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6182),
    [sym_preproc_open] = ACTIONS(6182),
    [sym_preproc_close] = ACTIONS(6182),
  },
  [STATE(4297)] = {
    [anon_sym_SEMI] = ACTIONS(6186),
    [aux_sym_where_condition_token1] = ACTIONS(6184),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6186),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6186),
    [anon_sym_LBRACK] = ACTIONS(6186),
    [aux_sym_basic_type_token6] = ACTIONS(6184),
    [aux_sym_basic_type_token22] = ACTIONS(6184),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6186),
    [aux_sym_addafter_modification_token1] = ACTIONS(6186),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6186),
    [aux_sym_modify_modification_token1] = ACTIONS(6186),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6186),
    [aux_sym_movelast_modification_token1] = ACTIONS(6186),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6186),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6186),
    [aux_sym_separator_action_token1] = ACTIONS(6186),
    [aux_sym_actionref_declaration_token1] = ACTIONS(6186),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(6186),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(6186),
    [aux_sym_customaction_declaration_token1] = ACTIONS(6186),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6186),
    [anon_sym_POUNDif] = ACTIONS(6186),
    [anon_sym_POUNDIF] = ACTIONS(6186),
    [anon_sym_POUNDIf] = ACTIONS(6186),
    [anon_sym_POUNDelif] = ACTIONS(6186),
    [anon_sym_POUNDELIF] = ACTIONS(6186),
    [anon_sym_POUNDElif] = ACTIONS(6186),
    [anon_sym_POUNDelse] = ACTIONS(6186),
    [anon_sym_POUNDELSE] = ACTIONS(6186),
    [anon_sym_POUNDElse] = ACTIONS(6186),
    [anon_sym_POUNDelse2] = ACTIONS(6186),
    [anon_sym_POUNDELSE2] = ACTIONS(6186),
    [anon_sym_POUNDElse2] = ACTIONS(6186),
    [anon_sym_POUNDendif] = ACTIONS(6186),
    [anon_sym_POUNDENDIF] = ACTIONS(6186),
    [anon_sym_POUNDEndif] = ACTIONS(6186),
    [anon_sym_POUNDendif2] = ACTIONS(6186),
    [anon_sym_POUNDENDIF2] = ACTIONS(6186),
    [anon_sym_POUNDEndif2] = ACTIONS(6186),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6186),
    [sym_trigger_keyword] = ACTIONS(6186),
    [sym_var_keyword] = ACTIONS(6186),
    [sym_local_keyword] = ACTIONS(6186),
    [sym_internal_keyword] = ACTIONS(6186),
    [sym_protected_keyword] = ACTIONS(6186),
    [sym_event_keyword] = ACTIONS(6186),
    [sym_fields_keyword] = ACTIONS(6186),
    [sym_keys_keyword] = ACTIONS(6186),
    [sym_fieldgroups_keyword] = ACTIONS(6186),
    [sym_actions_keyword] = ACTIONS(6186),
    [sym_layout_keyword] = ACTIONS(6186),
    [sym_area_keyword] = ACTIONS(6186),
    [sym_group_keyword] = ACTIONS(6186),
    [sym_repeater_keyword] = ACTIONS(6186),
    [sym_cuegroup_keyword] = ACTIONS(6186),
    [sym_fixed_keyword] = ACTIONS(6186),
    [sym_grid_keyword] = ACTIONS(6186),
    [sym_part_keyword] = ACTIONS(6186),
    [sym_systempart_keyword] = ACTIONS(6186),
    [sym_usercontrol_keyword] = ACTIONS(6186),
    [sym_dataset_keyword] = ACTIONS(6186),
    [sym_elements_keyword] = ACTIONS(6186),
    [sym_dataitem_keyword] = ACTIONS(6186),
    [sym_column_keyword] = ACTIONS(6186),
    [sym_filter_keyword] = ACTIONS(6186),
    [sym_labels_keyword] = ACTIONS(6186),
    [sym_rendering_keyword] = ACTIONS(6186),
    [sym_requestpage_keyword] = ACTIONS(6186),
    [sym_schema_keyword] = ACTIONS(6186),
    [sym_views_keyword] = ACTIONS(6186),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6186),
    [sym_preproc_open] = ACTIONS(6186),
    [sym_preproc_close] = ACTIONS(6186),
  },
  [STATE(4298)] = {
    [anon_sym_SEMI] = ACTIONS(9247),
    [aux_sym_where_condition_token1] = ACTIONS(9249),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9247),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9247),
    [anon_sym_LBRACK] = ACTIONS(9247),
    [aux_sym_basic_type_token6] = ACTIONS(9249),
    [aux_sym_basic_type_token22] = ACTIONS(9249),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9247),
    [aux_sym_addafter_modification_token1] = ACTIONS(9247),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9247),
    [aux_sym_modify_modification_token1] = ACTIONS(9247),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9247),
    [aux_sym_movelast_modification_token1] = ACTIONS(9247),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9247),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9247),
    [aux_sym_separator_action_token1] = ACTIONS(9247),
    [aux_sym_actionref_declaration_token1] = ACTIONS(9247),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(9247),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(9247),
    [aux_sym_customaction_declaration_token1] = ACTIONS(9247),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9247),
    [anon_sym_POUNDif] = ACTIONS(9247),
    [anon_sym_POUNDIF] = ACTIONS(9247),
    [anon_sym_POUNDIf] = ACTIONS(9247),
    [anon_sym_POUNDelif] = ACTIONS(9247),
    [anon_sym_POUNDELIF] = ACTIONS(9247),
    [anon_sym_POUNDElif] = ACTIONS(9247),
    [anon_sym_POUNDelse] = ACTIONS(9247),
    [anon_sym_POUNDELSE] = ACTIONS(9247),
    [anon_sym_POUNDElse] = ACTIONS(9247),
    [anon_sym_POUNDelse2] = ACTIONS(9247),
    [anon_sym_POUNDELSE2] = ACTIONS(9247),
    [anon_sym_POUNDElse2] = ACTIONS(9247),
    [anon_sym_POUNDendif] = ACTIONS(9247),
    [anon_sym_POUNDENDIF] = ACTIONS(9247),
    [anon_sym_POUNDEndif] = ACTIONS(9247),
    [anon_sym_POUNDendif2] = ACTIONS(9247),
    [anon_sym_POUNDENDIF2] = ACTIONS(9247),
    [anon_sym_POUNDEndif2] = ACTIONS(9247),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9247),
    [sym_trigger_keyword] = ACTIONS(9247),
    [sym_var_keyword] = ACTIONS(9247),
    [sym_local_keyword] = ACTIONS(9247),
    [sym_internal_keyword] = ACTIONS(9247),
    [sym_protected_keyword] = ACTIONS(9247),
    [sym_event_keyword] = ACTIONS(9247),
    [sym_fields_keyword] = ACTIONS(9247),
    [sym_keys_keyword] = ACTIONS(9247),
    [sym_fieldgroups_keyword] = ACTIONS(9247),
    [sym_actions_keyword] = ACTIONS(9247),
    [sym_layout_keyword] = ACTIONS(9247),
    [sym_area_keyword] = ACTIONS(9247),
    [sym_group_keyword] = ACTIONS(9247),
    [sym_repeater_keyword] = ACTIONS(9247),
    [sym_cuegroup_keyword] = ACTIONS(9247),
    [sym_fixed_keyword] = ACTIONS(9247),
    [sym_grid_keyword] = ACTIONS(9247),
    [sym_part_keyword] = ACTIONS(9247),
    [sym_systempart_keyword] = ACTIONS(9247),
    [sym_usercontrol_keyword] = ACTIONS(9247),
    [sym_dataset_keyword] = ACTIONS(9247),
    [sym_elements_keyword] = ACTIONS(9247),
    [sym_dataitem_keyword] = ACTIONS(9247),
    [sym_column_keyword] = ACTIONS(9247),
    [sym_filter_keyword] = ACTIONS(9247),
    [sym_labels_keyword] = ACTIONS(9247),
    [sym_rendering_keyword] = ACTIONS(9247),
    [sym_requestpage_keyword] = ACTIONS(9247),
    [sym_schema_keyword] = ACTIONS(9247),
    [sym_views_keyword] = ACTIONS(9247),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9247),
    [sym_preproc_open] = ACTIONS(9247),
    [sym_preproc_close] = ACTIONS(9247),
  },
  [STATE(4299)] = {
    [sym_identifier] = ACTIONS(8436),
    [anon_sym_SEMI] = ACTIONS(8434),
    [aux_sym_where_condition_token1] = ACTIONS(8436),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8436),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8436),
    [anon_sym_LBRACK] = ACTIONS(8434),
    [aux_sym_basic_type_token22] = ACTIONS(8436),
    [aux_sym_basic_type_token53] = ACTIONS(8436),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8436),
    [aux_sym_modify_modification_token1] = ACTIONS(8436),
    [aux_sym_separator_action_token1] = ACTIONS(8436),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8436),
    [aux_sym_type_declaration_token1] = ACTIONS(8436),
    [anon_sym_POUNDif] = ACTIONS(8434),
    [anon_sym_POUNDIF] = ACTIONS(8434),
    [anon_sym_POUNDIf] = ACTIONS(8434),
    [anon_sym_POUNDelif] = ACTIONS(8434),
    [anon_sym_POUNDELIF] = ACTIONS(8434),
    [anon_sym_POUNDElif] = ACTIONS(8434),
    [anon_sym_POUNDelse] = ACTIONS(8434),
    [anon_sym_POUNDELSE] = ACTIONS(8434),
    [anon_sym_POUNDElse] = ACTIONS(8434),
    [anon_sym_POUNDelse2] = ACTIONS(8434),
    [anon_sym_POUNDELSE2] = ACTIONS(8434),
    [anon_sym_POUNDElse2] = ACTIONS(8434),
    [anon_sym_POUNDendif] = ACTIONS(8434),
    [anon_sym_POUNDENDIF] = ACTIONS(8434),
    [anon_sym_POUNDEndif] = ACTIONS(8434),
    [anon_sym_POUNDendif2] = ACTIONS(8434),
    [anon_sym_POUNDENDIF2] = ACTIONS(8434),
    [anon_sym_POUNDEndif2] = ACTIONS(8434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8436),
    [sym_page_keyword] = ACTIONS(8436),
    [anon_sym_codeunit] = ACTIONS(8436),
    [anon_sym_CODEUNIT] = ACTIONS(8436),
    [anon_sym_Codeunit] = ACTIONS(8436),
    [anon_sym_CodeUnit] = ACTIONS(8436),
    [anon_sym_COdeunit] = ACTIONS(8436),
    [anon_sym_codeUnit] = ACTIONS(8436),
    [sym_report_keyword] = ACTIONS(8436),
    [sym_query_keyword] = ACTIONS(8436),
    [anon_sym_xmlport] = ACTIONS(8436),
    [anon_sym_XMLPORT] = ACTIONS(8436),
    [anon_sym_Xmlport] = ACTIONS(8436),
    [anon_sym_XMLport] = ACTIONS(8436),
    [anon_sym_XMLPort] = ACTIONS(8436),
    [anon_sym_XmlPort] = ACTIONS(8436),
    [sym_procedure_keyword] = ACTIONS(8436),
    [sym_trigger_keyword] = ACTIONS(8436),
    [sym_var_keyword] = ACTIONS(8436),
    [sym_local_keyword] = ACTIONS(8436),
    [sym_internal_keyword] = ACTIONS(8436),
    [sym_protected_keyword] = ACTIONS(8436),
    [sym_event_keyword] = ACTIONS(8436),
    [sym_fields_keyword] = ACTIONS(8436),
    [sym_keys_keyword] = ACTIONS(8436),
    [sym_key_keyword] = ACTIONS(8436),
    [sym_fieldgroups_keyword] = ACTIONS(8436),
    [sym_actions_keyword] = ACTIONS(8436),
    [sym_layout_keyword] = ACTIONS(8436),
    [sym_dataset_keyword] = ACTIONS(8436),
    [sym_elements_keyword] = ACTIONS(8436),
    [sym_labels_keyword] = ACTIONS(8436),
    [sym_rendering_keyword] = ACTIONS(8436),
    [sym_requestpage_keyword] = ACTIONS(8436),
    [sym_schema_keyword] = ACTIONS(8436),
    [sym_views_keyword] = ACTIONS(8436),
    [sym_quoted_identifier] = ACTIONS(8434),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8434),
    [sym_preproc_open] = ACTIONS(8434),
    [sym_preproc_close] = ACTIONS(8434),
    [sym_var_attribute_open] = ACTIONS(8434),
  },
  [STATE(4300)] = {
    [sym_identifier] = ACTIONS(7787),
    [anon_sym_SEMI] = ACTIONS(7785),
    [aux_sym_where_condition_token1] = ACTIONS(7787),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7787),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7787),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_basic_type_token22] = ACTIONS(7787),
    [aux_sym_basic_type_token53] = ACTIONS(7787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7787),
    [aux_sym_modify_modification_token1] = ACTIONS(7787),
    [aux_sym_separator_action_token1] = ACTIONS(7787),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7787),
    [aux_sym_type_declaration_token1] = ACTIONS(7787),
    [anon_sym_POUNDif] = ACTIONS(7785),
    [anon_sym_POUNDIF] = ACTIONS(7785),
    [anon_sym_POUNDIf] = ACTIONS(7785),
    [anon_sym_POUNDelif] = ACTIONS(7785),
    [anon_sym_POUNDELIF] = ACTIONS(7785),
    [anon_sym_POUNDElif] = ACTIONS(7785),
    [anon_sym_POUNDelse] = ACTIONS(7785),
    [anon_sym_POUNDELSE] = ACTIONS(7785),
    [anon_sym_POUNDElse] = ACTIONS(7785),
    [anon_sym_POUNDelse2] = ACTIONS(7785),
    [anon_sym_POUNDELSE2] = ACTIONS(7785),
    [anon_sym_POUNDElse2] = ACTIONS(7785),
    [anon_sym_POUNDendif] = ACTIONS(7785),
    [anon_sym_POUNDENDIF] = ACTIONS(7785),
    [anon_sym_POUNDEndif] = ACTIONS(7785),
    [anon_sym_POUNDendif2] = ACTIONS(7785),
    [anon_sym_POUNDENDIF2] = ACTIONS(7785),
    [anon_sym_POUNDEndif2] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7787),
    [sym_page_keyword] = ACTIONS(7787),
    [anon_sym_codeunit] = ACTIONS(7787),
    [anon_sym_CODEUNIT] = ACTIONS(7787),
    [anon_sym_Codeunit] = ACTIONS(7787),
    [anon_sym_CodeUnit] = ACTIONS(7787),
    [anon_sym_COdeunit] = ACTIONS(7787),
    [anon_sym_codeUnit] = ACTIONS(7787),
    [sym_report_keyword] = ACTIONS(7787),
    [sym_query_keyword] = ACTIONS(7787),
    [anon_sym_xmlport] = ACTIONS(7787),
    [anon_sym_XMLPORT] = ACTIONS(7787),
    [anon_sym_Xmlport] = ACTIONS(7787),
    [anon_sym_XMLport] = ACTIONS(7787),
    [anon_sym_XMLPort] = ACTIONS(7787),
    [anon_sym_XmlPort] = ACTIONS(7787),
    [sym_procedure_keyword] = ACTIONS(7787),
    [sym_trigger_keyword] = ACTIONS(7787),
    [sym_var_keyword] = ACTIONS(7787),
    [sym_local_keyword] = ACTIONS(7787),
    [sym_internal_keyword] = ACTIONS(7787),
    [sym_protected_keyword] = ACTIONS(7787),
    [sym_event_keyword] = ACTIONS(7787),
    [sym_fields_keyword] = ACTIONS(7787),
    [sym_keys_keyword] = ACTIONS(7787),
    [sym_key_keyword] = ACTIONS(7787),
    [sym_fieldgroups_keyword] = ACTIONS(7787),
    [sym_actions_keyword] = ACTIONS(7787),
    [sym_layout_keyword] = ACTIONS(7787),
    [sym_dataset_keyword] = ACTIONS(7787),
    [sym_elements_keyword] = ACTIONS(7787),
    [sym_labels_keyword] = ACTIONS(7787),
    [sym_rendering_keyword] = ACTIONS(7787),
    [sym_requestpage_keyword] = ACTIONS(7787),
    [sym_schema_keyword] = ACTIONS(7787),
    [sym_views_keyword] = ACTIONS(7787),
    [sym_quoted_identifier] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7785),
    [sym_preproc_close] = ACTIONS(7785),
    [sym_var_attribute_open] = ACTIONS(7785),
  },
  [STATE(4301)] = {
    [sym_identifier] = ACTIONS(7720),
    [anon_sym_SEMI] = ACTIONS(7715),
    [aux_sym_where_condition_token1] = ACTIONS(7720),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [anon_sym_LBRACK] = ACTIONS(7730),
    [aux_sym_basic_type_token22] = ACTIONS(7720),
    [aux_sym_basic_type_token53] = ACTIONS(7720),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7720),
    [aux_sym_modify_modification_token1] = ACTIONS(7727),
    [aux_sym_separator_action_token1] = ACTIONS(7720),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7720),
    [aux_sym_type_declaration_token1] = ACTIONS(7720),
    [anon_sym_POUNDif] = ACTIONS(7715),
    [anon_sym_POUNDIF] = ACTIONS(7715),
    [anon_sym_POUNDIf] = ACTIONS(7715),
    [anon_sym_POUNDelif] = ACTIONS(7730),
    [anon_sym_POUNDELIF] = ACTIONS(7730),
    [anon_sym_POUNDElif] = ACTIONS(7730),
    [anon_sym_POUNDelse] = ACTIONS(7730),
    [anon_sym_POUNDELSE] = ACTIONS(7730),
    [anon_sym_POUNDElse] = ACTIONS(7730),
    [anon_sym_POUNDelse2] = ACTIONS(7730),
    [anon_sym_POUNDELSE2] = ACTIONS(7730),
    [anon_sym_POUNDElse2] = ACTIONS(7730),
    [anon_sym_POUNDendif] = ACTIONS(7730),
    [anon_sym_POUNDENDIF] = ACTIONS(7730),
    [anon_sym_POUNDEndif] = ACTIONS(7730),
    [anon_sym_POUNDendif2] = ACTIONS(7730),
    [anon_sym_POUNDENDIF2] = ACTIONS(7730),
    [anon_sym_POUNDEndif2] = ACTIONS(7730),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7720),
    [sym_page_keyword] = ACTIONS(7725),
    [anon_sym_codeunit] = ACTIONS(7725),
    [anon_sym_CODEUNIT] = ACTIONS(7725),
    [anon_sym_Codeunit] = ACTIONS(7725),
    [anon_sym_CodeUnit] = ACTIONS(7725),
    [anon_sym_COdeunit] = ACTIONS(7725),
    [anon_sym_codeUnit] = ACTIONS(7725),
    [sym_report_keyword] = ACTIONS(7725),
    [sym_query_keyword] = ACTIONS(7725),
    [anon_sym_xmlport] = ACTIONS(7725),
    [anon_sym_XMLPORT] = ACTIONS(7725),
    [anon_sym_Xmlport] = ACTIONS(7725),
    [anon_sym_XMLport] = ACTIONS(7725),
    [anon_sym_XMLPort] = ACTIONS(7725),
    [anon_sym_XmlPort] = ACTIONS(7725),
    [sym_procedure_keyword] = ACTIONS(7727),
    [sym_trigger_keyword] = ACTIONS(7727),
    [sym_var_keyword] = ACTIONS(7727),
    [sym_local_keyword] = ACTIONS(7727),
    [sym_internal_keyword] = ACTIONS(7727),
    [sym_protected_keyword] = ACTIONS(7727),
    [sym_event_keyword] = ACTIONS(7727),
    [sym_fields_keyword] = ACTIONS(7727),
    [sym_keys_keyword] = ACTIONS(7727),
    [sym_key_keyword] = ACTIONS(7720),
    [sym_fieldgroups_keyword] = ACTIONS(7727),
    [sym_actions_keyword] = ACTIONS(7727),
    [sym_layout_keyword] = ACTIONS(7727),
    [sym_dataset_keyword] = ACTIONS(7720),
    [sym_elements_keyword] = ACTIONS(7727),
    [sym_labels_keyword] = ACTIONS(7727),
    [sym_rendering_keyword] = ACTIONS(7727),
    [sym_requestpage_keyword] = ACTIONS(7727),
    [sym_schema_keyword] = ACTIONS(7727),
    [sym_views_keyword] = ACTIONS(7727),
    [sym_quoted_identifier] = ACTIONS(7715),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7730),
    [sym_preproc_open] = ACTIONS(7715),
    [sym_preproc_close] = ACTIONS(7730),
    [sym_var_attribute_open] = ACTIONS(7730),
  },
  [STATE(4302)] = {
    [sym_identifier] = ACTIONS(7765),
    [anon_sym_SEMI] = ACTIONS(7760),
    [aux_sym_where_condition_token1] = ACTIONS(7765),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [anon_sym_LBRACK] = ACTIONS(7775),
    [aux_sym_basic_type_token22] = ACTIONS(7765),
    [aux_sym_basic_type_token53] = ACTIONS(7765),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7765),
    [aux_sym_modify_modification_token1] = ACTIONS(7772),
    [aux_sym_separator_action_token1] = ACTIONS(7765),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7765),
    [aux_sym_type_declaration_token1] = ACTIONS(7765),
    [anon_sym_POUNDif] = ACTIONS(7760),
    [anon_sym_POUNDIF] = ACTIONS(7760),
    [anon_sym_POUNDIf] = ACTIONS(7760),
    [anon_sym_POUNDelif] = ACTIONS(7775),
    [anon_sym_POUNDELIF] = ACTIONS(7775),
    [anon_sym_POUNDElif] = ACTIONS(7775),
    [anon_sym_POUNDelse] = ACTIONS(7775),
    [anon_sym_POUNDELSE] = ACTIONS(7775),
    [anon_sym_POUNDElse] = ACTIONS(7775),
    [anon_sym_POUNDelse2] = ACTIONS(7775),
    [anon_sym_POUNDELSE2] = ACTIONS(7775),
    [anon_sym_POUNDElse2] = ACTIONS(7775),
    [anon_sym_POUNDendif] = ACTIONS(7775),
    [anon_sym_POUNDENDIF] = ACTIONS(7775),
    [anon_sym_POUNDEndif] = ACTIONS(7775),
    [anon_sym_POUNDendif2] = ACTIONS(7775),
    [anon_sym_POUNDENDIF2] = ACTIONS(7775),
    [anon_sym_POUNDEndif2] = ACTIONS(7775),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7765),
    [sym_page_keyword] = ACTIONS(7770),
    [anon_sym_codeunit] = ACTIONS(7770),
    [anon_sym_CODEUNIT] = ACTIONS(7770),
    [anon_sym_Codeunit] = ACTIONS(7770),
    [anon_sym_CodeUnit] = ACTIONS(7770),
    [anon_sym_COdeunit] = ACTIONS(7770),
    [anon_sym_codeUnit] = ACTIONS(7770),
    [sym_report_keyword] = ACTIONS(7770),
    [sym_query_keyword] = ACTIONS(7770),
    [anon_sym_xmlport] = ACTIONS(7770),
    [anon_sym_XMLPORT] = ACTIONS(7770),
    [anon_sym_Xmlport] = ACTIONS(7770),
    [anon_sym_XMLport] = ACTIONS(7770),
    [anon_sym_XMLPort] = ACTIONS(7770),
    [anon_sym_XmlPort] = ACTIONS(7770),
    [sym_procedure_keyword] = ACTIONS(7772),
    [sym_trigger_keyword] = ACTIONS(7772),
    [sym_var_keyword] = ACTIONS(7772),
    [sym_local_keyword] = ACTIONS(7772),
    [sym_internal_keyword] = ACTIONS(7772),
    [sym_protected_keyword] = ACTIONS(7772),
    [sym_event_keyword] = ACTIONS(7772),
    [sym_fields_keyword] = ACTIONS(7772),
    [sym_keys_keyword] = ACTIONS(7772),
    [sym_key_keyword] = ACTIONS(7765),
    [sym_fieldgroups_keyword] = ACTIONS(7772),
    [sym_actions_keyword] = ACTIONS(7772),
    [sym_layout_keyword] = ACTIONS(7772),
    [sym_dataset_keyword] = ACTIONS(7765),
    [sym_elements_keyword] = ACTIONS(7772),
    [sym_labels_keyword] = ACTIONS(7772),
    [sym_rendering_keyword] = ACTIONS(7772),
    [sym_requestpage_keyword] = ACTIONS(7772),
    [sym_schema_keyword] = ACTIONS(7772),
    [sym_views_keyword] = ACTIONS(7772),
    [sym_quoted_identifier] = ACTIONS(7760),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7775),
    [sym_preproc_open] = ACTIONS(7760),
    [sym_preproc_close] = ACTIONS(7775),
    [sym_var_attribute_open] = ACTIONS(7775),
  },
  [STATE(4303)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
    [sym_var_attribute_open] = ACTIONS(5277),
  },
  [STATE(4304)] = {
    [sym_identifier] = ACTIONS(7418),
    [anon_sym_COMMA] = ACTIONS(7420),
    [anon_sym_DASH] = ACTIONS(7420),
    [aux_sym_boolean_token1] = ACTIONS(7418),
    [aux_sym_boolean_token2] = ACTIONS(7418),
    [sym_decimal] = ACTIONS(7418),
    [anon_sym_LPAREN] = ACTIONS(7420),
    [aux_sym_where_condition_token1] = ACTIONS(7418),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(7418),
    [aux_sym_if_table_relation_token1] = ACTIONS(7418),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7418),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7418),
    [anon_sym_LBRACK] = ACTIONS(7420),
    [aux_sym_record_type_token1] = ACTIONS(7418),
    [aux_sym_basic_type_token21] = ACTIONS(7418),
    [aux_sym_basic_type_token22] = ACTIONS(7418),
    [aux_sym_basic_type_token48] = ACTIONS(7418),
    [aux_sym_basic_type_token53] = ACTIONS(7418),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7418),
    [aux_sym_separator_action_token1] = ACTIONS(7418),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7418),
    [aux_sym_type_declaration_token1] = ACTIONS(7418),
    [anon_sym_POUNDif] = ACTIONS(7420),
    [anon_sym_POUNDIF] = ACTIONS(7420),
    [anon_sym_POUNDIf] = ACTIONS(7420),
    [anon_sym_not] = ACTIONS(7418),
    [anon_sym_NOT] = ACTIONS(7418),
    [anon_sym_Not] = ACTIONS(7418),
    [anon_sym_POUNDendif] = ACTIONS(7420),
    [anon_sym_POUNDENDIF] = ACTIONS(7420),
    [anon_sym_POUNDEndif] = ACTIONS(7420),
    [anon_sym_POUNDendif2] = ACTIONS(7420),
    [anon_sym_POUNDENDIF2] = ACTIONS(7420),
    [anon_sym_POUNDEndif2] = ACTIONS(7420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7418),
    [anon_sym_PLUS] = ACTIONS(7420),
    [sym_datetime_literal] = ACTIONS(7420),
    [sym_date_literal] = ACTIONS(7418),
    [sym_time_literal] = ACTIONS(7418),
    [sym_biginteger_literal] = ACTIONS(7420),
    [sym_table_keyword] = ACTIONS(7418),
    [sym_page_keyword] = ACTIONS(7418),
    [anon_sym_codeunit] = ACTIONS(7418),
    [anon_sym_CODEUNIT] = ACTIONS(7418),
    [anon_sym_Codeunit] = ACTIONS(7418),
    [anon_sym_CodeUnit] = ACTIONS(7418),
    [anon_sym_COdeunit] = ACTIONS(7418),
    [anon_sym_codeUnit] = ACTIONS(7418),
    [sym_report_keyword] = ACTIONS(7418),
    [sym_query_keyword] = ACTIONS(7418),
    [anon_sym_xmlport] = ACTIONS(7418),
    [anon_sym_XMLPORT] = ACTIONS(7418),
    [anon_sym_Xmlport] = ACTIONS(7418),
    [anon_sym_XMLport] = ACTIONS(7418),
    [anon_sym_XMLPort] = ACTIONS(7418),
    [anon_sym_XmlPort] = ACTIONS(7418),
    [anon_sym_enum] = ACTIONS(7418),
    [anon_sym_ENUM] = ACTIONS(7418),
    [anon_sym_Enum] = ACTIONS(7418),
    [anon_sym_eNUM] = ACTIONS(7418),
    [anon_sym_eNum] = ACTIONS(7418),
    [anon_sym_ENum] = ACTIONS(7418),
    [sym_key_keyword] = ACTIONS(7418),
    [sym_dataset_keyword] = ACTIONS(7418),
    [sym_quoted_identifier] = ACTIONS(7420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7420),
    [sym_verbatim_string] = ACTIONS(7420),
    [sym_integer] = ACTIONS(7418),
    [sym_continue_as_identifier] = ACTIONS(7420),
    [sym_preproc_open] = ACTIONS(7420),
    [sym_preproc_close] = ACTIONS(7420),
  },
  [STATE(4305)] = {
    [sym_identifier] = ACTIONS(8432),
    [anon_sym_SEMI] = ACTIONS(8430),
    [aux_sym_where_condition_token1] = ACTIONS(8432),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8432),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8432),
    [anon_sym_LBRACK] = ACTIONS(8430),
    [aux_sym_basic_type_token22] = ACTIONS(8432),
    [aux_sym_basic_type_token53] = ACTIONS(8432),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8432),
    [aux_sym_modify_modification_token1] = ACTIONS(8432),
    [aux_sym_separator_action_token1] = ACTIONS(8432),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8432),
    [aux_sym_type_declaration_token1] = ACTIONS(8432),
    [anon_sym_POUNDif] = ACTIONS(8430),
    [anon_sym_POUNDIF] = ACTIONS(8430),
    [anon_sym_POUNDIf] = ACTIONS(8430),
    [anon_sym_POUNDelif] = ACTIONS(8430),
    [anon_sym_POUNDELIF] = ACTIONS(8430),
    [anon_sym_POUNDElif] = ACTIONS(8430),
    [anon_sym_POUNDelse] = ACTIONS(8430),
    [anon_sym_POUNDELSE] = ACTIONS(8430),
    [anon_sym_POUNDElse] = ACTIONS(8430),
    [anon_sym_POUNDelse2] = ACTIONS(8430),
    [anon_sym_POUNDELSE2] = ACTIONS(8430),
    [anon_sym_POUNDElse2] = ACTIONS(8430),
    [anon_sym_POUNDendif] = ACTIONS(8430),
    [anon_sym_POUNDENDIF] = ACTIONS(8430),
    [anon_sym_POUNDEndif] = ACTIONS(8430),
    [anon_sym_POUNDendif2] = ACTIONS(8430),
    [anon_sym_POUNDENDIF2] = ACTIONS(8430),
    [anon_sym_POUNDEndif2] = ACTIONS(8430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8432),
    [sym_page_keyword] = ACTIONS(8432),
    [anon_sym_codeunit] = ACTIONS(8432),
    [anon_sym_CODEUNIT] = ACTIONS(8432),
    [anon_sym_Codeunit] = ACTIONS(8432),
    [anon_sym_CodeUnit] = ACTIONS(8432),
    [anon_sym_COdeunit] = ACTIONS(8432),
    [anon_sym_codeUnit] = ACTIONS(8432),
    [sym_report_keyword] = ACTIONS(8432),
    [sym_query_keyword] = ACTIONS(8432),
    [anon_sym_xmlport] = ACTIONS(8432),
    [anon_sym_XMLPORT] = ACTIONS(8432),
    [anon_sym_Xmlport] = ACTIONS(8432),
    [anon_sym_XMLport] = ACTIONS(8432),
    [anon_sym_XMLPort] = ACTIONS(8432),
    [anon_sym_XmlPort] = ACTIONS(8432),
    [sym_procedure_keyword] = ACTIONS(8432),
    [sym_trigger_keyword] = ACTIONS(8432),
    [sym_var_keyword] = ACTIONS(8432),
    [sym_local_keyword] = ACTIONS(8432),
    [sym_internal_keyword] = ACTIONS(8432),
    [sym_protected_keyword] = ACTIONS(8432),
    [sym_event_keyword] = ACTIONS(8432),
    [sym_fields_keyword] = ACTIONS(8432),
    [sym_keys_keyword] = ACTIONS(8432),
    [sym_key_keyword] = ACTIONS(8432),
    [sym_fieldgroups_keyword] = ACTIONS(8432),
    [sym_actions_keyword] = ACTIONS(8432),
    [sym_layout_keyword] = ACTIONS(8432),
    [sym_dataset_keyword] = ACTIONS(8432),
    [sym_elements_keyword] = ACTIONS(8432),
    [sym_labels_keyword] = ACTIONS(8432),
    [sym_rendering_keyword] = ACTIONS(8432),
    [sym_requestpage_keyword] = ACTIONS(8432),
    [sym_schema_keyword] = ACTIONS(8432),
    [sym_views_keyword] = ACTIONS(8432),
    [sym_quoted_identifier] = ACTIONS(8430),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8430),
    [sym_preproc_open] = ACTIONS(8430),
    [sym_preproc_close] = ACTIONS(8430),
    [sym_var_attribute_open] = ACTIONS(8430),
  },
  [STATE(4306)] = {
    [sym_identifier] = ACTIONS(8448),
    [anon_sym_SEMI] = ACTIONS(8446),
    [aux_sym_where_condition_token1] = ACTIONS(8448),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8448),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8448),
    [anon_sym_LBRACK] = ACTIONS(8446),
    [aux_sym_basic_type_token22] = ACTIONS(8448),
    [aux_sym_basic_type_token53] = ACTIONS(8448),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8448),
    [aux_sym_modify_modification_token1] = ACTIONS(8448),
    [aux_sym_separator_action_token1] = ACTIONS(8448),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8448),
    [aux_sym_type_declaration_token1] = ACTIONS(8448),
    [anon_sym_POUNDif] = ACTIONS(8446),
    [anon_sym_POUNDIF] = ACTIONS(8446),
    [anon_sym_POUNDIf] = ACTIONS(8446),
    [anon_sym_POUNDelif] = ACTIONS(8446),
    [anon_sym_POUNDELIF] = ACTIONS(8446),
    [anon_sym_POUNDElif] = ACTIONS(8446),
    [anon_sym_POUNDelse] = ACTIONS(8446),
    [anon_sym_POUNDELSE] = ACTIONS(8446),
    [anon_sym_POUNDElse] = ACTIONS(8446),
    [anon_sym_POUNDelse2] = ACTIONS(8446),
    [anon_sym_POUNDELSE2] = ACTIONS(8446),
    [anon_sym_POUNDElse2] = ACTIONS(8446),
    [anon_sym_POUNDendif] = ACTIONS(8446),
    [anon_sym_POUNDENDIF] = ACTIONS(8446),
    [anon_sym_POUNDEndif] = ACTIONS(8446),
    [anon_sym_POUNDendif2] = ACTIONS(8446),
    [anon_sym_POUNDENDIF2] = ACTIONS(8446),
    [anon_sym_POUNDEndif2] = ACTIONS(8446),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8448),
    [sym_page_keyword] = ACTIONS(8448),
    [anon_sym_codeunit] = ACTIONS(8448),
    [anon_sym_CODEUNIT] = ACTIONS(8448),
    [anon_sym_Codeunit] = ACTIONS(8448),
    [anon_sym_CodeUnit] = ACTIONS(8448),
    [anon_sym_COdeunit] = ACTIONS(8448),
    [anon_sym_codeUnit] = ACTIONS(8448),
    [sym_report_keyword] = ACTIONS(8448),
    [sym_query_keyword] = ACTIONS(8448),
    [anon_sym_xmlport] = ACTIONS(8448),
    [anon_sym_XMLPORT] = ACTIONS(8448),
    [anon_sym_Xmlport] = ACTIONS(8448),
    [anon_sym_XMLport] = ACTIONS(8448),
    [anon_sym_XMLPort] = ACTIONS(8448),
    [anon_sym_XmlPort] = ACTIONS(8448),
    [sym_procedure_keyword] = ACTIONS(8448),
    [sym_trigger_keyword] = ACTIONS(8448),
    [sym_var_keyword] = ACTIONS(8448),
    [sym_local_keyword] = ACTIONS(8448),
    [sym_internal_keyword] = ACTIONS(8448),
    [sym_protected_keyword] = ACTIONS(8448),
    [sym_event_keyword] = ACTIONS(8448),
    [sym_fields_keyword] = ACTIONS(8448),
    [sym_keys_keyword] = ACTIONS(8448),
    [sym_key_keyword] = ACTIONS(8448),
    [sym_fieldgroups_keyword] = ACTIONS(8448),
    [sym_actions_keyword] = ACTIONS(8448),
    [sym_layout_keyword] = ACTIONS(8448),
    [sym_dataset_keyword] = ACTIONS(8448),
    [sym_elements_keyword] = ACTIONS(8448),
    [sym_labels_keyword] = ACTIONS(8448),
    [sym_rendering_keyword] = ACTIONS(8448),
    [sym_requestpage_keyword] = ACTIONS(8448),
    [sym_schema_keyword] = ACTIONS(8448),
    [sym_views_keyword] = ACTIONS(8448),
    [sym_quoted_identifier] = ACTIONS(8446),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8446),
    [sym_preproc_open] = ACTIONS(8446),
    [sym_preproc_close] = ACTIONS(8446),
    [sym_var_attribute_open] = ACTIONS(8446),
  },
  [STATE(4307)] = {
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym_DOT] = ACTIONS(5407),
    [anon_sym_RBRACE] = ACTIONS(5405),
    [anon_sym_EQ] = ACTIONS(3683),
    [anon_sym_DASH] = ACTIONS(3681),
    [aux_sym_where_clause_token1] = ACTIONS(5405),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5405),
    [anon_sym_STAR] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5405),
    [aux_sym_modify_modification_token1] = ACTIONS(5405),
    [aux_sym_xmlport_element_token1] = ACTIONS(5405),
    [aux_sym_xmlport_element_token2] = ACTIONS(5405),
    [aux_sym_xmlport_element_token3] = ACTIONS(5405),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5405),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5410),
    [anon_sym_COLON_COLON] = ACTIONS(5394),
    [anon_sym_POUNDif] = ACTIONS(5405),
    [anon_sym_POUNDIF] = ACTIONS(5405),
    [anon_sym_POUNDIf] = ACTIONS(5405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3683),
    [aux_sym__expression_token1] = ACTIONS(3683),
    [aux_sym__expression_token2] = ACTIONS(3683),
    [anon_sym_SLASH] = ACTIONS(3681),
    [anon_sym_div] = ACTIONS(3683),
    [anon_sym_DIV] = ACTIONS(3683),
    [anon_sym_Div] = ACTIONS(3683),
    [anon_sym_mod] = ACTIONS(3681),
    [anon_sym_MOD] = ACTIONS(3681),
    [anon_sym_Mod] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_GT_EQ] = ACTIONS(3683),
    [anon_sym_LT_EQ] = ACTIONS(3683),
    [anon_sym_GT] = ACTIONS(3681),
    [anon_sym_LT] = ACTIONS(3681),
    [anon_sym_LT_GT] = ACTIONS(3683),
    [anon_sym_and] = ACTIONS(3683),
    [anon_sym_AND] = ACTIONS(3683),
    [anon_sym_And] = ACTIONS(3683),
    [anon_sym_or] = ACTIONS(3683),
    [anon_sym_OR] = ACTIONS(3683),
    [anon_sym_Or] = ACTIONS(3683),
    [anon_sym_xor] = ACTIONS(3683),
    [anon_sym_XOR] = ACTIONS(3683),
    [anon_sym_Xor] = ACTIONS(3683),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_in] = ACTIONS(3681),
    [anon_sym_IN] = ACTIONS(3681),
    [anon_sym_In] = ACTIONS(3681),
    [sym_procedure_keyword] = ACTIONS(5405),
    [sym_trigger_keyword] = ACTIONS(5405),
    [sym_var_keyword] = ACTIONS(5405),
    [sym_local_keyword] = ACTIONS(5405),
    [sym_internal_keyword] = ACTIONS(5405),
    [sym_protected_keyword] = ACTIONS(5405),
    [sym_event_keyword] = ACTIONS(5405),
    [sym_fields_keyword] = ACTIONS(5405),
    [sym_keys_keyword] = ACTIONS(5405),
    [sym_fieldgroups_keyword] = ACTIONS(5405),
    [sym_actions_keyword] = ACTIONS(5405),
    [sym_layout_keyword] = ACTIONS(5405),
    [sym_dataset_keyword] = ACTIONS(5405),
    [sym_elements_keyword] = ACTIONS(5405),
    [sym_labels_keyword] = ACTIONS(5405),
    [sym_rendering_keyword] = ACTIONS(5405),
    [sym_requestpage_keyword] = ACTIONS(5405),
    [sym_schema_keyword] = ACTIONS(5405),
    [sym_views_keyword] = ACTIONS(5405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5405),
    [sym_preproc_open] = ACTIONS(5405),
  },
  [STATE(4308)] = {
    [sym_preproc_conditional_permissions] = STATE(4313),
    [sym_tabledata_permission] = STATE(5160),
    [sym_preproc_if] = STATE(7952),
    [sym_codeunit_keyword] = STATE(11292),
    [sym_xmlport_keyword] = STATE(11292),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4313),
    [anon_sym_SEMI] = ACTIONS(7846),
    [aux_sym_tabledata_permission_token1] = ACTIONS(9736),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9736),
    [anon_sym_LBRACK] = ACTIONS(7846),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7846),
    [aux_sym_modify_modification_token1] = ACTIONS(7846),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7846),
    [anon_sym_POUNDif] = ACTIONS(7852),
    [anon_sym_POUNDIF] = ACTIONS(7852),
    [anon_sym_POUNDIf] = ACTIONS(7852),
    [anon_sym_POUNDelif] = ACTIONS(7846),
    [anon_sym_POUNDELIF] = ACTIONS(7846),
    [anon_sym_POUNDElif] = ACTIONS(7846),
    [anon_sym_POUNDelse] = ACTIONS(7846),
    [anon_sym_POUNDELSE] = ACTIONS(7846),
    [anon_sym_POUNDElse] = ACTIONS(7846),
    [anon_sym_POUNDelse2] = ACTIONS(7846),
    [anon_sym_POUNDELSE2] = ACTIONS(7846),
    [anon_sym_POUNDElse2] = ACTIONS(7846),
    [anon_sym_POUNDendif] = ACTIONS(7846),
    [anon_sym_POUNDENDIF] = ACTIONS(7846),
    [anon_sym_POUNDEndif] = ACTIONS(7846),
    [anon_sym_POUNDendif2] = ACTIONS(7846),
    [anon_sym_POUNDENDIF2] = ACTIONS(7846),
    [anon_sym_POUNDEndif2] = ACTIONS(7846),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4065),
    [sym_page_keyword] = ACTIONS(9736),
    [anon_sym_codeunit] = ACTIONS(7855),
    [anon_sym_CODEUNIT] = ACTIONS(7855),
    [anon_sym_Codeunit] = ACTIONS(7855),
    [anon_sym_CodeUnit] = ACTIONS(7855),
    [anon_sym_COdeunit] = ACTIONS(7855),
    [anon_sym_codeUnit] = ACTIONS(7855),
    [sym_report_keyword] = ACTIONS(9736),
    [sym_query_keyword] = ACTIONS(9736),
    [anon_sym_xmlport] = ACTIONS(7857),
    [anon_sym_XMLPORT] = ACTIONS(7857),
    [anon_sym_Xmlport] = ACTIONS(7857),
    [anon_sym_XMLport] = ACTIONS(7857),
    [anon_sym_XMLPort] = ACTIONS(7857),
    [anon_sym_XmlPort] = ACTIONS(7857),
    [sym_procedure_keyword] = ACTIONS(7846),
    [sym_trigger_keyword] = ACTIONS(7846),
    [sym_var_keyword] = ACTIONS(7846),
    [sym_local_keyword] = ACTIONS(7846),
    [sym_internal_keyword] = ACTIONS(7846),
    [sym_protected_keyword] = ACTIONS(7846),
    [sym_event_keyword] = ACTIONS(7846),
    [sym_fields_keyword] = ACTIONS(7846),
    [sym_keys_keyword] = ACTIONS(7846),
    [sym_fieldgroups_keyword] = ACTIONS(7846),
    [sym_actions_keyword] = ACTIONS(7846),
    [sym_layout_keyword] = ACTIONS(7846),
    [sym_dataset_keyword] = ACTIONS(7846),
    [sym_elements_keyword] = ACTIONS(7846),
    [sym_dataitem_keyword] = ACTIONS(7846),
    [sym_column_keyword] = ACTIONS(7846),
    [sym_filter_keyword] = ACTIONS(7846),
    [sym_labels_keyword] = ACTIONS(7846),
    [sym_rendering_keyword] = ACTIONS(7846),
    [sym_requestpage_keyword] = ACTIONS(7846),
    [sym_schema_keyword] = ACTIONS(7846),
    [sym_views_keyword] = ACTIONS(7846),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7846),
    [sym_preproc_open] = ACTIONS(7852),
    [sym_preproc_close] = ACTIONS(7846),
  },
  [STATE(4309)] = {
    [sym_identifier] = ACTIONS(8440),
    [anon_sym_SEMI] = ACTIONS(8438),
    [aux_sym_where_condition_token1] = ACTIONS(8440),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8440),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8440),
    [anon_sym_LBRACK] = ACTIONS(8438),
    [aux_sym_basic_type_token22] = ACTIONS(8440),
    [aux_sym_basic_type_token53] = ACTIONS(8440),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8440),
    [aux_sym_modify_modification_token1] = ACTIONS(8440),
    [aux_sym_separator_action_token1] = ACTIONS(8440),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8440),
    [aux_sym_type_declaration_token1] = ACTIONS(8440),
    [anon_sym_POUNDif] = ACTIONS(8438),
    [anon_sym_POUNDIF] = ACTIONS(8438),
    [anon_sym_POUNDIf] = ACTIONS(8438),
    [anon_sym_POUNDelif] = ACTIONS(8438),
    [anon_sym_POUNDELIF] = ACTIONS(8438),
    [anon_sym_POUNDElif] = ACTIONS(8438),
    [anon_sym_POUNDelse] = ACTIONS(8438),
    [anon_sym_POUNDELSE] = ACTIONS(8438),
    [anon_sym_POUNDElse] = ACTIONS(8438),
    [anon_sym_POUNDelse2] = ACTIONS(8438),
    [anon_sym_POUNDELSE2] = ACTIONS(8438),
    [anon_sym_POUNDElse2] = ACTIONS(8438),
    [anon_sym_POUNDendif] = ACTIONS(8438),
    [anon_sym_POUNDENDIF] = ACTIONS(8438),
    [anon_sym_POUNDEndif] = ACTIONS(8438),
    [anon_sym_POUNDendif2] = ACTIONS(8438),
    [anon_sym_POUNDENDIF2] = ACTIONS(8438),
    [anon_sym_POUNDEndif2] = ACTIONS(8438),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8440),
    [sym_page_keyword] = ACTIONS(8440),
    [anon_sym_codeunit] = ACTIONS(8440),
    [anon_sym_CODEUNIT] = ACTIONS(8440),
    [anon_sym_Codeunit] = ACTIONS(8440),
    [anon_sym_CodeUnit] = ACTIONS(8440),
    [anon_sym_COdeunit] = ACTIONS(8440),
    [anon_sym_codeUnit] = ACTIONS(8440),
    [sym_report_keyword] = ACTIONS(8440),
    [sym_query_keyword] = ACTIONS(8440),
    [anon_sym_xmlport] = ACTIONS(8440),
    [anon_sym_XMLPORT] = ACTIONS(8440),
    [anon_sym_Xmlport] = ACTIONS(8440),
    [anon_sym_XMLport] = ACTIONS(8440),
    [anon_sym_XMLPort] = ACTIONS(8440),
    [anon_sym_XmlPort] = ACTIONS(8440),
    [sym_procedure_keyword] = ACTIONS(8440),
    [sym_trigger_keyword] = ACTIONS(8440),
    [sym_var_keyword] = ACTIONS(8440),
    [sym_local_keyword] = ACTIONS(8440),
    [sym_internal_keyword] = ACTIONS(8440),
    [sym_protected_keyword] = ACTIONS(8440),
    [sym_event_keyword] = ACTIONS(8440),
    [sym_fields_keyword] = ACTIONS(8440),
    [sym_keys_keyword] = ACTIONS(8440),
    [sym_key_keyword] = ACTIONS(8440),
    [sym_fieldgroups_keyword] = ACTIONS(8440),
    [sym_actions_keyword] = ACTIONS(8440),
    [sym_layout_keyword] = ACTIONS(8440),
    [sym_dataset_keyword] = ACTIONS(8440),
    [sym_elements_keyword] = ACTIONS(8440),
    [sym_labels_keyword] = ACTIONS(8440),
    [sym_rendering_keyword] = ACTIONS(8440),
    [sym_requestpage_keyword] = ACTIONS(8440),
    [sym_schema_keyword] = ACTIONS(8440),
    [sym_views_keyword] = ACTIONS(8440),
    [sym_quoted_identifier] = ACTIONS(8438),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8438),
    [sym_preproc_open] = ACTIONS(8438),
    [sym_preproc_close] = ACTIONS(8438),
    [sym_var_attribute_open] = ACTIONS(8438),
  },
  [STATE(4310)] = {
    [sym_identifier] = ACTIONS(8444),
    [anon_sym_SEMI] = ACTIONS(8442),
    [aux_sym_where_condition_token1] = ACTIONS(8444),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8444),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8444),
    [anon_sym_LBRACK] = ACTIONS(8442),
    [aux_sym_basic_type_token22] = ACTIONS(8444),
    [aux_sym_basic_type_token53] = ACTIONS(8444),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8444),
    [aux_sym_modify_modification_token1] = ACTIONS(8444),
    [aux_sym_separator_action_token1] = ACTIONS(8444),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8444),
    [aux_sym_type_declaration_token1] = ACTIONS(8444),
    [anon_sym_POUNDif] = ACTIONS(8442),
    [anon_sym_POUNDIF] = ACTIONS(8442),
    [anon_sym_POUNDIf] = ACTIONS(8442),
    [anon_sym_POUNDelif] = ACTIONS(8442),
    [anon_sym_POUNDELIF] = ACTIONS(8442),
    [anon_sym_POUNDElif] = ACTIONS(8442),
    [anon_sym_POUNDelse] = ACTIONS(8442),
    [anon_sym_POUNDELSE] = ACTIONS(8442),
    [anon_sym_POUNDElse] = ACTIONS(8442),
    [anon_sym_POUNDelse2] = ACTIONS(8442),
    [anon_sym_POUNDELSE2] = ACTIONS(8442),
    [anon_sym_POUNDElse2] = ACTIONS(8442),
    [anon_sym_POUNDendif] = ACTIONS(8442),
    [anon_sym_POUNDENDIF] = ACTIONS(8442),
    [anon_sym_POUNDEndif] = ACTIONS(8442),
    [anon_sym_POUNDendif2] = ACTIONS(8442),
    [anon_sym_POUNDENDIF2] = ACTIONS(8442),
    [anon_sym_POUNDEndif2] = ACTIONS(8442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8444),
    [sym_page_keyword] = ACTIONS(8444),
    [anon_sym_codeunit] = ACTIONS(8444),
    [anon_sym_CODEUNIT] = ACTIONS(8444),
    [anon_sym_Codeunit] = ACTIONS(8444),
    [anon_sym_CodeUnit] = ACTIONS(8444),
    [anon_sym_COdeunit] = ACTIONS(8444),
    [anon_sym_codeUnit] = ACTIONS(8444),
    [sym_report_keyword] = ACTIONS(8444),
    [sym_query_keyword] = ACTIONS(8444),
    [anon_sym_xmlport] = ACTIONS(8444),
    [anon_sym_XMLPORT] = ACTIONS(8444),
    [anon_sym_Xmlport] = ACTIONS(8444),
    [anon_sym_XMLport] = ACTIONS(8444),
    [anon_sym_XMLPort] = ACTIONS(8444),
    [anon_sym_XmlPort] = ACTIONS(8444),
    [sym_procedure_keyword] = ACTIONS(8444),
    [sym_trigger_keyword] = ACTIONS(8444),
    [sym_var_keyword] = ACTIONS(8444),
    [sym_local_keyword] = ACTIONS(8444),
    [sym_internal_keyword] = ACTIONS(8444),
    [sym_protected_keyword] = ACTIONS(8444),
    [sym_event_keyword] = ACTIONS(8444),
    [sym_fields_keyword] = ACTIONS(8444),
    [sym_keys_keyword] = ACTIONS(8444),
    [sym_key_keyword] = ACTIONS(8444),
    [sym_fieldgroups_keyword] = ACTIONS(8444),
    [sym_actions_keyword] = ACTIONS(8444),
    [sym_layout_keyword] = ACTIONS(8444),
    [sym_dataset_keyword] = ACTIONS(8444),
    [sym_elements_keyword] = ACTIONS(8444),
    [sym_labels_keyword] = ACTIONS(8444),
    [sym_rendering_keyword] = ACTIONS(8444),
    [sym_requestpage_keyword] = ACTIONS(8444),
    [sym_schema_keyword] = ACTIONS(8444),
    [sym_views_keyword] = ACTIONS(8444),
    [sym_quoted_identifier] = ACTIONS(8442),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8442),
    [sym_preproc_open] = ACTIONS(8442),
    [sym_preproc_close] = ACTIONS(8442),
    [sym_var_attribute_open] = ACTIONS(8442),
  },
  [STATE(4311)] = {
    [sym_identifier] = ACTIONS(7770),
    [anon_sym_SEMI] = ACTIONS(8426),
    [aux_sym_where_condition_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [anon_sym_LBRACK] = ACTIONS(8426),
    [aux_sym_basic_type_token22] = ACTIONS(7770),
    [aux_sym_basic_type_token53] = ACTIONS(7770),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7770),
    [aux_sym_modify_modification_token1] = ACTIONS(7770),
    [aux_sym_separator_action_token1] = ACTIONS(7770),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7770),
    [aux_sym_type_declaration_token1] = ACTIONS(7770),
    [anon_sym_POUNDif] = ACTIONS(8426),
    [anon_sym_POUNDIF] = ACTIONS(8426),
    [anon_sym_POUNDIf] = ACTIONS(8426),
    [anon_sym_POUNDelif] = ACTIONS(8426),
    [anon_sym_POUNDELIF] = ACTIONS(8426),
    [anon_sym_POUNDElif] = ACTIONS(8426),
    [anon_sym_POUNDelse] = ACTIONS(8426),
    [anon_sym_POUNDELSE] = ACTIONS(8426),
    [anon_sym_POUNDElse] = ACTIONS(8426),
    [anon_sym_POUNDelse2] = ACTIONS(8426),
    [anon_sym_POUNDELSE2] = ACTIONS(8426),
    [anon_sym_POUNDElse2] = ACTIONS(8426),
    [anon_sym_POUNDendif] = ACTIONS(8426),
    [anon_sym_POUNDENDIF] = ACTIONS(8426),
    [anon_sym_POUNDEndif] = ACTIONS(8426),
    [anon_sym_POUNDendif2] = ACTIONS(8426),
    [anon_sym_POUNDENDIF2] = ACTIONS(8426),
    [anon_sym_POUNDEndif2] = ACTIONS(8426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7770),
    [sym_page_keyword] = ACTIONS(7770),
    [anon_sym_codeunit] = ACTIONS(7770),
    [anon_sym_CODEUNIT] = ACTIONS(7770),
    [anon_sym_Codeunit] = ACTIONS(7770),
    [anon_sym_CodeUnit] = ACTIONS(7770),
    [anon_sym_COdeunit] = ACTIONS(7770),
    [anon_sym_codeUnit] = ACTIONS(7770),
    [sym_report_keyword] = ACTIONS(7770),
    [sym_query_keyword] = ACTIONS(7770),
    [anon_sym_xmlport] = ACTIONS(7770),
    [anon_sym_XMLPORT] = ACTIONS(7770),
    [anon_sym_Xmlport] = ACTIONS(7770),
    [anon_sym_XMLport] = ACTIONS(7770),
    [anon_sym_XMLPort] = ACTIONS(7770),
    [anon_sym_XmlPort] = ACTIONS(7770),
    [sym_procedure_keyword] = ACTIONS(7770),
    [sym_trigger_keyword] = ACTIONS(7770),
    [sym_var_keyword] = ACTIONS(7770),
    [sym_local_keyword] = ACTIONS(7770),
    [sym_internal_keyword] = ACTIONS(7770),
    [sym_protected_keyword] = ACTIONS(7770),
    [sym_event_keyword] = ACTIONS(7770),
    [sym_fields_keyword] = ACTIONS(7770),
    [sym_keys_keyword] = ACTIONS(7770),
    [sym_key_keyword] = ACTIONS(7770),
    [sym_fieldgroups_keyword] = ACTIONS(7770),
    [sym_actions_keyword] = ACTIONS(7770),
    [sym_layout_keyword] = ACTIONS(7770),
    [sym_dataset_keyword] = ACTIONS(7770),
    [sym_elements_keyword] = ACTIONS(7770),
    [sym_labels_keyword] = ACTIONS(7770),
    [sym_rendering_keyword] = ACTIONS(7770),
    [sym_requestpage_keyword] = ACTIONS(7770),
    [sym_schema_keyword] = ACTIONS(7770),
    [sym_views_keyword] = ACTIONS(7770),
    [sym_quoted_identifier] = ACTIONS(8426),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8426),
    [sym_preproc_open] = ACTIONS(8426),
    [sym_preproc_close] = ACTIONS(8426),
    [sym_var_attribute_open] = ACTIONS(8426),
  },
  [STATE(4312)] = {
    [sym_identifier] = ACTIONS(7725),
    [anon_sym_SEMI] = ACTIONS(8428),
    [aux_sym_where_condition_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [anon_sym_LBRACK] = ACTIONS(8428),
    [aux_sym_basic_type_token22] = ACTIONS(7725),
    [aux_sym_basic_type_token53] = ACTIONS(7725),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7725),
    [aux_sym_modify_modification_token1] = ACTIONS(7725),
    [aux_sym_separator_action_token1] = ACTIONS(7725),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7725),
    [aux_sym_type_declaration_token1] = ACTIONS(7725),
    [anon_sym_POUNDif] = ACTIONS(8428),
    [anon_sym_POUNDIF] = ACTIONS(8428),
    [anon_sym_POUNDIf] = ACTIONS(8428),
    [anon_sym_POUNDelif] = ACTIONS(8428),
    [anon_sym_POUNDELIF] = ACTIONS(8428),
    [anon_sym_POUNDElif] = ACTIONS(8428),
    [anon_sym_POUNDelse] = ACTIONS(8428),
    [anon_sym_POUNDELSE] = ACTIONS(8428),
    [anon_sym_POUNDElse] = ACTIONS(8428),
    [anon_sym_POUNDelse2] = ACTIONS(8428),
    [anon_sym_POUNDELSE2] = ACTIONS(8428),
    [anon_sym_POUNDElse2] = ACTIONS(8428),
    [anon_sym_POUNDendif] = ACTIONS(8428),
    [anon_sym_POUNDENDIF] = ACTIONS(8428),
    [anon_sym_POUNDEndif] = ACTIONS(8428),
    [anon_sym_POUNDendif2] = ACTIONS(8428),
    [anon_sym_POUNDENDIF2] = ACTIONS(8428),
    [anon_sym_POUNDEndif2] = ACTIONS(8428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7725),
    [sym_page_keyword] = ACTIONS(7725),
    [anon_sym_codeunit] = ACTIONS(7725),
    [anon_sym_CODEUNIT] = ACTIONS(7725),
    [anon_sym_Codeunit] = ACTIONS(7725),
    [anon_sym_CodeUnit] = ACTIONS(7725),
    [anon_sym_COdeunit] = ACTIONS(7725),
    [anon_sym_codeUnit] = ACTIONS(7725),
    [sym_report_keyword] = ACTIONS(7725),
    [sym_query_keyword] = ACTIONS(7725),
    [anon_sym_xmlport] = ACTIONS(7725),
    [anon_sym_XMLPORT] = ACTIONS(7725),
    [anon_sym_Xmlport] = ACTIONS(7725),
    [anon_sym_XMLport] = ACTIONS(7725),
    [anon_sym_XMLPort] = ACTIONS(7725),
    [anon_sym_XmlPort] = ACTIONS(7725),
    [sym_procedure_keyword] = ACTIONS(7725),
    [sym_trigger_keyword] = ACTIONS(7725),
    [sym_var_keyword] = ACTIONS(7725),
    [sym_local_keyword] = ACTIONS(7725),
    [sym_internal_keyword] = ACTIONS(7725),
    [sym_protected_keyword] = ACTIONS(7725),
    [sym_event_keyword] = ACTIONS(7725),
    [sym_fields_keyword] = ACTIONS(7725),
    [sym_keys_keyword] = ACTIONS(7725),
    [sym_key_keyword] = ACTIONS(7725),
    [sym_fieldgroups_keyword] = ACTIONS(7725),
    [sym_actions_keyword] = ACTIONS(7725),
    [sym_layout_keyword] = ACTIONS(7725),
    [sym_dataset_keyword] = ACTIONS(7725),
    [sym_elements_keyword] = ACTIONS(7725),
    [sym_labels_keyword] = ACTIONS(7725),
    [sym_rendering_keyword] = ACTIONS(7725),
    [sym_requestpage_keyword] = ACTIONS(7725),
    [sym_schema_keyword] = ACTIONS(7725),
    [sym_views_keyword] = ACTIONS(7725),
    [sym_quoted_identifier] = ACTIONS(8428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8428),
    [sym_preproc_open] = ACTIONS(8428),
    [sym_preproc_close] = ACTIONS(8428),
    [sym_var_attribute_open] = ACTIONS(8428),
  },
  [STATE(4313)] = {
    [sym_preproc_conditional_permissions] = STATE(4313),
    [sym_tabledata_permission] = STATE(5160),
    [sym_preproc_if] = STATE(7952),
    [sym_codeunit_keyword] = STATE(11292),
    [sym_xmlport_keyword] = STATE(11292),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(4313),
    [anon_sym_SEMI] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token1] = ACTIONS(9738),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9738),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7795),
    [anon_sym_POUNDIF] = ACTIONS(7795),
    [anon_sym_POUNDIf] = ACTIONS(7795),
    [anon_sym_POUNDelif] = ACTIONS(7785),
    [anon_sym_POUNDELIF] = ACTIONS(7785),
    [anon_sym_POUNDElif] = ACTIONS(7785),
    [anon_sym_POUNDelse] = ACTIONS(7785),
    [anon_sym_POUNDELSE] = ACTIONS(7785),
    [anon_sym_POUNDElse] = ACTIONS(7785),
    [anon_sym_POUNDelse2] = ACTIONS(7785),
    [anon_sym_POUNDELSE2] = ACTIONS(7785),
    [anon_sym_POUNDElse2] = ACTIONS(7785),
    [anon_sym_POUNDendif] = ACTIONS(7785),
    [anon_sym_POUNDENDIF] = ACTIONS(7785),
    [anon_sym_POUNDEndif] = ACTIONS(7785),
    [anon_sym_POUNDendif2] = ACTIONS(7785),
    [anon_sym_POUNDENDIF2] = ACTIONS(7785),
    [anon_sym_POUNDEndif2] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9741),
    [sym_page_keyword] = ACTIONS(9738),
    [anon_sym_codeunit] = ACTIONS(7798),
    [anon_sym_CODEUNIT] = ACTIONS(7798),
    [anon_sym_Codeunit] = ACTIONS(7798),
    [anon_sym_CodeUnit] = ACTIONS(7798),
    [anon_sym_COdeunit] = ACTIONS(7798),
    [anon_sym_codeUnit] = ACTIONS(7798),
    [sym_report_keyword] = ACTIONS(9738),
    [sym_query_keyword] = ACTIONS(9738),
    [anon_sym_xmlport] = ACTIONS(7801),
    [anon_sym_XMLPORT] = ACTIONS(7801),
    [anon_sym_Xmlport] = ACTIONS(7801),
    [anon_sym_XMLport] = ACTIONS(7801),
    [anon_sym_XMLPort] = ACTIONS(7801),
    [anon_sym_XmlPort] = ACTIONS(7801),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_dataitem_keyword] = ACTIONS(7785),
    [sym_column_keyword] = ACTIONS(7785),
    [sym_filter_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7795),
    [sym_preproc_close] = ACTIONS(7785),
  },
  [STATE(4314)] = {
    [sym_boolean] = STATE(11132),
    [sym_option_member] = STATE(11189),
    [sym_keyword_identifier] = STATE(11132),
    [sym_codeunit_keyword] = STATE(11155),
    [sym_xmlport_keyword] = STATE(11155),
    [sym_enum_keyword] = STATE(11155),
    [sym_keyword_as_identifier] = STATE(11132),
    [sym_identifier] = ACTIONS(9149),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(9153),
    [aux_sym_boolean_token1] = ACTIONS(9155),
    [aux_sym_boolean_token2] = ACTIONS(9155),
    [aux_sym_where_condition_token1] = ACTIONS(4367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9157),
    [aux_sym_record_type_token1] = ACTIONS(9157),
    [aux_sym_basic_type_token21] = ACTIONS(9157),
    [aux_sym_basic_type_token22] = ACTIONS(9159),
    [aux_sym_basic_type_token48] = ACTIONS(9157),
    [aux_sym_basic_type_token53] = ACTIONS(4367),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4367),
    [aux_sym_separator_action_token1] = ACTIONS(4367),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4367),
    [aux_sym_type_declaration_token1] = ACTIONS(4367),
    [anon_sym_POUNDelif] = ACTIONS(611),
    [anon_sym_POUNDELIF] = ACTIONS(611),
    [anon_sym_POUNDElif] = ACTIONS(611),
    [anon_sym_POUNDelse] = ACTIONS(611),
    [anon_sym_POUNDELSE] = ACTIONS(611),
    [anon_sym_POUNDElse] = ACTIONS(611),
    [anon_sym_POUNDelse2] = ACTIONS(611),
    [anon_sym_POUNDELSE2] = ACTIONS(611),
    [anon_sym_POUNDElse2] = ACTIONS(611),
    [anon_sym_POUNDendif] = ACTIONS(611),
    [anon_sym_POUNDENDIF] = ACTIONS(611),
    [anon_sym_POUNDEndif] = ACTIONS(611),
    [anon_sym_POUNDendif2] = ACTIONS(611),
    [anon_sym_POUNDENDIF2] = ACTIONS(611),
    [anon_sym_POUNDEndif2] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9157),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9157),
    [sym_table_keyword] = ACTIONS(4367),
    [sym_page_keyword] = ACTIONS(9157),
    [anon_sym_codeunit] = ACTIONS(9161),
    [anon_sym_CODEUNIT] = ACTIONS(9161),
    [anon_sym_Codeunit] = ACTIONS(9161),
    [anon_sym_CodeUnit] = ACTIONS(9161),
    [anon_sym_COdeunit] = ACTIONS(9161),
    [anon_sym_codeUnit] = ACTIONS(9161),
    [sym_report_keyword] = ACTIONS(9157),
    [sym_query_keyword] = ACTIONS(9157),
    [anon_sym_xmlport] = ACTIONS(9163),
    [anon_sym_XMLPORT] = ACTIONS(9163),
    [anon_sym_Xmlport] = ACTIONS(9163),
    [anon_sym_XMLport] = ACTIONS(9163),
    [anon_sym_XMLPort] = ACTIONS(9163),
    [anon_sym_XmlPort] = ACTIONS(9163),
    [anon_sym_enum] = ACTIONS(9165),
    [anon_sym_ENUM] = ACTIONS(9165),
    [anon_sym_Enum] = ACTIONS(9165),
    [anon_sym_eNUM] = ACTIONS(9165),
    [anon_sym_eNum] = ACTIONS(9165),
    [anon_sym_ENum] = ACTIONS(9165),
    [sym_local_keyword] = ACTIONS(9149),
    [sym_internal_keyword] = ACTIONS(9149),
    [sym_protected_keyword] = ACTIONS(9149),
    [sym_key_keyword] = ACTIONS(4367),
    [sym_dataset_keyword] = ACTIONS(4367),
    [sym_quoted_identifier] = ACTIONS(9167),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9167),
    [sym_integer] = ACTIONS(9167),
    [sym_preproc_close] = ACTIONS(611),
  },
  [STATE(4315)] = {
    [sym_boolean] = STATE(8645),
    [sym_assignment_expression] = STATE(8645),
    [sym__expression] = STATE(8645),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8645),
    [sym_multiplicative_expression] = STATE(8645),
    [sym_additive_expression] = STATE(8645),
    [sym_comparison_expression] = STATE(8645),
    [sym_logical_expression] = STATE(8645),
    [sym_ternary_expression] = STATE(8645),
    [sym_unary_expression] = STATE(8645),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8645),
    [sym_list_literal] = STATE(8645),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8645),
    [sym__literal_value] = STATE(8645),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9744),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9746),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9748),
    [sym_date_literal] = ACTIONS(9744),
    [sym_time_literal] = ACTIONS(9744),
    [sym_biginteger_literal] = ACTIONS(9748),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9748),
    [sym_verbatim_string] = ACTIONS(9748),
    [sym_integer] = ACTIONS(9744),
    [sym_continue_as_identifier] = ACTIONS(9748),
  },
  [STATE(4316)] = {
    [sym_boolean] = STATE(8742),
    [sym_assignment_expression] = STATE(8742),
    [sym__expression] = STATE(8742),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8742),
    [sym_multiplicative_expression] = STATE(8742),
    [sym_additive_expression] = STATE(8742),
    [sym_comparison_expression] = STATE(8742),
    [sym_logical_expression] = STATE(8742),
    [sym_ternary_expression] = STATE(8742),
    [sym_unary_expression] = STATE(8742),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8742),
    [sym_list_literal] = STATE(8742),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8742),
    [sym__literal_value] = STATE(8742),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9750),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9752),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9754),
    [sym_date_literal] = ACTIONS(9750),
    [sym_time_literal] = ACTIONS(9750),
    [sym_biginteger_literal] = ACTIONS(9754),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9754),
    [sym_verbatim_string] = ACTIONS(9754),
    [sym_integer] = ACTIONS(9750),
    [sym_continue_as_identifier] = ACTIONS(9754),
  },
  [STATE(4317)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17680),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4318)] = {
    [sym_identifier] = ACTIONS(9760),
    [anon_sym_DASH] = ACTIONS(9762),
    [aux_sym_boolean_token1] = ACTIONS(9760),
    [aux_sym_boolean_token2] = ACTIONS(9760),
    [sym_decimal] = ACTIONS(9760),
    [anon_sym_LPAREN] = ACTIONS(9762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9760),
    [anon_sym_LBRACK] = ACTIONS(9762),
    [aux_sym_record_type_token1] = ACTIONS(9760),
    [aux_sym_basic_type_token21] = ACTIONS(9760),
    [aux_sym_basic_type_token22] = ACTIONS(9760),
    [aux_sym_basic_type_token48] = ACTIONS(9760),
    [anon_sym_POUNDif] = ACTIONS(9762),
    [anon_sym_POUNDIF] = ACTIONS(9762),
    [anon_sym_POUNDIf] = ACTIONS(9762),
    [anon_sym_not] = ACTIONS(9760),
    [anon_sym_NOT] = ACTIONS(9760),
    [anon_sym_Not] = ACTIONS(9760),
    [anon_sym_POUNDelif] = ACTIONS(9762),
    [anon_sym_POUNDELIF] = ACTIONS(9762),
    [anon_sym_POUNDElif] = ACTIONS(9762),
    [anon_sym_POUNDelse] = ACTIONS(9762),
    [anon_sym_POUNDELSE] = ACTIONS(9762),
    [anon_sym_POUNDElse] = ACTIONS(9762),
    [anon_sym_POUNDelse2] = ACTIONS(9762),
    [anon_sym_POUNDELSE2] = ACTIONS(9762),
    [anon_sym_POUNDElse2] = ACTIONS(9762),
    [anon_sym_POUNDendif] = ACTIONS(9762),
    [anon_sym_POUNDENDIF] = ACTIONS(9762),
    [anon_sym_POUNDEndif] = ACTIONS(9762),
    [anon_sym_POUNDendif2] = ACTIONS(9762),
    [anon_sym_POUNDENDIF2] = ACTIONS(9762),
    [anon_sym_POUNDEndif2] = ACTIONS(9762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9760),
    [anon_sym_PLUS] = ACTIONS(9762),
    [sym_datetime_literal] = ACTIONS(9762),
    [sym_date_literal] = ACTIONS(9760),
    [sym_time_literal] = ACTIONS(9760),
    [sym_biginteger_literal] = ACTIONS(9762),
    [anon_sym_else] = ACTIONS(9760),
    [anon_sym_ELSE] = ACTIONS(9760),
    [anon_sym_Else] = ACTIONS(9760),
    [sym_page_keyword] = ACTIONS(9760),
    [anon_sym_codeunit] = ACTIONS(9760),
    [anon_sym_CODEUNIT] = ACTIONS(9760),
    [anon_sym_Codeunit] = ACTIONS(9760),
    [anon_sym_CodeUnit] = ACTIONS(9760),
    [anon_sym_COdeunit] = ACTIONS(9760),
    [anon_sym_codeUnit] = ACTIONS(9760),
    [sym_report_keyword] = ACTIONS(9760),
    [sym_query_keyword] = ACTIONS(9760),
    [anon_sym_xmlport] = ACTIONS(9760),
    [anon_sym_XMLPORT] = ACTIONS(9760),
    [anon_sym_Xmlport] = ACTIONS(9760),
    [anon_sym_XMLport] = ACTIONS(9760),
    [anon_sym_XMLPort] = ACTIONS(9760),
    [anon_sym_XmlPort] = ACTIONS(9760),
    [anon_sym_enum] = ACTIONS(9760),
    [anon_sym_ENUM] = ACTIONS(9760),
    [anon_sym_Enum] = ACTIONS(9760),
    [anon_sym_eNUM] = ACTIONS(9760),
    [anon_sym_eNum] = ACTIONS(9760),
    [anon_sym_ENum] = ACTIONS(9760),
    [sym_quoted_identifier] = ACTIONS(9762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9762),
    [sym_verbatim_string] = ACTIONS(9762),
    [sym_integer] = ACTIONS(9760),
    [sym_continue_as_identifier] = ACTIONS(9762),
    [sym_preproc_open] = ACTIONS(9762),
    [sym_preproc_close] = ACTIONS(9762),
  },
  [STATE(4319)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17425),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4320)] = {
    [sym_identifier] = ACTIONS(9764),
    [anon_sym_DASH] = ACTIONS(9766),
    [aux_sym_boolean_token1] = ACTIONS(9764),
    [aux_sym_boolean_token2] = ACTIONS(9764),
    [sym_decimal] = ACTIONS(9764),
    [anon_sym_LPAREN] = ACTIONS(9766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9764),
    [anon_sym_LBRACK] = ACTIONS(9766),
    [aux_sym_record_type_token1] = ACTIONS(9764),
    [aux_sym_basic_type_token21] = ACTIONS(9764),
    [aux_sym_basic_type_token22] = ACTIONS(9764),
    [aux_sym_basic_type_token48] = ACTIONS(9764),
    [anon_sym_POUNDif] = ACTIONS(9766),
    [anon_sym_POUNDIF] = ACTIONS(9766),
    [anon_sym_POUNDIf] = ACTIONS(9766),
    [anon_sym_not] = ACTIONS(9764),
    [anon_sym_NOT] = ACTIONS(9764),
    [anon_sym_Not] = ACTIONS(9764),
    [anon_sym_POUNDelif] = ACTIONS(9766),
    [anon_sym_POUNDELIF] = ACTIONS(9766),
    [anon_sym_POUNDElif] = ACTIONS(9766),
    [anon_sym_POUNDelse] = ACTIONS(9766),
    [anon_sym_POUNDELSE] = ACTIONS(9766),
    [anon_sym_POUNDElse] = ACTIONS(9766),
    [anon_sym_POUNDelse2] = ACTIONS(9766),
    [anon_sym_POUNDELSE2] = ACTIONS(9766),
    [anon_sym_POUNDElse2] = ACTIONS(9766),
    [anon_sym_POUNDendif] = ACTIONS(9766),
    [anon_sym_POUNDENDIF] = ACTIONS(9766),
    [anon_sym_POUNDEndif] = ACTIONS(9766),
    [anon_sym_POUNDendif2] = ACTIONS(9766),
    [anon_sym_POUNDENDIF2] = ACTIONS(9766),
    [anon_sym_POUNDEndif2] = ACTIONS(9766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9764),
    [anon_sym_PLUS] = ACTIONS(9766),
    [sym_datetime_literal] = ACTIONS(9766),
    [sym_date_literal] = ACTIONS(9764),
    [sym_time_literal] = ACTIONS(9764),
    [sym_biginteger_literal] = ACTIONS(9766),
    [anon_sym_else] = ACTIONS(9764),
    [anon_sym_ELSE] = ACTIONS(9764),
    [anon_sym_Else] = ACTIONS(9764),
    [sym_page_keyword] = ACTIONS(9764),
    [anon_sym_codeunit] = ACTIONS(9764),
    [anon_sym_CODEUNIT] = ACTIONS(9764),
    [anon_sym_Codeunit] = ACTIONS(9764),
    [anon_sym_CodeUnit] = ACTIONS(9764),
    [anon_sym_COdeunit] = ACTIONS(9764),
    [anon_sym_codeUnit] = ACTIONS(9764),
    [sym_report_keyword] = ACTIONS(9764),
    [sym_query_keyword] = ACTIONS(9764),
    [anon_sym_xmlport] = ACTIONS(9764),
    [anon_sym_XMLPORT] = ACTIONS(9764),
    [anon_sym_Xmlport] = ACTIONS(9764),
    [anon_sym_XMLport] = ACTIONS(9764),
    [anon_sym_XMLPort] = ACTIONS(9764),
    [anon_sym_XmlPort] = ACTIONS(9764),
    [anon_sym_enum] = ACTIONS(9764),
    [anon_sym_ENUM] = ACTIONS(9764),
    [anon_sym_Enum] = ACTIONS(9764),
    [anon_sym_eNUM] = ACTIONS(9764),
    [anon_sym_eNum] = ACTIONS(9764),
    [anon_sym_ENum] = ACTIONS(9764),
    [sym_quoted_identifier] = ACTIONS(9766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9766),
    [sym_verbatim_string] = ACTIONS(9766),
    [sym_integer] = ACTIONS(9764),
    [sym_continue_as_identifier] = ACTIONS(9766),
    [sym_preproc_open] = ACTIONS(9766),
    [sym_preproc_close] = ACTIONS(9766),
  },
  [STATE(4321)] = {
    [sym_identifier] = ACTIONS(9768),
    [anon_sym_DASH] = ACTIONS(9770),
    [aux_sym_boolean_token1] = ACTIONS(9768),
    [aux_sym_boolean_token2] = ACTIONS(9768),
    [sym_decimal] = ACTIONS(9768),
    [anon_sym_LPAREN] = ACTIONS(9770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9768),
    [anon_sym_LBRACK] = ACTIONS(9770),
    [aux_sym_record_type_token1] = ACTIONS(9768),
    [aux_sym_basic_type_token21] = ACTIONS(9768),
    [aux_sym_basic_type_token22] = ACTIONS(9768),
    [aux_sym_basic_type_token48] = ACTIONS(9768),
    [anon_sym_POUNDif] = ACTIONS(9770),
    [anon_sym_POUNDIF] = ACTIONS(9770),
    [anon_sym_POUNDIf] = ACTIONS(9770),
    [anon_sym_not] = ACTIONS(9768),
    [anon_sym_NOT] = ACTIONS(9768),
    [anon_sym_Not] = ACTIONS(9768),
    [anon_sym_POUNDelif] = ACTIONS(9770),
    [anon_sym_POUNDELIF] = ACTIONS(9770),
    [anon_sym_POUNDElif] = ACTIONS(9770),
    [anon_sym_POUNDelse] = ACTIONS(9770),
    [anon_sym_POUNDELSE] = ACTIONS(9770),
    [anon_sym_POUNDElse] = ACTIONS(9770),
    [anon_sym_POUNDelse2] = ACTIONS(9770),
    [anon_sym_POUNDELSE2] = ACTIONS(9770),
    [anon_sym_POUNDElse2] = ACTIONS(9770),
    [anon_sym_POUNDendif] = ACTIONS(9770),
    [anon_sym_POUNDENDIF] = ACTIONS(9770),
    [anon_sym_POUNDEndif] = ACTIONS(9770),
    [anon_sym_POUNDendif2] = ACTIONS(9770),
    [anon_sym_POUNDENDIF2] = ACTIONS(9770),
    [anon_sym_POUNDEndif2] = ACTIONS(9770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9768),
    [anon_sym_PLUS] = ACTIONS(9770),
    [sym_datetime_literal] = ACTIONS(9770),
    [sym_date_literal] = ACTIONS(9768),
    [sym_time_literal] = ACTIONS(9768),
    [sym_biginteger_literal] = ACTIONS(9770),
    [anon_sym_else] = ACTIONS(9768),
    [anon_sym_ELSE] = ACTIONS(9768),
    [anon_sym_Else] = ACTIONS(9768),
    [sym_page_keyword] = ACTIONS(9768),
    [anon_sym_codeunit] = ACTIONS(9768),
    [anon_sym_CODEUNIT] = ACTIONS(9768),
    [anon_sym_Codeunit] = ACTIONS(9768),
    [anon_sym_CodeUnit] = ACTIONS(9768),
    [anon_sym_COdeunit] = ACTIONS(9768),
    [anon_sym_codeUnit] = ACTIONS(9768),
    [sym_report_keyword] = ACTIONS(9768),
    [sym_query_keyword] = ACTIONS(9768),
    [anon_sym_xmlport] = ACTIONS(9768),
    [anon_sym_XMLPORT] = ACTIONS(9768),
    [anon_sym_Xmlport] = ACTIONS(9768),
    [anon_sym_XMLport] = ACTIONS(9768),
    [anon_sym_XMLPort] = ACTIONS(9768),
    [anon_sym_XmlPort] = ACTIONS(9768),
    [anon_sym_enum] = ACTIONS(9768),
    [anon_sym_ENUM] = ACTIONS(9768),
    [anon_sym_Enum] = ACTIONS(9768),
    [anon_sym_eNUM] = ACTIONS(9768),
    [anon_sym_eNum] = ACTIONS(9768),
    [anon_sym_ENum] = ACTIONS(9768),
    [sym_quoted_identifier] = ACTIONS(9770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9770),
    [sym_verbatim_string] = ACTIONS(9770),
    [sym_integer] = ACTIONS(9768),
    [sym_continue_as_identifier] = ACTIONS(9770),
    [sym_preproc_open] = ACTIONS(9770),
    [sym_preproc_close] = ACTIONS(9770),
  },
  [STATE(4322)] = {
    [sym_identifier] = ACTIONS(9772),
    [anon_sym_DASH] = ACTIONS(9774),
    [aux_sym_boolean_token1] = ACTIONS(9772),
    [aux_sym_boolean_token2] = ACTIONS(9772),
    [sym_decimal] = ACTIONS(9772),
    [anon_sym_LPAREN] = ACTIONS(9774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9772),
    [anon_sym_LBRACK] = ACTIONS(9774),
    [aux_sym_record_type_token1] = ACTIONS(9772),
    [aux_sym_basic_type_token21] = ACTIONS(9772),
    [aux_sym_basic_type_token22] = ACTIONS(9772),
    [aux_sym_basic_type_token48] = ACTIONS(9772),
    [anon_sym_POUNDif] = ACTIONS(9774),
    [anon_sym_POUNDIF] = ACTIONS(9774),
    [anon_sym_POUNDIf] = ACTIONS(9774),
    [anon_sym_not] = ACTIONS(9772),
    [anon_sym_NOT] = ACTIONS(9772),
    [anon_sym_Not] = ACTIONS(9772),
    [anon_sym_POUNDelif] = ACTIONS(9774),
    [anon_sym_POUNDELIF] = ACTIONS(9774),
    [anon_sym_POUNDElif] = ACTIONS(9774),
    [anon_sym_POUNDelse] = ACTIONS(9774),
    [anon_sym_POUNDELSE] = ACTIONS(9774),
    [anon_sym_POUNDElse] = ACTIONS(9774),
    [anon_sym_POUNDelse2] = ACTIONS(9774),
    [anon_sym_POUNDELSE2] = ACTIONS(9774),
    [anon_sym_POUNDElse2] = ACTIONS(9774),
    [anon_sym_POUNDendif] = ACTIONS(9774),
    [anon_sym_POUNDENDIF] = ACTIONS(9774),
    [anon_sym_POUNDEndif] = ACTIONS(9774),
    [anon_sym_POUNDendif2] = ACTIONS(9774),
    [anon_sym_POUNDENDIF2] = ACTIONS(9774),
    [anon_sym_POUNDEndif2] = ACTIONS(9774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9772),
    [anon_sym_PLUS] = ACTIONS(9774),
    [sym_datetime_literal] = ACTIONS(9774),
    [sym_date_literal] = ACTIONS(9772),
    [sym_time_literal] = ACTIONS(9772),
    [sym_biginteger_literal] = ACTIONS(9774),
    [anon_sym_else] = ACTIONS(9772),
    [anon_sym_ELSE] = ACTIONS(9772),
    [anon_sym_Else] = ACTIONS(9772),
    [sym_page_keyword] = ACTIONS(9772),
    [anon_sym_codeunit] = ACTIONS(9772),
    [anon_sym_CODEUNIT] = ACTIONS(9772),
    [anon_sym_Codeunit] = ACTIONS(9772),
    [anon_sym_CodeUnit] = ACTIONS(9772),
    [anon_sym_COdeunit] = ACTIONS(9772),
    [anon_sym_codeUnit] = ACTIONS(9772),
    [sym_report_keyword] = ACTIONS(9772),
    [sym_query_keyword] = ACTIONS(9772),
    [anon_sym_xmlport] = ACTIONS(9772),
    [anon_sym_XMLPORT] = ACTIONS(9772),
    [anon_sym_Xmlport] = ACTIONS(9772),
    [anon_sym_XMLport] = ACTIONS(9772),
    [anon_sym_XMLPort] = ACTIONS(9772),
    [anon_sym_XmlPort] = ACTIONS(9772),
    [anon_sym_enum] = ACTIONS(9772),
    [anon_sym_ENUM] = ACTIONS(9772),
    [anon_sym_Enum] = ACTIONS(9772),
    [anon_sym_eNUM] = ACTIONS(9772),
    [anon_sym_eNum] = ACTIONS(9772),
    [anon_sym_ENum] = ACTIONS(9772),
    [sym_quoted_identifier] = ACTIONS(9774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9774),
    [sym_verbatim_string] = ACTIONS(9774),
    [sym_integer] = ACTIONS(9772),
    [sym_continue_as_identifier] = ACTIONS(9774),
    [sym_preproc_open] = ACTIONS(9774),
    [sym_preproc_close] = ACTIONS(9774),
  },
  [STATE(4323)] = {
    [sym_identifier] = ACTIONS(9776),
    [anon_sym_DASH] = ACTIONS(9778),
    [aux_sym_boolean_token1] = ACTIONS(9776),
    [aux_sym_boolean_token2] = ACTIONS(9776),
    [sym_decimal] = ACTIONS(9776),
    [anon_sym_LPAREN] = ACTIONS(9778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9776),
    [anon_sym_LBRACK] = ACTIONS(9778),
    [aux_sym_record_type_token1] = ACTIONS(9776),
    [aux_sym_basic_type_token21] = ACTIONS(9776),
    [aux_sym_basic_type_token22] = ACTIONS(9776),
    [aux_sym_basic_type_token48] = ACTIONS(9776),
    [anon_sym_POUNDif] = ACTIONS(9778),
    [anon_sym_POUNDIF] = ACTIONS(9778),
    [anon_sym_POUNDIf] = ACTIONS(9778),
    [anon_sym_not] = ACTIONS(9776),
    [anon_sym_NOT] = ACTIONS(9776),
    [anon_sym_Not] = ACTIONS(9776),
    [anon_sym_POUNDelif] = ACTIONS(9778),
    [anon_sym_POUNDELIF] = ACTIONS(9778),
    [anon_sym_POUNDElif] = ACTIONS(9778),
    [anon_sym_POUNDelse] = ACTIONS(9778),
    [anon_sym_POUNDELSE] = ACTIONS(9778),
    [anon_sym_POUNDElse] = ACTIONS(9778),
    [anon_sym_POUNDelse2] = ACTIONS(9778),
    [anon_sym_POUNDELSE2] = ACTIONS(9778),
    [anon_sym_POUNDElse2] = ACTIONS(9778),
    [anon_sym_POUNDendif] = ACTIONS(9778),
    [anon_sym_POUNDENDIF] = ACTIONS(9778),
    [anon_sym_POUNDEndif] = ACTIONS(9778),
    [anon_sym_POUNDendif2] = ACTIONS(9778),
    [anon_sym_POUNDENDIF2] = ACTIONS(9778),
    [anon_sym_POUNDEndif2] = ACTIONS(9778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9776),
    [anon_sym_PLUS] = ACTIONS(9778),
    [sym_datetime_literal] = ACTIONS(9778),
    [sym_date_literal] = ACTIONS(9776),
    [sym_time_literal] = ACTIONS(9776),
    [sym_biginteger_literal] = ACTIONS(9778),
    [anon_sym_else] = ACTIONS(9776),
    [anon_sym_ELSE] = ACTIONS(9776),
    [anon_sym_Else] = ACTIONS(9776),
    [sym_page_keyword] = ACTIONS(9776),
    [anon_sym_codeunit] = ACTIONS(9776),
    [anon_sym_CODEUNIT] = ACTIONS(9776),
    [anon_sym_Codeunit] = ACTIONS(9776),
    [anon_sym_CodeUnit] = ACTIONS(9776),
    [anon_sym_COdeunit] = ACTIONS(9776),
    [anon_sym_codeUnit] = ACTIONS(9776),
    [sym_report_keyword] = ACTIONS(9776),
    [sym_query_keyword] = ACTIONS(9776),
    [anon_sym_xmlport] = ACTIONS(9776),
    [anon_sym_XMLPORT] = ACTIONS(9776),
    [anon_sym_Xmlport] = ACTIONS(9776),
    [anon_sym_XMLport] = ACTIONS(9776),
    [anon_sym_XMLPort] = ACTIONS(9776),
    [anon_sym_XmlPort] = ACTIONS(9776),
    [anon_sym_enum] = ACTIONS(9776),
    [anon_sym_ENUM] = ACTIONS(9776),
    [anon_sym_Enum] = ACTIONS(9776),
    [anon_sym_eNUM] = ACTIONS(9776),
    [anon_sym_eNum] = ACTIONS(9776),
    [anon_sym_ENum] = ACTIONS(9776),
    [sym_quoted_identifier] = ACTIONS(9778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9778),
    [sym_verbatim_string] = ACTIONS(9778),
    [sym_integer] = ACTIONS(9776),
    [sym_continue_as_identifier] = ACTIONS(9778),
    [sym_preproc_open] = ACTIONS(9778),
    [sym_preproc_close] = ACTIONS(9778),
  },
  [STATE(4324)] = {
    [sym_identifier] = ACTIONS(9780),
    [anon_sym_DASH] = ACTIONS(9782),
    [aux_sym_boolean_token1] = ACTIONS(9780),
    [aux_sym_boolean_token2] = ACTIONS(9780),
    [sym_decimal] = ACTIONS(9780),
    [anon_sym_LPAREN] = ACTIONS(9782),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9780),
    [anon_sym_LBRACK] = ACTIONS(9782),
    [aux_sym_record_type_token1] = ACTIONS(9780),
    [aux_sym_basic_type_token21] = ACTIONS(9780),
    [aux_sym_basic_type_token22] = ACTIONS(9780),
    [aux_sym_basic_type_token48] = ACTIONS(9780),
    [anon_sym_POUNDif] = ACTIONS(9782),
    [anon_sym_POUNDIF] = ACTIONS(9782),
    [anon_sym_POUNDIf] = ACTIONS(9782),
    [anon_sym_not] = ACTIONS(9780),
    [anon_sym_NOT] = ACTIONS(9780),
    [anon_sym_Not] = ACTIONS(9780),
    [anon_sym_POUNDelif] = ACTIONS(9782),
    [anon_sym_POUNDELIF] = ACTIONS(9782),
    [anon_sym_POUNDElif] = ACTIONS(9782),
    [anon_sym_POUNDelse] = ACTIONS(9782),
    [anon_sym_POUNDELSE] = ACTIONS(9782),
    [anon_sym_POUNDElse] = ACTIONS(9782),
    [anon_sym_POUNDelse2] = ACTIONS(9782),
    [anon_sym_POUNDELSE2] = ACTIONS(9782),
    [anon_sym_POUNDElse2] = ACTIONS(9782),
    [anon_sym_POUNDendif] = ACTIONS(9782),
    [anon_sym_POUNDENDIF] = ACTIONS(9782),
    [anon_sym_POUNDEndif] = ACTIONS(9782),
    [anon_sym_POUNDendif2] = ACTIONS(9782),
    [anon_sym_POUNDENDIF2] = ACTIONS(9782),
    [anon_sym_POUNDEndif2] = ACTIONS(9782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9780),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9780),
    [anon_sym_PLUS] = ACTIONS(9782),
    [sym_datetime_literal] = ACTIONS(9782),
    [sym_date_literal] = ACTIONS(9780),
    [sym_time_literal] = ACTIONS(9780),
    [sym_biginteger_literal] = ACTIONS(9782),
    [anon_sym_else] = ACTIONS(9780),
    [anon_sym_ELSE] = ACTIONS(9780),
    [anon_sym_Else] = ACTIONS(9780),
    [sym_page_keyword] = ACTIONS(9780),
    [anon_sym_codeunit] = ACTIONS(9780),
    [anon_sym_CODEUNIT] = ACTIONS(9780),
    [anon_sym_Codeunit] = ACTIONS(9780),
    [anon_sym_CodeUnit] = ACTIONS(9780),
    [anon_sym_COdeunit] = ACTIONS(9780),
    [anon_sym_codeUnit] = ACTIONS(9780),
    [sym_report_keyword] = ACTIONS(9780),
    [sym_query_keyword] = ACTIONS(9780),
    [anon_sym_xmlport] = ACTIONS(9780),
    [anon_sym_XMLPORT] = ACTIONS(9780),
    [anon_sym_Xmlport] = ACTIONS(9780),
    [anon_sym_XMLport] = ACTIONS(9780),
    [anon_sym_XMLPort] = ACTIONS(9780),
    [anon_sym_XmlPort] = ACTIONS(9780),
    [anon_sym_enum] = ACTIONS(9780),
    [anon_sym_ENUM] = ACTIONS(9780),
    [anon_sym_Enum] = ACTIONS(9780),
    [anon_sym_eNUM] = ACTIONS(9780),
    [anon_sym_eNum] = ACTIONS(9780),
    [anon_sym_ENum] = ACTIONS(9780),
    [sym_quoted_identifier] = ACTIONS(9782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9782),
    [sym_verbatim_string] = ACTIONS(9782),
    [sym_integer] = ACTIONS(9780),
    [sym_continue_as_identifier] = ACTIONS(9782),
    [sym_preproc_open] = ACTIONS(9782),
    [sym_preproc_close] = ACTIONS(9782),
  },
  [STATE(4325)] = {
    [sym_identifier] = ACTIONS(9784),
    [anon_sym_DASH] = ACTIONS(9786),
    [aux_sym_boolean_token1] = ACTIONS(9784),
    [aux_sym_boolean_token2] = ACTIONS(9784),
    [sym_decimal] = ACTIONS(9784),
    [anon_sym_LPAREN] = ACTIONS(9786),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9784),
    [anon_sym_LBRACK] = ACTIONS(9786),
    [aux_sym_record_type_token1] = ACTIONS(9784),
    [aux_sym_basic_type_token21] = ACTIONS(9784),
    [aux_sym_basic_type_token22] = ACTIONS(9784),
    [aux_sym_basic_type_token48] = ACTIONS(9784),
    [anon_sym_POUNDif] = ACTIONS(9786),
    [anon_sym_POUNDIF] = ACTIONS(9786),
    [anon_sym_POUNDIf] = ACTIONS(9786),
    [anon_sym_not] = ACTIONS(9784),
    [anon_sym_NOT] = ACTIONS(9784),
    [anon_sym_Not] = ACTIONS(9784),
    [anon_sym_POUNDelif] = ACTIONS(9786),
    [anon_sym_POUNDELIF] = ACTIONS(9786),
    [anon_sym_POUNDElif] = ACTIONS(9786),
    [anon_sym_POUNDelse] = ACTIONS(9786),
    [anon_sym_POUNDELSE] = ACTIONS(9786),
    [anon_sym_POUNDElse] = ACTIONS(9786),
    [anon_sym_POUNDelse2] = ACTIONS(9786),
    [anon_sym_POUNDELSE2] = ACTIONS(9786),
    [anon_sym_POUNDElse2] = ACTIONS(9786),
    [anon_sym_POUNDendif] = ACTIONS(9786),
    [anon_sym_POUNDENDIF] = ACTIONS(9786),
    [anon_sym_POUNDEndif] = ACTIONS(9786),
    [anon_sym_POUNDendif2] = ACTIONS(9786),
    [anon_sym_POUNDENDIF2] = ACTIONS(9786),
    [anon_sym_POUNDEndif2] = ACTIONS(9786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9784),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9784),
    [anon_sym_PLUS] = ACTIONS(9786),
    [sym_datetime_literal] = ACTIONS(9786),
    [sym_date_literal] = ACTIONS(9784),
    [sym_time_literal] = ACTIONS(9784),
    [sym_biginteger_literal] = ACTIONS(9786),
    [anon_sym_else] = ACTIONS(9784),
    [anon_sym_ELSE] = ACTIONS(9784),
    [anon_sym_Else] = ACTIONS(9784),
    [sym_page_keyword] = ACTIONS(9784),
    [anon_sym_codeunit] = ACTIONS(9784),
    [anon_sym_CODEUNIT] = ACTIONS(9784),
    [anon_sym_Codeunit] = ACTIONS(9784),
    [anon_sym_CodeUnit] = ACTIONS(9784),
    [anon_sym_COdeunit] = ACTIONS(9784),
    [anon_sym_codeUnit] = ACTIONS(9784),
    [sym_report_keyword] = ACTIONS(9784),
    [sym_query_keyword] = ACTIONS(9784),
    [anon_sym_xmlport] = ACTIONS(9784),
    [anon_sym_XMLPORT] = ACTIONS(9784),
    [anon_sym_Xmlport] = ACTIONS(9784),
    [anon_sym_XMLport] = ACTIONS(9784),
    [anon_sym_XMLPort] = ACTIONS(9784),
    [anon_sym_XmlPort] = ACTIONS(9784),
    [anon_sym_enum] = ACTIONS(9784),
    [anon_sym_ENUM] = ACTIONS(9784),
    [anon_sym_Enum] = ACTIONS(9784),
    [anon_sym_eNUM] = ACTIONS(9784),
    [anon_sym_eNum] = ACTIONS(9784),
    [anon_sym_ENum] = ACTIONS(9784),
    [sym_quoted_identifier] = ACTIONS(9786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9786),
    [sym_verbatim_string] = ACTIONS(9786),
    [sym_integer] = ACTIONS(9784),
    [sym_continue_as_identifier] = ACTIONS(9786),
    [sym_preproc_open] = ACTIONS(9786),
    [sym_preproc_close] = ACTIONS(9786),
  },
  [STATE(4326)] = {
    [sym__layout_element] = STATE(4607),
    [sym_area_section] = STATE(4607),
    [sym_group_section] = STATE(4607),
    [sym_repeater_section] = STATE(4607),
    [sym_cuegroup_section] = STATE(4607),
    [sym_fixed_section] = STATE(4607),
    [sym_grid_section] = STATE(4607),
    [sym_page_field] = STATE(4607),
    [sym_part_section] = STATE(4607),
    [sym_systempart_section] = STATE(4607),
    [sym_usercontrol_section] = STATE(4607),
    [sym_preproc_split_field] = STATE(4607),
    [sym__field_header] = STATE(10667),
    [sym_label_section] = STATE(4607),
    [sym_addfirst_modification] = STATE(4607),
    [sym_addlast_modification] = STATE(4607),
    [sym_addafter_modification] = STATE(4607),
    [sym_addbefore_modification] = STATE(4607),
    [sym_modify_modification] = STATE(4607),
    [sym_movefirst_modification] = STATE(4607),
    [sym_movelast_modification] = STATE(4607),
    [sym_moveafter_modification] = STATE(4607),
    [sym_movebefore_modification] = STATE(4607),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6512),
    [sym_preproc_endif] = STATE(10155),
    [sym_preproc_conditional_layout] = STATE(4607),
    [aux_sym_layout_section_repeat1] = STATE(4607),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10715),
    [anon_sym_RBRACE] = ACTIONS(9788),
    [aux_sym_where_condition_token1] = ACTIONS(9790),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4327)] = {
    [sym_identifier] = ACTIONS(9802),
    [anon_sym_DASH] = ACTIONS(9804),
    [aux_sym_boolean_token1] = ACTIONS(9802),
    [aux_sym_boolean_token2] = ACTIONS(9802),
    [sym_decimal] = ACTIONS(9802),
    [anon_sym_LPAREN] = ACTIONS(9804),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9802),
    [anon_sym_LBRACK] = ACTIONS(9804),
    [aux_sym_record_type_token1] = ACTIONS(9802),
    [aux_sym_basic_type_token21] = ACTIONS(9802),
    [aux_sym_basic_type_token22] = ACTIONS(9802),
    [aux_sym_basic_type_token48] = ACTIONS(9802),
    [anon_sym_POUNDif] = ACTIONS(9804),
    [anon_sym_POUNDIF] = ACTIONS(9804),
    [anon_sym_POUNDIf] = ACTIONS(9804),
    [anon_sym_not] = ACTIONS(9802),
    [anon_sym_NOT] = ACTIONS(9802),
    [anon_sym_Not] = ACTIONS(9802),
    [anon_sym_POUNDelif] = ACTIONS(9804),
    [anon_sym_POUNDELIF] = ACTIONS(9804),
    [anon_sym_POUNDElif] = ACTIONS(9804),
    [anon_sym_POUNDelse] = ACTIONS(9804),
    [anon_sym_POUNDELSE] = ACTIONS(9804),
    [anon_sym_POUNDElse] = ACTIONS(9804),
    [anon_sym_POUNDelse2] = ACTIONS(9804),
    [anon_sym_POUNDELSE2] = ACTIONS(9804),
    [anon_sym_POUNDElse2] = ACTIONS(9804),
    [anon_sym_POUNDendif] = ACTIONS(9804),
    [anon_sym_POUNDENDIF] = ACTIONS(9804),
    [anon_sym_POUNDEndif] = ACTIONS(9804),
    [anon_sym_POUNDendif2] = ACTIONS(9804),
    [anon_sym_POUNDENDIF2] = ACTIONS(9804),
    [anon_sym_POUNDEndif2] = ACTIONS(9804),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9802),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9802),
    [anon_sym_PLUS] = ACTIONS(9804),
    [sym_datetime_literal] = ACTIONS(9804),
    [sym_date_literal] = ACTIONS(9802),
    [sym_time_literal] = ACTIONS(9802),
    [sym_biginteger_literal] = ACTIONS(9804),
    [anon_sym_else] = ACTIONS(9802),
    [anon_sym_ELSE] = ACTIONS(9802),
    [anon_sym_Else] = ACTIONS(9802),
    [sym_page_keyword] = ACTIONS(9802),
    [anon_sym_codeunit] = ACTIONS(9802),
    [anon_sym_CODEUNIT] = ACTIONS(9802),
    [anon_sym_Codeunit] = ACTIONS(9802),
    [anon_sym_CodeUnit] = ACTIONS(9802),
    [anon_sym_COdeunit] = ACTIONS(9802),
    [anon_sym_codeUnit] = ACTIONS(9802),
    [sym_report_keyword] = ACTIONS(9802),
    [sym_query_keyword] = ACTIONS(9802),
    [anon_sym_xmlport] = ACTIONS(9802),
    [anon_sym_XMLPORT] = ACTIONS(9802),
    [anon_sym_Xmlport] = ACTIONS(9802),
    [anon_sym_XMLport] = ACTIONS(9802),
    [anon_sym_XMLPort] = ACTIONS(9802),
    [anon_sym_XmlPort] = ACTIONS(9802),
    [anon_sym_enum] = ACTIONS(9802),
    [anon_sym_ENUM] = ACTIONS(9802),
    [anon_sym_Enum] = ACTIONS(9802),
    [anon_sym_eNUM] = ACTIONS(9802),
    [anon_sym_eNum] = ACTIONS(9802),
    [anon_sym_ENum] = ACTIONS(9802),
    [sym_quoted_identifier] = ACTIONS(9804),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9804),
    [sym_verbatim_string] = ACTIONS(9804),
    [sym_integer] = ACTIONS(9802),
    [sym_continue_as_identifier] = ACTIONS(9804),
    [sym_preproc_open] = ACTIONS(9804),
    [sym_preproc_close] = ACTIONS(9804),
  },
  [STATE(4328)] = {
    [sym_identifier] = ACTIONS(9764),
    [anon_sym_DASH] = ACTIONS(9766),
    [aux_sym_boolean_token1] = ACTIONS(9764),
    [aux_sym_boolean_token2] = ACTIONS(9764),
    [sym_decimal] = ACTIONS(9764),
    [anon_sym_LPAREN] = ACTIONS(9766),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9764),
    [anon_sym_LBRACK] = ACTIONS(9766),
    [aux_sym_record_type_token1] = ACTIONS(9764),
    [aux_sym_basic_type_token21] = ACTIONS(9764),
    [aux_sym_basic_type_token22] = ACTIONS(9764),
    [aux_sym_basic_type_token48] = ACTIONS(9764),
    [anon_sym_POUNDif] = ACTIONS(9766),
    [anon_sym_POUNDIF] = ACTIONS(9766),
    [anon_sym_POUNDIf] = ACTIONS(9766),
    [anon_sym_not] = ACTIONS(9764),
    [anon_sym_NOT] = ACTIONS(9764),
    [anon_sym_Not] = ACTIONS(9764),
    [anon_sym_POUNDelif] = ACTIONS(9766),
    [anon_sym_POUNDELIF] = ACTIONS(9766),
    [anon_sym_POUNDElif] = ACTIONS(9766),
    [anon_sym_POUNDelse] = ACTIONS(9766),
    [anon_sym_POUNDELSE] = ACTIONS(9766),
    [anon_sym_POUNDElse] = ACTIONS(9766),
    [anon_sym_POUNDelse2] = ACTIONS(9766),
    [anon_sym_POUNDELSE2] = ACTIONS(9766),
    [anon_sym_POUNDElse2] = ACTIONS(9766),
    [anon_sym_POUNDendif] = ACTIONS(9766),
    [anon_sym_POUNDENDIF] = ACTIONS(9766),
    [anon_sym_POUNDEndif] = ACTIONS(9766),
    [anon_sym_POUNDendif2] = ACTIONS(9766),
    [anon_sym_POUNDENDIF2] = ACTIONS(9766),
    [anon_sym_POUNDEndif2] = ACTIONS(9766),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9764),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9764),
    [anon_sym_PLUS] = ACTIONS(9766),
    [sym_datetime_literal] = ACTIONS(9766),
    [sym_date_literal] = ACTIONS(9764),
    [sym_time_literal] = ACTIONS(9764),
    [sym_biginteger_literal] = ACTIONS(9766),
    [anon_sym_else] = ACTIONS(9764),
    [anon_sym_ELSE] = ACTIONS(9764),
    [anon_sym_Else] = ACTIONS(9764),
    [sym_page_keyword] = ACTIONS(9764),
    [anon_sym_codeunit] = ACTIONS(9764),
    [anon_sym_CODEUNIT] = ACTIONS(9764),
    [anon_sym_Codeunit] = ACTIONS(9764),
    [anon_sym_CodeUnit] = ACTIONS(9764),
    [anon_sym_COdeunit] = ACTIONS(9764),
    [anon_sym_codeUnit] = ACTIONS(9764),
    [sym_report_keyword] = ACTIONS(9764),
    [sym_query_keyword] = ACTIONS(9764),
    [anon_sym_xmlport] = ACTIONS(9764),
    [anon_sym_XMLPORT] = ACTIONS(9764),
    [anon_sym_Xmlport] = ACTIONS(9764),
    [anon_sym_XMLport] = ACTIONS(9764),
    [anon_sym_XMLPort] = ACTIONS(9764),
    [anon_sym_XmlPort] = ACTIONS(9764),
    [anon_sym_enum] = ACTIONS(9764),
    [anon_sym_ENUM] = ACTIONS(9764),
    [anon_sym_Enum] = ACTIONS(9764),
    [anon_sym_eNUM] = ACTIONS(9764),
    [anon_sym_eNum] = ACTIONS(9764),
    [anon_sym_ENum] = ACTIONS(9764),
    [sym_quoted_identifier] = ACTIONS(9766),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9766),
    [sym_verbatim_string] = ACTIONS(9766),
    [sym_integer] = ACTIONS(9764),
    [sym_continue_as_identifier] = ACTIONS(9766),
    [sym_preproc_open] = ACTIONS(9766),
    [sym_preproc_close] = ACTIONS(9766),
  },
  [STATE(4329)] = {
    [sym_identifier] = ACTIONS(9768),
    [anon_sym_DASH] = ACTIONS(9770),
    [aux_sym_boolean_token1] = ACTIONS(9768),
    [aux_sym_boolean_token2] = ACTIONS(9768),
    [sym_decimal] = ACTIONS(9768),
    [anon_sym_LPAREN] = ACTIONS(9770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9768),
    [anon_sym_LBRACK] = ACTIONS(9770),
    [aux_sym_record_type_token1] = ACTIONS(9768),
    [aux_sym_basic_type_token21] = ACTIONS(9768),
    [aux_sym_basic_type_token22] = ACTIONS(9768),
    [aux_sym_basic_type_token48] = ACTIONS(9768),
    [anon_sym_POUNDif] = ACTIONS(9770),
    [anon_sym_POUNDIF] = ACTIONS(9770),
    [anon_sym_POUNDIf] = ACTIONS(9770),
    [anon_sym_not] = ACTIONS(9768),
    [anon_sym_NOT] = ACTIONS(9768),
    [anon_sym_Not] = ACTIONS(9768),
    [anon_sym_POUNDelif] = ACTIONS(9770),
    [anon_sym_POUNDELIF] = ACTIONS(9770),
    [anon_sym_POUNDElif] = ACTIONS(9770),
    [anon_sym_POUNDelse] = ACTIONS(9770),
    [anon_sym_POUNDELSE] = ACTIONS(9770),
    [anon_sym_POUNDElse] = ACTIONS(9770),
    [anon_sym_POUNDelse2] = ACTIONS(9770),
    [anon_sym_POUNDELSE2] = ACTIONS(9770),
    [anon_sym_POUNDElse2] = ACTIONS(9770),
    [anon_sym_POUNDendif] = ACTIONS(9770),
    [anon_sym_POUNDENDIF] = ACTIONS(9770),
    [anon_sym_POUNDEndif] = ACTIONS(9770),
    [anon_sym_POUNDendif2] = ACTIONS(9770),
    [anon_sym_POUNDENDIF2] = ACTIONS(9770),
    [anon_sym_POUNDEndif2] = ACTIONS(9770),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9768),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9768),
    [anon_sym_PLUS] = ACTIONS(9770),
    [sym_datetime_literal] = ACTIONS(9770),
    [sym_date_literal] = ACTIONS(9768),
    [sym_time_literal] = ACTIONS(9768),
    [sym_biginteger_literal] = ACTIONS(9770),
    [anon_sym_else] = ACTIONS(9768),
    [anon_sym_ELSE] = ACTIONS(9768),
    [anon_sym_Else] = ACTIONS(9768),
    [sym_page_keyword] = ACTIONS(9768),
    [anon_sym_codeunit] = ACTIONS(9768),
    [anon_sym_CODEUNIT] = ACTIONS(9768),
    [anon_sym_Codeunit] = ACTIONS(9768),
    [anon_sym_CodeUnit] = ACTIONS(9768),
    [anon_sym_COdeunit] = ACTIONS(9768),
    [anon_sym_codeUnit] = ACTIONS(9768),
    [sym_report_keyword] = ACTIONS(9768),
    [sym_query_keyword] = ACTIONS(9768),
    [anon_sym_xmlport] = ACTIONS(9768),
    [anon_sym_XMLPORT] = ACTIONS(9768),
    [anon_sym_Xmlport] = ACTIONS(9768),
    [anon_sym_XMLport] = ACTIONS(9768),
    [anon_sym_XMLPort] = ACTIONS(9768),
    [anon_sym_XmlPort] = ACTIONS(9768),
    [anon_sym_enum] = ACTIONS(9768),
    [anon_sym_ENUM] = ACTIONS(9768),
    [anon_sym_Enum] = ACTIONS(9768),
    [anon_sym_eNUM] = ACTIONS(9768),
    [anon_sym_eNum] = ACTIONS(9768),
    [anon_sym_ENum] = ACTIONS(9768),
    [sym_quoted_identifier] = ACTIONS(9770),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9770),
    [sym_verbatim_string] = ACTIONS(9770),
    [sym_integer] = ACTIONS(9768),
    [sym_continue_as_identifier] = ACTIONS(9770),
    [sym_preproc_open] = ACTIONS(9770),
    [sym_preproc_close] = ACTIONS(9770),
  },
  [STATE(4330)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(4382),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(9806),
    [aux_sym_where_clause_token1] = ACTIONS(3695),
    [aux_sym_where_condition_token1] = ACTIONS(3693),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3695),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3695),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3695),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [aux_sym_basic_type_token6] = ACTIONS(3693),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3695),
    [aux_sym_addafter_modification_token1] = ACTIONS(3695),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3695),
    [aux_sym_modify_modification_token1] = ACTIONS(3695),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3695),
    [aux_sym_movelast_modification_token1] = ACTIONS(3695),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3695),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3695),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3695),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [anon_sym_POUNDelif] = ACTIONS(3695),
    [anon_sym_POUNDELIF] = ACTIONS(3695),
    [anon_sym_POUNDElif] = ACTIONS(3695),
    [anon_sym_POUNDelse] = ACTIONS(3695),
    [anon_sym_POUNDELSE] = ACTIONS(3695),
    [anon_sym_POUNDElse] = ACTIONS(3695),
    [anon_sym_POUNDelse2] = ACTIONS(3695),
    [anon_sym_POUNDELSE2] = ACTIONS(3695),
    [anon_sym_POUNDElse2] = ACTIONS(3695),
    [anon_sym_POUNDendif] = ACTIONS(3695),
    [anon_sym_POUNDENDIF] = ACTIONS(3695),
    [anon_sym_POUNDEndif] = ACTIONS(3695),
    [anon_sym_POUNDendif2] = ACTIONS(3695),
    [anon_sym_POUNDENDIF2] = ACTIONS(3695),
    [anon_sym_POUNDEndif2] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3695),
    [sym_trigger_keyword] = ACTIONS(3695),
    [sym_var_keyword] = ACTIONS(3695),
    [sym_local_keyword] = ACTIONS(3695),
    [sym_internal_keyword] = ACTIONS(3695),
    [sym_protected_keyword] = ACTIONS(3695),
    [sym_event_keyword] = ACTIONS(3695),
    [sym_fields_keyword] = ACTIONS(3695),
    [sym_keys_keyword] = ACTIONS(3695),
    [sym_fieldgroups_keyword] = ACTIONS(3695),
    [sym_actions_keyword] = ACTIONS(3695),
    [sym_layout_keyword] = ACTIONS(3695),
    [sym_area_keyword] = ACTIONS(3695),
    [sym_group_keyword] = ACTIONS(3695),
    [sym_repeater_keyword] = ACTIONS(3695),
    [sym_cuegroup_keyword] = ACTIONS(3695),
    [sym_fixed_keyword] = ACTIONS(3695),
    [sym_grid_keyword] = ACTIONS(3695),
    [sym_part_keyword] = ACTIONS(3695),
    [sym_systempart_keyword] = ACTIONS(3695),
    [sym_usercontrol_keyword] = ACTIONS(3695),
    [sym_dataset_keyword] = ACTIONS(3695),
    [sym_elements_keyword] = ACTIONS(3695),
    [sym_dataitem_keyword] = ACTIONS(3695),
    [sym_column_keyword] = ACTIONS(3695),
    [sym_filter_keyword] = ACTIONS(3695),
    [sym_labels_keyword] = ACTIONS(3695),
    [sym_rendering_keyword] = ACTIONS(3695),
    [sym_requestpage_keyword] = ACTIONS(3695),
    [sym_schema_keyword] = ACTIONS(3695),
    [sym_views_keyword] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
    [sym_preproc_close] = ACTIONS(3695),
  },
  [STATE(4331)] = {
    [sym_identifier] = ACTIONS(9772),
    [anon_sym_DASH] = ACTIONS(9774),
    [aux_sym_boolean_token1] = ACTIONS(9772),
    [aux_sym_boolean_token2] = ACTIONS(9772),
    [sym_decimal] = ACTIONS(9772),
    [anon_sym_LPAREN] = ACTIONS(9774),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9772),
    [anon_sym_LBRACK] = ACTIONS(9774),
    [aux_sym_record_type_token1] = ACTIONS(9772),
    [aux_sym_basic_type_token21] = ACTIONS(9772),
    [aux_sym_basic_type_token22] = ACTIONS(9772),
    [aux_sym_basic_type_token48] = ACTIONS(9772),
    [anon_sym_POUNDif] = ACTIONS(9774),
    [anon_sym_POUNDIF] = ACTIONS(9774),
    [anon_sym_POUNDIf] = ACTIONS(9774),
    [anon_sym_not] = ACTIONS(9772),
    [anon_sym_NOT] = ACTIONS(9772),
    [anon_sym_Not] = ACTIONS(9772),
    [anon_sym_POUNDelif] = ACTIONS(9774),
    [anon_sym_POUNDELIF] = ACTIONS(9774),
    [anon_sym_POUNDElif] = ACTIONS(9774),
    [anon_sym_POUNDelse] = ACTIONS(9774),
    [anon_sym_POUNDELSE] = ACTIONS(9774),
    [anon_sym_POUNDElse] = ACTIONS(9774),
    [anon_sym_POUNDelse2] = ACTIONS(9774),
    [anon_sym_POUNDELSE2] = ACTIONS(9774),
    [anon_sym_POUNDElse2] = ACTIONS(9774),
    [anon_sym_POUNDendif] = ACTIONS(9774),
    [anon_sym_POUNDENDIF] = ACTIONS(9774),
    [anon_sym_POUNDEndif] = ACTIONS(9774),
    [anon_sym_POUNDendif2] = ACTIONS(9774),
    [anon_sym_POUNDENDIF2] = ACTIONS(9774),
    [anon_sym_POUNDEndif2] = ACTIONS(9774),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9772),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9772),
    [anon_sym_PLUS] = ACTIONS(9774),
    [sym_datetime_literal] = ACTIONS(9774),
    [sym_date_literal] = ACTIONS(9772),
    [sym_time_literal] = ACTIONS(9772),
    [sym_biginteger_literal] = ACTIONS(9774),
    [anon_sym_else] = ACTIONS(9772),
    [anon_sym_ELSE] = ACTIONS(9772),
    [anon_sym_Else] = ACTIONS(9772),
    [sym_page_keyword] = ACTIONS(9772),
    [anon_sym_codeunit] = ACTIONS(9772),
    [anon_sym_CODEUNIT] = ACTIONS(9772),
    [anon_sym_Codeunit] = ACTIONS(9772),
    [anon_sym_CodeUnit] = ACTIONS(9772),
    [anon_sym_COdeunit] = ACTIONS(9772),
    [anon_sym_codeUnit] = ACTIONS(9772),
    [sym_report_keyword] = ACTIONS(9772),
    [sym_query_keyword] = ACTIONS(9772),
    [anon_sym_xmlport] = ACTIONS(9772),
    [anon_sym_XMLPORT] = ACTIONS(9772),
    [anon_sym_Xmlport] = ACTIONS(9772),
    [anon_sym_XMLport] = ACTIONS(9772),
    [anon_sym_XMLPort] = ACTIONS(9772),
    [anon_sym_XmlPort] = ACTIONS(9772),
    [anon_sym_enum] = ACTIONS(9772),
    [anon_sym_ENUM] = ACTIONS(9772),
    [anon_sym_Enum] = ACTIONS(9772),
    [anon_sym_eNUM] = ACTIONS(9772),
    [anon_sym_eNum] = ACTIONS(9772),
    [anon_sym_ENum] = ACTIONS(9772),
    [sym_quoted_identifier] = ACTIONS(9774),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9774),
    [sym_verbatim_string] = ACTIONS(9774),
    [sym_integer] = ACTIONS(9772),
    [sym_continue_as_identifier] = ACTIONS(9774),
    [sym_preproc_open] = ACTIONS(9774),
    [sym_preproc_close] = ACTIONS(9774),
  },
  [STATE(4332)] = {
    [sym_identifier] = ACTIONS(9808),
    [anon_sym_DASH] = ACTIONS(9810),
    [aux_sym_boolean_token1] = ACTIONS(9808),
    [aux_sym_boolean_token2] = ACTIONS(9808),
    [sym_decimal] = ACTIONS(9808),
    [anon_sym_LPAREN] = ACTIONS(9810),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9808),
    [anon_sym_LBRACK] = ACTIONS(9810),
    [aux_sym_record_type_token1] = ACTIONS(9808),
    [aux_sym_basic_type_token21] = ACTIONS(9808),
    [aux_sym_basic_type_token22] = ACTIONS(9808),
    [aux_sym_basic_type_token48] = ACTIONS(9808),
    [anon_sym_POUNDif] = ACTIONS(9810),
    [anon_sym_POUNDIF] = ACTIONS(9810),
    [anon_sym_POUNDIf] = ACTIONS(9810),
    [anon_sym_not] = ACTIONS(9808),
    [anon_sym_NOT] = ACTIONS(9808),
    [anon_sym_Not] = ACTIONS(9808),
    [anon_sym_POUNDelif] = ACTIONS(9810),
    [anon_sym_POUNDELIF] = ACTIONS(9810),
    [anon_sym_POUNDElif] = ACTIONS(9810),
    [anon_sym_POUNDelse] = ACTIONS(9810),
    [anon_sym_POUNDELSE] = ACTIONS(9810),
    [anon_sym_POUNDElse] = ACTIONS(9810),
    [anon_sym_POUNDelse2] = ACTIONS(9810),
    [anon_sym_POUNDELSE2] = ACTIONS(9810),
    [anon_sym_POUNDElse2] = ACTIONS(9810),
    [anon_sym_POUNDendif] = ACTIONS(9810),
    [anon_sym_POUNDENDIF] = ACTIONS(9810),
    [anon_sym_POUNDEndif] = ACTIONS(9810),
    [anon_sym_POUNDendif2] = ACTIONS(9810),
    [anon_sym_POUNDENDIF2] = ACTIONS(9810),
    [anon_sym_POUNDEndif2] = ACTIONS(9810),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9808),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9808),
    [anon_sym_PLUS] = ACTIONS(9810),
    [sym_datetime_literal] = ACTIONS(9810),
    [sym_date_literal] = ACTIONS(9808),
    [sym_time_literal] = ACTIONS(9808),
    [sym_biginteger_literal] = ACTIONS(9810),
    [anon_sym_else] = ACTIONS(9808),
    [anon_sym_ELSE] = ACTIONS(9808),
    [anon_sym_Else] = ACTIONS(9808),
    [sym_page_keyword] = ACTIONS(9808),
    [anon_sym_codeunit] = ACTIONS(9808),
    [anon_sym_CODEUNIT] = ACTIONS(9808),
    [anon_sym_Codeunit] = ACTIONS(9808),
    [anon_sym_CodeUnit] = ACTIONS(9808),
    [anon_sym_COdeunit] = ACTIONS(9808),
    [anon_sym_codeUnit] = ACTIONS(9808),
    [sym_report_keyword] = ACTIONS(9808),
    [sym_query_keyword] = ACTIONS(9808),
    [anon_sym_xmlport] = ACTIONS(9808),
    [anon_sym_XMLPORT] = ACTIONS(9808),
    [anon_sym_Xmlport] = ACTIONS(9808),
    [anon_sym_XMLport] = ACTIONS(9808),
    [anon_sym_XMLPort] = ACTIONS(9808),
    [anon_sym_XmlPort] = ACTIONS(9808),
    [anon_sym_enum] = ACTIONS(9808),
    [anon_sym_ENUM] = ACTIONS(9808),
    [anon_sym_Enum] = ACTIONS(9808),
    [anon_sym_eNUM] = ACTIONS(9808),
    [anon_sym_eNum] = ACTIONS(9808),
    [anon_sym_ENum] = ACTIONS(9808),
    [sym_quoted_identifier] = ACTIONS(9810),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9810),
    [sym_verbatim_string] = ACTIONS(9810),
    [sym_integer] = ACTIONS(9808),
    [sym_continue_as_identifier] = ACTIONS(9810),
    [sym_preproc_open] = ACTIONS(9810),
    [sym_preproc_close] = ACTIONS(9810),
  },
  [STATE(4333)] = {
    [sym_identifier] = ACTIONS(9812),
    [anon_sym_DASH] = ACTIONS(9814),
    [aux_sym_boolean_token1] = ACTIONS(9812),
    [aux_sym_boolean_token2] = ACTIONS(9812),
    [sym_decimal] = ACTIONS(9812),
    [anon_sym_LPAREN] = ACTIONS(9814),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9812),
    [anon_sym_LBRACK] = ACTIONS(9814),
    [aux_sym_record_type_token1] = ACTIONS(9812),
    [aux_sym_basic_type_token21] = ACTIONS(9812),
    [aux_sym_basic_type_token22] = ACTIONS(9812),
    [aux_sym_basic_type_token48] = ACTIONS(9812),
    [anon_sym_POUNDif] = ACTIONS(9814),
    [anon_sym_POUNDIF] = ACTIONS(9814),
    [anon_sym_POUNDIf] = ACTIONS(9814),
    [anon_sym_not] = ACTIONS(9812),
    [anon_sym_NOT] = ACTIONS(9812),
    [anon_sym_Not] = ACTIONS(9812),
    [anon_sym_POUNDelif] = ACTIONS(9814),
    [anon_sym_POUNDELIF] = ACTIONS(9814),
    [anon_sym_POUNDElif] = ACTIONS(9814),
    [anon_sym_POUNDelse] = ACTIONS(9814),
    [anon_sym_POUNDELSE] = ACTIONS(9814),
    [anon_sym_POUNDElse] = ACTIONS(9814),
    [anon_sym_POUNDelse2] = ACTIONS(9814),
    [anon_sym_POUNDELSE2] = ACTIONS(9814),
    [anon_sym_POUNDElse2] = ACTIONS(9814),
    [anon_sym_POUNDendif] = ACTIONS(9814),
    [anon_sym_POUNDENDIF] = ACTIONS(9814),
    [anon_sym_POUNDEndif] = ACTIONS(9814),
    [anon_sym_POUNDendif2] = ACTIONS(9814),
    [anon_sym_POUNDENDIF2] = ACTIONS(9814),
    [anon_sym_POUNDEndif2] = ACTIONS(9814),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9812),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9812),
    [anon_sym_PLUS] = ACTIONS(9814),
    [sym_datetime_literal] = ACTIONS(9814),
    [sym_date_literal] = ACTIONS(9812),
    [sym_time_literal] = ACTIONS(9812),
    [sym_biginteger_literal] = ACTIONS(9814),
    [anon_sym_else] = ACTIONS(9812),
    [anon_sym_ELSE] = ACTIONS(9812),
    [anon_sym_Else] = ACTIONS(9812),
    [sym_page_keyword] = ACTIONS(9812),
    [anon_sym_codeunit] = ACTIONS(9812),
    [anon_sym_CODEUNIT] = ACTIONS(9812),
    [anon_sym_Codeunit] = ACTIONS(9812),
    [anon_sym_CodeUnit] = ACTIONS(9812),
    [anon_sym_COdeunit] = ACTIONS(9812),
    [anon_sym_codeUnit] = ACTIONS(9812),
    [sym_report_keyword] = ACTIONS(9812),
    [sym_query_keyword] = ACTIONS(9812),
    [anon_sym_xmlport] = ACTIONS(9812),
    [anon_sym_XMLPORT] = ACTIONS(9812),
    [anon_sym_Xmlport] = ACTIONS(9812),
    [anon_sym_XMLport] = ACTIONS(9812),
    [anon_sym_XMLPort] = ACTIONS(9812),
    [anon_sym_XmlPort] = ACTIONS(9812),
    [anon_sym_enum] = ACTIONS(9812),
    [anon_sym_ENUM] = ACTIONS(9812),
    [anon_sym_Enum] = ACTIONS(9812),
    [anon_sym_eNUM] = ACTIONS(9812),
    [anon_sym_eNum] = ACTIONS(9812),
    [anon_sym_ENum] = ACTIONS(9812),
    [sym_quoted_identifier] = ACTIONS(9814),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9814),
    [sym_verbatim_string] = ACTIONS(9814),
    [sym_integer] = ACTIONS(9812),
    [sym_continue_as_identifier] = ACTIONS(9814),
    [sym_preproc_open] = ACTIONS(9814),
    [sym_preproc_close] = ACTIONS(9814),
  },
  [STATE(4334)] = {
    [sym_identifier] = ACTIONS(9816),
    [anon_sym_DASH] = ACTIONS(9818),
    [aux_sym_boolean_token1] = ACTIONS(9816),
    [aux_sym_boolean_token2] = ACTIONS(9816),
    [sym_decimal] = ACTIONS(9816),
    [anon_sym_LPAREN] = ACTIONS(9818),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9816),
    [anon_sym_LBRACK] = ACTIONS(9818),
    [aux_sym_record_type_token1] = ACTIONS(9816),
    [aux_sym_basic_type_token21] = ACTIONS(9816),
    [aux_sym_basic_type_token22] = ACTIONS(9816),
    [aux_sym_basic_type_token48] = ACTIONS(9816),
    [anon_sym_POUNDif] = ACTIONS(9818),
    [anon_sym_POUNDIF] = ACTIONS(9818),
    [anon_sym_POUNDIf] = ACTIONS(9818),
    [anon_sym_not] = ACTIONS(9816),
    [anon_sym_NOT] = ACTIONS(9816),
    [anon_sym_Not] = ACTIONS(9816),
    [anon_sym_POUNDelif] = ACTIONS(9818),
    [anon_sym_POUNDELIF] = ACTIONS(9818),
    [anon_sym_POUNDElif] = ACTIONS(9818),
    [anon_sym_POUNDelse] = ACTIONS(9818),
    [anon_sym_POUNDELSE] = ACTIONS(9818),
    [anon_sym_POUNDElse] = ACTIONS(9818),
    [anon_sym_POUNDelse2] = ACTIONS(9818),
    [anon_sym_POUNDELSE2] = ACTIONS(9818),
    [anon_sym_POUNDElse2] = ACTIONS(9818),
    [anon_sym_POUNDendif] = ACTIONS(9818),
    [anon_sym_POUNDENDIF] = ACTIONS(9818),
    [anon_sym_POUNDEndif] = ACTIONS(9818),
    [anon_sym_POUNDendif2] = ACTIONS(9818),
    [anon_sym_POUNDENDIF2] = ACTIONS(9818),
    [anon_sym_POUNDEndif2] = ACTIONS(9818),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9816),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9816),
    [anon_sym_PLUS] = ACTIONS(9818),
    [sym_datetime_literal] = ACTIONS(9818),
    [sym_date_literal] = ACTIONS(9816),
    [sym_time_literal] = ACTIONS(9816),
    [sym_biginteger_literal] = ACTIONS(9818),
    [anon_sym_else] = ACTIONS(9816),
    [anon_sym_ELSE] = ACTIONS(9816),
    [anon_sym_Else] = ACTIONS(9816),
    [sym_page_keyword] = ACTIONS(9816),
    [anon_sym_codeunit] = ACTIONS(9816),
    [anon_sym_CODEUNIT] = ACTIONS(9816),
    [anon_sym_Codeunit] = ACTIONS(9816),
    [anon_sym_CodeUnit] = ACTIONS(9816),
    [anon_sym_COdeunit] = ACTIONS(9816),
    [anon_sym_codeUnit] = ACTIONS(9816),
    [sym_report_keyword] = ACTIONS(9816),
    [sym_query_keyword] = ACTIONS(9816),
    [anon_sym_xmlport] = ACTIONS(9816),
    [anon_sym_XMLPORT] = ACTIONS(9816),
    [anon_sym_Xmlport] = ACTIONS(9816),
    [anon_sym_XMLport] = ACTIONS(9816),
    [anon_sym_XMLPort] = ACTIONS(9816),
    [anon_sym_XmlPort] = ACTIONS(9816),
    [anon_sym_enum] = ACTIONS(9816),
    [anon_sym_ENUM] = ACTIONS(9816),
    [anon_sym_Enum] = ACTIONS(9816),
    [anon_sym_eNUM] = ACTIONS(9816),
    [anon_sym_eNum] = ACTIONS(9816),
    [anon_sym_ENum] = ACTIONS(9816),
    [sym_quoted_identifier] = ACTIONS(9818),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9818),
    [sym_verbatim_string] = ACTIONS(9818),
    [sym_integer] = ACTIONS(9816),
    [sym_continue_as_identifier] = ACTIONS(9818),
    [sym_preproc_open] = ACTIONS(9818),
    [sym_preproc_close] = ACTIONS(9818),
  },
  [STATE(4335)] = {
    [sym_boolean] = STATE(8642),
    [sym_assignment_expression] = STATE(8642),
    [sym__expression] = STATE(8642),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8642),
    [sym_multiplicative_expression] = STATE(8642),
    [sym_additive_expression] = STATE(8642),
    [sym_comparison_expression] = STATE(8642),
    [sym_logical_expression] = STATE(8642),
    [sym_ternary_expression] = STATE(8642),
    [sym_unary_expression] = STATE(8642),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8642),
    [sym_list_literal] = STATE(8642),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8642),
    [sym__literal_value] = STATE(8642),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9820),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [anon_sym_RBRACK] = ACTIONS(9822),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9824),
    [sym_date_literal] = ACTIONS(9820),
    [sym_time_literal] = ACTIONS(9820),
    [sym_biginteger_literal] = ACTIONS(9824),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9824),
    [sym_verbatim_string] = ACTIONS(9824),
    [sym_integer] = ACTIONS(9820),
    [sym_continue_as_identifier] = ACTIONS(9824),
  },
  [STATE(4336)] = {
    [sym_identifier] = ACTIONS(9826),
    [anon_sym_DASH] = ACTIONS(9828),
    [aux_sym_boolean_token1] = ACTIONS(9826),
    [aux_sym_boolean_token2] = ACTIONS(9826),
    [sym_decimal] = ACTIONS(9826),
    [anon_sym_LPAREN] = ACTIONS(9828),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9826),
    [anon_sym_LBRACK] = ACTIONS(9828),
    [aux_sym_record_type_token1] = ACTIONS(9826),
    [aux_sym_basic_type_token21] = ACTIONS(9826),
    [aux_sym_basic_type_token22] = ACTIONS(9826),
    [aux_sym_basic_type_token48] = ACTIONS(9826),
    [anon_sym_POUNDif] = ACTIONS(9828),
    [anon_sym_POUNDIF] = ACTIONS(9828),
    [anon_sym_POUNDIf] = ACTIONS(9828),
    [anon_sym_not] = ACTIONS(9826),
    [anon_sym_NOT] = ACTIONS(9826),
    [anon_sym_Not] = ACTIONS(9826),
    [anon_sym_POUNDelif] = ACTIONS(9828),
    [anon_sym_POUNDELIF] = ACTIONS(9828),
    [anon_sym_POUNDElif] = ACTIONS(9828),
    [anon_sym_POUNDelse] = ACTIONS(9828),
    [anon_sym_POUNDELSE] = ACTIONS(9828),
    [anon_sym_POUNDElse] = ACTIONS(9828),
    [anon_sym_POUNDelse2] = ACTIONS(9828),
    [anon_sym_POUNDELSE2] = ACTIONS(9828),
    [anon_sym_POUNDElse2] = ACTIONS(9828),
    [anon_sym_POUNDendif] = ACTIONS(9828),
    [anon_sym_POUNDENDIF] = ACTIONS(9828),
    [anon_sym_POUNDEndif] = ACTIONS(9828),
    [anon_sym_POUNDendif2] = ACTIONS(9828),
    [anon_sym_POUNDENDIF2] = ACTIONS(9828),
    [anon_sym_POUNDEndif2] = ACTIONS(9828),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9826),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9826),
    [anon_sym_PLUS] = ACTIONS(9828),
    [sym_datetime_literal] = ACTIONS(9828),
    [sym_date_literal] = ACTIONS(9826),
    [sym_time_literal] = ACTIONS(9826),
    [sym_biginteger_literal] = ACTIONS(9828),
    [anon_sym_else] = ACTIONS(9826),
    [anon_sym_ELSE] = ACTIONS(9826),
    [anon_sym_Else] = ACTIONS(9826),
    [sym_page_keyword] = ACTIONS(9826),
    [anon_sym_codeunit] = ACTIONS(9826),
    [anon_sym_CODEUNIT] = ACTIONS(9826),
    [anon_sym_Codeunit] = ACTIONS(9826),
    [anon_sym_CodeUnit] = ACTIONS(9826),
    [anon_sym_COdeunit] = ACTIONS(9826),
    [anon_sym_codeUnit] = ACTIONS(9826),
    [sym_report_keyword] = ACTIONS(9826),
    [sym_query_keyword] = ACTIONS(9826),
    [anon_sym_xmlport] = ACTIONS(9826),
    [anon_sym_XMLPORT] = ACTIONS(9826),
    [anon_sym_Xmlport] = ACTIONS(9826),
    [anon_sym_XMLport] = ACTIONS(9826),
    [anon_sym_XMLPort] = ACTIONS(9826),
    [anon_sym_XmlPort] = ACTIONS(9826),
    [anon_sym_enum] = ACTIONS(9826),
    [anon_sym_ENUM] = ACTIONS(9826),
    [anon_sym_Enum] = ACTIONS(9826),
    [anon_sym_eNUM] = ACTIONS(9826),
    [anon_sym_eNum] = ACTIONS(9826),
    [anon_sym_ENum] = ACTIONS(9826),
    [sym_quoted_identifier] = ACTIONS(9828),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9828),
    [sym_verbatim_string] = ACTIONS(9828),
    [sym_integer] = ACTIONS(9826),
    [sym_continue_as_identifier] = ACTIONS(9828),
    [sym_preproc_open] = ACTIONS(9828),
    [sym_preproc_close] = ACTIONS(9828),
  },
  [STATE(4337)] = {
    [sym_identifier] = ACTIONS(9830),
    [anon_sym_DASH] = ACTIONS(9832),
    [aux_sym_boolean_token1] = ACTIONS(9830),
    [aux_sym_boolean_token2] = ACTIONS(9830),
    [sym_decimal] = ACTIONS(9830),
    [anon_sym_LPAREN] = ACTIONS(9832),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9830),
    [anon_sym_LBRACK] = ACTIONS(9832),
    [aux_sym_record_type_token1] = ACTIONS(9830),
    [aux_sym_basic_type_token21] = ACTIONS(9830),
    [aux_sym_basic_type_token22] = ACTIONS(9830),
    [aux_sym_basic_type_token48] = ACTIONS(9830),
    [anon_sym_POUNDif] = ACTIONS(9832),
    [anon_sym_POUNDIF] = ACTIONS(9832),
    [anon_sym_POUNDIf] = ACTIONS(9832),
    [anon_sym_not] = ACTIONS(9830),
    [anon_sym_NOT] = ACTIONS(9830),
    [anon_sym_Not] = ACTIONS(9830),
    [anon_sym_POUNDelif] = ACTIONS(9832),
    [anon_sym_POUNDELIF] = ACTIONS(9832),
    [anon_sym_POUNDElif] = ACTIONS(9832),
    [anon_sym_POUNDelse] = ACTIONS(9832),
    [anon_sym_POUNDELSE] = ACTIONS(9832),
    [anon_sym_POUNDElse] = ACTIONS(9832),
    [anon_sym_POUNDelse2] = ACTIONS(9832),
    [anon_sym_POUNDELSE2] = ACTIONS(9832),
    [anon_sym_POUNDElse2] = ACTIONS(9832),
    [anon_sym_POUNDendif] = ACTIONS(9832),
    [anon_sym_POUNDENDIF] = ACTIONS(9832),
    [anon_sym_POUNDEndif] = ACTIONS(9832),
    [anon_sym_POUNDendif2] = ACTIONS(9832),
    [anon_sym_POUNDENDIF2] = ACTIONS(9832),
    [anon_sym_POUNDEndif2] = ACTIONS(9832),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9830),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9830),
    [anon_sym_PLUS] = ACTIONS(9832),
    [sym_datetime_literal] = ACTIONS(9832),
    [sym_date_literal] = ACTIONS(9830),
    [sym_time_literal] = ACTIONS(9830),
    [sym_biginteger_literal] = ACTIONS(9832),
    [anon_sym_else] = ACTIONS(9830),
    [anon_sym_ELSE] = ACTIONS(9830),
    [anon_sym_Else] = ACTIONS(9830),
    [sym_page_keyword] = ACTIONS(9830),
    [anon_sym_codeunit] = ACTIONS(9830),
    [anon_sym_CODEUNIT] = ACTIONS(9830),
    [anon_sym_Codeunit] = ACTIONS(9830),
    [anon_sym_CodeUnit] = ACTIONS(9830),
    [anon_sym_COdeunit] = ACTIONS(9830),
    [anon_sym_codeUnit] = ACTIONS(9830),
    [sym_report_keyword] = ACTIONS(9830),
    [sym_query_keyword] = ACTIONS(9830),
    [anon_sym_xmlport] = ACTIONS(9830),
    [anon_sym_XMLPORT] = ACTIONS(9830),
    [anon_sym_Xmlport] = ACTIONS(9830),
    [anon_sym_XMLport] = ACTIONS(9830),
    [anon_sym_XMLPort] = ACTIONS(9830),
    [anon_sym_XmlPort] = ACTIONS(9830),
    [anon_sym_enum] = ACTIONS(9830),
    [anon_sym_ENUM] = ACTIONS(9830),
    [anon_sym_Enum] = ACTIONS(9830),
    [anon_sym_eNUM] = ACTIONS(9830),
    [anon_sym_eNum] = ACTIONS(9830),
    [anon_sym_ENum] = ACTIONS(9830),
    [sym_quoted_identifier] = ACTIONS(9832),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9832),
    [sym_verbatim_string] = ACTIONS(9832),
    [sym_integer] = ACTIONS(9830),
    [sym_continue_as_identifier] = ACTIONS(9832),
    [sym_preproc_open] = ACTIONS(9832),
    [sym_preproc_close] = ACTIONS(9832),
  },
  [STATE(4338)] = {
    [sym_boolean] = STATE(8649),
    [sym_assignment_expression] = STATE(8649),
    [sym__expression] = STATE(8649),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8649),
    [sym_multiplicative_expression] = STATE(8649),
    [sym_additive_expression] = STATE(8649),
    [sym_comparison_expression] = STATE(8649),
    [sym_logical_expression] = STATE(8649),
    [sym_ternary_expression] = STATE(8649),
    [sym_unary_expression] = STATE(8649),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8649),
    [sym_list_literal] = STATE(8649),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8649),
    [sym__literal_value] = STATE(8649),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9834),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9836),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9838),
    [sym_date_literal] = ACTIONS(9834),
    [sym_time_literal] = ACTIONS(9834),
    [sym_biginteger_literal] = ACTIONS(9838),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9838),
    [sym_verbatim_string] = ACTIONS(9838),
    [sym_integer] = ACTIONS(9834),
    [sym_continue_as_identifier] = ACTIONS(9838),
  },
  [STATE(4339)] = {
    [sym_identifier] = ACTIONS(9840),
    [anon_sym_DASH] = ACTIONS(9842),
    [aux_sym_boolean_token1] = ACTIONS(9840),
    [aux_sym_boolean_token2] = ACTIONS(9840),
    [sym_decimal] = ACTIONS(9840),
    [anon_sym_LPAREN] = ACTIONS(9842),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9840),
    [anon_sym_LBRACK] = ACTIONS(9842),
    [aux_sym_record_type_token1] = ACTIONS(9840),
    [aux_sym_basic_type_token21] = ACTIONS(9840),
    [aux_sym_basic_type_token22] = ACTIONS(9840),
    [aux_sym_basic_type_token48] = ACTIONS(9840),
    [anon_sym_POUNDif] = ACTIONS(9842),
    [anon_sym_POUNDIF] = ACTIONS(9842),
    [anon_sym_POUNDIf] = ACTIONS(9842),
    [anon_sym_not] = ACTIONS(9840),
    [anon_sym_NOT] = ACTIONS(9840),
    [anon_sym_Not] = ACTIONS(9840),
    [anon_sym_POUNDelif] = ACTIONS(9842),
    [anon_sym_POUNDELIF] = ACTIONS(9842),
    [anon_sym_POUNDElif] = ACTIONS(9842),
    [anon_sym_POUNDelse] = ACTIONS(9842),
    [anon_sym_POUNDELSE] = ACTIONS(9842),
    [anon_sym_POUNDElse] = ACTIONS(9842),
    [anon_sym_POUNDelse2] = ACTIONS(9842),
    [anon_sym_POUNDELSE2] = ACTIONS(9842),
    [anon_sym_POUNDElse2] = ACTIONS(9842),
    [anon_sym_POUNDendif] = ACTIONS(9842),
    [anon_sym_POUNDENDIF] = ACTIONS(9842),
    [anon_sym_POUNDEndif] = ACTIONS(9842),
    [anon_sym_POUNDendif2] = ACTIONS(9842),
    [anon_sym_POUNDENDIF2] = ACTIONS(9842),
    [anon_sym_POUNDEndif2] = ACTIONS(9842),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9840),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9840),
    [anon_sym_PLUS] = ACTIONS(9842),
    [sym_datetime_literal] = ACTIONS(9842),
    [sym_date_literal] = ACTIONS(9840),
    [sym_time_literal] = ACTIONS(9840),
    [sym_biginteger_literal] = ACTIONS(9842),
    [anon_sym_else] = ACTIONS(9840),
    [anon_sym_ELSE] = ACTIONS(9840),
    [anon_sym_Else] = ACTIONS(9840),
    [sym_page_keyword] = ACTIONS(9840),
    [anon_sym_codeunit] = ACTIONS(9840),
    [anon_sym_CODEUNIT] = ACTIONS(9840),
    [anon_sym_Codeunit] = ACTIONS(9840),
    [anon_sym_CodeUnit] = ACTIONS(9840),
    [anon_sym_COdeunit] = ACTIONS(9840),
    [anon_sym_codeUnit] = ACTIONS(9840),
    [sym_report_keyword] = ACTIONS(9840),
    [sym_query_keyword] = ACTIONS(9840),
    [anon_sym_xmlport] = ACTIONS(9840),
    [anon_sym_XMLPORT] = ACTIONS(9840),
    [anon_sym_Xmlport] = ACTIONS(9840),
    [anon_sym_XMLport] = ACTIONS(9840),
    [anon_sym_XMLPort] = ACTIONS(9840),
    [anon_sym_XmlPort] = ACTIONS(9840),
    [anon_sym_enum] = ACTIONS(9840),
    [anon_sym_ENUM] = ACTIONS(9840),
    [anon_sym_Enum] = ACTIONS(9840),
    [anon_sym_eNUM] = ACTIONS(9840),
    [anon_sym_eNum] = ACTIONS(9840),
    [anon_sym_ENum] = ACTIONS(9840),
    [sym_quoted_identifier] = ACTIONS(9842),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9842),
    [sym_verbatim_string] = ACTIONS(9842),
    [sym_integer] = ACTIONS(9840),
    [sym_continue_as_identifier] = ACTIONS(9842),
    [sym_preproc_open] = ACTIONS(9842),
    [sym_preproc_close] = ACTIONS(9842),
  },
  [STATE(4340)] = {
    [sym_identifier] = ACTIONS(9808),
    [anon_sym_DASH] = ACTIONS(9810),
    [aux_sym_boolean_token1] = ACTIONS(9808),
    [aux_sym_boolean_token2] = ACTIONS(9808),
    [sym_decimal] = ACTIONS(9808),
    [anon_sym_LPAREN] = ACTIONS(9810),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9808),
    [anon_sym_LBRACK] = ACTIONS(9810),
    [aux_sym_record_type_token1] = ACTIONS(9808),
    [aux_sym_basic_type_token21] = ACTIONS(9808),
    [aux_sym_basic_type_token22] = ACTIONS(9808),
    [aux_sym_basic_type_token48] = ACTIONS(9808),
    [anon_sym_POUNDif] = ACTIONS(9810),
    [anon_sym_POUNDIF] = ACTIONS(9810),
    [anon_sym_POUNDIf] = ACTIONS(9810),
    [anon_sym_not] = ACTIONS(9808),
    [anon_sym_NOT] = ACTIONS(9808),
    [anon_sym_Not] = ACTIONS(9808),
    [anon_sym_POUNDelif] = ACTIONS(9810),
    [anon_sym_POUNDELIF] = ACTIONS(9810),
    [anon_sym_POUNDElif] = ACTIONS(9810),
    [anon_sym_POUNDelse] = ACTIONS(9810),
    [anon_sym_POUNDELSE] = ACTIONS(9810),
    [anon_sym_POUNDElse] = ACTIONS(9810),
    [anon_sym_POUNDelse2] = ACTIONS(9810),
    [anon_sym_POUNDELSE2] = ACTIONS(9810),
    [anon_sym_POUNDElse2] = ACTIONS(9810),
    [anon_sym_POUNDendif] = ACTIONS(9810),
    [anon_sym_POUNDENDIF] = ACTIONS(9810),
    [anon_sym_POUNDEndif] = ACTIONS(9810),
    [anon_sym_POUNDendif2] = ACTIONS(9810),
    [anon_sym_POUNDENDIF2] = ACTIONS(9810),
    [anon_sym_POUNDEndif2] = ACTIONS(9810),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9808),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9808),
    [anon_sym_PLUS] = ACTIONS(9810),
    [sym_datetime_literal] = ACTIONS(9810),
    [sym_date_literal] = ACTIONS(9808),
    [sym_time_literal] = ACTIONS(9808),
    [sym_biginteger_literal] = ACTIONS(9810),
    [anon_sym_else] = ACTIONS(9808),
    [anon_sym_ELSE] = ACTIONS(9808),
    [anon_sym_Else] = ACTIONS(9808),
    [sym_page_keyword] = ACTIONS(9808),
    [anon_sym_codeunit] = ACTIONS(9808),
    [anon_sym_CODEUNIT] = ACTIONS(9808),
    [anon_sym_Codeunit] = ACTIONS(9808),
    [anon_sym_CodeUnit] = ACTIONS(9808),
    [anon_sym_COdeunit] = ACTIONS(9808),
    [anon_sym_codeUnit] = ACTIONS(9808),
    [sym_report_keyword] = ACTIONS(9808),
    [sym_query_keyword] = ACTIONS(9808),
    [anon_sym_xmlport] = ACTIONS(9808),
    [anon_sym_XMLPORT] = ACTIONS(9808),
    [anon_sym_Xmlport] = ACTIONS(9808),
    [anon_sym_XMLport] = ACTIONS(9808),
    [anon_sym_XMLPort] = ACTIONS(9808),
    [anon_sym_XmlPort] = ACTIONS(9808),
    [anon_sym_enum] = ACTIONS(9808),
    [anon_sym_ENUM] = ACTIONS(9808),
    [anon_sym_Enum] = ACTIONS(9808),
    [anon_sym_eNUM] = ACTIONS(9808),
    [anon_sym_eNum] = ACTIONS(9808),
    [anon_sym_ENum] = ACTIONS(9808),
    [sym_quoted_identifier] = ACTIONS(9810),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9810),
    [sym_verbatim_string] = ACTIONS(9810),
    [sym_integer] = ACTIONS(9808),
    [sym_continue_as_identifier] = ACTIONS(9810),
    [sym_preproc_open] = ACTIONS(9810),
    [sym_preproc_close] = ACTIONS(9810),
  },
  [STATE(4341)] = {
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_LBRACE] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5277),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5277),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token6] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5277),
    [aux_sym_addafter_modification_token1] = ACTIONS(5277),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5277),
    [aux_sym_modify_modification_token1] = ACTIONS(5277),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5277),
    [aux_sym_movelast_modification_token1] = ACTIONS(5277),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5277),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5277),
    [aux_sym_separator_action_token1] = ACTIONS(5277),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5277),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5277),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5277),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5277),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5277),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5277),
    [sym_trigger_keyword] = ACTIONS(5277),
    [sym_var_keyword] = ACTIONS(5277),
    [sym_local_keyword] = ACTIONS(5277),
    [sym_internal_keyword] = ACTIONS(5277),
    [sym_protected_keyword] = ACTIONS(5277),
    [sym_event_keyword] = ACTIONS(5277),
    [sym_fields_keyword] = ACTIONS(5277),
    [sym_keys_keyword] = ACTIONS(5277),
    [sym_fieldgroups_keyword] = ACTIONS(5277),
    [sym_actions_keyword] = ACTIONS(5277),
    [sym_layout_keyword] = ACTIONS(5277),
    [sym_area_keyword] = ACTIONS(5277),
    [sym_group_keyword] = ACTIONS(5277),
    [sym_repeater_keyword] = ACTIONS(5277),
    [sym_cuegroup_keyword] = ACTIONS(5277),
    [sym_fixed_keyword] = ACTIONS(5277),
    [sym_grid_keyword] = ACTIONS(5277),
    [sym_part_keyword] = ACTIONS(5277),
    [sym_systempart_keyword] = ACTIONS(5277),
    [sym_usercontrol_keyword] = ACTIONS(5277),
    [sym_dataset_keyword] = ACTIONS(5277),
    [sym_elements_keyword] = ACTIONS(5277),
    [sym_labels_keyword] = ACTIONS(5277),
    [sym_rendering_keyword] = ACTIONS(5277),
    [sym_requestpage_keyword] = ACTIONS(5277),
    [sym_schema_keyword] = ACTIONS(5277),
    [sym_views_keyword] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
  },
  [STATE(4342)] = {
    [sym_boolean] = STATE(8670),
    [sym_assignment_expression] = STATE(8670),
    [sym__expression] = STATE(8670),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8670),
    [sym_multiplicative_expression] = STATE(8670),
    [sym_additive_expression] = STATE(8670),
    [sym_comparison_expression] = STATE(8670),
    [sym_logical_expression] = STATE(8670),
    [sym_ternary_expression] = STATE(8670),
    [sym_unary_expression] = STATE(8670),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8670),
    [sym_list_literal] = STATE(8670),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8670),
    [sym__literal_value] = STATE(8670),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9844),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9846),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9848),
    [sym_date_literal] = ACTIONS(9844),
    [sym_time_literal] = ACTIONS(9844),
    [sym_biginteger_literal] = ACTIONS(9848),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9848),
    [sym_verbatim_string] = ACTIONS(9848),
    [sym_integer] = ACTIONS(9844),
    [sym_continue_as_identifier] = ACTIONS(9848),
  },
  [STATE(4343)] = {
    [sym_boolean] = STATE(8646),
    [sym_assignment_expression] = STATE(8646),
    [sym__expression] = STATE(8646),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8646),
    [sym_multiplicative_expression] = STATE(8646),
    [sym_additive_expression] = STATE(8646),
    [sym_comparison_expression] = STATE(8646),
    [sym_logical_expression] = STATE(8646),
    [sym_ternary_expression] = STATE(8646),
    [sym_unary_expression] = STATE(8646),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8646),
    [sym_list_literal] = STATE(8646),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8646),
    [sym__literal_value] = STATE(8646),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9850),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9852),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9854),
    [sym_date_literal] = ACTIONS(9850),
    [sym_time_literal] = ACTIONS(9850),
    [sym_biginteger_literal] = ACTIONS(9854),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9854),
    [sym_verbatim_string] = ACTIONS(9854),
    [sym_integer] = ACTIONS(9850),
    [sym_continue_as_identifier] = ACTIONS(9854),
  },
  [STATE(4344)] = {
    [sym_preproc_conditional_controladdin] = STATE(4442),
    [sym__body_element] = STATE(8196),
    [sym_empty_statement] = STATE(8196),
    [sym_property] = STATE(8196),
    [sym_permissions_property] = STATE(8196),
    [sym_table_relation_property] = STATE(8196),
    [sym_fields_section] = STATE(8196),
    [sym_keys_section] = STATE(8196),
    [sym_fieldgroups_section] = STATE(8196),
    [sym_enum_value_declaration] = STATE(8196),
    [sym_labels_section] = STATE(8196),
    [sym_layout_section] = STATE(8196),
    [sym_modify_modification] = STATE(8196),
    [sym_actions_section] = STATE(8196),
    [sym_views_section] = STATE(8196),
    [sym_dataset_section] = STATE(8196),
    [sym_requestpage_section] = STATE(8196),
    [sym_rendering_section] = STATE(8196),
    [sym_elements_section] = STATE(8196),
    [sym_schema_section] = STATE(8196),
    [sym_assembly_declaration] = STATE(8196),
    [sym_event_declaration] = STATE(8196),
    [sym_procedure] = STATE(8196),
    [sym_preproc_split_procedure] = STATE(8196),
    [sym_preproc_split_procedure_preamble] = STATE(8196),
    [sym_interface_procedure] = STATE(4442),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8196),
    [sym_var_section] = STATE(8196),
    [sym_attribute_item] = STATE(8196),
    [sym_preproc_conditional] = STATE(8196),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(8154),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4908),
    [aux_sym_controladdin_declaration_repeat1] = STATE(4442),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4345)] = {
    [sym_boolean] = STATE(8736),
    [sym_aggregate_formula] = STATE(17525),
    [sym_assignment_expression] = STATE(8736),
    [sym__expression] = STATE(8736),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8736),
    [sym_multiplicative_expression] = STATE(8736),
    [sym_additive_expression] = STATE(8736),
    [sym_comparison_expression] = STATE(8736),
    [sym_logical_expression] = STATE(8736),
    [sym_ternary_expression] = STATE(8736),
    [sym_unary_expression] = STATE(8736),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8736),
    [sym_list_literal] = STATE(8736),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8736),
    [sym__literal_value] = STATE(8736),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9856),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9858),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(9860),
    [sym_date_literal] = ACTIONS(9858),
    [sym_time_literal] = ACTIONS(9858),
    [sym_biginteger_literal] = ACTIONS(9860),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9860),
    [sym_verbatim_string] = ACTIONS(9860),
    [sym_integer] = ACTIONS(9862),
    [sym_continue_as_identifier] = ACTIONS(9860),
  },
  [STATE(4346)] = {
    [sym_boolean] = STATE(8643),
    [sym_assignment_expression] = STATE(8643),
    [sym__expression] = STATE(8643),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8643),
    [sym_multiplicative_expression] = STATE(8643),
    [sym_additive_expression] = STATE(8643),
    [sym_comparison_expression] = STATE(8643),
    [sym_logical_expression] = STATE(8643),
    [sym_ternary_expression] = STATE(8643),
    [sym_unary_expression] = STATE(8643),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8643),
    [sym_list_literal] = STATE(8643),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8643),
    [sym__literal_value] = STATE(8643),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9864),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [anon_sym_RBRACK] = ACTIONS(9866),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9868),
    [sym_date_literal] = ACTIONS(9864),
    [sym_time_literal] = ACTIONS(9864),
    [sym_biginteger_literal] = ACTIONS(9868),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9868),
    [sym_verbatim_string] = ACTIONS(9868),
    [sym_integer] = ACTIONS(9864),
    [sym_continue_as_identifier] = ACTIONS(9868),
  },
  [STATE(4347)] = {
    [sym_boolean] = STATE(8641),
    [sym_assignment_expression] = STATE(8641),
    [sym__expression] = STATE(8641),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8641),
    [sym_multiplicative_expression] = STATE(8641),
    [sym_additive_expression] = STATE(8641),
    [sym_comparison_expression] = STATE(8641),
    [sym_logical_expression] = STATE(8641),
    [sym_ternary_expression] = STATE(8641),
    [sym_unary_expression] = STATE(8641),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8641),
    [sym_list_literal] = STATE(8641),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8641),
    [sym__literal_value] = STATE(8641),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9870),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [anon_sym_RBRACK] = ACTIONS(9872),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9874),
    [sym_date_literal] = ACTIONS(9870),
    [sym_time_literal] = ACTIONS(9870),
    [sym_biginteger_literal] = ACTIONS(9874),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9874),
    [sym_verbatim_string] = ACTIONS(9874),
    [sym_integer] = ACTIONS(9870),
    [sym_continue_as_identifier] = ACTIONS(9874),
  },
  [STATE(4348)] = {
    [sym_boolean] = STATE(8654),
    [sym_assignment_expression] = STATE(8654),
    [sym__expression] = STATE(8654),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8654),
    [sym_multiplicative_expression] = STATE(8654),
    [sym_additive_expression] = STATE(8654),
    [sym_comparison_expression] = STATE(8654),
    [sym_logical_expression] = STATE(8654),
    [sym_ternary_expression] = STATE(8654),
    [sym_unary_expression] = STATE(8654),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8654),
    [sym_list_literal] = STATE(8654),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8654),
    [sym__literal_value] = STATE(8654),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9876),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9878),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9880),
    [sym_date_literal] = ACTIONS(9876),
    [sym_time_literal] = ACTIONS(9876),
    [sym_biginteger_literal] = ACTIONS(9880),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9880),
    [sym_verbatim_string] = ACTIONS(9880),
    [sym_integer] = ACTIONS(9876),
    [sym_continue_as_identifier] = ACTIONS(9880),
  },
  [STATE(4349)] = {
    [sym_identifier] = ACTIONS(9776),
    [anon_sym_DASH] = ACTIONS(9778),
    [aux_sym_boolean_token1] = ACTIONS(9776),
    [aux_sym_boolean_token2] = ACTIONS(9776),
    [sym_decimal] = ACTIONS(9776),
    [anon_sym_LPAREN] = ACTIONS(9778),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9776),
    [anon_sym_LBRACK] = ACTIONS(9778),
    [aux_sym_record_type_token1] = ACTIONS(9776),
    [aux_sym_basic_type_token21] = ACTIONS(9776),
    [aux_sym_basic_type_token22] = ACTIONS(9776),
    [aux_sym_basic_type_token48] = ACTIONS(9776),
    [anon_sym_POUNDif] = ACTIONS(9778),
    [anon_sym_POUNDIF] = ACTIONS(9778),
    [anon_sym_POUNDIf] = ACTIONS(9778),
    [anon_sym_not] = ACTIONS(9776),
    [anon_sym_NOT] = ACTIONS(9776),
    [anon_sym_Not] = ACTIONS(9776),
    [anon_sym_POUNDelif] = ACTIONS(9778),
    [anon_sym_POUNDELIF] = ACTIONS(9778),
    [anon_sym_POUNDElif] = ACTIONS(9778),
    [anon_sym_POUNDelse] = ACTIONS(9778),
    [anon_sym_POUNDELSE] = ACTIONS(9778),
    [anon_sym_POUNDElse] = ACTIONS(9778),
    [anon_sym_POUNDelse2] = ACTIONS(9778),
    [anon_sym_POUNDELSE2] = ACTIONS(9778),
    [anon_sym_POUNDElse2] = ACTIONS(9778),
    [anon_sym_POUNDendif] = ACTIONS(9778),
    [anon_sym_POUNDENDIF] = ACTIONS(9778),
    [anon_sym_POUNDEndif] = ACTIONS(9778),
    [anon_sym_POUNDendif2] = ACTIONS(9778),
    [anon_sym_POUNDENDIF2] = ACTIONS(9778),
    [anon_sym_POUNDEndif2] = ACTIONS(9778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9776),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9776),
    [anon_sym_PLUS] = ACTIONS(9778),
    [sym_datetime_literal] = ACTIONS(9778),
    [sym_date_literal] = ACTIONS(9776),
    [sym_time_literal] = ACTIONS(9776),
    [sym_biginteger_literal] = ACTIONS(9778),
    [anon_sym_else] = ACTIONS(9776),
    [anon_sym_ELSE] = ACTIONS(9776),
    [anon_sym_Else] = ACTIONS(9776),
    [sym_page_keyword] = ACTIONS(9776),
    [anon_sym_codeunit] = ACTIONS(9776),
    [anon_sym_CODEUNIT] = ACTIONS(9776),
    [anon_sym_Codeunit] = ACTIONS(9776),
    [anon_sym_CodeUnit] = ACTIONS(9776),
    [anon_sym_COdeunit] = ACTIONS(9776),
    [anon_sym_codeUnit] = ACTIONS(9776),
    [sym_report_keyword] = ACTIONS(9776),
    [sym_query_keyword] = ACTIONS(9776),
    [anon_sym_xmlport] = ACTIONS(9776),
    [anon_sym_XMLPORT] = ACTIONS(9776),
    [anon_sym_Xmlport] = ACTIONS(9776),
    [anon_sym_XMLport] = ACTIONS(9776),
    [anon_sym_XMLPort] = ACTIONS(9776),
    [anon_sym_XmlPort] = ACTIONS(9776),
    [anon_sym_enum] = ACTIONS(9776),
    [anon_sym_ENUM] = ACTIONS(9776),
    [anon_sym_Enum] = ACTIONS(9776),
    [anon_sym_eNUM] = ACTIONS(9776),
    [anon_sym_eNum] = ACTIONS(9776),
    [anon_sym_ENum] = ACTIONS(9776),
    [sym_quoted_identifier] = ACTIONS(9778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9778),
    [sym_verbatim_string] = ACTIONS(9778),
    [sym_integer] = ACTIONS(9776),
    [sym_continue_as_identifier] = ACTIONS(9778),
    [sym_preproc_open] = ACTIONS(9778),
    [sym_preproc_close] = ACTIONS(9778),
  },
  [STATE(4350)] = {
    [sym_boolean] = STATE(8662),
    [sym_assignment_expression] = STATE(8662),
    [sym__expression] = STATE(8662),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8662),
    [sym_multiplicative_expression] = STATE(8662),
    [sym_additive_expression] = STATE(8662),
    [sym_comparison_expression] = STATE(8662),
    [sym_logical_expression] = STATE(8662),
    [sym_ternary_expression] = STATE(8662),
    [sym_unary_expression] = STATE(8662),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8662),
    [sym_list_literal] = STATE(8662),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8662),
    [sym__literal_value] = STATE(8662),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9882),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9884),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9886),
    [sym_date_literal] = ACTIONS(9882),
    [sym_time_literal] = ACTIONS(9882),
    [sym_biginteger_literal] = ACTIONS(9886),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9886),
    [sym_verbatim_string] = ACTIONS(9886),
    [sym_integer] = ACTIONS(9882),
    [sym_continue_as_identifier] = ACTIONS(9886),
  },
  [STATE(4351)] = {
    [sym_identifier] = ACTIONS(9888),
    [anon_sym_DASH] = ACTIONS(9890),
    [aux_sym_boolean_token1] = ACTIONS(9888),
    [aux_sym_boolean_token2] = ACTIONS(9888),
    [sym_decimal] = ACTIONS(9888),
    [anon_sym_LPAREN] = ACTIONS(9890),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9888),
    [anon_sym_LBRACK] = ACTIONS(9890),
    [aux_sym_record_type_token1] = ACTIONS(9888),
    [aux_sym_basic_type_token21] = ACTIONS(9888),
    [aux_sym_basic_type_token22] = ACTIONS(9888),
    [aux_sym_basic_type_token48] = ACTIONS(9888),
    [anon_sym_POUNDif] = ACTIONS(9890),
    [anon_sym_POUNDIF] = ACTIONS(9890),
    [anon_sym_POUNDIf] = ACTIONS(9890),
    [anon_sym_not] = ACTIONS(9888),
    [anon_sym_NOT] = ACTIONS(9888),
    [anon_sym_Not] = ACTIONS(9888),
    [anon_sym_POUNDelif] = ACTIONS(9890),
    [anon_sym_POUNDELIF] = ACTIONS(9890),
    [anon_sym_POUNDElif] = ACTIONS(9890),
    [anon_sym_POUNDelse] = ACTIONS(9890),
    [anon_sym_POUNDELSE] = ACTIONS(9890),
    [anon_sym_POUNDElse] = ACTIONS(9890),
    [anon_sym_POUNDelse2] = ACTIONS(9890),
    [anon_sym_POUNDELSE2] = ACTIONS(9890),
    [anon_sym_POUNDElse2] = ACTIONS(9890),
    [anon_sym_POUNDendif] = ACTIONS(9890),
    [anon_sym_POUNDENDIF] = ACTIONS(9890),
    [anon_sym_POUNDEndif] = ACTIONS(9890),
    [anon_sym_POUNDendif2] = ACTIONS(9890),
    [anon_sym_POUNDENDIF2] = ACTIONS(9890),
    [anon_sym_POUNDEndif2] = ACTIONS(9890),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9888),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9888),
    [anon_sym_PLUS] = ACTIONS(9890),
    [sym_datetime_literal] = ACTIONS(9890),
    [sym_date_literal] = ACTIONS(9888),
    [sym_time_literal] = ACTIONS(9888),
    [sym_biginteger_literal] = ACTIONS(9890),
    [anon_sym_else] = ACTIONS(9888),
    [anon_sym_ELSE] = ACTIONS(9888),
    [anon_sym_Else] = ACTIONS(9888),
    [sym_page_keyword] = ACTIONS(9888),
    [anon_sym_codeunit] = ACTIONS(9888),
    [anon_sym_CODEUNIT] = ACTIONS(9888),
    [anon_sym_Codeunit] = ACTIONS(9888),
    [anon_sym_CodeUnit] = ACTIONS(9888),
    [anon_sym_COdeunit] = ACTIONS(9888),
    [anon_sym_codeUnit] = ACTIONS(9888),
    [sym_report_keyword] = ACTIONS(9888),
    [sym_query_keyword] = ACTIONS(9888),
    [anon_sym_xmlport] = ACTIONS(9888),
    [anon_sym_XMLPORT] = ACTIONS(9888),
    [anon_sym_Xmlport] = ACTIONS(9888),
    [anon_sym_XMLport] = ACTIONS(9888),
    [anon_sym_XMLPort] = ACTIONS(9888),
    [anon_sym_XmlPort] = ACTIONS(9888),
    [anon_sym_enum] = ACTIONS(9888),
    [anon_sym_ENUM] = ACTIONS(9888),
    [anon_sym_Enum] = ACTIONS(9888),
    [anon_sym_eNUM] = ACTIONS(9888),
    [anon_sym_eNum] = ACTIONS(9888),
    [anon_sym_ENum] = ACTIONS(9888),
    [sym_quoted_identifier] = ACTIONS(9890),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9890),
    [sym_verbatim_string] = ACTIONS(9890),
    [sym_integer] = ACTIONS(9888),
    [sym_continue_as_identifier] = ACTIONS(9890),
    [sym_preproc_open] = ACTIONS(9890),
    [sym_preproc_close] = ACTIONS(9890),
  },
  [STATE(4352)] = {
    [sym_boolean] = STATE(8665),
    [sym_assignment_expression] = STATE(8665),
    [sym__expression] = STATE(8665),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8665),
    [sym_multiplicative_expression] = STATE(8665),
    [sym_additive_expression] = STATE(8665),
    [sym_comparison_expression] = STATE(8665),
    [sym_logical_expression] = STATE(8665),
    [sym_ternary_expression] = STATE(8665),
    [sym_unary_expression] = STATE(8665),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8665),
    [sym_list_literal] = STATE(8665),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8665),
    [sym__literal_value] = STATE(8665),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9892),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9894),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9896),
    [sym_date_literal] = ACTIONS(9892),
    [sym_time_literal] = ACTIONS(9892),
    [sym_biginteger_literal] = ACTIONS(9896),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9896),
    [sym_verbatim_string] = ACTIONS(9896),
    [sym_integer] = ACTIONS(9892),
    [sym_continue_as_identifier] = ACTIONS(9896),
  },
  [STATE(4353)] = {
    [sym_boolean] = STATE(8902),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8685),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8685),
    [sym_database_reference] = STATE(8939),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9898),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9900),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9902),
    [sym_date_literal] = ACTIONS(9904),
    [sym_time_literal] = ACTIONS(9904),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(9906),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9902),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9904),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4354)] = {
    [sym__layout_element] = STATE(4701),
    [sym_area_section] = STATE(4701),
    [sym_group_section] = STATE(4701),
    [sym_repeater_section] = STATE(4701),
    [sym_cuegroup_section] = STATE(4701),
    [sym_fixed_section] = STATE(4701),
    [sym_grid_section] = STATE(4701),
    [sym_page_field] = STATE(4701),
    [sym_part_section] = STATE(4701),
    [sym_systempart_section] = STATE(4701),
    [sym_usercontrol_section] = STATE(4701),
    [sym_preproc_split_field] = STATE(4701),
    [sym__field_header] = STATE(10667),
    [sym_label_section] = STATE(4701),
    [sym_addfirst_modification] = STATE(4701),
    [sym_addlast_modification] = STATE(4701),
    [sym_addafter_modification] = STATE(4701),
    [sym_addbefore_modification] = STATE(4701),
    [sym_modify_modification] = STATE(4701),
    [sym_movefirst_modification] = STATE(4701),
    [sym_movelast_modification] = STATE(4701),
    [sym_moveafter_modification] = STATE(4701),
    [sym_movebefore_modification] = STATE(4701),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6512),
    [sym_preproc_endif] = STATE(10155),
    [sym_preproc_conditional_layout] = STATE(4701),
    [aux_sym_layout_section_repeat1] = STATE(4701),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10715),
    [anon_sym_RBRACE] = ACTIONS(9908),
    [aux_sym_where_condition_token1] = ACTIONS(9790),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4355)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17299),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4356)] = {
    [sym_boolean] = STATE(8721),
    [sym_assignment_expression] = STATE(8721),
    [sym__expression] = STATE(8721),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8721),
    [sym_multiplicative_expression] = STATE(8721),
    [sym_additive_expression] = STATE(8721),
    [sym_comparison_expression] = STATE(8721),
    [sym_logical_expression] = STATE(8721),
    [sym_ternary_expression] = STATE(8721),
    [sym_unary_expression] = STATE(8721),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8721),
    [sym_list_literal] = STATE(8721),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8721),
    [sym__literal_value] = STATE(8721),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9910),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9912),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9914),
    [sym_date_literal] = ACTIONS(9910),
    [sym_time_literal] = ACTIONS(9910),
    [sym_biginteger_literal] = ACTIONS(9914),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9914),
    [sym_verbatim_string] = ACTIONS(9914),
    [sym_integer] = ACTIONS(9910),
    [sym_continue_as_identifier] = ACTIONS(9914),
  },
  [STATE(4357)] = {
    [sym_boolean] = STATE(8714),
    [sym_assignment_expression] = STATE(8714),
    [sym__expression] = STATE(8714),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8714),
    [sym_multiplicative_expression] = STATE(8714),
    [sym_additive_expression] = STATE(8714),
    [sym_comparison_expression] = STATE(8714),
    [sym_logical_expression] = STATE(8714),
    [sym_ternary_expression] = STATE(8714),
    [sym_unary_expression] = STATE(8714),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8714),
    [sym_list_literal] = STATE(8714),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8714),
    [sym__literal_value] = STATE(8714),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9916),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9918),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9920),
    [sym_date_literal] = ACTIONS(9916),
    [sym_time_literal] = ACTIONS(9916),
    [sym_biginteger_literal] = ACTIONS(9920),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9920),
    [sym_verbatim_string] = ACTIONS(9920),
    [sym_integer] = ACTIONS(9916),
    [sym_continue_as_identifier] = ACTIONS(9920),
  },
  [STATE(4358)] = {
    [sym__layout_element] = STATE(4587),
    [sym_area_section] = STATE(4587),
    [sym_group_section] = STATE(4587),
    [sym_repeater_section] = STATE(4587),
    [sym_cuegroup_section] = STATE(4587),
    [sym_fixed_section] = STATE(4587),
    [sym_grid_section] = STATE(4587),
    [sym_page_field] = STATE(4587),
    [sym_part_section] = STATE(4587),
    [sym_systempart_section] = STATE(4587),
    [sym_usercontrol_section] = STATE(4587),
    [sym_preproc_split_field] = STATE(4587),
    [sym__field_header] = STATE(10667),
    [sym_label_section] = STATE(4587),
    [sym_addfirst_modification] = STATE(4587),
    [sym_addlast_modification] = STATE(4587),
    [sym_addafter_modification] = STATE(4587),
    [sym_addbefore_modification] = STATE(4587),
    [sym_modify_modification] = STATE(4587),
    [sym_movefirst_modification] = STATE(4587),
    [sym_movelast_modification] = STATE(4587),
    [sym_moveafter_modification] = STATE(4587),
    [sym_movebefore_modification] = STATE(4587),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6512),
    [sym_preproc_endif] = STATE(10155),
    [sym_preproc_conditional_layout] = STATE(4587),
    [aux_sym_layout_section_repeat1] = STATE(4587),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10715),
    [anon_sym_RBRACE] = ACTIONS(9922),
    [aux_sym_where_condition_token1] = ACTIONS(9790),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4359)] = {
    [sym_boolean] = STATE(8720),
    [sym_assignment_expression] = STATE(8720),
    [sym__expression] = STATE(8720),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8720),
    [sym_multiplicative_expression] = STATE(8720),
    [sym_additive_expression] = STATE(8720),
    [sym_comparison_expression] = STATE(8720),
    [sym_logical_expression] = STATE(8720),
    [sym_ternary_expression] = STATE(8720),
    [sym_unary_expression] = STATE(8720),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8720),
    [sym_list_literal] = STATE(8720),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8720),
    [sym__literal_value] = STATE(8720),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9924),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9926),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9928),
    [sym_date_literal] = ACTIONS(9924),
    [sym_time_literal] = ACTIONS(9924),
    [sym_biginteger_literal] = ACTIONS(9928),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9928),
    [sym_verbatim_string] = ACTIONS(9928),
    [sym_integer] = ACTIONS(9924),
    [sym_continue_as_identifier] = ACTIONS(9928),
  },
  [STATE(4360)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17965),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4361)] = {
    [sym_boolean] = STATE(8637),
    [sym_assignment_expression] = STATE(8637),
    [sym__expression] = STATE(8637),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8637),
    [sym_multiplicative_expression] = STATE(8637),
    [sym_additive_expression] = STATE(8637),
    [sym_comparison_expression] = STATE(8637),
    [sym_logical_expression] = STATE(8637),
    [sym_ternary_expression] = STATE(8637),
    [sym_unary_expression] = STATE(8637),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8637),
    [sym_list_literal] = STATE(8637),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8637),
    [sym__literal_value] = STATE(8637),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9930),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9932),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9934),
    [sym_date_literal] = ACTIONS(9930),
    [sym_time_literal] = ACTIONS(9930),
    [sym_biginteger_literal] = ACTIONS(9934),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9934),
    [sym_verbatim_string] = ACTIONS(9934),
    [sym_integer] = ACTIONS(9930),
    [sym_continue_as_identifier] = ACTIONS(9934),
  },
  [STATE(4362)] = {
    [sym_identifier] = ACTIONS(9936),
    [anon_sym_DASH] = ACTIONS(9938),
    [aux_sym_boolean_token1] = ACTIONS(9936),
    [aux_sym_boolean_token2] = ACTIONS(9936),
    [sym_decimal] = ACTIONS(9936),
    [anon_sym_LPAREN] = ACTIONS(9938),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9936),
    [anon_sym_LBRACK] = ACTIONS(9938),
    [aux_sym_record_type_token1] = ACTIONS(9936),
    [aux_sym_basic_type_token21] = ACTIONS(9936),
    [aux_sym_basic_type_token22] = ACTIONS(9936),
    [aux_sym_basic_type_token48] = ACTIONS(9936),
    [anon_sym_POUNDif] = ACTIONS(9938),
    [anon_sym_POUNDIF] = ACTIONS(9938),
    [anon_sym_POUNDIf] = ACTIONS(9938),
    [anon_sym_not] = ACTIONS(9936),
    [anon_sym_NOT] = ACTIONS(9936),
    [anon_sym_Not] = ACTIONS(9936),
    [anon_sym_POUNDelif] = ACTIONS(9938),
    [anon_sym_POUNDELIF] = ACTIONS(9938),
    [anon_sym_POUNDElif] = ACTIONS(9938),
    [anon_sym_POUNDelse] = ACTIONS(9938),
    [anon_sym_POUNDELSE] = ACTIONS(9938),
    [anon_sym_POUNDElse] = ACTIONS(9938),
    [anon_sym_POUNDelse2] = ACTIONS(9938),
    [anon_sym_POUNDELSE2] = ACTIONS(9938),
    [anon_sym_POUNDElse2] = ACTIONS(9938),
    [anon_sym_POUNDendif] = ACTIONS(9938),
    [anon_sym_POUNDENDIF] = ACTIONS(9938),
    [anon_sym_POUNDEndif] = ACTIONS(9938),
    [anon_sym_POUNDendif2] = ACTIONS(9938),
    [anon_sym_POUNDENDIF2] = ACTIONS(9938),
    [anon_sym_POUNDEndif2] = ACTIONS(9938),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9936),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9936),
    [anon_sym_PLUS] = ACTIONS(9938),
    [sym_datetime_literal] = ACTIONS(9938),
    [sym_date_literal] = ACTIONS(9936),
    [sym_time_literal] = ACTIONS(9936),
    [sym_biginteger_literal] = ACTIONS(9938),
    [anon_sym_else] = ACTIONS(9936),
    [anon_sym_ELSE] = ACTIONS(9936),
    [anon_sym_Else] = ACTIONS(9936),
    [sym_page_keyword] = ACTIONS(9936),
    [anon_sym_codeunit] = ACTIONS(9936),
    [anon_sym_CODEUNIT] = ACTIONS(9936),
    [anon_sym_Codeunit] = ACTIONS(9936),
    [anon_sym_CodeUnit] = ACTIONS(9936),
    [anon_sym_COdeunit] = ACTIONS(9936),
    [anon_sym_codeUnit] = ACTIONS(9936),
    [sym_report_keyword] = ACTIONS(9936),
    [sym_query_keyword] = ACTIONS(9936),
    [anon_sym_xmlport] = ACTIONS(9936),
    [anon_sym_XMLPORT] = ACTIONS(9936),
    [anon_sym_Xmlport] = ACTIONS(9936),
    [anon_sym_XMLport] = ACTIONS(9936),
    [anon_sym_XMLPort] = ACTIONS(9936),
    [anon_sym_XmlPort] = ACTIONS(9936),
    [anon_sym_enum] = ACTIONS(9936),
    [anon_sym_ENUM] = ACTIONS(9936),
    [anon_sym_Enum] = ACTIONS(9936),
    [anon_sym_eNUM] = ACTIONS(9936),
    [anon_sym_eNum] = ACTIONS(9936),
    [anon_sym_ENum] = ACTIONS(9936),
    [sym_quoted_identifier] = ACTIONS(9938),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9938),
    [sym_verbatim_string] = ACTIONS(9938),
    [sym_integer] = ACTIONS(9936),
    [sym_continue_as_identifier] = ACTIONS(9938),
    [sym_preproc_open] = ACTIONS(9938),
    [sym_preproc_close] = ACTIONS(9938),
  },
  [STATE(4363)] = {
    [sym_boolean] = STATE(8681),
    [sym_assignment_expression] = STATE(8681),
    [sym__expression] = STATE(8681),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8681),
    [sym_multiplicative_expression] = STATE(8681),
    [sym_additive_expression] = STATE(8681),
    [sym_comparison_expression] = STATE(8681),
    [sym_logical_expression] = STATE(8681),
    [sym_ternary_expression] = STATE(8681),
    [sym_unary_expression] = STATE(8681),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8681),
    [sym_list_literal] = STATE(8681),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8681),
    [sym__literal_value] = STATE(8681),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9940),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9942),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9944),
    [sym_date_literal] = ACTIONS(9940),
    [sym_time_literal] = ACTIONS(9940),
    [sym_biginteger_literal] = ACTIONS(9944),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9944),
    [sym_verbatim_string] = ACTIONS(9944),
    [sym_integer] = ACTIONS(9940),
    [sym_continue_as_identifier] = ACTIONS(9944),
  },
  [STATE(4364)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(13465),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4365)] = {
    [sym_identifier] = ACTIONS(9948),
    [anon_sym_DASH] = ACTIONS(9950),
    [aux_sym_boolean_token1] = ACTIONS(9948),
    [aux_sym_boolean_token2] = ACTIONS(9948),
    [sym_decimal] = ACTIONS(9948),
    [anon_sym_LPAREN] = ACTIONS(9950),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9948),
    [anon_sym_LBRACK] = ACTIONS(9950),
    [aux_sym_record_type_token1] = ACTIONS(9948),
    [aux_sym_basic_type_token21] = ACTIONS(9948),
    [aux_sym_basic_type_token22] = ACTIONS(9948),
    [aux_sym_basic_type_token48] = ACTIONS(9948),
    [anon_sym_POUNDif] = ACTIONS(9950),
    [anon_sym_POUNDIF] = ACTIONS(9950),
    [anon_sym_POUNDIf] = ACTIONS(9950),
    [anon_sym_not] = ACTIONS(9948),
    [anon_sym_NOT] = ACTIONS(9948),
    [anon_sym_Not] = ACTIONS(9948),
    [anon_sym_POUNDelif] = ACTIONS(9950),
    [anon_sym_POUNDELIF] = ACTIONS(9950),
    [anon_sym_POUNDElif] = ACTIONS(9950),
    [anon_sym_POUNDelse] = ACTIONS(9950),
    [anon_sym_POUNDELSE] = ACTIONS(9950),
    [anon_sym_POUNDElse] = ACTIONS(9950),
    [anon_sym_POUNDelse2] = ACTIONS(9950),
    [anon_sym_POUNDELSE2] = ACTIONS(9950),
    [anon_sym_POUNDElse2] = ACTIONS(9950),
    [anon_sym_POUNDendif] = ACTIONS(9950),
    [anon_sym_POUNDENDIF] = ACTIONS(9950),
    [anon_sym_POUNDEndif] = ACTIONS(9950),
    [anon_sym_POUNDendif2] = ACTIONS(9950),
    [anon_sym_POUNDENDIF2] = ACTIONS(9950),
    [anon_sym_POUNDEndif2] = ACTIONS(9950),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9948),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9948),
    [anon_sym_PLUS] = ACTIONS(9950),
    [sym_datetime_literal] = ACTIONS(9950),
    [sym_date_literal] = ACTIONS(9948),
    [sym_time_literal] = ACTIONS(9948),
    [sym_biginteger_literal] = ACTIONS(9950),
    [anon_sym_else] = ACTIONS(9948),
    [anon_sym_ELSE] = ACTIONS(9948),
    [anon_sym_Else] = ACTIONS(9948),
    [sym_page_keyword] = ACTIONS(9948),
    [anon_sym_codeunit] = ACTIONS(9948),
    [anon_sym_CODEUNIT] = ACTIONS(9948),
    [anon_sym_Codeunit] = ACTIONS(9948),
    [anon_sym_CodeUnit] = ACTIONS(9948),
    [anon_sym_COdeunit] = ACTIONS(9948),
    [anon_sym_codeUnit] = ACTIONS(9948),
    [sym_report_keyword] = ACTIONS(9948),
    [sym_query_keyword] = ACTIONS(9948),
    [anon_sym_xmlport] = ACTIONS(9948),
    [anon_sym_XMLPORT] = ACTIONS(9948),
    [anon_sym_Xmlport] = ACTIONS(9948),
    [anon_sym_XMLport] = ACTIONS(9948),
    [anon_sym_XMLPort] = ACTIONS(9948),
    [anon_sym_XmlPort] = ACTIONS(9948),
    [anon_sym_enum] = ACTIONS(9948),
    [anon_sym_ENUM] = ACTIONS(9948),
    [anon_sym_Enum] = ACTIONS(9948),
    [anon_sym_eNUM] = ACTIONS(9948),
    [anon_sym_eNum] = ACTIONS(9948),
    [anon_sym_ENum] = ACTIONS(9948),
    [sym_quoted_identifier] = ACTIONS(9950),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9950),
    [sym_verbatim_string] = ACTIONS(9950),
    [sym_integer] = ACTIONS(9948),
    [sym_continue_as_identifier] = ACTIONS(9950),
    [sym_preproc_open] = ACTIONS(9950),
    [sym_preproc_close] = ACTIONS(9950),
  },
  [STATE(4366)] = {
    [sym_identifier] = ACTIONS(9952),
    [anon_sym_DASH] = ACTIONS(9954),
    [aux_sym_boolean_token1] = ACTIONS(9952),
    [aux_sym_boolean_token2] = ACTIONS(9952),
    [sym_decimal] = ACTIONS(9952),
    [anon_sym_LPAREN] = ACTIONS(9954),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9952),
    [anon_sym_LBRACK] = ACTIONS(9954),
    [aux_sym_record_type_token1] = ACTIONS(9952),
    [aux_sym_basic_type_token21] = ACTIONS(9952),
    [aux_sym_basic_type_token22] = ACTIONS(9952),
    [aux_sym_basic_type_token48] = ACTIONS(9952),
    [anon_sym_POUNDif] = ACTIONS(9954),
    [anon_sym_POUNDIF] = ACTIONS(9954),
    [anon_sym_POUNDIf] = ACTIONS(9954),
    [anon_sym_not] = ACTIONS(9952),
    [anon_sym_NOT] = ACTIONS(9952),
    [anon_sym_Not] = ACTIONS(9952),
    [anon_sym_POUNDelif] = ACTIONS(9954),
    [anon_sym_POUNDELIF] = ACTIONS(9954),
    [anon_sym_POUNDElif] = ACTIONS(9954),
    [anon_sym_POUNDelse] = ACTIONS(9954),
    [anon_sym_POUNDELSE] = ACTIONS(9954),
    [anon_sym_POUNDElse] = ACTIONS(9954),
    [anon_sym_POUNDelse2] = ACTIONS(9954),
    [anon_sym_POUNDELSE2] = ACTIONS(9954),
    [anon_sym_POUNDElse2] = ACTIONS(9954),
    [anon_sym_POUNDendif] = ACTIONS(9954),
    [anon_sym_POUNDENDIF] = ACTIONS(9954),
    [anon_sym_POUNDEndif] = ACTIONS(9954),
    [anon_sym_POUNDendif2] = ACTIONS(9954),
    [anon_sym_POUNDENDIF2] = ACTIONS(9954),
    [anon_sym_POUNDEndif2] = ACTIONS(9954),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9952),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9952),
    [anon_sym_PLUS] = ACTIONS(9954),
    [sym_datetime_literal] = ACTIONS(9954),
    [sym_date_literal] = ACTIONS(9952),
    [sym_time_literal] = ACTIONS(9952),
    [sym_biginteger_literal] = ACTIONS(9954),
    [anon_sym_else] = ACTIONS(9952),
    [anon_sym_ELSE] = ACTIONS(9952),
    [anon_sym_Else] = ACTIONS(9952),
    [sym_page_keyword] = ACTIONS(9952),
    [anon_sym_codeunit] = ACTIONS(9952),
    [anon_sym_CODEUNIT] = ACTIONS(9952),
    [anon_sym_Codeunit] = ACTIONS(9952),
    [anon_sym_CodeUnit] = ACTIONS(9952),
    [anon_sym_COdeunit] = ACTIONS(9952),
    [anon_sym_codeUnit] = ACTIONS(9952),
    [sym_report_keyword] = ACTIONS(9952),
    [sym_query_keyword] = ACTIONS(9952),
    [anon_sym_xmlport] = ACTIONS(9952),
    [anon_sym_XMLPORT] = ACTIONS(9952),
    [anon_sym_Xmlport] = ACTIONS(9952),
    [anon_sym_XMLport] = ACTIONS(9952),
    [anon_sym_XMLPort] = ACTIONS(9952),
    [anon_sym_XmlPort] = ACTIONS(9952),
    [anon_sym_enum] = ACTIONS(9952),
    [anon_sym_ENUM] = ACTIONS(9952),
    [anon_sym_Enum] = ACTIONS(9952),
    [anon_sym_eNUM] = ACTIONS(9952),
    [anon_sym_eNum] = ACTIONS(9952),
    [anon_sym_ENum] = ACTIONS(9952),
    [sym_quoted_identifier] = ACTIONS(9954),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9954),
    [sym_verbatim_string] = ACTIONS(9954),
    [sym_integer] = ACTIONS(9952),
    [sym_continue_as_identifier] = ACTIONS(9954),
    [sym_preproc_open] = ACTIONS(9954),
    [sym_preproc_close] = ACTIONS(9954),
  },
  [STATE(4367)] = {
    [sym_identifier] = ACTIONS(9956),
    [anon_sym_DASH] = ACTIONS(9958),
    [aux_sym_boolean_token1] = ACTIONS(9956),
    [aux_sym_boolean_token2] = ACTIONS(9956),
    [sym_decimal] = ACTIONS(9956),
    [anon_sym_LPAREN] = ACTIONS(9958),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9956),
    [anon_sym_LBRACK] = ACTIONS(9958),
    [aux_sym_record_type_token1] = ACTIONS(9956),
    [aux_sym_basic_type_token21] = ACTIONS(9956),
    [aux_sym_basic_type_token22] = ACTIONS(9956),
    [aux_sym_basic_type_token48] = ACTIONS(9956),
    [anon_sym_POUNDif] = ACTIONS(9958),
    [anon_sym_POUNDIF] = ACTIONS(9958),
    [anon_sym_POUNDIf] = ACTIONS(9958),
    [anon_sym_not] = ACTIONS(9956),
    [anon_sym_NOT] = ACTIONS(9956),
    [anon_sym_Not] = ACTIONS(9956),
    [anon_sym_POUNDelif] = ACTIONS(9958),
    [anon_sym_POUNDELIF] = ACTIONS(9958),
    [anon_sym_POUNDElif] = ACTIONS(9958),
    [anon_sym_POUNDelse] = ACTIONS(9958),
    [anon_sym_POUNDELSE] = ACTIONS(9958),
    [anon_sym_POUNDElse] = ACTIONS(9958),
    [anon_sym_POUNDelse2] = ACTIONS(9958),
    [anon_sym_POUNDELSE2] = ACTIONS(9958),
    [anon_sym_POUNDElse2] = ACTIONS(9958),
    [anon_sym_POUNDendif] = ACTIONS(9958),
    [anon_sym_POUNDENDIF] = ACTIONS(9958),
    [anon_sym_POUNDEndif] = ACTIONS(9958),
    [anon_sym_POUNDendif2] = ACTIONS(9958),
    [anon_sym_POUNDENDIF2] = ACTIONS(9958),
    [anon_sym_POUNDEndif2] = ACTIONS(9958),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9956),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9956),
    [anon_sym_PLUS] = ACTIONS(9958),
    [sym_datetime_literal] = ACTIONS(9958),
    [sym_date_literal] = ACTIONS(9956),
    [sym_time_literal] = ACTIONS(9956),
    [sym_biginteger_literal] = ACTIONS(9958),
    [anon_sym_else] = ACTIONS(9956),
    [anon_sym_ELSE] = ACTIONS(9956),
    [anon_sym_Else] = ACTIONS(9956),
    [sym_page_keyword] = ACTIONS(9956),
    [anon_sym_codeunit] = ACTIONS(9956),
    [anon_sym_CODEUNIT] = ACTIONS(9956),
    [anon_sym_Codeunit] = ACTIONS(9956),
    [anon_sym_CodeUnit] = ACTIONS(9956),
    [anon_sym_COdeunit] = ACTIONS(9956),
    [anon_sym_codeUnit] = ACTIONS(9956),
    [sym_report_keyword] = ACTIONS(9956),
    [sym_query_keyword] = ACTIONS(9956),
    [anon_sym_xmlport] = ACTIONS(9956),
    [anon_sym_XMLPORT] = ACTIONS(9956),
    [anon_sym_Xmlport] = ACTIONS(9956),
    [anon_sym_XMLport] = ACTIONS(9956),
    [anon_sym_XMLPort] = ACTIONS(9956),
    [anon_sym_XmlPort] = ACTIONS(9956),
    [anon_sym_enum] = ACTIONS(9956),
    [anon_sym_ENUM] = ACTIONS(9956),
    [anon_sym_Enum] = ACTIONS(9956),
    [anon_sym_eNUM] = ACTIONS(9956),
    [anon_sym_eNum] = ACTIONS(9956),
    [anon_sym_ENum] = ACTIONS(9956),
    [sym_quoted_identifier] = ACTIONS(9958),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9958),
    [sym_verbatim_string] = ACTIONS(9958),
    [sym_integer] = ACTIONS(9956),
    [sym_continue_as_identifier] = ACTIONS(9958),
    [sym_preproc_open] = ACTIONS(9958),
    [sym_preproc_close] = ACTIONS(9958),
  },
  [STATE(4368)] = {
    [sym_boolean] = STATE(8629),
    [sym_assignment_expression] = STATE(8629),
    [sym__expression] = STATE(8629),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8629),
    [sym_multiplicative_expression] = STATE(8629),
    [sym_additive_expression] = STATE(8629),
    [sym_comparison_expression] = STATE(8629),
    [sym_logical_expression] = STATE(8629),
    [sym_ternary_expression] = STATE(8629),
    [sym_unary_expression] = STATE(8629),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8629),
    [sym_list_literal] = STATE(8629),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8629),
    [sym__literal_value] = STATE(8629),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9960),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [anon_sym_RBRACK] = ACTIONS(9962),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9964),
    [sym_date_literal] = ACTIONS(9960),
    [sym_time_literal] = ACTIONS(9960),
    [sym_biginteger_literal] = ACTIONS(9964),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9964),
    [sym_verbatim_string] = ACTIONS(9964),
    [sym_integer] = ACTIONS(9960),
    [sym_continue_as_identifier] = ACTIONS(9964),
  },
  [STATE(4369)] = {
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(6589),
    [anon_sym_RBRACE] = ACTIONS(3695),
    [anon_sym_EQ] = ACTIONS(6591),
    [anon_sym_DASH] = ACTIONS(6589),
    [aux_sym_where_clause_token1] = ACTIONS(3695),
    [anon_sym_DOT_DOT] = ACTIONS(6591),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3695),
    [anon_sym_STAR] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(6593),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3695),
    [aux_sym_modify_modification_token1] = ACTIONS(3695),
    [aux_sym_xmlport_element_token1] = ACTIONS(3695),
    [aux_sym_xmlport_element_token2] = ACTIONS(3695),
    [aux_sym_xmlport_element_token3] = ACTIONS(3695),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(3695),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(3695),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3693),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(6591),
    [aux_sym__expression_token1] = ACTIONS(6591),
    [aux_sym__expression_token2] = ACTIONS(6591),
    [anon_sym_SLASH] = ACTIONS(6589),
    [anon_sym_div] = ACTIONS(6591),
    [anon_sym_DIV] = ACTIONS(6591),
    [anon_sym_Div] = ACTIONS(6591),
    [anon_sym_mod] = ACTIONS(6589),
    [anon_sym_MOD] = ACTIONS(6589),
    [anon_sym_Mod] = ACTIONS(6589),
    [anon_sym_PLUS] = ACTIONS(6589),
    [anon_sym_GT_EQ] = ACTIONS(6591),
    [anon_sym_LT_EQ] = ACTIONS(6591),
    [anon_sym_GT] = ACTIONS(6589),
    [anon_sym_LT] = ACTIONS(6589),
    [anon_sym_LT_GT] = ACTIONS(6591),
    [anon_sym_and] = ACTIONS(6591),
    [anon_sym_AND] = ACTIONS(6591),
    [anon_sym_And] = ACTIONS(6591),
    [anon_sym_or] = ACTIONS(6591),
    [anon_sym_OR] = ACTIONS(6591),
    [anon_sym_Or] = ACTIONS(6591),
    [anon_sym_xor] = ACTIONS(6591),
    [anon_sym_XOR] = ACTIONS(6591),
    [anon_sym_Xor] = ACTIONS(6591),
    [anon_sym_QMARK] = ACTIONS(6591),
    [anon_sym_in] = ACTIONS(6589),
    [anon_sym_IN] = ACTIONS(6589),
    [anon_sym_In] = ACTIONS(6589),
    [sym_procedure_keyword] = ACTIONS(3695),
    [sym_trigger_keyword] = ACTIONS(3695),
    [sym_var_keyword] = ACTIONS(3695),
    [sym_local_keyword] = ACTIONS(3695),
    [sym_internal_keyword] = ACTIONS(3695),
    [sym_protected_keyword] = ACTIONS(3695),
    [sym_event_keyword] = ACTIONS(3695),
    [sym_fields_keyword] = ACTIONS(3695),
    [sym_keys_keyword] = ACTIONS(3695),
    [sym_fieldgroups_keyword] = ACTIONS(3695),
    [sym_actions_keyword] = ACTIONS(3695),
    [sym_layout_keyword] = ACTIONS(3695),
    [sym_dataset_keyword] = ACTIONS(3695),
    [sym_elements_keyword] = ACTIONS(3695),
    [sym_labels_keyword] = ACTIONS(3695),
    [sym_rendering_keyword] = ACTIONS(3695),
    [sym_requestpage_keyword] = ACTIONS(3695),
    [sym_schema_keyword] = ACTIONS(3695),
    [sym_views_keyword] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
  },
  [STATE(4370)] = {
    [sym_identifier] = ACTIONS(9966),
    [anon_sym_DASH] = ACTIONS(9968),
    [aux_sym_boolean_token1] = ACTIONS(9966),
    [aux_sym_boolean_token2] = ACTIONS(9966),
    [sym_decimal] = ACTIONS(9966),
    [anon_sym_LPAREN] = ACTIONS(9968),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9966),
    [anon_sym_LBRACK] = ACTIONS(9968),
    [aux_sym_record_type_token1] = ACTIONS(9966),
    [aux_sym_basic_type_token21] = ACTIONS(9966),
    [aux_sym_basic_type_token22] = ACTIONS(9966),
    [aux_sym_basic_type_token48] = ACTIONS(9966),
    [anon_sym_POUNDif] = ACTIONS(9968),
    [anon_sym_POUNDIF] = ACTIONS(9968),
    [anon_sym_POUNDIf] = ACTIONS(9968),
    [anon_sym_not] = ACTIONS(9966),
    [anon_sym_NOT] = ACTIONS(9966),
    [anon_sym_Not] = ACTIONS(9966),
    [anon_sym_POUNDelif] = ACTIONS(9968),
    [anon_sym_POUNDELIF] = ACTIONS(9968),
    [anon_sym_POUNDElif] = ACTIONS(9968),
    [anon_sym_POUNDelse] = ACTIONS(9968),
    [anon_sym_POUNDELSE] = ACTIONS(9968),
    [anon_sym_POUNDElse] = ACTIONS(9968),
    [anon_sym_POUNDelse2] = ACTIONS(9968),
    [anon_sym_POUNDELSE2] = ACTIONS(9968),
    [anon_sym_POUNDElse2] = ACTIONS(9968),
    [anon_sym_POUNDendif] = ACTIONS(9968),
    [anon_sym_POUNDENDIF] = ACTIONS(9968),
    [anon_sym_POUNDEndif] = ACTIONS(9968),
    [anon_sym_POUNDendif2] = ACTIONS(9968),
    [anon_sym_POUNDENDIF2] = ACTIONS(9968),
    [anon_sym_POUNDEndif2] = ACTIONS(9968),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9966),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9966),
    [anon_sym_PLUS] = ACTIONS(9968),
    [sym_datetime_literal] = ACTIONS(9968),
    [sym_date_literal] = ACTIONS(9966),
    [sym_time_literal] = ACTIONS(9966),
    [sym_biginteger_literal] = ACTIONS(9968),
    [anon_sym_else] = ACTIONS(9966),
    [anon_sym_ELSE] = ACTIONS(9966),
    [anon_sym_Else] = ACTIONS(9966),
    [sym_page_keyword] = ACTIONS(9966),
    [anon_sym_codeunit] = ACTIONS(9966),
    [anon_sym_CODEUNIT] = ACTIONS(9966),
    [anon_sym_Codeunit] = ACTIONS(9966),
    [anon_sym_CodeUnit] = ACTIONS(9966),
    [anon_sym_COdeunit] = ACTIONS(9966),
    [anon_sym_codeUnit] = ACTIONS(9966),
    [sym_report_keyword] = ACTIONS(9966),
    [sym_query_keyword] = ACTIONS(9966),
    [anon_sym_xmlport] = ACTIONS(9966),
    [anon_sym_XMLPORT] = ACTIONS(9966),
    [anon_sym_Xmlport] = ACTIONS(9966),
    [anon_sym_XMLport] = ACTIONS(9966),
    [anon_sym_XMLPort] = ACTIONS(9966),
    [anon_sym_XmlPort] = ACTIONS(9966),
    [anon_sym_enum] = ACTIONS(9966),
    [anon_sym_ENUM] = ACTIONS(9966),
    [anon_sym_Enum] = ACTIONS(9966),
    [anon_sym_eNUM] = ACTIONS(9966),
    [anon_sym_eNum] = ACTIONS(9966),
    [anon_sym_ENum] = ACTIONS(9966),
    [sym_quoted_identifier] = ACTIONS(9968),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9968),
    [sym_verbatim_string] = ACTIONS(9968),
    [sym_integer] = ACTIONS(9966),
    [sym_continue_as_identifier] = ACTIONS(9968),
    [sym_preproc_open] = ACTIONS(9968),
    [sym_preproc_close] = ACTIONS(9968),
  },
  [STATE(4371)] = {
    [sym_boolean] = STATE(8640),
    [sym_assignment_expression] = STATE(8640),
    [sym__expression] = STATE(8640),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8640),
    [sym_multiplicative_expression] = STATE(8640),
    [sym_additive_expression] = STATE(8640),
    [sym_comparison_expression] = STATE(8640),
    [sym_logical_expression] = STATE(8640),
    [sym_ternary_expression] = STATE(8640),
    [sym_unary_expression] = STATE(8640),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8640),
    [sym_list_literal] = STATE(8640),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8640),
    [sym__literal_value] = STATE(8640),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9970),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9972),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9974),
    [sym_date_literal] = ACTIONS(9970),
    [sym_time_literal] = ACTIONS(9970),
    [sym_biginteger_literal] = ACTIONS(9974),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9974),
    [sym_verbatim_string] = ACTIONS(9974),
    [sym_integer] = ACTIONS(9970),
    [sym_continue_as_identifier] = ACTIONS(9974),
  },
  [STATE(4372)] = {
    [sym_identifier] = ACTIONS(9888),
    [anon_sym_DASH] = ACTIONS(9890),
    [aux_sym_boolean_token1] = ACTIONS(9888),
    [aux_sym_boolean_token2] = ACTIONS(9888),
    [sym_decimal] = ACTIONS(9888),
    [anon_sym_LPAREN] = ACTIONS(9890),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9888),
    [anon_sym_LBRACK] = ACTIONS(9890),
    [aux_sym_record_type_token1] = ACTIONS(9888),
    [aux_sym_basic_type_token21] = ACTIONS(9888),
    [aux_sym_basic_type_token22] = ACTIONS(9888),
    [aux_sym_basic_type_token48] = ACTIONS(9888),
    [anon_sym_POUNDif] = ACTIONS(9890),
    [anon_sym_POUNDIF] = ACTIONS(9890),
    [anon_sym_POUNDIf] = ACTIONS(9890),
    [anon_sym_not] = ACTIONS(9888),
    [anon_sym_NOT] = ACTIONS(9888),
    [anon_sym_Not] = ACTIONS(9888),
    [anon_sym_POUNDelif] = ACTIONS(9890),
    [anon_sym_POUNDELIF] = ACTIONS(9890),
    [anon_sym_POUNDElif] = ACTIONS(9890),
    [anon_sym_POUNDelse] = ACTIONS(9890),
    [anon_sym_POUNDELSE] = ACTIONS(9890),
    [anon_sym_POUNDElse] = ACTIONS(9890),
    [anon_sym_POUNDelse2] = ACTIONS(9890),
    [anon_sym_POUNDELSE2] = ACTIONS(9890),
    [anon_sym_POUNDElse2] = ACTIONS(9890),
    [anon_sym_POUNDendif] = ACTIONS(9890),
    [anon_sym_POUNDENDIF] = ACTIONS(9890),
    [anon_sym_POUNDEndif] = ACTIONS(9890),
    [anon_sym_POUNDendif2] = ACTIONS(9890),
    [anon_sym_POUNDENDIF2] = ACTIONS(9890),
    [anon_sym_POUNDEndif2] = ACTIONS(9890),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9888),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9888),
    [anon_sym_PLUS] = ACTIONS(9890),
    [sym_datetime_literal] = ACTIONS(9890),
    [sym_date_literal] = ACTIONS(9888),
    [sym_time_literal] = ACTIONS(9888),
    [sym_biginteger_literal] = ACTIONS(9890),
    [anon_sym_else] = ACTIONS(9888),
    [anon_sym_ELSE] = ACTIONS(9888),
    [anon_sym_Else] = ACTIONS(9888),
    [sym_page_keyword] = ACTIONS(9888),
    [anon_sym_codeunit] = ACTIONS(9888),
    [anon_sym_CODEUNIT] = ACTIONS(9888),
    [anon_sym_Codeunit] = ACTIONS(9888),
    [anon_sym_CodeUnit] = ACTIONS(9888),
    [anon_sym_COdeunit] = ACTIONS(9888),
    [anon_sym_codeUnit] = ACTIONS(9888),
    [sym_report_keyword] = ACTIONS(9888),
    [sym_query_keyword] = ACTIONS(9888),
    [anon_sym_xmlport] = ACTIONS(9888),
    [anon_sym_XMLPORT] = ACTIONS(9888),
    [anon_sym_Xmlport] = ACTIONS(9888),
    [anon_sym_XMLport] = ACTIONS(9888),
    [anon_sym_XMLPort] = ACTIONS(9888),
    [anon_sym_XmlPort] = ACTIONS(9888),
    [anon_sym_enum] = ACTIONS(9888),
    [anon_sym_ENUM] = ACTIONS(9888),
    [anon_sym_Enum] = ACTIONS(9888),
    [anon_sym_eNUM] = ACTIONS(9888),
    [anon_sym_eNum] = ACTIONS(9888),
    [anon_sym_ENum] = ACTIONS(9888),
    [sym_quoted_identifier] = ACTIONS(9890),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9890),
    [sym_verbatim_string] = ACTIONS(9890),
    [sym_integer] = ACTIONS(9888),
    [sym_continue_as_identifier] = ACTIONS(9890),
    [sym_preproc_open] = ACTIONS(9890),
    [sym_preproc_close] = ACTIONS(9890),
  },
  [STATE(4373)] = {
    [sym_boolean] = STATE(8631),
    [sym_assignment_expression] = STATE(8631),
    [sym__expression] = STATE(8631),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8631),
    [sym_multiplicative_expression] = STATE(8631),
    [sym_additive_expression] = STATE(8631),
    [sym_comparison_expression] = STATE(8631),
    [sym_logical_expression] = STATE(8631),
    [sym_ternary_expression] = STATE(8631),
    [sym_unary_expression] = STATE(8631),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8631),
    [sym_list_literal] = STATE(8631),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8631),
    [sym__literal_value] = STATE(8631),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9976),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9978),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9980),
    [sym_date_literal] = ACTIONS(9976),
    [sym_time_literal] = ACTIONS(9976),
    [sym_biginteger_literal] = ACTIONS(9980),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9980),
    [sym_verbatim_string] = ACTIONS(9980),
    [sym_integer] = ACTIONS(9976),
    [sym_continue_as_identifier] = ACTIONS(9980),
  },
  [STATE(4374)] = {
    [sym_identifier] = ACTIONS(9760),
    [anon_sym_DASH] = ACTIONS(9762),
    [aux_sym_boolean_token1] = ACTIONS(9760),
    [aux_sym_boolean_token2] = ACTIONS(9760),
    [sym_decimal] = ACTIONS(9760),
    [anon_sym_LPAREN] = ACTIONS(9762),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9760),
    [anon_sym_LBRACK] = ACTIONS(9762),
    [aux_sym_record_type_token1] = ACTIONS(9760),
    [aux_sym_basic_type_token21] = ACTIONS(9760),
    [aux_sym_basic_type_token22] = ACTIONS(9760),
    [aux_sym_basic_type_token48] = ACTIONS(9760),
    [anon_sym_POUNDif] = ACTIONS(9762),
    [anon_sym_POUNDIF] = ACTIONS(9762),
    [anon_sym_POUNDIf] = ACTIONS(9762),
    [anon_sym_not] = ACTIONS(9760),
    [anon_sym_NOT] = ACTIONS(9760),
    [anon_sym_Not] = ACTIONS(9760),
    [anon_sym_POUNDelif] = ACTIONS(9762),
    [anon_sym_POUNDELIF] = ACTIONS(9762),
    [anon_sym_POUNDElif] = ACTIONS(9762),
    [anon_sym_POUNDelse] = ACTIONS(9762),
    [anon_sym_POUNDELSE] = ACTIONS(9762),
    [anon_sym_POUNDElse] = ACTIONS(9762),
    [anon_sym_POUNDelse2] = ACTIONS(9762),
    [anon_sym_POUNDELSE2] = ACTIONS(9762),
    [anon_sym_POUNDElse2] = ACTIONS(9762),
    [anon_sym_POUNDendif] = ACTIONS(9762),
    [anon_sym_POUNDENDIF] = ACTIONS(9762),
    [anon_sym_POUNDEndif] = ACTIONS(9762),
    [anon_sym_POUNDendif2] = ACTIONS(9762),
    [anon_sym_POUNDENDIF2] = ACTIONS(9762),
    [anon_sym_POUNDEndif2] = ACTIONS(9762),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9760),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9760),
    [anon_sym_PLUS] = ACTIONS(9762),
    [sym_datetime_literal] = ACTIONS(9762),
    [sym_date_literal] = ACTIONS(9760),
    [sym_time_literal] = ACTIONS(9760),
    [sym_biginteger_literal] = ACTIONS(9762),
    [anon_sym_else] = ACTIONS(9760),
    [anon_sym_ELSE] = ACTIONS(9760),
    [anon_sym_Else] = ACTIONS(9760),
    [sym_page_keyword] = ACTIONS(9760),
    [anon_sym_codeunit] = ACTIONS(9760),
    [anon_sym_CODEUNIT] = ACTIONS(9760),
    [anon_sym_Codeunit] = ACTIONS(9760),
    [anon_sym_CodeUnit] = ACTIONS(9760),
    [anon_sym_COdeunit] = ACTIONS(9760),
    [anon_sym_codeUnit] = ACTIONS(9760),
    [sym_report_keyword] = ACTIONS(9760),
    [sym_query_keyword] = ACTIONS(9760),
    [anon_sym_xmlport] = ACTIONS(9760),
    [anon_sym_XMLPORT] = ACTIONS(9760),
    [anon_sym_Xmlport] = ACTIONS(9760),
    [anon_sym_XMLport] = ACTIONS(9760),
    [anon_sym_XMLPort] = ACTIONS(9760),
    [anon_sym_XmlPort] = ACTIONS(9760),
    [anon_sym_enum] = ACTIONS(9760),
    [anon_sym_ENUM] = ACTIONS(9760),
    [anon_sym_Enum] = ACTIONS(9760),
    [anon_sym_eNUM] = ACTIONS(9760),
    [anon_sym_eNum] = ACTIONS(9760),
    [anon_sym_ENum] = ACTIONS(9760),
    [sym_quoted_identifier] = ACTIONS(9762),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9762),
    [sym_verbatim_string] = ACTIONS(9762),
    [sym_integer] = ACTIONS(9760),
    [sym_continue_as_identifier] = ACTIONS(9762),
    [sym_preproc_open] = ACTIONS(9762),
    [sym_preproc_close] = ACTIONS(9762),
  },
  [STATE(4375)] = {
    [sym_identifier] = ACTIONS(9840),
    [anon_sym_DASH] = ACTIONS(9842),
    [aux_sym_boolean_token1] = ACTIONS(9840),
    [aux_sym_boolean_token2] = ACTIONS(9840),
    [sym_decimal] = ACTIONS(9840),
    [anon_sym_LPAREN] = ACTIONS(9842),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9840),
    [anon_sym_LBRACK] = ACTIONS(9842),
    [aux_sym_record_type_token1] = ACTIONS(9840),
    [aux_sym_basic_type_token21] = ACTIONS(9840),
    [aux_sym_basic_type_token22] = ACTIONS(9840),
    [aux_sym_basic_type_token48] = ACTIONS(9840),
    [anon_sym_POUNDif] = ACTIONS(9842),
    [anon_sym_POUNDIF] = ACTIONS(9842),
    [anon_sym_POUNDIf] = ACTIONS(9842),
    [anon_sym_not] = ACTIONS(9840),
    [anon_sym_NOT] = ACTIONS(9840),
    [anon_sym_Not] = ACTIONS(9840),
    [anon_sym_POUNDelif] = ACTIONS(9842),
    [anon_sym_POUNDELIF] = ACTIONS(9842),
    [anon_sym_POUNDElif] = ACTIONS(9842),
    [anon_sym_POUNDelse] = ACTIONS(9842),
    [anon_sym_POUNDELSE] = ACTIONS(9842),
    [anon_sym_POUNDElse] = ACTIONS(9842),
    [anon_sym_POUNDelse2] = ACTIONS(9842),
    [anon_sym_POUNDELSE2] = ACTIONS(9842),
    [anon_sym_POUNDElse2] = ACTIONS(9842),
    [anon_sym_POUNDendif] = ACTIONS(9842),
    [anon_sym_POUNDENDIF] = ACTIONS(9842),
    [anon_sym_POUNDEndif] = ACTIONS(9842),
    [anon_sym_POUNDendif2] = ACTIONS(9842),
    [anon_sym_POUNDENDIF2] = ACTIONS(9842),
    [anon_sym_POUNDEndif2] = ACTIONS(9842),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9840),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9840),
    [anon_sym_PLUS] = ACTIONS(9842),
    [sym_datetime_literal] = ACTIONS(9842),
    [sym_date_literal] = ACTIONS(9840),
    [sym_time_literal] = ACTIONS(9840),
    [sym_biginteger_literal] = ACTIONS(9842),
    [anon_sym_else] = ACTIONS(9840),
    [anon_sym_ELSE] = ACTIONS(9840),
    [anon_sym_Else] = ACTIONS(9840),
    [sym_page_keyword] = ACTIONS(9840),
    [anon_sym_codeunit] = ACTIONS(9840),
    [anon_sym_CODEUNIT] = ACTIONS(9840),
    [anon_sym_Codeunit] = ACTIONS(9840),
    [anon_sym_CodeUnit] = ACTIONS(9840),
    [anon_sym_COdeunit] = ACTIONS(9840),
    [anon_sym_codeUnit] = ACTIONS(9840),
    [sym_report_keyword] = ACTIONS(9840),
    [sym_query_keyword] = ACTIONS(9840),
    [anon_sym_xmlport] = ACTIONS(9840),
    [anon_sym_XMLPORT] = ACTIONS(9840),
    [anon_sym_Xmlport] = ACTIONS(9840),
    [anon_sym_XMLport] = ACTIONS(9840),
    [anon_sym_XMLPort] = ACTIONS(9840),
    [anon_sym_XmlPort] = ACTIONS(9840),
    [anon_sym_enum] = ACTIONS(9840),
    [anon_sym_ENUM] = ACTIONS(9840),
    [anon_sym_Enum] = ACTIONS(9840),
    [anon_sym_eNUM] = ACTIONS(9840),
    [anon_sym_eNum] = ACTIONS(9840),
    [anon_sym_ENum] = ACTIONS(9840),
    [sym_quoted_identifier] = ACTIONS(9842),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9842),
    [sym_verbatim_string] = ACTIONS(9842),
    [sym_integer] = ACTIONS(9840),
    [sym_continue_as_identifier] = ACTIONS(9842),
    [sym_preproc_open] = ACTIONS(9842),
    [sym_preproc_close] = ACTIONS(9842),
  },
  [STATE(4376)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(14678),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4377)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(18077),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4378)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(14207),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4379)] = {
    [sym_boolean] = STATE(8648),
    [sym_assignment_expression] = STATE(8648),
    [sym__expression] = STATE(8648),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8648),
    [sym_multiplicative_expression] = STATE(8648),
    [sym_additive_expression] = STATE(8648),
    [sym_comparison_expression] = STATE(8648),
    [sym_logical_expression] = STATE(8648),
    [sym_ternary_expression] = STATE(8648),
    [sym_unary_expression] = STATE(8648),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8648),
    [sym_list_literal] = STATE(8648),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8648),
    [sym__literal_value] = STATE(8648),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9982),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9984),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9986),
    [sym_date_literal] = ACTIONS(9982),
    [sym_time_literal] = ACTIONS(9982),
    [sym_biginteger_literal] = ACTIONS(9986),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9986),
    [sym_verbatim_string] = ACTIONS(9986),
    [sym_integer] = ACTIONS(9982),
    [sym_continue_as_identifier] = ACTIONS(9986),
  },
  [STATE(4380)] = {
    [sym_boolean] = STATE(9116),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8701),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8701),
    [sym_database_reference] = STATE(9129),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9988),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9990),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9992),
    [sym_date_literal] = ACTIONS(9994),
    [sym_time_literal] = ACTIONS(9994),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(9996),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9992),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9994),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4381)] = {
    [sym_identifier] = ACTIONS(9998),
    [anon_sym_DASH] = ACTIONS(10000),
    [aux_sym_boolean_token1] = ACTIONS(9998),
    [aux_sym_boolean_token2] = ACTIONS(9998),
    [sym_decimal] = ACTIONS(9998),
    [anon_sym_LPAREN] = ACTIONS(10000),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9998),
    [anon_sym_LBRACK] = ACTIONS(10000),
    [aux_sym_record_type_token1] = ACTIONS(9998),
    [aux_sym_basic_type_token21] = ACTIONS(9998),
    [aux_sym_basic_type_token22] = ACTIONS(9998),
    [aux_sym_basic_type_token48] = ACTIONS(9998),
    [anon_sym_POUNDif] = ACTIONS(10000),
    [anon_sym_POUNDIF] = ACTIONS(10000),
    [anon_sym_POUNDIf] = ACTIONS(10000),
    [anon_sym_not] = ACTIONS(9998),
    [anon_sym_NOT] = ACTIONS(9998),
    [anon_sym_Not] = ACTIONS(9998),
    [anon_sym_POUNDelif] = ACTIONS(10000),
    [anon_sym_POUNDELIF] = ACTIONS(10000),
    [anon_sym_POUNDElif] = ACTIONS(10000),
    [anon_sym_POUNDelse] = ACTIONS(10000),
    [anon_sym_POUNDELSE] = ACTIONS(10000),
    [anon_sym_POUNDElse] = ACTIONS(10000),
    [anon_sym_POUNDelse2] = ACTIONS(10000),
    [anon_sym_POUNDELSE2] = ACTIONS(10000),
    [anon_sym_POUNDElse2] = ACTIONS(10000),
    [anon_sym_POUNDendif] = ACTIONS(10000),
    [anon_sym_POUNDENDIF] = ACTIONS(10000),
    [anon_sym_POUNDEndif] = ACTIONS(10000),
    [anon_sym_POUNDendif2] = ACTIONS(10000),
    [anon_sym_POUNDENDIF2] = ACTIONS(10000),
    [anon_sym_POUNDEndif2] = ACTIONS(10000),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9998),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9998),
    [anon_sym_PLUS] = ACTIONS(10000),
    [sym_datetime_literal] = ACTIONS(10000),
    [sym_date_literal] = ACTIONS(9998),
    [sym_time_literal] = ACTIONS(9998),
    [sym_biginteger_literal] = ACTIONS(10000),
    [anon_sym_else] = ACTIONS(9998),
    [anon_sym_ELSE] = ACTIONS(9998),
    [anon_sym_Else] = ACTIONS(9998),
    [sym_page_keyword] = ACTIONS(9998),
    [anon_sym_codeunit] = ACTIONS(9998),
    [anon_sym_CODEUNIT] = ACTIONS(9998),
    [anon_sym_Codeunit] = ACTIONS(9998),
    [anon_sym_CodeUnit] = ACTIONS(9998),
    [anon_sym_COdeunit] = ACTIONS(9998),
    [anon_sym_codeUnit] = ACTIONS(9998),
    [sym_report_keyword] = ACTIONS(9998),
    [sym_query_keyword] = ACTIONS(9998),
    [anon_sym_xmlport] = ACTIONS(9998),
    [anon_sym_XMLPORT] = ACTIONS(9998),
    [anon_sym_Xmlport] = ACTIONS(9998),
    [anon_sym_XMLport] = ACTIONS(9998),
    [anon_sym_XMLPort] = ACTIONS(9998),
    [anon_sym_XmlPort] = ACTIONS(9998),
    [anon_sym_enum] = ACTIONS(9998),
    [anon_sym_ENUM] = ACTIONS(9998),
    [anon_sym_Enum] = ACTIONS(9998),
    [anon_sym_eNUM] = ACTIONS(9998),
    [anon_sym_eNum] = ACTIONS(9998),
    [anon_sym_ENum] = ACTIONS(9998),
    [sym_quoted_identifier] = ACTIONS(10000),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10000),
    [sym_verbatim_string] = ACTIONS(10000),
    [sym_integer] = ACTIONS(9998),
    [sym_continue_as_identifier] = ACTIONS(10000),
    [sym_preproc_open] = ACTIONS(10000),
    [sym_preproc_close] = ACTIONS(10000),
  },
  [STATE(4382)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(4389),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(9806),
    [aux_sym_where_clause_token1] = ACTIONS(3701),
    [aux_sym_where_condition_token1] = ACTIONS(3699),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3701),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3701),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3701),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [aux_sym_basic_type_token6] = ACTIONS(3699),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3701),
    [aux_sym_addafter_modification_token1] = ACTIONS(3701),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3701),
    [aux_sym_modify_modification_token1] = ACTIONS(3701),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3701),
    [aux_sym_movelast_modification_token1] = ACTIONS(3701),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3701),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3701),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3701),
    [anon_sym_POUNDif] = ACTIONS(3701),
    [anon_sym_POUNDIF] = ACTIONS(3701),
    [anon_sym_POUNDIf] = ACTIONS(3701),
    [anon_sym_POUNDelif] = ACTIONS(3701),
    [anon_sym_POUNDELIF] = ACTIONS(3701),
    [anon_sym_POUNDElif] = ACTIONS(3701),
    [anon_sym_POUNDelse] = ACTIONS(3701),
    [anon_sym_POUNDELSE] = ACTIONS(3701),
    [anon_sym_POUNDElse] = ACTIONS(3701),
    [anon_sym_POUNDelse2] = ACTIONS(3701),
    [anon_sym_POUNDELSE2] = ACTIONS(3701),
    [anon_sym_POUNDElse2] = ACTIONS(3701),
    [anon_sym_POUNDendif] = ACTIONS(3701),
    [anon_sym_POUNDENDIF] = ACTIONS(3701),
    [anon_sym_POUNDEndif] = ACTIONS(3701),
    [anon_sym_POUNDendif2] = ACTIONS(3701),
    [anon_sym_POUNDENDIF2] = ACTIONS(3701),
    [anon_sym_POUNDEndif2] = ACTIONS(3701),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3701),
    [sym_trigger_keyword] = ACTIONS(3701),
    [sym_var_keyword] = ACTIONS(3701),
    [sym_local_keyword] = ACTIONS(3701),
    [sym_internal_keyword] = ACTIONS(3701),
    [sym_protected_keyword] = ACTIONS(3701),
    [sym_event_keyword] = ACTIONS(3701),
    [sym_fields_keyword] = ACTIONS(3701),
    [sym_keys_keyword] = ACTIONS(3701),
    [sym_fieldgroups_keyword] = ACTIONS(3701),
    [sym_actions_keyword] = ACTIONS(3701),
    [sym_layout_keyword] = ACTIONS(3701),
    [sym_area_keyword] = ACTIONS(3701),
    [sym_group_keyword] = ACTIONS(3701),
    [sym_repeater_keyword] = ACTIONS(3701),
    [sym_cuegroup_keyword] = ACTIONS(3701),
    [sym_fixed_keyword] = ACTIONS(3701),
    [sym_grid_keyword] = ACTIONS(3701),
    [sym_part_keyword] = ACTIONS(3701),
    [sym_systempart_keyword] = ACTIONS(3701),
    [sym_usercontrol_keyword] = ACTIONS(3701),
    [sym_dataset_keyword] = ACTIONS(3701),
    [sym_elements_keyword] = ACTIONS(3701),
    [sym_dataitem_keyword] = ACTIONS(3701),
    [sym_column_keyword] = ACTIONS(3701),
    [sym_filter_keyword] = ACTIONS(3701),
    [sym_labels_keyword] = ACTIONS(3701),
    [sym_rendering_keyword] = ACTIONS(3701),
    [sym_requestpage_keyword] = ACTIONS(3701),
    [sym_schema_keyword] = ACTIONS(3701),
    [sym_views_keyword] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3701),
    [sym_preproc_open] = ACTIONS(3701),
    [sym_preproc_close] = ACTIONS(3701),
  },
  [STATE(4383)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17850),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4384)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(18133),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4385)] = {
    [sym__layout_element] = STATE(4484),
    [sym_area_section] = STATE(4484),
    [sym_group_section] = STATE(4484),
    [sym_repeater_section] = STATE(4484),
    [sym_cuegroup_section] = STATE(4484),
    [sym_fixed_section] = STATE(4484),
    [sym_grid_section] = STATE(4484),
    [sym_page_field] = STATE(4484),
    [sym_part_section] = STATE(4484),
    [sym_systempart_section] = STATE(4484),
    [sym_usercontrol_section] = STATE(4484),
    [sym_preproc_split_field] = STATE(4484),
    [sym__field_header] = STATE(10667),
    [sym_label_section] = STATE(4484),
    [sym_addfirst_modification] = STATE(4484),
    [sym_addlast_modification] = STATE(4484),
    [sym_addafter_modification] = STATE(4484),
    [sym_addbefore_modification] = STATE(4484),
    [sym_modify_modification] = STATE(4484),
    [sym_movefirst_modification] = STATE(4484),
    [sym_movelast_modification] = STATE(4484),
    [sym_moveafter_modification] = STATE(4484),
    [sym_movebefore_modification] = STATE(4484),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6512),
    [sym_preproc_endif] = STATE(10155),
    [sym_preproc_conditional_layout] = STATE(4484),
    [aux_sym_layout_section_repeat1] = STATE(4484),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10715),
    [anon_sym_RBRACE] = ACTIONS(10002),
    [aux_sym_where_condition_token1] = ACTIONS(9790),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4386)] = {
    [sym_boolean] = STATE(8676),
    [sym_assignment_expression] = STATE(8676),
    [sym__expression] = STATE(8676),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8676),
    [sym_multiplicative_expression] = STATE(8676),
    [sym_additive_expression] = STATE(8676),
    [sym_comparison_expression] = STATE(8676),
    [sym_logical_expression] = STATE(8676),
    [sym_ternary_expression] = STATE(8676),
    [sym_unary_expression] = STATE(8676),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8676),
    [sym_list_literal] = STATE(8676),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8676),
    [sym__literal_value] = STATE(8676),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10004),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(8375),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10006),
    [sym_date_literal] = ACTIONS(10004),
    [sym_time_literal] = ACTIONS(10004),
    [sym_biginteger_literal] = ACTIONS(10006),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10006),
    [sym_verbatim_string] = ACTIONS(10006),
    [sym_integer] = ACTIONS(10004),
    [sym_continue_as_identifier] = ACTIONS(10006),
  },
  [STATE(4387)] = {
    [sym_identifier] = ACTIONS(10008),
    [anon_sym_DASH] = ACTIONS(10010),
    [aux_sym_boolean_token1] = ACTIONS(10008),
    [aux_sym_boolean_token2] = ACTIONS(10008),
    [sym_decimal] = ACTIONS(10008),
    [anon_sym_LPAREN] = ACTIONS(10010),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10008),
    [anon_sym_LBRACK] = ACTIONS(10010),
    [aux_sym_record_type_token1] = ACTIONS(10008),
    [aux_sym_basic_type_token21] = ACTIONS(10008),
    [aux_sym_basic_type_token22] = ACTIONS(10008),
    [aux_sym_basic_type_token48] = ACTIONS(10008),
    [anon_sym_POUNDif] = ACTIONS(10010),
    [anon_sym_POUNDIF] = ACTIONS(10010),
    [anon_sym_POUNDIf] = ACTIONS(10010),
    [anon_sym_not] = ACTIONS(10008),
    [anon_sym_NOT] = ACTIONS(10008),
    [anon_sym_Not] = ACTIONS(10008),
    [anon_sym_POUNDelif] = ACTIONS(10010),
    [anon_sym_POUNDELIF] = ACTIONS(10010),
    [anon_sym_POUNDElif] = ACTIONS(10010),
    [anon_sym_POUNDelse] = ACTIONS(10010),
    [anon_sym_POUNDELSE] = ACTIONS(10010),
    [anon_sym_POUNDElse] = ACTIONS(10010),
    [anon_sym_POUNDelse2] = ACTIONS(10010),
    [anon_sym_POUNDELSE2] = ACTIONS(10010),
    [anon_sym_POUNDElse2] = ACTIONS(10010),
    [anon_sym_POUNDendif] = ACTIONS(10010),
    [anon_sym_POUNDENDIF] = ACTIONS(10010),
    [anon_sym_POUNDEndif] = ACTIONS(10010),
    [anon_sym_POUNDendif2] = ACTIONS(10010),
    [anon_sym_POUNDENDIF2] = ACTIONS(10010),
    [anon_sym_POUNDEndif2] = ACTIONS(10010),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10008),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10008),
    [anon_sym_PLUS] = ACTIONS(10010),
    [sym_datetime_literal] = ACTIONS(10010),
    [sym_date_literal] = ACTIONS(10008),
    [sym_time_literal] = ACTIONS(10008),
    [sym_biginteger_literal] = ACTIONS(10010),
    [anon_sym_else] = ACTIONS(10008),
    [anon_sym_ELSE] = ACTIONS(10008),
    [anon_sym_Else] = ACTIONS(10008),
    [sym_page_keyword] = ACTIONS(10008),
    [anon_sym_codeunit] = ACTIONS(10008),
    [anon_sym_CODEUNIT] = ACTIONS(10008),
    [anon_sym_Codeunit] = ACTIONS(10008),
    [anon_sym_CodeUnit] = ACTIONS(10008),
    [anon_sym_COdeunit] = ACTIONS(10008),
    [anon_sym_codeUnit] = ACTIONS(10008),
    [sym_report_keyword] = ACTIONS(10008),
    [sym_query_keyword] = ACTIONS(10008),
    [anon_sym_xmlport] = ACTIONS(10008),
    [anon_sym_XMLPORT] = ACTIONS(10008),
    [anon_sym_Xmlport] = ACTIONS(10008),
    [anon_sym_XMLport] = ACTIONS(10008),
    [anon_sym_XMLPort] = ACTIONS(10008),
    [anon_sym_XmlPort] = ACTIONS(10008),
    [anon_sym_enum] = ACTIONS(10008),
    [anon_sym_ENUM] = ACTIONS(10008),
    [anon_sym_Enum] = ACTIONS(10008),
    [anon_sym_eNUM] = ACTIONS(10008),
    [anon_sym_eNum] = ACTIONS(10008),
    [anon_sym_ENum] = ACTIONS(10008),
    [sym_quoted_identifier] = ACTIONS(10010),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10010),
    [sym_verbatim_string] = ACTIONS(10010),
    [sym_integer] = ACTIONS(10008),
    [sym_continue_as_identifier] = ACTIONS(10010),
    [sym_preproc_open] = ACTIONS(10010),
    [sym_preproc_close] = ACTIONS(10010),
  },
  [STATE(4388)] = {
    [sym_boolean] = STATE(8639),
    [sym_assignment_expression] = STATE(8639),
    [sym__expression] = STATE(8639),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8639),
    [sym_multiplicative_expression] = STATE(8639),
    [sym_additive_expression] = STATE(8639),
    [sym_comparison_expression] = STATE(8639),
    [sym_logical_expression] = STATE(8639),
    [sym_ternary_expression] = STATE(8639),
    [sym_unary_expression] = STATE(8639),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8639),
    [sym_list_literal] = STATE(8639),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8639),
    [sym__literal_value] = STATE(8639),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10012),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10014),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10016),
    [sym_date_literal] = ACTIONS(10012),
    [sym_time_literal] = ACTIONS(10012),
    [sym_biginteger_literal] = ACTIONS(10016),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10016),
    [sym_verbatim_string] = ACTIONS(10016),
    [sym_integer] = ACTIONS(10012),
    [sym_continue_as_identifier] = ACTIONS(10016),
  },
  [STATE(4389)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(4389),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(10018),
    [aux_sym_where_clause_token1] = ACTIONS(3705),
    [aux_sym_where_condition_token1] = ACTIONS(3703),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3705),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3705),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3705),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_basic_type_token6] = ACTIONS(3703),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3705),
    [aux_sym_addafter_modification_token1] = ACTIONS(3705),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3705),
    [aux_sym_modify_modification_token1] = ACTIONS(3705),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3705),
    [aux_sym_movelast_modification_token1] = ACTIONS(3705),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3705),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3705),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3705),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_POUNDelif] = ACTIONS(3705),
    [anon_sym_POUNDELIF] = ACTIONS(3705),
    [anon_sym_POUNDElif] = ACTIONS(3705),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [anon_sym_POUNDendif] = ACTIONS(3705),
    [anon_sym_POUNDENDIF] = ACTIONS(3705),
    [anon_sym_POUNDEndif] = ACTIONS(3705),
    [anon_sym_POUNDendif2] = ACTIONS(3705),
    [anon_sym_POUNDENDIF2] = ACTIONS(3705),
    [anon_sym_POUNDEndif2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3705),
    [sym_trigger_keyword] = ACTIONS(3705),
    [sym_var_keyword] = ACTIONS(3705),
    [sym_local_keyword] = ACTIONS(3705),
    [sym_internal_keyword] = ACTIONS(3705),
    [sym_protected_keyword] = ACTIONS(3705),
    [sym_event_keyword] = ACTIONS(3705),
    [sym_fields_keyword] = ACTIONS(3705),
    [sym_keys_keyword] = ACTIONS(3705),
    [sym_fieldgroups_keyword] = ACTIONS(3705),
    [sym_actions_keyword] = ACTIONS(3705),
    [sym_layout_keyword] = ACTIONS(3705),
    [sym_area_keyword] = ACTIONS(3705),
    [sym_group_keyword] = ACTIONS(3705),
    [sym_repeater_keyword] = ACTIONS(3705),
    [sym_cuegroup_keyword] = ACTIONS(3705),
    [sym_fixed_keyword] = ACTIONS(3705),
    [sym_grid_keyword] = ACTIONS(3705),
    [sym_part_keyword] = ACTIONS(3705),
    [sym_systempart_keyword] = ACTIONS(3705),
    [sym_usercontrol_keyword] = ACTIONS(3705),
    [sym_dataset_keyword] = ACTIONS(3705),
    [sym_elements_keyword] = ACTIONS(3705),
    [sym_dataitem_keyword] = ACTIONS(3705),
    [sym_column_keyword] = ACTIONS(3705),
    [sym_filter_keyword] = ACTIONS(3705),
    [sym_labels_keyword] = ACTIONS(3705),
    [sym_rendering_keyword] = ACTIONS(3705),
    [sym_requestpage_keyword] = ACTIONS(3705),
    [sym_schema_keyword] = ACTIONS(3705),
    [sym_views_keyword] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
    [sym_preproc_close] = ACTIONS(3705),
  },
  [STATE(4390)] = {
    [sym_identifier] = ACTIONS(10021),
    [anon_sym_DASH] = ACTIONS(10023),
    [aux_sym_boolean_token1] = ACTIONS(10021),
    [aux_sym_boolean_token2] = ACTIONS(10021),
    [sym_decimal] = ACTIONS(10021),
    [anon_sym_LPAREN] = ACTIONS(10023),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10021),
    [anon_sym_LBRACK] = ACTIONS(10023),
    [aux_sym_record_type_token1] = ACTIONS(10021),
    [aux_sym_basic_type_token21] = ACTIONS(10021),
    [aux_sym_basic_type_token22] = ACTIONS(10021),
    [aux_sym_basic_type_token48] = ACTIONS(10021),
    [anon_sym_POUNDif] = ACTIONS(10023),
    [anon_sym_POUNDIF] = ACTIONS(10023),
    [anon_sym_POUNDIf] = ACTIONS(10023),
    [anon_sym_not] = ACTIONS(10021),
    [anon_sym_NOT] = ACTIONS(10021),
    [anon_sym_Not] = ACTIONS(10021),
    [anon_sym_POUNDelif] = ACTIONS(10023),
    [anon_sym_POUNDELIF] = ACTIONS(10023),
    [anon_sym_POUNDElif] = ACTIONS(10023),
    [anon_sym_POUNDelse] = ACTIONS(10023),
    [anon_sym_POUNDELSE] = ACTIONS(10023),
    [anon_sym_POUNDElse] = ACTIONS(10023),
    [anon_sym_POUNDelse2] = ACTIONS(10023),
    [anon_sym_POUNDELSE2] = ACTIONS(10023),
    [anon_sym_POUNDElse2] = ACTIONS(10023),
    [anon_sym_POUNDendif] = ACTIONS(10023),
    [anon_sym_POUNDENDIF] = ACTIONS(10023),
    [anon_sym_POUNDEndif] = ACTIONS(10023),
    [anon_sym_POUNDendif2] = ACTIONS(10023),
    [anon_sym_POUNDENDIF2] = ACTIONS(10023),
    [anon_sym_POUNDEndif2] = ACTIONS(10023),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10021),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10021),
    [anon_sym_PLUS] = ACTIONS(10023),
    [sym_datetime_literal] = ACTIONS(10023),
    [sym_date_literal] = ACTIONS(10021),
    [sym_time_literal] = ACTIONS(10021),
    [sym_biginteger_literal] = ACTIONS(10023),
    [anon_sym_else] = ACTIONS(10021),
    [anon_sym_ELSE] = ACTIONS(10021),
    [anon_sym_Else] = ACTIONS(10021),
    [sym_page_keyword] = ACTIONS(10021),
    [anon_sym_codeunit] = ACTIONS(10021),
    [anon_sym_CODEUNIT] = ACTIONS(10021),
    [anon_sym_Codeunit] = ACTIONS(10021),
    [anon_sym_CodeUnit] = ACTIONS(10021),
    [anon_sym_COdeunit] = ACTIONS(10021),
    [anon_sym_codeUnit] = ACTIONS(10021),
    [sym_report_keyword] = ACTIONS(10021),
    [sym_query_keyword] = ACTIONS(10021),
    [anon_sym_xmlport] = ACTIONS(10021),
    [anon_sym_XMLPORT] = ACTIONS(10021),
    [anon_sym_Xmlport] = ACTIONS(10021),
    [anon_sym_XMLport] = ACTIONS(10021),
    [anon_sym_XMLPort] = ACTIONS(10021),
    [anon_sym_XmlPort] = ACTIONS(10021),
    [anon_sym_enum] = ACTIONS(10021),
    [anon_sym_ENUM] = ACTIONS(10021),
    [anon_sym_Enum] = ACTIONS(10021),
    [anon_sym_eNUM] = ACTIONS(10021),
    [anon_sym_eNum] = ACTIONS(10021),
    [anon_sym_ENum] = ACTIONS(10021),
    [sym_quoted_identifier] = ACTIONS(10023),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10023),
    [sym_verbatim_string] = ACTIONS(10023),
    [sym_integer] = ACTIONS(10021),
    [sym_continue_as_identifier] = ACTIONS(10023),
    [sym_preproc_open] = ACTIONS(10023),
    [sym_preproc_close] = ACTIONS(10023),
  },
  [STATE(4391)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(14159),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4392)] = {
    [sym_preproc_conditional_controladdin] = STATE(4469),
    [sym__body_element] = STATE(8196),
    [sym_empty_statement] = STATE(8196),
    [sym_property] = STATE(8196),
    [sym_permissions_property] = STATE(8196),
    [sym_table_relation_property] = STATE(8196),
    [sym_fields_section] = STATE(8196),
    [sym_keys_section] = STATE(8196),
    [sym_fieldgroups_section] = STATE(8196),
    [sym_enum_value_declaration] = STATE(8196),
    [sym_labels_section] = STATE(8196),
    [sym_layout_section] = STATE(8196),
    [sym_modify_modification] = STATE(8196),
    [sym_actions_section] = STATE(8196),
    [sym_views_section] = STATE(8196),
    [sym_dataset_section] = STATE(8196),
    [sym_requestpage_section] = STATE(8196),
    [sym_rendering_section] = STATE(8196),
    [sym_elements_section] = STATE(8196),
    [sym_schema_section] = STATE(8196),
    [sym_assembly_declaration] = STATE(8196),
    [sym_event_declaration] = STATE(8196),
    [sym_procedure] = STATE(8196),
    [sym_preproc_split_procedure] = STATE(8196),
    [sym_preproc_split_procedure_preamble] = STATE(8196),
    [sym_interface_procedure] = STATE(4469),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(8196),
    [sym_var_section] = STATE(8196),
    [sym_attribute_item] = STATE(8196),
    [sym_preproc_conditional] = STATE(8196),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(9978),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4897),
    [aux_sym_controladdin_declaration_repeat1] = STATE(4469),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4393)] = {
    [sym_boolean] = STATE(8679),
    [sym_assignment_expression] = STATE(8679),
    [sym__expression] = STATE(8679),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8679),
    [sym_multiplicative_expression] = STATE(8679),
    [sym_additive_expression] = STATE(8679),
    [sym_comparison_expression] = STATE(8679),
    [sym_logical_expression] = STATE(8679),
    [sym_ternary_expression] = STATE(8679),
    [sym_unary_expression] = STATE(8679),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_list_literal] = STATE(8679),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8679),
    [sym__literal_value] = STATE(8679),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10025),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10027),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10029),
    [sym_date_literal] = ACTIONS(10025),
    [sym_time_literal] = ACTIONS(10025),
    [sym_biginteger_literal] = ACTIONS(10029),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10029),
    [sym_verbatim_string] = ACTIONS(10029),
    [sym_integer] = ACTIONS(10025),
    [sym_continue_as_identifier] = ACTIONS(10029),
  },
  [STATE(4394)] = {
    [sym_boolean] = STATE(8668),
    [sym_assignment_expression] = STATE(8668),
    [sym__expression] = STATE(8668),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8668),
    [sym_multiplicative_expression] = STATE(8668),
    [sym_additive_expression] = STATE(8668),
    [sym_comparison_expression] = STATE(8668),
    [sym_logical_expression] = STATE(8668),
    [sym_ternary_expression] = STATE(8668),
    [sym_unary_expression] = STATE(8668),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8668),
    [sym_list_literal] = STATE(8668),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8668),
    [sym__literal_value] = STATE(8668),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10031),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [anon_sym_RBRACK] = ACTIONS(10033),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10035),
    [sym_date_literal] = ACTIONS(10031),
    [sym_time_literal] = ACTIONS(10031),
    [sym_biginteger_literal] = ACTIONS(10035),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10035),
    [sym_verbatim_string] = ACTIONS(10035),
    [sym_integer] = ACTIONS(10031),
    [sym_continue_as_identifier] = ACTIONS(10035),
  },
  [STATE(4395)] = {
    [sym_boolean] = STATE(8626),
    [sym_assignment_expression] = STATE(8626),
    [sym__expression] = STATE(8626),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8626),
    [sym_multiplicative_expression] = STATE(8626),
    [sym_additive_expression] = STATE(8626),
    [sym_comparison_expression] = STATE(8626),
    [sym_logical_expression] = STATE(8626),
    [sym_ternary_expression] = STATE(8626),
    [sym_unary_expression] = STATE(8626),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8626),
    [sym_list_literal] = STATE(8626),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8626),
    [sym__literal_value] = STATE(8626),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10037),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [anon_sym_RBRACK] = ACTIONS(10039),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10041),
    [sym_date_literal] = ACTIONS(10037),
    [sym_time_literal] = ACTIONS(10037),
    [sym_biginteger_literal] = ACTIONS(10041),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10041),
    [sym_verbatim_string] = ACTIONS(10041),
    [sym_integer] = ACTIONS(10037),
    [sym_continue_as_identifier] = ACTIONS(10041),
  },
  [STATE(4396)] = {
    [sym_identifier] = ACTIONS(10043),
    [anon_sym_DASH] = ACTIONS(10045),
    [aux_sym_boolean_token1] = ACTIONS(10043),
    [aux_sym_boolean_token2] = ACTIONS(10043),
    [sym_decimal] = ACTIONS(10043),
    [anon_sym_LPAREN] = ACTIONS(10045),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10043),
    [anon_sym_LBRACK] = ACTIONS(10045),
    [aux_sym_record_type_token1] = ACTIONS(10043),
    [aux_sym_basic_type_token21] = ACTIONS(10043),
    [aux_sym_basic_type_token22] = ACTIONS(10043),
    [aux_sym_basic_type_token48] = ACTIONS(10043),
    [anon_sym_POUNDif] = ACTIONS(10045),
    [anon_sym_POUNDIF] = ACTIONS(10045),
    [anon_sym_POUNDIf] = ACTIONS(10045),
    [anon_sym_not] = ACTIONS(10043),
    [anon_sym_NOT] = ACTIONS(10043),
    [anon_sym_Not] = ACTIONS(10043),
    [anon_sym_POUNDelif] = ACTIONS(10045),
    [anon_sym_POUNDELIF] = ACTIONS(10045),
    [anon_sym_POUNDElif] = ACTIONS(10045),
    [anon_sym_POUNDelse] = ACTIONS(10045),
    [anon_sym_POUNDELSE] = ACTIONS(10045),
    [anon_sym_POUNDElse] = ACTIONS(10045),
    [anon_sym_POUNDelse2] = ACTIONS(10045),
    [anon_sym_POUNDELSE2] = ACTIONS(10045),
    [anon_sym_POUNDElse2] = ACTIONS(10045),
    [anon_sym_POUNDendif] = ACTIONS(10045),
    [anon_sym_POUNDENDIF] = ACTIONS(10045),
    [anon_sym_POUNDEndif] = ACTIONS(10045),
    [anon_sym_POUNDendif2] = ACTIONS(10045),
    [anon_sym_POUNDENDIF2] = ACTIONS(10045),
    [anon_sym_POUNDEndif2] = ACTIONS(10045),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10043),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10043),
    [anon_sym_PLUS] = ACTIONS(10045),
    [sym_datetime_literal] = ACTIONS(10045),
    [sym_date_literal] = ACTIONS(10043),
    [sym_time_literal] = ACTIONS(10043),
    [sym_biginteger_literal] = ACTIONS(10045),
    [anon_sym_else] = ACTIONS(10043),
    [anon_sym_ELSE] = ACTIONS(10043),
    [anon_sym_Else] = ACTIONS(10043),
    [sym_page_keyword] = ACTIONS(10043),
    [anon_sym_codeunit] = ACTIONS(10043),
    [anon_sym_CODEUNIT] = ACTIONS(10043),
    [anon_sym_Codeunit] = ACTIONS(10043),
    [anon_sym_CodeUnit] = ACTIONS(10043),
    [anon_sym_COdeunit] = ACTIONS(10043),
    [anon_sym_codeUnit] = ACTIONS(10043),
    [sym_report_keyword] = ACTIONS(10043),
    [sym_query_keyword] = ACTIONS(10043),
    [anon_sym_xmlport] = ACTIONS(10043),
    [anon_sym_XMLPORT] = ACTIONS(10043),
    [anon_sym_Xmlport] = ACTIONS(10043),
    [anon_sym_XMLport] = ACTIONS(10043),
    [anon_sym_XMLPort] = ACTIONS(10043),
    [anon_sym_XmlPort] = ACTIONS(10043),
    [anon_sym_enum] = ACTIONS(10043),
    [anon_sym_ENUM] = ACTIONS(10043),
    [anon_sym_Enum] = ACTIONS(10043),
    [anon_sym_eNUM] = ACTIONS(10043),
    [anon_sym_eNum] = ACTIONS(10043),
    [anon_sym_ENum] = ACTIONS(10043),
    [sym_quoted_identifier] = ACTIONS(10045),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10045),
    [sym_verbatim_string] = ACTIONS(10045),
    [sym_integer] = ACTIONS(10043),
    [sym_continue_as_identifier] = ACTIONS(10045),
    [sym_preproc_open] = ACTIONS(10045),
    [sym_preproc_close] = ACTIONS(10045),
  },
  [STATE(4397)] = {
    [sym_boolean] = STATE(8672),
    [sym_assignment_expression] = STATE(8672),
    [sym__expression] = STATE(8672),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8672),
    [sym_multiplicative_expression] = STATE(8672),
    [sym_additive_expression] = STATE(8672),
    [sym_comparison_expression] = STATE(8672),
    [sym_logical_expression] = STATE(8672),
    [sym_ternary_expression] = STATE(8672),
    [sym_unary_expression] = STATE(8672),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8672),
    [sym_list_literal] = STATE(8672),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8672),
    [sym__literal_value] = STATE(8672),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10047),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10049),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10051),
    [sym_date_literal] = ACTIONS(10047),
    [sym_time_literal] = ACTIONS(10047),
    [sym_biginteger_literal] = ACTIONS(10051),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10051),
    [sym_verbatim_string] = ACTIONS(10051),
    [sym_integer] = ACTIONS(10047),
    [sym_continue_as_identifier] = ACTIONS(10051),
  },
  [STATE(4398)] = {
    [sym_boolean] = STATE(8677),
    [sym_assignment_expression] = STATE(8677),
    [sym__expression] = STATE(8677),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8677),
    [sym_multiplicative_expression] = STATE(8677),
    [sym_additive_expression] = STATE(8677),
    [sym_comparison_expression] = STATE(8677),
    [sym_logical_expression] = STATE(8677),
    [sym_ternary_expression] = STATE(8677),
    [sym_unary_expression] = STATE(8677),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8677),
    [sym_list_literal] = STATE(8677),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8677),
    [sym__literal_value] = STATE(8677),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8373),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(8375),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(8377),
    [sym_date_literal] = ACTIONS(8373),
    [sym_time_literal] = ACTIONS(8373),
    [sym_biginteger_literal] = ACTIONS(8377),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8377),
    [sym_verbatim_string] = ACTIONS(8377),
    [sym_integer] = ACTIONS(8373),
    [sym_continue_as_identifier] = ACTIONS(8377),
  },
  [STATE(4399)] = {
    [sym_boolean] = STATE(8851),
    [sym__attribute_argument] = STATE(16578),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8661),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8661),
    [sym_database_reference] = STATE(8839),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9498),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(9502),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9504),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(9506),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4400)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(18273),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4401)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(14228),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4402)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(14229),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4403)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(14247),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4404)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(14248),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4405)] = {
    [sym_boolean] = STATE(9102),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8702),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8702),
    [sym_database_reference] = STATE(8873),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(10053),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10055),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10057),
    [sym_date_literal] = ACTIONS(10059),
    [sym_time_literal] = ACTIONS(10059),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(10061),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10057),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(10059),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4406)] = {
    [sym_identifier] = ACTIONS(10063),
    [anon_sym_DASH] = ACTIONS(10065),
    [aux_sym_boolean_token1] = ACTIONS(10063),
    [aux_sym_boolean_token2] = ACTIONS(10063),
    [sym_decimal] = ACTIONS(10063),
    [anon_sym_LPAREN] = ACTIONS(10065),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10063),
    [anon_sym_LBRACK] = ACTIONS(10065),
    [aux_sym_record_type_token1] = ACTIONS(10063),
    [aux_sym_basic_type_token21] = ACTIONS(10063),
    [aux_sym_basic_type_token22] = ACTIONS(10063),
    [aux_sym_basic_type_token48] = ACTIONS(10063),
    [anon_sym_POUNDif] = ACTIONS(10065),
    [anon_sym_POUNDIF] = ACTIONS(10065),
    [anon_sym_POUNDIf] = ACTIONS(10065),
    [anon_sym_not] = ACTIONS(10063),
    [anon_sym_NOT] = ACTIONS(10063),
    [anon_sym_Not] = ACTIONS(10063),
    [anon_sym_POUNDelif] = ACTIONS(10065),
    [anon_sym_POUNDELIF] = ACTIONS(10065),
    [anon_sym_POUNDElif] = ACTIONS(10065),
    [anon_sym_POUNDelse] = ACTIONS(10065),
    [anon_sym_POUNDELSE] = ACTIONS(10065),
    [anon_sym_POUNDElse] = ACTIONS(10065),
    [anon_sym_POUNDelse2] = ACTIONS(10065),
    [anon_sym_POUNDELSE2] = ACTIONS(10065),
    [anon_sym_POUNDElse2] = ACTIONS(10065),
    [anon_sym_POUNDendif] = ACTIONS(10065),
    [anon_sym_POUNDENDIF] = ACTIONS(10065),
    [anon_sym_POUNDEndif] = ACTIONS(10065),
    [anon_sym_POUNDendif2] = ACTIONS(10065),
    [anon_sym_POUNDENDIF2] = ACTIONS(10065),
    [anon_sym_POUNDEndif2] = ACTIONS(10065),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10063),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10063),
    [anon_sym_PLUS] = ACTIONS(10065),
    [sym_datetime_literal] = ACTIONS(10065),
    [sym_date_literal] = ACTIONS(10063),
    [sym_time_literal] = ACTIONS(10063),
    [sym_biginteger_literal] = ACTIONS(10065),
    [anon_sym_else] = ACTIONS(10063),
    [anon_sym_ELSE] = ACTIONS(10063),
    [anon_sym_Else] = ACTIONS(10063),
    [sym_page_keyword] = ACTIONS(10063),
    [anon_sym_codeunit] = ACTIONS(10063),
    [anon_sym_CODEUNIT] = ACTIONS(10063),
    [anon_sym_Codeunit] = ACTIONS(10063),
    [anon_sym_CodeUnit] = ACTIONS(10063),
    [anon_sym_COdeunit] = ACTIONS(10063),
    [anon_sym_codeUnit] = ACTIONS(10063),
    [sym_report_keyword] = ACTIONS(10063),
    [sym_query_keyword] = ACTIONS(10063),
    [anon_sym_xmlport] = ACTIONS(10063),
    [anon_sym_XMLPORT] = ACTIONS(10063),
    [anon_sym_Xmlport] = ACTIONS(10063),
    [anon_sym_XMLport] = ACTIONS(10063),
    [anon_sym_XMLPort] = ACTIONS(10063),
    [anon_sym_XmlPort] = ACTIONS(10063),
    [anon_sym_enum] = ACTIONS(10063),
    [anon_sym_ENUM] = ACTIONS(10063),
    [anon_sym_Enum] = ACTIONS(10063),
    [anon_sym_eNUM] = ACTIONS(10063),
    [anon_sym_eNum] = ACTIONS(10063),
    [anon_sym_ENum] = ACTIONS(10063),
    [sym_quoted_identifier] = ACTIONS(10065),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10065),
    [sym_verbatim_string] = ACTIONS(10065),
    [sym_integer] = ACTIONS(10063),
    [sym_continue_as_identifier] = ACTIONS(10065),
    [sym_preproc_open] = ACTIONS(10065),
    [sym_preproc_close] = ACTIONS(10065),
  },
  [STATE(4407)] = {
    [sym_identifier] = ACTIONS(10067),
    [anon_sym_DASH] = ACTIONS(10069),
    [aux_sym_boolean_token1] = ACTIONS(10067),
    [aux_sym_boolean_token2] = ACTIONS(10067),
    [sym_decimal] = ACTIONS(10067),
    [anon_sym_LPAREN] = ACTIONS(10069),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10067),
    [anon_sym_LBRACK] = ACTIONS(10069),
    [aux_sym_record_type_token1] = ACTIONS(10067),
    [aux_sym_basic_type_token21] = ACTIONS(10067),
    [aux_sym_basic_type_token22] = ACTIONS(10067),
    [aux_sym_basic_type_token48] = ACTIONS(10067),
    [anon_sym_POUNDif] = ACTIONS(10069),
    [anon_sym_POUNDIF] = ACTIONS(10069),
    [anon_sym_POUNDIf] = ACTIONS(10069),
    [anon_sym_not] = ACTIONS(10067),
    [anon_sym_NOT] = ACTIONS(10067),
    [anon_sym_Not] = ACTIONS(10067),
    [anon_sym_POUNDelif] = ACTIONS(10069),
    [anon_sym_POUNDELIF] = ACTIONS(10069),
    [anon_sym_POUNDElif] = ACTIONS(10069),
    [anon_sym_POUNDelse] = ACTIONS(10069),
    [anon_sym_POUNDELSE] = ACTIONS(10069),
    [anon_sym_POUNDElse] = ACTIONS(10069),
    [anon_sym_POUNDelse2] = ACTIONS(10069),
    [anon_sym_POUNDELSE2] = ACTIONS(10069),
    [anon_sym_POUNDElse2] = ACTIONS(10069),
    [anon_sym_POUNDendif] = ACTIONS(10069),
    [anon_sym_POUNDENDIF] = ACTIONS(10069),
    [anon_sym_POUNDEndif] = ACTIONS(10069),
    [anon_sym_POUNDendif2] = ACTIONS(10069),
    [anon_sym_POUNDENDIF2] = ACTIONS(10069),
    [anon_sym_POUNDEndif2] = ACTIONS(10069),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10067),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10067),
    [anon_sym_PLUS] = ACTIONS(10069),
    [sym_datetime_literal] = ACTIONS(10069),
    [sym_date_literal] = ACTIONS(10067),
    [sym_time_literal] = ACTIONS(10067),
    [sym_biginteger_literal] = ACTIONS(10069),
    [anon_sym_else] = ACTIONS(10067),
    [anon_sym_ELSE] = ACTIONS(10067),
    [anon_sym_Else] = ACTIONS(10067),
    [sym_page_keyword] = ACTIONS(10067),
    [anon_sym_codeunit] = ACTIONS(10067),
    [anon_sym_CODEUNIT] = ACTIONS(10067),
    [anon_sym_Codeunit] = ACTIONS(10067),
    [anon_sym_CodeUnit] = ACTIONS(10067),
    [anon_sym_COdeunit] = ACTIONS(10067),
    [anon_sym_codeUnit] = ACTIONS(10067),
    [sym_report_keyword] = ACTIONS(10067),
    [sym_query_keyword] = ACTIONS(10067),
    [anon_sym_xmlport] = ACTIONS(10067),
    [anon_sym_XMLPORT] = ACTIONS(10067),
    [anon_sym_Xmlport] = ACTIONS(10067),
    [anon_sym_XMLport] = ACTIONS(10067),
    [anon_sym_XMLPort] = ACTIONS(10067),
    [anon_sym_XmlPort] = ACTIONS(10067),
    [anon_sym_enum] = ACTIONS(10067),
    [anon_sym_ENUM] = ACTIONS(10067),
    [anon_sym_Enum] = ACTIONS(10067),
    [anon_sym_eNUM] = ACTIONS(10067),
    [anon_sym_eNum] = ACTIONS(10067),
    [anon_sym_ENum] = ACTIONS(10067),
    [sym_quoted_identifier] = ACTIONS(10069),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10069),
    [sym_verbatim_string] = ACTIONS(10069),
    [sym_integer] = ACTIONS(10067),
    [sym_continue_as_identifier] = ACTIONS(10069),
    [sym_preproc_open] = ACTIONS(10069),
    [sym_preproc_close] = ACTIONS(10069),
  },
  [STATE(4408)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17741),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4409)] = {
    [sym_boolean] = STATE(8630),
    [sym_assignment_expression] = STATE(8630),
    [sym__expression] = STATE(8630),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8630),
    [sym_multiplicative_expression] = STATE(8630),
    [sym_additive_expression] = STATE(8630),
    [sym_comparison_expression] = STATE(8630),
    [sym_logical_expression] = STATE(8630),
    [sym_ternary_expression] = STATE(8630),
    [sym_unary_expression] = STATE(8630),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8630),
    [sym_list_literal] = STATE(8630),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8630),
    [sym__literal_value] = STATE(8630),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10071),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10073),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10075),
    [sym_date_literal] = ACTIONS(10071),
    [sym_time_literal] = ACTIONS(10071),
    [sym_biginteger_literal] = ACTIONS(10075),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10075),
    [sym_verbatim_string] = ACTIONS(10075),
    [sym_integer] = ACTIONS(10071),
    [sym_continue_as_identifier] = ACTIONS(10075),
  },
  [STATE(4410)] = {
    [sym_boolean] = STATE(8682),
    [sym_assignment_expression] = STATE(8682),
    [sym__expression] = STATE(8682),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8682),
    [sym_multiplicative_expression] = STATE(8682),
    [sym_additive_expression] = STATE(8682),
    [sym_comparison_expression] = STATE(8682),
    [sym_logical_expression] = STATE(8682),
    [sym_ternary_expression] = STATE(8682),
    [sym_unary_expression] = STATE(8682),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8682),
    [sym_list_literal] = STATE(8682),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8682),
    [sym__literal_value] = STATE(8682),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10077),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [anon_sym_RBRACK] = ACTIONS(10079),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10081),
    [sym_date_literal] = ACTIONS(10077),
    [sym_time_literal] = ACTIONS(10077),
    [sym_biginteger_literal] = ACTIONS(10081),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10081),
    [sym_verbatim_string] = ACTIONS(10081),
    [sym_integer] = ACTIONS(10077),
    [sym_continue_as_identifier] = ACTIONS(10081),
  },
  [STATE(4411)] = {
    [sym_identifier] = ACTIONS(10083),
    [anon_sym_DASH] = ACTIONS(10085),
    [aux_sym_boolean_token1] = ACTIONS(10083),
    [aux_sym_boolean_token2] = ACTIONS(10083),
    [sym_decimal] = ACTIONS(10083),
    [anon_sym_LPAREN] = ACTIONS(10085),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10083),
    [anon_sym_LBRACK] = ACTIONS(10085),
    [aux_sym_record_type_token1] = ACTIONS(10083),
    [aux_sym_basic_type_token21] = ACTIONS(10083),
    [aux_sym_basic_type_token22] = ACTIONS(10083),
    [aux_sym_basic_type_token48] = ACTIONS(10083),
    [anon_sym_POUNDif] = ACTIONS(10085),
    [anon_sym_POUNDIF] = ACTIONS(10085),
    [anon_sym_POUNDIf] = ACTIONS(10085),
    [anon_sym_not] = ACTIONS(10083),
    [anon_sym_NOT] = ACTIONS(10083),
    [anon_sym_Not] = ACTIONS(10083),
    [anon_sym_POUNDelif] = ACTIONS(10085),
    [anon_sym_POUNDELIF] = ACTIONS(10085),
    [anon_sym_POUNDElif] = ACTIONS(10085),
    [anon_sym_POUNDelse] = ACTIONS(10085),
    [anon_sym_POUNDELSE] = ACTIONS(10085),
    [anon_sym_POUNDElse] = ACTIONS(10085),
    [anon_sym_POUNDelse2] = ACTIONS(10085),
    [anon_sym_POUNDELSE2] = ACTIONS(10085),
    [anon_sym_POUNDElse2] = ACTIONS(10085),
    [anon_sym_POUNDendif] = ACTIONS(10085),
    [anon_sym_POUNDENDIF] = ACTIONS(10085),
    [anon_sym_POUNDEndif] = ACTIONS(10085),
    [anon_sym_POUNDendif2] = ACTIONS(10085),
    [anon_sym_POUNDENDIF2] = ACTIONS(10085),
    [anon_sym_POUNDEndif2] = ACTIONS(10085),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10083),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10083),
    [anon_sym_PLUS] = ACTIONS(10085),
    [sym_datetime_literal] = ACTIONS(10085),
    [sym_date_literal] = ACTIONS(10083),
    [sym_time_literal] = ACTIONS(10083),
    [sym_biginteger_literal] = ACTIONS(10085),
    [anon_sym_else] = ACTIONS(10083),
    [anon_sym_ELSE] = ACTIONS(10083),
    [anon_sym_Else] = ACTIONS(10083),
    [sym_page_keyword] = ACTIONS(10083),
    [anon_sym_codeunit] = ACTIONS(10083),
    [anon_sym_CODEUNIT] = ACTIONS(10083),
    [anon_sym_Codeunit] = ACTIONS(10083),
    [anon_sym_CodeUnit] = ACTIONS(10083),
    [anon_sym_COdeunit] = ACTIONS(10083),
    [anon_sym_codeUnit] = ACTIONS(10083),
    [sym_report_keyword] = ACTIONS(10083),
    [sym_query_keyword] = ACTIONS(10083),
    [anon_sym_xmlport] = ACTIONS(10083),
    [anon_sym_XMLPORT] = ACTIONS(10083),
    [anon_sym_Xmlport] = ACTIONS(10083),
    [anon_sym_XMLport] = ACTIONS(10083),
    [anon_sym_XMLPort] = ACTIONS(10083),
    [anon_sym_XmlPort] = ACTIONS(10083),
    [anon_sym_enum] = ACTIONS(10083),
    [anon_sym_ENUM] = ACTIONS(10083),
    [anon_sym_Enum] = ACTIONS(10083),
    [anon_sym_eNUM] = ACTIONS(10083),
    [anon_sym_eNum] = ACTIONS(10083),
    [anon_sym_ENum] = ACTIONS(10083),
    [sym_quoted_identifier] = ACTIONS(10085),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10085),
    [sym_verbatim_string] = ACTIONS(10085),
    [sym_integer] = ACTIONS(10083),
    [sym_continue_as_identifier] = ACTIONS(10085),
    [sym_preproc_open] = ACTIONS(10085),
    [sym_preproc_close] = ACTIONS(10085),
  },
  [STATE(4412)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17242),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4413)] = {
    [sym_boolean] = STATE(8683),
    [sym_assignment_expression] = STATE(8683),
    [sym__expression] = STATE(8683),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8683),
    [sym_multiplicative_expression] = STATE(8683),
    [sym_additive_expression] = STATE(8683),
    [sym_comparison_expression] = STATE(8683),
    [sym_logical_expression] = STATE(8683),
    [sym_ternary_expression] = STATE(8683),
    [sym_unary_expression] = STATE(8683),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8683),
    [sym_list_literal] = STATE(8683),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8683),
    [sym__literal_value] = STATE(8683),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10087),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10089),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10091),
    [sym_date_literal] = ACTIONS(10087),
    [sym_time_literal] = ACTIONS(10087),
    [sym_biginteger_literal] = ACTIONS(10091),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10091),
    [sym_verbatim_string] = ACTIONS(10091),
    [sym_integer] = ACTIONS(10087),
    [sym_continue_as_identifier] = ACTIONS(10091),
  },
  [STATE(4414)] = {
    [sym_boolean] = STATE(8651),
    [sym_assignment_expression] = STATE(8651),
    [sym__expression] = STATE(8651),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8651),
    [sym_multiplicative_expression] = STATE(8651),
    [sym_additive_expression] = STATE(8651),
    [sym_comparison_expression] = STATE(8651),
    [sym_logical_expression] = STATE(8651),
    [sym_ternary_expression] = STATE(8651),
    [sym_unary_expression] = STATE(8651),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8651),
    [sym_list_literal] = STATE(8651),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8651),
    [sym__literal_value] = STATE(8651),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10093),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10095),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10097),
    [sym_date_literal] = ACTIONS(10093),
    [sym_time_literal] = ACTIONS(10093),
    [sym_biginteger_literal] = ACTIONS(10097),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10097),
    [sym_verbatim_string] = ACTIONS(10097),
    [sym_integer] = ACTIONS(10093),
    [sym_continue_as_identifier] = ACTIONS(10097),
  },
  [STATE(4415)] = {
    [sym_boolean] = STATE(8653),
    [sym_assignment_expression] = STATE(8653),
    [sym__expression] = STATE(8653),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8653),
    [sym_multiplicative_expression] = STATE(8653),
    [sym_additive_expression] = STATE(8653),
    [sym_comparison_expression] = STATE(8653),
    [sym_logical_expression] = STATE(8653),
    [sym_ternary_expression] = STATE(8653),
    [sym_unary_expression] = STATE(8653),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8653),
    [sym_list_literal] = STATE(8653),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8653),
    [sym__literal_value] = STATE(8653),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10099),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10101),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10103),
    [sym_date_literal] = ACTIONS(10099),
    [sym_time_literal] = ACTIONS(10099),
    [sym_biginteger_literal] = ACTIONS(10103),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10103),
    [sym_verbatim_string] = ACTIONS(10103),
    [sym_integer] = ACTIONS(10099),
    [sym_continue_as_identifier] = ACTIONS(10103),
  },
  [STATE(4416)] = {
    [sym_identifier] = ACTIONS(10105),
    [anon_sym_DASH] = ACTIONS(10107),
    [aux_sym_boolean_token1] = ACTIONS(10105),
    [aux_sym_boolean_token2] = ACTIONS(10105),
    [sym_decimal] = ACTIONS(10105),
    [anon_sym_LPAREN] = ACTIONS(10107),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10105),
    [anon_sym_LBRACK] = ACTIONS(10107),
    [aux_sym_record_type_token1] = ACTIONS(10105),
    [aux_sym_basic_type_token21] = ACTIONS(10105),
    [aux_sym_basic_type_token22] = ACTIONS(10105),
    [aux_sym_basic_type_token48] = ACTIONS(10105),
    [anon_sym_POUNDif] = ACTIONS(10107),
    [anon_sym_POUNDIF] = ACTIONS(10107),
    [anon_sym_POUNDIf] = ACTIONS(10107),
    [anon_sym_not] = ACTIONS(10105),
    [anon_sym_NOT] = ACTIONS(10105),
    [anon_sym_Not] = ACTIONS(10105),
    [anon_sym_POUNDelif] = ACTIONS(10107),
    [anon_sym_POUNDELIF] = ACTIONS(10107),
    [anon_sym_POUNDElif] = ACTIONS(10107),
    [anon_sym_POUNDelse] = ACTIONS(10107),
    [anon_sym_POUNDELSE] = ACTIONS(10107),
    [anon_sym_POUNDElse] = ACTIONS(10107),
    [anon_sym_POUNDelse2] = ACTIONS(10107),
    [anon_sym_POUNDELSE2] = ACTIONS(10107),
    [anon_sym_POUNDElse2] = ACTIONS(10107),
    [anon_sym_POUNDendif] = ACTIONS(10107),
    [anon_sym_POUNDENDIF] = ACTIONS(10107),
    [anon_sym_POUNDEndif] = ACTIONS(10107),
    [anon_sym_POUNDendif2] = ACTIONS(10107),
    [anon_sym_POUNDENDIF2] = ACTIONS(10107),
    [anon_sym_POUNDEndif2] = ACTIONS(10107),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10105),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10105),
    [anon_sym_PLUS] = ACTIONS(10107),
    [sym_datetime_literal] = ACTIONS(10107),
    [sym_date_literal] = ACTIONS(10105),
    [sym_time_literal] = ACTIONS(10105),
    [sym_biginteger_literal] = ACTIONS(10107),
    [anon_sym_else] = ACTIONS(10105),
    [anon_sym_ELSE] = ACTIONS(10105),
    [anon_sym_Else] = ACTIONS(10105),
    [sym_page_keyword] = ACTIONS(10105),
    [anon_sym_codeunit] = ACTIONS(10105),
    [anon_sym_CODEUNIT] = ACTIONS(10105),
    [anon_sym_Codeunit] = ACTIONS(10105),
    [anon_sym_CodeUnit] = ACTIONS(10105),
    [anon_sym_COdeunit] = ACTIONS(10105),
    [anon_sym_codeUnit] = ACTIONS(10105),
    [sym_report_keyword] = ACTIONS(10105),
    [sym_query_keyword] = ACTIONS(10105),
    [anon_sym_xmlport] = ACTIONS(10105),
    [anon_sym_XMLPORT] = ACTIONS(10105),
    [anon_sym_Xmlport] = ACTIONS(10105),
    [anon_sym_XMLport] = ACTIONS(10105),
    [anon_sym_XMLPort] = ACTIONS(10105),
    [anon_sym_XmlPort] = ACTIONS(10105),
    [anon_sym_enum] = ACTIONS(10105),
    [anon_sym_ENUM] = ACTIONS(10105),
    [anon_sym_Enum] = ACTIONS(10105),
    [anon_sym_eNUM] = ACTIONS(10105),
    [anon_sym_eNum] = ACTIONS(10105),
    [anon_sym_ENum] = ACTIONS(10105),
    [sym_quoted_identifier] = ACTIONS(10107),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10107),
    [sym_verbatim_string] = ACTIONS(10107),
    [sym_integer] = ACTIONS(10105),
    [sym_continue_as_identifier] = ACTIONS(10107),
    [sym_preproc_open] = ACTIONS(10107),
    [sym_preproc_close] = ACTIONS(10107),
  },
  [STATE(4417)] = {
    [sym_boolean] = STATE(8667),
    [sym_assignment_expression] = STATE(8667),
    [sym__expression] = STATE(8667),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8667),
    [sym_multiplicative_expression] = STATE(8667),
    [sym_additive_expression] = STATE(8667),
    [sym_comparison_expression] = STATE(8667),
    [sym_logical_expression] = STATE(8667),
    [sym_ternary_expression] = STATE(8667),
    [sym_unary_expression] = STATE(8667),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8667),
    [sym_list_literal] = STATE(8667),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8667),
    [sym__literal_value] = STATE(8667),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10109),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10111),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10113),
    [sym_date_literal] = ACTIONS(10109),
    [sym_time_literal] = ACTIONS(10109),
    [sym_biginteger_literal] = ACTIONS(10113),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10113),
    [sym_verbatim_string] = ACTIONS(10113),
    [sym_integer] = ACTIONS(10109),
    [sym_continue_as_identifier] = ACTIONS(10113),
  },
  [STATE(4418)] = {
    [sym_identifier] = ACTIONS(9830),
    [anon_sym_DASH] = ACTIONS(9832),
    [aux_sym_boolean_token1] = ACTIONS(9830),
    [aux_sym_boolean_token2] = ACTIONS(9830),
    [sym_decimal] = ACTIONS(9830),
    [anon_sym_LPAREN] = ACTIONS(9832),
    [aux_sym_tabledata_permission_token2] = ACTIONS(9830),
    [anon_sym_LBRACK] = ACTIONS(9832),
    [aux_sym_record_type_token1] = ACTIONS(9830),
    [aux_sym_basic_type_token21] = ACTIONS(9830),
    [aux_sym_basic_type_token22] = ACTIONS(9830),
    [aux_sym_basic_type_token48] = ACTIONS(9830),
    [anon_sym_POUNDif] = ACTIONS(9832),
    [anon_sym_POUNDIF] = ACTIONS(9832),
    [anon_sym_POUNDIf] = ACTIONS(9832),
    [anon_sym_not] = ACTIONS(9830),
    [anon_sym_NOT] = ACTIONS(9830),
    [anon_sym_Not] = ACTIONS(9830),
    [anon_sym_POUNDelif] = ACTIONS(9832),
    [anon_sym_POUNDELIF] = ACTIONS(9832),
    [anon_sym_POUNDElif] = ACTIONS(9832),
    [anon_sym_POUNDelse] = ACTIONS(9832),
    [anon_sym_POUNDELSE] = ACTIONS(9832),
    [anon_sym_POUNDElse] = ACTIONS(9832),
    [anon_sym_POUNDelse2] = ACTIONS(9832),
    [anon_sym_POUNDELSE2] = ACTIONS(9832),
    [anon_sym_POUNDElse2] = ACTIONS(9832),
    [anon_sym_POUNDendif] = ACTIONS(9832),
    [anon_sym_POUNDENDIF] = ACTIONS(9832),
    [anon_sym_POUNDEndif] = ACTIONS(9832),
    [anon_sym_POUNDendif2] = ACTIONS(9832),
    [anon_sym_POUNDENDIF2] = ACTIONS(9832),
    [anon_sym_POUNDEndif2] = ACTIONS(9832),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(9830),
    [aux_sym_keyword_identifier_token2] = ACTIONS(9830),
    [anon_sym_PLUS] = ACTIONS(9832),
    [sym_datetime_literal] = ACTIONS(9832),
    [sym_date_literal] = ACTIONS(9830),
    [sym_time_literal] = ACTIONS(9830),
    [sym_biginteger_literal] = ACTIONS(9832),
    [anon_sym_else] = ACTIONS(9830),
    [anon_sym_ELSE] = ACTIONS(9830),
    [anon_sym_Else] = ACTIONS(9830),
    [sym_page_keyword] = ACTIONS(9830),
    [anon_sym_codeunit] = ACTIONS(9830),
    [anon_sym_CODEUNIT] = ACTIONS(9830),
    [anon_sym_Codeunit] = ACTIONS(9830),
    [anon_sym_CodeUnit] = ACTIONS(9830),
    [anon_sym_COdeunit] = ACTIONS(9830),
    [anon_sym_codeUnit] = ACTIONS(9830),
    [sym_report_keyword] = ACTIONS(9830),
    [sym_query_keyword] = ACTIONS(9830),
    [anon_sym_xmlport] = ACTIONS(9830),
    [anon_sym_XMLPORT] = ACTIONS(9830),
    [anon_sym_Xmlport] = ACTIONS(9830),
    [anon_sym_XMLport] = ACTIONS(9830),
    [anon_sym_XMLPort] = ACTIONS(9830),
    [anon_sym_XmlPort] = ACTIONS(9830),
    [anon_sym_enum] = ACTIONS(9830),
    [anon_sym_ENUM] = ACTIONS(9830),
    [anon_sym_Enum] = ACTIONS(9830),
    [anon_sym_eNUM] = ACTIONS(9830),
    [anon_sym_eNum] = ACTIONS(9830),
    [anon_sym_ENum] = ACTIONS(9830),
    [sym_quoted_identifier] = ACTIONS(9832),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9832),
    [sym_verbatim_string] = ACTIONS(9832),
    [sym_integer] = ACTIONS(9830),
    [sym_continue_as_identifier] = ACTIONS(9832),
    [sym_preproc_open] = ACTIONS(9832),
    [sym_preproc_close] = ACTIONS(9832),
  },
  [STATE(4419)] = {
    [sym__layout_element] = STATE(4566),
    [sym_area_section] = STATE(4566),
    [sym_group_section] = STATE(4566),
    [sym_repeater_section] = STATE(4566),
    [sym_cuegroup_section] = STATE(4566),
    [sym_fixed_section] = STATE(4566),
    [sym_grid_section] = STATE(4566),
    [sym_page_field] = STATE(4566),
    [sym_part_section] = STATE(4566),
    [sym_systempart_section] = STATE(4566),
    [sym_usercontrol_section] = STATE(4566),
    [sym_preproc_split_field] = STATE(4566),
    [sym__field_header] = STATE(10667),
    [sym_label_section] = STATE(4566),
    [sym_addfirst_modification] = STATE(4566),
    [sym_addlast_modification] = STATE(4566),
    [sym_addafter_modification] = STATE(4566),
    [sym_addbefore_modification] = STATE(4566),
    [sym_modify_modification] = STATE(4566),
    [sym_movefirst_modification] = STATE(4566),
    [sym_movelast_modification] = STATE(4566),
    [sym_moveafter_modification] = STATE(4566),
    [sym_movebefore_modification] = STATE(4566),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6512),
    [sym_preproc_endif] = STATE(10155),
    [sym_preproc_conditional_layout] = STATE(4566),
    [aux_sym_layout_section_repeat1] = STATE(4566),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10715),
    [anon_sym_RBRACE] = ACTIONS(10115),
    [aux_sym_where_condition_token1] = ACTIONS(9790),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4420)] = {
    [sym_boolean] = STATE(8634),
    [sym_assignment_expression] = STATE(8634),
    [sym__expression] = STATE(8634),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8634),
    [sym_multiplicative_expression] = STATE(8634),
    [sym_additive_expression] = STATE(8634),
    [sym_comparison_expression] = STATE(8634),
    [sym_logical_expression] = STATE(8634),
    [sym_ternary_expression] = STATE(8634),
    [sym_unary_expression] = STATE(8634),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8634),
    [sym_list_literal] = STATE(8634),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8634),
    [sym__literal_value] = STATE(8634),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10117),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(9852),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10119),
    [sym_date_literal] = ACTIONS(10117),
    [sym_time_literal] = ACTIONS(10117),
    [sym_biginteger_literal] = ACTIONS(10119),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10119),
    [sym_verbatim_string] = ACTIONS(10119),
    [sym_integer] = ACTIONS(10117),
    [sym_continue_as_identifier] = ACTIONS(10119),
  },
  [STATE(4421)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17281),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4422)] = {
    [aux_sym_option_member_list_repeat2] = STATE(4422),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(10121),
    [anon_sym_DASH] = ACTIONS(838),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [anon_sym_POUNDif] = ACTIONS(838),
    [anon_sym_POUNDIF] = ACTIONS(838),
    [anon_sym_POUNDIf] = ACTIONS(838),
    [anon_sym_POUNDelif] = ACTIONS(838),
    [anon_sym_POUNDELIF] = ACTIONS(838),
    [anon_sym_POUNDElif] = ACTIONS(838),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [anon_sym_POUNDendif] = ACTIONS(838),
    [anon_sym_POUNDENDIF] = ACTIONS(838),
    [anon_sym_POUNDEndif] = ACTIONS(838),
    [anon_sym_POUNDendif2] = ACTIONS(838),
    [anon_sym_POUNDENDIF2] = ACTIONS(838),
    [anon_sym_POUNDEndif2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_var_keyword] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(838),
    [sym_preproc_open] = ACTIONS(838),
    [sym_preproc_close] = ACTIONS(838),
  },
  [STATE(4423)] = {
    [sym_boolean] = STATE(8650),
    [sym_assignment_expression] = STATE(8650),
    [sym__expression] = STATE(8650),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8650),
    [sym_multiplicative_expression] = STATE(8650),
    [sym_additive_expression] = STATE(8650),
    [sym_comparison_expression] = STATE(8650),
    [sym_logical_expression] = STATE(8650),
    [sym_ternary_expression] = STATE(8650),
    [sym_unary_expression] = STATE(8650),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8650),
    [sym_list_literal] = STATE(8650),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8650),
    [sym__literal_value] = STATE(8650),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10124),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10126),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10128),
    [sym_date_literal] = ACTIONS(10124),
    [sym_time_literal] = ACTIONS(10124),
    [sym_biginteger_literal] = ACTIONS(10128),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10128),
    [sym_verbatim_string] = ACTIONS(10128),
    [sym_integer] = ACTIONS(10124),
    [sym_continue_as_identifier] = ACTIONS(10128),
  },
  [STATE(4424)] = {
    [sym_boolean] = STATE(8836),
    [sym__preproc_call_prefix] = STATE(11508),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8752),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8752),
    [sym_subscript_expression] = STATE(8752),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8752),
    [sym_database_reference] = STATE(8836),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(9946),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(7531),
    [sym_date_literal] = ACTIONS(7529),
    [sym_time_literal] = ACTIONS(7529),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7531),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(7529),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4425)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17347),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4426)] = {
    [sym_identifier] = ACTIONS(10130),
    [anon_sym_DASH] = ACTIONS(10132),
    [aux_sym_boolean_token1] = ACTIONS(10130),
    [aux_sym_boolean_token2] = ACTIONS(10130),
    [sym_decimal] = ACTIONS(10130),
    [anon_sym_LPAREN] = ACTIONS(10132),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10130),
    [anon_sym_LBRACK] = ACTIONS(10132),
    [aux_sym_record_type_token1] = ACTIONS(10130),
    [aux_sym_basic_type_token21] = ACTIONS(10130),
    [aux_sym_basic_type_token22] = ACTIONS(10130),
    [aux_sym_basic_type_token48] = ACTIONS(10130),
    [anon_sym_POUNDif] = ACTIONS(10132),
    [anon_sym_POUNDIF] = ACTIONS(10132),
    [anon_sym_POUNDIf] = ACTIONS(10132),
    [anon_sym_not] = ACTIONS(10130),
    [anon_sym_NOT] = ACTIONS(10130),
    [anon_sym_Not] = ACTIONS(10130),
    [anon_sym_POUNDelif] = ACTIONS(10132),
    [anon_sym_POUNDELIF] = ACTIONS(10132),
    [anon_sym_POUNDElif] = ACTIONS(10132),
    [anon_sym_POUNDelse] = ACTIONS(10132),
    [anon_sym_POUNDELSE] = ACTIONS(10132),
    [anon_sym_POUNDElse] = ACTIONS(10132),
    [anon_sym_POUNDelse2] = ACTIONS(10132),
    [anon_sym_POUNDELSE2] = ACTIONS(10132),
    [anon_sym_POUNDElse2] = ACTIONS(10132),
    [anon_sym_POUNDendif] = ACTIONS(10132),
    [anon_sym_POUNDENDIF] = ACTIONS(10132),
    [anon_sym_POUNDEndif] = ACTIONS(10132),
    [anon_sym_POUNDendif2] = ACTIONS(10132),
    [anon_sym_POUNDENDIF2] = ACTIONS(10132),
    [anon_sym_POUNDEndif2] = ACTIONS(10132),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10130),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10130),
    [anon_sym_PLUS] = ACTIONS(10132),
    [sym_datetime_literal] = ACTIONS(10132),
    [sym_date_literal] = ACTIONS(10130),
    [sym_time_literal] = ACTIONS(10130),
    [sym_biginteger_literal] = ACTIONS(10132),
    [anon_sym_else] = ACTIONS(10130),
    [anon_sym_ELSE] = ACTIONS(10130),
    [anon_sym_Else] = ACTIONS(10130),
    [sym_page_keyword] = ACTIONS(10130),
    [anon_sym_codeunit] = ACTIONS(10130),
    [anon_sym_CODEUNIT] = ACTIONS(10130),
    [anon_sym_Codeunit] = ACTIONS(10130),
    [anon_sym_CodeUnit] = ACTIONS(10130),
    [anon_sym_COdeunit] = ACTIONS(10130),
    [anon_sym_codeUnit] = ACTIONS(10130),
    [sym_report_keyword] = ACTIONS(10130),
    [sym_query_keyword] = ACTIONS(10130),
    [anon_sym_xmlport] = ACTIONS(10130),
    [anon_sym_XMLPORT] = ACTIONS(10130),
    [anon_sym_Xmlport] = ACTIONS(10130),
    [anon_sym_XMLport] = ACTIONS(10130),
    [anon_sym_XMLPort] = ACTIONS(10130),
    [anon_sym_XmlPort] = ACTIONS(10130),
    [anon_sym_enum] = ACTIONS(10130),
    [anon_sym_ENUM] = ACTIONS(10130),
    [anon_sym_Enum] = ACTIONS(10130),
    [anon_sym_eNUM] = ACTIONS(10130),
    [anon_sym_eNum] = ACTIONS(10130),
    [anon_sym_ENum] = ACTIONS(10130),
    [sym_quoted_identifier] = ACTIONS(10132),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10132),
    [sym_verbatim_string] = ACTIONS(10132),
    [sym_integer] = ACTIONS(10130),
    [sym_continue_as_identifier] = ACTIONS(10132),
    [sym_preproc_open] = ACTIONS(10132),
    [sym_preproc_close] = ACTIONS(10132),
  },
  [STATE(4427)] = {
    [sym_boolean] = STATE(8664),
    [sym_assignment_expression] = STATE(8664),
    [sym__expression] = STATE(8664),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8664),
    [sym_multiplicative_expression] = STATE(8664),
    [sym_additive_expression] = STATE(8664),
    [sym_comparison_expression] = STATE(8664),
    [sym_logical_expression] = STATE(8664),
    [sym_ternary_expression] = STATE(8664),
    [sym_unary_expression] = STATE(8664),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8664),
    [sym_list_literal] = STATE(8664),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8664),
    [sym__literal_value] = STATE(8664),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10134),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [anon_sym_RBRACK] = ACTIONS(10136),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10138),
    [sym_date_literal] = ACTIONS(10134),
    [sym_time_literal] = ACTIONS(10134),
    [sym_biginteger_literal] = ACTIONS(10138),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10138),
    [sym_verbatim_string] = ACTIONS(10138),
    [sym_integer] = ACTIONS(10134),
    [sym_continue_as_identifier] = ACTIONS(10138),
  },
  [STATE(4428)] = {
    [sym_identifier] = ACTIONS(10140),
    [anon_sym_DASH] = ACTIONS(10142),
    [aux_sym_boolean_token1] = ACTIONS(10140),
    [aux_sym_boolean_token2] = ACTIONS(10140),
    [sym_decimal] = ACTIONS(10140),
    [anon_sym_LPAREN] = ACTIONS(10142),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10140),
    [anon_sym_LBRACK] = ACTIONS(10142),
    [aux_sym_record_type_token1] = ACTIONS(10140),
    [aux_sym_basic_type_token21] = ACTIONS(10140),
    [aux_sym_basic_type_token22] = ACTIONS(10140),
    [aux_sym_basic_type_token48] = ACTIONS(10140),
    [anon_sym_POUNDif] = ACTIONS(10142),
    [anon_sym_POUNDIF] = ACTIONS(10142),
    [anon_sym_POUNDIf] = ACTIONS(10142),
    [anon_sym_not] = ACTIONS(10140),
    [anon_sym_NOT] = ACTIONS(10140),
    [anon_sym_Not] = ACTIONS(10140),
    [anon_sym_POUNDelif] = ACTIONS(10142),
    [anon_sym_POUNDELIF] = ACTIONS(10142),
    [anon_sym_POUNDElif] = ACTIONS(10142),
    [anon_sym_POUNDelse] = ACTIONS(10142),
    [anon_sym_POUNDELSE] = ACTIONS(10142),
    [anon_sym_POUNDElse] = ACTIONS(10142),
    [anon_sym_POUNDelse2] = ACTIONS(10142),
    [anon_sym_POUNDELSE2] = ACTIONS(10142),
    [anon_sym_POUNDElse2] = ACTIONS(10142),
    [anon_sym_POUNDendif] = ACTIONS(10142),
    [anon_sym_POUNDENDIF] = ACTIONS(10142),
    [anon_sym_POUNDEndif] = ACTIONS(10142),
    [anon_sym_POUNDendif2] = ACTIONS(10142),
    [anon_sym_POUNDENDIF2] = ACTIONS(10142),
    [anon_sym_POUNDEndif2] = ACTIONS(10142),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10140),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10140),
    [anon_sym_PLUS] = ACTIONS(10142),
    [sym_datetime_literal] = ACTIONS(10142),
    [sym_date_literal] = ACTIONS(10140),
    [sym_time_literal] = ACTIONS(10140),
    [sym_biginteger_literal] = ACTIONS(10142),
    [anon_sym_else] = ACTIONS(10140),
    [anon_sym_ELSE] = ACTIONS(10140),
    [anon_sym_Else] = ACTIONS(10140),
    [sym_page_keyword] = ACTIONS(10140),
    [anon_sym_codeunit] = ACTIONS(10140),
    [anon_sym_CODEUNIT] = ACTIONS(10140),
    [anon_sym_Codeunit] = ACTIONS(10140),
    [anon_sym_CodeUnit] = ACTIONS(10140),
    [anon_sym_COdeunit] = ACTIONS(10140),
    [anon_sym_codeUnit] = ACTIONS(10140),
    [sym_report_keyword] = ACTIONS(10140),
    [sym_query_keyword] = ACTIONS(10140),
    [anon_sym_xmlport] = ACTIONS(10140),
    [anon_sym_XMLPORT] = ACTIONS(10140),
    [anon_sym_Xmlport] = ACTIONS(10140),
    [anon_sym_XMLport] = ACTIONS(10140),
    [anon_sym_XMLPort] = ACTIONS(10140),
    [anon_sym_XmlPort] = ACTIONS(10140),
    [anon_sym_enum] = ACTIONS(10140),
    [anon_sym_ENUM] = ACTIONS(10140),
    [anon_sym_Enum] = ACTIONS(10140),
    [anon_sym_eNUM] = ACTIONS(10140),
    [anon_sym_eNum] = ACTIONS(10140),
    [anon_sym_ENum] = ACTIONS(10140),
    [sym_quoted_identifier] = ACTIONS(10142),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10142),
    [sym_verbatim_string] = ACTIONS(10142),
    [sym_integer] = ACTIONS(10140),
    [sym_continue_as_identifier] = ACTIONS(10142),
    [sym_preproc_open] = ACTIONS(10142),
    [sym_preproc_close] = ACTIONS(10142),
  },
  [STATE(4429)] = {
    [sym_boolean] = STATE(8666),
    [sym_assignment_expression] = STATE(8666),
    [sym__expression] = STATE(8666),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8666),
    [sym_multiplicative_expression] = STATE(8666),
    [sym_additive_expression] = STATE(8666),
    [sym_comparison_expression] = STATE(8666),
    [sym_logical_expression] = STATE(8666),
    [sym_ternary_expression] = STATE(8666),
    [sym_unary_expression] = STATE(8666),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8666),
    [sym_list_literal] = STATE(8666),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8666),
    [sym__literal_value] = STATE(8666),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10144),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10146),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10148),
    [sym_date_literal] = ACTIONS(10144),
    [sym_time_literal] = ACTIONS(10144),
    [sym_biginteger_literal] = ACTIONS(10148),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10148),
    [sym_verbatim_string] = ACTIONS(10148),
    [sym_integer] = ACTIONS(10144),
    [sym_continue_as_identifier] = ACTIONS(10148),
  },
  [STATE(4430)] = {
    [sym_boolean] = STATE(9060),
    [sym_assignment_expression] = STATE(8836),
    [sym__expression] = STATE(8836),
    [sym_keyword_identifier] = STATE(8688),
    [sym_range_expression] = STATE(8836),
    [sym_multiplicative_expression] = STATE(8836),
    [sym_additive_expression] = STATE(8836),
    [sym_comparison_expression] = STATE(8836),
    [sym_logical_expression] = STATE(8836),
    [sym_ternary_expression] = STATE(8836),
    [sym_unary_expression] = STATE(8836),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8836),
    [sym_list_literal] = STATE(8836),
    [sym_qualified_enum_value] = STATE(8688),
    [sym_database_reference] = STATE(9067),
    [sym__literal_value] = STATE(8836),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(10150),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(7529),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10152),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10154),
    [sym_date_literal] = ACTIONS(10156),
    [sym_time_literal] = ACTIONS(10156),
    [sym_biginteger_literal] = ACTIONS(7531),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(10158),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10154),
    [sym_verbatim_string] = ACTIONS(7531),
    [sym_integer] = ACTIONS(10156),
    [sym_continue_as_identifier] = ACTIONS(7531),
  },
  [STATE(4431)] = {
    [sym_identifier] = ACTIONS(10160),
    [anon_sym_DASH] = ACTIONS(10162),
    [aux_sym_boolean_token1] = ACTIONS(10160),
    [aux_sym_boolean_token2] = ACTIONS(10160),
    [sym_decimal] = ACTIONS(10160),
    [anon_sym_LPAREN] = ACTIONS(10162),
    [aux_sym_tabledata_permission_token2] = ACTIONS(10160),
    [anon_sym_LBRACK] = ACTIONS(10162),
    [aux_sym_record_type_token1] = ACTIONS(10160),
    [aux_sym_basic_type_token21] = ACTIONS(10160),
    [aux_sym_basic_type_token22] = ACTIONS(10160),
    [aux_sym_basic_type_token48] = ACTIONS(10160),
    [anon_sym_POUNDif] = ACTIONS(10162),
    [anon_sym_POUNDIF] = ACTIONS(10162),
    [anon_sym_POUNDIf] = ACTIONS(10162),
    [anon_sym_not] = ACTIONS(10160),
    [anon_sym_NOT] = ACTIONS(10160),
    [anon_sym_Not] = ACTIONS(10160),
    [anon_sym_POUNDelif] = ACTIONS(10162),
    [anon_sym_POUNDELIF] = ACTIONS(10162),
    [anon_sym_POUNDElif] = ACTIONS(10162),
    [anon_sym_POUNDelse] = ACTIONS(10162),
    [anon_sym_POUNDELSE] = ACTIONS(10162),
    [anon_sym_POUNDElse] = ACTIONS(10162),
    [anon_sym_POUNDelse2] = ACTIONS(10162),
    [anon_sym_POUNDELSE2] = ACTIONS(10162),
    [anon_sym_POUNDElse2] = ACTIONS(10162),
    [anon_sym_POUNDendif] = ACTIONS(10162),
    [anon_sym_POUNDENDIF] = ACTIONS(10162),
    [anon_sym_POUNDEndif] = ACTIONS(10162),
    [anon_sym_POUNDendif2] = ACTIONS(10162),
    [anon_sym_POUNDENDIF2] = ACTIONS(10162),
    [anon_sym_POUNDEndif2] = ACTIONS(10162),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(10160),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10160),
    [anon_sym_PLUS] = ACTIONS(10162),
    [sym_datetime_literal] = ACTIONS(10162),
    [sym_date_literal] = ACTIONS(10160),
    [sym_time_literal] = ACTIONS(10160),
    [sym_biginteger_literal] = ACTIONS(10162),
    [anon_sym_else] = ACTIONS(10160),
    [anon_sym_ELSE] = ACTIONS(10160),
    [anon_sym_Else] = ACTIONS(10160),
    [sym_page_keyword] = ACTIONS(10160),
    [anon_sym_codeunit] = ACTIONS(10160),
    [anon_sym_CODEUNIT] = ACTIONS(10160),
    [anon_sym_Codeunit] = ACTIONS(10160),
    [anon_sym_CodeUnit] = ACTIONS(10160),
    [anon_sym_COdeunit] = ACTIONS(10160),
    [anon_sym_codeUnit] = ACTIONS(10160),
    [sym_report_keyword] = ACTIONS(10160),
    [sym_query_keyword] = ACTIONS(10160),
    [anon_sym_xmlport] = ACTIONS(10160),
    [anon_sym_XMLPORT] = ACTIONS(10160),
    [anon_sym_Xmlport] = ACTIONS(10160),
    [anon_sym_XMLport] = ACTIONS(10160),
    [anon_sym_XMLPort] = ACTIONS(10160),
    [anon_sym_XmlPort] = ACTIONS(10160),
    [anon_sym_enum] = ACTIONS(10160),
    [anon_sym_ENUM] = ACTIONS(10160),
    [anon_sym_Enum] = ACTIONS(10160),
    [anon_sym_eNUM] = ACTIONS(10160),
    [anon_sym_eNum] = ACTIONS(10160),
    [anon_sym_ENum] = ACTIONS(10160),
    [sym_quoted_identifier] = ACTIONS(10162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10162),
    [sym_verbatim_string] = ACTIONS(10162),
    [sym_integer] = ACTIONS(10160),
    [sym_continue_as_identifier] = ACTIONS(10162),
    [sym_preproc_open] = ACTIONS(10162),
    [sym_preproc_close] = ACTIONS(10162),
  },
  [STATE(4432)] = {
    [sym_boolean] = STATE(8636),
    [sym_assignment_expression] = STATE(8636),
    [sym__expression] = STATE(8636),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8636),
    [sym_multiplicative_expression] = STATE(8636),
    [sym_additive_expression] = STATE(8636),
    [sym_comparison_expression] = STATE(8636),
    [sym_logical_expression] = STATE(8636),
    [sym_ternary_expression] = STATE(8636),
    [sym_unary_expression] = STATE(8636),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8636),
    [sym_list_literal] = STATE(8636),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8636),
    [sym__literal_value] = STATE(8636),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10164),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [anon_sym_RPAREN] = ACTIONS(10166),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10168),
    [sym_date_literal] = ACTIONS(10164),
    [sym_time_literal] = ACTIONS(10164),
    [sym_biginteger_literal] = ACTIONS(10168),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10168),
    [sym_verbatim_string] = ACTIONS(10168),
    [sym_integer] = ACTIONS(10164),
    [sym_continue_as_identifier] = ACTIONS(10168),
  },
  [STATE(4433)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17284),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4434)] = {
    [sym_boolean] = STATE(8767),
    [sym__field_source] = STATE(17997),
    [sym_assignment_expression] = STATE(8767),
    [sym__expression] = STATE(8767),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8767),
    [sym_multiplicative_expression] = STATE(8767),
    [sym_additive_expression] = STATE(8767),
    [sym_comparison_expression] = STATE(8767),
    [sym_logical_expression] = STATE(8767),
    [sym_ternary_expression] = STATE(8767),
    [sym_unary_expression] = STATE(8767),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8767),
    [sym_list_literal] = STATE(8767),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8767),
    [sym__literal_value] = STATE(8767),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9756),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9758),
    [sym_date_literal] = ACTIONS(9756),
    [sym_time_literal] = ACTIONS(9756),
    [sym_biginteger_literal] = ACTIONS(9758),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9758),
    [sym_verbatim_string] = ACTIONS(9758),
    [sym_integer] = ACTIONS(9756),
    [sym_continue_as_identifier] = ACTIONS(9758),
  },
  [STATE(4435)] = {
    [sym_boolean] = STATE(8474),
    [sym_assignment_expression] = STATE(8474),
    [sym__expression] = STATE(8474),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8474),
    [sym_multiplicative_expression] = STATE(8474),
    [sym_additive_expression] = STATE(8474),
    [sym_comparison_expression] = STATE(8474),
    [sym_logical_expression] = STATE(8474),
    [sym_ternary_expression] = STATE(8474),
    [sym_unary_expression] = STATE(8474),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8474),
    [sym_list_literal] = STATE(8474),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8474),
    [sym__literal_value] = STATE(8474),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10170),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10172),
    [sym_date_literal] = ACTIONS(10170),
    [sym_time_literal] = ACTIONS(10170),
    [sym_biginteger_literal] = ACTIONS(10172),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10172),
    [sym_verbatim_string] = ACTIONS(10172),
    [sym_integer] = ACTIONS(10170),
    [sym_continue_as_identifier] = ACTIONS(10172),
  },
  [STATE(4436)] = {
    [sym_boolean] = STATE(8547),
    [sym_assignment_expression] = STATE(8547),
    [sym__expression] = STATE(8547),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8547),
    [sym_multiplicative_expression] = STATE(8547),
    [sym_additive_expression] = STATE(8547),
    [sym_comparison_expression] = STATE(8547),
    [sym_logical_expression] = STATE(8547),
    [sym_ternary_expression] = STATE(8547),
    [sym_unary_expression] = STATE(8547),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8547),
    [sym_list_literal] = STATE(8547),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8547),
    [sym__literal_value] = STATE(8547),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10174),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10176),
    [sym_date_literal] = ACTIONS(10174),
    [sym_time_literal] = ACTIONS(10174),
    [sym_biginteger_literal] = ACTIONS(10176),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10176),
    [sym_verbatim_string] = ACTIONS(10176),
    [sym_integer] = ACTIONS(10174),
    [sym_continue_as_identifier] = ACTIONS(10176),
  },
  [STATE(4437)] = {
    [sym_boolean] = STATE(8548),
    [sym_assignment_expression] = STATE(8548),
    [sym__expression] = STATE(8548),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8548),
    [sym_multiplicative_expression] = STATE(8548),
    [sym_additive_expression] = STATE(8548),
    [sym_comparison_expression] = STATE(8548),
    [sym_logical_expression] = STATE(8548),
    [sym_ternary_expression] = STATE(8548),
    [sym_unary_expression] = STATE(8548),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8548),
    [sym_list_literal] = STATE(8548),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8548),
    [sym__literal_value] = STATE(8548),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10178),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10180),
    [sym_date_literal] = ACTIONS(10178),
    [sym_time_literal] = ACTIONS(10178),
    [sym_biginteger_literal] = ACTIONS(10180),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10180),
    [sym_verbatim_string] = ACTIONS(10180),
    [sym_integer] = ACTIONS(10178),
    [sym_continue_as_identifier] = ACTIONS(10180),
  },
  [STATE(4438)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(9973),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4439)] = {
    [sym_boolean] = STATE(8373),
    [sym_assignment_expression] = STATE(8373),
    [sym__expression] = STATE(8373),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8373),
    [sym_multiplicative_expression] = STATE(8373),
    [sym_additive_expression] = STATE(8373),
    [sym_comparison_expression] = STATE(8373),
    [sym_logical_expression] = STATE(8373),
    [sym_ternary_expression] = STATE(8373),
    [sym_unary_expression] = STATE(8373),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8373),
    [sym_list_literal] = STATE(8373),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8373),
    [sym__literal_value] = STATE(8373),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10182),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10184),
    [sym_date_literal] = ACTIONS(10182),
    [sym_time_literal] = ACTIONS(10182),
    [sym_biginteger_literal] = ACTIONS(10184),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10184),
    [sym_verbatim_string] = ACTIONS(10184),
    [sym_integer] = ACTIONS(10182),
    [sym_continue_as_identifier] = ACTIONS(10184),
  },
  [STATE(4440)] = {
    [sym_boolean] = STATE(7585),
    [sym_assignment_expression] = STATE(7585),
    [sym__expression] = STATE(7585),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7585),
    [sym_multiplicative_expression] = STATE(7585),
    [sym_additive_expression] = STATE(7585),
    [sym_comparison_expression] = STATE(7585),
    [sym_logical_expression] = STATE(7585),
    [sym_ternary_expression] = STATE(7585),
    [sym_unary_expression] = STATE(7585),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7585),
    [sym_list_literal] = STATE(7585),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7585),
    [sym__literal_value] = STATE(7585),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(9664),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(9666),
    [sym_date_literal] = ACTIONS(9664),
    [sym_time_literal] = ACTIONS(9664),
    [sym_biginteger_literal] = ACTIONS(9666),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(9666),
    [sym_verbatim_string] = ACTIONS(9666),
    [sym_integer] = ACTIONS(9664),
    [sym_continue_as_identifier] = ACTIONS(9666),
  },
  [STATE(4441)] = {
    [sym_boolean] = STATE(8375),
    [sym_assignment_expression] = STATE(8375),
    [sym__expression] = STATE(8375),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8375),
    [sym_multiplicative_expression] = STATE(8375),
    [sym_additive_expression] = STATE(8375),
    [sym_comparison_expression] = STATE(8375),
    [sym_logical_expression] = STATE(8375),
    [sym_ternary_expression] = STATE(8375),
    [sym_unary_expression] = STATE(8375),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8375),
    [sym_list_literal] = STATE(8375),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8375),
    [sym__literal_value] = STATE(8375),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10186),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10188),
    [sym_date_literal] = ACTIONS(10186),
    [sym_time_literal] = ACTIONS(10186),
    [sym_biginteger_literal] = ACTIONS(10188),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10188),
    [sym_verbatim_string] = ACTIONS(10188),
    [sym_integer] = ACTIONS(10186),
    [sym_continue_as_identifier] = ACTIONS(10188),
  },
  [STATE(4442)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(8213),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4443)] = {
    [sym_preproc_conditional_controladdin] = STATE(4467),
    [sym__body_element] = STATE(4467),
    [sym_empty_statement] = STATE(4467),
    [sym_property] = STATE(4467),
    [sym_permissions_property] = STATE(4467),
    [sym_table_relation_property] = STATE(4467),
    [sym_fields_section] = STATE(4467),
    [sym_keys_section] = STATE(4467),
    [sym_fieldgroups_section] = STATE(4467),
    [sym_enum_value_declaration] = STATE(4467),
    [sym_labels_section] = STATE(4467),
    [sym_layout_section] = STATE(4467),
    [sym_modify_modification] = STATE(4467),
    [sym_actions_section] = STATE(4467),
    [sym_views_section] = STATE(4467),
    [sym_dataset_section] = STATE(4467),
    [sym_requestpage_section] = STATE(4467),
    [sym_rendering_section] = STATE(4467),
    [sym_elements_section] = STATE(4467),
    [sym_schema_section] = STATE(4467),
    [sym_assembly_declaration] = STATE(4467),
    [sym_event_declaration] = STATE(4467),
    [sym_procedure] = STATE(4467),
    [sym_preproc_split_procedure] = STATE(4467),
    [sym_preproc_split_procedure_preamble] = STATE(4467),
    [sym_interface_procedure] = STATE(4467),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4467),
    [sym_var_section] = STATE(4467),
    [sym_attribute_item] = STATE(4467),
    [sym_preproc_conditional] = STATE(4467),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(8213),
    [aux_sym_controladdin_declaration_repeat1] = STATE(4467),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4444)] = {
    [sym_boolean] = STATE(7534),
    [sym_assignment_expression] = STATE(7534),
    [sym__expression] = STATE(7534),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7534),
    [sym_multiplicative_expression] = STATE(7534),
    [sym_additive_expression] = STATE(7534),
    [sym_comparison_expression] = STATE(7534),
    [sym_logical_expression] = STATE(7534),
    [sym_ternary_expression] = STATE(7534),
    [sym_unary_expression] = STATE(7534),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7534),
    [sym_list_literal] = STATE(7534),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7534),
    [sym__literal_value] = STATE(7534),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10190),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10192),
    [sym_date_literal] = ACTIONS(10190),
    [sym_time_literal] = ACTIONS(10190),
    [sym_biginteger_literal] = ACTIONS(10192),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10192),
    [sym_verbatim_string] = ACTIONS(10192),
    [sym_integer] = ACTIONS(10190),
    [sym_continue_as_identifier] = ACTIONS(10192),
  },
  [STATE(4445)] = {
    [sym_boolean] = STATE(8707),
    [sym_assignment_expression] = STATE(8707),
    [sym__expression] = STATE(8707),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8707),
    [sym_multiplicative_expression] = STATE(8707),
    [sym_additive_expression] = STATE(8707),
    [sym_comparison_expression] = STATE(8707),
    [sym_logical_expression] = STATE(8707),
    [sym_ternary_expression] = STATE(8707),
    [sym_unary_expression] = STATE(8707),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8707),
    [sym_list_literal] = STATE(8707),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8707),
    [sym__literal_value] = STATE(8707),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10194),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(10196),
    [sym_date_literal] = ACTIONS(10194),
    [sym_time_literal] = ACTIONS(10194),
    [sym_biginteger_literal] = ACTIONS(10196),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10196),
    [sym_verbatim_string] = ACTIONS(10196),
    [sym_integer] = ACTIONS(10194),
    [sym_continue_as_identifier] = ACTIONS(10196),
  },
  [STATE(4446)] = {
    [sym_boolean] = STATE(7535),
    [sym_assignment_expression] = STATE(7535),
    [sym__expression] = STATE(7535),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7535),
    [sym_multiplicative_expression] = STATE(7535),
    [sym_additive_expression] = STATE(7535),
    [sym_comparison_expression] = STATE(7535),
    [sym_logical_expression] = STATE(7535),
    [sym_ternary_expression] = STATE(7535),
    [sym_unary_expression] = STATE(7535),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7535),
    [sym_list_literal] = STATE(7535),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7535),
    [sym__literal_value] = STATE(7535),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10198),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10200),
    [sym_date_literal] = ACTIONS(10198),
    [sym_time_literal] = ACTIONS(10198),
    [sym_biginteger_literal] = ACTIONS(10200),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10200),
    [sym_verbatim_string] = ACTIONS(10200),
    [sym_integer] = ACTIONS(10198),
    [sym_continue_as_identifier] = ACTIONS(10200),
  },
  [STATE(4447)] = {
    [sym_boolean] = STATE(8711),
    [sym_assignment_expression] = STATE(8711),
    [sym__expression] = STATE(8711),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8711),
    [sym_multiplicative_expression] = STATE(8711),
    [sym_additive_expression] = STATE(8711),
    [sym_comparison_expression] = STATE(8711),
    [sym_logical_expression] = STATE(8711),
    [sym_ternary_expression] = STATE(8711),
    [sym_unary_expression] = STATE(8711),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8711),
    [sym_list_literal] = STATE(8711),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8711),
    [sym__literal_value] = STATE(8711),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10202),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(10204),
    [sym_date_literal] = ACTIONS(10202),
    [sym_time_literal] = ACTIONS(10202),
    [sym_biginteger_literal] = ACTIONS(10204),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10204),
    [sym_verbatim_string] = ACTIONS(10204),
    [sym_integer] = ACTIONS(10202),
    [sym_continue_as_identifier] = ACTIONS(10204),
  },
  [STATE(4448)] = {
    [sym_boolean] = STATE(7536),
    [sym_assignment_expression] = STATE(7536),
    [sym__expression] = STATE(7536),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7536),
    [sym_multiplicative_expression] = STATE(7536),
    [sym_additive_expression] = STATE(7536),
    [sym_comparison_expression] = STATE(7536),
    [sym_logical_expression] = STATE(7536),
    [sym_ternary_expression] = STATE(7536),
    [sym_unary_expression] = STATE(7536),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7536),
    [sym_list_literal] = STATE(7536),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7536),
    [sym__literal_value] = STATE(7536),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10206),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10208),
    [sym_date_literal] = ACTIONS(10206),
    [sym_time_literal] = ACTIONS(10206),
    [sym_biginteger_literal] = ACTIONS(10208),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10208),
    [sym_verbatim_string] = ACTIONS(10208),
    [sym_integer] = ACTIONS(10206),
    [sym_continue_as_identifier] = ACTIONS(10208),
  },
  [STATE(4449)] = {
    [sym_boolean] = STATE(7537),
    [sym_assignment_expression] = STATE(7537),
    [sym__expression] = STATE(7537),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7537),
    [sym_multiplicative_expression] = STATE(7537),
    [sym_additive_expression] = STATE(7537),
    [sym_comparison_expression] = STATE(7537),
    [sym_logical_expression] = STATE(7537),
    [sym_ternary_expression] = STATE(7537),
    [sym_unary_expression] = STATE(7537),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7537),
    [sym_list_literal] = STATE(7537),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7537),
    [sym__literal_value] = STATE(7537),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10210),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10212),
    [sym_date_literal] = ACTIONS(10210),
    [sym_time_literal] = ACTIONS(10210),
    [sym_biginteger_literal] = ACTIONS(10212),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10212),
    [sym_verbatim_string] = ACTIONS(10212),
    [sym_integer] = ACTIONS(10210),
    [sym_continue_as_identifier] = ACTIONS(10212),
  },
  [STATE(4450)] = {
    [sym_boolean] = STATE(7538),
    [sym_assignment_expression] = STATE(7538),
    [sym__expression] = STATE(7538),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7538),
    [sym_multiplicative_expression] = STATE(7538),
    [sym_additive_expression] = STATE(7538),
    [sym_comparison_expression] = STATE(7538),
    [sym_logical_expression] = STATE(7538),
    [sym_ternary_expression] = STATE(7538),
    [sym_unary_expression] = STATE(7538),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7538),
    [sym_list_literal] = STATE(7538),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7538),
    [sym__literal_value] = STATE(7538),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10214),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10216),
    [sym_date_literal] = ACTIONS(10214),
    [sym_time_literal] = ACTIONS(10214),
    [sym_biginteger_literal] = ACTIONS(10216),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10216),
    [sym_verbatim_string] = ACTIONS(10216),
    [sym_integer] = ACTIONS(10214),
    [sym_continue_as_identifier] = ACTIONS(10216),
  },
  [STATE(4451)] = {
    [sym_boolean] = STATE(7539),
    [sym_assignment_expression] = STATE(7539),
    [sym__expression] = STATE(7539),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7539),
    [sym_multiplicative_expression] = STATE(7539),
    [sym_additive_expression] = STATE(7539),
    [sym_comparison_expression] = STATE(7539),
    [sym_logical_expression] = STATE(7539),
    [sym_ternary_expression] = STATE(7539),
    [sym_unary_expression] = STATE(7539),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7539),
    [sym_list_literal] = STATE(7539),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7539),
    [sym__literal_value] = STATE(7539),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10218),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10220),
    [sym_date_literal] = ACTIONS(10218),
    [sym_time_literal] = ACTIONS(10218),
    [sym_biginteger_literal] = ACTIONS(10220),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10220),
    [sym_verbatim_string] = ACTIONS(10220),
    [sym_integer] = ACTIONS(10218),
    [sym_continue_as_identifier] = ACTIONS(10220),
  },
  [STATE(4452)] = {
    [sym_boolean] = STATE(7540),
    [sym_assignment_expression] = STATE(7540),
    [sym__expression] = STATE(7540),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7540),
    [sym_multiplicative_expression] = STATE(7540),
    [sym_additive_expression] = STATE(7540),
    [sym_comparison_expression] = STATE(7540),
    [sym_logical_expression] = STATE(7540),
    [sym_ternary_expression] = STATE(7540),
    [sym_unary_expression] = STATE(7540),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7540),
    [sym_list_literal] = STATE(7540),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7540),
    [sym__literal_value] = STATE(7540),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10222),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10224),
    [sym_date_literal] = ACTIONS(10222),
    [sym_time_literal] = ACTIONS(10222),
    [sym_biginteger_literal] = ACTIONS(10224),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10224),
    [sym_verbatim_string] = ACTIONS(10224),
    [sym_integer] = ACTIONS(10222),
    [sym_continue_as_identifier] = ACTIONS(10224),
  },
  [STATE(4453)] = {
    [sym_boolean] = STATE(7541),
    [sym_assignment_expression] = STATE(7541),
    [sym__expression] = STATE(7541),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7541),
    [sym_multiplicative_expression] = STATE(7541),
    [sym_additive_expression] = STATE(7541),
    [sym_comparison_expression] = STATE(7541),
    [sym_logical_expression] = STATE(7541),
    [sym_ternary_expression] = STATE(7541),
    [sym_unary_expression] = STATE(7541),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7541),
    [sym_list_literal] = STATE(7541),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7541),
    [sym__literal_value] = STATE(7541),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10226),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10228),
    [sym_date_literal] = ACTIONS(10226),
    [sym_time_literal] = ACTIONS(10226),
    [sym_biginteger_literal] = ACTIONS(10228),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10228),
    [sym_verbatim_string] = ACTIONS(10228),
    [sym_integer] = ACTIONS(10226),
    [sym_continue_as_identifier] = ACTIONS(10228),
  },
  [STATE(4454)] = {
    [sym_boolean] = STATE(7542),
    [sym_assignment_expression] = STATE(7542),
    [sym__expression] = STATE(7542),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7542),
    [sym_multiplicative_expression] = STATE(7542),
    [sym_additive_expression] = STATE(7542),
    [sym_comparison_expression] = STATE(7542),
    [sym_logical_expression] = STATE(7542),
    [sym_ternary_expression] = STATE(7542),
    [sym_unary_expression] = STATE(7542),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7542),
    [sym_list_literal] = STATE(7542),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7542),
    [sym__literal_value] = STATE(7542),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10230),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10232),
    [sym_date_literal] = ACTIONS(10230),
    [sym_time_literal] = ACTIONS(10230),
    [sym_biginteger_literal] = ACTIONS(10232),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10232),
    [sym_verbatim_string] = ACTIONS(10232),
    [sym_integer] = ACTIONS(10230),
    [sym_continue_as_identifier] = ACTIONS(10232),
  },
  [STATE(4455)] = {
    [sym_boolean] = STATE(7543),
    [sym_assignment_expression] = STATE(7543),
    [sym__expression] = STATE(7543),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7543),
    [sym_multiplicative_expression] = STATE(7543),
    [sym_additive_expression] = STATE(7543),
    [sym_comparison_expression] = STATE(7543),
    [sym_logical_expression] = STATE(7543),
    [sym_ternary_expression] = STATE(7543),
    [sym_unary_expression] = STATE(7543),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7543),
    [sym_list_literal] = STATE(7543),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7543),
    [sym__literal_value] = STATE(7543),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10234),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10236),
    [sym_date_literal] = ACTIONS(10234),
    [sym_time_literal] = ACTIONS(10234),
    [sym_biginteger_literal] = ACTIONS(10236),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10236),
    [sym_verbatim_string] = ACTIONS(10236),
    [sym_integer] = ACTIONS(10234),
    [sym_continue_as_identifier] = ACTIONS(10236),
  },
  [STATE(4456)] = {
    [sym_boolean] = STATE(7544),
    [sym_assignment_expression] = STATE(7544),
    [sym__expression] = STATE(7544),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7544),
    [sym_multiplicative_expression] = STATE(7544),
    [sym_additive_expression] = STATE(7544),
    [sym_comparison_expression] = STATE(7544),
    [sym_logical_expression] = STATE(7544),
    [sym_ternary_expression] = STATE(7544),
    [sym_unary_expression] = STATE(7544),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7544),
    [sym_list_literal] = STATE(7544),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7544),
    [sym__literal_value] = STATE(7544),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10238),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10240),
    [sym_date_literal] = ACTIONS(10238),
    [sym_time_literal] = ACTIONS(10238),
    [sym_biginteger_literal] = ACTIONS(10240),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10240),
    [sym_verbatim_string] = ACTIONS(10240),
    [sym_integer] = ACTIONS(10238),
    [sym_continue_as_identifier] = ACTIONS(10240),
  },
  [STATE(4457)] = {
    [sym_boolean] = STATE(7545),
    [sym_assignment_expression] = STATE(7545),
    [sym__expression] = STATE(7545),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7545),
    [sym_multiplicative_expression] = STATE(7545),
    [sym_additive_expression] = STATE(7545),
    [sym_comparison_expression] = STATE(7545),
    [sym_logical_expression] = STATE(7545),
    [sym_ternary_expression] = STATE(7545),
    [sym_unary_expression] = STATE(7545),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7545),
    [sym_list_literal] = STATE(7545),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7545),
    [sym__literal_value] = STATE(7545),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10242),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10244),
    [sym_date_literal] = ACTIONS(10242),
    [sym_time_literal] = ACTIONS(10242),
    [sym_biginteger_literal] = ACTIONS(10244),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10244),
    [sym_verbatim_string] = ACTIONS(10244),
    [sym_integer] = ACTIONS(10242),
    [sym_continue_as_identifier] = ACTIONS(10244),
  },
  [STATE(4458)] = {
    [sym_boolean] = STATE(7546),
    [sym_assignment_expression] = STATE(7546),
    [sym__expression] = STATE(7546),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7546),
    [sym_multiplicative_expression] = STATE(7546),
    [sym_additive_expression] = STATE(7546),
    [sym_comparison_expression] = STATE(7546),
    [sym_logical_expression] = STATE(7546),
    [sym_ternary_expression] = STATE(7546),
    [sym_unary_expression] = STATE(7546),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7546),
    [sym_list_literal] = STATE(7546),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7546),
    [sym__literal_value] = STATE(7546),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10246),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10248),
    [sym_date_literal] = ACTIONS(10246),
    [sym_time_literal] = ACTIONS(10246),
    [sym_biginteger_literal] = ACTIONS(10248),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10248),
    [sym_verbatim_string] = ACTIONS(10248),
    [sym_integer] = ACTIONS(10246),
    [sym_continue_as_identifier] = ACTIONS(10248),
  },
  [STATE(4459)] = {
    [sym_boolean] = STATE(7547),
    [sym_assignment_expression] = STATE(7547),
    [sym__expression] = STATE(7547),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7547),
    [sym_multiplicative_expression] = STATE(7547),
    [sym_additive_expression] = STATE(7547),
    [sym_comparison_expression] = STATE(7547),
    [sym_logical_expression] = STATE(7547),
    [sym_ternary_expression] = STATE(7547),
    [sym_unary_expression] = STATE(7547),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7547),
    [sym_list_literal] = STATE(7547),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7547),
    [sym__literal_value] = STATE(7547),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10250),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10252),
    [sym_date_literal] = ACTIONS(10250),
    [sym_time_literal] = ACTIONS(10250),
    [sym_biginteger_literal] = ACTIONS(10252),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10252),
    [sym_verbatim_string] = ACTIONS(10252),
    [sym_integer] = ACTIONS(10250),
    [sym_continue_as_identifier] = ACTIONS(10252),
  },
  [STATE(4460)] = {
    [sym_boolean] = STATE(7548),
    [sym_assignment_expression] = STATE(7548),
    [sym__expression] = STATE(7548),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7548),
    [sym_multiplicative_expression] = STATE(7548),
    [sym_additive_expression] = STATE(7548),
    [sym_comparison_expression] = STATE(7548),
    [sym_logical_expression] = STATE(7548),
    [sym_ternary_expression] = STATE(7548),
    [sym_unary_expression] = STATE(7548),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7548),
    [sym_list_literal] = STATE(7548),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7548),
    [sym__literal_value] = STATE(7548),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10254),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10256),
    [sym_date_literal] = ACTIONS(10254),
    [sym_time_literal] = ACTIONS(10254),
    [sym_biginteger_literal] = ACTIONS(10256),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10256),
    [sym_verbatim_string] = ACTIONS(10256),
    [sym_integer] = ACTIONS(10254),
    [sym_continue_as_identifier] = ACTIONS(10256),
  },
  [STATE(4461)] = {
    [sym_boolean] = STATE(7549),
    [sym_assignment_expression] = STATE(7549),
    [sym__expression] = STATE(7549),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7549),
    [sym_multiplicative_expression] = STATE(7549),
    [sym_additive_expression] = STATE(7549),
    [sym_comparison_expression] = STATE(7549),
    [sym_logical_expression] = STATE(7549),
    [sym_ternary_expression] = STATE(7549),
    [sym_unary_expression] = STATE(7549),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7549),
    [sym_list_literal] = STATE(7549),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7549),
    [sym__literal_value] = STATE(7549),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10258),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10260),
    [sym_date_literal] = ACTIONS(10258),
    [sym_time_literal] = ACTIONS(10258),
    [sym_biginteger_literal] = ACTIONS(10260),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10260),
    [sym_verbatim_string] = ACTIONS(10260),
    [sym_integer] = ACTIONS(10258),
    [sym_continue_as_identifier] = ACTIONS(10260),
  },
  [STATE(4462)] = {
    [sym_boolean] = STATE(7550),
    [sym_assignment_expression] = STATE(7550),
    [sym__expression] = STATE(7550),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7550),
    [sym_multiplicative_expression] = STATE(7550),
    [sym_additive_expression] = STATE(7550),
    [sym_comparison_expression] = STATE(7550),
    [sym_logical_expression] = STATE(7550),
    [sym_ternary_expression] = STATE(7550),
    [sym_unary_expression] = STATE(7550),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7550),
    [sym_list_literal] = STATE(7550),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7550),
    [sym__literal_value] = STATE(7550),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10262),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10264),
    [sym_date_literal] = ACTIONS(10262),
    [sym_time_literal] = ACTIONS(10262),
    [sym_biginteger_literal] = ACTIONS(10264),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10264),
    [sym_verbatim_string] = ACTIONS(10264),
    [sym_integer] = ACTIONS(10262),
    [sym_continue_as_identifier] = ACTIONS(10264),
  },
  [STATE(4463)] = {
    [sym_boolean] = STATE(7551),
    [sym_assignment_expression] = STATE(7551),
    [sym__expression] = STATE(7551),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7551),
    [sym_multiplicative_expression] = STATE(7551),
    [sym_additive_expression] = STATE(7551),
    [sym_comparison_expression] = STATE(7551),
    [sym_logical_expression] = STATE(7551),
    [sym_ternary_expression] = STATE(7551),
    [sym_unary_expression] = STATE(7551),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7551),
    [sym_list_literal] = STATE(7551),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7551),
    [sym__literal_value] = STATE(7551),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10266),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10268),
    [sym_date_literal] = ACTIONS(10266),
    [sym_time_literal] = ACTIONS(10266),
    [sym_biginteger_literal] = ACTIONS(10268),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10268),
    [sym_verbatim_string] = ACTIONS(10268),
    [sym_integer] = ACTIONS(10266),
    [sym_continue_as_identifier] = ACTIONS(10268),
  },
  [STATE(4464)] = {
    [sym_boolean] = STATE(7552),
    [sym_assignment_expression] = STATE(7552),
    [sym__expression] = STATE(7552),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7552),
    [sym_multiplicative_expression] = STATE(7552),
    [sym_additive_expression] = STATE(7552),
    [sym_comparison_expression] = STATE(7552),
    [sym_logical_expression] = STATE(7552),
    [sym_ternary_expression] = STATE(7552),
    [sym_unary_expression] = STATE(7552),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7552),
    [sym_list_literal] = STATE(7552),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7552),
    [sym__literal_value] = STATE(7552),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10270),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10272),
    [sym_date_literal] = ACTIONS(10270),
    [sym_time_literal] = ACTIONS(10270),
    [sym_biginteger_literal] = ACTIONS(10272),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10272),
    [sym_verbatim_string] = ACTIONS(10272),
    [sym_integer] = ACTIONS(10270),
    [sym_continue_as_identifier] = ACTIONS(10272),
  },
  [STATE(4465)] = {
    [sym_boolean] = STATE(7553),
    [sym_assignment_expression] = STATE(7553),
    [sym__expression] = STATE(7553),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7553),
    [sym_multiplicative_expression] = STATE(7553),
    [sym_additive_expression] = STATE(7553),
    [sym_comparison_expression] = STATE(7553),
    [sym_logical_expression] = STATE(7553),
    [sym_ternary_expression] = STATE(7553),
    [sym_unary_expression] = STATE(7553),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7553),
    [sym_list_literal] = STATE(7553),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7553),
    [sym__literal_value] = STATE(7553),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10274),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10276),
    [sym_date_literal] = ACTIONS(10274),
    [sym_time_literal] = ACTIONS(10274),
    [sym_biginteger_literal] = ACTIONS(10276),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10276),
    [sym_verbatim_string] = ACTIONS(10276),
    [sym_integer] = ACTIONS(10274),
    [sym_continue_as_identifier] = ACTIONS(10276),
  },
  [STATE(4466)] = {
    [sym_boolean] = STATE(8614),
    [sym_assignment_expression] = STATE(8614),
    [sym__expression] = STATE(8614),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8614),
    [sym_multiplicative_expression] = STATE(8614),
    [sym_additive_expression] = STATE(8614),
    [sym_comparison_expression] = STATE(8614),
    [sym_logical_expression] = STATE(8614),
    [sym_ternary_expression] = STATE(8614),
    [sym_unary_expression] = STATE(8614),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8614),
    [sym_list_literal] = STATE(8614),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8614),
    [sym__literal_value] = STATE(8614),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10278),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10280),
    [sym_date_literal] = ACTIONS(10278),
    [sym_time_literal] = ACTIONS(10278),
    [sym_biginteger_literal] = ACTIONS(10280),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10280),
    [sym_verbatim_string] = ACTIONS(10280),
    [sym_integer] = ACTIONS(10278),
    [sym_continue_as_identifier] = ACTIONS(10280),
  },
  [STATE(4467)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(8224),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4468)] = {
    [sym_preproc_conditional_controladdin] = STATE(4470),
    [sym__body_element] = STATE(4470),
    [sym_empty_statement] = STATE(4470),
    [sym_property] = STATE(4470),
    [sym_permissions_property] = STATE(4470),
    [sym_table_relation_property] = STATE(4470),
    [sym_fields_section] = STATE(4470),
    [sym_keys_section] = STATE(4470),
    [sym_fieldgroups_section] = STATE(4470),
    [sym_enum_value_declaration] = STATE(4470),
    [sym_labels_section] = STATE(4470),
    [sym_layout_section] = STATE(4470),
    [sym_modify_modification] = STATE(4470),
    [sym_actions_section] = STATE(4470),
    [sym_views_section] = STATE(4470),
    [sym_dataset_section] = STATE(4470),
    [sym_requestpage_section] = STATE(4470),
    [sym_rendering_section] = STATE(4470),
    [sym_elements_section] = STATE(4470),
    [sym_schema_section] = STATE(4470),
    [sym_assembly_declaration] = STATE(4470),
    [sym_event_declaration] = STATE(4470),
    [sym_procedure] = STATE(4470),
    [sym_preproc_split_procedure] = STATE(4470),
    [sym_preproc_split_procedure_preamble] = STATE(4470),
    [sym_interface_procedure] = STATE(4470),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4470),
    [sym_var_section] = STATE(4470),
    [sym_attribute_item] = STATE(4470),
    [sym_preproc_conditional] = STATE(4470),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(8224),
    [aux_sym_controladdin_declaration_repeat1] = STATE(4470),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4469)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(9980),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4470)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(8157),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4471)] = {
    [sym_boolean] = STATE(8762),
    [sym_assignment_expression] = STATE(8762),
    [sym__expression] = STATE(8762),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8762),
    [sym_multiplicative_expression] = STATE(8762),
    [sym_additive_expression] = STATE(8762),
    [sym_comparison_expression] = STATE(8762),
    [sym_logical_expression] = STATE(8762),
    [sym_ternary_expression] = STATE(8762),
    [sym_unary_expression] = STATE(8762),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8762),
    [sym_list_literal] = STATE(8762),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8762),
    [sym__literal_value] = STATE(8762),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10282),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(10284),
    [sym_date_literal] = ACTIONS(10282),
    [sym_time_literal] = ACTIONS(10282),
    [sym_biginteger_literal] = ACTIONS(10284),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10284),
    [sym_verbatim_string] = ACTIONS(10284),
    [sym_integer] = ACTIONS(10282),
    [sym_continue_as_identifier] = ACTIONS(10284),
  },
  [STATE(4472)] = {
    [sym_boolean] = STATE(1808),
    [sym_assignment_expression] = STATE(1808),
    [sym__expression] = STATE(1808),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1808),
    [sym_multiplicative_expression] = STATE(1808),
    [sym_additive_expression] = STATE(1808),
    [sym_comparison_expression] = STATE(1808),
    [sym_logical_expression] = STATE(1808),
    [sym_ternary_expression] = STATE(1808),
    [sym_unary_expression] = STATE(1808),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1808),
    [sym_list_literal] = STATE(1808),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1808),
    [sym__literal_value] = STATE(1808),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(10286),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(10288),
    [sym_date_literal] = ACTIONS(10286),
    [sym_time_literal] = ACTIONS(10286),
    [sym_biginteger_literal] = ACTIONS(10288),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10288),
    [sym_verbatim_string] = ACTIONS(10288),
    [sym_integer] = ACTIONS(10286),
    [sym_continue_as_identifier] = ACTIONS(10288),
  },
  [STATE(4473)] = {
    [sym_boolean] = STATE(1810),
    [sym_assignment_expression] = STATE(1810),
    [sym__expression] = STATE(1810),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1810),
    [sym_multiplicative_expression] = STATE(1810),
    [sym_additive_expression] = STATE(1810),
    [sym_comparison_expression] = STATE(1810),
    [sym_logical_expression] = STATE(1810),
    [sym_ternary_expression] = STATE(1810),
    [sym_unary_expression] = STATE(1810),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1810),
    [sym_list_literal] = STATE(1810),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1810),
    [sym__literal_value] = STATE(1810),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(10290),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(10292),
    [sym_date_literal] = ACTIONS(10290),
    [sym_time_literal] = ACTIONS(10290),
    [sym_biginteger_literal] = ACTIONS(10292),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10292),
    [sym_verbatim_string] = ACTIONS(10292),
    [sym_integer] = ACTIONS(10290),
    [sym_continue_as_identifier] = ACTIONS(10292),
  },
  [STATE(4474)] = {
    [sym_boolean] = STATE(1910),
    [sym_assignment_expression] = STATE(1910),
    [sym__expression] = STATE(1910),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1910),
    [sym_multiplicative_expression] = STATE(1910),
    [sym_additive_expression] = STATE(1910),
    [sym_comparison_expression] = STATE(1910),
    [sym_logical_expression] = STATE(1910),
    [sym_ternary_expression] = STATE(1910),
    [sym_unary_expression] = STATE(1910),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1910),
    [sym_list_literal] = STATE(1910),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1910),
    [sym__literal_value] = STATE(1910),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10294),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10296),
    [sym_date_literal] = ACTIONS(10294),
    [sym_time_literal] = ACTIONS(10294),
    [sym_biginteger_literal] = ACTIONS(10296),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10296),
    [sym_verbatim_string] = ACTIONS(10296),
    [sym_integer] = ACTIONS(10294),
    [sym_continue_as_identifier] = ACTIONS(10296),
  },
  [STATE(4475)] = {
    [sym_boolean] = STATE(3464),
    [sym_assignment_expression] = STATE(3464),
    [sym__expression] = STATE(3464),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3464),
    [sym_multiplicative_expression] = STATE(3464),
    [sym_additive_expression] = STATE(3464),
    [sym_comparison_expression] = STATE(3464),
    [sym_logical_expression] = STATE(3464),
    [sym_ternary_expression] = STATE(3464),
    [sym_unary_expression] = STATE(3464),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3464),
    [sym_list_literal] = STATE(3464),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3464),
    [sym__literal_value] = STATE(3464),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10298),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10300),
    [sym_date_literal] = ACTIONS(10298),
    [sym_time_literal] = ACTIONS(10298),
    [sym_biginteger_literal] = ACTIONS(10300),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10300),
    [sym_verbatim_string] = ACTIONS(10300),
    [sym_integer] = ACTIONS(10298),
    [sym_continue_as_identifier] = ACTIONS(10300),
  },
  [STATE(4476)] = {
    [sym__body_element] = STATE(4481),
    [sym_empty_statement] = STATE(4481),
    [sym_property] = STATE(4481),
    [sym_permissions_property] = STATE(4481),
    [sym_table_relation_property] = STATE(4481),
    [sym_fields_section] = STATE(4481),
    [sym_keys_section] = STATE(4481),
    [sym_fieldgroups_section] = STATE(4481),
    [sym_enum_value_declaration] = STATE(4481),
    [sym_labels_section] = STATE(4481),
    [sym_layout_section] = STATE(4481),
    [sym_modify_modification] = STATE(4481),
    [sym_actions_section] = STATE(4481),
    [sym_views_section] = STATE(4481),
    [sym_dataset_section] = STATE(4481),
    [sym_requestpage_section] = STATE(4481),
    [sym_rendering_section] = STATE(4481),
    [sym_elements_section] = STATE(4481),
    [sym_schema_section] = STATE(4481),
    [sym_xmlport_element] = STATE(4481),
    [sym__xmlport_body_element] = STATE(4481),
    [sym_preproc_conditional_xmlport] = STATE(4481),
    [sym_xmlport_attribute] = STATE(4481),
    [sym_assembly_declaration] = STATE(4481),
    [sym_event_declaration] = STATE(4481),
    [sym_procedure] = STATE(4481),
    [sym_preproc_split_procedure] = STATE(4481),
    [sym_preproc_split_procedure_preamble] = STATE(4481),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4481),
    [sym_var_section] = STATE(4481),
    [sym_attribute_item] = STATE(4481),
    [sym_preproc_conditional] = STATE(4481),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4481),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10304),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4477)] = {
    [sym_where_clause] = STATE(4933),
    [anon_sym_SEMI] = ACTIONS(5386),
    [aux_sym_where_clause_token1] = ACTIONS(5390),
    [aux_sym_where_condition_token1] = ACTIONS(5392),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5386),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5386),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5386),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [aux_sym_basic_type_token6] = ACTIONS(5392),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5386),
    [aux_sym_addafter_modification_token1] = ACTIONS(5386),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5386),
    [aux_sym_modify_modification_token1] = ACTIONS(5386),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5386),
    [aux_sym_movelast_modification_token1] = ACTIONS(5386),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5386),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5386),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5386),
    [anon_sym_POUNDif] = ACTIONS(5386),
    [anon_sym_POUNDIF] = ACTIONS(5386),
    [anon_sym_POUNDIf] = ACTIONS(5386),
    [anon_sym_POUNDelif] = ACTIONS(5386),
    [anon_sym_POUNDELIF] = ACTIONS(5386),
    [anon_sym_POUNDElif] = ACTIONS(5386),
    [anon_sym_POUNDelse] = ACTIONS(5386),
    [anon_sym_POUNDELSE] = ACTIONS(5386),
    [anon_sym_POUNDElse] = ACTIONS(5386),
    [anon_sym_POUNDelse2] = ACTIONS(5386),
    [anon_sym_POUNDELSE2] = ACTIONS(5386),
    [anon_sym_POUNDElse2] = ACTIONS(5386),
    [anon_sym_POUNDendif] = ACTIONS(5386),
    [anon_sym_POUNDENDIF] = ACTIONS(5386),
    [anon_sym_POUNDEndif] = ACTIONS(5386),
    [anon_sym_POUNDendif2] = ACTIONS(5386),
    [anon_sym_POUNDENDIF2] = ACTIONS(5386),
    [anon_sym_POUNDEndif2] = ACTIONS(5386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5386),
    [sym_trigger_keyword] = ACTIONS(5386),
    [sym_var_keyword] = ACTIONS(5386),
    [sym_local_keyword] = ACTIONS(5386),
    [sym_internal_keyword] = ACTIONS(5386),
    [sym_protected_keyword] = ACTIONS(5386),
    [sym_event_keyword] = ACTIONS(5386),
    [sym_fields_keyword] = ACTIONS(5386),
    [sym_keys_keyword] = ACTIONS(5386),
    [sym_fieldgroups_keyword] = ACTIONS(5386),
    [sym_actions_keyword] = ACTIONS(5386),
    [sym_layout_keyword] = ACTIONS(5386),
    [sym_area_keyword] = ACTIONS(5386),
    [sym_group_keyword] = ACTIONS(5386),
    [sym_repeater_keyword] = ACTIONS(5386),
    [sym_cuegroup_keyword] = ACTIONS(5386),
    [sym_fixed_keyword] = ACTIONS(5386),
    [sym_grid_keyword] = ACTIONS(5386),
    [sym_part_keyword] = ACTIONS(5386),
    [sym_systempart_keyword] = ACTIONS(5386),
    [sym_usercontrol_keyword] = ACTIONS(5386),
    [sym_dataset_keyword] = ACTIONS(5386),
    [sym_elements_keyword] = ACTIONS(5386),
    [sym_dataitem_keyword] = ACTIONS(5386),
    [sym_column_keyword] = ACTIONS(5386),
    [sym_filter_keyword] = ACTIONS(5386),
    [sym_labels_keyword] = ACTIONS(5386),
    [sym_rendering_keyword] = ACTIONS(5386),
    [sym_requestpage_keyword] = ACTIONS(5386),
    [sym_schema_keyword] = ACTIONS(5386),
    [sym_views_keyword] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5386),
    [sym_preproc_open] = ACTIONS(5386),
    [sym_preproc_close] = ACTIONS(5386),
  },
  [STATE(4478)] = {
    [sym_boolean] = STATE(1812),
    [sym_assignment_expression] = STATE(1812),
    [sym__expression] = STATE(1812),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1812),
    [sym_multiplicative_expression] = STATE(1812),
    [sym_additive_expression] = STATE(1812),
    [sym_comparison_expression] = STATE(1812),
    [sym_logical_expression] = STATE(1812),
    [sym_ternary_expression] = STATE(1812),
    [sym_unary_expression] = STATE(1812),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1812),
    [sym_list_literal] = STATE(1812),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1812),
    [sym__literal_value] = STATE(1812),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(10354),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(10356),
    [sym_date_literal] = ACTIONS(10354),
    [sym_time_literal] = ACTIONS(10354),
    [sym_biginteger_literal] = ACTIONS(10356),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10356),
    [sym_verbatim_string] = ACTIONS(10356),
    [sym_integer] = ACTIONS(10354),
    [sym_continue_as_identifier] = ACTIONS(10356),
  },
  [STATE(4479)] = {
    [sym_boolean] = STATE(3433),
    [sym_assignment_expression] = STATE(3433),
    [sym__expression] = STATE(3433),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3433),
    [sym_multiplicative_expression] = STATE(3433),
    [sym_additive_expression] = STATE(3433),
    [sym_comparison_expression] = STATE(3433),
    [sym_logical_expression] = STATE(3433),
    [sym_ternary_expression] = STATE(3433),
    [sym_unary_expression] = STATE(3433),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3433),
    [sym_list_literal] = STATE(3433),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3433),
    [sym__literal_value] = STATE(3433),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10358),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10360),
    [sym_date_literal] = ACTIONS(10358),
    [sym_time_literal] = ACTIONS(10358),
    [sym_biginteger_literal] = ACTIONS(10360),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10360),
    [sym_verbatim_string] = ACTIONS(10360),
    [sym_integer] = ACTIONS(10358),
    [sym_continue_as_identifier] = ACTIONS(10360),
  },
  [STATE(4480)] = {
    [sym_boolean] = STATE(3434),
    [sym_assignment_expression] = STATE(3434),
    [sym__expression] = STATE(3434),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3434),
    [sym_multiplicative_expression] = STATE(3434),
    [sym_additive_expression] = STATE(3434),
    [sym_comparison_expression] = STATE(3434),
    [sym_logical_expression] = STATE(3434),
    [sym_ternary_expression] = STATE(3434),
    [sym_unary_expression] = STATE(3434),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3434),
    [sym_list_literal] = STATE(3434),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3434),
    [sym__literal_value] = STATE(3434),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10362),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10364),
    [sym_date_literal] = ACTIONS(10362),
    [sym_time_literal] = ACTIONS(10362),
    [sym_biginteger_literal] = ACTIONS(10364),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10364),
    [sym_verbatim_string] = ACTIONS(10364),
    [sym_integer] = ACTIONS(10362),
    [sym_continue_as_identifier] = ACTIONS(10364),
  },
  [STATE(4481)] = {
    [sym__body_element] = STATE(4775),
    [sym_empty_statement] = STATE(4775),
    [sym_property] = STATE(4775),
    [sym_permissions_property] = STATE(4775),
    [sym_table_relation_property] = STATE(4775),
    [sym_fields_section] = STATE(4775),
    [sym_keys_section] = STATE(4775),
    [sym_fieldgroups_section] = STATE(4775),
    [sym_enum_value_declaration] = STATE(4775),
    [sym_labels_section] = STATE(4775),
    [sym_layout_section] = STATE(4775),
    [sym_modify_modification] = STATE(4775),
    [sym_actions_section] = STATE(4775),
    [sym_views_section] = STATE(4775),
    [sym_dataset_section] = STATE(4775),
    [sym_requestpage_section] = STATE(4775),
    [sym_rendering_section] = STATE(4775),
    [sym_elements_section] = STATE(4775),
    [sym_schema_section] = STATE(4775),
    [sym_xmlport_element] = STATE(4775),
    [sym__xmlport_body_element] = STATE(4775),
    [sym_preproc_conditional_xmlport] = STATE(4775),
    [sym_xmlport_attribute] = STATE(4775),
    [sym_assembly_declaration] = STATE(4775),
    [sym_event_declaration] = STATE(4775),
    [sym_procedure] = STATE(4775),
    [sym_preproc_split_procedure] = STATE(4775),
    [sym_preproc_split_procedure_preamble] = STATE(4775),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4775),
    [sym_var_section] = STATE(4775),
    [sym_attribute_item] = STATE(4775),
    [sym_preproc_conditional] = STATE(4775),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4775),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10366),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4482)] = {
    [sym_boolean] = STATE(3435),
    [sym_assignment_expression] = STATE(3435),
    [sym__expression] = STATE(3435),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3435),
    [sym_multiplicative_expression] = STATE(3435),
    [sym_additive_expression] = STATE(3435),
    [sym_comparison_expression] = STATE(3435),
    [sym_logical_expression] = STATE(3435),
    [sym_ternary_expression] = STATE(3435),
    [sym_unary_expression] = STATE(3435),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3435),
    [sym_list_literal] = STATE(3435),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3435),
    [sym__literal_value] = STATE(3435),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10368),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10370),
    [sym_date_literal] = ACTIONS(10368),
    [sym_time_literal] = ACTIONS(10368),
    [sym_biginteger_literal] = ACTIONS(10370),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10370),
    [sym_verbatim_string] = ACTIONS(10370),
    [sym_integer] = ACTIONS(10368),
    [sym_continue_as_identifier] = ACTIONS(10370),
  },
  [STATE(4483)] = {
    [sym_preproc_conditional_controladdin] = STATE(4703),
    [sym__body_element] = STATE(4703),
    [sym_empty_statement] = STATE(4703),
    [sym_property] = STATE(4703),
    [sym_permissions_property] = STATE(4703),
    [sym_table_relation_property] = STATE(4703),
    [sym_fields_section] = STATE(4703),
    [sym_keys_section] = STATE(4703),
    [sym_fieldgroups_section] = STATE(4703),
    [sym_enum_value_declaration] = STATE(4703),
    [sym_labels_section] = STATE(4703),
    [sym_layout_section] = STATE(4703),
    [sym_modify_modification] = STATE(4703),
    [sym_actions_section] = STATE(4703),
    [sym_views_section] = STATE(4703),
    [sym_dataset_section] = STATE(4703),
    [sym_requestpage_section] = STATE(4703),
    [sym_rendering_section] = STATE(4703),
    [sym_elements_section] = STATE(4703),
    [sym_schema_section] = STATE(4703),
    [sym_assembly_declaration] = STATE(4703),
    [sym_event_declaration] = STATE(4703),
    [sym_procedure] = STATE(4703),
    [sym_preproc_split_procedure] = STATE(4703),
    [sym_preproc_split_procedure_preamble] = STATE(4703),
    [sym_interface_procedure] = STATE(4703),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4703),
    [sym_var_section] = STATE(4703),
    [sym_attribute_item] = STATE(4703),
    [sym_preproc_conditional] = STATE(4703),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(9973),
    [aux_sym_controladdin_declaration_repeat1] = STATE(4703),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4484)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6490),
    [sym_preproc_endif] = STATE(10154),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10691),
    [anon_sym_RBRACE] = ACTIONS(10372),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4485)] = {
    [sym__body_element] = STATE(4488),
    [sym_empty_statement] = STATE(4488),
    [sym_property] = STATE(4488),
    [sym_permissions_property] = STATE(4488),
    [sym_table_relation_property] = STATE(4488),
    [sym_fields_section] = STATE(4488),
    [sym_keys_section] = STATE(4488),
    [sym_fieldgroups_section] = STATE(4488),
    [sym_enum_value_declaration] = STATE(4488),
    [sym_labels_section] = STATE(4488),
    [sym_layout_section] = STATE(4488),
    [sym_modify_modification] = STATE(4488),
    [sym_actions_section] = STATE(4488),
    [sym_views_section] = STATE(4488),
    [sym_dataset_section] = STATE(4488),
    [sym_requestpage_section] = STATE(4488),
    [sym_rendering_section] = STATE(4488),
    [sym_elements_section] = STATE(4488),
    [sym_schema_section] = STATE(4488),
    [sym_xmlport_element] = STATE(4488),
    [sym__xmlport_body_element] = STATE(4488),
    [sym_preproc_conditional_xmlport] = STATE(4488),
    [sym_xmlport_attribute] = STATE(4488),
    [sym_assembly_declaration] = STATE(4488),
    [sym_event_declaration] = STATE(4488),
    [sym_procedure] = STATE(4488),
    [sym_preproc_split_procedure] = STATE(4488),
    [sym_preproc_split_procedure_preamble] = STATE(4488),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4488),
    [sym_var_section] = STATE(4488),
    [sym_attribute_item] = STATE(4488),
    [sym_preproc_conditional] = STATE(4488),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4488),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10376),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4486)] = {
    [sym_boolean] = STATE(8250),
    [sym_assignment_expression] = STATE(8250),
    [sym__expression] = STATE(8250),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8250),
    [sym_multiplicative_expression] = STATE(8250),
    [sym_additive_expression] = STATE(8250),
    [sym_comparison_expression] = STATE(8250),
    [sym_logical_expression] = STATE(8250),
    [sym_ternary_expression] = STATE(8250),
    [sym_unary_expression] = STATE(8250),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8250),
    [sym_list_literal] = STATE(8250),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8250),
    [sym__literal_value] = STATE(8250),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10382),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10392),
    [sym_date_literal] = ACTIONS(10382),
    [sym_time_literal] = ACTIONS(10382),
    [sym_biginteger_literal] = ACTIONS(10392),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10392),
    [sym_verbatim_string] = ACTIONS(10392),
    [sym_integer] = ACTIONS(10382),
    [sym_continue_as_identifier] = ACTIONS(10392),
  },
  [STATE(4487)] = {
    [sym_boolean] = STATE(8550),
    [sym_assignment_expression] = STATE(8550),
    [sym__expression] = STATE(8550),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8550),
    [sym_multiplicative_expression] = STATE(8550),
    [sym_additive_expression] = STATE(8550),
    [sym_comparison_expression] = STATE(8550),
    [sym_logical_expression] = STATE(8550),
    [sym_ternary_expression] = STATE(8550),
    [sym_unary_expression] = STATE(8550),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8550),
    [sym_list_literal] = STATE(8550),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8550),
    [sym__literal_value] = STATE(8550),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10396),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10398),
    [sym_date_literal] = ACTIONS(10396),
    [sym_time_literal] = ACTIONS(10396),
    [sym_biginteger_literal] = ACTIONS(10398),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10398),
    [sym_verbatim_string] = ACTIONS(10398),
    [sym_integer] = ACTIONS(10396),
    [sym_continue_as_identifier] = ACTIONS(10398),
  },
  [STATE(4488)] = {
    [sym__body_element] = STATE(4775),
    [sym_empty_statement] = STATE(4775),
    [sym_property] = STATE(4775),
    [sym_permissions_property] = STATE(4775),
    [sym_table_relation_property] = STATE(4775),
    [sym_fields_section] = STATE(4775),
    [sym_keys_section] = STATE(4775),
    [sym_fieldgroups_section] = STATE(4775),
    [sym_enum_value_declaration] = STATE(4775),
    [sym_labels_section] = STATE(4775),
    [sym_layout_section] = STATE(4775),
    [sym_modify_modification] = STATE(4775),
    [sym_actions_section] = STATE(4775),
    [sym_views_section] = STATE(4775),
    [sym_dataset_section] = STATE(4775),
    [sym_requestpage_section] = STATE(4775),
    [sym_rendering_section] = STATE(4775),
    [sym_elements_section] = STATE(4775),
    [sym_schema_section] = STATE(4775),
    [sym_xmlport_element] = STATE(4775),
    [sym__xmlport_body_element] = STATE(4775),
    [sym_preproc_conditional_xmlport] = STATE(4775),
    [sym_xmlport_attribute] = STATE(4775),
    [sym_assembly_declaration] = STATE(4775),
    [sym_event_declaration] = STATE(4775),
    [sym_procedure] = STATE(4775),
    [sym_preproc_split_procedure] = STATE(4775),
    [sym_preproc_split_procedure_preamble] = STATE(4775),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4775),
    [sym_var_section] = STATE(4775),
    [sym_attribute_item] = STATE(4775),
    [sym_preproc_conditional] = STATE(4775),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4775),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10400),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4489)] = {
    [sym_boolean] = STATE(3437),
    [sym_assignment_expression] = STATE(3437),
    [sym__expression] = STATE(3437),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3437),
    [sym_multiplicative_expression] = STATE(3437),
    [sym_additive_expression] = STATE(3437),
    [sym_comparison_expression] = STATE(3437),
    [sym_logical_expression] = STATE(3437),
    [sym_ternary_expression] = STATE(3437),
    [sym_unary_expression] = STATE(3437),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3437),
    [sym_list_literal] = STATE(3437),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3437),
    [sym__literal_value] = STATE(3437),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10402),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10404),
    [sym_date_literal] = ACTIONS(10402),
    [sym_time_literal] = ACTIONS(10402),
    [sym_biginteger_literal] = ACTIONS(10404),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10404),
    [sym_verbatim_string] = ACTIONS(10404),
    [sym_integer] = ACTIONS(10402),
    [sym_continue_as_identifier] = ACTIONS(10404),
  },
  [STATE(4490)] = {
    [sym_boolean] = STATE(3439),
    [sym_assignment_expression] = STATE(3439),
    [sym__expression] = STATE(3439),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3439),
    [sym_multiplicative_expression] = STATE(3439),
    [sym_additive_expression] = STATE(3439),
    [sym_comparison_expression] = STATE(3439),
    [sym_logical_expression] = STATE(3439),
    [sym_ternary_expression] = STATE(3439),
    [sym_unary_expression] = STATE(3439),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3439),
    [sym_list_literal] = STATE(3439),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3439),
    [sym__literal_value] = STATE(3439),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10406),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10408),
    [sym_date_literal] = ACTIONS(10406),
    [sym_time_literal] = ACTIONS(10406),
    [sym_biginteger_literal] = ACTIONS(10408),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10408),
    [sym_verbatim_string] = ACTIONS(10408),
    [sym_integer] = ACTIONS(10406),
    [sym_continue_as_identifier] = ACTIONS(10408),
  },
  [STATE(4491)] = {
    [sym_boolean] = STATE(3440),
    [sym_assignment_expression] = STATE(3440),
    [sym__expression] = STATE(3440),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3440),
    [sym_multiplicative_expression] = STATE(3440),
    [sym_additive_expression] = STATE(3440),
    [sym_comparison_expression] = STATE(3440),
    [sym_logical_expression] = STATE(3440),
    [sym_ternary_expression] = STATE(3440),
    [sym_unary_expression] = STATE(3440),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3440),
    [sym_list_literal] = STATE(3440),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3440),
    [sym__literal_value] = STATE(3440),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10410),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10412),
    [sym_date_literal] = ACTIONS(10410),
    [sym_time_literal] = ACTIONS(10410),
    [sym_biginteger_literal] = ACTIONS(10412),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10412),
    [sym_verbatim_string] = ACTIONS(10412),
    [sym_integer] = ACTIONS(10410),
    [sym_continue_as_identifier] = ACTIONS(10412),
  },
  [STATE(4492)] = {
    [sym_boolean] = STATE(3441),
    [sym_assignment_expression] = STATE(3441),
    [sym__expression] = STATE(3441),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3441),
    [sym_multiplicative_expression] = STATE(3441),
    [sym_additive_expression] = STATE(3441),
    [sym_comparison_expression] = STATE(3441),
    [sym_logical_expression] = STATE(3441),
    [sym_ternary_expression] = STATE(3441),
    [sym_unary_expression] = STATE(3441),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3441),
    [sym_list_literal] = STATE(3441),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3441),
    [sym__literal_value] = STATE(3441),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10414),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10416),
    [sym_date_literal] = ACTIONS(10414),
    [sym_time_literal] = ACTIONS(10414),
    [sym_biginteger_literal] = ACTIONS(10416),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10416),
    [sym_verbatim_string] = ACTIONS(10416),
    [sym_integer] = ACTIONS(10414),
    [sym_continue_as_identifier] = ACTIONS(10416),
  },
  [STATE(4493)] = {
    [sym_boolean] = STATE(3442),
    [sym_assignment_expression] = STATE(3442),
    [sym__expression] = STATE(3442),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3442),
    [sym_multiplicative_expression] = STATE(3442),
    [sym_additive_expression] = STATE(3442),
    [sym_comparison_expression] = STATE(3442),
    [sym_logical_expression] = STATE(3442),
    [sym_ternary_expression] = STATE(3442),
    [sym_unary_expression] = STATE(3442),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3442),
    [sym_list_literal] = STATE(3442),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3442),
    [sym__literal_value] = STATE(3442),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10418),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10420),
    [sym_date_literal] = ACTIONS(10418),
    [sym_time_literal] = ACTIONS(10418),
    [sym_biginteger_literal] = ACTIONS(10420),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10420),
    [sym_verbatim_string] = ACTIONS(10420),
    [sym_integer] = ACTIONS(10418),
    [sym_continue_as_identifier] = ACTIONS(10420),
  },
  [STATE(4494)] = {
    [sym_boolean] = STATE(3443),
    [sym_assignment_expression] = STATE(3443),
    [sym__expression] = STATE(3443),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3443),
    [sym_multiplicative_expression] = STATE(3443),
    [sym_additive_expression] = STATE(3443),
    [sym_comparison_expression] = STATE(3443),
    [sym_logical_expression] = STATE(3443),
    [sym_ternary_expression] = STATE(3443),
    [sym_unary_expression] = STATE(3443),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3443),
    [sym_list_literal] = STATE(3443),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3443),
    [sym__literal_value] = STATE(3443),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10422),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10424),
    [sym_date_literal] = ACTIONS(10422),
    [sym_time_literal] = ACTIONS(10422),
    [sym_biginteger_literal] = ACTIONS(10424),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10424),
    [sym_verbatim_string] = ACTIONS(10424),
    [sym_integer] = ACTIONS(10422),
    [sym_continue_as_identifier] = ACTIONS(10424),
  },
  [STATE(4495)] = {
    [sym_boolean] = STATE(3444),
    [sym_assignment_expression] = STATE(3444),
    [sym__expression] = STATE(3444),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3444),
    [sym_multiplicative_expression] = STATE(3444),
    [sym_additive_expression] = STATE(3444),
    [sym_comparison_expression] = STATE(3444),
    [sym_logical_expression] = STATE(3444),
    [sym_ternary_expression] = STATE(3444),
    [sym_unary_expression] = STATE(3444),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3444),
    [sym_list_literal] = STATE(3444),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3444),
    [sym__literal_value] = STATE(3444),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10426),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10428),
    [sym_date_literal] = ACTIONS(10426),
    [sym_time_literal] = ACTIONS(10426),
    [sym_biginteger_literal] = ACTIONS(10428),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10428),
    [sym_verbatim_string] = ACTIONS(10428),
    [sym_integer] = ACTIONS(10426),
    [sym_continue_as_identifier] = ACTIONS(10428),
  },
  [STATE(4496)] = {
    [sym_boolean] = STATE(3445),
    [sym_assignment_expression] = STATE(3445),
    [sym__expression] = STATE(3445),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3445),
    [sym_multiplicative_expression] = STATE(3445),
    [sym_additive_expression] = STATE(3445),
    [sym_comparison_expression] = STATE(3445),
    [sym_logical_expression] = STATE(3445),
    [sym_ternary_expression] = STATE(3445),
    [sym_unary_expression] = STATE(3445),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3445),
    [sym_list_literal] = STATE(3445),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3445),
    [sym__literal_value] = STATE(3445),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10430),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10432),
    [sym_date_literal] = ACTIONS(10430),
    [sym_time_literal] = ACTIONS(10430),
    [sym_biginteger_literal] = ACTIONS(10432),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10432),
    [sym_verbatim_string] = ACTIONS(10432),
    [sym_integer] = ACTIONS(10430),
    [sym_continue_as_identifier] = ACTIONS(10432),
  },
  [STATE(4497)] = {
    [sym_boolean] = STATE(3446),
    [sym_assignment_expression] = STATE(3446),
    [sym__expression] = STATE(3446),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3446),
    [sym_multiplicative_expression] = STATE(3446),
    [sym_additive_expression] = STATE(3446),
    [sym_comparison_expression] = STATE(3446),
    [sym_logical_expression] = STATE(3446),
    [sym_ternary_expression] = STATE(3446),
    [sym_unary_expression] = STATE(3446),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3446),
    [sym_list_literal] = STATE(3446),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3446),
    [sym__literal_value] = STATE(3446),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10434),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10436),
    [sym_date_literal] = ACTIONS(10434),
    [sym_time_literal] = ACTIONS(10434),
    [sym_biginteger_literal] = ACTIONS(10436),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10436),
    [sym_verbatim_string] = ACTIONS(10436),
    [sym_integer] = ACTIONS(10434),
    [sym_continue_as_identifier] = ACTIONS(10436),
  },
  [STATE(4498)] = {
    [sym_boolean] = STATE(3447),
    [sym_assignment_expression] = STATE(3447),
    [sym__expression] = STATE(3447),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3447),
    [sym_multiplicative_expression] = STATE(3447),
    [sym_additive_expression] = STATE(3447),
    [sym_comparison_expression] = STATE(3447),
    [sym_logical_expression] = STATE(3447),
    [sym_ternary_expression] = STATE(3447),
    [sym_unary_expression] = STATE(3447),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3447),
    [sym_list_literal] = STATE(3447),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3447),
    [sym__literal_value] = STATE(3447),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10438),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10440),
    [sym_date_literal] = ACTIONS(10438),
    [sym_time_literal] = ACTIONS(10438),
    [sym_biginteger_literal] = ACTIONS(10440),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10440),
    [sym_verbatim_string] = ACTIONS(10440),
    [sym_integer] = ACTIONS(10438),
    [sym_continue_as_identifier] = ACTIONS(10440),
  },
  [STATE(4499)] = {
    [sym_boolean] = STATE(3468),
    [sym_assignment_expression] = STATE(3468),
    [sym__expression] = STATE(3468),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3468),
    [sym_multiplicative_expression] = STATE(3468),
    [sym_additive_expression] = STATE(3468),
    [sym_comparison_expression] = STATE(3468),
    [sym_logical_expression] = STATE(3468),
    [sym_ternary_expression] = STATE(3468),
    [sym_unary_expression] = STATE(3468),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3468),
    [sym_list_literal] = STATE(3468),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3468),
    [sym__literal_value] = STATE(3468),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10442),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10444),
    [sym_date_literal] = ACTIONS(10442),
    [sym_time_literal] = ACTIONS(10442),
    [sym_biginteger_literal] = ACTIONS(10444),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10444),
    [sym_verbatim_string] = ACTIONS(10444),
    [sym_integer] = ACTIONS(10442),
    [sym_continue_as_identifier] = ACTIONS(10444),
  },
  [STATE(4500)] = {
    [sym_boolean] = STATE(3449),
    [sym_assignment_expression] = STATE(3449),
    [sym__expression] = STATE(3449),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3449),
    [sym_multiplicative_expression] = STATE(3449),
    [sym_additive_expression] = STATE(3449),
    [sym_comparison_expression] = STATE(3449),
    [sym_logical_expression] = STATE(3449),
    [sym_ternary_expression] = STATE(3449),
    [sym_unary_expression] = STATE(3449),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3449),
    [sym_list_literal] = STATE(3449),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3449),
    [sym__literal_value] = STATE(3449),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10446),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10448),
    [sym_date_literal] = ACTIONS(10446),
    [sym_time_literal] = ACTIONS(10446),
    [sym_biginteger_literal] = ACTIONS(10448),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10448),
    [sym_verbatim_string] = ACTIONS(10448),
    [sym_integer] = ACTIONS(10446),
    [sym_continue_as_identifier] = ACTIONS(10448),
  },
  [STATE(4501)] = {
    [sym_boolean] = STATE(3450),
    [sym_assignment_expression] = STATE(3450),
    [sym__expression] = STATE(3450),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3450),
    [sym_multiplicative_expression] = STATE(3450),
    [sym_additive_expression] = STATE(3450),
    [sym_comparison_expression] = STATE(3450),
    [sym_logical_expression] = STATE(3450),
    [sym_ternary_expression] = STATE(3450),
    [sym_unary_expression] = STATE(3450),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3450),
    [sym_list_literal] = STATE(3450),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3450),
    [sym__literal_value] = STATE(3450),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10450),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10452),
    [sym_date_literal] = ACTIONS(10450),
    [sym_time_literal] = ACTIONS(10450),
    [sym_biginteger_literal] = ACTIONS(10452),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10452),
    [sym_verbatim_string] = ACTIONS(10452),
    [sym_integer] = ACTIONS(10450),
    [sym_continue_as_identifier] = ACTIONS(10452),
  },
  [STATE(4502)] = {
    [sym_boolean] = STATE(3451),
    [sym_assignment_expression] = STATE(3451),
    [sym__expression] = STATE(3451),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3451),
    [sym_multiplicative_expression] = STATE(3451),
    [sym_additive_expression] = STATE(3451),
    [sym_comparison_expression] = STATE(3451),
    [sym_logical_expression] = STATE(3451),
    [sym_ternary_expression] = STATE(3451),
    [sym_unary_expression] = STATE(3451),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3451),
    [sym_list_literal] = STATE(3451),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3451),
    [sym__literal_value] = STATE(3451),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10454),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10456),
    [sym_date_literal] = ACTIONS(10454),
    [sym_time_literal] = ACTIONS(10454),
    [sym_biginteger_literal] = ACTIONS(10456),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10456),
    [sym_verbatim_string] = ACTIONS(10456),
    [sym_integer] = ACTIONS(10454),
    [sym_continue_as_identifier] = ACTIONS(10456),
  },
  [STATE(4503)] = {
    [sym_boolean] = STATE(3452),
    [sym_assignment_expression] = STATE(3452),
    [sym__expression] = STATE(3452),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3452),
    [sym_multiplicative_expression] = STATE(3452),
    [sym_additive_expression] = STATE(3452),
    [sym_comparison_expression] = STATE(3452),
    [sym_logical_expression] = STATE(3452),
    [sym_ternary_expression] = STATE(3452),
    [sym_unary_expression] = STATE(3452),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3452),
    [sym_list_literal] = STATE(3452),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3452),
    [sym__literal_value] = STATE(3452),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10458),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10460),
    [sym_date_literal] = ACTIONS(10458),
    [sym_time_literal] = ACTIONS(10458),
    [sym_biginteger_literal] = ACTIONS(10460),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10460),
    [sym_verbatim_string] = ACTIONS(10460),
    [sym_integer] = ACTIONS(10458),
    [sym_continue_as_identifier] = ACTIONS(10460),
  },
  [STATE(4504)] = {
    [sym_boolean] = STATE(3453),
    [sym_assignment_expression] = STATE(3453),
    [sym__expression] = STATE(3453),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3453),
    [sym_multiplicative_expression] = STATE(3453),
    [sym_additive_expression] = STATE(3453),
    [sym_comparison_expression] = STATE(3453),
    [sym_logical_expression] = STATE(3453),
    [sym_ternary_expression] = STATE(3453),
    [sym_unary_expression] = STATE(3453),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3453),
    [sym_list_literal] = STATE(3453),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3453),
    [sym__literal_value] = STATE(3453),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10462),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10464),
    [sym_date_literal] = ACTIONS(10462),
    [sym_time_literal] = ACTIONS(10462),
    [sym_biginteger_literal] = ACTIONS(10464),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10464),
    [sym_verbatim_string] = ACTIONS(10464),
    [sym_integer] = ACTIONS(10462),
    [sym_continue_as_identifier] = ACTIONS(10464),
  },
  [STATE(4505)] = {
    [sym_boolean] = STATE(3454),
    [sym_assignment_expression] = STATE(3454),
    [sym__expression] = STATE(3454),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3454),
    [sym_multiplicative_expression] = STATE(3454),
    [sym_additive_expression] = STATE(3454),
    [sym_comparison_expression] = STATE(3454),
    [sym_logical_expression] = STATE(3454),
    [sym_ternary_expression] = STATE(3454),
    [sym_unary_expression] = STATE(3454),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3454),
    [sym_list_literal] = STATE(3454),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3454),
    [sym__literal_value] = STATE(3454),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10466),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10468),
    [sym_date_literal] = ACTIONS(10466),
    [sym_time_literal] = ACTIONS(10466),
    [sym_biginteger_literal] = ACTIONS(10468),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10468),
    [sym_verbatim_string] = ACTIONS(10468),
    [sym_integer] = ACTIONS(10466),
    [sym_continue_as_identifier] = ACTIONS(10468),
  },
  [STATE(4506)] = {
    [sym_boolean] = STATE(3455),
    [sym_assignment_expression] = STATE(3455),
    [sym__expression] = STATE(3455),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3455),
    [sym_multiplicative_expression] = STATE(3455),
    [sym_additive_expression] = STATE(3455),
    [sym_comparison_expression] = STATE(3455),
    [sym_logical_expression] = STATE(3455),
    [sym_ternary_expression] = STATE(3455),
    [sym_unary_expression] = STATE(3455),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3455),
    [sym_list_literal] = STATE(3455),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3455),
    [sym__literal_value] = STATE(3455),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10470),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10472),
    [sym_date_literal] = ACTIONS(10470),
    [sym_time_literal] = ACTIONS(10470),
    [sym_biginteger_literal] = ACTIONS(10472),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10472),
    [sym_verbatim_string] = ACTIONS(10472),
    [sym_integer] = ACTIONS(10470),
    [sym_continue_as_identifier] = ACTIONS(10472),
  },
  [STATE(4507)] = {
    [sym_preproc_conditional_controladdin] = STATE(4438),
    [sym__body_element] = STATE(4438),
    [sym_empty_statement] = STATE(4438),
    [sym_property] = STATE(4438),
    [sym_permissions_property] = STATE(4438),
    [sym_table_relation_property] = STATE(4438),
    [sym_fields_section] = STATE(4438),
    [sym_keys_section] = STATE(4438),
    [sym_fieldgroups_section] = STATE(4438),
    [sym_enum_value_declaration] = STATE(4438),
    [sym_labels_section] = STATE(4438),
    [sym_layout_section] = STATE(4438),
    [sym_modify_modification] = STATE(4438),
    [sym_actions_section] = STATE(4438),
    [sym_views_section] = STATE(4438),
    [sym_dataset_section] = STATE(4438),
    [sym_requestpage_section] = STATE(4438),
    [sym_rendering_section] = STATE(4438),
    [sym_elements_section] = STATE(4438),
    [sym_schema_section] = STATE(4438),
    [sym_assembly_declaration] = STATE(4438),
    [sym_event_declaration] = STATE(4438),
    [sym_procedure] = STATE(4438),
    [sym_preproc_split_procedure] = STATE(4438),
    [sym_preproc_split_procedure_preamble] = STATE(4438),
    [sym_interface_procedure] = STATE(4438),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4438),
    [sym_var_section] = STATE(4438),
    [sym_attribute_item] = STATE(4438),
    [sym_preproc_conditional] = STATE(4438),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(9980),
    [aux_sym_controladdin_declaration_repeat1] = STATE(4438),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4508)] = {
    [sym_boolean] = STATE(1999),
    [sym_assignment_expression] = STATE(1999),
    [sym__expression] = STATE(1999),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1999),
    [sym_multiplicative_expression] = STATE(1999),
    [sym_additive_expression] = STATE(1999),
    [sym_comparison_expression] = STATE(1999),
    [sym_logical_expression] = STATE(1999),
    [sym_ternary_expression] = STATE(1999),
    [sym_unary_expression] = STATE(1999),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1999),
    [sym_list_literal] = STATE(1999),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1999),
    [sym__literal_value] = STATE(1999),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(10474),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(10476),
    [sym_date_literal] = ACTIONS(10474),
    [sym_time_literal] = ACTIONS(10474),
    [sym_biginteger_literal] = ACTIONS(10476),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10476),
    [sym_verbatim_string] = ACTIONS(10476),
    [sym_integer] = ACTIONS(10474),
    [sym_continue_as_identifier] = ACTIONS(10476),
  },
  [STATE(4509)] = {
    [sym_boolean] = STATE(8663),
    [sym_assignment_expression] = STATE(8663),
    [sym__expression] = STATE(8663),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8663),
    [sym_multiplicative_expression] = STATE(8663),
    [sym_additive_expression] = STATE(8663),
    [sym_comparison_expression] = STATE(8663),
    [sym_logical_expression] = STATE(8663),
    [sym_ternary_expression] = STATE(8663),
    [sym_unary_expression] = STATE(8663),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8663),
    [sym_list_literal] = STATE(8663),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8663),
    [sym__literal_value] = STATE(8663),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(8083),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(8087),
    [sym_date_literal] = ACTIONS(8083),
    [sym_time_literal] = ACTIONS(8083),
    [sym_biginteger_literal] = ACTIONS(8087),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(8087),
    [sym_verbatim_string] = ACTIONS(8087),
    [sym_integer] = ACTIONS(8083),
    [sym_continue_as_identifier] = ACTIONS(8087),
  },
  [STATE(4510)] = {
    [sym_boolean] = STATE(2265),
    [sym_assignment_expression] = STATE(2265),
    [sym__expression] = STATE(2265),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2265),
    [sym_multiplicative_expression] = STATE(2265),
    [sym_additive_expression] = STATE(2265),
    [sym_comparison_expression] = STATE(2265),
    [sym_logical_expression] = STATE(2265),
    [sym_ternary_expression] = STATE(2265),
    [sym_unary_expression] = STATE(2265),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2265),
    [sym_list_literal] = STATE(2265),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2265),
    [sym__literal_value] = STATE(2265),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10478),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10480),
    [sym_date_literal] = ACTIONS(10478),
    [sym_time_literal] = ACTIONS(10478),
    [sym_biginteger_literal] = ACTIONS(10480),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10480),
    [sym_verbatim_string] = ACTIONS(10480),
    [sym_integer] = ACTIONS(10478),
    [sym_continue_as_identifier] = ACTIONS(10480),
  },
  [STATE(4511)] = {
    [sym_boolean] = STATE(2285),
    [sym_assignment_expression] = STATE(2285),
    [sym__expression] = STATE(2285),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2285),
    [sym_multiplicative_expression] = STATE(2285),
    [sym_additive_expression] = STATE(2285),
    [sym_comparison_expression] = STATE(2285),
    [sym_logical_expression] = STATE(2285),
    [sym_ternary_expression] = STATE(2285),
    [sym_unary_expression] = STATE(2285),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2285),
    [sym_list_literal] = STATE(2285),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2285),
    [sym__literal_value] = STATE(2285),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10482),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10484),
    [sym_date_literal] = ACTIONS(10482),
    [sym_time_literal] = ACTIONS(10482),
    [sym_biginteger_literal] = ACTIONS(10484),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10484),
    [sym_verbatim_string] = ACTIONS(10484),
    [sym_integer] = ACTIONS(10482),
    [sym_continue_as_identifier] = ACTIONS(10484),
  },
  [STATE(4512)] = {
    [sym_boolean] = STATE(2741),
    [sym_assignment_expression] = STATE(2741),
    [sym__expression] = STATE(2741),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2741),
    [sym_multiplicative_expression] = STATE(2741),
    [sym_additive_expression] = STATE(2741),
    [sym_comparison_expression] = STATE(2741),
    [sym_logical_expression] = STATE(2741),
    [sym_ternary_expression] = STATE(2741),
    [sym_unary_expression] = STATE(2741),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2741),
    [sym_list_literal] = STATE(2741),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2741),
    [sym__literal_value] = STATE(2741),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10488),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10492),
    [sym_date_literal] = ACTIONS(10488),
    [sym_time_literal] = ACTIONS(10488),
    [sym_biginteger_literal] = ACTIONS(10492),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10492),
    [sym_verbatim_string] = ACTIONS(10492),
    [sym_integer] = ACTIONS(10488),
    [sym_continue_as_identifier] = ACTIONS(10492),
  },
  [STATE(4513)] = {
    [sym_boolean] = STATE(2744),
    [sym_assignment_expression] = STATE(2744),
    [sym__expression] = STATE(2744),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2744),
    [sym_multiplicative_expression] = STATE(2744),
    [sym_additive_expression] = STATE(2744),
    [sym_comparison_expression] = STATE(2744),
    [sym_logical_expression] = STATE(2744),
    [sym_ternary_expression] = STATE(2744),
    [sym_unary_expression] = STATE(2744),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2744),
    [sym_list_literal] = STATE(2744),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2744),
    [sym__literal_value] = STATE(2744),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10496),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10498),
    [sym_date_literal] = ACTIONS(10496),
    [sym_time_literal] = ACTIONS(10496),
    [sym_biginteger_literal] = ACTIONS(10498),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10498),
    [sym_verbatim_string] = ACTIONS(10498),
    [sym_integer] = ACTIONS(10496),
    [sym_continue_as_identifier] = ACTIONS(10498),
  },
  [STATE(4514)] = {
    [sym_boolean] = STATE(2745),
    [sym_assignment_expression] = STATE(2745),
    [sym__expression] = STATE(2745),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2745),
    [sym_multiplicative_expression] = STATE(2745),
    [sym_additive_expression] = STATE(2745),
    [sym_comparison_expression] = STATE(2745),
    [sym_logical_expression] = STATE(2745),
    [sym_ternary_expression] = STATE(2745),
    [sym_unary_expression] = STATE(2745),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2745),
    [sym_list_literal] = STATE(2745),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2745),
    [sym__literal_value] = STATE(2745),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10500),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10502),
    [sym_date_literal] = ACTIONS(10500),
    [sym_time_literal] = ACTIONS(10500),
    [sym_biginteger_literal] = ACTIONS(10502),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10502),
    [sym_verbatim_string] = ACTIONS(10502),
    [sym_integer] = ACTIONS(10500),
    [sym_continue_as_identifier] = ACTIONS(10502),
  },
  [STATE(4515)] = {
    [sym_boolean] = STATE(2747),
    [sym_assignment_expression] = STATE(2747),
    [sym__expression] = STATE(2747),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2747),
    [sym_multiplicative_expression] = STATE(2747),
    [sym_additive_expression] = STATE(2747),
    [sym_comparison_expression] = STATE(2747),
    [sym_logical_expression] = STATE(2747),
    [sym_ternary_expression] = STATE(2747),
    [sym_unary_expression] = STATE(2747),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2747),
    [sym_list_literal] = STATE(2747),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2747),
    [sym__literal_value] = STATE(2747),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10504),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10506),
    [sym_date_literal] = ACTIONS(10504),
    [sym_time_literal] = ACTIONS(10504),
    [sym_biginteger_literal] = ACTIONS(10506),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10506),
    [sym_verbatim_string] = ACTIONS(10506),
    [sym_integer] = ACTIONS(10504),
    [sym_continue_as_identifier] = ACTIONS(10506),
  },
  [STATE(4516)] = {
    [sym_boolean] = STATE(2749),
    [sym_assignment_expression] = STATE(2749),
    [sym__expression] = STATE(2749),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2749),
    [sym_multiplicative_expression] = STATE(2749),
    [sym_additive_expression] = STATE(2749),
    [sym_comparison_expression] = STATE(2749),
    [sym_logical_expression] = STATE(2749),
    [sym_ternary_expression] = STATE(2749),
    [sym_unary_expression] = STATE(2749),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2749),
    [sym_list_literal] = STATE(2749),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2749),
    [sym__literal_value] = STATE(2749),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10508),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10510),
    [sym_date_literal] = ACTIONS(10508),
    [sym_time_literal] = ACTIONS(10508),
    [sym_biginteger_literal] = ACTIONS(10510),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10510),
    [sym_verbatim_string] = ACTIONS(10510),
    [sym_integer] = ACTIONS(10508),
    [sym_continue_as_identifier] = ACTIONS(10510),
  },
  [STATE(4517)] = {
    [sym_boolean] = STATE(2750),
    [sym_assignment_expression] = STATE(2750),
    [sym__expression] = STATE(2750),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2750),
    [sym_multiplicative_expression] = STATE(2750),
    [sym_additive_expression] = STATE(2750),
    [sym_comparison_expression] = STATE(2750),
    [sym_logical_expression] = STATE(2750),
    [sym_ternary_expression] = STATE(2750),
    [sym_unary_expression] = STATE(2750),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2750),
    [sym_list_literal] = STATE(2750),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2750),
    [sym__literal_value] = STATE(2750),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10512),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10514),
    [sym_date_literal] = ACTIONS(10512),
    [sym_time_literal] = ACTIONS(10512),
    [sym_biginteger_literal] = ACTIONS(10514),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10514),
    [sym_verbatim_string] = ACTIONS(10514),
    [sym_integer] = ACTIONS(10512),
    [sym_continue_as_identifier] = ACTIONS(10514),
  },
  [STATE(4518)] = {
    [sym_boolean] = STATE(2752),
    [sym_assignment_expression] = STATE(2752),
    [sym__expression] = STATE(2752),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2752),
    [sym_multiplicative_expression] = STATE(2752),
    [sym_additive_expression] = STATE(2752),
    [sym_comparison_expression] = STATE(2752),
    [sym_logical_expression] = STATE(2752),
    [sym_ternary_expression] = STATE(2752),
    [sym_unary_expression] = STATE(2752),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2752),
    [sym_list_literal] = STATE(2752),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2752),
    [sym__literal_value] = STATE(2752),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10516),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10518),
    [sym_date_literal] = ACTIONS(10516),
    [sym_time_literal] = ACTIONS(10516),
    [sym_biginteger_literal] = ACTIONS(10518),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10518),
    [sym_verbatim_string] = ACTIONS(10518),
    [sym_integer] = ACTIONS(10516),
    [sym_continue_as_identifier] = ACTIONS(10518),
  },
  [STATE(4519)] = {
    [sym_boolean] = STATE(2754),
    [sym_assignment_expression] = STATE(2754),
    [sym__expression] = STATE(2754),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2754),
    [sym_multiplicative_expression] = STATE(2754),
    [sym_additive_expression] = STATE(2754),
    [sym_comparison_expression] = STATE(2754),
    [sym_logical_expression] = STATE(2754),
    [sym_ternary_expression] = STATE(2754),
    [sym_unary_expression] = STATE(2754),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2754),
    [sym_list_literal] = STATE(2754),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2754),
    [sym__literal_value] = STATE(2754),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10520),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10522),
    [sym_date_literal] = ACTIONS(10520),
    [sym_time_literal] = ACTIONS(10520),
    [sym_biginteger_literal] = ACTIONS(10522),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10522),
    [sym_verbatim_string] = ACTIONS(10522),
    [sym_integer] = ACTIONS(10520),
    [sym_continue_as_identifier] = ACTIONS(10522),
  },
  [STATE(4520)] = {
    [sym_boolean] = STATE(2755),
    [sym_assignment_expression] = STATE(2755),
    [sym__expression] = STATE(2755),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2755),
    [sym_multiplicative_expression] = STATE(2755),
    [sym_additive_expression] = STATE(2755),
    [sym_comparison_expression] = STATE(2755),
    [sym_logical_expression] = STATE(2755),
    [sym_ternary_expression] = STATE(2755),
    [sym_unary_expression] = STATE(2755),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2755),
    [sym_list_literal] = STATE(2755),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2755),
    [sym__literal_value] = STATE(2755),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10524),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10526),
    [sym_date_literal] = ACTIONS(10524),
    [sym_time_literal] = ACTIONS(10524),
    [sym_biginteger_literal] = ACTIONS(10526),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10526),
    [sym_verbatim_string] = ACTIONS(10526),
    [sym_integer] = ACTIONS(10524),
    [sym_continue_as_identifier] = ACTIONS(10526),
  },
  [STATE(4521)] = {
    [sym_boolean] = STATE(2756),
    [sym_assignment_expression] = STATE(2756),
    [sym__expression] = STATE(2756),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2756),
    [sym_multiplicative_expression] = STATE(2756),
    [sym_additive_expression] = STATE(2756),
    [sym_comparison_expression] = STATE(2756),
    [sym_logical_expression] = STATE(2756),
    [sym_ternary_expression] = STATE(2756),
    [sym_unary_expression] = STATE(2756),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2756),
    [sym_list_literal] = STATE(2756),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2756),
    [sym__literal_value] = STATE(2756),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10528),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10530),
    [sym_date_literal] = ACTIONS(10528),
    [sym_time_literal] = ACTIONS(10528),
    [sym_biginteger_literal] = ACTIONS(10530),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10530),
    [sym_verbatim_string] = ACTIONS(10530),
    [sym_integer] = ACTIONS(10528),
    [sym_continue_as_identifier] = ACTIONS(10530),
  },
  [STATE(4522)] = {
    [sym_boolean] = STATE(2757),
    [sym_assignment_expression] = STATE(2757),
    [sym__expression] = STATE(2757),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2757),
    [sym_multiplicative_expression] = STATE(2757),
    [sym_additive_expression] = STATE(2757),
    [sym_comparison_expression] = STATE(2757),
    [sym_logical_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_list_literal] = STATE(2757),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2757),
    [sym__literal_value] = STATE(2757),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10532),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10534),
    [sym_date_literal] = ACTIONS(10532),
    [sym_time_literal] = ACTIONS(10532),
    [sym_biginteger_literal] = ACTIONS(10534),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10534),
    [sym_verbatim_string] = ACTIONS(10534),
    [sym_integer] = ACTIONS(10532),
    [sym_continue_as_identifier] = ACTIONS(10534),
  },
  [STATE(4523)] = {
    [sym_boolean] = STATE(2758),
    [sym_assignment_expression] = STATE(2758),
    [sym__expression] = STATE(2758),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2758),
    [sym_multiplicative_expression] = STATE(2758),
    [sym_additive_expression] = STATE(2758),
    [sym_comparison_expression] = STATE(2758),
    [sym_logical_expression] = STATE(2758),
    [sym_ternary_expression] = STATE(2758),
    [sym_unary_expression] = STATE(2758),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2758),
    [sym_list_literal] = STATE(2758),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2758),
    [sym__literal_value] = STATE(2758),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10536),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10538),
    [sym_date_literal] = ACTIONS(10536),
    [sym_time_literal] = ACTIONS(10536),
    [sym_biginteger_literal] = ACTIONS(10538),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10538),
    [sym_verbatim_string] = ACTIONS(10538),
    [sym_integer] = ACTIONS(10536),
    [sym_continue_as_identifier] = ACTIONS(10538),
  },
  [STATE(4524)] = {
    [sym_boolean] = STATE(2737),
    [sym_assignment_expression] = STATE(2737),
    [sym__expression] = STATE(2737),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2737),
    [sym_multiplicative_expression] = STATE(2737),
    [sym_additive_expression] = STATE(2737),
    [sym_comparison_expression] = STATE(2737),
    [sym_logical_expression] = STATE(2737),
    [sym_ternary_expression] = STATE(2737),
    [sym_unary_expression] = STATE(2737),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2737),
    [sym_list_literal] = STATE(2737),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2737),
    [sym__literal_value] = STATE(2737),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10540),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10542),
    [sym_date_literal] = ACTIONS(10540),
    [sym_time_literal] = ACTIONS(10540),
    [sym_biginteger_literal] = ACTIONS(10542),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10542),
    [sym_verbatim_string] = ACTIONS(10542),
    [sym_integer] = ACTIONS(10540),
    [sym_continue_as_identifier] = ACTIONS(10542),
  },
  [STATE(4525)] = {
    [sym_boolean] = STATE(2728),
    [sym_assignment_expression] = STATE(2728),
    [sym__expression] = STATE(2728),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2728),
    [sym_multiplicative_expression] = STATE(2728),
    [sym_additive_expression] = STATE(2728),
    [sym_comparison_expression] = STATE(2728),
    [sym_logical_expression] = STATE(2728),
    [sym_ternary_expression] = STATE(2728),
    [sym_unary_expression] = STATE(2728),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2728),
    [sym_list_literal] = STATE(2728),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2728),
    [sym__literal_value] = STATE(2728),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10544),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10546),
    [sym_date_literal] = ACTIONS(10544),
    [sym_time_literal] = ACTIONS(10544),
    [sym_biginteger_literal] = ACTIONS(10546),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10546),
    [sym_verbatim_string] = ACTIONS(10546),
    [sym_integer] = ACTIONS(10544),
    [sym_continue_as_identifier] = ACTIONS(10546),
  },
  [STATE(4526)] = {
    [sym_boolean] = STATE(2734),
    [sym_assignment_expression] = STATE(2734),
    [sym__expression] = STATE(2734),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2734),
    [sym_multiplicative_expression] = STATE(2734),
    [sym_additive_expression] = STATE(2734),
    [sym_comparison_expression] = STATE(2734),
    [sym_logical_expression] = STATE(2734),
    [sym_ternary_expression] = STATE(2734),
    [sym_unary_expression] = STATE(2734),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2734),
    [sym_list_literal] = STATE(2734),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2734),
    [sym__literal_value] = STATE(2734),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10548),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10550),
    [sym_date_literal] = ACTIONS(10548),
    [sym_time_literal] = ACTIONS(10548),
    [sym_biginteger_literal] = ACTIONS(10550),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10550),
    [sym_verbatim_string] = ACTIONS(10550),
    [sym_integer] = ACTIONS(10548),
    [sym_continue_as_identifier] = ACTIONS(10550),
  },
  [STATE(4527)] = {
    [sym_boolean] = STATE(2730),
    [sym_assignment_expression] = STATE(2730),
    [sym__expression] = STATE(2730),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2730),
    [sym_multiplicative_expression] = STATE(2730),
    [sym_additive_expression] = STATE(2730),
    [sym_comparison_expression] = STATE(2730),
    [sym_logical_expression] = STATE(2730),
    [sym_ternary_expression] = STATE(2730),
    [sym_unary_expression] = STATE(2730),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2730),
    [sym_list_literal] = STATE(2730),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2730),
    [sym__literal_value] = STATE(2730),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10552),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10554),
    [sym_date_literal] = ACTIONS(10552),
    [sym_time_literal] = ACTIONS(10552),
    [sym_biginteger_literal] = ACTIONS(10554),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10554),
    [sym_verbatim_string] = ACTIONS(10554),
    [sym_integer] = ACTIONS(10552),
    [sym_continue_as_identifier] = ACTIONS(10554),
  },
  [STATE(4528)] = {
    [sym_boolean] = STATE(2732),
    [sym_assignment_expression] = STATE(2732),
    [sym__expression] = STATE(2732),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2732),
    [sym_multiplicative_expression] = STATE(2732),
    [sym_additive_expression] = STATE(2732),
    [sym_comparison_expression] = STATE(2732),
    [sym_logical_expression] = STATE(2732),
    [sym_ternary_expression] = STATE(2732),
    [sym_unary_expression] = STATE(2732),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2732),
    [sym_list_literal] = STATE(2732),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2732),
    [sym__literal_value] = STATE(2732),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10556),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10558),
    [sym_date_literal] = ACTIONS(10556),
    [sym_time_literal] = ACTIONS(10556),
    [sym_biginteger_literal] = ACTIONS(10558),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10558),
    [sym_verbatim_string] = ACTIONS(10558),
    [sym_integer] = ACTIONS(10556),
    [sym_continue_as_identifier] = ACTIONS(10558),
  },
  [STATE(4529)] = {
    [sym_boolean] = STATE(2735),
    [sym_assignment_expression] = STATE(2735),
    [sym__expression] = STATE(2735),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2735),
    [sym_multiplicative_expression] = STATE(2735),
    [sym_additive_expression] = STATE(2735),
    [sym_comparison_expression] = STATE(2735),
    [sym_logical_expression] = STATE(2735),
    [sym_ternary_expression] = STATE(2735),
    [sym_unary_expression] = STATE(2735),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2735),
    [sym_list_literal] = STATE(2735),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2735),
    [sym__literal_value] = STATE(2735),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10560),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10562),
    [sym_date_literal] = ACTIONS(10560),
    [sym_time_literal] = ACTIONS(10560),
    [sym_biginteger_literal] = ACTIONS(10562),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10562),
    [sym_verbatim_string] = ACTIONS(10562),
    [sym_integer] = ACTIONS(10560),
    [sym_continue_as_identifier] = ACTIONS(10562),
  },
  [STATE(4530)] = {
    [sym_boolean] = STATE(2740),
    [sym_assignment_expression] = STATE(2740),
    [sym__expression] = STATE(2740),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2740),
    [sym_multiplicative_expression] = STATE(2740),
    [sym_additive_expression] = STATE(2740),
    [sym_comparison_expression] = STATE(2740),
    [sym_logical_expression] = STATE(2740),
    [sym_ternary_expression] = STATE(2740),
    [sym_unary_expression] = STATE(2740),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2740),
    [sym_list_literal] = STATE(2740),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2740),
    [sym__literal_value] = STATE(2740),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10564),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10566),
    [sym_date_literal] = ACTIONS(10564),
    [sym_time_literal] = ACTIONS(10564),
    [sym_biginteger_literal] = ACTIONS(10566),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10566),
    [sym_verbatim_string] = ACTIONS(10566),
    [sym_integer] = ACTIONS(10564),
    [sym_continue_as_identifier] = ACTIONS(10566),
  },
  [STATE(4531)] = {
    [sym_boolean] = STATE(2746),
    [sym_assignment_expression] = STATE(2746),
    [sym__expression] = STATE(2746),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2746),
    [sym_multiplicative_expression] = STATE(2746),
    [sym_additive_expression] = STATE(2746),
    [sym_comparison_expression] = STATE(2746),
    [sym_logical_expression] = STATE(2746),
    [sym_ternary_expression] = STATE(2746),
    [sym_unary_expression] = STATE(2746),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2746),
    [sym_list_literal] = STATE(2746),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2746),
    [sym__literal_value] = STATE(2746),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10568),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10570),
    [sym_date_literal] = ACTIONS(10568),
    [sym_time_literal] = ACTIONS(10568),
    [sym_biginteger_literal] = ACTIONS(10570),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10570),
    [sym_verbatim_string] = ACTIONS(10570),
    [sym_integer] = ACTIONS(10568),
    [sym_continue_as_identifier] = ACTIONS(10570),
  },
  [STATE(4532)] = {
    [sym_boolean] = STATE(2753),
    [sym_assignment_expression] = STATE(2753),
    [sym__expression] = STATE(2753),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2753),
    [sym_multiplicative_expression] = STATE(2753),
    [sym_additive_expression] = STATE(2753),
    [sym_comparison_expression] = STATE(2753),
    [sym_logical_expression] = STATE(2753),
    [sym_ternary_expression] = STATE(2753),
    [sym_unary_expression] = STATE(2753),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2753),
    [sym_list_literal] = STATE(2753),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2753),
    [sym__literal_value] = STATE(2753),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10572),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10574),
    [sym_date_literal] = ACTIONS(10572),
    [sym_time_literal] = ACTIONS(10572),
    [sym_biginteger_literal] = ACTIONS(10574),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10574),
    [sym_verbatim_string] = ACTIONS(10574),
    [sym_integer] = ACTIONS(10572),
    [sym_continue_as_identifier] = ACTIONS(10574),
  },
  [STATE(4533)] = {
    [sym_boolean] = STATE(2729),
    [sym_assignment_expression] = STATE(2729),
    [sym__expression] = STATE(2729),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2729),
    [sym_multiplicative_expression] = STATE(2729),
    [sym_additive_expression] = STATE(2729),
    [sym_comparison_expression] = STATE(2729),
    [sym_logical_expression] = STATE(2729),
    [sym_ternary_expression] = STATE(2729),
    [sym_unary_expression] = STATE(2729),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2729),
    [sym_list_literal] = STATE(2729),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2729),
    [sym__literal_value] = STATE(2729),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10576),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10578),
    [sym_date_literal] = ACTIONS(10576),
    [sym_time_literal] = ACTIONS(10576),
    [sym_biginteger_literal] = ACTIONS(10578),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10578),
    [sym_verbatim_string] = ACTIONS(10578),
    [sym_integer] = ACTIONS(10576),
    [sym_continue_as_identifier] = ACTIONS(10578),
  },
  [STATE(4534)] = {
    [sym_boolean] = STATE(8489),
    [sym_assignment_expression] = STATE(8489),
    [sym__expression] = STATE(8489),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8489),
    [sym_multiplicative_expression] = STATE(8489),
    [sym_additive_expression] = STATE(8489),
    [sym_comparison_expression] = STATE(8489),
    [sym_logical_expression] = STATE(8489),
    [sym_ternary_expression] = STATE(8489),
    [sym_unary_expression] = STATE(8489),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8489),
    [sym_list_literal] = STATE(8489),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8489),
    [sym__literal_value] = STATE(8489),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10580),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10582),
    [sym_date_literal] = ACTIONS(10580),
    [sym_time_literal] = ACTIONS(10580),
    [sym_biginteger_literal] = ACTIONS(10582),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10582),
    [sym_verbatim_string] = ACTIONS(10582),
    [sym_integer] = ACTIONS(10580),
    [sym_continue_as_identifier] = ACTIONS(10582),
  },
  [STATE(4535)] = {
    [sym__body_element] = STATE(4775),
    [sym_empty_statement] = STATE(4775),
    [sym_property] = STATE(4775),
    [sym_permissions_property] = STATE(4775),
    [sym_table_relation_property] = STATE(4775),
    [sym_fields_section] = STATE(4775),
    [sym_keys_section] = STATE(4775),
    [sym_fieldgroups_section] = STATE(4775),
    [sym_enum_value_declaration] = STATE(4775),
    [sym_labels_section] = STATE(4775),
    [sym_layout_section] = STATE(4775),
    [sym_modify_modification] = STATE(4775),
    [sym_actions_section] = STATE(4775),
    [sym_views_section] = STATE(4775),
    [sym_dataset_section] = STATE(4775),
    [sym_requestpage_section] = STATE(4775),
    [sym_rendering_section] = STATE(4775),
    [sym_elements_section] = STATE(4775),
    [sym_schema_section] = STATE(4775),
    [sym_xmlport_element] = STATE(4775),
    [sym__xmlport_body_element] = STATE(4775),
    [sym_preproc_conditional_xmlport] = STATE(4775),
    [sym_xmlport_attribute] = STATE(4775),
    [sym_assembly_declaration] = STATE(4775),
    [sym_event_declaration] = STATE(4775),
    [sym_procedure] = STATE(4775),
    [sym_preproc_split_procedure] = STATE(4775),
    [sym_preproc_split_procedure_preamble] = STATE(4775),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4775),
    [sym_var_section] = STATE(4775),
    [sym_attribute_item] = STATE(4775),
    [sym_preproc_conditional] = STATE(4775),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4775),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10584),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4536)] = {
    [sym_boolean] = STATE(8254),
    [sym_assignment_expression] = STATE(8254),
    [sym__expression] = STATE(8254),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8254),
    [sym_multiplicative_expression] = STATE(8254),
    [sym_additive_expression] = STATE(8254),
    [sym_comparison_expression] = STATE(8254),
    [sym_logical_expression] = STATE(8254),
    [sym_ternary_expression] = STATE(8254),
    [sym_unary_expression] = STATE(8254),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8254),
    [sym_list_literal] = STATE(8254),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8254),
    [sym__literal_value] = STATE(8254),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10586),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10588),
    [sym_date_literal] = ACTIONS(10586),
    [sym_time_literal] = ACTIONS(10586),
    [sym_biginteger_literal] = ACTIONS(10588),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10588),
    [sym_verbatim_string] = ACTIONS(10588),
    [sym_integer] = ACTIONS(10586),
    [sym_continue_as_identifier] = ACTIONS(10588),
  },
  [STATE(4537)] = {
    [sym_boolean] = STATE(8454),
    [sym_assignment_expression] = STATE(8454),
    [sym__expression] = STATE(8454),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8454),
    [sym_multiplicative_expression] = STATE(8454),
    [sym_additive_expression] = STATE(8454),
    [sym_comparison_expression] = STATE(8454),
    [sym_logical_expression] = STATE(8454),
    [sym_ternary_expression] = STATE(8454),
    [sym_unary_expression] = STATE(8454),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8454),
    [sym_list_literal] = STATE(8454),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8454),
    [sym__literal_value] = STATE(8454),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10590),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10592),
    [sym_date_literal] = ACTIONS(10590),
    [sym_time_literal] = ACTIONS(10590),
    [sym_biginteger_literal] = ACTIONS(10592),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10592),
    [sym_verbatim_string] = ACTIONS(10592),
    [sym_integer] = ACTIONS(10590),
    [sym_continue_as_identifier] = ACTIONS(10592),
  },
  [STATE(4538)] = {
    [sym_boolean] = STATE(8539),
    [sym_assignment_expression] = STATE(8539),
    [sym__expression] = STATE(8539),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8539),
    [sym_multiplicative_expression] = STATE(8539),
    [sym_additive_expression] = STATE(8539),
    [sym_comparison_expression] = STATE(8539),
    [sym_logical_expression] = STATE(8539),
    [sym_ternary_expression] = STATE(8539),
    [sym_unary_expression] = STATE(8539),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8539),
    [sym_list_literal] = STATE(8539),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8539),
    [sym__literal_value] = STATE(8539),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10594),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10596),
    [sym_date_literal] = ACTIONS(10594),
    [sym_time_literal] = ACTIONS(10594),
    [sym_biginteger_literal] = ACTIONS(10596),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10596),
    [sym_verbatim_string] = ACTIONS(10596),
    [sym_integer] = ACTIONS(10594),
    [sym_continue_as_identifier] = ACTIONS(10596),
  },
  [STATE(4539)] = {
    [sym_boolean] = STATE(8455),
    [sym_assignment_expression] = STATE(8455),
    [sym__expression] = STATE(8455),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8455),
    [sym_multiplicative_expression] = STATE(8455),
    [sym_additive_expression] = STATE(8455),
    [sym_comparison_expression] = STATE(8455),
    [sym_logical_expression] = STATE(8455),
    [sym_ternary_expression] = STATE(8455),
    [sym_unary_expression] = STATE(8455),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8455),
    [sym_list_literal] = STATE(8455),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8455),
    [sym__literal_value] = STATE(8455),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10598),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10600),
    [sym_date_literal] = ACTIONS(10598),
    [sym_time_literal] = ACTIONS(10598),
    [sym_biginteger_literal] = ACTIONS(10600),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10600),
    [sym_verbatim_string] = ACTIONS(10600),
    [sym_integer] = ACTIONS(10598),
    [sym_continue_as_identifier] = ACTIONS(10600),
  },
  [STATE(4540)] = {
    [sym_boolean] = STATE(8456),
    [sym_assignment_expression] = STATE(8456),
    [sym__expression] = STATE(8456),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8456),
    [sym_multiplicative_expression] = STATE(8456),
    [sym_additive_expression] = STATE(8456),
    [sym_comparison_expression] = STATE(8456),
    [sym_logical_expression] = STATE(8456),
    [sym_ternary_expression] = STATE(8456),
    [sym_unary_expression] = STATE(8456),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8456),
    [sym_list_literal] = STATE(8456),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8456),
    [sym__literal_value] = STATE(8456),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10602),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10604),
    [sym_date_literal] = ACTIONS(10602),
    [sym_time_literal] = ACTIONS(10602),
    [sym_biginteger_literal] = ACTIONS(10604),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10604),
    [sym_verbatim_string] = ACTIONS(10604),
    [sym_integer] = ACTIONS(10602),
    [sym_continue_as_identifier] = ACTIONS(10604),
  },
  [STATE(4541)] = {
    [sym_boolean] = STATE(8457),
    [sym_assignment_expression] = STATE(8457),
    [sym__expression] = STATE(8457),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8457),
    [sym_multiplicative_expression] = STATE(8457),
    [sym_additive_expression] = STATE(8457),
    [sym_comparison_expression] = STATE(8457),
    [sym_logical_expression] = STATE(8457),
    [sym_ternary_expression] = STATE(8457),
    [sym_unary_expression] = STATE(8457),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8457),
    [sym_list_literal] = STATE(8457),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8457),
    [sym__literal_value] = STATE(8457),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10606),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10608),
    [sym_date_literal] = ACTIONS(10606),
    [sym_time_literal] = ACTIONS(10606),
    [sym_biginteger_literal] = ACTIONS(10608),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10608),
    [sym_verbatim_string] = ACTIONS(10608),
    [sym_integer] = ACTIONS(10606),
    [sym_continue_as_identifier] = ACTIONS(10608),
  },
  [STATE(4542)] = {
    [sym_boolean] = STATE(8459),
    [sym_assignment_expression] = STATE(8459),
    [sym__expression] = STATE(8459),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8459),
    [sym_multiplicative_expression] = STATE(8459),
    [sym_additive_expression] = STATE(8459),
    [sym_comparison_expression] = STATE(8459),
    [sym_logical_expression] = STATE(8459),
    [sym_ternary_expression] = STATE(8459),
    [sym_unary_expression] = STATE(8459),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8459),
    [sym_list_literal] = STATE(8459),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8459),
    [sym__literal_value] = STATE(8459),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10610),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10612),
    [sym_date_literal] = ACTIONS(10610),
    [sym_time_literal] = ACTIONS(10610),
    [sym_biginteger_literal] = ACTIONS(10612),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10612),
    [sym_verbatim_string] = ACTIONS(10612),
    [sym_integer] = ACTIONS(10610),
    [sym_continue_as_identifier] = ACTIONS(10612),
  },
  [STATE(4543)] = {
    [sym_boolean] = STATE(8460),
    [sym_assignment_expression] = STATE(8460),
    [sym__expression] = STATE(8460),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8460),
    [sym_multiplicative_expression] = STATE(8460),
    [sym_additive_expression] = STATE(8460),
    [sym_comparison_expression] = STATE(8460),
    [sym_logical_expression] = STATE(8460),
    [sym_ternary_expression] = STATE(8460),
    [sym_unary_expression] = STATE(8460),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8460),
    [sym_list_literal] = STATE(8460),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8460),
    [sym__literal_value] = STATE(8460),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10614),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10616),
    [sym_date_literal] = ACTIONS(10614),
    [sym_time_literal] = ACTIONS(10614),
    [sym_biginteger_literal] = ACTIONS(10616),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10616),
    [sym_verbatim_string] = ACTIONS(10616),
    [sym_integer] = ACTIONS(10614),
    [sym_continue_as_identifier] = ACTIONS(10616),
  },
  [STATE(4544)] = {
    [sym_boolean] = STATE(8461),
    [sym_assignment_expression] = STATE(8461),
    [sym__expression] = STATE(8461),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8461),
    [sym_multiplicative_expression] = STATE(8461),
    [sym_additive_expression] = STATE(8461),
    [sym_comparison_expression] = STATE(8461),
    [sym_logical_expression] = STATE(8461),
    [sym_ternary_expression] = STATE(8461),
    [sym_unary_expression] = STATE(8461),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8461),
    [sym_list_literal] = STATE(8461),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8461),
    [sym__literal_value] = STATE(8461),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10618),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10620),
    [sym_date_literal] = ACTIONS(10618),
    [sym_time_literal] = ACTIONS(10618),
    [sym_biginteger_literal] = ACTIONS(10620),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10620),
    [sym_verbatim_string] = ACTIONS(10620),
    [sym_integer] = ACTIONS(10618),
    [sym_continue_as_identifier] = ACTIONS(10620),
  },
  [STATE(4545)] = {
    [sym_boolean] = STATE(8462),
    [sym_assignment_expression] = STATE(8462),
    [sym__expression] = STATE(8462),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8462),
    [sym_multiplicative_expression] = STATE(8462),
    [sym_additive_expression] = STATE(8462),
    [sym_comparison_expression] = STATE(8462),
    [sym_logical_expression] = STATE(8462),
    [sym_ternary_expression] = STATE(8462),
    [sym_unary_expression] = STATE(8462),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8462),
    [sym_list_literal] = STATE(8462),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8462),
    [sym__literal_value] = STATE(8462),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10622),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10624),
    [sym_date_literal] = ACTIONS(10622),
    [sym_time_literal] = ACTIONS(10622),
    [sym_biginteger_literal] = ACTIONS(10624),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10624),
    [sym_verbatim_string] = ACTIONS(10624),
    [sym_integer] = ACTIONS(10622),
    [sym_continue_as_identifier] = ACTIONS(10624),
  },
  [STATE(4546)] = {
    [sym_boolean] = STATE(8463),
    [sym_assignment_expression] = STATE(8463),
    [sym__expression] = STATE(8463),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8463),
    [sym_multiplicative_expression] = STATE(8463),
    [sym_additive_expression] = STATE(8463),
    [sym_comparison_expression] = STATE(8463),
    [sym_logical_expression] = STATE(8463),
    [sym_ternary_expression] = STATE(8463),
    [sym_unary_expression] = STATE(8463),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8463),
    [sym_list_literal] = STATE(8463),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8463),
    [sym__literal_value] = STATE(8463),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10626),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10628),
    [sym_date_literal] = ACTIONS(10626),
    [sym_time_literal] = ACTIONS(10626),
    [sym_biginteger_literal] = ACTIONS(10628),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10628),
    [sym_verbatim_string] = ACTIONS(10628),
    [sym_integer] = ACTIONS(10626),
    [sym_continue_as_identifier] = ACTIONS(10628),
  },
  [STATE(4547)] = {
    [sym_boolean] = STATE(8464),
    [sym_assignment_expression] = STATE(8464),
    [sym__expression] = STATE(8464),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8464),
    [sym_multiplicative_expression] = STATE(8464),
    [sym_additive_expression] = STATE(8464),
    [sym_comparison_expression] = STATE(8464),
    [sym_logical_expression] = STATE(8464),
    [sym_ternary_expression] = STATE(8464),
    [sym_unary_expression] = STATE(8464),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8464),
    [sym_list_literal] = STATE(8464),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8464),
    [sym__literal_value] = STATE(8464),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10630),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10632),
    [sym_date_literal] = ACTIONS(10630),
    [sym_time_literal] = ACTIONS(10630),
    [sym_biginteger_literal] = ACTIONS(10632),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10632),
    [sym_verbatim_string] = ACTIONS(10632),
    [sym_integer] = ACTIONS(10630),
    [sym_continue_as_identifier] = ACTIONS(10632),
  },
  [STATE(4548)] = {
    [sym_boolean] = STATE(8465),
    [sym_assignment_expression] = STATE(8465),
    [sym__expression] = STATE(8465),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8465),
    [sym_multiplicative_expression] = STATE(8465),
    [sym_additive_expression] = STATE(8465),
    [sym_comparison_expression] = STATE(8465),
    [sym_logical_expression] = STATE(8465),
    [sym_ternary_expression] = STATE(8465),
    [sym_unary_expression] = STATE(8465),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8465),
    [sym_list_literal] = STATE(8465),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8465),
    [sym__literal_value] = STATE(8465),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10634),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10636),
    [sym_date_literal] = ACTIONS(10634),
    [sym_time_literal] = ACTIONS(10634),
    [sym_biginteger_literal] = ACTIONS(10636),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10636),
    [sym_verbatim_string] = ACTIONS(10636),
    [sym_integer] = ACTIONS(10634),
    [sym_continue_as_identifier] = ACTIONS(10636),
  },
  [STATE(4549)] = {
    [sym_boolean] = STATE(8466),
    [sym_assignment_expression] = STATE(8466),
    [sym__expression] = STATE(8466),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8466),
    [sym_multiplicative_expression] = STATE(8466),
    [sym_additive_expression] = STATE(8466),
    [sym_comparison_expression] = STATE(8466),
    [sym_logical_expression] = STATE(8466),
    [sym_ternary_expression] = STATE(8466),
    [sym_unary_expression] = STATE(8466),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8466),
    [sym_list_literal] = STATE(8466),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8466),
    [sym__literal_value] = STATE(8466),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10638),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10640),
    [sym_date_literal] = ACTIONS(10638),
    [sym_time_literal] = ACTIONS(10638),
    [sym_biginteger_literal] = ACTIONS(10640),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10640),
    [sym_verbatim_string] = ACTIONS(10640),
    [sym_integer] = ACTIONS(10638),
    [sym_continue_as_identifier] = ACTIONS(10640),
  },
  [STATE(4550)] = {
    [sym_boolean] = STATE(8467),
    [sym_assignment_expression] = STATE(8467),
    [sym__expression] = STATE(8467),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8467),
    [sym_multiplicative_expression] = STATE(8467),
    [sym_additive_expression] = STATE(8467),
    [sym_comparison_expression] = STATE(8467),
    [sym_logical_expression] = STATE(8467),
    [sym_ternary_expression] = STATE(8467),
    [sym_unary_expression] = STATE(8467),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8467),
    [sym_list_literal] = STATE(8467),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8467),
    [sym__literal_value] = STATE(8467),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10642),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10644),
    [sym_date_literal] = ACTIONS(10642),
    [sym_time_literal] = ACTIONS(10642),
    [sym_biginteger_literal] = ACTIONS(10644),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10644),
    [sym_verbatim_string] = ACTIONS(10644),
    [sym_integer] = ACTIONS(10642),
    [sym_continue_as_identifier] = ACTIONS(10644),
  },
  [STATE(4551)] = {
    [sym_boolean] = STATE(8468),
    [sym_assignment_expression] = STATE(8468),
    [sym__expression] = STATE(8468),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8468),
    [sym_multiplicative_expression] = STATE(8468),
    [sym_additive_expression] = STATE(8468),
    [sym_comparison_expression] = STATE(8468),
    [sym_logical_expression] = STATE(8468),
    [sym_ternary_expression] = STATE(8468),
    [sym_unary_expression] = STATE(8468),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8468),
    [sym_list_literal] = STATE(8468),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8468),
    [sym__literal_value] = STATE(8468),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10646),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10648),
    [sym_date_literal] = ACTIONS(10646),
    [sym_time_literal] = ACTIONS(10646),
    [sym_biginteger_literal] = ACTIONS(10648),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10648),
    [sym_verbatim_string] = ACTIONS(10648),
    [sym_integer] = ACTIONS(10646),
    [sym_continue_as_identifier] = ACTIONS(10648),
  },
  [STATE(4552)] = {
    [sym_boolean] = STATE(8469),
    [sym_assignment_expression] = STATE(8469),
    [sym__expression] = STATE(8469),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8469),
    [sym_multiplicative_expression] = STATE(8469),
    [sym_additive_expression] = STATE(8469),
    [sym_comparison_expression] = STATE(8469),
    [sym_logical_expression] = STATE(8469),
    [sym_ternary_expression] = STATE(8469),
    [sym_unary_expression] = STATE(8469),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8469),
    [sym_list_literal] = STATE(8469),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8469),
    [sym__literal_value] = STATE(8469),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10650),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10652),
    [sym_date_literal] = ACTIONS(10650),
    [sym_time_literal] = ACTIONS(10650),
    [sym_biginteger_literal] = ACTIONS(10652),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10652),
    [sym_verbatim_string] = ACTIONS(10652),
    [sym_integer] = ACTIONS(10650),
    [sym_continue_as_identifier] = ACTIONS(10652),
  },
  [STATE(4553)] = {
    [sym_boolean] = STATE(8470),
    [sym_assignment_expression] = STATE(8470),
    [sym__expression] = STATE(8470),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8470),
    [sym_multiplicative_expression] = STATE(8470),
    [sym_additive_expression] = STATE(8470),
    [sym_comparison_expression] = STATE(8470),
    [sym_logical_expression] = STATE(8470),
    [sym_ternary_expression] = STATE(8470),
    [sym_unary_expression] = STATE(8470),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8470),
    [sym_list_literal] = STATE(8470),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8470),
    [sym__literal_value] = STATE(8470),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10654),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10656),
    [sym_date_literal] = ACTIONS(10654),
    [sym_time_literal] = ACTIONS(10654),
    [sym_biginteger_literal] = ACTIONS(10656),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10656),
    [sym_verbatim_string] = ACTIONS(10656),
    [sym_integer] = ACTIONS(10654),
    [sym_continue_as_identifier] = ACTIONS(10656),
  },
  [STATE(4554)] = {
    [sym_boolean] = STATE(8471),
    [sym_assignment_expression] = STATE(8471),
    [sym__expression] = STATE(8471),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8471),
    [sym_multiplicative_expression] = STATE(8471),
    [sym_additive_expression] = STATE(8471),
    [sym_comparison_expression] = STATE(8471),
    [sym_logical_expression] = STATE(8471),
    [sym_ternary_expression] = STATE(8471),
    [sym_unary_expression] = STATE(8471),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8471),
    [sym_list_literal] = STATE(8471),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8471),
    [sym__literal_value] = STATE(8471),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10658),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10660),
    [sym_date_literal] = ACTIONS(10658),
    [sym_time_literal] = ACTIONS(10658),
    [sym_biginteger_literal] = ACTIONS(10660),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10660),
    [sym_verbatim_string] = ACTIONS(10660),
    [sym_integer] = ACTIONS(10658),
    [sym_continue_as_identifier] = ACTIONS(10660),
  },
  [STATE(4555)] = {
    [sym_boolean] = STATE(8472),
    [sym_assignment_expression] = STATE(8472),
    [sym__expression] = STATE(8472),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8472),
    [sym_multiplicative_expression] = STATE(8472),
    [sym_additive_expression] = STATE(8472),
    [sym_comparison_expression] = STATE(8472),
    [sym_logical_expression] = STATE(8472),
    [sym_ternary_expression] = STATE(8472),
    [sym_unary_expression] = STATE(8472),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_list_literal] = STATE(8472),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8472),
    [sym__literal_value] = STATE(8472),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10662),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10664),
    [sym_date_literal] = ACTIONS(10662),
    [sym_time_literal] = ACTIONS(10662),
    [sym_biginteger_literal] = ACTIONS(10664),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10664),
    [sym_verbatim_string] = ACTIONS(10664),
    [sym_integer] = ACTIONS(10662),
    [sym_continue_as_identifier] = ACTIONS(10664),
  },
  [STATE(4556)] = {
    [sym_boolean] = STATE(8473),
    [sym_assignment_expression] = STATE(8473),
    [sym__expression] = STATE(8473),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8473),
    [sym_multiplicative_expression] = STATE(8473),
    [sym_additive_expression] = STATE(8473),
    [sym_comparison_expression] = STATE(8473),
    [sym_logical_expression] = STATE(8473),
    [sym_ternary_expression] = STATE(8473),
    [sym_unary_expression] = STATE(8473),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8473),
    [sym_list_literal] = STATE(8473),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8473),
    [sym__literal_value] = STATE(8473),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10666),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10668),
    [sym_date_literal] = ACTIONS(10666),
    [sym_time_literal] = ACTIONS(10666),
    [sym_biginteger_literal] = ACTIONS(10668),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10668),
    [sym_verbatim_string] = ACTIONS(10668),
    [sym_integer] = ACTIONS(10666),
    [sym_continue_as_identifier] = ACTIONS(10668),
  },
  [STATE(4557)] = {
    [sym_boolean] = STATE(8475),
    [sym_assignment_expression] = STATE(8475),
    [sym__expression] = STATE(8475),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8475),
    [sym_multiplicative_expression] = STATE(8475),
    [sym_additive_expression] = STATE(8475),
    [sym_comparison_expression] = STATE(8475),
    [sym_logical_expression] = STATE(8475),
    [sym_ternary_expression] = STATE(8475),
    [sym_unary_expression] = STATE(8475),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8475),
    [sym_list_literal] = STATE(8475),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8475),
    [sym__literal_value] = STATE(8475),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10670),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10672),
    [sym_date_literal] = ACTIONS(10670),
    [sym_time_literal] = ACTIONS(10670),
    [sym_biginteger_literal] = ACTIONS(10672),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10672),
    [sym_verbatim_string] = ACTIONS(10672),
    [sym_integer] = ACTIONS(10670),
    [sym_continue_as_identifier] = ACTIONS(10672),
  },
  [STATE(4558)] = {
    [sym_boolean] = STATE(8490),
    [sym_assignment_expression] = STATE(8490),
    [sym__expression] = STATE(8490),
    [sym_keyword_identifier] = STATE(8336),
    [sym_range_expression] = STATE(8490),
    [sym_multiplicative_expression] = STATE(8490),
    [sym_additive_expression] = STATE(8490),
    [sym_comparison_expression] = STATE(8490),
    [sym_logical_expression] = STATE(8490),
    [sym_ternary_expression] = STATE(8490),
    [sym_unary_expression] = STATE(8490),
    [sym_call_expression] = STATE(8635),
    [sym_member_expression] = STATE(8336),
    [sym_subscript_expression] = STATE(8336),
    [sym_parenthesized_expression] = STATE(8490),
    [sym_list_literal] = STATE(8490),
    [sym_qualified_enum_value] = STATE(8336),
    [sym_database_reference] = STATE(8490),
    [sym__literal_value] = STATE(8490),
    [sym_codeunit_keyword] = STATE(8484),
    [sym_xmlport_keyword] = STATE(8484),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(1370),
    [anon_sym_DASH] = ACTIONS(1374),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10674),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(1386),
    [anon_sym_NOT] = ACTIONS(1386),
    [anon_sym_Not] = ACTIONS(1386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1388),
    [anon_sym_PLUS] = ACTIONS(1374),
    [sym_datetime_literal] = ACTIONS(10676),
    [sym_date_literal] = ACTIONS(10674),
    [sym_time_literal] = ACTIONS(10674),
    [sym_biginteger_literal] = ACTIONS(10676),
    [sym_page_keyword] = ACTIONS(1388),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1388),
    [sym_query_keyword] = ACTIONS(1388),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(1404),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10676),
    [sym_verbatim_string] = ACTIONS(10676),
    [sym_integer] = ACTIONS(10674),
    [sym_continue_as_identifier] = ACTIONS(10676),
  },
  [STATE(4559)] = {
    [sym_boolean] = STATE(1882),
    [sym_assignment_expression] = STATE(1882),
    [sym__expression] = STATE(1882),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1882),
    [sym_multiplicative_expression] = STATE(1882),
    [sym_additive_expression] = STATE(1882),
    [sym_comparison_expression] = STATE(1882),
    [sym_logical_expression] = STATE(1882),
    [sym_ternary_expression] = STATE(1882),
    [sym_unary_expression] = STATE(1882),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1882),
    [sym_list_literal] = STATE(1882),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1882),
    [sym__literal_value] = STATE(1882),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10678),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10680),
    [sym_date_literal] = ACTIONS(10678),
    [sym_time_literal] = ACTIONS(10678),
    [sym_biginteger_literal] = ACTIONS(10680),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10680),
    [sym_verbatim_string] = ACTIONS(10680),
    [sym_integer] = ACTIONS(10678),
    [sym_continue_as_identifier] = ACTIONS(10680),
  },
  [STATE(4560)] = {
    [sym_boolean] = STATE(1883),
    [sym_assignment_expression] = STATE(1883),
    [sym__expression] = STATE(1883),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1883),
    [sym_multiplicative_expression] = STATE(1883),
    [sym_additive_expression] = STATE(1883),
    [sym_comparison_expression] = STATE(1883),
    [sym_logical_expression] = STATE(1883),
    [sym_ternary_expression] = STATE(1883),
    [sym_unary_expression] = STATE(1883),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1883),
    [sym_list_literal] = STATE(1883),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1883),
    [sym__literal_value] = STATE(1883),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10682),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10684),
    [sym_date_literal] = ACTIONS(10682),
    [sym_time_literal] = ACTIONS(10682),
    [sym_biginteger_literal] = ACTIONS(10684),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10684),
    [sym_verbatim_string] = ACTIONS(10684),
    [sym_integer] = ACTIONS(10682),
    [sym_continue_as_identifier] = ACTIONS(10684),
  },
  [STATE(4561)] = {
    [sym__body_element] = STATE(4565),
    [sym_empty_statement] = STATE(4565),
    [sym_property] = STATE(4565),
    [sym_permissions_property] = STATE(4565),
    [sym_table_relation_property] = STATE(4565),
    [sym_fields_section] = STATE(4565),
    [sym_keys_section] = STATE(4565),
    [sym_fieldgroups_section] = STATE(4565),
    [sym_enum_value_declaration] = STATE(4565),
    [sym_labels_section] = STATE(4565),
    [sym_layout_section] = STATE(4565),
    [sym_modify_modification] = STATE(4565),
    [sym_actions_section] = STATE(4565),
    [sym_views_section] = STATE(4565),
    [sym_dataset_section] = STATE(4565),
    [sym_requestpage_section] = STATE(4565),
    [sym_rendering_section] = STATE(4565),
    [sym_elements_section] = STATE(4565),
    [sym_schema_section] = STATE(4565),
    [sym_xmlport_element] = STATE(4565),
    [sym__xmlport_body_element] = STATE(4565),
    [sym_preproc_conditional_xmlport] = STATE(4565),
    [sym_xmlport_attribute] = STATE(4565),
    [sym_assembly_declaration] = STATE(4565),
    [sym_event_declaration] = STATE(4565),
    [sym_procedure] = STATE(4565),
    [sym_preproc_split_procedure] = STATE(4565),
    [sym_preproc_split_procedure_preamble] = STATE(4565),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4565),
    [sym_var_section] = STATE(4565),
    [sym_attribute_item] = STATE(4565),
    [sym_preproc_conditional] = STATE(4565),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4565),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10686),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4562)] = {
    [sym_boolean] = STATE(1911),
    [sym_assignment_expression] = STATE(1911),
    [sym__expression] = STATE(1911),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1911),
    [sym_multiplicative_expression] = STATE(1911),
    [sym_additive_expression] = STATE(1911),
    [sym_comparison_expression] = STATE(1911),
    [sym_logical_expression] = STATE(1911),
    [sym_ternary_expression] = STATE(1911),
    [sym_unary_expression] = STATE(1911),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1911),
    [sym_list_literal] = STATE(1911),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1911),
    [sym__literal_value] = STATE(1911),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10688),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10690),
    [sym_date_literal] = ACTIONS(10688),
    [sym_time_literal] = ACTIONS(10688),
    [sym_biginteger_literal] = ACTIONS(10690),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10690),
    [sym_verbatim_string] = ACTIONS(10690),
    [sym_integer] = ACTIONS(10688),
    [sym_continue_as_identifier] = ACTIONS(10690),
  },
  [STATE(4563)] = {
    [sym_boolean] = STATE(1912),
    [sym_assignment_expression] = STATE(1912),
    [sym__expression] = STATE(1912),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1912),
    [sym_multiplicative_expression] = STATE(1912),
    [sym_additive_expression] = STATE(1912),
    [sym_comparison_expression] = STATE(1912),
    [sym_logical_expression] = STATE(1912),
    [sym_ternary_expression] = STATE(1912),
    [sym_unary_expression] = STATE(1912),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1912),
    [sym_list_literal] = STATE(1912),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1912),
    [sym__literal_value] = STATE(1912),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10692),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10694),
    [sym_date_literal] = ACTIONS(10692),
    [sym_time_literal] = ACTIONS(10692),
    [sym_biginteger_literal] = ACTIONS(10694),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10694),
    [sym_verbatim_string] = ACTIONS(10694),
    [sym_integer] = ACTIONS(10692),
    [sym_continue_as_identifier] = ACTIONS(10694),
  },
  [STATE(4564)] = {
    [sym_boolean] = STATE(1884),
    [sym_assignment_expression] = STATE(1884),
    [sym__expression] = STATE(1884),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1884),
    [sym_multiplicative_expression] = STATE(1884),
    [sym_additive_expression] = STATE(1884),
    [sym_comparison_expression] = STATE(1884),
    [sym_logical_expression] = STATE(1884),
    [sym_ternary_expression] = STATE(1884),
    [sym_unary_expression] = STATE(1884),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1884),
    [sym_list_literal] = STATE(1884),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1884),
    [sym__literal_value] = STATE(1884),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10696),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10698),
    [sym_date_literal] = ACTIONS(10696),
    [sym_time_literal] = ACTIONS(10696),
    [sym_biginteger_literal] = ACTIONS(10698),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10698),
    [sym_verbatim_string] = ACTIONS(10698),
    [sym_integer] = ACTIONS(10696),
    [sym_continue_as_identifier] = ACTIONS(10698),
  },
  [STATE(4565)] = {
    [sym__body_element] = STATE(4775),
    [sym_empty_statement] = STATE(4775),
    [sym_property] = STATE(4775),
    [sym_permissions_property] = STATE(4775),
    [sym_table_relation_property] = STATE(4775),
    [sym_fields_section] = STATE(4775),
    [sym_keys_section] = STATE(4775),
    [sym_fieldgroups_section] = STATE(4775),
    [sym_enum_value_declaration] = STATE(4775),
    [sym_labels_section] = STATE(4775),
    [sym_layout_section] = STATE(4775),
    [sym_modify_modification] = STATE(4775),
    [sym_actions_section] = STATE(4775),
    [sym_views_section] = STATE(4775),
    [sym_dataset_section] = STATE(4775),
    [sym_requestpage_section] = STATE(4775),
    [sym_rendering_section] = STATE(4775),
    [sym_elements_section] = STATE(4775),
    [sym_schema_section] = STATE(4775),
    [sym_xmlport_element] = STATE(4775),
    [sym__xmlport_body_element] = STATE(4775),
    [sym_preproc_conditional_xmlport] = STATE(4775),
    [sym_xmlport_attribute] = STATE(4775),
    [sym_assembly_declaration] = STATE(4775),
    [sym_event_declaration] = STATE(4775),
    [sym_procedure] = STATE(4775),
    [sym_preproc_split_procedure] = STATE(4775),
    [sym_preproc_split_procedure_preamble] = STATE(4775),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4775),
    [sym_var_section] = STATE(4775),
    [sym_attribute_item] = STATE(4775),
    [sym_preproc_conditional] = STATE(4775),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4775),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10700),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4566)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6490),
    [sym_preproc_endif] = STATE(10154),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10691),
    [anon_sym_RBRACE] = ACTIONS(10702),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4567)] = {
    [sym__body_element] = STATE(4568),
    [sym_empty_statement] = STATE(4568),
    [sym_property] = STATE(4568),
    [sym_permissions_property] = STATE(4568),
    [sym_table_relation_property] = STATE(4568),
    [sym_fields_section] = STATE(4568),
    [sym_keys_section] = STATE(4568),
    [sym_fieldgroups_section] = STATE(4568),
    [sym_enum_value_declaration] = STATE(4568),
    [sym_labels_section] = STATE(4568),
    [sym_layout_section] = STATE(4568),
    [sym_modify_modification] = STATE(4568),
    [sym_actions_section] = STATE(4568),
    [sym_views_section] = STATE(4568),
    [sym_dataset_section] = STATE(4568),
    [sym_requestpage_section] = STATE(4568),
    [sym_rendering_section] = STATE(4568),
    [sym_elements_section] = STATE(4568),
    [sym_schema_section] = STATE(4568),
    [sym_xmlport_element] = STATE(4568),
    [sym__xmlport_body_element] = STATE(4568),
    [sym_preproc_conditional_xmlport] = STATE(4568),
    [sym_xmlport_attribute] = STATE(4568),
    [sym_assembly_declaration] = STATE(4568),
    [sym_event_declaration] = STATE(4568),
    [sym_procedure] = STATE(4568),
    [sym_preproc_split_procedure] = STATE(4568),
    [sym_preproc_split_procedure_preamble] = STATE(4568),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4568),
    [sym_var_section] = STATE(4568),
    [sym_attribute_item] = STATE(4568),
    [sym_preproc_conditional] = STATE(4568),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4568),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10704),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4568)] = {
    [sym__body_element] = STATE(4775),
    [sym_empty_statement] = STATE(4775),
    [sym_property] = STATE(4775),
    [sym_permissions_property] = STATE(4775),
    [sym_table_relation_property] = STATE(4775),
    [sym_fields_section] = STATE(4775),
    [sym_keys_section] = STATE(4775),
    [sym_fieldgroups_section] = STATE(4775),
    [sym_enum_value_declaration] = STATE(4775),
    [sym_labels_section] = STATE(4775),
    [sym_layout_section] = STATE(4775),
    [sym_modify_modification] = STATE(4775),
    [sym_actions_section] = STATE(4775),
    [sym_views_section] = STATE(4775),
    [sym_dataset_section] = STATE(4775),
    [sym_requestpage_section] = STATE(4775),
    [sym_rendering_section] = STATE(4775),
    [sym_elements_section] = STATE(4775),
    [sym_schema_section] = STATE(4775),
    [sym_xmlport_element] = STATE(4775),
    [sym__xmlport_body_element] = STATE(4775),
    [sym_preproc_conditional_xmlport] = STATE(4775),
    [sym_xmlport_attribute] = STATE(4775),
    [sym_assembly_declaration] = STATE(4775),
    [sym_event_declaration] = STATE(4775),
    [sym_procedure] = STATE(4775),
    [sym_preproc_split_procedure] = STATE(4775),
    [sym_preproc_split_procedure_preamble] = STATE(4775),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4775),
    [sym_var_section] = STATE(4775),
    [sym_attribute_item] = STATE(4775),
    [sym_preproc_conditional] = STATE(4775),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4775),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(10706),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4569)] = {
    [sym_boolean] = STATE(2748),
    [sym_assignment_expression] = STATE(2748),
    [sym__expression] = STATE(2748),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2748),
    [sym_multiplicative_expression] = STATE(2748),
    [sym_additive_expression] = STATE(2748),
    [sym_comparison_expression] = STATE(2748),
    [sym_logical_expression] = STATE(2748),
    [sym_ternary_expression] = STATE(2748),
    [sym_unary_expression] = STATE(2748),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2748),
    [sym_list_literal] = STATE(2748),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2748),
    [sym__literal_value] = STATE(2748),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10708),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10710),
    [sym_date_literal] = ACTIONS(10708),
    [sym_time_literal] = ACTIONS(10708),
    [sym_biginteger_literal] = ACTIONS(10710),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10710),
    [sym_verbatim_string] = ACTIONS(10710),
    [sym_integer] = ACTIONS(10708),
    [sym_continue_as_identifier] = ACTIONS(10710),
  },
  [STATE(4570)] = {
    [sym_boolean] = STATE(2731),
    [sym_assignment_expression] = STATE(2731),
    [sym__expression] = STATE(2731),
    [sym_keyword_identifier] = STATE(2742),
    [sym_range_expression] = STATE(2731),
    [sym_multiplicative_expression] = STATE(2731),
    [sym_additive_expression] = STATE(2731),
    [sym_comparison_expression] = STATE(2731),
    [sym_logical_expression] = STATE(2731),
    [sym_ternary_expression] = STATE(2731),
    [sym_unary_expression] = STATE(2731),
    [sym_call_expression] = STATE(2830),
    [sym_member_expression] = STATE(2742),
    [sym_subscript_expression] = STATE(2742),
    [sym_parenthesized_expression] = STATE(2731),
    [sym_list_literal] = STATE(2731),
    [sym_qualified_enum_value] = STATE(2742),
    [sym_database_reference] = STATE(2731),
    [sym__literal_value] = STATE(2731),
    [sym_codeunit_keyword] = STATE(2844),
    [sym_xmlport_keyword] = STATE(2844),
    [sym_enum_keyword] = STATE(2858),
    [sym_identifier] = ACTIONS(10486),
    [anon_sym_DASH] = ACTIONS(7493),
    [aux_sym_boolean_token1] = ACTIONS(4588),
    [aux_sym_boolean_token2] = ACTIONS(4588),
    [sym_decimal] = ACTIONS(10712),
    [anon_sym_LPAREN] = ACTIONS(7497),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4592),
    [anon_sym_LBRACK] = ACTIONS(10490),
    [aux_sym_record_type_token1] = ACTIONS(4592),
    [aux_sym_basic_type_token21] = ACTIONS(4592),
    [aux_sym_basic_type_token22] = ACTIONS(4592),
    [aux_sym_basic_type_token48] = ACTIONS(4592),
    [anon_sym_not] = ACTIONS(7499),
    [anon_sym_NOT] = ACTIONS(7499),
    [anon_sym_Not] = ACTIONS(7499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(4592),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7505),
    [anon_sym_PLUS] = ACTIONS(7493),
    [sym_datetime_literal] = ACTIONS(10714),
    [sym_date_literal] = ACTIONS(10712),
    [sym_time_literal] = ACTIONS(10712),
    [sym_biginteger_literal] = ACTIONS(10714),
    [sym_page_keyword] = ACTIONS(7505),
    [anon_sym_codeunit] = ACTIONS(4596),
    [anon_sym_CODEUNIT] = ACTIONS(4596),
    [anon_sym_Codeunit] = ACTIONS(4596),
    [anon_sym_CodeUnit] = ACTIONS(4596),
    [anon_sym_COdeunit] = ACTIONS(4596),
    [anon_sym_codeUnit] = ACTIONS(4596),
    [sym_report_keyword] = ACTIONS(7505),
    [sym_query_keyword] = ACTIONS(7505),
    [anon_sym_xmlport] = ACTIONS(4598),
    [anon_sym_XMLPORT] = ACTIONS(4598),
    [anon_sym_Xmlport] = ACTIONS(4598),
    [anon_sym_XMLport] = ACTIONS(4598),
    [anon_sym_XMLPort] = ACTIONS(4598),
    [anon_sym_XmlPort] = ACTIONS(4598),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_ENUM] = ACTIONS(4600),
    [anon_sym_Enum] = ACTIONS(4600),
    [anon_sym_eNUM] = ACTIONS(4600),
    [anon_sym_eNum] = ACTIONS(4600),
    [anon_sym_ENum] = ACTIONS(4600),
    [sym_quoted_identifier] = ACTIONS(10494),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10714),
    [sym_verbatim_string] = ACTIONS(10714),
    [sym_integer] = ACTIONS(10712),
    [sym_continue_as_identifier] = ACTIONS(10714),
  },
  [STATE(4571)] = {
    [sym_boolean] = STATE(1913),
    [sym_assignment_expression] = STATE(1913),
    [sym__expression] = STATE(1913),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1913),
    [sym_multiplicative_expression] = STATE(1913),
    [sym_additive_expression] = STATE(1913),
    [sym_comparison_expression] = STATE(1913),
    [sym_logical_expression] = STATE(1913),
    [sym_ternary_expression] = STATE(1913),
    [sym_unary_expression] = STATE(1913),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1913),
    [sym_list_literal] = STATE(1913),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1913),
    [sym__literal_value] = STATE(1913),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10716),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10718),
    [sym_date_literal] = ACTIONS(10716),
    [sym_time_literal] = ACTIONS(10716),
    [sym_biginteger_literal] = ACTIONS(10718),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10718),
    [sym_verbatim_string] = ACTIONS(10718),
    [sym_integer] = ACTIONS(10716),
    [sym_continue_as_identifier] = ACTIONS(10718),
  },
  [STATE(4572)] = {
    [sym_boolean] = STATE(8284),
    [sym_assignment_expression] = STATE(8284),
    [sym__expression] = STATE(8284),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8284),
    [sym_multiplicative_expression] = STATE(8284),
    [sym_additive_expression] = STATE(8284),
    [sym_comparison_expression] = STATE(8284),
    [sym_logical_expression] = STATE(8284),
    [sym_ternary_expression] = STATE(8284),
    [sym_unary_expression] = STATE(8284),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8284),
    [sym_list_literal] = STATE(8284),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8284),
    [sym__literal_value] = STATE(8284),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10720),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10722),
    [sym_date_literal] = ACTIONS(10720),
    [sym_time_literal] = ACTIONS(10720),
    [sym_biginteger_literal] = ACTIONS(10722),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10722),
    [sym_verbatim_string] = ACTIONS(10722),
    [sym_integer] = ACTIONS(10720),
    [sym_continue_as_identifier] = ACTIONS(10722),
  },
  [STATE(4573)] = {
    [sym_boolean] = STATE(1897),
    [sym_assignment_expression] = STATE(1897),
    [sym__expression] = STATE(1897),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1897),
    [sym_multiplicative_expression] = STATE(1897),
    [sym_additive_expression] = STATE(1897),
    [sym_comparison_expression] = STATE(1897),
    [sym_logical_expression] = STATE(1897),
    [sym_ternary_expression] = STATE(1897),
    [sym_unary_expression] = STATE(1897),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1897),
    [sym_list_literal] = STATE(1897),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1897),
    [sym__literal_value] = STATE(1897),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10724),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10726),
    [sym_date_literal] = ACTIONS(10724),
    [sym_time_literal] = ACTIONS(10724),
    [sym_biginteger_literal] = ACTIONS(10726),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10726),
    [sym_verbatim_string] = ACTIONS(10726),
    [sym_integer] = ACTIONS(10724),
    [sym_continue_as_identifier] = ACTIONS(10726),
  },
  [STATE(4574)] = {
    [sym_boolean] = STATE(8259),
    [sym_assignment_expression] = STATE(8259),
    [sym__expression] = STATE(8259),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8259),
    [sym_multiplicative_expression] = STATE(8259),
    [sym_additive_expression] = STATE(8259),
    [sym_comparison_expression] = STATE(8259),
    [sym_logical_expression] = STATE(8259),
    [sym_ternary_expression] = STATE(8259),
    [sym_unary_expression] = STATE(8259),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8259),
    [sym_list_literal] = STATE(8259),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8259),
    [sym__literal_value] = STATE(8259),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10728),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10730),
    [sym_date_literal] = ACTIONS(10728),
    [sym_time_literal] = ACTIONS(10728),
    [sym_biginteger_literal] = ACTIONS(10730),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10730),
    [sym_verbatim_string] = ACTIONS(10730),
    [sym_integer] = ACTIONS(10728),
    [sym_continue_as_identifier] = ACTIONS(10730),
  },
  [STATE(4575)] = {
    [sym_boolean] = STATE(8260),
    [sym_assignment_expression] = STATE(8260),
    [sym__expression] = STATE(8260),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8260),
    [sym_multiplicative_expression] = STATE(8260),
    [sym_additive_expression] = STATE(8260),
    [sym_comparison_expression] = STATE(8260),
    [sym_logical_expression] = STATE(8260),
    [sym_ternary_expression] = STATE(8260),
    [sym_unary_expression] = STATE(8260),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8260),
    [sym_list_literal] = STATE(8260),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8260),
    [sym__literal_value] = STATE(8260),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10732),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10734),
    [sym_date_literal] = ACTIONS(10732),
    [sym_time_literal] = ACTIONS(10732),
    [sym_biginteger_literal] = ACTIONS(10734),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10734),
    [sym_verbatim_string] = ACTIONS(10734),
    [sym_integer] = ACTIONS(10732),
    [sym_continue_as_identifier] = ACTIONS(10734),
  },
  [STATE(4576)] = {
    [sym_boolean] = STATE(8261),
    [sym_assignment_expression] = STATE(8261),
    [sym__expression] = STATE(8261),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8261),
    [sym_multiplicative_expression] = STATE(8261),
    [sym_additive_expression] = STATE(8261),
    [sym_comparison_expression] = STATE(8261),
    [sym_logical_expression] = STATE(8261),
    [sym_ternary_expression] = STATE(8261),
    [sym_unary_expression] = STATE(8261),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8261),
    [sym_list_literal] = STATE(8261),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8261),
    [sym__literal_value] = STATE(8261),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10736),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10738),
    [sym_date_literal] = ACTIONS(10736),
    [sym_time_literal] = ACTIONS(10736),
    [sym_biginteger_literal] = ACTIONS(10738),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10738),
    [sym_verbatim_string] = ACTIONS(10738),
    [sym_integer] = ACTIONS(10736),
    [sym_continue_as_identifier] = ACTIONS(10738),
  },
  [STATE(4577)] = {
    [sym_boolean] = STATE(3459),
    [sym_assignment_expression] = STATE(3459),
    [sym__expression] = STATE(3459),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3459),
    [sym_multiplicative_expression] = STATE(3459),
    [sym_additive_expression] = STATE(3459),
    [sym_comparison_expression] = STATE(3459),
    [sym_logical_expression] = STATE(3459),
    [sym_ternary_expression] = STATE(3459),
    [sym_unary_expression] = STATE(3459),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3459),
    [sym_list_literal] = STATE(3459),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3459),
    [sym__literal_value] = STATE(3459),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10740),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10742),
    [sym_date_literal] = ACTIONS(10740),
    [sym_time_literal] = ACTIONS(10740),
    [sym_biginteger_literal] = ACTIONS(10742),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10742),
    [sym_verbatim_string] = ACTIONS(10742),
    [sym_integer] = ACTIONS(10740),
    [sym_continue_as_identifier] = ACTIONS(10742),
  },
  [STATE(4578)] = {
    [sym_boolean] = STATE(8262),
    [sym_assignment_expression] = STATE(8262),
    [sym__expression] = STATE(8262),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8262),
    [sym_multiplicative_expression] = STATE(8262),
    [sym_additive_expression] = STATE(8262),
    [sym_comparison_expression] = STATE(8262),
    [sym_logical_expression] = STATE(8262),
    [sym_ternary_expression] = STATE(8262),
    [sym_unary_expression] = STATE(8262),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8262),
    [sym_list_literal] = STATE(8262),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8262),
    [sym__literal_value] = STATE(8262),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10744),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10746),
    [sym_date_literal] = ACTIONS(10744),
    [sym_time_literal] = ACTIONS(10744),
    [sym_biginteger_literal] = ACTIONS(10746),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10746),
    [sym_verbatim_string] = ACTIONS(10746),
    [sym_integer] = ACTIONS(10744),
    [sym_continue_as_identifier] = ACTIONS(10746),
  },
  [STATE(4579)] = {
    [sym_boolean] = STATE(8263),
    [sym_assignment_expression] = STATE(8263),
    [sym__expression] = STATE(8263),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8263),
    [sym_multiplicative_expression] = STATE(8263),
    [sym_additive_expression] = STATE(8263),
    [sym_comparison_expression] = STATE(8263),
    [sym_logical_expression] = STATE(8263),
    [sym_ternary_expression] = STATE(8263),
    [sym_unary_expression] = STATE(8263),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8263),
    [sym_list_literal] = STATE(8263),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8263),
    [sym__literal_value] = STATE(8263),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10748),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10750),
    [sym_date_literal] = ACTIONS(10748),
    [sym_time_literal] = ACTIONS(10748),
    [sym_biginteger_literal] = ACTIONS(10750),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10750),
    [sym_verbatim_string] = ACTIONS(10750),
    [sym_integer] = ACTIONS(10748),
    [sym_continue_as_identifier] = ACTIONS(10750),
  },
  [STATE(4580)] = {
    [sym_boolean] = STATE(8264),
    [sym_assignment_expression] = STATE(8264),
    [sym__expression] = STATE(8264),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8264),
    [sym_multiplicative_expression] = STATE(8264),
    [sym_additive_expression] = STATE(8264),
    [sym_comparison_expression] = STATE(8264),
    [sym_logical_expression] = STATE(8264),
    [sym_ternary_expression] = STATE(8264),
    [sym_unary_expression] = STATE(8264),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8264),
    [sym_list_literal] = STATE(8264),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8264),
    [sym__literal_value] = STATE(8264),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10752),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10754),
    [sym_date_literal] = ACTIONS(10752),
    [sym_time_literal] = ACTIONS(10752),
    [sym_biginteger_literal] = ACTIONS(10754),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10754),
    [sym_verbatim_string] = ACTIONS(10754),
    [sym_integer] = ACTIONS(10752),
    [sym_continue_as_identifier] = ACTIONS(10754),
  },
  [STATE(4581)] = {
    [sym_boolean] = STATE(8265),
    [sym_assignment_expression] = STATE(8265),
    [sym__expression] = STATE(8265),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8265),
    [sym_multiplicative_expression] = STATE(8265),
    [sym_additive_expression] = STATE(8265),
    [sym_comparison_expression] = STATE(8265),
    [sym_logical_expression] = STATE(8265),
    [sym_ternary_expression] = STATE(8265),
    [sym_unary_expression] = STATE(8265),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8265),
    [sym_list_literal] = STATE(8265),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8265),
    [sym__literal_value] = STATE(8265),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10756),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10758),
    [sym_date_literal] = ACTIONS(10756),
    [sym_time_literal] = ACTIONS(10756),
    [sym_biginteger_literal] = ACTIONS(10758),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10758),
    [sym_verbatim_string] = ACTIONS(10758),
    [sym_integer] = ACTIONS(10756),
    [sym_continue_as_identifier] = ACTIONS(10758),
  },
  [STATE(4582)] = {
    [sym_boolean] = STATE(3550),
    [sym_assignment_expression] = STATE(3550),
    [sym__expression] = STATE(3550),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3550),
    [sym_multiplicative_expression] = STATE(3550),
    [sym_additive_expression] = STATE(3550),
    [sym_comparison_expression] = STATE(3550),
    [sym_logical_expression] = STATE(3550),
    [sym_ternary_expression] = STATE(3550),
    [sym_unary_expression] = STATE(3550),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3550),
    [sym_list_literal] = STATE(3550),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3550),
    [sym__literal_value] = STATE(3550),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10760),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10762),
    [sym_date_literal] = ACTIONS(10760),
    [sym_time_literal] = ACTIONS(10760),
    [sym_biginteger_literal] = ACTIONS(10762),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10762),
    [sym_verbatim_string] = ACTIONS(10762),
    [sym_integer] = ACTIONS(10760),
    [sym_continue_as_identifier] = ACTIONS(10762),
  },
  [STATE(4583)] = {
    [sym_boolean] = STATE(3532),
    [sym_assignment_expression] = STATE(3532),
    [sym__expression] = STATE(3532),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3532),
    [sym_multiplicative_expression] = STATE(3532),
    [sym_additive_expression] = STATE(3532),
    [sym_comparison_expression] = STATE(3532),
    [sym_logical_expression] = STATE(3532),
    [sym_ternary_expression] = STATE(3532),
    [sym_unary_expression] = STATE(3532),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3532),
    [sym_list_literal] = STATE(3532),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3532),
    [sym__literal_value] = STATE(3532),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10764),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10766),
    [sym_date_literal] = ACTIONS(10764),
    [sym_time_literal] = ACTIONS(10764),
    [sym_biginteger_literal] = ACTIONS(10766),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10766),
    [sym_verbatim_string] = ACTIONS(10766),
    [sym_integer] = ACTIONS(10764),
    [sym_continue_as_identifier] = ACTIONS(10766),
  },
  [STATE(4584)] = {
    [sym_boolean] = STATE(8266),
    [sym_assignment_expression] = STATE(8266),
    [sym__expression] = STATE(8266),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8266),
    [sym_multiplicative_expression] = STATE(8266),
    [sym_additive_expression] = STATE(8266),
    [sym_comparison_expression] = STATE(8266),
    [sym_logical_expression] = STATE(8266),
    [sym_ternary_expression] = STATE(8266),
    [sym_unary_expression] = STATE(8266),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8266),
    [sym_list_literal] = STATE(8266),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8266),
    [sym__literal_value] = STATE(8266),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10768),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10770),
    [sym_date_literal] = ACTIONS(10768),
    [sym_time_literal] = ACTIONS(10768),
    [sym_biginteger_literal] = ACTIONS(10770),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10770),
    [sym_verbatim_string] = ACTIONS(10770),
    [sym_integer] = ACTIONS(10768),
    [sym_continue_as_identifier] = ACTIONS(10770),
  },
  [STATE(4585)] = {
    [sym_boolean] = STATE(3542),
    [sym_assignment_expression] = STATE(3542),
    [sym__expression] = STATE(3542),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3542),
    [sym_multiplicative_expression] = STATE(3542),
    [sym_additive_expression] = STATE(3542),
    [sym_comparison_expression] = STATE(3542),
    [sym_logical_expression] = STATE(3542),
    [sym_ternary_expression] = STATE(3542),
    [sym_unary_expression] = STATE(3542),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3542),
    [sym_list_literal] = STATE(3542),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3542),
    [sym__literal_value] = STATE(3542),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10772),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10774),
    [sym_date_literal] = ACTIONS(10772),
    [sym_time_literal] = ACTIONS(10772),
    [sym_biginteger_literal] = ACTIONS(10774),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10774),
    [sym_verbatim_string] = ACTIONS(10774),
    [sym_integer] = ACTIONS(10772),
    [sym_continue_as_identifier] = ACTIONS(10774),
  },
  [STATE(4586)] = {
    [sym_boolean] = STATE(8267),
    [sym_assignment_expression] = STATE(8267),
    [sym__expression] = STATE(8267),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8267),
    [sym_multiplicative_expression] = STATE(8267),
    [sym_additive_expression] = STATE(8267),
    [sym_comparison_expression] = STATE(8267),
    [sym_logical_expression] = STATE(8267),
    [sym_ternary_expression] = STATE(8267),
    [sym_unary_expression] = STATE(8267),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8267),
    [sym_list_literal] = STATE(8267),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8267),
    [sym__literal_value] = STATE(8267),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10776),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10778),
    [sym_date_literal] = ACTIONS(10776),
    [sym_time_literal] = ACTIONS(10776),
    [sym_biginteger_literal] = ACTIONS(10778),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10778),
    [sym_verbatim_string] = ACTIONS(10778),
    [sym_integer] = ACTIONS(10776),
    [sym_continue_as_identifier] = ACTIONS(10778),
  },
  [STATE(4587)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6490),
    [sym_preproc_endif] = STATE(10154),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10691),
    [anon_sym_RBRACE] = ACTIONS(10780),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4588)] = {
    [sym_boolean] = STATE(8289),
    [sym_assignment_expression] = STATE(8289),
    [sym__expression] = STATE(8289),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8289),
    [sym_multiplicative_expression] = STATE(8289),
    [sym_additive_expression] = STATE(8289),
    [sym_comparison_expression] = STATE(8289),
    [sym_logical_expression] = STATE(8289),
    [sym_ternary_expression] = STATE(8289),
    [sym_unary_expression] = STATE(8289),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8289),
    [sym_list_literal] = STATE(8289),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8289),
    [sym__literal_value] = STATE(8289),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10782),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10784),
    [sym_date_literal] = ACTIONS(10782),
    [sym_time_literal] = ACTIONS(10782),
    [sym_biginteger_literal] = ACTIONS(10784),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10784),
    [sym_verbatim_string] = ACTIONS(10784),
    [sym_integer] = ACTIONS(10782),
    [sym_continue_as_identifier] = ACTIONS(10784),
  },
  [STATE(4589)] = {
    [sym_boolean] = STATE(8269),
    [sym_assignment_expression] = STATE(8269),
    [sym__expression] = STATE(8269),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8269),
    [sym_multiplicative_expression] = STATE(8269),
    [sym_additive_expression] = STATE(8269),
    [sym_comparison_expression] = STATE(8269),
    [sym_logical_expression] = STATE(8269),
    [sym_ternary_expression] = STATE(8269),
    [sym_unary_expression] = STATE(8269),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8269),
    [sym_list_literal] = STATE(8269),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8269),
    [sym__literal_value] = STATE(8269),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10786),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10788),
    [sym_date_literal] = ACTIONS(10786),
    [sym_time_literal] = ACTIONS(10786),
    [sym_biginteger_literal] = ACTIONS(10788),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10788),
    [sym_verbatim_string] = ACTIONS(10788),
    [sym_integer] = ACTIONS(10786),
    [sym_continue_as_identifier] = ACTIONS(10788),
  },
  [STATE(4590)] = {
    [sym_boolean] = STATE(8270),
    [sym_assignment_expression] = STATE(8270),
    [sym__expression] = STATE(8270),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8270),
    [sym_multiplicative_expression] = STATE(8270),
    [sym_additive_expression] = STATE(8270),
    [sym_comparison_expression] = STATE(8270),
    [sym_logical_expression] = STATE(8270),
    [sym_ternary_expression] = STATE(8270),
    [sym_unary_expression] = STATE(8270),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8270),
    [sym_list_literal] = STATE(8270),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8270),
    [sym__literal_value] = STATE(8270),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10790),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10792),
    [sym_date_literal] = ACTIONS(10790),
    [sym_time_literal] = ACTIONS(10790),
    [sym_biginteger_literal] = ACTIONS(10792),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10792),
    [sym_verbatim_string] = ACTIONS(10792),
    [sym_integer] = ACTIONS(10790),
    [sym_continue_as_identifier] = ACTIONS(10792),
  },
  [STATE(4591)] = {
    [sym_boolean] = STATE(8271),
    [sym_assignment_expression] = STATE(8271),
    [sym__expression] = STATE(8271),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8271),
    [sym_multiplicative_expression] = STATE(8271),
    [sym_additive_expression] = STATE(8271),
    [sym_comparison_expression] = STATE(8271),
    [sym_logical_expression] = STATE(8271),
    [sym_ternary_expression] = STATE(8271),
    [sym_unary_expression] = STATE(8271),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8271),
    [sym_list_literal] = STATE(8271),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8271),
    [sym__literal_value] = STATE(8271),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10794),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10796),
    [sym_date_literal] = ACTIONS(10794),
    [sym_time_literal] = ACTIONS(10794),
    [sym_biginteger_literal] = ACTIONS(10796),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10796),
    [sym_verbatim_string] = ACTIONS(10796),
    [sym_integer] = ACTIONS(10794),
    [sym_continue_as_identifier] = ACTIONS(10796),
  },
  [STATE(4592)] = {
    [sym_boolean] = STATE(8272),
    [sym_assignment_expression] = STATE(8272),
    [sym__expression] = STATE(8272),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8272),
    [sym_multiplicative_expression] = STATE(8272),
    [sym_additive_expression] = STATE(8272),
    [sym_comparison_expression] = STATE(8272),
    [sym_logical_expression] = STATE(8272),
    [sym_ternary_expression] = STATE(8272),
    [sym_unary_expression] = STATE(8272),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8272),
    [sym_list_literal] = STATE(8272),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8272),
    [sym__literal_value] = STATE(8272),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10798),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10800),
    [sym_date_literal] = ACTIONS(10798),
    [sym_time_literal] = ACTIONS(10798),
    [sym_biginteger_literal] = ACTIONS(10800),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10800),
    [sym_verbatim_string] = ACTIONS(10800),
    [sym_integer] = ACTIONS(10798),
    [sym_continue_as_identifier] = ACTIONS(10800),
  },
  [STATE(4593)] = {
    [sym_boolean] = STATE(8273),
    [sym_assignment_expression] = STATE(8273),
    [sym__expression] = STATE(8273),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8273),
    [sym_multiplicative_expression] = STATE(8273),
    [sym_additive_expression] = STATE(8273),
    [sym_comparison_expression] = STATE(8273),
    [sym_logical_expression] = STATE(8273),
    [sym_ternary_expression] = STATE(8273),
    [sym_unary_expression] = STATE(8273),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8273),
    [sym_list_literal] = STATE(8273),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8273),
    [sym__literal_value] = STATE(8273),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10802),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10804),
    [sym_date_literal] = ACTIONS(10802),
    [sym_time_literal] = ACTIONS(10802),
    [sym_biginteger_literal] = ACTIONS(10804),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10804),
    [sym_verbatim_string] = ACTIONS(10804),
    [sym_integer] = ACTIONS(10802),
    [sym_continue_as_identifier] = ACTIONS(10804),
  },
  [STATE(4594)] = {
    [sym_boolean] = STATE(8274),
    [sym_assignment_expression] = STATE(8274),
    [sym__expression] = STATE(8274),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8274),
    [sym_multiplicative_expression] = STATE(8274),
    [sym_additive_expression] = STATE(8274),
    [sym_comparison_expression] = STATE(8274),
    [sym_logical_expression] = STATE(8274),
    [sym_ternary_expression] = STATE(8274),
    [sym_unary_expression] = STATE(8274),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8274),
    [sym_list_literal] = STATE(8274),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8274),
    [sym__literal_value] = STATE(8274),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10806),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10808),
    [sym_date_literal] = ACTIONS(10806),
    [sym_time_literal] = ACTIONS(10806),
    [sym_biginteger_literal] = ACTIONS(10808),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10808),
    [sym_verbatim_string] = ACTIONS(10808),
    [sym_integer] = ACTIONS(10806),
    [sym_continue_as_identifier] = ACTIONS(10808),
  },
  [STATE(4595)] = {
    [sym_boolean] = STATE(8275),
    [sym_assignment_expression] = STATE(8275),
    [sym__expression] = STATE(8275),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8275),
    [sym_multiplicative_expression] = STATE(8275),
    [sym_additive_expression] = STATE(8275),
    [sym_comparison_expression] = STATE(8275),
    [sym_logical_expression] = STATE(8275),
    [sym_ternary_expression] = STATE(8275),
    [sym_unary_expression] = STATE(8275),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8275),
    [sym_list_literal] = STATE(8275),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8275),
    [sym__literal_value] = STATE(8275),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10810),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10812),
    [sym_date_literal] = ACTIONS(10810),
    [sym_time_literal] = ACTIONS(10810),
    [sym_biginteger_literal] = ACTIONS(10812),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10812),
    [sym_verbatim_string] = ACTIONS(10812),
    [sym_integer] = ACTIONS(10810),
    [sym_continue_as_identifier] = ACTIONS(10812),
  },
  [STATE(4596)] = {
    [sym_boolean] = STATE(8276),
    [sym_assignment_expression] = STATE(8276),
    [sym__expression] = STATE(8276),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8276),
    [sym_multiplicative_expression] = STATE(8276),
    [sym_additive_expression] = STATE(8276),
    [sym_comparison_expression] = STATE(8276),
    [sym_logical_expression] = STATE(8276),
    [sym_ternary_expression] = STATE(8276),
    [sym_unary_expression] = STATE(8276),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8276),
    [sym_list_literal] = STATE(8276),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8276),
    [sym__literal_value] = STATE(8276),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10814),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10816),
    [sym_date_literal] = ACTIONS(10814),
    [sym_time_literal] = ACTIONS(10814),
    [sym_biginteger_literal] = ACTIONS(10816),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10816),
    [sym_verbatim_string] = ACTIONS(10816),
    [sym_integer] = ACTIONS(10814),
    [sym_continue_as_identifier] = ACTIONS(10816),
  },
  [STATE(4597)] = {
    [sym_boolean] = STATE(8277),
    [sym_assignment_expression] = STATE(8277),
    [sym__expression] = STATE(8277),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8277),
    [sym_multiplicative_expression] = STATE(8277),
    [sym_additive_expression] = STATE(8277),
    [sym_comparison_expression] = STATE(8277),
    [sym_logical_expression] = STATE(8277),
    [sym_ternary_expression] = STATE(8277),
    [sym_unary_expression] = STATE(8277),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8277),
    [sym_list_literal] = STATE(8277),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8277),
    [sym__literal_value] = STATE(8277),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10818),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10820),
    [sym_date_literal] = ACTIONS(10818),
    [sym_time_literal] = ACTIONS(10818),
    [sym_biginteger_literal] = ACTIONS(10820),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10820),
    [sym_verbatim_string] = ACTIONS(10820),
    [sym_integer] = ACTIONS(10818),
    [sym_continue_as_identifier] = ACTIONS(10820),
  },
  [STATE(4598)] = {
    [sym_boolean] = STATE(8278),
    [sym_assignment_expression] = STATE(8278),
    [sym__expression] = STATE(8278),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8278),
    [sym_multiplicative_expression] = STATE(8278),
    [sym_additive_expression] = STATE(8278),
    [sym_comparison_expression] = STATE(8278),
    [sym_logical_expression] = STATE(8278),
    [sym_ternary_expression] = STATE(8278),
    [sym_unary_expression] = STATE(8278),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8278),
    [sym_list_literal] = STATE(8278),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8278),
    [sym__literal_value] = STATE(8278),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10822),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10824),
    [sym_date_literal] = ACTIONS(10822),
    [sym_time_literal] = ACTIONS(10822),
    [sym_biginteger_literal] = ACTIONS(10824),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10824),
    [sym_verbatim_string] = ACTIONS(10824),
    [sym_integer] = ACTIONS(10822),
    [sym_continue_as_identifier] = ACTIONS(10824),
  },
  [STATE(4599)] = {
    [sym_boolean] = STATE(8279),
    [sym_assignment_expression] = STATE(8279),
    [sym__expression] = STATE(8279),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8279),
    [sym_multiplicative_expression] = STATE(8279),
    [sym_additive_expression] = STATE(8279),
    [sym_comparison_expression] = STATE(8279),
    [sym_logical_expression] = STATE(8279),
    [sym_ternary_expression] = STATE(8279),
    [sym_unary_expression] = STATE(8279),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8279),
    [sym_list_literal] = STATE(8279),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8279),
    [sym__literal_value] = STATE(8279),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(10826),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(10828),
    [sym_date_literal] = ACTIONS(10826),
    [sym_time_literal] = ACTIONS(10826),
    [sym_biginteger_literal] = ACTIONS(10828),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10828),
    [sym_verbatim_string] = ACTIONS(10828),
    [sym_integer] = ACTIONS(10826),
    [sym_continue_as_identifier] = ACTIONS(10828),
  },
  [STATE(4600)] = {
    [sym_boolean] = STATE(1914),
    [sym_assignment_expression] = STATE(1914),
    [sym__expression] = STATE(1914),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1914),
    [sym_multiplicative_expression] = STATE(1914),
    [sym_additive_expression] = STATE(1914),
    [sym_comparison_expression] = STATE(1914),
    [sym_logical_expression] = STATE(1914),
    [sym_ternary_expression] = STATE(1914),
    [sym_unary_expression] = STATE(1914),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1914),
    [sym_list_literal] = STATE(1914),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1914),
    [sym__literal_value] = STATE(1914),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10830),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10832),
    [sym_date_literal] = ACTIONS(10830),
    [sym_time_literal] = ACTIONS(10830),
    [sym_biginteger_literal] = ACTIONS(10832),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10832),
    [sym_verbatim_string] = ACTIONS(10832),
    [sym_integer] = ACTIONS(10830),
    [sym_continue_as_identifier] = ACTIONS(10832),
  },
  [STATE(4601)] = {
    [sym_boolean] = STATE(1920),
    [sym_assignment_expression] = STATE(1920),
    [sym__expression] = STATE(1920),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1920),
    [sym_multiplicative_expression] = STATE(1920),
    [sym_additive_expression] = STATE(1920),
    [sym_comparison_expression] = STATE(1920),
    [sym_logical_expression] = STATE(1920),
    [sym_ternary_expression] = STATE(1920),
    [sym_unary_expression] = STATE(1920),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1920),
    [sym_list_literal] = STATE(1920),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1920),
    [sym__literal_value] = STATE(1920),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10834),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10836),
    [sym_date_literal] = ACTIONS(10834),
    [sym_time_literal] = ACTIONS(10834),
    [sym_biginteger_literal] = ACTIONS(10836),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10836),
    [sym_verbatim_string] = ACTIONS(10836),
    [sym_integer] = ACTIONS(10834),
    [sym_continue_as_identifier] = ACTIONS(10836),
  },
  [STATE(4602)] = {
    [sym_boolean] = STATE(1921),
    [sym_assignment_expression] = STATE(1921),
    [sym__expression] = STATE(1921),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1921),
    [sym_multiplicative_expression] = STATE(1921),
    [sym_additive_expression] = STATE(1921),
    [sym_comparison_expression] = STATE(1921),
    [sym_logical_expression] = STATE(1921),
    [sym_ternary_expression] = STATE(1921),
    [sym_unary_expression] = STATE(1921),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1921),
    [sym_list_literal] = STATE(1921),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1921),
    [sym__literal_value] = STATE(1921),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10838),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10840),
    [sym_date_literal] = ACTIONS(10838),
    [sym_time_literal] = ACTIONS(10838),
    [sym_biginteger_literal] = ACTIONS(10840),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10840),
    [sym_verbatim_string] = ACTIONS(10840),
    [sym_integer] = ACTIONS(10838),
    [sym_continue_as_identifier] = ACTIONS(10840),
  },
  [STATE(4603)] = {
    [sym_boolean] = STATE(3462),
    [sym_assignment_expression] = STATE(3462),
    [sym__expression] = STATE(3462),
    [sym_keyword_identifier] = STATE(3465),
    [sym_range_expression] = STATE(3462),
    [sym_multiplicative_expression] = STATE(3462),
    [sym_additive_expression] = STATE(3462),
    [sym_comparison_expression] = STATE(3462),
    [sym_logical_expression] = STATE(3462),
    [sym_ternary_expression] = STATE(3462),
    [sym_unary_expression] = STATE(3462),
    [sym_call_expression] = STATE(3501),
    [sym_member_expression] = STATE(3465),
    [sym_subscript_expression] = STATE(3465),
    [sym_parenthesized_expression] = STATE(3462),
    [sym_list_literal] = STATE(3462),
    [sym_qualified_enum_value] = STATE(3465),
    [sym_database_reference] = STATE(3462),
    [sym__literal_value] = STATE(3462),
    [sym_codeunit_keyword] = STATE(3483),
    [sym_xmlport_keyword] = STATE(3483),
    [sym_enum_keyword] = STATE(3490),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_DASH] = ACTIONS(429),
    [aux_sym_boolean_token1] = ACTIONS(431),
    [aux_sym_boolean_token2] = ACTIONS(431),
    [sym_decimal] = ACTIONS(10842),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_tabledata_permission_token2] = ACTIONS(437),
    [anon_sym_LBRACK] = ACTIONS(439),
    [aux_sym_record_type_token1] = ACTIONS(437),
    [aux_sym_basic_type_token21] = ACTIONS(437),
    [aux_sym_basic_type_token22] = ACTIONS(437),
    [aux_sym_basic_type_token48] = ACTIONS(437),
    [anon_sym_not] = ACTIONS(443),
    [anon_sym_NOT] = ACTIONS(443),
    [anon_sym_Not] = ACTIONS(443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(437),
    [aux_sym_keyword_identifier_token2] = ACTIONS(447),
    [anon_sym_PLUS] = ACTIONS(429),
    [sym_datetime_literal] = ACTIONS(10844),
    [sym_date_literal] = ACTIONS(10842),
    [sym_time_literal] = ACTIONS(10842),
    [sym_biginteger_literal] = ACTIONS(10844),
    [sym_page_keyword] = ACTIONS(447),
    [anon_sym_codeunit] = ACTIONS(459),
    [anon_sym_CODEUNIT] = ACTIONS(459),
    [anon_sym_Codeunit] = ACTIONS(459),
    [anon_sym_CodeUnit] = ACTIONS(459),
    [anon_sym_COdeunit] = ACTIONS(459),
    [anon_sym_codeUnit] = ACTIONS(459),
    [sym_report_keyword] = ACTIONS(447),
    [sym_query_keyword] = ACTIONS(447),
    [anon_sym_xmlport] = ACTIONS(461),
    [anon_sym_XMLPORT] = ACTIONS(461),
    [anon_sym_Xmlport] = ACTIONS(461),
    [anon_sym_XMLport] = ACTIONS(461),
    [anon_sym_XMLPort] = ACTIONS(461),
    [anon_sym_XmlPort] = ACTIONS(461),
    [anon_sym_enum] = ACTIONS(463),
    [anon_sym_ENUM] = ACTIONS(463),
    [anon_sym_Enum] = ACTIONS(463),
    [anon_sym_eNUM] = ACTIONS(463),
    [anon_sym_eNum] = ACTIONS(463),
    [anon_sym_ENum] = ACTIONS(463),
    [sym_quoted_identifier] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10844),
    [sym_verbatim_string] = ACTIONS(10844),
    [sym_integer] = ACTIONS(10842),
    [sym_continue_as_identifier] = ACTIONS(10844),
  },
  [STATE(4604)] = {
    [sym_boolean] = STATE(2350),
    [sym_assignment_expression] = STATE(2350),
    [sym__expression] = STATE(2350),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2350),
    [sym_multiplicative_expression] = STATE(2350),
    [sym_additive_expression] = STATE(2350),
    [sym_comparison_expression] = STATE(2350),
    [sym_logical_expression] = STATE(2350),
    [sym_ternary_expression] = STATE(2350),
    [sym_unary_expression] = STATE(2350),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2350),
    [sym_list_literal] = STATE(2350),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2350),
    [sym__literal_value] = STATE(2350),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10846),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10848),
    [sym_date_literal] = ACTIONS(10846),
    [sym_time_literal] = ACTIONS(10846),
    [sym_biginteger_literal] = ACTIONS(10848),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10848),
    [sym_verbatim_string] = ACTIONS(10848),
    [sym_integer] = ACTIONS(10846),
    [sym_continue_as_identifier] = ACTIONS(10848),
  },
  [STATE(4605)] = {
    [sym_boolean] = STATE(2334),
    [sym_assignment_expression] = STATE(2334),
    [sym__expression] = STATE(2334),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2334),
    [sym_multiplicative_expression] = STATE(2334),
    [sym_additive_expression] = STATE(2334),
    [sym_comparison_expression] = STATE(2334),
    [sym_logical_expression] = STATE(2334),
    [sym_ternary_expression] = STATE(2334),
    [sym_unary_expression] = STATE(2334),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2334),
    [sym_list_literal] = STATE(2334),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2334),
    [sym__literal_value] = STATE(2334),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10850),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10852),
    [sym_date_literal] = ACTIONS(10850),
    [sym_time_literal] = ACTIONS(10850),
    [sym_biginteger_literal] = ACTIONS(10852),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10852),
    [sym_verbatim_string] = ACTIONS(10852),
    [sym_integer] = ACTIONS(10850),
    [sym_continue_as_identifier] = ACTIONS(10852),
  },
  [STATE(4606)] = {
    [sym_boolean] = STATE(2320),
    [sym_assignment_expression] = STATE(2320),
    [sym__expression] = STATE(2320),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2320),
    [sym_multiplicative_expression] = STATE(2320),
    [sym_additive_expression] = STATE(2320),
    [sym_comparison_expression] = STATE(2320),
    [sym_logical_expression] = STATE(2320),
    [sym_ternary_expression] = STATE(2320),
    [sym_unary_expression] = STATE(2320),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2320),
    [sym_list_literal] = STATE(2320),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2320),
    [sym__literal_value] = STATE(2320),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10854),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10856),
    [sym_date_literal] = ACTIONS(10854),
    [sym_time_literal] = ACTIONS(10854),
    [sym_biginteger_literal] = ACTIONS(10856),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10856),
    [sym_verbatim_string] = ACTIONS(10856),
    [sym_integer] = ACTIONS(10854),
    [sym_continue_as_identifier] = ACTIONS(10856),
  },
  [STATE(4607)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6490),
    [sym_preproc_endif] = STATE(10154),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10691),
    [anon_sym_RBRACE] = ACTIONS(10858),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4608)] = {
    [sym_boolean] = STATE(8522),
    [sym_assignment_expression] = STATE(8522),
    [sym__expression] = STATE(8522),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8522),
    [sym_multiplicative_expression] = STATE(8522),
    [sym_additive_expression] = STATE(8522),
    [sym_comparison_expression] = STATE(8522),
    [sym_logical_expression] = STATE(8522),
    [sym_ternary_expression] = STATE(8522),
    [sym_unary_expression] = STATE(8522),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8522),
    [sym_list_literal] = STATE(8522),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8522),
    [sym__literal_value] = STATE(8522),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10860),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10862),
    [sym_date_literal] = ACTIONS(10860),
    [sym_time_literal] = ACTIONS(10860),
    [sym_biginteger_literal] = ACTIONS(10862),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10862),
    [sym_verbatim_string] = ACTIONS(10862),
    [sym_integer] = ACTIONS(10860),
    [sym_continue_as_identifier] = ACTIONS(10862),
  },
  [STATE(4609)] = {
    [sym_boolean] = STATE(2260),
    [sym_assignment_expression] = STATE(2260),
    [sym__expression] = STATE(2260),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2260),
    [sym_multiplicative_expression] = STATE(2260),
    [sym_additive_expression] = STATE(2260),
    [sym_comparison_expression] = STATE(2260),
    [sym_logical_expression] = STATE(2260),
    [sym_ternary_expression] = STATE(2260),
    [sym_unary_expression] = STATE(2260),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2260),
    [sym_list_literal] = STATE(2260),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2260),
    [sym__literal_value] = STATE(2260),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10864),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10866),
    [sym_date_literal] = ACTIONS(10864),
    [sym_time_literal] = ACTIONS(10864),
    [sym_biginteger_literal] = ACTIONS(10866),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10866),
    [sym_verbatim_string] = ACTIONS(10866),
    [sym_integer] = ACTIONS(10864),
    [sym_continue_as_identifier] = ACTIONS(10866),
  },
  [STATE(4610)] = {
    [sym_boolean] = STATE(8723),
    [sym_assignment_expression] = STATE(8723),
    [sym__expression] = STATE(8723),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8723),
    [sym_multiplicative_expression] = STATE(8723),
    [sym_additive_expression] = STATE(8723),
    [sym_comparison_expression] = STATE(8723),
    [sym_logical_expression] = STATE(8723),
    [sym_ternary_expression] = STATE(8723),
    [sym_unary_expression] = STATE(8723),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8723),
    [sym_list_literal] = STATE(8723),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8723),
    [sym__literal_value] = STATE(8723),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10868),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10870),
    [sym_date_literal] = ACTIONS(10868),
    [sym_time_literal] = ACTIONS(10868),
    [sym_biginteger_literal] = ACTIONS(10870),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10870),
    [sym_verbatim_string] = ACTIONS(10870),
    [sym_integer] = ACTIONS(10868),
    [sym_continue_as_identifier] = ACTIONS(10870),
  },
  [STATE(4611)] = {
    [sym_boolean] = STATE(1894),
    [sym_assignment_expression] = STATE(1894),
    [sym__expression] = STATE(1894),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1894),
    [sym_multiplicative_expression] = STATE(1894),
    [sym_additive_expression] = STATE(1894),
    [sym_comparison_expression] = STATE(1894),
    [sym_logical_expression] = STATE(1894),
    [sym_ternary_expression] = STATE(1894),
    [sym_unary_expression] = STATE(1894),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1894),
    [sym_list_literal] = STATE(1894),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1894),
    [sym__literal_value] = STATE(1894),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10872),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10874),
    [sym_date_literal] = ACTIONS(10872),
    [sym_time_literal] = ACTIONS(10872),
    [sym_biginteger_literal] = ACTIONS(10874),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10874),
    [sym_verbatim_string] = ACTIONS(10874),
    [sym_integer] = ACTIONS(10872),
    [sym_continue_as_identifier] = ACTIONS(10874),
  },
  [STATE(4612)] = {
    [sym_boolean] = STATE(1891),
    [sym_assignment_expression] = STATE(1891),
    [sym__expression] = STATE(1891),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1891),
    [sym_multiplicative_expression] = STATE(1891),
    [sym_additive_expression] = STATE(1891),
    [sym_comparison_expression] = STATE(1891),
    [sym_logical_expression] = STATE(1891),
    [sym_ternary_expression] = STATE(1891),
    [sym_unary_expression] = STATE(1891),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1891),
    [sym_list_literal] = STATE(1891),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1891),
    [sym__literal_value] = STATE(1891),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10876),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10878),
    [sym_date_literal] = ACTIONS(10876),
    [sym_time_literal] = ACTIONS(10876),
    [sym_biginteger_literal] = ACTIONS(10878),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10878),
    [sym_verbatim_string] = ACTIONS(10878),
    [sym_integer] = ACTIONS(10876),
    [sym_continue_as_identifier] = ACTIONS(10878),
  },
  [STATE(4613)] = {
    [sym_boolean] = STATE(1904),
    [sym_assignment_expression] = STATE(1904),
    [sym__expression] = STATE(1904),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1904),
    [sym_multiplicative_expression] = STATE(1904),
    [sym_additive_expression] = STATE(1904),
    [sym_comparison_expression] = STATE(1904),
    [sym_logical_expression] = STATE(1904),
    [sym_ternary_expression] = STATE(1904),
    [sym_unary_expression] = STATE(1904),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1904),
    [sym_list_literal] = STATE(1904),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1904),
    [sym__literal_value] = STATE(1904),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10880),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10882),
    [sym_date_literal] = ACTIONS(10880),
    [sym_time_literal] = ACTIONS(10880),
    [sym_biginteger_literal] = ACTIONS(10882),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10882),
    [sym_verbatim_string] = ACTIONS(10882),
    [sym_integer] = ACTIONS(10880),
    [sym_continue_as_identifier] = ACTIONS(10882),
  },
  [STATE(4614)] = {
    [sym_boolean] = STATE(2262),
    [sym_assignment_expression] = STATE(2262),
    [sym__expression] = STATE(2262),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2262),
    [sym_multiplicative_expression] = STATE(2262),
    [sym_additive_expression] = STATE(2262),
    [sym_comparison_expression] = STATE(2262),
    [sym_logical_expression] = STATE(2262),
    [sym_ternary_expression] = STATE(2262),
    [sym_unary_expression] = STATE(2262),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2262),
    [sym_list_literal] = STATE(2262),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2262),
    [sym__literal_value] = STATE(2262),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10884),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10886),
    [sym_date_literal] = ACTIONS(10884),
    [sym_time_literal] = ACTIONS(10884),
    [sym_biginteger_literal] = ACTIONS(10886),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10886),
    [sym_verbatim_string] = ACTIONS(10886),
    [sym_integer] = ACTIONS(10884),
    [sym_continue_as_identifier] = ACTIONS(10886),
  },
  [STATE(4615)] = {
    [sym_boolean] = STATE(2263),
    [sym_assignment_expression] = STATE(2263),
    [sym__expression] = STATE(2263),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2263),
    [sym_multiplicative_expression] = STATE(2263),
    [sym_additive_expression] = STATE(2263),
    [sym_comparison_expression] = STATE(2263),
    [sym_logical_expression] = STATE(2263),
    [sym_ternary_expression] = STATE(2263),
    [sym_unary_expression] = STATE(2263),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2263),
    [sym_list_literal] = STATE(2263),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2263),
    [sym__literal_value] = STATE(2263),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10888),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10890),
    [sym_date_literal] = ACTIONS(10888),
    [sym_time_literal] = ACTIONS(10888),
    [sym_biginteger_literal] = ACTIONS(10890),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10890),
    [sym_verbatim_string] = ACTIONS(10890),
    [sym_integer] = ACTIONS(10888),
    [sym_continue_as_identifier] = ACTIONS(10890),
  },
  [STATE(4616)] = {
    [sym_boolean] = STATE(2264),
    [sym_assignment_expression] = STATE(2264),
    [sym__expression] = STATE(2264),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2264),
    [sym_multiplicative_expression] = STATE(2264),
    [sym_additive_expression] = STATE(2264),
    [sym_comparison_expression] = STATE(2264),
    [sym_logical_expression] = STATE(2264),
    [sym_ternary_expression] = STATE(2264),
    [sym_unary_expression] = STATE(2264),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2264),
    [sym_list_literal] = STATE(2264),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2264),
    [sym__literal_value] = STATE(2264),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10892),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10894),
    [sym_date_literal] = ACTIONS(10892),
    [sym_time_literal] = ACTIONS(10892),
    [sym_biginteger_literal] = ACTIONS(10894),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10894),
    [sym_verbatim_string] = ACTIONS(10894),
    [sym_integer] = ACTIONS(10892),
    [sym_continue_as_identifier] = ACTIONS(10894),
  },
  [STATE(4617)] = {
    [sym_boolean] = STATE(2266),
    [sym_assignment_expression] = STATE(2266),
    [sym__expression] = STATE(2266),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2266),
    [sym_multiplicative_expression] = STATE(2266),
    [sym_additive_expression] = STATE(2266),
    [sym_comparison_expression] = STATE(2266),
    [sym_logical_expression] = STATE(2266),
    [sym_ternary_expression] = STATE(2266),
    [sym_unary_expression] = STATE(2266),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2266),
    [sym_list_literal] = STATE(2266),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2266),
    [sym__literal_value] = STATE(2266),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10896),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10898),
    [sym_date_literal] = ACTIONS(10896),
    [sym_time_literal] = ACTIONS(10896),
    [sym_biginteger_literal] = ACTIONS(10898),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10898),
    [sym_verbatim_string] = ACTIONS(10898),
    [sym_integer] = ACTIONS(10896),
    [sym_continue_as_identifier] = ACTIONS(10898),
  },
  [STATE(4618)] = {
    [sym_boolean] = STATE(2267),
    [sym_assignment_expression] = STATE(2267),
    [sym__expression] = STATE(2267),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2267),
    [sym_multiplicative_expression] = STATE(2267),
    [sym_additive_expression] = STATE(2267),
    [sym_comparison_expression] = STATE(2267),
    [sym_logical_expression] = STATE(2267),
    [sym_ternary_expression] = STATE(2267),
    [sym_unary_expression] = STATE(2267),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2267),
    [sym_list_literal] = STATE(2267),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2267),
    [sym__literal_value] = STATE(2267),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10900),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10902),
    [sym_date_literal] = ACTIONS(10900),
    [sym_time_literal] = ACTIONS(10900),
    [sym_biginteger_literal] = ACTIONS(10902),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10902),
    [sym_verbatim_string] = ACTIONS(10902),
    [sym_integer] = ACTIONS(10900),
    [sym_continue_as_identifier] = ACTIONS(10902),
  },
  [STATE(4619)] = {
    [sym_boolean] = STATE(2268),
    [sym_assignment_expression] = STATE(2268),
    [sym__expression] = STATE(2268),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2268),
    [sym_multiplicative_expression] = STATE(2268),
    [sym_additive_expression] = STATE(2268),
    [sym_comparison_expression] = STATE(2268),
    [sym_logical_expression] = STATE(2268),
    [sym_ternary_expression] = STATE(2268),
    [sym_unary_expression] = STATE(2268),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2268),
    [sym_list_literal] = STATE(2268),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2268),
    [sym__literal_value] = STATE(2268),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10904),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10906),
    [sym_date_literal] = ACTIONS(10904),
    [sym_time_literal] = ACTIONS(10904),
    [sym_biginteger_literal] = ACTIONS(10906),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10906),
    [sym_verbatim_string] = ACTIONS(10906),
    [sym_integer] = ACTIONS(10904),
    [sym_continue_as_identifier] = ACTIONS(10906),
  },
  [STATE(4620)] = {
    [sym_boolean] = STATE(2269),
    [sym_assignment_expression] = STATE(2269),
    [sym__expression] = STATE(2269),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2269),
    [sym_multiplicative_expression] = STATE(2269),
    [sym_additive_expression] = STATE(2269),
    [sym_comparison_expression] = STATE(2269),
    [sym_logical_expression] = STATE(2269),
    [sym_ternary_expression] = STATE(2269),
    [sym_unary_expression] = STATE(2269),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2269),
    [sym_list_literal] = STATE(2269),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2269),
    [sym__literal_value] = STATE(2269),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10908),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10910),
    [sym_date_literal] = ACTIONS(10908),
    [sym_time_literal] = ACTIONS(10908),
    [sym_biginteger_literal] = ACTIONS(10910),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10910),
    [sym_verbatim_string] = ACTIONS(10910),
    [sym_integer] = ACTIONS(10908),
    [sym_continue_as_identifier] = ACTIONS(10910),
  },
  [STATE(4621)] = {
    [sym_boolean] = STATE(2270),
    [sym_assignment_expression] = STATE(2270),
    [sym__expression] = STATE(2270),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2270),
    [sym_multiplicative_expression] = STATE(2270),
    [sym_additive_expression] = STATE(2270),
    [sym_comparison_expression] = STATE(2270),
    [sym_logical_expression] = STATE(2270),
    [sym_ternary_expression] = STATE(2270),
    [sym_unary_expression] = STATE(2270),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2270),
    [sym_list_literal] = STATE(2270),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2270),
    [sym__literal_value] = STATE(2270),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10912),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10914),
    [sym_date_literal] = ACTIONS(10912),
    [sym_time_literal] = ACTIONS(10912),
    [sym_biginteger_literal] = ACTIONS(10914),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10914),
    [sym_verbatim_string] = ACTIONS(10914),
    [sym_integer] = ACTIONS(10912),
    [sym_continue_as_identifier] = ACTIONS(10914),
  },
  [STATE(4622)] = {
    [sym_boolean] = STATE(8437),
    [sym_assignment_expression] = STATE(8437),
    [sym__expression] = STATE(8437),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8437),
    [sym_multiplicative_expression] = STATE(8437),
    [sym_additive_expression] = STATE(8437),
    [sym_comparison_expression] = STATE(8437),
    [sym_logical_expression] = STATE(8437),
    [sym_ternary_expression] = STATE(8437),
    [sym_unary_expression] = STATE(8437),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8437),
    [sym_list_literal] = STATE(8437),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8437),
    [sym__literal_value] = STATE(8437),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10916),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10918),
    [sym_date_literal] = ACTIONS(10916),
    [sym_time_literal] = ACTIONS(10916),
    [sym_biginteger_literal] = ACTIONS(10918),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10918),
    [sym_verbatim_string] = ACTIONS(10918),
    [sym_integer] = ACTIONS(10916),
    [sym_continue_as_identifier] = ACTIONS(10918),
  },
  [STATE(4623)] = {
    [sym_boolean] = STATE(2271),
    [sym_assignment_expression] = STATE(2271),
    [sym__expression] = STATE(2271),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2271),
    [sym_multiplicative_expression] = STATE(2271),
    [sym_additive_expression] = STATE(2271),
    [sym_comparison_expression] = STATE(2271),
    [sym_logical_expression] = STATE(2271),
    [sym_ternary_expression] = STATE(2271),
    [sym_unary_expression] = STATE(2271),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2271),
    [sym_list_literal] = STATE(2271),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2271),
    [sym__literal_value] = STATE(2271),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10920),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10922),
    [sym_date_literal] = ACTIONS(10920),
    [sym_time_literal] = ACTIONS(10920),
    [sym_biginteger_literal] = ACTIONS(10922),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10922),
    [sym_verbatim_string] = ACTIONS(10922),
    [sym_integer] = ACTIONS(10920),
    [sym_continue_as_identifier] = ACTIONS(10922),
  },
  [STATE(4624)] = {
    [sym_boolean] = STATE(2272),
    [sym_assignment_expression] = STATE(2272),
    [sym__expression] = STATE(2272),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2272),
    [sym_multiplicative_expression] = STATE(2272),
    [sym_additive_expression] = STATE(2272),
    [sym_comparison_expression] = STATE(2272),
    [sym_logical_expression] = STATE(2272),
    [sym_ternary_expression] = STATE(2272),
    [sym_unary_expression] = STATE(2272),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2272),
    [sym_list_literal] = STATE(2272),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2272),
    [sym__literal_value] = STATE(2272),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10924),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10926),
    [sym_date_literal] = ACTIONS(10924),
    [sym_time_literal] = ACTIONS(10924),
    [sym_biginteger_literal] = ACTIONS(10926),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10926),
    [sym_verbatim_string] = ACTIONS(10926),
    [sym_integer] = ACTIONS(10924),
    [sym_continue_as_identifier] = ACTIONS(10926),
  },
  [STATE(4625)] = {
    [sym_boolean] = STATE(8441),
    [sym_assignment_expression] = STATE(8441),
    [sym__expression] = STATE(8441),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8441),
    [sym_multiplicative_expression] = STATE(8441),
    [sym_additive_expression] = STATE(8441),
    [sym_comparison_expression] = STATE(8441),
    [sym_logical_expression] = STATE(8441),
    [sym_ternary_expression] = STATE(8441),
    [sym_unary_expression] = STATE(8441),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8441),
    [sym_list_literal] = STATE(8441),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8441),
    [sym__literal_value] = STATE(8441),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10928),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10930),
    [sym_date_literal] = ACTIONS(10928),
    [sym_time_literal] = ACTIONS(10928),
    [sym_biginteger_literal] = ACTIONS(10930),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10930),
    [sym_verbatim_string] = ACTIONS(10930),
    [sym_integer] = ACTIONS(10928),
    [sym_continue_as_identifier] = ACTIONS(10930),
  },
  [STATE(4626)] = {
    [sym_boolean] = STATE(2273),
    [sym_assignment_expression] = STATE(2273),
    [sym__expression] = STATE(2273),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2273),
    [sym_multiplicative_expression] = STATE(2273),
    [sym_additive_expression] = STATE(2273),
    [sym_comparison_expression] = STATE(2273),
    [sym_logical_expression] = STATE(2273),
    [sym_ternary_expression] = STATE(2273),
    [sym_unary_expression] = STATE(2273),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2273),
    [sym_list_literal] = STATE(2273),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2273),
    [sym__literal_value] = STATE(2273),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10932),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10934),
    [sym_date_literal] = ACTIONS(10932),
    [sym_time_literal] = ACTIONS(10932),
    [sym_biginteger_literal] = ACTIONS(10934),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10934),
    [sym_verbatim_string] = ACTIONS(10934),
    [sym_integer] = ACTIONS(10932),
    [sym_continue_as_identifier] = ACTIONS(10934),
  },
  [STATE(4627)] = {
    [sym_boolean] = STATE(8833),
    [sym_assignment_expression] = STATE(8833),
    [sym__expression] = STATE(8833),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8833),
    [sym_multiplicative_expression] = STATE(8833),
    [sym_additive_expression] = STATE(8833),
    [sym_comparison_expression] = STATE(8833),
    [sym_logical_expression] = STATE(8833),
    [sym_ternary_expression] = STATE(8833),
    [sym_unary_expression] = STATE(8833),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8703),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8833),
    [sym_list_literal] = STATE(8833),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8833),
    [sym__literal_value] = STATE(8833),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(10936),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10938),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10940),
    [sym_date_literal] = ACTIONS(10938),
    [sym_time_literal] = ACTIONS(10938),
    [sym_biginteger_literal] = ACTIONS(10940),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(10942),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10940),
    [sym_verbatim_string] = ACTIONS(10940),
    [sym_integer] = ACTIONS(10938),
    [sym_continue_as_identifier] = ACTIONS(10940),
  },
  [STATE(4628)] = {
    [sym_boolean] = STATE(8442),
    [sym_assignment_expression] = STATE(8442),
    [sym__expression] = STATE(8442),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8442),
    [sym_multiplicative_expression] = STATE(8442),
    [sym_additive_expression] = STATE(8442),
    [sym_comparison_expression] = STATE(8442),
    [sym_logical_expression] = STATE(8442),
    [sym_ternary_expression] = STATE(8442),
    [sym_unary_expression] = STATE(8442),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8442),
    [sym_list_literal] = STATE(8442),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8442),
    [sym__literal_value] = STATE(8442),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10944),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10946),
    [sym_date_literal] = ACTIONS(10944),
    [sym_time_literal] = ACTIONS(10944),
    [sym_biginteger_literal] = ACTIONS(10946),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10946),
    [sym_verbatim_string] = ACTIONS(10946),
    [sym_integer] = ACTIONS(10944),
    [sym_continue_as_identifier] = ACTIONS(10946),
  },
  [STATE(4629)] = {
    [sym_boolean] = STATE(8747),
    [sym_assignment_expression] = STATE(8747),
    [sym__expression] = STATE(8747),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8747),
    [sym_multiplicative_expression] = STATE(8747),
    [sym_additive_expression] = STATE(8747),
    [sym_comparison_expression] = STATE(8747),
    [sym_logical_expression] = STATE(8747),
    [sym_ternary_expression] = STATE(8747),
    [sym_unary_expression] = STATE(8747),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8747),
    [sym_list_literal] = STATE(8747),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8747),
    [sym__literal_value] = STATE(8747),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10948),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(10950),
    [sym_date_literal] = ACTIONS(10948),
    [sym_time_literal] = ACTIONS(10948),
    [sym_biginteger_literal] = ACTIONS(10950),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10950),
    [sym_verbatim_string] = ACTIONS(10950),
    [sym_integer] = ACTIONS(10948),
    [sym_continue_as_identifier] = ACTIONS(10950),
  },
  [STATE(4630)] = {
    [sym_boolean] = STATE(2274),
    [sym_assignment_expression] = STATE(2274),
    [sym__expression] = STATE(2274),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2274),
    [sym_multiplicative_expression] = STATE(2274),
    [sym_additive_expression] = STATE(2274),
    [sym_comparison_expression] = STATE(2274),
    [sym_logical_expression] = STATE(2274),
    [sym_ternary_expression] = STATE(2274),
    [sym_unary_expression] = STATE(2274),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2274),
    [sym_list_literal] = STATE(2274),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2274),
    [sym__literal_value] = STATE(2274),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10952),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10954),
    [sym_date_literal] = ACTIONS(10952),
    [sym_time_literal] = ACTIONS(10952),
    [sym_biginteger_literal] = ACTIONS(10954),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10954),
    [sym_verbatim_string] = ACTIONS(10954),
    [sym_integer] = ACTIONS(10952),
    [sym_continue_as_identifier] = ACTIONS(10954),
  },
  [STATE(4631)] = {
    [sym_boolean] = STATE(2275),
    [sym_assignment_expression] = STATE(2275),
    [sym__expression] = STATE(2275),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2275),
    [sym_multiplicative_expression] = STATE(2275),
    [sym_additive_expression] = STATE(2275),
    [sym_comparison_expression] = STATE(2275),
    [sym_logical_expression] = STATE(2275),
    [sym_ternary_expression] = STATE(2275),
    [sym_unary_expression] = STATE(2275),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2275),
    [sym_list_literal] = STATE(2275),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2275),
    [sym__literal_value] = STATE(2275),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10956),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10958),
    [sym_date_literal] = ACTIONS(10956),
    [sym_time_literal] = ACTIONS(10956),
    [sym_biginteger_literal] = ACTIONS(10958),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10958),
    [sym_verbatim_string] = ACTIONS(10958),
    [sym_integer] = ACTIONS(10956),
    [sym_continue_as_identifier] = ACTIONS(10958),
  },
  [STATE(4632)] = {
    [sym_boolean] = STATE(2294),
    [sym_assignment_expression] = STATE(2294),
    [sym__expression] = STATE(2294),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2294),
    [sym_multiplicative_expression] = STATE(2294),
    [sym_additive_expression] = STATE(2294),
    [sym_comparison_expression] = STATE(2294),
    [sym_logical_expression] = STATE(2294),
    [sym_ternary_expression] = STATE(2294),
    [sym_unary_expression] = STATE(2294),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2294),
    [sym_list_literal] = STATE(2294),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2294),
    [sym__literal_value] = STATE(2294),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10960),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10962),
    [sym_date_literal] = ACTIONS(10960),
    [sym_time_literal] = ACTIONS(10960),
    [sym_biginteger_literal] = ACTIONS(10962),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10962),
    [sym_verbatim_string] = ACTIONS(10962),
    [sym_integer] = ACTIONS(10960),
    [sym_continue_as_identifier] = ACTIONS(10962),
  },
  [STATE(4633)] = {
    [sym_boolean] = STATE(2277),
    [sym_assignment_expression] = STATE(2277),
    [sym__expression] = STATE(2277),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2277),
    [sym_multiplicative_expression] = STATE(2277),
    [sym_additive_expression] = STATE(2277),
    [sym_comparison_expression] = STATE(2277),
    [sym_logical_expression] = STATE(2277),
    [sym_ternary_expression] = STATE(2277),
    [sym_unary_expression] = STATE(2277),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2277),
    [sym_list_literal] = STATE(2277),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2277),
    [sym__literal_value] = STATE(2277),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10964),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10966),
    [sym_date_literal] = ACTIONS(10964),
    [sym_time_literal] = ACTIONS(10964),
    [sym_biginteger_literal] = ACTIONS(10966),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10966),
    [sym_verbatim_string] = ACTIONS(10966),
    [sym_integer] = ACTIONS(10964),
    [sym_continue_as_identifier] = ACTIONS(10966),
  },
  [STATE(4634)] = {
    [sym_boolean] = STATE(2278),
    [sym_assignment_expression] = STATE(2278),
    [sym__expression] = STATE(2278),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2278),
    [sym_multiplicative_expression] = STATE(2278),
    [sym_additive_expression] = STATE(2278),
    [sym_comparison_expression] = STATE(2278),
    [sym_logical_expression] = STATE(2278),
    [sym_ternary_expression] = STATE(2278),
    [sym_unary_expression] = STATE(2278),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2278),
    [sym_list_literal] = STATE(2278),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2278),
    [sym__literal_value] = STATE(2278),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10968),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10970),
    [sym_date_literal] = ACTIONS(10968),
    [sym_time_literal] = ACTIONS(10968),
    [sym_biginteger_literal] = ACTIONS(10970),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10970),
    [sym_verbatim_string] = ACTIONS(10970),
    [sym_integer] = ACTIONS(10968),
    [sym_continue_as_identifier] = ACTIONS(10970),
  },
  [STATE(4635)] = {
    [sym_boolean] = STATE(2279),
    [sym_assignment_expression] = STATE(2279),
    [sym__expression] = STATE(2279),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2279),
    [sym_multiplicative_expression] = STATE(2279),
    [sym_additive_expression] = STATE(2279),
    [sym_comparison_expression] = STATE(2279),
    [sym_logical_expression] = STATE(2279),
    [sym_ternary_expression] = STATE(2279),
    [sym_unary_expression] = STATE(2279),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2279),
    [sym_list_literal] = STATE(2279),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2279),
    [sym__literal_value] = STATE(2279),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10972),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10974),
    [sym_date_literal] = ACTIONS(10972),
    [sym_time_literal] = ACTIONS(10972),
    [sym_biginteger_literal] = ACTIONS(10974),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10974),
    [sym_verbatim_string] = ACTIONS(10974),
    [sym_integer] = ACTIONS(10972),
    [sym_continue_as_identifier] = ACTIONS(10974),
  },
  [STATE(4636)] = {
    [sym_boolean] = STATE(2280),
    [sym_assignment_expression] = STATE(2280),
    [sym__expression] = STATE(2280),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2280),
    [sym_multiplicative_expression] = STATE(2280),
    [sym_additive_expression] = STATE(2280),
    [sym_comparison_expression] = STATE(2280),
    [sym_logical_expression] = STATE(2280),
    [sym_ternary_expression] = STATE(2280),
    [sym_unary_expression] = STATE(2280),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2280),
    [sym_list_literal] = STATE(2280),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2280),
    [sym__literal_value] = STATE(2280),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10976),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10978),
    [sym_date_literal] = ACTIONS(10976),
    [sym_time_literal] = ACTIONS(10976),
    [sym_biginteger_literal] = ACTIONS(10978),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10978),
    [sym_verbatim_string] = ACTIONS(10978),
    [sym_integer] = ACTIONS(10976),
    [sym_continue_as_identifier] = ACTIONS(10978),
  },
  [STATE(4637)] = {
    [sym_boolean] = STATE(8443),
    [sym_assignment_expression] = STATE(8443),
    [sym__expression] = STATE(8443),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8443),
    [sym_multiplicative_expression] = STATE(8443),
    [sym_additive_expression] = STATE(8443),
    [sym_comparison_expression] = STATE(8443),
    [sym_logical_expression] = STATE(8443),
    [sym_ternary_expression] = STATE(8443),
    [sym_unary_expression] = STATE(8443),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8443),
    [sym_list_literal] = STATE(8443),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8443),
    [sym__literal_value] = STATE(8443),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10980),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10982),
    [sym_date_literal] = ACTIONS(10980),
    [sym_time_literal] = ACTIONS(10980),
    [sym_biginteger_literal] = ACTIONS(10982),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10982),
    [sym_verbatim_string] = ACTIONS(10982),
    [sym_integer] = ACTIONS(10980),
    [sym_continue_as_identifier] = ACTIONS(10982),
  },
  [STATE(4638)] = {
    [sym_boolean] = STATE(2281),
    [sym_assignment_expression] = STATE(2281),
    [sym__expression] = STATE(2281),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2281),
    [sym_multiplicative_expression] = STATE(2281),
    [sym_additive_expression] = STATE(2281),
    [sym_comparison_expression] = STATE(2281),
    [sym_logical_expression] = STATE(2281),
    [sym_ternary_expression] = STATE(2281),
    [sym_unary_expression] = STATE(2281),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2281),
    [sym_list_literal] = STATE(2281),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2281),
    [sym__literal_value] = STATE(2281),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10984),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10986),
    [sym_date_literal] = ACTIONS(10984),
    [sym_time_literal] = ACTIONS(10984),
    [sym_biginteger_literal] = ACTIONS(10986),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10986),
    [sym_verbatim_string] = ACTIONS(10986),
    [sym_integer] = ACTIONS(10984),
    [sym_continue_as_identifier] = ACTIONS(10986),
  },
  [STATE(4639)] = {
    [sym_boolean] = STATE(2282),
    [sym_assignment_expression] = STATE(2282),
    [sym__expression] = STATE(2282),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2282),
    [sym_multiplicative_expression] = STATE(2282),
    [sym_additive_expression] = STATE(2282),
    [sym_comparison_expression] = STATE(2282),
    [sym_logical_expression] = STATE(2282),
    [sym_ternary_expression] = STATE(2282),
    [sym_unary_expression] = STATE(2282),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2282),
    [sym_list_literal] = STATE(2282),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2282),
    [sym__literal_value] = STATE(2282),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10988),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10990),
    [sym_date_literal] = ACTIONS(10988),
    [sym_time_literal] = ACTIONS(10988),
    [sym_biginteger_literal] = ACTIONS(10990),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10990),
    [sym_verbatim_string] = ACTIONS(10990),
    [sym_integer] = ACTIONS(10988),
    [sym_continue_as_identifier] = ACTIONS(10990),
  },
  [STATE(4640)] = {
    [sym_boolean] = STATE(2283),
    [sym_assignment_expression] = STATE(2283),
    [sym__expression] = STATE(2283),
    [sym_keyword_identifier] = STATE(2289),
    [sym_range_expression] = STATE(2283),
    [sym_multiplicative_expression] = STATE(2283),
    [sym_additive_expression] = STATE(2283),
    [sym_comparison_expression] = STATE(2283),
    [sym_logical_expression] = STATE(2283),
    [sym_ternary_expression] = STATE(2283),
    [sym_unary_expression] = STATE(2283),
    [sym_call_expression] = STATE(2303),
    [sym_member_expression] = STATE(2289),
    [sym_subscript_expression] = STATE(2289),
    [sym_parenthesized_expression] = STATE(2283),
    [sym_list_literal] = STATE(2283),
    [sym_qualified_enum_value] = STATE(2289),
    [sym_database_reference] = STATE(2283),
    [sym__literal_value] = STATE(2283),
    [sym_codeunit_keyword] = STATE(2299),
    [sym_xmlport_keyword] = STATE(2299),
    [sym_enum_keyword] = STATE(2308),
    [sym_identifier] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [aux_sym_boolean_token1] = ACTIONS(363),
    [aux_sym_boolean_token2] = ACTIONS(363),
    [sym_decimal] = ACTIONS(10992),
    [anon_sym_LPAREN] = ACTIONS(367),
    [aux_sym_tabledata_permission_token2] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(371),
    [aux_sym_record_type_token1] = ACTIONS(369),
    [aux_sym_basic_type_token21] = ACTIONS(369),
    [aux_sym_basic_type_token22] = ACTIONS(369),
    [aux_sym_basic_type_token48] = ACTIONS(369),
    [anon_sym_not] = ACTIONS(373),
    [anon_sym_NOT] = ACTIONS(373),
    [anon_sym_Not] = ACTIONS(373),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(369),
    [aux_sym_keyword_identifier_token2] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(361),
    [sym_datetime_literal] = ACTIONS(10994),
    [sym_date_literal] = ACTIONS(10992),
    [sym_time_literal] = ACTIONS(10992),
    [sym_biginteger_literal] = ACTIONS(10994),
    [sym_page_keyword] = ACTIONS(379),
    [anon_sym_codeunit] = ACTIONS(385),
    [anon_sym_CODEUNIT] = ACTIONS(385),
    [anon_sym_Codeunit] = ACTIONS(385),
    [anon_sym_CodeUnit] = ACTIONS(385),
    [anon_sym_COdeunit] = ACTIONS(385),
    [anon_sym_codeUnit] = ACTIONS(385),
    [sym_report_keyword] = ACTIONS(379),
    [sym_query_keyword] = ACTIONS(379),
    [anon_sym_xmlport] = ACTIONS(387),
    [anon_sym_XMLPORT] = ACTIONS(387),
    [anon_sym_Xmlport] = ACTIONS(387),
    [anon_sym_XMLport] = ACTIONS(387),
    [anon_sym_XMLPort] = ACTIONS(387),
    [anon_sym_XmlPort] = ACTIONS(387),
    [anon_sym_enum] = ACTIONS(389),
    [anon_sym_ENUM] = ACTIONS(389),
    [anon_sym_Enum] = ACTIONS(389),
    [anon_sym_eNUM] = ACTIONS(389),
    [anon_sym_eNum] = ACTIONS(389),
    [anon_sym_ENum] = ACTIONS(389),
    [sym_quoted_identifier] = ACTIONS(391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10994),
    [sym_verbatim_string] = ACTIONS(10994),
    [sym_integer] = ACTIONS(10992),
    [sym_continue_as_identifier] = ACTIONS(10994),
  },
  [STATE(4641)] = {
    [sym_boolean] = STATE(1875),
    [sym_assignment_expression] = STATE(1875),
    [sym__expression] = STATE(1875),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1875),
    [sym_multiplicative_expression] = STATE(1875),
    [sym_additive_expression] = STATE(1875),
    [sym_comparison_expression] = STATE(1875),
    [sym_logical_expression] = STATE(1875),
    [sym_ternary_expression] = STATE(1875),
    [sym_unary_expression] = STATE(1875),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1875),
    [sym_list_literal] = STATE(1875),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1875),
    [sym__literal_value] = STATE(1875),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(10996),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(10998),
    [sym_date_literal] = ACTIONS(10996),
    [sym_time_literal] = ACTIONS(10996),
    [sym_biginteger_literal] = ACTIONS(10998),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10998),
    [sym_verbatim_string] = ACTIONS(10998),
    [sym_integer] = ACTIONS(10996),
    [sym_continue_as_identifier] = ACTIONS(10998),
  },
  [STATE(4642)] = {
    [sym_boolean] = STATE(1885),
    [sym_assignment_expression] = STATE(1885),
    [sym__expression] = STATE(1885),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1885),
    [sym_multiplicative_expression] = STATE(1885),
    [sym_additive_expression] = STATE(1885),
    [sym_comparison_expression] = STATE(1885),
    [sym_logical_expression] = STATE(1885),
    [sym_ternary_expression] = STATE(1885),
    [sym_unary_expression] = STATE(1885),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1885),
    [sym_list_literal] = STATE(1885),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1885),
    [sym__literal_value] = STATE(1885),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11000),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11002),
    [sym_date_literal] = ACTIONS(11000),
    [sym_time_literal] = ACTIONS(11000),
    [sym_biginteger_literal] = ACTIONS(11002),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11002),
    [sym_verbatim_string] = ACTIONS(11002),
    [sym_integer] = ACTIONS(11000),
    [sym_continue_as_identifier] = ACTIONS(11002),
  },
  [STATE(4643)] = {
    [sym__body_element] = STATE(4775),
    [sym_empty_statement] = STATE(4775),
    [sym_property] = STATE(4775),
    [sym_permissions_property] = STATE(4775),
    [sym_table_relation_property] = STATE(4775),
    [sym_fields_section] = STATE(4775),
    [sym_keys_section] = STATE(4775),
    [sym_fieldgroups_section] = STATE(4775),
    [sym_enum_value_declaration] = STATE(4775),
    [sym_labels_section] = STATE(4775),
    [sym_layout_section] = STATE(4775),
    [sym_modify_modification] = STATE(4775),
    [sym_actions_section] = STATE(4775),
    [sym_views_section] = STATE(4775),
    [sym_dataset_section] = STATE(4775),
    [sym_requestpage_section] = STATE(4775),
    [sym_rendering_section] = STATE(4775),
    [sym_elements_section] = STATE(4775),
    [sym_schema_section] = STATE(4775),
    [sym_xmlport_element] = STATE(4775),
    [sym__xmlport_body_element] = STATE(4775),
    [sym_preproc_conditional_xmlport] = STATE(4775),
    [sym_xmlport_attribute] = STATE(4775),
    [sym_assembly_declaration] = STATE(4775),
    [sym_event_declaration] = STATE(4775),
    [sym_procedure] = STATE(4775),
    [sym_preproc_split_procedure] = STATE(4775),
    [sym_preproc_split_procedure_preamble] = STATE(4775),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4775),
    [sym_var_section] = STATE(4775),
    [sym_attribute_item] = STATE(4775),
    [sym_preproc_conditional] = STATE(4775),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4775),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(11004),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4644)] = {
    [sym_boolean] = STATE(8751),
    [sym_assignment_expression] = STATE(8751),
    [sym__expression] = STATE(8751),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8751),
    [sym_multiplicative_expression] = STATE(8751),
    [sym_additive_expression] = STATE(8751),
    [sym_comparison_expression] = STATE(8751),
    [sym_logical_expression] = STATE(8751),
    [sym_ternary_expression] = STATE(8751),
    [sym_unary_expression] = STATE(8751),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8751),
    [sym_list_literal] = STATE(8751),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8751),
    [sym__literal_value] = STATE(8751),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11006),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11008),
    [sym_date_literal] = ACTIONS(11006),
    [sym_time_literal] = ACTIONS(11006),
    [sym_biginteger_literal] = ACTIONS(11008),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11008),
    [sym_verbatim_string] = ACTIONS(11008),
    [sym_integer] = ACTIONS(11006),
    [sym_continue_as_identifier] = ACTIONS(11008),
  },
  [STATE(4645)] = {
    [sym_boolean] = STATE(8660),
    [sym_assignment_expression] = STATE(8660),
    [sym__expression] = STATE(8660),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8660),
    [sym_multiplicative_expression] = STATE(8660),
    [sym_additive_expression] = STATE(8660),
    [sym_comparison_expression] = STATE(8660),
    [sym_logical_expression] = STATE(8660),
    [sym_ternary_expression] = STATE(8660),
    [sym_unary_expression] = STATE(8660),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8660),
    [sym_list_literal] = STATE(8660),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8660),
    [sym__literal_value] = STATE(8660),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11010),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11012),
    [sym_date_literal] = ACTIONS(11010),
    [sym_time_literal] = ACTIONS(11010),
    [sym_biginteger_literal] = ACTIONS(11012),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11012),
    [sym_verbatim_string] = ACTIONS(11012),
    [sym_integer] = ACTIONS(11010),
    [sym_continue_as_identifier] = ACTIONS(11012),
  },
  [STATE(4646)] = {
    [sym_boolean] = STATE(8730),
    [sym_assignment_expression] = STATE(8730),
    [sym__expression] = STATE(8730),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8730),
    [sym_multiplicative_expression] = STATE(8730),
    [sym_additive_expression] = STATE(8730),
    [sym_comparison_expression] = STATE(8730),
    [sym_logical_expression] = STATE(8730),
    [sym_ternary_expression] = STATE(8730),
    [sym_unary_expression] = STATE(8730),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8730),
    [sym_list_literal] = STATE(8730),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8730),
    [sym__literal_value] = STATE(8730),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11014),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11016),
    [sym_date_literal] = ACTIONS(11014),
    [sym_time_literal] = ACTIONS(11014),
    [sym_biginteger_literal] = ACTIONS(11016),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11016),
    [sym_verbatim_string] = ACTIONS(11016),
    [sym_integer] = ACTIONS(11014),
    [sym_continue_as_identifier] = ACTIONS(11016),
  },
  [STATE(4647)] = {
    [sym_boolean] = STATE(8519),
    [sym_assignment_expression] = STATE(8519),
    [sym__expression] = STATE(8519),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8519),
    [sym_multiplicative_expression] = STATE(8519),
    [sym_additive_expression] = STATE(8519),
    [sym_comparison_expression] = STATE(8519),
    [sym_logical_expression] = STATE(8519),
    [sym_ternary_expression] = STATE(8519),
    [sym_unary_expression] = STATE(8519),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8519),
    [sym_list_literal] = STATE(8519),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8519),
    [sym__literal_value] = STATE(8519),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11018),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11020),
    [sym_date_literal] = ACTIONS(11018),
    [sym_time_literal] = ACTIONS(11018),
    [sym_biginteger_literal] = ACTIONS(11020),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11020),
    [sym_verbatim_string] = ACTIONS(11020),
    [sym_integer] = ACTIONS(11018),
    [sym_continue_as_identifier] = ACTIONS(11020),
  },
  [STATE(4648)] = {
    [sym_boolean] = STATE(8520),
    [sym_assignment_expression] = STATE(8520),
    [sym__expression] = STATE(8520),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8520),
    [sym_multiplicative_expression] = STATE(8520),
    [sym_additive_expression] = STATE(8520),
    [sym_comparison_expression] = STATE(8520),
    [sym_logical_expression] = STATE(8520),
    [sym_ternary_expression] = STATE(8520),
    [sym_unary_expression] = STATE(8520),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8520),
    [sym_list_literal] = STATE(8520),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8520),
    [sym__literal_value] = STATE(8520),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11022),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11024),
    [sym_date_literal] = ACTIONS(11022),
    [sym_time_literal] = ACTIONS(11022),
    [sym_biginteger_literal] = ACTIONS(11024),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11024),
    [sym_verbatim_string] = ACTIONS(11024),
    [sym_integer] = ACTIONS(11022),
    [sym_continue_as_identifier] = ACTIONS(11024),
  },
  [STATE(4649)] = {
    [sym_boolean] = STATE(8521),
    [sym_assignment_expression] = STATE(8521),
    [sym__expression] = STATE(8521),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8521),
    [sym_multiplicative_expression] = STATE(8521),
    [sym_additive_expression] = STATE(8521),
    [sym_comparison_expression] = STATE(8521),
    [sym_logical_expression] = STATE(8521),
    [sym_ternary_expression] = STATE(8521),
    [sym_unary_expression] = STATE(8521),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8521),
    [sym_list_literal] = STATE(8521),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8521),
    [sym__literal_value] = STATE(8521),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11026),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11028),
    [sym_date_literal] = ACTIONS(11026),
    [sym_time_literal] = ACTIONS(11026),
    [sym_biginteger_literal] = ACTIONS(11028),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11028),
    [sym_verbatim_string] = ACTIONS(11028),
    [sym_integer] = ACTIONS(11026),
    [sym_continue_as_identifier] = ACTIONS(11028),
  },
  [STATE(4650)] = {
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(3705),
    [aux_sym_where_clause_token1] = ACTIONS(3705),
    [aux_sym_where_condition_token1] = ACTIONS(3703),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3705),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3705),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3705),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_basic_type_token6] = ACTIONS(3703),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3705),
    [aux_sym_addafter_modification_token1] = ACTIONS(3705),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3705),
    [aux_sym_modify_modification_token1] = ACTIONS(3705),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3705),
    [aux_sym_movelast_modification_token1] = ACTIONS(3705),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3705),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3705),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3705),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [anon_sym_POUNDelif] = ACTIONS(3705),
    [anon_sym_POUNDELIF] = ACTIONS(3705),
    [anon_sym_POUNDElif] = ACTIONS(3705),
    [anon_sym_POUNDelse] = ACTIONS(3705),
    [anon_sym_POUNDELSE] = ACTIONS(3705),
    [anon_sym_POUNDElse] = ACTIONS(3705),
    [anon_sym_POUNDelse2] = ACTIONS(3705),
    [anon_sym_POUNDELSE2] = ACTIONS(3705),
    [anon_sym_POUNDElse2] = ACTIONS(3705),
    [anon_sym_POUNDendif] = ACTIONS(3705),
    [anon_sym_POUNDENDIF] = ACTIONS(3705),
    [anon_sym_POUNDEndif] = ACTIONS(3705),
    [anon_sym_POUNDendif2] = ACTIONS(3705),
    [anon_sym_POUNDENDIF2] = ACTIONS(3705),
    [anon_sym_POUNDEndif2] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3705),
    [sym_trigger_keyword] = ACTIONS(3705),
    [sym_var_keyword] = ACTIONS(3705),
    [sym_local_keyword] = ACTIONS(3705),
    [sym_internal_keyword] = ACTIONS(3705),
    [sym_protected_keyword] = ACTIONS(3705),
    [sym_event_keyword] = ACTIONS(3705),
    [sym_fields_keyword] = ACTIONS(3705),
    [sym_keys_keyword] = ACTIONS(3705),
    [sym_fieldgroups_keyword] = ACTIONS(3705),
    [sym_actions_keyword] = ACTIONS(3705),
    [sym_layout_keyword] = ACTIONS(3705),
    [sym_area_keyword] = ACTIONS(3705),
    [sym_group_keyword] = ACTIONS(3705),
    [sym_repeater_keyword] = ACTIONS(3705),
    [sym_cuegroup_keyword] = ACTIONS(3705),
    [sym_fixed_keyword] = ACTIONS(3705),
    [sym_grid_keyword] = ACTIONS(3705),
    [sym_part_keyword] = ACTIONS(3705),
    [sym_systempart_keyword] = ACTIONS(3705),
    [sym_usercontrol_keyword] = ACTIONS(3705),
    [sym_dataset_keyword] = ACTIONS(3705),
    [sym_elements_keyword] = ACTIONS(3705),
    [sym_dataitem_keyword] = ACTIONS(3705),
    [sym_column_keyword] = ACTIONS(3705),
    [sym_filter_keyword] = ACTIONS(3705),
    [sym_labels_keyword] = ACTIONS(3705),
    [sym_rendering_keyword] = ACTIONS(3705),
    [sym_requestpage_keyword] = ACTIONS(3705),
    [sym_schema_keyword] = ACTIONS(3705),
    [sym_views_keyword] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
    [sym_preproc_close] = ACTIONS(3705),
  },
  [STATE(4651)] = {
    [sym_boolean] = STATE(1888),
    [sym_assignment_expression] = STATE(1888),
    [sym__expression] = STATE(1888),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1888),
    [sym_multiplicative_expression] = STATE(1888),
    [sym_additive_expression] = STATE(1888),
    [sym_comparison_expression] = STATE(1888),
    [sym_logical_expression] = STATE(1888),
    [sym_ternary_expression] = STATE(1888),
    [sym_unary_expression] = STATE(1888),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1888),
    [sym_list_literal] = STATE(1888),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1888),
    [sym__literal_value] = STATE(1888),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11030),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11032),
    [sym_date_literal] = ACTIONS(11030),
    [sym_time_literal] = ACTIONS(11030),
    [sym_biginteger_literal] = ACTIONS(11032),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11032),
    [sym_verbatim_string] = ACTIONS(11032),
    [sym_integer] = ACTIONS(11030),
    [sym_continue_as_identifier] = ACTIONS(11032),
  },
  [STATE(4652)] = {
    [sym_boolean] = STATE(8733),
    [sym_assignment_expression] = STATE(8733),
    [sym__expression] = STATE(8733),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8733),
    [sym_multiplicative_expression] = STATE(8733),
    [sym_additive_expression] = STATE(8733),
    [sym_comparison_expression] = STATE(8733),
    [sym_logical_expression] = STATE(8733),
    [sym_ternary_expression] = STATE(8733),
    [sym_unary_expression] = STATE(8733),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8733),
    [sym_list_literal] = STATE(8733),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8733),
    [sym__literal_value] = STATE(8733),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11034),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11036),
    [sym_date_literal] = ACTIONS(11034),
    [sym_time_literal] = ACTIONS(11034),
    [sym_biginteger_literal] = ACTIONS(11036),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11036),
    [sym_verbatim_string] = ACTIONS(11036),
    [sym_integer] = ACTIONS(11034),
    [sym_continue_as_identifier] = ACTIONS(11036),
  },
  [STATE(4653)] = {
    [sym_boolean] = STATE(8612),
    [sym_assignment_expression] = STATE(8612),
    [sym__expression] = STATE(8612),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8612),
    [sym_multiplicative_expression] = STATE(8612),
    [sym_additive_expression] = STATE(8612),
    [sym_comparison_expression] = STATE(8612),
    [sym_logical_expression] = STATE(8612),
    [sym_ternary_expression] = STATE(8612),
    [sym_unary_expression] = STATE(8612),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8612),
    [sym_list_literal] = STATE(8612),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8612),
    [sym__literal_value] = STATE(8612),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11038),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11040),
    [sym_date_literal] = ACTIONS(11038),
    [sym_time_literal] = ACTIONS(11038),
    [sym_biginteger_literal] = ACTIONS(11040),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11040),
    [sym_verbatim_string] = ACTIONS(11040),
    [sym_integer] = ACTIONS(11038),
    [sym_continue_as_identifier] = ACTIONS(11040),
  },
  [STATE(4654)] = {
    [sym_boolean] = STATE(7417),
    [sym_assignment_expression] = STATE(7417),
    [sym__expression] = STATE(7417),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7417),
    [sym_multiplicative_expression] = STATE(7417),
    [sym_additive_expression] = STATE(7417),
    [sym_comparison_expression] = STATE(7417),
    [sym_logical_expression] = STATE(7417),
    [sym_ternary_expression] = STATE(7417),
    [sym_unary_expression] = STATE(7417),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7417),
    [sym_list_literal] = STATE(7417),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7417),
    [sym__literal_value] = STATE(7417),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11042),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11044),
    [sym_date_literal] = ACTIONS(11042),
    [sym_time_literal] = ACTIONS(11042),
    [sym_biginteger_literal] = ACTIONS(11044),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11044),
    [sym_verbatim_string] = ACTIONS(11044),
    [sym_integer] = ACTIONS(11042),
    [sym_continue_as_identifier] = ACTIONS(11044),
  },
  [STATE(4655)] = {
    [sym_boolean] = STATE(8713),
    [sym_assignment_expression] = STATE(8713),
    [sym__expression] = STATE(8713),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8713),
    [sym_multiplicative_expression] = STATE(8713),
    [sym_additive_expression] = STATE(8713),
    [sym_comparison_expression] = STATE(8713),
    [sym_logical_expression] = STATE(8713),
    [sym_ternary_expression] = STATE(8713),
    [sym_unary_expression] = STATE(8713),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8713),
    [sym_list_literal] = STATE(8713),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8713),
    [sym__literal_value] = STATE(8713),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11046),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11048),
    [sym_date_literal] = ACTIONS(11046),
    [sym_time_literal] = ACTIONS(11046),
    [sym_biginteger_literal] = ACTIONS(11048),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11048),
    [sym_verbatim_string] = ACTIONS(11048),
    [sym_integer] = ACTIONS(11046),
    [sym_continue_as_identifier] = ACTIONS(11048),
  },
  [STATE(4656)] = {
    [sym_boolean] = STATE(8638),
    [sym_assignment_expression] = STATE(8638),
    [sym__expression] = STATE(8638),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8638),
    [sym_multiplicative_expression] = STATE(8638),
    [sym_additive_expression] = STATE(8638),
    [sym_comparison_expression] = STATE(8638),
    [sym_logical_expression] = STATE(8638),
    [sym_ternary_expression] = STATE(8638),
    [sym_unary_expression] = STATE(8638),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8638),
    [sym_list_literal] = STATE(8638),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8638),
    [sym__literal_value] = STATE(8638),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11050),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11052),
    [sym_date_literal] = ACTIONS(11050),
    [sym_time_literal] = ACTIONS(11050),
    [sym_biginteger_literal] = ACTIONS(11052),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11052),
    [sym_verbatim_string] = ACTIONS(11052),
    [sym_integer] = ACTIONS(11050),
    [sym_continue_as_identifier] = ACTIONS(11052),
  },
  [STATE(4657)] = {
    [sym_boolean] = STATE(7436),
    [sym_assignment_expression] = STATE(7436),
    [sym__expression] = STATE(7436),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7436),
    [sym_multiplicative_expression] = STATE(7436),
    [sym_additive_expression] = STATE(7436),
    [sym_comparison_expression] = STATE(7436),
    [sym_logical_expression] = STATE(7436),
    [sym_ternary_expression] = STATE(7436),
    [sym_unary_expression] = STATE(7436),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7436),
    [sym_list_literal] = STATE(7436),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7436),
    [sym__literal_value] = STATE(7436),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11054),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11056),
    [sym_date_literal] = ACTIONS(11054),
    [sym_time_literal] = ACTIONS(11054),
    [sym_biginteger_literal] = ACTIONS(11056),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11056),
    [sym_verbatim_string] = ACTIONS(11056),
    [sym_integer] = ACTIONS(11054),
    [sym_continue_as_identifier] = ACTIONS(11056),
  },
  [STATE(4658)] = {
    [sym_boolean] = STATE(8618),
    [sym_assignment_expression] = STATE(8618),
    [sym__expression] = STATE(8618),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8618),
    [sym_multiplicative_expression] = STATE(8618),
    [sym_additive_expression] = STATE(8618),
    [sym_comparison_expression] = STATE(8618),
    [sym_logical_expression] = STATE(8618),
    [sym_ternary_expression] = STATE(8618),
    [sym_unary_expression] = STATE(8618),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8618),
    [sym_list_literal] = STATE(8618),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8618),
    [sym__literal_value] = STATE(8618),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11058),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11060),
    [sym_date_literal] = ACTIONS(11058),
    [sym_time_literal] = ACTIONS(11058),
    [sym_biginteger_literal] = ACTIONS(11060),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11060),
    [sym_verbatim_string] = ACTIONS(11060),
    [sym_integer] = ACTIONS(11058),
    [sym_continue_as_identifier] = ACTIONS(11060),
  },
  [STATE(4659)] = {
    [sym_boolean] = STATE(8619),
    [sym_assignment_expression] = STATE(8619),
    [sym__expression] = STATE(8619),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8619),
    [sym_multiplicative_expression] = STATE(8619),
    [sym_additive_expression] = STATE(8619),
    [sym_comparison_expression] = STATE(8619),
    [sym_logical_expression] = STATE(8619),
    [sym_ternary_expression] = STATE(8619),
    [sym_unary_expression] = STATE(8619),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8619),
    [sym_list_literal] = STATE(8619),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8619),
    [sym__literal_value] = STATE(8619),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11062),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11064),
    [sym_date_literal] = ACTIONS(11062),
    [sym_time_literal] = ACTIONS(11062),
    [sym_biginteger_literal] = ACTIONS(11064),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11064),
    [sym_verbatim_string] = ACTIONS(11064),
    [sym_integer] = ACTIONS(11062),
    [sym_continue_as_identifier] = ACTIONS(11064),
  },
  [STATE(4660)] = {
    [sym_boolean] = STATE(8496),
    [sym_assignment_expression] = STATE(8496),
    [sym__expression] = STATE(8496),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8496),
    [sym_multiplicative_expression] = STATE(8496),
    [sym_additive_expression] = STATE(8496),
    [sym_comparison_expression] = STATE(8496),
    [sym_logical_expression] = STATE(8496),
    [sym_ternary_expression] = STATE(8496),
    [sym_unary_expression] = STATE(8496),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8496),
    [sym_list_literal] = STATE(8496),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8496),
    [sym__literal_value] = STATE(8496),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11066),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11068),
    [sym_date_literal] = ACTIONS(11066),
    [sym_time_literal] = ACTIONS(11066),
    [sym_biginteger_literal] = ACTIONS(11068),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11068),
    [sym_verbatim_string] = ACTIONS(11068),
    [sym_integer] = ACTIONS(11066),
    [sym_continue_as_identifier] = ACTIONS(11068),
  },
  [STATE(4661)] = {
    [sym_boolean] = STATE(1893),
    [sym_assignment_expression] = STATE(1893),
    [sym__expression] = STATE(1893),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1893),
    [sym_multiplicative_expression] = STATE(1893),
    [sym_additive_expression] = STATE(1893),
    [sym_comparison_expression] = STATE(1893),
    [sym_logical_expression] = STATE(1893),
    [sym_ternary_expression] = STATE(1893),
    [sym_unary_expression] = STATE(1893),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1893),
    [sym_list_literal] = STATE(1893),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1893),
    [sym__literal_value] = STATE(1893),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11070),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11072),
    [sym_date_literal] = ACTIONS(11070),
    [sym_time_literal] = ACTIONS(11070),
    [sym_biginteger_literal] = ACTIONS(11072),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11072),
    [sym_verbatim_string] = ACTIONS(11072),
    [sym_integer] = ACTIONS(11070),
    [sym_continue_as_identifier] = ACTIONS(11072),
  },
  [STATE(4662)] = {
    [sym_boolean] = STATE(1898),
    [sym_assignment_expression] = STATE(1898),
    [sym__expression] = STATE(1898),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1898),
    [sym_multiplicative_expression] = STATE(1898),
    [sym_additive_expression] = STATE(1898),
    [sym_comparison_expression] = STATE(1898),
    [sym_logical_expression] = STATE(1898),
    [sym_ternary_expression] = STATE(1898),
    [sym_unary_expression] = STATE(1898),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1898),
    [sym_list_literal] = STATE(1898),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1898),
    [sym__literal_value] = STATE(1898),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11074),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11076),
    [sym_date_literal] = ACTIONS(11074),
    [sym_time_literal] = ACTIONS(11074),
    [sym_biginteger_literal] = ACTIONS(11076),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11076),
    [sym_verbatim_string] = ACTIONS(11076),
    [sym_integer] = ACTIONS(11074),
    [sym_continue_as_identifier] = ACTIONS(11076),
  },
  [STATE(4663)] = {
    [sym_boolean] = STATE(8717),
    [sym_assignment_expression] = STATE(8717),
    [sym__expression] = STATE(8717),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8717),
    [sym_multiplicative_expression] = STATE(8717),
    [sym_additive_expression] = STATE(8717),
    [sym_comparison_expression] = STATE(8717),
    [sym_logical_expression] = STATE(8717),
    [sym_ternary_expression] = STATE(8717),
    [sym_unary_expression] = STATE(8717),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8717),
    [sym_list_literal] = STATE(8717),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8717),
    [sym__literal_value] = STATE(8717),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11078),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11080),
    [sym_date_literal] = ACTIONS(11078),
    [sym_time_literal] = ACTIONS(11078),
    [sym_biginteger_literal] = ACTIONS(11080),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11080),
    [sym_verbatim_string] = ACTIONS(11080),
    [sym_integer] = ACTIONS(11078),
    [sym_continue_as_identifier] = ACTIONS(11080),
  },
  [STATE(4664)] = {
    [sym_boolean] = STATE(8722),
    [sym_assignment_expression] = STATE(8722),
    [sym__expression] = STATE(8722),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8722),
    [sym_multiplicative_expression] = STATE(8722),
    [sym_additive_expression] = STATE(8722),
    [sym_comparison_expression] = STATE(8722),
    [sym_logical_expression] = STATE(8722),
    [sym_ternary_expression] = STATE(8722),
    [sym_unary_expression] = STATE(8722),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8722),
    [sym_list_literal] = STATE(8722),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8722),
    [sym__literal_value] = STATE(8722),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11082),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11084),
    [sym_date_literal] = ACTIONS(11082),
    [sym_time_literal] = ACTIONS(11082),
    [sym_biginteger_literal] = ACTIONS(11084),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11084),
    [sym_verbatim_string] = ACTIONS(11084),
    [sym_integer] = ACTIONS(11082),
    [sym_continue_as_identifier] = ACTIONS(11084),
  },
  [STATE(4665)] = {
    [sym_boolean] = STATE(8774),
    [sym_assignment_expression] = STATE(8774),
    [sym__expression] = STATE(8774),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8774),
    [sym_multiplicative_expression] = STATE(8774),
    [sym_additive_expression] = STATE(8774),
    [sym_comparison_expression] = STATE(8774),
    [sym_logical_expression] = STATE(8774),
    [sym_ternary_expression] = STATE(8774),
    [sym_unary_expression] = STATE(8774),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8774),
    [sym_list_literal] = STATE(8774),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8774),
    [sym__literal_value] = STATE(8774),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11086),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11088),
    [sym_date_literal] = ACTIONS(11086),
    [sym_time_literal] = ACTIONS(11086),
    [sym_biginteger_literal] = ACTIONS(11088),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11088),
    [sym_verbatim_string] = ACTIONS(11088),
    [sym_integer] = ACTIONS(11086),
    [sym_continue_as_identifier] = ACTIONS(11088),
  },
  [STATE(4666)] = {
    [sym_boolean] = STATE(8772),
    [sym_assignment_expression] = STATE(8772),
    [sym__expression] = STATE(8772),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8772),
    [sym_multiplicative_expression] = STATE(8772),
    [sym_additive_expression] = STATE(8772),
    [sym_comparison_expression] = STATE(8772),
    [sym_logical_expression] = STATE(8772),
    [sym_ternary_expression] = STATE(8772),
    [sym_unary_expression] = STATE(8772),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8772),
    [sym_list_literal] = STATE(8772),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8772),
    [sym__literal_value] = STATE(8772),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11090),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11092),
    [sym_date_literal] = ACTIONS(11090),
    [sym_time_literal] = ACTIONS(11090),
    [sym_biginteger_literal] = ACTIONS(11092),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11092),
    [sym_verbatim_string] = ACTIONS(11092),
    [sym_integer] = ACTIONS(11090),
    [sym_continue_as_identifier] = ACTIONS(11092),
  },
  [STATE(4667)] = {
    [sym_boolean] = STATE(8754),
    [sym_assignment_expression] = STATE(8754),
    [sym__expression] = STATE(8754),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8754),
    [sym_multiplicative_expression] = STATE(8754),
    [sym_additive_expression] = STATE(8754),
    [sym_comparison_expression] = STATE(8754),
    [sym_logical_expression] = STATE(8754),
    [sym_ternary_expression] = STATE(8754),
    [sym_unary_expression] = STATE(8754),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8754),
    [sym_list_literal] = STATE(8754),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8754),
    [sym__literal_value] = STATE(8754),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11094),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11096),
    [sym_date_literal] = ACTIONS(11094),
    [sym_time_literal] = ACTIONS(11094),
    [sym_biginteger_literal] = ACTIONS(11096),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11096),
    [sym_verbatim_string] = ACTIONS(11096),
    [sym_integer] = ACTIONS(11094),
    [sym_continue_as_identifier] = ACTIONS(11096),
  },
  [STATE(4668)] = {
    [sym_boolean] = STATE(8708),
    [sym_assignment_expression] = STATE(8708),
    [sym__expression] = STATE(8708),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8708),
    [sym_multiplicative_expression] = STATE(8708),
    [sym_additive_expression] = STATE(8708),
    [sym_comparison_expression] = STATE(8708),
    [sym_logical_expression] = STATE(8708),
    [sym_ternary_expression] = STATE(8708),
    [sym_unary_expression] = STATE(8708),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8708),
    [sym_list_literal] = STATE(8708),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8708),
    [sym__literal_value] = STATE(8708),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11098),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11100),
    [sym_date_literal] = ACTIONS(11098),
    [sym_time_literal] = ACTIONS(11098),
    [sym_biginteger_literal] = ACTIONS(11100),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11100),
    [sym_verbatim_string] = ACTIONS(11100),
    [sym_integer] = ACTIONS(11098),
    [sym_continue_as_identifier] = ACTIONS(11100),
  },
  [STATE(4669)] = {
    [sym_boolean] = STATE(8727),
    [sym_assignment_expression] = STATE(8727),
    [sym__expression] = STATE(8727),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8727),
    [sym_multiplicative_expression] = STATE(8727),
    [sym_additive_expression] = STATE(8727),
    [sym_comparison_expression] = STATE(8727),
    [sym_logical_expression] = STATE(8727),
    [sym_ternary_expression] = STATE(8727),
    [sym_unary_expression] = STATE(8727),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8727),
    [sym_list_literal] = STATE(8727),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8727),
    [sym__literal_value] = STATE(8727),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11102),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11104),
    [sym_date_literal] = ACTIONS(11102),
    [sym_time_literal] = ACTIONS(11102),
    [sym_biginteger_literal] = ACTIONS(11104),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11104),
    [sym_verbatim_string] = ACTIONS(11104),
    [sym_integer] = ACTIONS(11102),
    [sym_continue_as_identifier] = ACTIONS(11104),
  },
  [STATE(4670)] = {
    [sym_boolean] = STATE(8734),
    [sym_assignment_expression] = STATE(8734),
    [sym__expression] = STATE(8734),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8734),
    [sym_multiplicative_expression] = STATE(8734),
    [sym_additive_expression] = STATE(8734),
    [sym_comparison_expression] = STATE(8734),
    [sym_logical_expression] = STATE(8734),
    [sym_ternary_expression] = STATE(8734),
    [sym_unary_expression] = STATE(8734),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8734),
    [sym_list_literal] = STATE(8734),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8734),
    [sym__literal_value] = STATE(8734),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11106),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11108),
    [sym_date_literal] = ACTIONS(11106),
    [sym_time_literal] = ACTIONS(11106),
    [sym_biginteger_literal] = ACTIONS(11108),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11108),
    [sym_verbatim_string] = ACTIONS(11108),
    [sym_integer] = ACTIONS(11106),
    [sym_continue_as_identifier] = ACTIONS(11108),
  },
  [STATE(4671)] = {
    [sym_boolean] = STATE(8740),
    [sym_assignment_expression] = STATE(8740),
    [sym__expression] = STATE(8740),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8740),
    [sym_multiplicative_expression] = STATE(8740),
    [sym_additive_expression] = STATE(8740),
    [sym_comparison_expression] = STATE(8740),
    [sym_logical_expression] = STATE(8740),
    [sym_ternary_expression] = STATE(8740),
    [sym_unary_expression] = STATE(8740),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8740),
    [sym_list_literal] = STATE(8740),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8740),
    [sym__literal_value] = STATE(8740),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11110),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11112),
    [sym_date_literal] = ACTIONS(11110),
    [sym_time_literal] = ACTIONS(11110),
    [sym_biginteger_literal] = ACTIONS(11112),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11112),
    [sym_verbatim_string] = ACTIONS(11112),
    [sym_integer] = ACTIONS(11110),
    [sym_continue_as_identifier] = ACTIONS(11112),
  },
  [STATE(4672)] = {
    [sym_boolean] = STATE(8715),
    [sym_assignment_expression] = STATE(8715),
    [sym__expression] = STATE(8715),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8715),
    [sym_multiplicative_expression] = STATE(8715),
    [sym_additive_expression] = STATE(8715),
    [sym_comparison_expression] = STATE(8715),
    [sym_logical_expression] = STATE(8715),
    [sym_ternary_expression] = STATE(8715),
    [sym_unary_expression] = STATE(8715),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8715),
    [sym_list_literal] = STATE(8715),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8715),
    [sym__literal_value] = STATE(8715),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11114),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11116),
    [sym_date_literal] = ACTIONS(11114),
    [sym_time_literal] = ACTIONS(11114),
    [sym_biginteger_literal] = ACTIONS(11116),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11116),
    [sym_verbatim_string] = ACTIONS(11116),
    [sym_integer] = ACTIONS(11114),
    [sym_continue_as_identifier] = ACTIONS(11116),
  },
  [STATE(4673)] = {
    [sym_boolean] = STATE(8735),
    [sym_assignment_expression] = STATE(8735),
    [sym__expression] = STATE(8735),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8735),
    [sym_multiplicative_expression] = STATE(8735),
    [sym_additive_expression] = STATE(8735),
    [sym_comparison_expression] = STATE(8735),
    [sym_logical_expression] = STATE(8735),
    [sym_ternary_expression] = STATE(8735),
    [sym_unary_expression] = STATE(8735),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8735),
    [sym_list_literal] = STATE(8735),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8735),
    [sym__literal_value] = STATE(8735),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11118),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11120),
    [sym_date_literal] = ACTIONS(11118),
    [sym_time_literal] = ACTIONS(11118),
    [sym_biginteger_literal] = ACTIONS(11120),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11120),
    [sym_verbatim_string] = ACTIONS(11120),
    [sym_integer] = ACTIONS(11118),
    [sym_continue_as_identifier] = ACTIONS(11120),
  },
  [STATE(4674)] = {
    [sym_boolean] = STATE(8746),
    [sym_assignment_expression] = STATE(8746),
    [sym__expression] = STATE(8746),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8746),
    [sym_multiplicative_expression] = STATE(8746),
    [sym_additive_expression] = STATE(8746),
    [sym_comparison_expression] = STATE(8746),
    [sym_logical_expression] = STATE(8746),
    [sym_ternary_expression] = STATE(8746),
    [sym_unary_expression] = STATE(8746),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8746),
    [sym_list_literal] = STATE(8746),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8746),
    [sym__literal_value] = STATE(8746),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11122),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11124),
    [sym_date_literal] = ACTIONS(11122),
    [sym_time_literal] = ACTIONS(11122),
    [sym_biginteger_literal] = ACTIONS(11124),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11124),
    [sym_verbatim_string] = ACTIONS(11124),
    [sym_integer] = ACTIONS(11122),
    [sym_continue_as_identifier] = ACTIONS(11124),
  },
  [STATE(4675)] = {
    [sym_boolean] = STATE(8761),
    [sym_assignment_expression] = STATE(8761),
    [sym__expression] = STATE(8761),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8761),
    [sym_multiplicative_expression] = STATE(8761),
    [sym_additive_expression] = STATE(8761),
    [sym_comparison_expression] = STATE(8761),
    [sym_logical_expression] = STATE(8761),
    [sym_ternary_expression] = STATE(8761),
    [sym_unary_expression] = STATE(8761),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8761),
    [sym_list_literal] = STATE(8761),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8761),
    [sym__literal_value] = STATE(8761),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11126),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11128),
    [sym_date_literal] = ACTIONS(11126),
    [sym_time_literal] = ACTIONS(11126),
    [sym_biginteger_literal] = ACTIONS(11128),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11128),
    [sym_verbatim_string] = ACTIONS(11128),
    [sym_integer] = ACTIONS(11126),
    [sym_continue_as_identifier] = ACTIONS(11128),
  },
  [STATE(4676)] = {
    [sym_boolean] = STATE(8763),
    [sym_assignment_expression] = STATE(8763),
    [sym__expression] = STATE(8763),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8763),
    [sym_multiplicative_expression] = STATE(8763),
    [sym_additive_expression] = STATE(8763),
    [sym_comparison_expression] = STATE(8763),
    [sym_logical_expression] = STATE(8763),
    [sym_ternary_expression] = STATE(8763),
    [sym_unary_expression] = STATE(8763),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8763),
    [sym_list_literal] = STATE(8763),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8763),
    [sym__literal_value] = STATE(8763),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11130),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11132),
    [sym_date_literal] = ACTIONS(11130),
    [sym_time_literal] = ACTIONS(11130),
    [sym_biginteger_literal] = ACTIONS(11132),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11132),
    [sym_verbatim_string] = ACTIONS(11132),
    [sym_integer] = ACTIONS(11130),
    [sym_continue_as_identifier] = ACTIONS(11132),
  },
  [STATE(4677)] = {
    [sym_boolean] = STATE(1916),
    [sym_assignment_expression] = STATE(1916),
    [sym__expression] = STATE(1916),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1916),
    [sym_multiplicative_expression] = STATE(1916),
    [sym_additive_expression] = STATE(1916),
    [sym_comparison_expression] = STATE(1916),
    [sym_logical_expression] = STATE(1916),
    [sym_ternary_expression] = STATE(1916),
    [sym_unary_expression] = STATE(1916),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1916),
    [sym_list_literal] = STATE(1916),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1916),
    [sym__literal_value] = STATE(1916),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11134),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11136),
    [sym_date_literal] = ACTIONS(11134),
    [sym_time_literal] = ACTIONS(11134),
    [sym_biginteger_literal] = ACTIONS(11136),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11136),
    [sym_verbatim_string] = ACTIONS(11136),
    [sym_integer] = ACTIONS(11134),
    [sym_continue_as_identifier] = ACTIONS(11136),
  },
  [STATE(4678)] = {
    [sym_boolean] = STATE(8769),
    [sym_assignment_expression] = STATE(8769),
    [sym__expression] = STATE(8769),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8769),
    [sym_multiplicative_expression] = STATE(8769),
    [sym_additive_expression] = STATE(8769),
    [sym_comparison_expression] = STATE(8769),
    [sym_logical_expression] = STATE(8769),
    [sym_ternary_expression] = STATE(8769),
    [sym_unary_expression] = STATE(8769),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8769),
    [sym_list_literal] = STATE(8769),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8769),
    [sym__literal_value] = STATE(8769),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11138),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11140),
    [sym_date_literal] = ACTIONS(11138),
    [sym_time_literal] = ACTIONS(11138),
    [sym_biginteger_literal] = ACTIONS(11140),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11140),
    [sym_verbatim_string] = ACTIONS(11140),
    [sym_integer] = ACTIONS(11138),
    [sym_continue_as_identifier] = ACTIONS(11140),
  },
  [STATE(4679)] = {
    [sym_boolean] = STATE(8770),
    [sym_assignment_expression] = STATE(8770),
    [sym__expression] = STATE(8770),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8770),
    [sym_multiplicative_expression] = STATE(8770),
    [sym_additive_expression] = STATE(8770),
    [sym_comparison_expression] = STATE(8770),
    [sym_logical_expression] = STATE(8770),
    [sym_ternary_expression] = STATE(8770),
    [sym_unary_expression] = STATE(8770),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8770),
    [sym_list_literal] = STATE(8770),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8770),
    [sym__literal_value] = STATE(8770),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11142),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11144),
    [sym_date_literal] = ACTIONS(11142),
    [sym_time_literal] = ACTIONS(11142),
    [sym_biginteger_literal] = ACTIONS(11144),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11144),
    [sym_verbatim_string] = ACTIONS(11144),
    [sym_integer] = ACTIONS(11142),
    [sym_continue_as_identifier] = ACTIONS(11144),
  },
  [STATE(4680)] = {
    [sym_boolean] = STATE(8778),
    [sym_assignment_expression] = STATE(8778),
    [sym__expression] = STATE(8778),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8778),
    [sym_multiplicative_expression] = STATE(8778),
    [sym_additive_expression] = STATE(8778),
    [sym_comparison_expression] = STATE(8778),
    [sym_logical_expression] = STATE(8778),
    [sym_ternary_expression] = STATE(8778),
    [sym_unary_expression] = STATE(8778),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8778),
    [sym_list_literal] = STATE(8778),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8778),
    [sym__literal_value] = STATE(8778),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11146),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11148),
    [sym_date_literal] = ACTIONS(11146),
    [sym_time_literal] = ACTIONS(11146),
    [sym_biginteger_literal] = ACTIONS(11148),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11148),
    [sym_verbatim_string] = ACTIONS(11148),
    [sym_integer] = ACTIONS(11146),
    [sym_continue_as_identifier] = ACTIONS(11148),
  },
  [STATE(4681)] = {
    [sym_boolean] = STATE(8779),
    [sym_assignment_expression] = STATE(8779),
    [sym__expression] = STATE(8779),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8779),
    [sym_multiplicative_expression] = STATE(8779),
    [sym_additive_expression] = STATE(8779),
    [sym_comparison_expression] = STATE(8779),
    [sym_logical_expression] = STATE(8779),
    [sym_ternary_expression] = STATE(8779),
    [sym_unary_expression] = STATE(8779),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8779),
    [sym_list_literal] = STATE(8779),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8779),
    [sym__literal_value] = STATE(8779),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11150),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11152),
    [sym_date_literal] = ACTIONS(11150),
    [sym_time_literal] = ACTIONS(11150),
    [sym_biginteger_literal] = ACTIONS(11152),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11152),
    [sym_verbatim_string] = ACTIONS(11152),
    [sym_integer] = ACTIONS(11150),
    [sym_continue_as_identifier] = ACTIONS(11152),
  },
  [STATE(4682)] = {
    [sym_boolean] = STATE(1918),
    [sym_assignment_expression] = STATE(1918),
    [sym__expression] = STATE(1918),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1918),
    [sym_multiplicative_expression] = STATE(1918),
    [sym_additive_expression] = STATE(1918),
    [sym_comparison_expression] = STATE(1918),
    [sym_logical_expression] = STATE(1918),
    [sym_ternary_expression] = STATE(1918),
    [sym_unary_expression] = STATE(1918),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1918),
    [sym_list_literal] = STATE(1918),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1918),
    [sym__literal_value] = STATE(1918),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11154),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11156),
    [sym_date_literal] = ACTIONS(11154),
    [sym_time_literal] = ACTIONS(11154),
    [sym_biginteger_literal] = ACTIONS(11156),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11156),
    [sym_verbatim_string] = ACTIONS(11156),
    [sym_integer] = ACTIONS(11154),
    [sym_continue_as_identifier] = ACTIONS(11156),
  },
  [STATE(4683)] = {
    [sym_boolean] = STATE(1919),
    [sym_assignment_expression] = STATE(1919),
    [sym__expression] = STATE(1919),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1919),
    [sym_multiplicative_expression] = STATE(1919),
    [sym_additive_expression] = STATE(1919),
    [sym_comparison_expression] = STATE(1919),
    [sym_logical_expression] = STATE(1919),
    [sym_ternary_expression] = STATE(1919),
    [sym_unary_expression] = STATE(1919),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1919),
    [sym_list_literal] = STATE(1919),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1919),
    [sym__literal_value] = STATE(1919),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11158),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11160),
    [sym_date_literal] = ACTIONS(11158),
    [sym_time_literal] = ACTIONS(11158),
    [sym_biginteger_literal] = ACTIONS(11160),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11160),
    [sym_verbatim_string] = ACTIONS(11160),
    [sym_integer] = ACTIONS(11158),
    [sym_continue_as_identifier] = ACTIONS(11160),
  },
  [STATE(4684)] = {
    [sym_boolean] = STATE(8185),
    [sym_assignment_expression] = STATE(8185),
    [sym__expression] = STATE(8185),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8185),
    [sym_multiplicative_expression] = STATE(8185),
    [sym_additive_expression] = STATE(8185),
    [sym_comparison_expression] = STATE(8185),
    [sym_logical_expression] = STATE(8185),
    [sym_ternary_expression] = STATE(8185),
    [sym_unary_expression] = STATE(8185),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8185),
    [sym_list_literal] = STATE(8185),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8185),
    [sym__literal_value] = STATE(8185),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(11162),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(11164),
    [sym_date_literal] = ACTIONS(11162),
    [sym_time_literal] = ACTIONS(11162),
    [sym_biginteger_literal] = ACTIONS(11164),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11164),
    [sym_verbatim_string] = ACTIONS(11164),
    [sym_integer] = ACTIONS(11162),
    [sym_continue_as_identifier] = ACTIONS(11164),
  },
  [STATE(4685)] = {
    [sym_boolean] = STATE(1877),
    [sym_assignment_expression] = STATE(1877),
    [sym__expression] = STATE(1877),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1877),
    [sym_multiplicative_expression] = STATE(1877),
    [sym_additive_expression] = STATE(1877),
    [sym_comparison_expression] = STATE(1877),
    [sym_logical_expression] = STATE(1877),
    [sym_ternary_expression] = STATE(1877),
    [sym_unary_expression] = STATE(1877),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1877),
    [sym_list_literal] = STATE(1877),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1877),
    [sym__literal_value] = STATE(1877),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11166),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11168),
    [sym_date_literal] = ACTIONS(11166),
    [sym_time_literal] = ACTIONS(11166),
    [sym_biginteger_literal] = ACTIONS(11168),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11168),
    [sym_verbatim_string] = ACTIONS(11168),
    [sym_integer] = ACTIONS(11166),
    [sym_continue_as_identifier] = ACTIONS(11168),
  },
  [STATE(4686)] = {
    [sym_boolean] = STATE(1878),
    [sym_assignment_expression] = STATE(1878),
    [sym__expression] = STATE(1878),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1878),
    [sym_multiplicative_expression] = STATE(1878),
    [sym_additive_expression] = STATE(1878),
    [sym_comparison_expression] = STATE(1878),
    [sym_logical_expression] = STATE(1878),
    [sym_ternary_expression] = STATE(1878),
    [sym_unary_expression] = STATE(1878),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1878),
    [sym_list_literal] = STATE(1878),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1878),
    [sym__literal_value] = STATE(1878),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11170),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11172),
    [sym_date_literal] = ACTIONS(11170),
    [sym_time_literal] = ACTIONS(11170),
    [sym_biginteger_literal] = ACTIONS(11172),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11172),
    [sym_verbatim_string] = ACTIONS(11172),
    [sym_integer] = ACTIONS(11170),
    [sym_continue_as_identifier] = ACTIONS(11172),
  },
  [STATE(4687)] = {
    [sym_boolean] = STATE(1874),
    [sym_assignment_expression] = STATE(1874),
    [sym__expression] = STATE(1874),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1874),
    [sym_multiplicative_expression] = STATE(1874),
    [sym_additive_expression] = STATE(1874),
    [sym_comparison_expression] = STATE(1874),
    [sym_logical_expression] = STATE(1874),
    [sym_ternary_expression] = STATE(1874),
    [sym_unary_expression] = STATE(1874),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1874),
    [sym_list_literal] = STATE(1874),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1874),
    [sym__literal_value] = STATE(1874),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11174),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11176),
    [sym_date_literal] = ACTIONS(11174),
    [sym_time_literal] = ACTIONS(11174),
    [sym_biginteger_literal] = ACTIONS(11176),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11176),
    [sym_verbatim_string] = ACTIONS(11176),
    [sym_integer] = ACTIONS(11174),
    [sym_continue_as_identifier] = ACTIONS(11176),
  },
  [STATE(4688)] = {
    [sym_boolean] = STATE(1880),
    [sym_assignment_expression] = STATE(1880),
    [sym__expression] = STATE(1880),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1880),
    [sym_multiplicative_expression] = STATE(1880),
    [sym_additive_expression] = STATE(1880),
    [sym_comparison_expression] = STATE(1880),
    [sym_logical_expression] = STATE(1880),
    [sym_ternary_expression] = STATE(1880),
    [sym_unary_expression] = STATE(1880),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1880),
    [sym_list_literal] = STATE(1880),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1880),
    [sym__literal_value] = STATE(1880),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11178),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11180),
    [sym_date_literal] = ACTIONS(11178),
    [sym_time_literal] = ACTIONS(11178),
    [sym_biginteger_literal] = ACTIONS(11180),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11180),
    [sym_verbatim_string] = ACTIONS(11180),
    [sym_integer] = ACTIONS(11178),
    [sym_continue_as_identifier] = ACTIONS(11180),
  },
  [STATE(4689)] = {
    [sym_boolean] = STATE(8732),
    [sym_assignment_expression] = STATE(8732),
    [sym__expression] = STATE(8732),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8732),
    [sym_multiplicative_expression] = STATE(8732),
    [sym_additive_expression] = STATE(8732),
    [sym_comparison_expression] = STATE(8732),
    [sym_logical_expression] = STATE(8732),
    [sym_ternary_expression] = STATE(8732),
    [sym_unary_expression] = STATE(8732),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8732),
    [sym_list_literal] = STATE(8732),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8732),
    [sym__literal_value] = STATE(8732),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11182),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11184),
    [sym_date_literal] = ACTIONS(11182),
    [sym_time_literal] = ACTIONS(11182),
    [sym_biginteger_literal] = ACTIONS(11184),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11184),
    [sym_verbatim_string] = ACTIONS(11184),
    [sym_integer] = ACTIONS(11182),
    [sym_continue_as_identifier] = ACTIONS(11184),
  },
  [STATE(4690)] = {
    [sym_boolean] = STATE(8627),
    [sym_assignment_expression] = STATE(8627),
    [sym__expression] = STATE(8627),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8627),
    [sym_multiplicative_expression] = STATE(8627),
    [sym_additive_expression] = STATE(8627),
    [sym_comparison_expression] = STATE(8627),
    [sym_logical_expression] = STATE(8627),
    [sym_ternary_expression] = STATE(8627),
    [sym_unary_expression] = STATE(8627),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8627),
    [sym_list_literal] = STATE(8627),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8627),
    [sym__literal_value] = STATE(8627),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11186),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11188),
    [sym_date_literal] = ACTIONS(11186),
    [sym_time_literal] = ACTIONS(11186),
    [sym_biginteger_literal] = ACTIONS(11188),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11188),
    [sym_verbatim_string] = ACTIONS(11188),
    [sym_integer] = ACTIONS(11186),
    [sym_continue_as_identifier] = ACTIONS(11188),
  },
  [STATE(4691)] = {
    [sym_boolean] = STATE(8725),
    [sym_assignment_expression] = STATE(8725),
    [sym__expression] = STATE(8725),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8725),
    [sym_multiplicative_expression] = STATE(8725),
    [sym_additive_expression] = STATE(8725),
    [sym_comparison_expression] = STATE(8725),
    [sym_logical_expression] = STATE(8725),
    [sym_ternary_expression] = STATE(8725),
    [sym_unary_expression] = STATE(8725),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8725),
    [sym_list_literal] = STATE(8725),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8725),
    [sym__literal_value] = STATE(8725),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11190),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11192),
    [sym_date_literal] = ACTIONS(11190),
    [sym_time_literal] = ACTIONS(11190),
    [sym_biginteger_literal] = ACTIONS(11192),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11192),
    [sym_verbatim_string] = ACTIONS(11192),
    [sym_integer] = ACTIONS(11190),
    [sym_continue_as_identifier] = ACTIONS(11192),
  },
  [STATE(4692)] = {
    [sym_boolean] = STATE(8374),
    [sym_assignment_expression] = STATE(8374),
    [sym__expression] = STATE(8374),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8374),
    [sym_multiplicative_expression] = STATE(8374),
    [sym_additive_expression] = STATE(8374),
    [sym_comparison_expression] = STATE(8374),
    [sym_logical_expression] = STATE(8374),
    [sym_ternary_expression] = STATE(8374),
    [sym_unary_expression] = STATE(8374),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8374),
    [sym_list_literal] = STATE(8374),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8374),
    [sym__literal_value] = STATE(8374),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11194),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11196),
    [sym_date_literal] = ACTIONS(11194),
    [sym_time_literal] = ACTIONS(11194),
    [sym_biginteger_literal] = ACTIONS(11196),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11196),
    [sym_verbatim_string] = ACTIONS(11196),
    [sym_integer] = ACTIONS(11194),
    [sym_continue_as_identifier] = ACTIONS(11196),
  },
  [STATE(4693)] = {
    [sym_boolean] = STATE(8383),
    [sym_assignment_expression] = STATE(8383),
    [sym__expression] = STATE(8383),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8383),
    [sym_multiplicative_expression] = STATE(8383),
    [sym_additive_expression] = STATE(8383),
    [sym_comparison_expression] = STATE(8383),
    [sym_logical_expression] = STATE(8383),
    [sym_ternary_expression] = STATE(8383),
    [sym_unary_expression] = STATE(8383),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8383),
    [sym_list_literal] = STATE(8383),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8383),
    [sym__literal_value] = STATE(8383),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11198),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11200),
    [sym_date_literal] = ACTIONS(11198),
    [sym_time_literal] = ACTIONS(11198),
    [sym_biginteger_literal] = ACTIONS(11200),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11200),
    [sym_verbatim_string] = ACTIONS(11200),
    [sym_integer] = ACTIONS(11198),
    [sym_continue_as_identifier] = ACTIONS(11200),
  },
  [STATE(4694)] = {
    [sym_boolean] = STATE(8389),
    [sym_assignment_expression] = STATE(8389),
    [sym__expression] = STATE(8389),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8389),
    [sym_multiplicative_expression] = STATE(8389),
    [sym_additive_expression] = STATE(8389),
    [sym_comparison_expression] = STATE(8389),
    [sym_logical_expression] = STATE(8389),
    [sym_ternary_expression] = STATE(8389),
    [sym_unary_expression] = STATE(8389),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8389),
    [sym_list_literal] = STATE(8389),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8389),
    [sym__literal_value] = STATE(8389),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11202),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11204),
    [sym_date_literal] = ACTIONS(11202),
    [sym_time_literal] = ACTIONS(11202),
    [sym_biginteger_literal] = ACTIONS(11204),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11204),
    [sym_verbatim_string] = ACTIONS(11204),
    [sym_integer] = ACTIONS(11202),
    [sym_continue_as_identifier] = ACTIONS(11204),
  },
  [STATE(4695)] = {
    [sym_boolean] = STATE(1879),
    [sym_assignment_expression] = STATE(1879),
    [sym__expression] = STATE(1879),
    [sym_keyword_identifier] = STATE(1917),
    [sym_range_expression] = STATE(1879),
    [sym_multiplicative_expression] = STATE(1879),
    [sym_additive_expression] = STATE(1879),
    [sym_comparison_expression] = STATE(1879),
    [sym_logical_expression] = STATE(1879),
    [sym_ternary_expression] = STATE(1879),
    [sym_unary_expression] = STATE(1879),
    [sym_call_expression] = STATE(1925),
    [sym_member_expression] = STATE(1917),
    [sym_subscript_expression] = STATE(1917),
    [sym_parenthesized_expression] = STATE(1879),
    [sym_list_literal] = STATE(1879),
    [sym_qualified_enum_value] = STATE(1917),
    [sym_database_reference] = STATE(1879),
    [sym__literal_value] = STATE(1879),
    [sym_codeunit_keyword] = STATE(1924),
    [sym_xmlport_keyword] = STATE(1924),
    [sym_enum_keyword] = STATE(1909),
    [sym_identifier] = ACTIONS(639),
    [anon_sym_DASH] = ACTIONS(641),
    [aux_sym_boolean_token1] = ACTIONS(643),
    [aux_sym_boolean_token2] = ACTIONS(643),
    [sym_decimal] = ACTIONS(11206),
    [anon_sym_LPAREN] = ACTIONS(647),
    [aux_sym_tabledata_permission_token2] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(651),
    [aux_sym_record_type_token1] = ACTIONS(649),
    [aux_sym_basic_type_token21] = ACTIONS(649),
    [aux_sym_basic_type_token22] = ACTIONS(649),
    [aux_sym_basic_type_token48] = ACTIONS(649),
    [anon_sym_not] = ACTIONS(653),
    [anon_sym_NOT] = ACTIONS(653),
    [anon_sym_Not] = ACTIONS(653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(649),
    [aux_sym_keyword_identifier_token2] = ACTIONS(655),
    [anon_sym_PLUS] = ACTIONS(641),
    [sym_datetime_literal] = ACTIONS(11208),
    [sym_date_literal] = ACTIONS(11206),
    [sym_time_literal] = ACTIONS(11206),
    [sym_biginteger_literal] = ACTIONS(11208),
    [sym_page_keyword] = ACTIONS(655),
    [anon_sym_codeunit] = ACTIONS(661),
    [anon_sym_CODEUNIT] = ACTIONS(661),
    [anon_sym_Codeunit] = ACTIONS(661),
    [anon_sym_CodeUnit] = ACTIONS(661),
    [anon_sym_COdeunit] = ACTIONS(661),
    [anon_sym_codeUnit] = ACTIONS(661),
    [sym_report_keyword] = ACTIONS(655),
    [sym_query_keyword] = ACTIONS(655),
    [anon_sym_xmlport] = ACTIONS(663),
    [anon_sym_XMLPORT] = ACTIONS(663),
    [anon_sym_Xmlport] = ACTIONS(663),
    [anon_sym_XMLport] = ACTIONS(663),
    [anon_sym_XMLPort] = ACTIONS(663),
    [anon_sym_XmlPort] = ACTIONS(663),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_ENUM] = ACTIONS(665),
    [anon_sym_Enum] = ACTIONS(665),
    [anon_sym_eNUM] = ACTIONS(665),
    [anon_sym_eNum] = ACTIONS(665),
    [anon_sym_ENum] = ACTIONS(665),
    [sym_quoted_identifier] = ACTIONS(667),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11208),
    [sym_verbatim_string] = ACTIONS(11208),
    [sym_integer] = ACTIONS(11206),
    [sym_continue_as_identifier] = ACTIONS(11208),
  },
  [STATE(4696)] = {
    [sym_boolean] = STATE(1989),
    [sym_assignment_expression] = STATE(1989),
    [sym__expression] = STATE(1989),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1989),
    [sym_multiplicative_expression] = STATE(1989),
    [sym_additive_expression] = STATE(1989),
    [sym_comparison_expression] = STATE(1989),
    [sym_logical_expression] = STATE(1989),
    [sym_ternary_expression] = STATE(1989),
    [sym_unary_expression] = STATE(1989),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1989),
    [sym_list_literal] = STATE(1989),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1989),
    [sym__literal_value] = STATE(1989),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11210),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11212),
    [sym_date_literal] = ACTIONS(11210),
    [sym_time_literal] = ACTIONS(11210),
    [sym_biginteger_literal] = ACTIONS(11212),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11212),
    [sym_verbatim_string] = ACTIONS(11212),
    [sym_integer] = ACTIONS(11210),
    [sym_continue_as_identifier] = ACTIONS(11212),
  },
  [STATE(4697)] = {
    [sym_boolean] = STATE(8415),
    [sym_assignment_expression] = STATE(8415),
    [sym__expression] = STATE(8415),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8415),
    [sym_multiplicative_expression] = STATE(8415),
    [sym_additive_expression] = STATE(8415),
    [sym_comparison_expression] = STATE(8415),
    [sym_logical_expression] = STATE(8415),
    [sym_ternary_expression] = STATE(8415),
    [sym_unary_expression] = STATE(8415),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8415),
    [sym_list_literal] = STATE(8415),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8415),
    [sym__literal_value] = STATE(8415),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11214),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11216),
    [sym_date_literal] = ACTIONS(11214),
    [sym_time_literal] = ACTIONS(11214),
    [sym_biginteger_literal] = ACTIONS(11216),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11216),
    [sym_verbatim_string] = ACTIONS(11216),
    [sym_integer] = ACTIONS(11214),
    [sym_continue_as_identifier] = ACTIONS(11216),
  },
  [STATE(4698)] = {
    [sym_boolean] = STATE(8419),
    [sym_assignment_expression] = STATE(8419),
    [sym__expression] = STATE(8419),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8419),
    [sym_multiplicative_expression] = STATE(8419),
    [sym_additive_expression] = STATE(8419),
    [sym_comparison_expression] = STATE(8419),
    [sym_logical_expression] = STATE(8419),
    [sym_ternary_expression] = STATE(8419),
    [sym_unary_expression] = STATE(8419),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8419),
    [sym_list_literal] = STATE(8419),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8419),
    [sym__literal_value] = STATE(8419),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11218),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11220),
    [sym_date_literal] = ACTIONS(11218),
    [sym_time_literal] = ACTIONS(11218),
    [sym_biginteger_literal] = ACTIONS(11220),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11220),
    [sym_verbatim_string] = ACTIONS(11220),
    [sym_integer] = ACTIONS(11218),
    [sym_continue_as_identifier] = ACTIONS(11220),
  },
  [STATE(4699)] = {
    [sym_boolean] = STATE(8420),
    [sym_assignment_expression] = STATE(8420),
    [sym__expression] = STATE(8420),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8420),
    [sym_multiplicative_expression] = STATE(8420),
    [sym_additive_expression] = STATE(8420),
    [sym_comparison_expression] = STATE(8420),
    [sym_logical_expression] = STATE(8420),
    [sym_ternary_expression] = STATE(8420),
    [sym_unary_expression] = STATE(8420),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8420),
    [sym_list_literal] = STATE(8420),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8420),
    [sym__literal_value] = STATE(8420),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11222),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11224),
    [sym_date_literal] = ACTIONS(11222),
    [sym_time_literal] = ACTIONS(11222),
    [sym_biginteger_literal] = ACTIONS(11224),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11224),
    [sym_verbatim_string] = ACTIONS(11224),
    [sym_integer] = ACTIONS(11222),
    [sym_continue_as_identifier] = ACTIONS(11224),
  },
  [STATE(4700)] = {
    [sym__layout_element] = STATE(4895),
    [sym_area_section] = STATE(4895),
    [sym_group_section] = STATE(4895),
    [sym_repeater_section] = STATE(4895),
    [sym_cuegroup_section] = STATE(4895),
    [sym_fixed_section] = STATE(4895),
    [sym_grid_section] = STATE(4895),
    [sym_page_field] = STATE(4895),
    [sym_part_section] = STATE(4895),
    [sym_systempart_section] = STATE(4895),
    [sym_usercontrol_section] = STATE(4895),
    [sym_preproc_split_field] = STATE(4895),
    [sym__field_header] = STATE(10798),
    [sym_label_section] = STATE(4895),
    [sym_addfirst_modification] = STATE(4895),
    [sym_addlast_modification] = STATE(4895),
    [sym_addafter_modification] = STATE(4895),
    [sym_addbefore_modification] = STATE(4895),
    [sym_modify_modification] = STATE(4895),
    [sym_movefirst_modification] = STATE(4895),
    [sym_movelast_modification] = STATE(4895),
    [sym_moveafter_modification] = STATE(4895),
    [sym_movebefore_modification] = STATE(4895),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6501),
    [sym_preproc_endif] = STATE(8524),
    [sym_preproc_conditional_layout] = STATE(4895),
    [aux_sym_layout_section_repeat1] = STATE(4895),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10803),
    [aux_sym_where_condition_token1] = ACTIONS(9790),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(11226),
    [anon_sym_POUNDENDIF] = ACTIONS(11226),
    [anon_sym_POUNDEndif] = ACTIONS(11226),
    [anon_sym_POUNDendif2] = ACTIONS(11226),
    [anon_sym_POUNDENDIF2] = ACTIONS(11226),
    [anon_sym_POUNDEndif2] = ACTIONS(11226),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(11226),
  },
  [STATE(4701)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6490),
    [sym_preproc_endif] = STATE(10154),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10691),
    [anon_sym_RBRACE] = ACTIONS(11228),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4702)] = {
    [sym_identifier] = ACTIONS(7418),
    [anon_sym_DASH] = ACTIONS(7420),
    [aux_sym_boolean_token1] = ACTIONS(7418),
    [aux_sym_boolean_token2] = ACTIONS(7418),
    [sym_decimal] = ACTIONS(7418),
    [anon_sym_LPAREN] = ACTIONS(7420),
    [aux_sym_where_condition_token1] = ACTIONS(7418),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(7418),
    [aux_sym_if_table_relation_token1] = ACTIONS(7418),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7418),
    [anon_sym_LBRACK] = ACTIONS(7420),
    [aux_sym_record_type_token1] = ACTIONS(7418),
    [aux_sym_basic_type_token21] = ACTIONS(7418),
    [aux_sym_basic_type_token22] = ACTIONS(7418),
    [aux_sym_basic_type_token48] = ACTIONS(7418),
    [aux_sym_basic_type_token53] = ACTIONS(7418),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7418),
    [aux_sym_separator_action_token1] = ACTIONS(7418),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7418),
    [aux_sym_type_declaration_token1] = ACTIONS(7418),
    [anon_sym_POUNDif] = ACTIONS(7420),
    [anon_sym_POUNDIF] = ACTIONS(7420),
    [anon_sym_POUNDIf] = ACTIONS(7420),
    [anon_sym_not] = ACTIONS(7418),
    [anon_sym_NOT] = ACTIONS(7418),
    [anon_sym_Not] = ACTIONS(7418),
    [anon_sym_POUNDendif] = ACTIONS(7420),
    [anon_sym_POUNDENDIF] = ACTIONS(7420),
    [anon_sym_POUNDEndif] = ACTIONS(7420),
    [anon_sym_POUNDendif2] = ACTIONS(7420),
    [anon_sym_POUNDENDIF2] = ACTIONS(7420),
    [anon_sym_POUNDEndif2] = ACTIONS(7420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7418),
    [aux_sym_keyword_identifier_token2] = ACTIONS(7418),
    [anon_sym_PLUS] = ACTIONS(7420),
    [sym_datetime_literal] = ACTIONS(7420),
    [sym_date_literal] = ACTIONS(7418),
    [sym_time_literal] = ACTIONS(7418),
    [sym_biginteger_literal] = ACTIONS(7420),
    [sym_table_keyword] = ACTIONS(7418),
    [sym_page_keyword] = ACTIONS(7418),
    [anon_sym_codeunit] = ACTIONS(7418),
    [anon_sym_CODEUNIT] = ACTIONS(7418),
    [anon_sym_Codeunit] = ACTIONS(7418),
    [anon_sym_CodeUnit] = ACTIONS(7418),
    [anon_sym_COdeunit] = ACTIONS(7418),
    [anon_sym_codeUnit] = ACTIONS(7418),
    [sym_report_keyword] = ACTIONS(7418),
    [sym_query_keyword] = ACTIONS(7418),
    [anon_sym_xmlport] = ACTIONS(7418),
    [anon_sym_XMLPORT] = ACTIONS(7418),
    [anon_sym_Xmlport] = ACTIONS(7418),
    [anon_sym_XMLport] = ACTIONS(7418),
    [anon_sym_XMLPort] = ACTIONS(7418),
    [anon_sym_XmlPort] = ACTIONS(7418),
    [anon_sym_enum] = ACTIONS(7418),
    [anon_sym_ENUM] = ACTIONS(7418),
    [anon_sym_Enum] = ACTIONS(7418),
    [anon_sym_eNUM] = ACTIONS(7418),
    [anon_sym_eNum] = ACTIONS(7418),
    [anon_sym_ENum] = ACTIONS(7418),
    [sym_key_keyword] = ACTIONS(7418),
    [sym_dataset_keyword] = ACTIONS(7418),
    [sym_quoted_identifier] = ACTIONS(7420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(7420),
    [sym_verbatim_string] = ACTIONS(7420),
    [sym_integer] = ACTIONS(7418),
    [sym_continue_as_identifier] = ACTIONS(7420),
    [sym_preproc_open] = ACTIONS(7420),
    [sym_preproc_close] = ACTIONS(7420),
  },
  [STATE(4703)] = {
    [sym_preproc_conditional_controladdin] = STATE(3959),
    [sym__body_element] = STATE(3959),
    [sym_empty_statement] = STATE(3959),
    [sym_property] = STATE(3959),
    [sym_permissions_property] = STATE(3959),
    [sym_table_relation_property] = STATE(3959),
    [sym_fields_section] = STATE(3959),
    [sym_keys_section] = STATE(3959),
    [sym_fieldgroups_section] = STATE(3959),
    [sym_enum_value_declaration] = STATE(3959),
    [sym_labels_section] = STATE(3959),
    [sym_layout_section] = STATE(3959),
    [sym_modify_modification] = STATE(3959),
    [sym_actions_section] = STATE(3959),
    [sym_views_section] = STATE(3959),
    [sym_dataset_section] = STATE(3959),
    [sym_requestpage_section] = STATE(3959),
    [sym_rendering_section] = STATE(3959),
    [sym_elements_section] = STATE(3959),
    [sym_schema_section] = STATE(3959),
    [sym_assembly_declaration] = STATE(3959),
    [sym_event_declaration] = STATE(3959),
    [sym_procedure] = STATE(3959),
    [sym_preproc_split_procedure] = STATE(3959),
    [sym_preproc_split_procedure_preamble] = STATE(3959),
    [sym_interface_procedure] = STATE(3959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(3959),
    [sym_var_section] = STATE(3959),
    [sym_attribute_item] = STATE(3959),
    [sym_preproc_conditional] = STATE(3959),
    [sym_preproc_if] = STATE(3593),
    [sym_preproc_endif] = STATE(9975),
    [aux_sym_controladdin_declaration_repeat1] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8450),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4704)] = {
    [sym__body_element] = STATE(4535),
    [sym_empty_statement] = STATE(4535),
    [sym_property] = STATE(4535),
    [sym_permissions_property] = STATE(4535),
    [sym_table_relation_property] = STATE(4535),
    [sym_fields_section] = STATE(4535),
    [sym_keys_section] = STATE(4535),
    [sym_fieldgroups_section] = STATE(4535),
    [sym_enum_value_declaration] = STATE(4535),
    [sym_labels_section] = STATE(4535),
    [sym_layout_section] = STATE(4535),
    [sym_modify_modification] = STATE(4535),
    [sym_actions_section] = STATE(4535),
    [sym_views_section] = STATE(4535),
    [sym_dataset_section] = STATE(4535),
    [sym_requestpage_section] = STATE(4535),
    [sym_rendering_section] = STATE(4535),
    [sym_elements_section] = STATE(4535),
    [sym_schema_section] = STATE(4535),
    [sym_xmlport_element] = STATE(4535),
    [sym__xmlport_body_element] = STATE(4535),
    [sym_preproc_conditional_xmlport] = STATE(4535),
    [sym_xmlport_attribute] = STATE(4535),
    [sym_assembly_declaration] = STATE(4535),
    [sym_event_declaration] = STATE(4535),
    [sym_procedure] = STATE(4535),
    [sym_preproc_split_procedure] = STATE(4535),
    [sym_preproc_split_procedure_preamble] = STATE(4535),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4535),
    [sym_var_section] = STATE(4535),
    [sym_attribute_item] = STATE(4535),
    [sym_preproc_conditional] = STATE(4535),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4535),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(11230),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4705)] = {
    [sym__body_element] = STATE(4643),
    [sym_empty_statement] = STATE(4643),
    [sym_property] = STATE(4643),
    [sym_permissions_property] = STATE(4643),
    [sym_table_relation_property] = STATE(4643),
    [sym_fields_section] = STATE(4643),
    [sym_keys_section] = STATE(4643),
    [sym_fieldgroups_section] = STATE(4643),
    [sym_enum_value_declaration] = STATE(4643),
    [sym_labels_section] = STATE(4643),
    [sym_layout_section] = STATE(4643),
    [sym_modify_modification] = STATE(4643),
    [sym_actions_section] = STATE(4643),
    [sym_views_section] = STATE(4643),
    [sym_dataset_section] = STATE(4643),
    [sym_requestpage_section] = STATE(4643),
    [sym_rendering_section] = STATE(4643),
    [sym_elements_section] = STATE(4643),
    [sym_schema_section] = STATE(4643),
    [sym_xmlport_element] = STATE(4643),
    [sym__xmlport_body_element] = STATE(4643),
    [sym_preproc_conditional_xmlport] = STATE(4643),
    [sym_xmlport_attribute] = STATE(4643),
    [sym_assembly_declaration] = STATE(4643),
    [sym_event_declaration] = STATE(4643),
    [sym_procedure] = STATE(4643),
    [sym_preproc_split_procedure] = STATE(4643),
    [sym_preproc_split_procedure_preamble] = STATE(4643),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4643),
    [sym_var_section] = STATE(4643),
    [sym_attribute_item] = STATE(4643),
    [sym_preproc_conditional] = STATE(4643),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4643),
    [anon_sym_SEMI] = ACTIONS(10302),
    [anon_sym_RBRACE] = ACTIONS(11232),
    [anon_sym_LBRACK] = ACTIONS(10306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(10308),
    [aux_sym_modify_modification_token1] = ACTIONS(10310),
    [aux_sym_xmlport_element_token1] = ACTIONS(10312),
    [aux_sym_xmlport_element_token2] = ACTIONS(10312),
    [aux_sym_xmlport_element_token3] = ACTIONS(10312),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(10314),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(10314),
    [aux_sym_assembly_declaration_token1] = ACTIONS(10316),
    [anon_sym_POUNDif] = ACTIONS(7376),
    [anon_sym_POUNDIF] = ACTIONS(7376),
    [anon_sym_POUNDIf] = ACTIONS(7376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(10318),
    [sym_trigger_keyword] = ACTIONS(10320),
    [sym_var_keyword] = ACTIONS(10322),
    [sym_local_keyword] = ACTIONS(10324),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(10324),
    [sym_event_keyword] = ACTIONS(10326),
    [sym_fields_keyword] = ACTIONS(10328),
    [sym_keys_keyword] = ACTIONS(10330),
    [sym_fieldgroups_keyword] = ACTIONS(10332),
    [sym_actions_keyword] = ACTIONS(10334),
    [sym_layout_keyword] = ACTIONS(10336),
    [sym_dataset_keyword] = ACTIONS(10338),
    [sym_elements_keyword] = ACTIONS(10340),
    [sym_labels_keyword] = ACTIONS(10342),
    [sym_rendering_keyword] = ACTIONS(10344),
    [sym_requestpage_keyword] = ACTIONS(10346),
    [sym_schema_keyword] = ACTIONS(10348),
    [sym_views_keyword] = ACTIONS(10350),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(10352),
    [sym_preproc_open] = ACTIONS(7376),
  },
  [STATE(4706)] = {
    [sym_boolean] = STATE(1956),
    [sym_assignment_expression] = STATE(1956),
    [sym__expression] = STATE(1956),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1956),
    [sym_multiplicative_expression] = STATE(1956),
    [sym_additive_expression] = STATE(1956),
    [sym_comparison_expression] = STATE(1956),
    [sym_logical_expression] = STATE(1956),
    [sym_ternary_expression] = STATE(1956),
    [sym_unary_expression] = STATE(1956),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1956),
    [sym_list_literal] = STATE(1956),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1956),
    [sym__literal_value] = STATE(1956),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11234),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11236),
    [sym_date_literal] = ACTIONS(11234),
    [sym_time_literal] = ACTIONS(11234),
    [sym_biginteger_literal] = ACTIONS(11236),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11236),
    [sym_verbatim_string] = ACTIONS(11236),
    [sym_integer] = ACTIONS(11234),
    [sym_continue_as_identifier] = ACTIONS(11236),
  },
  [STATE(4707)] = {
    [sym_boolean] = STATE(1959),
    [sym_assignment_expression] = STATE(1959),
    [sym__expression] = STATE(1959),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1959),
    [sym_multiplicative_expression] = STATE(1959),
    [sym_additive_expression] = STATE(1959),
    [sym_comparison_expression] = STATE(1959),
    [sym_logical_expression] = STATE(1959),
    [sym_ternary_expression] = STATE(1959),
    [sym_unary_expression] = STATE(1959),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1959),
    [sym_list_literal] = STATE(1959),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1959),
    [sym__literal_value] = STATE(1959),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11238),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11240),
    [sym_date_literal] = ACTIONS(11238),
    [sym_time_literal] = ACTIONS(11238),
    [sym_biginteger_literal] = ACTIONS(11240),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11240),
    [sym_verbatim_string] = ACTIONS(11240),
    [sym_integer] = ACTIONS(11238),
    [sym_continue_as_identifier] = ACTIONS(11240),
  },
  [STATE(4708)] = {
    [sym_boolean] = STATE(1971),
    [sym_assignment_expression] = STATE(1971),
    [sym__expression] = STATE(1971),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1971),
    [sym_multiplicative_expression] = STATE(1971),
    [sym_additive_expression] = STATE(1971),
    [sym_comparison_expression] = STATE(1971),
    [sym_logical_expression] = STATE(1971),
    [sym_ternary_expression] = STATE(1971),
    [sym_unary_expression] = STATE(1971),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1971),
    [sym_list_literal] = STATE(1971),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1971),
    [sym__literal_value] = STATE(1971),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11242),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11244),
    [sym_date_literal] = ACTIONS(11242),
    [sym_time_literal] = ACTIONS(11242),
    [sym_biginteger_literal] = ACTIONS(11244),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11244),
    [sym_verbatim_string] = ACTIONS(11244),
    [sym_integer] = ACTIONS(11242),
    [sym_continue_as_identifier] = ACTIONS(11244),
  },
  [STATE(4709)] = {
    [sym_boolean] = STATE(1977),
    [sym_assignment_expression] = STATE(1977),
    [sym__expression] = STATE(1977),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1977),
    [sym_multiplicative_expression] = STATE(1977),
    [sym_additive_expression] = STATE(1977),
    [sym_comparison_expression] = STATE(1977),
    [sym_logical_expression] = STATE(1977),
    [sym_ternary_expression] = STATE(1977),
    [sym_unary_expression] = STATE(1977),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1977),
    [sym_list_literal] = STATE(1977),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1977),
    [sym__literal_value] = STATE(1977),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11246),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11248),
    [sym_date_literal] = ACTIONS(11246),
    [sym_time_literal] = ACTIONS(11246),
    [sym_biginteger_literal] = ACTIONS(11248),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11248),
    [sym_verbatim_string] = ACTIONS(11248),
    [sym_integer] = ACTIONS(11246),
    [sym_continue_as_identifier] = ACTIONS(11248),
  },
  [STATE(4710)] = {
    [sym_boolean] = STATE(1997),
    [sym_assignment_expression] = STATE(1997),
    [sym__expression] = STATE(1997),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1997),
    [sym_multiplicative_expression] = STATE(1997),
    [sym_additive_expression] = STATE(1997),
    [sym_comparison_expression] = STATE(1997),
    [sym_logical_expression] = STATE(1997),
    [sym_ternary_expression] = STATE(1997),
    [sym_unary_expression] = STATE(1997),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1997),
    [sym_list_literal] = STATE(1997),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1997),
    [sym__literal_value] = STATE(1997),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11250),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11252),
    [sym_date_literal] = ACTIONS(11250),
    [sym_time_literal] = ACTIONS(11250),
    [sym_biginteger_literal] = ACTIONS(11252),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11252),
    [sym_verbatim_string] = ACTIONS(11252),
    [sym_integer] = ACTIONS(11250),
    [sym_continue_as_identifier] = ACTIONS(11252),
  },
  [STATE(4711)] = {
    [sym_boolean] = STATE(1998),
    [sym_assignment_expression] = STATE(1998),
    [sym__expression] = STATE(1998),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1998),
    [sym_multiplicative_expression] = STATE(1998),
    [sym_additive_expression] = STATE(1998),
    [sym_comparison_expression] = STATE(1998),
    [sym_logical_expression] = STATE(1998),
    [sym_ternary_expression] = STATE(1998),
    [sym_unary_expression] = STATE(1998),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1998),
    [sym_list_literal] = STATE(1998),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1998),
    [sym__literal_value] = STATE(1998),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11254),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11256),
    [sym_date_literal] = ACTIONS(11254),
    [sym_time_literal] = ACTIONS(11254),
    [sym_biginteger_literal] = ACTIONS(11256),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11256),
    [sym_verbatim_string] = ACTIONS(11256),
    [sym_integer] = ACTIONS(11254),
    [sym_continue_as_identifier] = ACTIONS(11256),
  },
  [STATE(4712)] = {
    [sym_boolean] = STATE(2000),
    [sym_assignment_expression] = STATE(2000),
    [sym__expression] = STATE(2000),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(2000),
    [sym_multiplicative_expression] = STATE(2000),
    [sym_additive_expression] = STATE(2000),
    [sym_comparison_expression] = STATE(2000),
    [sym_logical_expression] = STATE(2000),
    [sym_ternary_expression] = STATE(2000),
    [sym_unary_expression] = STATE(2000),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(2000),
    [sym_list_literal] = STATE(2000),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(2000),
    [sym__literal_value] = STATE(2000),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11258),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11260),
    [sym_date_literal] = ACTIONS(11258),
    [sym_time_literal] = ACTIONS(11258),
    [sym_biginteger_literal] = ACTIONS(11260),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11260),
    [sym_verbatim_string] = ACTIONS(11260),
    [sym_integer] = ACTIONS(11258),
    [sym_continue_as_identifier] = ACTIONS(11260),
  },
  [STATE(4713)] = {
    [sym_boolean] = STATE(2002),
    [sym_assignment_expression] = STATE(2002),
    [sym__expression] = STATE(2002),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(2002),
    [sym_multiplicative_expression] = STATE(2002),
    [sym_additive_expression] = STATE(2002),
    [sym_comparison_expression] = STATE(2002),
    [sym_logical_expression] = STATE(2002),
    [sym_ternary_expression] = STATE(2002),
    [sym_unary_expression] = STATE(2002),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(2002),
    [sym_list_literal] = STATE(2002),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(2002),
    [sym__literal_value] = STATE(2002),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11262),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11264),
    [sym_date_literal] = ACTIONS(11262),
    [sym_time_literal] = ACTIONS(11262),
    [sym_biginteger_literal] = ACTIONS(11264),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11264),
    [sym_verbatim_string] = ACTIONS(11264),
    [sym_integer] = ACTIONS(11262),
    [sym_continue_as_identifier] = ACTIONS(11264),
  },
  [STATE(4714)] = {
    [sym_boolean] = STATE(2026),
    [sym_assignment_expression] = STATE(2026),
    [sym__expression] = STATE(2026),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(2026),
    [sym_multiplicative_expression] = STATE(2026),
    [sym_additive_expression] = STATE(2026),
    [sym_comparison_expression] = STATE(2026),
    [sym_logical_expression] = STATE(2026),
    [sym_ternary_expression] = STATE(2026),
    [sym_unary_expression] = STATE(2026),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(2026),
    [sym_list_literal] = STATE(2026),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(2026),
    [sym__literal_value] = STATE(2026),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11266),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11268),
    [sym_date_literal] = ACTIONS(11266),
    [sym_time_literal] = ACTIONS(11266),
    [sym_biginteger_literal] = ACTIONS(11268),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11268),
    [sym_verbatim_string] = ACTIONS(11268),
    [sym_integer] = ACTIONS(11266),
    [sym_continue_as_identifier] = ACTIONS(11268),
  },
  [STATE(4715)] = {
    [sym_boolean] = STATE(1952),
    [sym_assignment_expression] = STATE(1952),
    [sym__expression] = STATE(1952),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1952),
    [sym_multiplicative_expression] = STATE(1952),
    [sym_additive_expression] = STATE(1952),
    [sym_comparison_expression] = STATE(1952),
    [sym_logical_expression] = STATE(1952),
    [sym_ternary_expression] = STATE(1952),
    [sym_unary_expression] = STATE(1952),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1952),
    [sym_list_literal] = STATE(1952),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1952),
    [sym__literal_value] = STATE(1952),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11270),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11272),
    [sym_date_literal] = ACTIONS(11270),
    [sym_time_literal] = ACTIONS(11270),
    [sym_biginteger_literal] = ACTIONS(11272),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11272),
    [sym_verbatim_string] = ACTIONS(11272),
    [sym_integer] = ACTIONS(11270),
    [sym_continue_as_identifier] = ACTIONS(11272),
  },
  [STATE(4716)] = {
    [sym_boolean] = STATE(1954),
    [sym_assignment_expression] = STATE(1954),
    [sym__expression] = STATE(1954),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1954),
    [sym_multiplicative_expression] = STATE(1954),
    [sym_additive_expression] = STATE(1954),
    [sym_comparison_expression] = STATE(1954),
    [sym_logical_expression] = STATE(1954),
    [sym_ternary_expression] = STATE(1954),
    [sym_unary_expression] = STATE(1954),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1954),
    [sym_list_literal] = STATE(1954),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1954),
    [sym__literal_value] = STATE(1954),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11274),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11276),
    [sym_date_literal] = ACTIONS(11274),
    [sym_time_literal] = ACTIONS(11274),
    [sym_biginteger_literal] = ACTIONS(11276),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11276),
    [sym_verbatim_string] = ACTIONS(11276),
    [sym_integer] = ACTIONS(11274),
    [sym_continue_as_identifier] = ACTIONS(11276),
  },
  [STATE(4717)] = {
    [sym_boolean] = STATE(1969),
    [sym_assignment_expression] = STATE(1969),
    [sym__expression] = STATE(1969),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1969),
    [sym_multiplicative_expression] = STATE(1969),
    [sym_additive_expression] = STATE(1969),
    [sym_comparison_expression] = STATE(1969),
    [sym_logical_expression] = STATE(1969),
    [sym_ternary_expression] = STATE(1969),
    [sym_unary_expression] = STATE(1969),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1969),
    [sym_list_literal] = STATE(1969),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1969),
    [sym__literal_value] = STATE(1969),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11278),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11280),
    [sym_date_literal] = ACTIONS(11278),
    [sym_time_literal] = ACTIONS(11278),
    [sym_biginteger_literal] = ACTIONS(11280),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11280),
    [sym_verbatim_string] = ACTIONS(11280),
    [sym_integer] = ACTIONS(11278),
    [sym_continue_as_identifier] = ACTIONS(11280),
  },
  [STATE(4718)] = {
    [sym_boolean] = STATE(1983),
    [sym_assignment_expression] = STATE(1983),
    [sym__expression] = STATE(1983),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1983),
    [sym_multiplicative_expression] = STATE(1983),
    [sym_additive_expression] = STATE(1983),
    [sym_comparison_expression] = STATE(1983),
    [sym_logical_expression] = STATE(1983),
    [sym_ternary_expression] = STATE(1983),
    [sym_unary_expression] = STATE(1983),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1983),
    [sym_list_literal] = STATE(1983),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1983),
    [sym__literal_value] = STATE(1983),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11282),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11284),
    [sym_date_literal] = ACTIONS(11282),
    [sym_time_literal] = ACTIONS(11282),
    [sym_biginteger_literal] = ACTIONS(11284),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11284),
    [sym_verbatim_string] = ACTIONS(11284),
    [sym_integer] = ACTIONS(11282),
    [sym_continue_as_identifier] = ACTIONS(11284),
  },
  [STATE(4719)] = {
    [sym_boolean] = STATE(7588),
    [sym_assignment_expression] = STATE(7588),
    [sym__expression] = STATE(7588),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(7588),
    [sym_multiplicative_expression] = STATE(7588),
    [sym_additive_expression] = STATE(7588),
    [sym_comparison_expression] = STATE(7588),
    [sym_logical_expression] = STATE(7588),
    [sym_ternary_expression] = STATE(7588),
    [sym_unary_expression] = STATE(7588),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(7588),
    [sym_list_literal] = STATE(7588),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(7588),
    [sym__literal_value] = STATE(7588),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11286),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11288),
    [sym_date_literal] = ACTIONS(11286),
    [sym_time_literal] = ACTIONS(11286),
    [sym_biginteger_literal] = ACTIONS(11288),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11288),
    [sym_verbatim_string] = ACTIONS(11288),
    [sym_integer] = ACTIONS(11286),
    [sym_continue_as_identifier] = ACTIONS(11288),
  },
  [STATE(4720)] = {
    [sym_boolean] = STATE(8741),
    [sym_assignment_expression] = STATE(8741),
    [sym__expression] = STATE(8741),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8741),
    [sym_multiplicative_expression] = STATE(8741),
    [sym_additive_expression] = STATE(8741),
    [sym_comparison_expression] = STATE(8741),
    [sym_logical_expression] = STATE(8741),
    [sym_ternary_expression] = STATE(8741),
    [sym_unary_expression] = STATE(8741),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8741),
    [sym_list_literal] = STATE(8741),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8741),
    [sym__literal_value] = STATE(8741),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11290),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11292),
    [sym_date_literal] = ACTIONS(11290),
    [sym_time_literal] = ACTIONS(11290),
    [sym_biginteger_literal] = ACTIONS(11292),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11292),
    [sym_verbatim_string] = ACTIONS(11292),
    [sym_integer] = ACTIONS(11290),
    [sym_continue_as_identifier] = ACTIONS(11292),
  },
  [STATE(4721)] = {
    [sym_boolean] = STATE(8647),
    [sym_assignment_expression] = STATE(8647),
    [sym__expression] = STATE(8647),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8647),
    [sym_multiplicative_expression] = STATE(8647),
    [sym_additive_expression] = STATE(8647),
    [sym_comparison_expression] = STATE(8647),
    [sym_logical_expression] = STATE(8647),
    [sym_ternary_expression] = STATE(8647),
    [sym_unary_expression] = STATE(8647),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8647),
    [sym_list_literal] = STATE(8647),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8647),
    [sym__literal_value] = STATE(8647),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11294),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11296),
    [sym_date_literal] = ACTIONS(11294),
    [sym_time_literal] = ACTIONS(11294),
    [sym_biginteger_literal] = ACTIONS(11296),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11296),
    [sym_verbatim_string] = ACTIONS(11296),
    [sym_integer] = ACTIONS(11294),
    [sym_continue_as_identifier] = ACTIONS(11296),
  },
  [STATE(4722)] = {
    [sym_boolean] = STATE(8745),
    [sym_assignment_expression] = STATE(8745),
    [sym__expression] = STATE(8745),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8745),
    [sym_multiplicative_expression] = STATE(8745),
    [sym_additive_expression] = STATE(8745),
    [sym_comparison_expression] = STATE(8745),
    [sym_logical_expression] = STATE(8745),
    [sym_ternary_expression] = STATE(8745),
    [sym_unary_expression] = STATE(8745),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8745),
    [sym_list_literal] = STATE(8745),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8745),
    [sym__literal_value] = STATE(8745),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11298),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11300),
    [sym_date_literal] = ACTIONS(11298),
    [sym_time_literal] = ACTIONS(11298),
    [sym_biginteger_literal] = ACTIONS(11300),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11300),
    [sym_verbatim_string] = ACTIONS(11300),
    [sym_integer] = ACTIONS(11298),
    [sym_continue_as_identifier] = ACTIONS(11300),
  },
  [STATE(4723)] = {
    [sym_boolean] = STATE(8447),
    [sym_assignment_expression] = STATE(8447),
    [sym__expression] = STATE(8447),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8447),
    [sym_multiplicative_expression] = STATE(8447),
    [sym_additive_expression] = STATE(8447),
    [sym_comparison_expression] = STATE(8447),
    [sym_logical_expression] = STATE(8447),
    [sym_ternary_expression] = STATE(8447),
    [sym_unary_expression] = STATE(8447),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8447),
    [sym_list_literal] = STATE(8447),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8447),
    [sym__literal_value] = STATE(8447),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11302),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11304),
    [sym_date_literal] = ACTIONS(11302),
    [sym_time_literal] = ACTIONS(11302),
    [sym_biginteger_literal] = ACTIONS(11304),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11304),
    [sym_verbatim_string] = ACTIONS(11304),
    [sym_integer] = ACTIONS(11302),
    [sym_continue_as_identifier] = ACTIONS(11304),
  },
  [STATE(4724)] = {
    [sym_boolean] = STATE(8450),
    [sym_assignment_expression] = STATE(8450),
    [sym__expression] = STATE(8450),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8450),
    [sym_multiplicative_expression] = STATE(8450),
    [sym_additive_expression] = STATE(8450),
    [sym_comparison_expression] = STATE(8450),
    [sym_logical_expression] = STATE(8450),
    [sym_ternary_expression] = STATE(8450),
    [sym_unary_expression] = STATE(8450),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8450),
    [sym_list_literal] = STATE(8450),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8450),
    [sym__literal_value] = STATE(8450),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11306),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11308),
    [sym_date_literal] = ACTIONS(11306),
    [sym_time_literal] = ACTIONS(11306),
    [sym_biginteger_literal] = ACTIONS(11308),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11308),
    [sym_verbatim_string] = ACTIONS(11308),
    [sym_integer] = ACTIONS(11306),
    [sym_continue_as_identifier] = ACTIONS(11308),
  },
  [STATE(4725)] = {
    [sym_boolean] = STATE(8451),
    [sym_assignment_expression] = STATE(8451),
    [sym__expression] = STATE(8451),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8451),
    [sym_multiplicative_expression] = STATE(8451),
    [sym_additive_expression] = STATE(8451),
    [sym_comparison_expression] = STATE(8451),
    [sym_logical_expression] = STATE(8451),
    [sym_ternary_expression] = STATE(8451),
    [sym_unary_expression] = STATE(8451),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8451),
    [sym_list_literal] = STATE(8451),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8451),
    [sym__literal_value] = STATE(8451),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11310),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11312),
    [sym_date_literal] = ACTIONS(11310),
    [sym_time_literal] = ACTIONS(11310),
    [sym_biginteger_literal] = ACTIONS(11312),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11312),
    [sym_verbatim_string] = ACTIONS(11312),
    [sym_integer] = ACTIONS(11310),
    [sym_continue_as_identifier] = ACTIONS(11312),
  },
  [STATE(4726)] = {
    [sym_boolean] = STATE(8613),
    [sym_assignment_expression] = STATE(8613),
    [sym__expression] = STATE(8613),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8613),
    [sym_multiplicative_expression] = STATE(8613),
    [sym_additive_expression] = STATE(8613),
    [sym_comparison_expression] = STATE(8613),
    [sym_logical_expression] = STATE(8613),
    [sym_ternary_expression] = STATE(8613),
    [sym_unary_expression] = STATE(8613),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8613),
    [sym_list_literal] = STATE(8613),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8613),
    [sym__literal_value] = STATE(8613),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11314),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11316),
    [sym_date_literal] = ACTIONS(11314),
    [sym_time_literal] = ACTIONS(11314),
    [sym_biginteger_literal] = ACTIONS(11316),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11316),
    [sym_verbatim_string] = ACTIONS(11316),
    [sym_integer] = ACTIONS(11314),
    [sym_continue_as_identifier] = ACTIONS(11316),
  },
  [STATE(4727)] = {
    [sym_boolean] = STATE(8482),
    [sym_assignment_expression] = STATE(8482),
    [sym__expression] = STATE(8482),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8482),
    [sym_multiplicative_expression] = STATE(8482),
    [sym_additive_expression] = STATE(8482),
    [sym_comparison_expression] = STATE(8482),
    [sym_logical_expression] = STATE(8482),
    [sym_ternary_expression] = STATE(8482),
    [sym_unary_expression] = STATE(8482),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8482),
    [sym_list_literal] = STATE(8482),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8482),
    [sym__literal_value] = STATE(8482),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11318),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11320),
    [sym_date_literal] = ACTIONS(11318),
    [sym_time_literal] = ACTIONS(11318),
    [sym_biginteger_literal] = ACTIONS(11320),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11320),
    [sym_verbatim_string] = ACTIONS(11320),
    [sym_integer] = ACTIONS(11318),
    [sym_continue_as_identifier] = ACTIONS(11320),
  },
  [STATE(4728)] = {
    [sym_boolean] = STATE(8497),
    [sym_assignment_expression] = STATE(8497),
    [sym__expression] = STATE(8497),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8497),
    [sym_multiplicative_expression] = STATE(8497),
    [sym_additive_expression] = STATE(8497),
    [sym_comparison_expression] = STATE(8497),
    [sym_logical_expression] = STATE(8497),
    [sym_ternary_expression] = STATE(8497),
    [sym_unary_expression] = STATE(8497),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8497),
    [sym_list_literal] = STATE(8497),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8497),
    [sym__literal_value] = STATE(8497),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11322),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11324),
    [sym_date_literal] = ACTIONS(11322),
    [sym_time_literal] = ACTIONS(11322),
    [sym_biginteger_literal] = ACTIONS(11324),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11324),
    [sym_verbatim_string] = ACTIONS(11324),
    [sym_integer] = ACTIONS(11322),
    [sym_continue_as_identifier] = ACTIONS(11324),
  },
  [STATE(4729)] = {
    [sym_boolean] = STATE(8499),
    [sym_assignment_expression] = STATE(8499),
    [sym__expression] = STATE(8499),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8499),
    [sym_multiplicative_expression] = STATE(8499),
    [sym_additive_expression] = STATE(8499),
    [sym_comparison_expression] = STATE(8499),
    [sym_logical_expression] = STATE(8499),
    [sym_ternary_expression] = STATE(8499),
    [sym_unary_expression] = STATE(8499),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8499),
    [sym_list_literal] = STATE(8499),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8499),
    [sym__literal_value] = STATE(8499),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11326),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11328),
    [sym_date_literal] = ACTIONS(11326),
    [sym_time_literal] = ACTIONS(11326),
    [sym_biginteger_literal] = ACTIONS(11328),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11328),
    [sym_verbatim_string] = ACTIONS(11328),
    [sym_integer] = ACTIONS(11326),
    [sym_continue_as_identifier] = ACTIONS(11328),
  },
  [STATE(4730)] = {
    [sym_boolean] = STATE(1984),
    [sym_assignment_expression] = STATE(1984),
    [sym__expression] = STATE(1984),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1984),
    [sym_multiplicative_expression] = STATE(1984),
    [sym_additive_expression] = STATE(1984),
    [sym_comparison_expression] = STATE(1984),
    [sym_logical_expression] = STATE(1984),
    [sym_ternary_expression] = STATE(1984),
    [sym_unary_expression] = STATE(1984),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1984),
    [sym_list_literal] = STATE(1984),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1984),
    [sym__literal_value] = STATE(1984),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11330),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11332),
    [sym_date_literal] = ACTIONS(11330),
    [sym_time_literal] = ACTIONS(11330),
    [sym_biginteger_literal] = ACTIONS(11332),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11332),
    [sym_verbatim_string] = ACTIONS(11332),
    [sym_integer] = ACTIONS(11330),
    [sym_continue_as_identifier] = ACTIONS(11332),
  },
  [STATE(4731)] = {
    [sym__layout_element] = STATE(4878),
    [sym_area_section] = STATE(4878),
    [sym_group_section] = STATE(4878),
    [sym_repeater_section] = STATE(4878),
    [sym_cuegroup_section] = STATE(4878),
    [sym_fixed_section] = STATE(4878),
    [sym_grid_section] = STATE(4878),
    [sym_page_field] = STATE(4878),
    [sym_part_section] = STATE(4878),
    [sym_systempart_section] = STATE(4878),
    [sym_usercontrol_section] = STATE(4878),
    [sym_preproc_split_field] = STATE(4878),
    [sym__field_header] = STATE(10667),
    [sym_label_section] = STATE(4878),
    [sym_addfirst_modification] = STATE(4878),
    [sym_addlast_modification] = STATE(4878),
    [sym_addafter_modification] = STATE(4878),
    [sym_addbefore_modification] = STATE(4878),
    [sym_modify_modification] = STATE(4878),
    [sym_movefirst_modification] = STATE(4878),
    [sym_movelast_modification] = STATE(4878),
    [sym_moveafter_modification] = STATE(4878),
    [sym_movebefore_modification] = STATE(4878),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6512),
    [sym_preproc_endif] = STATE(10155),
    [sym_preproc_conditional_layout] = STATE(4878),
    [aux_sym_layout_section_repeat1] = STATE(4878),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10715),
    [aux_sym_where_condition_token1] = ACTIONS(9790),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4732)] = {
    [sym_boolean] = STATE(1987),
    [sym_assignment_expression] = STATE(1987),
    [sym__expression] = STATE(1987),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1987),
    [sym_multiplicative_expression] = STATE(1987),
    [sym_additive_expression] = STATE(1987),
    [sym_comparison_expression] = STATE(1987),
    [sym_logical_expression] = STATE(1987),
    [sym_ternary_expression] = STATE(1987),
    [sym_unary_expression] = STATE(1987),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1987),
    [sym_list_literal] = STATE(1987),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1987),
    [sym__literal_value] = STATE(1987),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11334),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11336),
    [sym_date_literal] = ACTIONS(11334),
    [sym_time_literal] = ACTIONS(11334),
    [sym_biginteger_literal] = ACTIONS(11336),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11336),
    [sym_verbatim_string] = ACTIONS(11336),
    [sym_integer] = ACTIONS(11334),
    [sym_continue_as_identifier] = ACTIONS(11336),
  },
  [STATE(4733)] = {
    [sym_boolean] = STATE(1809),
    [sym_assignment_expression] = STATE(1809),
    [sym__expression] = STATE(1809),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1809),
    [sym_multiplicative_expression] = STATE(1809),
    [sym_additive_expression] = STATE(1809),
    [sym_comparison_expression] = STATE(1809),
    [sym_logical_expression] = STATE(1809),
    [sym_ternary_expression] = STATE(1809),
    [sym_unary_expression] = STATE(1809),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1809),
    [sym_list_literal] = STATE(1809),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1809),
    [sym__literal_value] = STATE(1809),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11338),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11340),
    [sym_date_literal] = ACTIONS(11338),
    [sym_time_literal] = ACTIONS(11338),
    [sym_biginteger_literal] = ACTIONS(11340),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11340),
    [sym_verbatim_string] = ACTIONS(11340),
    [sym_integer] = ACTIONS(11338),
    [sym_continue_as_identifier] = ACTIONS(11340),
  },
  [STATE(4734)] = {
    [sym_boolean] = STATE(1988),
    [sym_assignment_expression] = STATE(1988),
    [sym__expression] = STATE(1988),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1988),
    [sym_multiplicative_expression] = STATE(1988),
    [sym_additive_expression] = STATE(1988),
    [sym_comparison_expression] = STATE(1988),
    [sym_logical_expression] = STATE(1988),
    [sym_ternary_expression] = STATE(1988),
    [sym_unary_expression] = STATE(1988),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1988),
    [sym_list_literal] = STATE(1988),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1988),
    [sym__literal_value] = STATE(1988),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11342),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11344),
    [sym_date_literal] = ACTIONS(11342),
    [sym_time_literal] = ACTIONS(11342),
    [sym_biginteger_literal] = ACTIONS(11344),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11344),
    [sym_verbatim_string] = ACTIONS(11344),
    [sym_integer] = ACTIONS(11342),
    [sym_continue_as_identifier] = ACTIONS(11344),
  },
  [STATE(4735)] = {
    [sym_boolean] = STATE(1991),
    [sym_assignment_expression] = STATE(1991),
    [sym__expression] = STATE(1991),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1991),
    [sym_multiplicative_expression] = STATE(1991),
    [sym_additive_expression] = STATE(1991),
    [sym_comparison_expression] = STATE(1991),
    [sym_logical_expression] = STATE(1991),
    [sym_ternary_expression] = STATE(1991),
    [sym_unary_expression] = STATE(1991),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1991),
    [sym_list_literal] = STATE(1991),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1991),
    [sym__literal_value] = STATE(1991),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11346),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11348),
    [sym_date_literal] = ACTIONS(11346),
    [sym_time_literal] = ACTIONS(11346),
    [sym_biginteger_literal] = ACTIONS(11348),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11348),
    [sym_verbatim_string] = ACTIONS(11348),
    [sym_integer] = ACTIONS(11346),
    [sym_continue_as_identifier] = ACTIONS(11348),
  },
  [STATE(4736)] = {
    [sym_boolean] = STATE(8718),
    [sym_assignment_expression] = STATE(8718),
    [sym__expression] = STATE(8718),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8718),
    [sym_multiplicative_expression] = STATE(8718),
    [sym_additive_expression] = STATE(8718),
    [sym_comparison_expression] = STATE(8718),
    [sym_logical_expression] = STATE(8718),
    [sym_ternary_expression] = STATE(8718),
    [sym_unary_expression] = STATE(8718),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8718),
    [sym_list_literal] = STATE(8718),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8718),
    [sym__literal_value] = STATE(8718),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11350),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11352),
    [sym_date_literal] = ACTIONS(11350),
    [sym_time_literal] = ACTIONS(11350),
    [sym_biginteger_literal] = ACTIONS(11352),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11352),
    [sym_verbatim_string] = ACTIONS(11352),
    [sym_integer] = ACTIONS(11350),
    [sym_continue_as_identifier] = ACTIONS(11352),
  },
  [STATE(4737)] = {
    [sym_boolean] = STATE(8669),
    [sym_assignment_expression] = STATE(8669),
    [sym__expression] = STATE(8669),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8669),
    [sym_multiplicative_expression] = STATE(8669),
    [sym_additive_expression] = STATE(8669),
    [sym_comparison_expression] = STATE(8669),
    [sym_logical_expression] = STATE(8669),
    [sym_ternary_expression] = STATE(8669),
    [sym_unary_expression] = STATE(8669),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8669),
    [sym_list_literal] = STATE(8669),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8669),
    [sym__literal_value] = STATE(8669),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11354),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11356),
    [sym_date_literal] = ACTIONS(11354),
    [sym_time_literal] = ACTIONS(11354),
    [sym_biginteger_literal] = ACTIONS(11356),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11356),
    [sym_verbatim_string] = ACTIONS(11356),
    [sym_integer] = ACTIONS(11354),
    [sym_continue_as_identifier] = ACTIONS(11356),
  },
  [STATE(4738)] = {
    [sym_boolean] = STATE(8780),
    [sym_assignment_expression] = STATE(8780),
    [sym__expression] = STATE(8780),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8780),
    [sym_multiplicative_expression] = STATE(8780),
    [sym_additive_expression] = STATE(8780),
    [sym_comparison_expression] = STATE(8780),
    [sym_logical_expression] = STATE(8780),
    [sym_ternary_expression] = STATE(8780),
    [sym_unary_expression] = STATE(8780),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8780),
    [sym_list_literal] = STATE(8780),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8780),
    [sym__literal_value] = STATE(8780),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11358),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11360),
    [sym_date_literal] = ACTIONS(11358),
    [sym_time_literal] = ACTIONS(11358),
    [sym_biginteger_literal] = ACTIONS(11360),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11360),
    [sym_verbatim_string] = ACTIONS(11360),
    [sym_integer] = ACTIONS(11358),
    [sym_continue_as_identifier] = ACTIONS(11360),
  },
  [STATE(4739)] = {
    [sym_boolean] = STATE(8530),
    [sym_assignment_expression] = STATE(8530),
    [sym__expression] = STATE(8530),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8530),
    [sym_multiplicative_expression] = STATE(8530),
    [sym_additive_expression] = STATE(8530),
    [sym_comparison_expression] = STATE(8530),
    [sym_logical_expression] = STATE(8530),
    [sym_ternary_expression] = STATE(8530),
    [sym_unary_expression] = STATE(8530),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8530),
    [sym_list_literal] = STATE(8530),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8530),
    [sym__literal_value] = STATE(8530),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11362),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11364),
    [sym_date_literal] = ACTIONS(11362),
    [sym_time_literal] = ACTIONS(11362),
    [sym_biginteger_literal] = ACTIONS(11364),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11364),
    [sym_verbatim_string] = ACTIONS(11364),
    [sym_integer] = ACTIONS(11362),
    [sym_continue_as_identifier] = ACTIONS(11364),
  },
  [STATE(4740)] = {
    [sym_boolean] = STATE(8531),
    [sym_assignment_expression] = STATE(8531),
    [sym__expression] = STATE(8531),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8531),
    [sym_multiplicative_expression] = STATE(8531),
    [sym_additive_expression] = STATE(8531),
    [sym_comparison_expression] = STATE(8531),
    [sym_logical_expression] = STATE(8531),
    [sym_ternary_expression] = STATE(8531),
    [sym_unary_expression] = STATE(8531),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8531),
    [sym_list_literal] = STATE(8531),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8531),
    [sym__literal_value] = STATE(8531),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11366),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11368),
    [sym_date_literal] = ACTIONS(11366),
    [sym_time_literal] = ACTIONS(11366),
    [sym_biginteger_literal] = ACTIONS(11368),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11368),
    [sym_verbatim_string] = ACTIONS(11368),
    [sym_integer] = ACTIONS(11366),
    [sym_continue_as_identifier] = ACTIONS(11368),
  },
  [STATE(4741)] = {
    [sym_boolean] = STATE(8532),
    [sym_assignment_expression] = STATE(8532),
    [sym__expression] = STATE(8532),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8532),
    [sym_multiplicative_expression] = STATE(8532),
    [sym_additive_expression] = STATE(8532),
    [sym_comparison_expression] = STATE(8532),
    [sym_logical_expression] = STATE(8532),
    [sym_ternary_expression] = STATE(8532),
    [sym_unary_expression] = STATE(8532),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8532),
    [sym_list_literal] = STATE(8532),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8532),
    [sym__literal_value] = STATE(8532),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11370),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11372),
    [sym_date_literal] = ACTIONS(11370),
    [sym_time_literal] = ACTIONS(11370),
    [sym_biginteger_literal] = ACTIONS(11372),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11372),
    [sym_verbatim_string] = ACTIONS(11372),
    [sym_integer] = ACTIONS(11370),
    [sym_continue_as_identifier] = ACTIONS(11372),
  },
  [STATE(4742)] = {
    [sym_boolean] = STATE(8542),
    [sym_assignment_expression] = STATE(8542),
    [sym__expression] = STATE(8542),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8542),
    [sym_multiplicative_expression] = STATE(8542),
    [sym_additive_expression] = STATE(8542),
    [sym_comparison_expression] = STATE(8542),
    [sym_logical_expression] = STATE(8542),
    [sym_ternary_expression] = STATE(8542),
    [sym_unary_expression] = STATE(8542),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8542),
    [sym_list_literal] = STATE(8542),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8542),
    [sym__literal_value] = STATE(8542),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11374),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11376),
    [sym_date_literal] = ACTIONS(11374),
    [sym_time_literal] = ACTIONS(11374),
    [sym_biginteger_literal] = ACTIONS(11376),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11376),
    [sym_verbatim_string] = ACTIONS(11376),
    [sym_integer] = ACTIONS(11374),
    [sym_continue_as_identifier] = ACTIONS(11376),
  },
  [STATE(4743)] = {
    [sym_boolean] = STATE(8533),
    [sym_assignment_expression] = STATE(8533),
    [sym__expression] = STATE(8533),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8533),
    [sym_multiplicative_expression] = STATE(8533),
    [sym_additive_expression] = STATE(8533),
    [sym_comparison_expression] = STATE(8533),
    [sym_logical_expression] = STATE(8533),
    [sym_ternary_expression] = STATE(8533),
    [sym_unary_expression] = STATE(8533),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8533),
    [sym_list_literal] = STATE(8533),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8533),
    [sym__literal_value] = STATE(8533),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11378),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11380),
    [sym_date_literal] = ACTIONS(11378),
    [sym_time_literal] = ACTIONS(11378),
    [sym_biginteger_literal] = ACTIONS(11380),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11380),
    [sym_verbatim_string] = ACTIONS(11380),
    [sym_integer] = ACTIONS(11378),
    [sym_continue_as_identifier] = ACTIONS(11380),
  },
  [STATE(4744)] = {
    [sym_boolean] = STATE(1960),
    [sym_assignment_expression] = STATE(1960),
    [sym__expression] = STATE(1960),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1960),
    [sym_multiplicative_expression] = STATE(1960),
    [sym_additive_expression] = STATE(1960),
    [sym_comparison_expression] = STATE(1960),
    [sym_logical_expression] = STATE(1960),
    [sym_ternary_expression] = STATE(1960),
    [sym_unary_expression] = STATE(1960),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1960),
    [sym_list_literal] = STATE(1960),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1960),
    [sym__literal_value] = STATE(1960),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11382),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11384),
    [sym_date_literal] = ACTIONS(11382),
    [sym_time_literal] = ACTIONS(11382),
    [sym_biginteger_literal] = ACTIONS(11384),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11384),
    [sym_verbatim_string] = ACTIONS(11384),
    [sym_integer] = ACTIONS(11382),
    [sym_continue_as_identifier] = ACTIONS(11384),
  },
  [STATE(4745)] = {
    [sym_boolean] = STATE(1961),
    [sym_assignment_expression] = STATE(1961),
    [sym__expression] = STATE(1961),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1961),
    [sym_multiplicative_expression] = STATE(1961),
    [sym_additive_expression] = STATE(1961),
    [sym_comparison_expression] = STATE(1961),
    [sym_logical_expression] = STATE(1961),
    [sym_ternary_expression] = STATE(1961),
    [sym_unary_expression] = STATE(1961),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1961),
    [sym_list_literal] = STATE(1961),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1961),
    [sym__literal_value] = STATE(1961),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11386),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11388),
    [sym_date_literal] = ACTIONS(11386),
    [sym_time_literal] = ACTIONS(11386),
    [sym_biginteger_literal] = ACTIONS(11388),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11388),
    [sym_verbatim_string] = ACTIONS(11388),
    [sym_integer] = ACTIONS(11386),
    [sym_continue_as_identifier] = ACTIONS(11388),
  },
  [STATE(4746)] = {
    [sym_boolean] = STATE(1962),
    [sym_assignment_expression] = STATE(1962),
    [sym__expression] = STATE(1962),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1962),
    [sym_multiplicative_expression] = STATE(1962),
    [sym_additive_expression] = STATE(1962),
    [sym_comparison_expression] = STATE(1962),
    [sym_logical_expression] = STATE(1962),
    [sym_ternary_expression] = STATE(1962),
    [sym_unary_expression] = STATE(1962),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1962),
    [sym_list_literal] = STATE(1962),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1962),
    [sym__literal_value] = STATE(1962),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11390),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11392),
    [sym_date_literal] = ACTIONS(11390),
    [sym_time_literal] = ACTIONS(11390),
    [sym_biginteger_literal] = ACTIONS(11392),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11392),
    [sym_verbatim_string] = ACTIONS(11392),
    [sym_integer] = ACTIONS(11390),
    [sym_continue_as_identifier] = ACTIONS(11392),
  },
  [STATE(4747)] = {
    [sym_boolean] = STATE(8535),
    [sym_assignment_expression] = STATE(8535),
    [sym__expression] = STATE(8535),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8535),
    [sym_multiplicative_expression] = STATE(8535),
    [sym_additive_expression] = STATE(8535),
    [sym_comparison_expression] = STATE(8535),
    [sym_logical_expression] = STATE(8535),
    [sym_ternary_expression] = STATE(8535),
    [sym_unary_expression] = STATE(8535),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8535),
    [sym_list_literal] = STATE(8535),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8535),
    [sym__literal_value] = STATE(8535),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11394),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11396),
    [sym_date_literal] = ACTIONS(11394),
    [sym_time_literal] = ACTIONS(11394),
    [sym_biginteger_literal] = ACTIONS(11396),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11396),
    [sym_verbatim_string] = ACTIONS(11396),
    [sym_integer] = ACTIONS(11394),
    [sym_continue_as_identifier] = ACTIONS(11396),
  },
  [STATE(4748)] = {
    [sym_boolean] = STATE(8536),
    [sym_assignment_expression] = STATE(8536),
    [sym__expression] = STATE(8536),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8536),
    [sym_multiplicative_expression] = STATE(8536),
    [sym_additive_expression] = STATE(8536),
    [sym_comparison_expression] = STATE(8536),
    [sym_logical_expression] = STATE(8536),
    [sym_ternary_expression] = STATE(8536),
    [sym_unary_expression] = STATE(8536),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8536),
    [sym_list_literal] = STATE(8536),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8536),
    [sym__literal_value] = STATE(8536),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11398),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11400),
    [sym_date_literal] = ACTIONS(11398),
    [sym_time_literal] = ACTIONS(11398),
    [sym_biginteger_literal] = ACTIONS(11400),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11400),
    [sym_verbatim_string] = ACTIONS(11400),
    [sym_integer] = ACTIONS(11398),
    [sym_continue_as_identifier] = ACTIONS(11400),
  },
  [STATE(4749)] = {
    [sym_boolean] = STATE(1963),
    [sym_assignment_expression] = STATE(1963),
    [sym__expression] = STATE(1963),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1963),
    [sym_multiplicative_expression] = STATE(1963),
    [sym_additive_expression] = STATE(1963),
    [sym_comparison_expression] = STATE(1963),
    [sym_logical_expression] = STATE(1963),
    [sym_ternary_expression] = STATE(1963),
    [sym_unary_expression] = STATE(1963),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1963),
    [sym_list_literal] = STATE(1963),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1963),
    [sym__literal_value] = STATE(1963),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11402),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11404),
    [sym_date_literal] = ACTIONS(11402),
    [sym_time_literal] = ACTIONS(11402),
    [sym_biginteger_literal] = ACTIONS(11404),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11404),
    [sym_verbatim_string] = ACTIONS(11404),
    [sym_integer] = ACTIONS(11402),
    [sym_continue_as_identifier] = ACTIONS(11404),
  },
  [STATE(4750)] = {
    [sym_boolean] = STATE(1786),
    [sym_assignment_expression] = STATE(1786),
    [sym__expression] = STATE(1786),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1786),
    [sym_multiplicative_expression] = STATE(1786),
    [sym_additive_expression] = STATE(1786),
    [sym_comparison_expression] = STATE(1786),
    [sym_logical_expression] = STATE(1786),
    [sym_ternary_expression] = STATE(1786),
    [sym_unary_expression] = STATE(1786),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1786),
    [sym_list_literal] = STATE(1786),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1786),
    [sym__literal_value] = STATE(1786),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11406),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11408),
    [sym_date_literal] = ACTIONS(11406),
    [sym_time_literal] = ACTIONS(11406),
    [sym_biginteger_literal] = ACTIONS(11408),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11408),
    [sym_verbatim_string] = ACTIONS(11408),
    [sym_integer] = ACTIONS(11406),
    [sym_continue_as_identifier] = ACTIONS(11408),
  },
  [STATE(4751)] = {
    [sym_boolean] = STATE(1776),
    [sym_assignment_expression] = STATE(1776),
    [sym__expression] = STATE(1776),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1776),
    [sym_multiplicative_expression] = STATE(1776),
    [sym_additive_expression] = STATE(1776),
    [sym_comparison_expression] = STATE(1776),
    [sym_logical_expression] = STATE(1776),
    [sym_ternary_expression] = STATE(1776),
    [sym_unary_expression] = STATE(1776),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1776),
    [sym_list_literal] = STATE(1776),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1776),
    [sym__literal_value] = STATE(1776),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11410),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11412),
    [sym_date_literal] = ACTIONS(11410),
    [sym_time_literal] = ACTIONS(11410),
    [sym_biginteger_literal] = ACTIONS(11412),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11412),
    [sym_verbatim_string] = ACTIONS(11412),
    [sym_integer] = ACTIONS(11410),
    [sym_continue_as_identifier] = ACTIONS(11412),
  },
  [STATE(4752)] = {
    [sym_boolean] = STATE(1773),
    [sym_assignment_expression] = STATE(1773),
    [sym__expression] = STATE(1773),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1773),
    [sym_multiplicative_expression] = STATE(1773),
    [sym_additive_expression] = STATE(1773),
    [sym_comparison_expression] = STATE(1773),
    [sym_logical_expression] = STATE(1773),
    [sym_ternary_expression] = STATE(1773),
    [sym_unary_expression] = STATE(1773),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1773),
    [sym_list_literal] = STATE(1773),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1773),
    [sym__literal_value] = STATE(1773),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11414),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11416),
    [sym_date_literal] = ACTIONS(11414),
    [sym_time_literal] = ACTIONS(11414),
    [sym_biginteger_literal] = ACTIONS(11416),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11416),
    [sym_verbatim_string] = ACTIONS(11416),
    [sym_integer] = ACTIONS(11414),
    [sym_continue_as_identifier] = ACTIONS(11416),
  },
  [STATE(4753)] = {
    [sym_boolean] = STATE(1774),
    [sym_assignment_expression] = STATE(1774),
    [sym__expression] = STATE(1774),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1774),
    [sym_multiplicative_expression] = STATE(1774),
    [sym_additive_expression] = STATE(1774),
    [sym_comparison_expression] = STATE(1774),
    [sym_logical_expression] = STATE(1774),
    [sym_ternary_expression] = STATE(1774),
    [sym_unary_expression] = STATE(1774),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1774),
    [sym_list_literal] = STATE(1774),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1774),
    [sym__literal_value] = STATE(1774),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11418),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11420),
    [sym_date_literal] = ACTIONS(11418),
    [sym_time_literal] = ACTIONS(11418),
    [sym_biginteger_literal] = ACTIONS(11420),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11420),
    [sym_verbatim_string] = ACTIONS(11420),
    [sym_integer] = ACTIONS(11418),
    [sym_continue_as_identifier] = ACTIONS(11420),
  },
  [STATE(4754)] = {
    [sym_boolean] = STATE(1787),
    [sym_assignment_expression] = STATE(1787),
    [sym__expression] = STATE(1787),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1787),
    [sym_multiplicative_expression] = STATE(1787),
    [sym_additive_expression] = STATE(1787),
    [sym_comparison_expression] = STATE(1787),
    [sym_logical_expression] = STATE(1787),
    [sym_ternary_expression] = STATE(1787),
    [sym_unary_expression] = STATE(1787),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1787),
    [sym_list_literal] = STATE(1787),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1787),
    [sym__literal_value] = STATE(1787),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11422),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11424),
    [sym_date_literal] = ACTIONS(11422),
    [sym_time_literal] = ACTIONS(11422),
    [sym_biginteger_literal] = ACTIONS(11424),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11424),
    [sym_verbatim_string] = ACTIONS(11424),
    [sym_integer] = ACTIONS(11422),
    [sym_continue_as_identifier] = ACTIONS(11424),
  },
  [STATE(4755)] = {
    [sym_boolean] = STATE(1788),
    [sym_assignment_expression] = STATE(1788),
    [sym__expression] = STATE(1788),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1788),
    [sym_multiplicative_expression] = STATE(1788),
    [sym_additive_expression] = STATE(1788),
    [sym_comparison_expression] = STATE(1788),
    [sym_logical_expression] = STATE(1788),
    [sym_ternary_expression] = STATE(1788),
    [sym_unary_expression] = STATE(1788),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1788),
    [sym_list_literal] = STATE(1788),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1788),
    [sym__literal_value] = STATE(1788),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11426),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11428),
    [sym_date_literal] = ACTIONS(11426),
    [sym_time_literal] = ACTIONS(11426),
    [sym_biginteger_literal] = ACTIONS(11428),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11428),
    [sym_verbatim_string] = ACTIONS(11428),
    [sym_integer] = ACTIONS(11426),
    [sym_continue_as_identifier] = ACTIONS(11428),
  },
  [STATE(4756)] = {
    [sym_boolean] = STATE(1772),
    [sym_assignment_expression] = STATE(1772),
    [sym__expression] = STATE(1772),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1772),
    [sym_multiplicative_expression] = STATE(1772),
    [sym_additive_expression] = STATE(1772),
    [sym_comparison_expression] = STATE(1772),
    [sym_logical_expression] = STATE(1772),
    [sym_ternary_expression] = STATE(1772),
    [sym_unary_expression] = STATE(1772),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1772),
    [sym_list_literal] = STATE(1772),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1772),
    [sym__literal_value] = STATE(1772),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11430),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11432),
    [sym_date_literal] = ACTIONS(11430),
    [sym_time_literal] = ACTIONS(11430),
    [sym_biginteger_literal] = ACTIONS(11432),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11432),
    [sym_verbatim_string] = ACTIONS(11432),
    [sym_integer] = ACTIONS(11430),
    [sym_continue_as_identifier] = ACTIONS(11432),
  },
  [STATE(4757)] = {
    [sym_boolean] = STATE(1791),
    [sym_assignment_expression] = STATE(1791),
    [sym__expression] = STATE(1791),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1791),
    [sym_multiplicative_expression] = STATE(1791),
    [sym_additive_expression] = STATE(1791),
    [sym_comparison_expression] = STATE(1791),
    [sym_logical_expression] = STATE(1791),
    [sym_ternary_expression] = STATE(1791),
    [sym_unary_expression] = STATE(1791),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1791),
    [sym_list_literal] = STATE(1791),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1791),
    [sym__literal_value] = STATE(1791),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11434),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11436),
    [sym_date_literal] = ACTIONS(11434),
    [sym_time_literal] = ACTIONS(11434),
    [sym_biginteger_literal] = ACTIONS(11436),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11436),
    [sym_verbatim_string] = ACTIONS(11436),
    [sym_integer] = ACTIONS(11434),
    [sym_continue_as_identifier] = ACTIONS(11436),
  },
  [STATE(4758)] = {
    [sym_boolean] = STATE(1813),
    [sym_assignment_expression] = STATE(1813),
    [sym__expression] = STATE(1813),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1813),
    [sym_multiplicative_expression] = STATE(1813),
    [sym_additive_expression] = STATE(1813),
    [sym_comparison_expression] = STATE(1813),
    [sym_logical_expression] = STATE(1813),
    [sym_ternary_expression] = STATE(1813),
    [sym_unary_expression] = STATE(1813),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1813),
    [sym_list_literal] = STATE(1813),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1813),
    [sym__literal_value] = STATE(1813),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11438),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11440),
    [sym_date_literal] = ACTIONS(11438),
    [sym_time_literal] = ACTIONS(11438),
    [sym_biginteger_literal] = ACTIONS(11440),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11440),
    [sym_verbatim_string] = ACTIONS(11440),
    [sym_integer] = ACTIONS(11438),
    [sym_continue_as_identifier] = ACTIONS(11440),
  },
  [STATE(4759)] = {
    [sym_boolean] = STATE(1793),
    [sym_assignment_expression] = STATE(1793),
    [sym__expression] = STATE(1793),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1793),
    [sym_multiplicative_expression] = STATE(1793),
    [sym_additive_expression] = STATE(1793),
    [sym_comparison_expression] = STATE(1793),
    [sym_logical_expression] = STATE(1793),
    [sym_ternary_expression] = STATE(1793),
    [sym_unary_expression] = STATE(1793),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1793),
    [sym_list_literal] = STATE(1793),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1793),
    [sym__literal_value] = STATE(1793),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11442),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11444),
    [sym_date_literal] = ACTIONS(11442),
    [sym_time_literal] = ACTIONS(11442),
    [sym_biginteger_literal] = ACTIONS(11444),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11444),
    [sym_verbatim_string] = ACTIONS(11444),
    [sym_integer] = ACTIONS(11442),
    [sym_continue_as_identifier] = ACTIONS(11444),
  },
  [STATE(4760)] = {
    [sym_boolean] = STATE(1794),
    [sym_assignment_expression] = STATE(1794),
    [sym__expression] = STATE(1794),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1794),
    [sym_multiplicative_expression] = STATE(1794),
    [sym_additive_expression] = STATE(1794),
    [sym_comparison_expression] = STATE(1794),
    [sym_logical_expression] = STATE(1794),
    [sym_ternary_expression] = STATE(1794),
    [sym_unary_expression] = STATE(1794),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1794),
    [sym_list_literal] = STATE(1794),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1794),
    [sym__literal_value] = STATE(1794),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11446),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11448),
    [sym_date_literal] = ACTIONS(11446),
    [sym_time_literal] = ACTIONS(11446),
    [sym_biginteger_literal] = ACTIONS(11448),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11448),
    [sym_verbatim_string] = ACTIONS(11448),
    [sym_integer] = ACTIONS(11446),
    [sym_continue_as_identifier] = ACTIONS(11448),
  },
  [STATE(4761)] = {
    [sym_boolean] = STATE(1795),
    [sym_assignment_expression] = STATE(1795),
    [sym__expression] = STATE(1795),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1795),
    [sym_multiplicative_expression] = STATE(1795),
    [sym_additive_expression] = STATE(1795),
    [sym_comparison_expression] = STATE(1795),
    [sym_logical_expression] = STATE(1795),
    [sym_ternary_expression] = STATE(1795),
    [sym_unary_expression] = STATE(1795),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1795),
    [sym_list_literal] = STATE(1795),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1795),
    [sym__literal_value] = STATE(1795),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11450),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11452),
    [sym_date_literal] = ACTIONS(11450),
    [sym_time_literal] = ACTIONS(11450),
    [sym_biginteger_literal] = ACTIONS(11452),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11452),
    [sym_verbatim_string] = ACTIONS(11452),
    [sym_integer] = ACTIONS(11450),
    [sym_continue_as_identifier] = ACTIONS(11452),
  },
  [STATE(4762)] = {
    [sym_boolean] = STATE(1802),
    [sym_assignment_expression] = STATE(1802),
    [sym__expression] = STATE(1802),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1802),
    [sym_multiplicative_expression] = STATE(1802),
    [sym_additive_expression] = STATE(1802),
    [sym_comparison_expression] = STATE(1802),
    [sym_logical_expression] = STATE(1802),
    [sym_ternary_expression] = STATE(1802),
    [sym_unary_expression] = STATE(1802),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1802),
    [sym_list_literal] = STATE(1802),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1802),
    [sym__literal_value] = STATE(1802),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11454),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11456),
    [sym_date_literal] = ACTIONS(11454),
    [sym_time_literal] = ACTIONS(11454),
    [sym_biginteger_literal] = ACTIONS(11456),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11456),
    [sym_verbatim_string] = ACTIONS(11456),
    [sym_integer] = ACTIONS(11454),
    [sym_continue_as_identifier] = ACTIONS(11456),
  },
  [STATE(4763)] = {
    [sym_boolean] = STATE(1803),
    [sym_assignment_expression] = STATE(1803),
    [sym__expression] = STATE(1803),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1803),
    [sym_multiplicative_expression] = STATE(1803),
    [sym_additive_expression] = STATE(1803),
    [sym_comparison_expression] = STATE(1803),
    [sym_logical_expression] = STATE(1803),
    [sym_ternary_expression] = STATE(1803),
    [sym_unary_expression] = STATE(1803),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1803),
    [sym_list_literal] = STATE(1803),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1803),
    [sym__literal_value] = STATE(1803),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11458),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11460),
    [sym_date_literal] = ACTIONS(11458),
    [sym_time_literal] = ACTIONS(11458),
    [sym_biginteger_literal] = ACTIONS(11460),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11460),
    [sym_verbatim_string] = ACTIONS(11460),
    [sym_integer] = ACTIONS(11458),
    [sym_continue_as_identifier] = ACTIONS(11460),
  },
  [STATE(4764)] = {
    [sym_boolean] = STATE(1804),
    [sym_assignment_expression] = STATE(1804),
    [sym__expression] = STATE(1804),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1804),
    [sym_multiplicative_expression] = STATE(1804),
    [sym_additive_expression] = STATE(1804),
    [sym_comparison_expression] = STATE(1804),
    [sym_logical_expression] = STATE(1804),
    [sym_ternary_expression] = STATE(1804),
    [sym_unary_expression] = STATE(1804),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1804),
    [sym_list_literal] = STATE(1804),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1804),
    [sym__literal_value] = STATE(1804),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11462),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11464),
    [sym_date_literal] = ACTIONS(11462),
    [sym_time_literal] = ACTIONS(11462),
    [sym_biginteger_literal] = ACTIONS(11464),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11464),
    [sym_verbatim_string] = ACTIONS(11464),
    [sym_integer] = ACTIONS(11462),
    [sym_continue_as_identifier] = ACTIONS(11464),
  },
  [STATE(4765)] = {
    [sym_boolean] = STATE(1807),
    [sym_assignment_expression] = STATE(1807),
    [sym__expression] = STATE(1807),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1807),
    [sym_multiplicative_expression] = STATE(1807),
    [sym_additive_expression] = STATE(1807),
    [sym_comparison_expression] = STATE(1807),
    [sym_logical_expression] = STATE(1807),
    [sym_ternary_expression] = STATE(1807),
    [sym_unary_expression] = STATE(1807),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1807),
    [sym_list_literal] = STATE(1807),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1807),
    [sym__literal_value] = STATE(1807),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11466),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11468),
    [sym_date_literal] = ACTIONS(11466),
    [sym_time_literal] = ACTIONS(11466),
    [sym_biginteger_literal] = ACTIONS(11468),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11468),
    [sym_verbatim_string] = ACTIONS(11468),
    [sym_integer] = ACTIONS(11466),
    [sym_continue_as_identifier] = ACTIONS(11468),
  },
  [STATE(4766)] = {
    [sym_boolean] = STATE(1789),
    [sym_assignment_expression] = STATE(1789),
    [sym__expression] = STATE(1789),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1789),
    [sym_multiplicative_expression] = STATE(1789),
    [sym_additive_expression] = STATE(1789),
    [sym_comparison_expression] = STATE(1789),
    [sym_logical_expression] = STATE(1789),
    [sym_ternary_expression] = STATE(1789),
    [sym_unary_expression] = STATE(1789),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1789),
    [sym_list_literal] = STATE(1789),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1789),
    [sym__literal_value] = STATE(1789),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11470),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11472),
    [sym_date_literal] = ACTIONS(11470),
    [sym_time_literal] = ACTIONS(11470),
    [sym_biginteger_literal] = ACTIONS(11472),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11472),
    [sym_verbatim_string] = ACTIONS(11472),
    [sym_integer] = ACTIONS(11470),
    [sym_continue_as_identifier] = ACTIONS(11472),
  },
  [STATE(4767)] = {
    [sym_boolean] = STATE(1792),
    [sym_assignment_expression] = STATE(1792),
    [sym__expression] = STATE(1792),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1792),
    [sym_multiplicative_expression] = STATE(1792),
    [sym_additive_expression] = STATE(1792),
    [sym_comparison_expression] = STATE(1792),
    [sym_logical_expression] = STATE(1792),
    [sym_ternary_expression] = STATE(1792),
    [sym_unary_expression] = STATE(1792),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1792),
    [sym_list_literal] = STATE(1792),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1792),
    [sym__literal_value] = STATE(1792),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11474),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11476),
    [sym_date_literal] = ACTIONS(11474),
    [sym_time_literal] = ACTIONS(11474),
    [sym_biginteger_literal] = ACTIONS(11476),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11476),
    [sym_verbatim_string] = ACTIONS(11476),
    [sym_integer] = ACTIONS(11474),
    [sym_continue_as_identifier] = ACTIONS(11476),
  },
  [STATE(4768)] = {
    [sym_boolean] = STATE(1798),
    [sym_assignment_expression] = STATE(1798),
    [sym__expression] = STATE(1798),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1798),
    [sym_multiplicative_expression] = STATE(1798),
    [sym_additive_expression] = STATE(1798),
    [sym_comparison_expression] = STATE(1798),
    [sym_logical_expression] = STATE(1798),
    [sym_ternary_expression] = STATE(1798),
    [sym_unary_expression] = STATE(1798),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1798),
    [sym_list_literal] = STATE(1798),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1798),
    [sym__literal_value] = STATE(1798),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11478),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11480),
    [sym_date_literal] = ACTIONS(11478),
    [sym_time_literal] = ACTIONS(11478),
    [sym_biginteger_literal] = ACTIONS(11480),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11480),
    [sym_verbatim_string] = ACTIONS(11480),
    [sym_integer] = ACTIONS(11478),
    [sym_continue_as_identifier] = ACTIONS(11480),
  },
  [STATE(4769)] = {
    [sym_boolean] = STATE(1811),
    [sym_assignment_expression] = STATE(1811),
    [sym__expression] = STATE(1811),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1811),
    [sym_multiplicative_expression] = STATE(1811),
    [sym_additive_expression] = STATE(1811),
    [sym_comparison_expression] = STATE(1811),
    [sym_logical_expression] = STATE(1811),
    [sym_ternary_expression] = STATE(1811),
    [sym_unary_expression] = STATE(1811),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1811),
    [sym_list_literal] = STATE(1811),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1811),
    [sym__literal_value] = STATE(1811),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11482),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11484),
    [sym_date_literal] = ACTIONS(11482),
    [sym_time_literal] = ACTIONS(11482),
    [sym_biginteger_literal] = ACTIONS(11484),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11484),
    [sym_verbatim_string] = ACTIONS(11484),
    [sym_integer] = ACTIONS(11482),
    [sym_continue_as_identifier] = ACTIONS(11484),
  },
  [STATE(4770)] = {
    [sym_boolean] = STATE(1777),
    [sym_assignment_expression] = STATE(1777),
    [sym__expression] = STATE(1777),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1777),
    [sym_multiplicative_expression] = STATE(1777),
    [sym_additive_expression] = STATE(1777),
    [sym_comparison_expression] = STATE(1777),
    [sym_logical_expression] = STATE(1777),
    [sym_ternary_expression] = STATE(1777),
    [sym_unary_expression] = STATE(1777),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1777),
    [sym_list_literal] = STATE(1777),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1777),
    [sym__literal_value] = STATE(1777),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11486),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11488),
    [sym_date_literal] = ACTIONS(11486),
    [sym_time_literal] = ACTIONS(11486),
    [sym_biginteger_literal] = ACTIONS(11488),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11488),
    [sym_verbatim_string] = ACTIONS(11488),
    [sym_integer] = ACTIONS(11486),
    [sym_continue_as_identifier] = ACTIONS(11488),
  },
  [STATE(4771)] = {
    [sym_boolean] = STATE(1778),
    [sym_assignment_expression] = STATE(1778),
    [sym__expression] = STATE(1778),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1778),
    [sym_multiplicative_expression] = STATE(1778),
    [sym_additive_expression] = STATE(1778),
    [sym_comparison_expression] = STATE(1778),
    [sym_logical_expression] = STATE(1778),
    [sym_ternary_expression] = STATE(1778),
    [sym_unary_expression] = STATE(1778),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1778),
    [sym_list_literal] = STATE(1778),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1778),
    [sym__literal_value] = STATE(1778),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11490),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11492),
    [sym_date_literal] = ACTIONS(11490),
    [sym_time_literal] = ACTIONS(11490),
    [sym_biginteger_literal] = ACTIONS(11492),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11492),
    [sym_verbatim_string] = ACTIONS(11492),
    [sym_integer] = ACTIONS(11490),
    [sym_continue_as_identifier] = ACTIONS(11492),
  },
  [STATE(4772)] = {
    [sym_boolean] = STATE(1964),
    [sym_assignment_expression] = STATE(1964),
    [sym__expression] = STATE(1964),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1964),
    [sym_multiplicative_expression] = STATE(1964),
    [sym_additive_expression] = STATE(1964),
    [sym_comparison_expression] = STATE(1964),
    [sym_logical_expression] = STATE(1964),
    [sym_ternary_expression] = STATE(1964),
    [sym_unary_expression] = STATE(1964),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1964),
    [sym_list_literal] = STATE(1964),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1964),
    [sym__literal_value] = STATE(1964),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11494),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11496),
    [sym_date_literal] = ACTIONS(11494),
    [sym_time_literal] = ACTIONS(11494),
    [sym_biginteger_literal] = ACTIONS(11496),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11496),
    [sym_verbatim_string] = ACTIONS(11496),
    [sym_integer] = ACTIONS(11494),
    [sym_continue_as_identifier] = ACTIONS(11496),
  },
  [STATE(4773)] = {
    [sym_boolean] = STATE(1980),
    [sym_assignment_expression] = STATE(1980),
    [sym__expression] = STATE(1980),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1980),
    [sym_multiplicative_expression] = STATE(1980),
    [sym_additive_expression] = STATE(1980),
    [sym_comparison_expression] = STATE(1980),
    [sym_logical_expression] = STATE(1980),
    [sym_ternary_expression] = STATE(1980),
    [sym_unary_expression] = STATE(1980),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1980),
    [sym_list_literal] = STATE(1980),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1980),
    [sym__literal_value] = STATE(1980),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11498),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11500),
    [sym_date_literal] = ACTIONS(11498),
    [sym_time_literal] = ACTIONS(11498),
    [sym_biginteger_literal] = ACTIONS(11500),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11500),
    [sym_verbatim_string] = ACTIONS(11500),
    [sym_integer] = ACTIONS(11498),
    [sym_continue_as_identifier] = ACTIONS(11500),
  },
  [STATE(4774)] = {
    [sym_boolean] = STATE(2028),
    [sym_assignment_expression] = STATE(2028),
    [sym__expression] = STATE(2028),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(2028),
    [sym_multiplicative_expression] = STATE(2028),
    [sym_additive_expression] = STATE(2028),
    [sym_comparison_expression] = STATE(2028),
    [sym_logical_expression] = STATE(2028),
    [sym_ternary_expression] = STATE(2028),
    [sym_unary_expression] = STATE(2028),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(2028),
    [sym_list_literal] = STATE(2028),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(2028),
    [sym__literal_value] = STATE(2028),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11502),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11504),
    [sym_date_literal] = ACTIONS(11502),
    [sym_time_literal] = ACTIONS(11502),
    [sym_biginteger_literal] = ACTIONS(11504),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11504),
    [sym_verbatim_string] = ACTIONS(11504),
    [sym_integer] = ACTIONS(11502),
    [sym_continue_as_identifier] = ACTIONS(11504),
  },
  [STATE(4775)] = {
    [sym__body_element] = STATE(4775),
    [sym_empty_statement] = STATE(4775),
    [sym_property] = STATE(4775),
    [sym_permissions_property] = STATE(4775),
    [sym_table_relation_property] = STATE(4775),
    [sym_fields_section] = STATE(4775),
    [sym_keys_section] = STATE(4775),
    [sym_fieldgroups_section] = STATE(4775),
    [sym_enum_value_declaration] = STATE(4775),
    [sym_labels_section] = STATE(4775),
    [sym_layout_section] = STATE(4775),
    [sym_modify_modification] = STATE(4775),
    [sym_actions_section] = STATE(4775),
    [sym_views_section] = STATE(4775),
    [sym_dataset_section] = STATE(4775),
    [sym_requestpage_section] = STATE(4775),
    [sym_rendering_section] = STATE(4775),
    [sym_elements_section] = STATE(4775),
    [sym_schema_section] = STATE(4775),
    [sym_xmlport_element] = STATE(4775),
    [sym__xmlport_body_element] = STATE(4775),
    [sym_preproc_conditional_xmlport] = STATE(4775),
    [sym_xmlport_attribute] = STATE(4775),
    [sym_assembly_declaration] = STATE(4775),
    [sym_event_declaration] = STATE(4775),
    [sym_procedure] = STATE(4775),
    [sym_preproc_split_procedure] = STATE(4775),
    [sym_preproc_split_procedure_preamble] = STATE(4775),
    [sym_procedure_modifier] = STATE(17685),
    [sym_trigger_declaration] = STATE(4775),
    [sym_var_section] = STATE(4775),
    [sym_attribute_item] = STATE(4775),
    [sym_preproc_conditional] = STATE(4775),
    [sym_preproc_if] = STATE(3417),
    [aux_sym_xmlport_element_repeat1] = STATE(4775),
    [anon_sym_SEMI] = ACTIONS(11506),
    [anon_sym_RBRACE] = ACTIONS(8132),
    [anon_sym_LBRACK] = ACTIONS(11509),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(11512),
    [aux_sym_modify_modification_token1] = ACTIONS(11515),
    [aux_sym_xmlport_element_token1] = ACTIONS(11518),
    [aux_sym_xmlport_element_token2] = ACTIONS(11518),
    [aux_sym_xmlport_element_token3] = ACTIONS(11518),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(11521),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(11521),
    [aux_sym_assembly_declaration_token1] = ACTIONS(11524),
    [anon_sym_POUNDif] = ACTIONS(8129),
    [anon_sym_POUNDIF] = ACTIONS(8129),
    [anon_sym_POUNDIf] = ACTIONS(8129),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(11527),
    [sym_trigger_keyword] = ACTIONS(11530),
    [sym_var_keyword] = ACTIONS(11533),
    [sym_local_keyword] = ACTIONS(11536),
    [sym_internal_keyword] = ACTIONS(8146),
    [sym_protected_keyword] = ACTIONS(11536),
    [sym_event_keyword] = ACTIONS(11539),
    [sym_fields_keyword] = ACTIONS(11542),
    [sym_keys_keyword] = ACTIONS(11545),
    [sym_fieldgroups_keyword] = ACTIONS(11548),
    [sym_actions_keyword] = ACTIONS(11551),
    [sym_layout_keyword] = ACTIONS(11554),
    [sym_dataset_keyword] = ACTIONS(11557),
    [sym_elements_keyword] = ACTIONS(11560),
    [sym_labels_keyword] = ACTIONS(11563),
    [sym_rendering_keyword] = ACTIONS(11566),
    [sym_requestpage_keyword] = ACTIONS(11569),
    [sym_schema_keyword] = ACTIONS(11572),
    [sym_views_keyword] = ACTIONS(11575),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(11578),
    [sym_preproc_open] = ACTIONS(8129),
  },
  [STATE(4776)] = {
    [sym_boolean] = STATE(8743),
    [sym_assignment_expression] = STATE(8743),
    [sym__expression] = STATE(8743),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8743),
    [sym_multiplicative_expression] = STATE(8743),
    [sym_additive_expression] = STATE(8743),
    [sym_comparison_expression] = STATE(8743),
    [sym_logical_expression] = STATE(8743),
    [sym_ternary_expression] = STATE(8743),
    [sym_unary_expression] = STATE(8743),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8743),
    [sym_list_literal] = STATE(8743),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8743),
    [sym__literal_value] = STATE(8743),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11581),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11583),
    [sym_date_literal] = ACTIONS(11581),
    [sym_time_literal] = ACTIONS(11581),
    [sym_biginteger_literal] = ACTIONS(11583),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11583),
    [sym_verbatim_string] = ACTIONS(11583),
    [sym_integer] = ACTIONS(11581),
    [sym_continue_as_identifier] = ACTIONS(11583),
  },
  [STATE(4777)] = {
    [sym_boolean] = STATE(8632),
    [sym_assignment_expression] = STATE(8632),
    [sym__expression] = STATE(8632),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8632),
    [sym_multiplicative_expression] = STATE(8632),
    [sym_additive_expression] = STATE(8632),
    [sym_comparison_expression] = STATE(8632),
    [sym_logical_expression] = STATE(8632),
    [sym_ternary_expression] = STATE(8632),
    [sym_unary_expression] = STATE(8632),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8632),
    [sym_list_literal] = STATE(8632),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8632),
    [sym__literal_value] = STATE(8632),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11585),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11587),
    [sym_date_literal] = ACTIONS(11585),
    [sym_time_literal] = ACTIONS(11585),
    [sym_biginteger_literal] = ACTIONS(11587),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11587),
    [sym_verbatim_string] = ACTIONS(11587),
    [sym_integer] = ACTIONS(11585),
    [sym_continue_as_identifier] = ACTIONS(11587),
  },
  [STATE(4778)] = {
    [sym_boolean] = STATE(8766),
    [sym_assignment_expression] = STATE(8766),
    [sym__expression] = STATE(8766),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8766),
    [sym_multiplicative_expression] = STATE(8766),
    [sym_additive_expression] = STATE(8766),
    [sym_comparison_expression] = STATE(8766),
    [sym_logical_expression] = STATE(8766),
    [sym_ternary_expression] = STATE(8766),
    [sym_unary_expression] = STATE(8766),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8766),
    [sym_list_literal] = STATE(8766),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8766),
    [sym__literal_value] = STATE(8766),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11589),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11591),
    [sym_date_literal] = ACTIONS(11589),
    [sym_time_literal] = ACTIONS(11589),
    [sym_biginteger_literal] = ACTIONS(11591),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11591),
    [sym_verbatim_string] = ACTIONS(11591),
    [sym_integer] = ACTIONS(11589),
    [sym_continue_as_identifier] = ACTIONS(11591),
  },
  [STATE(4779)] = {
    [sym_boolean] = STATE(8543),
    [sym_assignment_expression] = STATE(8543),
    [sym__expression] = STATE(8543),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8543),
    [sym_multiplicative_expression] = STATE(8543),
    [sym_additive_expression] = STATE(8543),
    [sym_comparison_expression] = STATE(8543),
    [sym_logical_expression] = STATE(8543),
    [sym_ternary_expression] = STATE(8543),
    [sym_unary_expression] = STATE(8543),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8543),
    [sym_list_literal] = STATE(8543),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8543),
    [sym__literal_value] = STATE(8543),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11593),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11595),
    [sym_date_literal] = ACTIONS(11593),
    [sym_time_literal] = ACTIONS(11593),
    [sym_biginteger_literal] = ACTIONS(11595),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11595),
    [sym_verbatim_string] = ACTIONS(11595),
    [sym_integer] = ACTIONS(11593),
    [sym_continue_as_identifier] = ACTIONS(11595),
  },
  [STATE(4780)] = {
    [sym_boolean] = STATE(8545),
    [sym_assignment_expression] = STATE(8545),
    [sym__expression] = STATE(8545),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8545),
    [sym_multiplicative_expression] = STATE(8545),
    [sym_additive_expression] = STATE(8545),
    [sym_comparison_expression] = STATE(8545),
    [sym_logical_expression] = STATE(8545),
    [sym_ternary_expression] = STATE(8545),
    [sym_unary_expression] = STATE(8545),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8545),
    [sym_list_literal] = STATE(8545),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8545),
    [sym__literal_value] = STATE(8545),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11597),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11599),
    [sym_date_literal] = ACTIONS(11597),
    [sym_time_literal] = ACTIONS(11597),
    [sym_biginteger_literal] = ACTIONS(11599),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11599),
    [sym_verbatim_string] = ACTIONS(11599),
    [sym_integer] = ACTIONS(11597),
    [sym_continue_as_identifier] = ACTIONS(11599),
  },
  [STATE(4781)] = {
    [sym_boolean] = STATE(8546),
    [sym_assignment_expression] = STATE(8546),
    [sym__expression] = STATE(8546),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8546),
    [sym_multiplicative_expression] = STATE(8546),
    [sym_additive_expression] = STATE(8546),
    [sym_comparison_expression] = STATE(8546),
    [sym_logical_expression] = STATE(8546),
    [sym_ternary_expression] = STATE(8546),
    [sym_unary_expression] = STATE(8546),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8546),
    [sym_list_literal] = STATE(8546),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8546),
    [sym__literal_value] = STATE(8546),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11601),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11603),
    [sym_date_literal] = ACTIONS(11601),
    [sym_time_literal] = ACTIONS(11601),
    [sym_biginteger_literal] = ACTIONS(11603),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11603),
    [sym_verbatim_string] = ACTIONS(11603),
    [sym_integer] = ACTIONS(11601),
    [sym_continue_as_identifier] = ACTIONS(11603),
  },
  [STATE(4782)] = {
    [sym_boolean] = STATE(8552),
    [sym_assignment_expression] = STATE(8552),
    [sym__expression] = STATE(8552),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8552),
    [sym_multiplicative_expression] = STATE(8552),
    [sym_additive_expression] = STATE(8552),
    [sym_comparison_expression] = STATE(8552),
    [sym_logical_expression] = STATE(8552),
    [sym_ternary_expression] = STATE(8552),
    [sym_unary_expression] = STATE(8552),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8552),
    [sym_list_literal] = STATE(8552),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8552),
    [sym__literal_value] = STATE(8552),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11605),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11607),
    [sym_date_literal] = ACTIONS(11605),
    [sym_time_literal] = ACTIONS(11605),
    [sym_biginteger_literal] = ACTIONS(11607),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11607),
    [sym_verbatim_string] = ACTIONS(11607),
    [sym_integer] = ACTIONS(11605),
    [sym_continue_as_identifier] = ACTIONS(11607),
  },
  [STATE(4783)] = {
    [sym_boolean] = STATE(8553),
    [sym_assignment_expression] = STATE(8553),
    [sym__expression] = STATE(8553),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8553),
    [sym_multiplicative_expression] = STATE(8553),
    [sym_additive_expression] = STATE(8553),
    [sym_comparison_expression] = STATE(8553),
    [sym_logical_expression] = STATE(8553),
    [sym_ternary_expression] = STATE(8553),
    [sym_unary_expression] = STATE(8553),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8553),
    [sym_list_literal] = STATE(8553),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8553),
    [sym__literal_value] = STATE(8553),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11609),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11611),
    [sym_date_literal] = ACTIONS(11609),
    [sym_time_literal] = ACTIONS(11609),
    [sym_biginteger_literal] = ACTIONS(11611),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11611),
    [sym_verbatim_string] = ACTIONS(11611),
    [sym_integer] = ACTIONS(11609),
    [sym_continue_as_identifier] = ACTIONS(11611),
  },
  [STATE(4784)] = {
    [sym_boolean] = STATE(8554),
    [sym_assignment_expression] = STATE(8554),
    [sym__expression] = STATE(8554),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8554),
    [sym_multiplicative_expression] = STATE(8554),
    [sym_additive_expression] = STATE(8554),
    [sym_comparison_expression] = STATE(8554),
    [sym_logical_expression] = STATE(8554),
    [sym_ternary_expression] = STATE(8554),
    [sym_unary_expression] = STATE(8554),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8554),
    [sym_list_literal] = STATE(8554),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8554),
    [sym__literal_value] = STATE(8554),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11613),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11615),
    [sym_date_literal] = ACTIONS(11613),
    [sym_time_literal] = ACTIONS(11613),
    [sym_biginteger_literal] = ACTIONS(11615),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11615),
    [sym_verbatim_string] = ACTIONS(11615),
    [sym_integer] = ACTIONS(11613),
    [sym_continue_as_identifier] = ACTIONS(11615),
  },
  [STATE(4785)] = {
    [sym_boolean] = STATE(8361),
    [sym_assignment_expression] = STATE(8361),
    [sym__expression] = STATE(8361),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8361),
    [sym_multiplicative_expression] = STATE(8361),
    [sym_additive_expression] = STATE(8361),
    [sym_comparison_expression] = STATE(8361),
    [sym_logical_expression] = STATE(8361),
    [sym_ternary_expression] = STATE(8361),
    [sym_unary_expression] = STATE(8361),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8361),
    [sym_list_literal] = STATE(8361),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8361),
    [sym__literal_value] = STATE(8361),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11617),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11619),
    [sym_date_literal] = ACTIONS(11617),
    [sym_time_literal] = ACTIONS(11617),
    [sym_biginteger_literal] = ACTIONS(11619),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11619),
    [sym_verbatim_string] = ACTIONS(11619),
    [sym_integer] = ACTIONS(11617),
    [sym_continue_as_identifier] = ACTIONS(11619),
  },
  [STATE(4786)] = {
    [sym_boolean] = STATE(8365),
    [sym_assignment_expression] = STATE(8365),
    [sym__expression] = STATE(8365),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8365),
    [sym_multiplicative_expression] = STATE(8365),
    [sym_additive_expression] = STATE(8365),
    [sym_comparison_expression] = STATE(8365),
    [sym_logical_expression] = STATE(8365),
    [sym_ternary_expression] = STATE(8365),
    [sym_unary_expression] = STATE(8365),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8365),
    [sym_list_literal] = STATE(8365),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8365),
    [sym__literal_value] = STATE(8365),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11621),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11623),
    [sym_date_literal] = ACTIONS(11621),
    [sym_time_literal] = ACTIONS(11621),
    [sym_biginteger_literal] = ACTIONS(11623),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11623),
    [sym_verbatim_string] = ACTIONS(11623),
    [sym_integer] = ACTIONS(11621),
    [sym_continue_as_identifier] = ACTIONS(11623),
  },
  [STATE(4787)] = {
    [sym_boolean] = STATE(1785),
    [sym_assignment_expression] = STATE(1785),
    [sym__expression] = STATE(1785),
    [sym_keyword_identifier] = STATE(1790),
    [sym_range_expression] = STATE(1785),
    [sym_multiplicative_expression] = STATE(1785),
    [sym_additive_expression] = STATE(1785),
    [sym_comparison_expression] = STATE(1785),
    [sym_logical_expression] = STATE(1785),
    [sym_ternary_expression] = STATE(1785),
    [sym_unary_expression] = STATE(1785),
    [sym_call_expression] = STATE(1832),
    [sym_member_expression] = STATE(1790),
    [sym_subscript_expression] = STATE(1790),
    [sym_parenthesized_expression] = STATE(1785),
    [sym_list_literal] = STATE(1785),
    [sym_qualified_enum_value] = STATE(1790),
    [sym_database_reference] = STATE(1785),
    [sym__literal_value] = STATE(1785),
    [sym_codeunit_keyword] = STATE(1831),
    [sym_xmlport_keyword] = STATE(1831),
    [sym_enum_keyword] = STATE(1782),
    [sym_identifier] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(59),
    [aux_sym_boolean_token1] = ACTIONS(61),
    [aux_sym_boolean_token2] = ACTIONS(61),
    [sym_decimal] = ACTIONS(11625),
    [anon_sym_LPAREN] = ACTIONS(65),
    [aux_sym_tabledata_permission_token2] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(69),
    [aux_sym_record_type_token1] = ACTIONS(67),
    [aux_sym_basic_type_token21] = ACTIONS(67),
    [aux_sym_basic_type_token22] = ACTIONS(67),
    [aux_sym_basic_type_token48] = ACTIONS(67),
    [anon_sym_not] = ACTIONS(75),
    [anon_sym_NOT] = ACTIONS(75),
    [anon_sym_Not] = ACTIONS(75),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(67),
    [aux_sym_keyword_identifier_token2] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(59),
    [sym_datetime_literal] = ACTIONS(11627),
    [sym_date_literal] = ACTIONS(11625),
    [sym_time_literal] = ACTIONS(11625),
    [sym_biginteger_literal] = ACTIONS(11627),
    [sym_page_keyword] = ACTIONS(83),
    [anon_sym_codeunit] = ACTIONS(109),
    [anon_sym_CODEUNIT] = ACTIONS(109),
    [anon_sym_Codeunit] = ACTIONS(109),
    [anon_sym_CodeUnit] = ACTIONS(109),
    [anon_sym_COdeunit] = ACTIONS(109),
    [anon_sym_codeUnit] = ACTIONS(109),
    [sym_report_keyword] = ACTIONS(83),
    [sym_query_keyword] = ACTIONS(83),
    [anon_sym_xmlport] = ACTIONS(111),
    [anon_sym_XMLPORT] = ACTIONS(111),
    [anon_sym_Xmlport] = ACTIONS(111),
    [anon_sym_XMLport] = ACTIONS(111),
    [anon_sym_XMLPort] = ACTIONS(111),
    [anon_sym_XmlPort] = ACTIONS(111),
    [anon_sym_enum] = ACTIONS(113),
    [anon_sym_ENUM] = ACTIONS(113),
    [anon_sym_Enum] = ACTIONS(113),
    [anon_sym_eNUM] = ACTIONS(113),
    [anon_sym_eNum] = ACTIONS(113),
    [anon_sym_ENum] = ACTIONS(113),
    [sym_quoted_identifier] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11627),
    [sym_verbatim_string] = ACTIONS(11627),
    [sym_integer] = ACTIONS(11625),
    [sym_continue_as_identifier] = ACTIONS(11627),
  },
  [STATE(4788)] = {
    [sym_boolean] = STATE(8366),
    [sym_assignment_expression] = STATE(8366),
    [sym__expression] = STATE(8366),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8366),
    [sym_multiplicative_expression] = STATE(8366),
    [sym_additive_expression] = STATE(8366),
    [sym_comparison_expression] = STATE(8366),
    [sym_logical_expression] = STATE(8366),
    [sym_ternary_expression] = STATE(8366),
    [sym_unary_expression] = STATE(8366),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8366),
    [sym_list_literal] = STATE(8366),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8366),
    [sym__literal_value] = STATE(8366),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11629),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11631),
    [sym_date_literal] = ACTIONS(11629),
    [sym_time_literal] = ACTIONS(11629),
    [sym_biginteger_literal] = ACTIONS(11631),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11631),
    [sym_verbatim_string] = ACTIONS(11631),
    [sym_integer] = ACTIONS(11629),
    [sym_continue_as_identifier] = ACTIONS(11631),
  },
  [STATE(4789)] = {
    [sym_boolean] = STATE(8367),
    [sym_assignment_expression] = STATE(8367),
    [sym__expression] = STATE(8367),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8367),
    [sym_multiplicative_expression] = STATE(8367),
    [sym_additive_expression] = STATE(8367),
    [sym_comparison_expression] = STATE(8367),
    [sym_logical_expression] = STATE(8367),
    [sym_ternary_expression] = STATE(8367),
    [sym_unary_expression] = STATE(8367),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8367),
    [sym_list_literal] = STATE(8367),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8367),
    [sym__literal_value] = STATE(8367),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11633),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11635),
    [sym_date_literal] = ACTIONS(11633),
    [sym_time_literal] = ACTIONS(11633),
    [sym_biginteger_literal] = ACTIONS(11635),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11635),
    [sym_verbatim_string] = ACTIONS(11635),
    [sym_integer] = ACTIONS(11633),
    [sym_continue_as_identifier] = ACTIONS(11635),
  },
  [STATE(4790)] = {
    [sym_boolean] = STATE(8726),
    [sym_assignment_expression] = STATE(8726),
    [sym__expression] = STATE(8726),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8726),
    [sym_multiplicative_expression] = STATE(8726),
    [sym_additive_expression] = STATE(8726),
    [sym_comparison_expression] = STATE(8726),
    [sym_logical_expression] = STATE(8726),
    [sym_ternary_expression] = STATE(8726),
    [sym_unary_expression] = STATE(8726),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8726),
    [sym_list_literal] = STATE(8726),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8726),
    [sym__literal_value] = STATE(8726),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11637),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11639),
    [sym_date_literal] = ACTIONS(11637),
    [sym_time_literal] = ACTIONS(11637),
    [sym_biginteger_literal] = ACTIONS(11639),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11639),
    [sym_verbatim_string] = ACTIONS(11639),
    [sym_integer] = ACTIONS(11637),
    [sym_continue_as_identifier] = ACTIONS(11639),
  },
  [STATE(4791)] = {
    [sym_boolean] = STATE(8678),
    [sym_assignment_expression] = STATE(8678),
    [sym__expression] = STATE(8678),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8678),
    [sym_multiplicative_expression] = STATE(8678),
    [sym_additive_expression] = STATE(8678),
    [sym_comparison_expression] = STATE(8678),
    [sym_logical_expression] = STATE(8678),
    [sym_ternary_expression] = STATE(8678),
    [sym_unary_expression] = STATE(8678),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8678),
    [sym_list_literal] = STATE(8678),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8678),
    [sym__literal_value] = STATE(8678),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11641),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11643),
    [sym_date_literal] = ACTIONS(11641),
    [sym_time_literal] = ACTIONS(11641),
    [sym_biginteger_literal] = ACTIONS(11643),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11643),
    [sym_verbatim_string] = ACTIONS(11643),
    [sym_integer] = ACTIONS(11641),
    [sym_continue_as_identifier] = ACTIONS(11643),
  },
  [STATE(4792)] = {
    [sym_boolean] = STATE(8755),
    [sym_assignment_expression] = STATE(8755),
    [sym__expression] = STATE(8755),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8755),
    [sym_multiplicative_expression] = STATE(8755),
    [sym_additive_expression] = STATE(8755),
    [sym_comparison_expression] = STATE(8755),
    [sym_logical_expression] = STATE(8755),
    [sym_ternary_expression] = STATE(8755),
    [sym_unary_expression] = STATE(8755),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8755),
    [sym_list_literal] = STATE(8755),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8755),
    [sym__literal_value] = STATE(8755),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11645),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11647),
    [sym_date_literal] = ACTIONS(11645),
    [sym_time_literal] = ACTIONS(11645),
    [sym_biginteger_literal] = ACTIONS(11647),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11647),
    [sym_verbatim_string] = ACTIONS(11647),
    [sym_integer] = ACTIONS(11645),
    [sym_continue_as_identifier] = ACTIONS(11647),
  },
  [STATE(4793)] = {
    [sym_boolean] = STATE(8368),
    [sym_assignment_expression] = STATE(8368),
    [sym__expression] = STATE(8368),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8368),
    [sym_multiplicative_expression] = STATE(8368),
    [sym_additive_expression] = STATE(8368),
    [sym_comparison_expression] = STATE(8368),
    [sym_logical_expression] = STATE(8368),
    [sym_ternary_expression] = STATE(8368),
    [sym_unary_expression] = STATE(8368),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8368),
    [sym_list_literal] = STATE(8368),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8368),
    [sym__literal_value] = STATE(8368),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11649),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11651),
    [sym_date_literal] = ACTIONS(11649),
    [sym_time_literal] = ACTIONS(11649),
    [sym_biginteger_literal] = ACTIONS(11651),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11651),
    [sym_verbatim_string] = ACTIONS(11651),
    [sym_integer] = ACTIONS(11649),
    [sym_continue_as_identifier] = ACTIONS(11651),
  },
  [STATE(4794)] = {
    [sym_boolean] = STATE(8369),
    [sym_assignment_expression] = STATE(8369),
    [sym__expression] = STATE(8369),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8369),
    [sym_multiplicative_expression] = STATE(8369),
    [sym_additive_expression] = STATE(8369),
    [sym_comparison_expression] = STATE(8369),
    [sym_logical_expression] = STATE(8369),
    [sym_ternary_expression] = STATE(8369),
    [sym_unary_expression] = STATE(8369),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8369),
    [sym_list_literal] = STATE(8369),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8369),
    [sym__literal_value] = STATE(8369),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11653),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11655),
    [sym_date_literal] = ACTIONS(11653),
    [sym_time_literal] = ACTIONS(11653),
    [sym_biginteger_literal] = ACTIONS(11655),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11655),
    [sym_verbatim_string] = ACTIONS(11655),
    [sym_integer] = ACTIONS(11653),
    [sym_continue_as_identifier] = ACTIONS(11655),
  },
  [STATE(4795)] = {
    [sym_boolean] = STATE(8771),
    [sym_assignment_expression] = STATE(8771),
    [sym__expression] = STATE(8771),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8771),
    [sym_multiplicative_expression] = STATE(8771),
    [sym_additive_expression] = STATE(8771),
    [sym_comparison_expression] = STATE(8771),
    [sym_logical_expression] = STATE(8771),
    [sym_ternary_expression] = STATE(8771),
    [sym_unary_expression] = STATE(8771),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8771),
    [sym_list_literal] = STATE(8771),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8771),
    [sym__literal_value] = STATE(8771),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11657),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11659),
    [sym_date_literal] = ACTIONS(11657),
    [sym_time_literal] = ACTIONS(11657),
    [sym_biginteger_literal] = ACTIONS(11659),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11659),
    [sym_verbatim_string] = ACTIONS(11659),
    [sym_integer] = ACTIONS(11657),
    [sym_continue_as_identifier] = ACTIONS(11659),
  },
  [STATE(4796)] = {
    [sym_boolean] = STATE(8624),
    [sym_assignment_expression] = STATE(8624),
    [sym__expression] = STATE(8624),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8624),
    [sym_multiplicative_expression] = STATE(8624),
    [sym_additive_expression] = STATE(8624),
    [sym_comparison_expression] = STATE(8624),
    [sym_logical_expression] = STATE(8624),
    [sym_ternary_expression] = STATE(8624),
    [sym_unary_expression] = STATE(8624),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8624),
    [sym_list_literal] = STATE(8624),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8624),
    [sym__literal_value] = STATE(8624),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11661),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11663),
    [sym_date_literal] = ACTIONS(11661),
    [sym_time_literal] = ACTIONS(11661),
    [sym_biginteger_literal] = ACTIONS(11663),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11663),
    [sym_verbatim_string] = ACTIONS(11663),
    [sym_integer] = ACTIONS(11661),
    [sym_continue_as_identifier] = ACTIONS(11663),
  },
  [STATE(4797)] = {
    [sym_boolean] = STATE(8716),
    [sym_assignment_expression] = STATE(8716),
    [sym__expression] = STATE(8716),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8716),
    [sym_multiplicative_expression] = STATE(8716),
    [sym_additive_expression] = STATE(8716),
    [sym_comparison_expression] = STATE(8716),
    [sym_logical_expression] = STATE(8716),
    [sym_ternary_expression] = STATE(8716),
    [sym_unary_expression] = STATE(8716),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8716),
    [sym_list_literal] = STATE(8716),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8716),
    [sym__literal_value] = STATE(8716),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11665),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11667),
    [sym_date_literal] = ACTIONS(11665),
    [sym_time_literal] = ACTIONS(11665),
    [sym_biginteger_literal] = ACTIONS(11667),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11667),
    [sym_verbatim_string] = ACTIONS(11667),
    [sym_integer] = ACTIONS(11665),
    [sym_continue_as_identifier] = ACTIONS(11667),
  },
  [STATE(4798)] = {
    [sym_boolean] = STATE(8359),
    [sym_assignment_expression] = STATE(8359),
    [sym__expression] = STATE(8359),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8359),
    [sym_multiplicative_expression] = STATE(8359),
    [sym_additive_expression] = STATE(8359),
    [sym_comparison_expression] = STATE(8359),
    [sym_logical_expression] = STATE(8359),
    [sym_ternary_expression] = STATE(8359),
    [sym_unary_expression] = STATE(8359),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8359),
    [sym_list_literal] = STATE(8359),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8359),
    [sym__literal_value] = STATE(8359),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11669),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11671),
    [sym_date_literal] = ACTIONS(11669),
    [sym_time_literal] = ACTIONS(11669),
    [sym_biginteger_literal] = ACTIONS(11671),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11671),
    [sym_verbatim_string] = ACTIONS(11671),
    [sym_integer] = ACTIONS(11669),
    [sym_continue_as_identifier] = ACTIONS(11671),
  },
  [STATE(4799)] = {
    [sym_boolean] = STATE(8728),
    [sym_assignment_expression] = STATE(8728),
    [sym__expression] = STATE(8728),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8728),
    [sym_multiplicative_expression] = STATE(8728),
    [sym_additive_expression] = STATE(8728),
    [sym_comparison_expression] = STATE(8728),
    [sym_logical_expression] = STATE(8728),
    [sym_ternary_expression] = STATE(8728),
    [sym_unary_expression] = STATE(8728),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8728),
    [sym_list_literal] = STATE(8728),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8728),
    [sym__literal_value] = STATE(8728),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11673),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11675),
    [sym_date_literal] = ACTIONS(11673),
    [sym_time_literal] = ACTIONS(11673),
    [sym_biginteger_literal] = ACTIONS(11675),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11675),
    [sym_verbatim_string] = ACTIONS(11675),
    [sym_integer] = ACTIONS(11673),
    [sym_continue_as_identifier] = ACTIONS(11675),
  },
  [STATE(4800)] = {
    [sym_boolean] = STATE(8353),
    [sym_assignment_expression] = STATE(8353),
    [sym__expression] = STATE(8353),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8353),
    [sym_multiplicative_expression] = STATE(8353),
    [sym_additive_expression] = STATE(8353),
    [sym_comparison_expression] = STATE(8353),
    [sym_logical_expression] = STATE(8353),
    [sym_ternary_expression] = STATE(8353),
    [sym_unary_expression] = STATE(8353),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8353),
    [sym_list_literal] = STATE(8353),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8353),
    [sym__literal_value] = STATE(8353),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11677),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11679),
    [sym_date_literal] = ACTIONS(11677),
    [sym_time_literal] = ACTIONS(11677),
    [sym_biginteger_literal] = ACTIONS(11679),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11679),
    [sym_verbatim_string] = ACTIONS(11679),
    [sym_integer] = ACTIONS(11677),
    [sym_continue_as_identifier] = ACTIONS(11679),
  },
  [STATE(4801)] = {
    [sym_identifier] = ACTIONS(11681),
    [anon_sym_COMMA] = ACTIONS(11684),
    [anon_sym_COLON] = ACTIONS(11686),
    [anon_sym_DASH] = ACTIONS(11688),
    [aux_sym_boolean_token1] = ACTIONS(11681),
    [aux_sym_boolean_token2] = ACTIONS(11681),
    [sym_decimal] = ACTIONS(11681),
    [anon_sym_LPAREN] = ACTIONS(11688),
    [aux_sym_tabledata_permission_token2] = ACTIONS(11681),
    [anon_sym_LBRACK] = ACTIONS(11688),
    [aux_sym_record_type_token1] = ACTIONS(11681),
    [aux_sym_basic_type_token21] = ACTIONS(11681),
    [aux_sym_basic_type_token22] = ACTIONS(11681),
    [aux_sym_basic_type_token48] = ACTIONS(11681),
    [anon_sym_POUNDif] = ACTIONS(11686),
    [anon_sym_POUNDIF] = ACTIONS(11686),
    [anon_sym_POUNDIf] = ACTIONS(11686),
    [anon_sym_not] = ACTIONS(11681),
    [anon_sym_NOT] = ACTIONS(11681),
    [anon_sym_Not] = ACTIONS(11681),
    [anon_sym_POUNDelif] = ACTIONS(11691),
    [anon_sym_POUNDELIF] = ACTIONS(11691),
    [anon_sym_POUNDElif] = ACTIONS(11691),
    [anon_sym_POUNDelse] = ACTIONS(11691),
    [anon_sym_POUNDELSE] = ACTIONS(11691),
    [anon_sym_POUNDElse] = ACTIONS(11691),
    [anon_sym_POUNDelse2] = ACTIONS(11691),
    [anon_sym_POUNDELSE2] = ACTIONS(11691),
    [anon_sym_POUNDElse2] = ACTIONS(11691),
    [anon_sym_POUNDendif] = ACTIONS(11691),
    [anon_sym_POUNDENDIF] = ACTIONS(11691),
    [anon_sym_POUNDEndif] = ACTIONS(11691),
    [anon_sym_POUNDendif2] = ACTIONS(11691),
    [anon_sym_POUNDENDIF2] = ACTIONS(11691),
    [anon_sym_POUNDEndif2] = ACTIONS(11691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(11681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(11681),
    [anon_sym_PLUS] = ACTIONS(11688),
    [sym_datetime_literal] = ACTIONS(11688),
    [sym_date_literal] = ACTIONS(11681),
    [sym_time_literal] = ACTIONS(11681),
    [sym_biginteger_literal] = ACTIONS(11688),
    [sym_page_keyword] = ACTIONS(11681),
    [anon_sym_codeunit] = ACTIONS(11681),
    [anon_sym_CODEUNIT] = ACTIONS(11681),
    [anon_sym_Codeunit] = ACTIONS(11681),
    [anon_sym_CodeUnit] = ACTIONS(11681),
    [anon_sym_COdeunit] = ACTIONS(11681),
    [anon_sym_codeUnit] = ACTIONS(11681),
    [sym_report_keyword] = ACTIONS(11681),
    [sym_query_keyword] = ACTIONS(11681),
    [anon_sym_xmlport] = ACTIONS(11681),
    [anon_sym_XMLPORT] = ACTIONS(11681),
    [anon_sym_Xmlport] = ACTIONS(11681),
    [anon_sym_XMLport] = ACTIONS(11681),
    [anon_sym_XMLPort] = ACTIONS(11681),
    [anon_sym_XmlPort] = ACTIONS(11681),
    [anon_sym_enum] = ACTIONS(11681),
    [anon_sym_ENUM] = ACTIONS(11681),
    [anon_sym_Enum] = ACTIONS(11681),
    [anon_sym_eNUM] = ACTIONS(11681),
    [anon_sym_eNum] = ACTIONS(11681),
    [anon_sym_ENum] = ACTIONS(11681),
    [sym_quoted_identifier] = ACTIONS(11688),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11688),
    [sym_verbatim_string] = ACTIONS(11688),
    [sym_integer] = ACTIONS(11681),
    [sym_continue_as_identifier] = ACTIONS(11688),
    [sym_preproc_open] = ACTIONS(11686),
    [sym_preproc_close] = ACTIONS(11691),
  },
  [STATE(4802)] = {
    [sym_boolean] = STATE(8354),
    [sym_assignment_expression] = STATE(8354),
    [sym__expression] = STATE(8354),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8354),
    [sym_multiplicative_expression] = STATE(8354),
    [sym_additive_expression] = STATE(8354),
    [sym_comparison_expression] = STATE(8354),
    [sym_logical_expression] = STATE(8354),
    [sym_ternary_expression] = STATE(8354),
    [sym_unary_expression] = STATE(8354),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8354),
    [sym_list_literal] = STATE(8354),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8354),
    [sym__literal_value] = STATE(8354),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11693),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11695),
    [sym_date_literal] = ACTIONS(11693),
    [sym_time_literal] = ACTIONS(11693),
    [sym_biginteger_literal] = ACTIONS(11695),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11695),
    [sym_verbatim_string] = ACTIONS(11695),
    [sym_integer] = ACTIONS(11693),
    [sym_continue_as_identifier] = ACTIONS(11695),
  },
  [STATE(4803)] = {
    [sym_boolean] = STATE(8709),
    [sym_assignment_expression] = STATE(8709),
    [sym__expression] = STATE(8709),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8709),
    [sym_multiplicative_expression] = STATE(8709),
    [sym_additive_expression] = STATE(8709),
    [sym_comparison_expression] = STATE(8709),
    [sym_logical_expression] = STATE(8709),
    [sym_ternary_expression] = STATE(8709),
    [sym_unary_expression] = STATE(8709),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8709),
    [sym_list_literal] = STATE(8709),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8709),
    [sym__literal_value] = STATE(8709),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11697),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11699),
    [sym_date_literal] = ACTIONS(11697),
    [sym_time_literal] = ACTIONS(11697),
    [sym_biginteger_literal] = ACTIONS(11699),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11699),
    [sym_verbatim_string] = ACTIONS(11699),
    [sym_integer] = ACTIONS(11697),
    [sym_continue_as_identifier] = ACTIONS(11699),
  },
  [STATE(4804)] = {
    [sym_boolean] = STATE(8372),
    [sym_assignment_expression] = STATE(8372),
    [sym__expression] = STATE(8372),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8372),
    [sym_multiplicative_expression] = STATE(8372),
    [sym_additive_expression] = STATE(8372),
    [sym_comparison_expression] = STATE(8372),
    [sym_logical_expression] = STATE(8372),
    [sym_ternary_expression] = STATE(8372),
    [sym_unary_expression] = STATE(8372),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8372),
    [sym_list_literal] = STATE(8372),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8372),
    [sym__literal_value] = STATE(8372),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11701),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11703),
    [sym_date_literal] = ACTIONS(11701),
    [sym_time_literal] = ACTIONS(11701),
    [sym_biginteger_literal] = ACTIONS(11703),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11703),
    [sym_verbatim_string] = ACTIONS(11703),
    [sym_integer] = ACTIONS(11701),
    [sym_continue_as_identifier] = ACTIONS(11703),
  },
  [STATE(4805)] = {
    [sym_boolean] = STATE(8386),
    [sym_assignment_expression] = STATE(8386),
    [sym__expression] = STATE(8386),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8386),
    [sym_multiplicative_expression] = STATE(8386),
    [sym_additive_expression] = STATE(8386),
    [sym_comparison_expression] = STATE(8386),
    [sym_logical_expression] = STATE(8386),
    [sym_ternary_expression] = STATE(8386),
    [sym_unary_expression] = STATE(8386),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8386),
    [sym_list_literal] = STATE(8386),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8386),
    [sym__literal_value] = STATE(8386),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11705),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11707),
    [sym_date_literal] = ACTIONS(11705),
    [sym_time_literal] = ACTIONS(11705),
    [sym_biginteger_literal] = ACTIONS(11707),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11707),
    [sym_verbatim_string] = ACTIONS(11707),
    [sym_integer] = ACTIONS(11705),
    [sym_continue_as_identifier] = ACTIONS(11707),
  },
  [STATE(4806)] = {
    [sym_boolean] = STATE(8406),
    [sym_assignment_expression] = STATE(8406),
    [sym__expression] = STATE(8406),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8406),
    [sym_multiplicative_expression] = STATE(8406),
    [sym_additive_expression] = STATE(8406),
    [sym_comparison_expression] = STATE(8406),
    [sym_logical_expression] = STATE(8406),
    [sym_ternary_expression] = STATE(8406),
    [sym_unary_expression] = STATE(8406),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8406),
    [sym_list_literal] = STATE(8406),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8406),
    [sym__literal_value] = STATE(8406),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11709),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11711),
    [sym_date_literal] = ACTIONS(11709),
    [sym_time_literal] = ACTIONS(11709),
    [sym_biginteger_literal] = ACTIONS(11711),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11711),
    [sym_verbatim_string] = ACTIONS(11711),
    [sym_integer] = ACTIONS(11709),
    [sym_continue_as_identifier] = ACTIONS(11711),
  },
  [STATE(4807)] = {
    [sym_boolean] = STATE(8537),
    [sym_assignment_expression] = STATE(8537),
    [sym__expression] = STATE(8537),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8537),
    [sym_multiplicative_expression] = STATE(8537),
    [sym_additive_expression] = STATE(8537),
    [sym_comparison_expression] = STATE(8537),
    [sym_logical_expression] = STATE(8537),
    [sym_ternary_expression] = STATE(8537),
    [sym_unary_expression] = STATE(8537),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8537),
    [sym_list_literal] = STATE(8537),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8537),
    [sym__literal_value] = STATE(8537),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11713),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11715),
    [sym_date_literal] = ACTIONS(11713),
    [sym_time_literal] = ACTIONS(11713),
    [sym_biginteger_literal] = ACTIONS(11715),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11715),
    [sym_verbatim_string] = ACTIONS(11715),
    [sym_integer] = ACTIONS(11713),
    [sym_continue_as_identifier] = ACTIONS(11715),
  },
  [STATE(4808)] = {
    [sym_boolean] = STATE(8215),
    [sym_assignment_expression] = STATE(8215),
    [sym__expression] = STATE(8215),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8215),
    [sym_multiplicative_expression] = STATE(8215),
    [sym_additive_expression] = STATE(8215),
    [sym_comparison_expression] = STATE(8215),
    [sym_logical_expression] = STATE(8215),
    [sym_ternary_expression] = STATE(8215),
    [sym_unary_expression] = STATE(8215),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8215),
    [sym_list_literal] = STATE(8215),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8215),
    [sym__literal_value] = STATE(8215),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(11717),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(11719),
    [sym_date_literal] = ACTIONS(11717),
    [sym_time_literal] = ACTIONS(11717),
    [sym_biginteger_literal] = ACTIONS(11719),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11719),
    [sym_verbatim_string] = ACTIONS(11719),
    [sym_integer] = ACTIONS(11717),
    [sym_continue_as_identifier] = ACTIONS(11719),
  },
  [STATE(4809)] = {
    [sym_boolean] = STATE(8538),
    [sym_assignment_expression] = STATE(8538),
    [sym__expression] = STATE(8538),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8538),
    [sym_multiplicative_expression] = STATE(8538),
    [sym_additive_expression] = STATE(8538),
    [sym_comparison_expression] = STATE(8538),
    [sym_logical_expression] = STATE(8538),
    [sym_ternary_expression] = STATE(8538),
    [sym_unary_expression] = STATE(8538),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8538),
    [sym_list_literal] = STATE(8538),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8538),
    [sym__literal_value] = STATE(8538),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11721),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11723),
    [sym_date_literal] = ACTIONS(11721),
    [sym_time_literal] = ACTIONS(11721),
    [sym_biginteger_literal] = ACTIONS(11723),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11723),
    [sym_verbatim_string] = ACTIONS(11723),
    [sym_integer] = ACTIONS(11721),
    [sym_continue_as_identifier] = ACTIONS(11723),
  },
  [STATE(4810)] = {
    [sym_boolean] = STATE(1968),
    [sym_assignment_expression] = STATE(1968),
    [sym__expression] = STATE(1968),
    [sym_keyword_identifier] = STATE(1990),
    [sym_range_expression] = STATE(1968),
    [sym_multiplicative_expression] = STATE(1968),
    [sym_additive_expression] = STATE(1968),
    [sym_comparison_expression] = STATE(1968),
    [sym_logical_expression] = STATE(1968),
    [sym_ternary_expression] = STATE(1968),
    [sym_unary_expression] = STATE(1968),
    [sym_call_expression] = STATE(2041),
    [sym_member_expression] = STATE(1990),
    [sym_subscript_expression] = STATE(1990),
    [sym_parenthesized_expression] = STATE(1968),
    [sym_list_literal] = STATE(1968),
    [sym_qualified_enum_value] = STATE(1990),
    [sym_database_reference] = STATE(1968),
    [sym__literal_value] = STATE(1968),
    [sym_codeunit_keyword] = STATE(2035),
    [sym_xmlport_keyword] = STATE(2035),
    [sym_enum_keyword] = STATE(1978),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(673),
    [aux_sym_boolean_token1] = ACTIONS(675),
    [aux_sym_boolean_token2] = ACTIONS(675),
    [sym_decimal] = ACTIONS(11725),
    [anon_sym_LPAREN] = ACTIONS(679),
    [aux_sym_tabledata_permission_token2] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(683),
    [aux_sym_record_type_token1] = ACTIONS(681),
    [aux_sym_basic_type_token21] = ACTIONS(681),
    [aux_sym_basic_type_token22] = ACTIONS(681),
    [aux_sym_basic_type_token48] = ACTIONS(681),
    [anon_sym_not] = ACTIONS(689),
    [anon_sym_NOT] = ACTIONS(689),
    [anon_sym_Not] = ACTIONS(689),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(681),
    [aux_sym_keyword_identifier_token2] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(673),
    [sym_datetime_literal] = ACTIONS(11727),
    [sym_date_literal] = ACTIONS(11725),
    [sym_time_literal] = ACTIONS(11725),
    [sym_biginteger_literal] = ACTIONS(11727),
    [sym_page_keyword] = ACTIONS(691),
    [anon_sym_codeunit] = ACTIONS(703),
    [anon_sym_CODEUNIT] = ACTIONS(703),
    [anon_sym_Codeunit] = ACTIONS(703),
    [anon_sym_CodeUnit] = ACTIONS(703),
    [anon_sym_COdeunit] = ACTIONS(703),
    [anon_sym_codeUnit] = ACTIONS(703),
    [sym_report_keyword] = ACTIONS(691),
    [sym_query_keyword] = ACTIONS(691),
    [anon_sym_xmlport] = ACTIONS(705),
    [anon_sym_XMLPORT] = ACTIONS(705),
    [anon_sym_Xmlport] = ACTIONS(705),
    [anon_sym_XMLport] = ACTIONS(705),
    [anon_sym_XMLPort] = ACTIONS(705),
    [anon_sym_XmlPort] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(707),
    [anon_sym_ENUM] = ACTIONS(707),
    [anon_sym_Enum] = ACTIONS(707),
    [anon_sym_eNUM] = ACTIONS(707),
    [anon_sym_eNum] = ACTIONS(707),
    [anon_sym_ENum] = ACTIONS(707),
    [sym_quoted_identifier] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11727),
    [sym_verbatim_string] = ACTIONS(11727),
    [sym_integer] = ACTIONS(11725),
    [sym_continue_as_identifier] = ACTIONS(11727),
  },
  [STATE(4811)] = {
    [sym_boolean] = STATE(8216),
    [sym_assignment_expression] = STATE(8216),
    [sym__expression] = STATE(8216),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8216),
    [sym_multiplicative_expression] = STATE(8216),
    [sym_additive_expression] = STATE(8216),
    [sym_comparison_expression] = STATE(8216),
    [sym_logical_expression] = STATE(8216),
    [sym_ternary_expression] = STATE(8216),
    [sym_unary_expression] = STATE(8216),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8216),
    [sym_list_literal] = STATE(8216),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8216),
    [sym__literal_value] = STATE(8216),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(11729),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(11731),
    [sym_date_literal] = ACTIONS(11729),
    [sym_time_literal] = ACTIONS(11729),
    [sym_biginteger_literal] = ACTIONS(11731),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11731),
    [sym_verbatim_string] = ACTIONS(11731),
    [sym_integer] = ACTIONS(11729),
    [sym_continue_as_identifier] = ACTIONS(11731),
  },
  [STATE(4812)] = {
    [sym_boolean] = STATE(8217),
    [sym_assignment_expression] = STATE(8217),
    [sym__expression] = STATE(8217),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8217),
    [sym_multiplicative_expression] = STATE(8217),
    [sym_additive_expression] = STATE(8217),
    [sym_comparison_expression] = STATE(8217),
    [sym_logical_expression] = STATE(8217),
    [sym_ternary_expression] = STATE(8217),
    [sym_unary_expression] = STATE(8217),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8217),
    [sym_list_literal] = STATE(8217),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8217),
    [sym__literal_value] = STATE(8217),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(11733),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(11735),
    [sym_date_literal] = ACTIONS(11733),
    [sym_time_literal] = ACTIONS(11733),
    [sym_biginteger_literal] = ACTIONS(11735),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11735),
    [sym_verbatim_string] = ACTIONS(11735),
    [sym_integer] = ACTIONS(11733),
    [sym_continue_as_identifier] = ACTIONS(11735),
  },
  [STATE(4813)] = {
    [sym_boolean] = STATE(8446),
    [sym_assignment_expression] = STATE(8446),
    [sym__expression] = STATE(8446),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8446),
    [sym_multiplicative_expression] = STATE(8446),
    [sym_additive_expression] = STATE(8446),
    [sym_comparison_expression] = STATE(8446),
    [sym_logical_expression] = STATE(8446),
    [sym_ternary_expression] = STATE(8446),
    [sym_unary_expression] = STATE(8446),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8446),
    [sym_list_literal] = STATE(8446),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8446),
    [sym__literal_value] = STATE(8446),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11737),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11739),
    [sym_date_literal] = ACTIONS(11737),
    [sym_time_literal] = ACTIONS(11737),
    [sym_biginteger_literal] = ACTIONS(11739),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11739),
    [sym_verbatim_string] = ACTIONS(11739),
    [sym_integer] = ACTIONS(11737),
    [sym_continue_as_identifier] = ACTIONS(11739),
  },
  [STATE(4814)] = {
    [sym_boolean] = STATE(8218),
    [sym_assignment_expression] = STATE(8218),
    [sym__expression] = STATE(8218),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8218),
    [sym_multiplicative_expression] = STATE(8218),
    [sym_additive_expression] = STATE(8218),
    [sym_comparison_expression] = STATE(8218),
    [sym_logical_expression] = STATE(8218),
    [sym_ternary_expression] = STATE(8218),
    [sym_unary_expression] = STATE(8218),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8218),
    [sym_list_literal] = STATE(8218),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8218),
    [sym__literal_value] = STATE(8218),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(11741),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(11743),
    [sym_date_literal] = ACTIONS(11741),
    [sym_time_literal] = ACTIONS(11741),
    [sym_biginteger_literal] = ACTIONS(11743),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11743),
    [sym_verbatim_string] = ACTIONS(11743),
    [sym_integer] = ACTIONS(11741),
    [sym_continue_as_identifier] = ACTIONS(11743),
  },
  [STATE(4815)] = {
    [sym_boolean] = STATE(8219),
    [sym_assignment_expression] = STATE(8219),
    [sym__expression] = STATE(8219),
    [sym_keyword_identifier] = STATE(8238),
    [sym_range_expression] = STATE(8219),
    [sym_multiplicative_expression] = STATE(8219),
    [sym_additive_expression] = STATE(8219),
    [sym_comparison_expression] = STATE(8219),
    [sym_logical_expression] = STATE(8219),
    [sym_ternary_expression] = STATE(8219),
    [sym_unary_expression] = STATE(8219),
    [sym_call_expression] = STATE(8327),
    [sym_member_expression] = STATE(8238),
    [sym_subscript_expression] = STATE(8238),
    [sym_parenthesized_expression] = STATE(8219),
    [sym_list_literal] = STATE(8219),
    [sym_qualified_enum_value] = STATE(8238),
    [sym_database_reference] = STATE(8219),
    [sym__literal_value] = STATE(8219),
    [sym_codeunit_keyword] = STATE(8286),
    [sym_xmlport_keyword] = STATE(8286),
    [sym_enum_keyword] = STATE(8241),
    [sym_identifier] = ACTIONS(10378),
    [anon_sym_DASH] = ACTIONS(10380),
    [aux_sym_boolean_token1] = ACTIONS(7223),
    [aux_sym_boolean_token2] = ACTIONS(7223),
    [sym_decimal] = ACTIONS(11745),
    [anon_sym_LPAREN] = ACTIONS(10384),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7227),
    [anon_sym_LBRACK] = ACTIONS(10386),
    [aux_sym_record_type_token1] = ACTIONS(7227),
    [aux_sym_basic_type_token21] = ACTIONS(7227),
    [aux_sym_basic_type_token22] = ACTIONS(7227),
    [aux_sym_basic_type_token48] = ACTIONS(7227),
    [anon_sym_not] = ACTIONS(10388),
    [anon_sym_NOT] = ACTIONS(10388),
    [anon_sym_Not] = ACTIONS(10388),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(7227),
    [aux_sym_keyword_identifier_token2] = ACTIONS(10390),
    [anon_sym_PLUS] = ACTIONS(10380),
    [sym_datetime_literal] = ACTIONS(11747),
    [sym_date_literal] = ACTIONS(11745),
    [sym_time_literal] = ACTIONS(11745),
    [sym_biginteger_literal] = ACTIONS(11747),
    [sym_page_keyword] = ACTIONS(10390),
    [anon_sym_codeunit] = ACTIONS(7231),
    [anon_sym_CODEUNIT] = ACTIONS(7231),
    [anon_sym_Codeunit] = ACTIONS(7231),
    [anon_sym_CodeUnit] = ACTIONS(7231),
    [anon_sym_COdeunit] = ACTIONS(7231),
    [anon_sym_codeUnit] = ACTIONS(7231),
    [sym_report_keyword] = ACTIONS(10390),
    [sym_query_keyword] = ACTIONS(10390),
    [anon_sym_xmlport] = ACTIONS(7233),
    [anon_sym_XMLPORT] = ACTIONS(7233),
    [anon_sym_Xmlport] = ACTIONS(7233),
    [anon_sym_XMLport] = ACTIONS(7233),
    [anon_sym_XMLPort] = ACTIONS(7233),
    [anon_sym_XmlPort] = ACTIONS(7233),
    [anon_sym_enum] = ACTIONS(7235),
    [anon_sym_ENUM] = ACTIONS(7235),
    [anon_sym_Enum] = ACTIONS(7235),
    [anon_sym_eNUM] = ACTIONS(7235),
    [anon_sym_eNum] = ACTIONS(7235),
    [anon_sym_ENum] = ACTIONS(7235),
    [sym_quoted_identifier] = ACTIONS(10394),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11747),
    [sym_verbatim_string] = ACTIONS(11747),
    [sym_integer] = ACTIONS(11745),
    [sym_continue_as_identifier] = ACTIONS(11747),
  },
  [STATE(4816)] = {
    [sym_boolean] = STATE(8557),
    [sym_assignment_expression] = STATE(8557),
    [sym__expression] = STATE(8557),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8557),
    [sym_multiplicative_expression] = STATE(8557),
    [sym_additive_expression] = STATE(8557),
    [sym_comparison_expression] = STATE(8557),
    [sym_logical_expression] = STATE(8557),
    [sym_ternary_expression] = STATE(8557),
    [sym_unary_expression] = STATE(8557),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8557),
    [sym_list_literal] = STATE(8557),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8557),
    [sym__literal_value] = STATE(8557),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11749),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11751),
    [sym_date_literal] = ACTIONS(11749),
    [sym_time_literal] = ACTIONS(11749),
    [sym_biginteger_literal] = ACTIONS(11751),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11751),
    [sym_verbatim_string] = ACTIONS(11751),
    [sym_integer] = ACTIONS(11749),
    [sym_continue_as_identifier] = ACTIONS(11751),
  },
  [STATE(4817)] = {
    [sym_boolean] = STATE(8559),
    [sym_assignment_expression] = STATE(8559),
    [sym__expression] = STATE(8559),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8559),
    [sym_multiplicative_expression] = STATE(8559),
    [sym_additive_expression] = STATE(8559),
    [sym_comparison_expression] = STATE(8559),
    [sym_logical_expression] = STATE(8559),
    [sym_ternary_expression] = STATE(8559),
    [sym_unary_expression] = STATE(8559),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8559),
    [sym_list_literal] = STATE(8559),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8559),
    [sym__literal_value] = STATE(8559),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11753),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11755),
    [sym_date_literal] = ACTIONS(11753),
    [sym_time_literal] = ACTIONS(11753),
    [sym_biginteger_literal] = ACTIONS(11755),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11755),
    [sym_verbatim_string] = ACTIONS(11755),
    [sym_integer] = ACTIONS(11753),
    [sym_continue_as_identifier] = ACTIONS(11755),
  },
  [STATE(4818)] = {
    [sym_boolean] = STATE(8560),
    [sym_assignment_expression] = STATE(8560),
    [sym__expression] = STATE(8560),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8560),
    [sym_multiplicative_expression] = STATE(8560),
    [sym_additive_expression] = STATE(8560),
    [sym_comparison_expression] = STATE(8560),
    [sym_logical_expression] = STATE(8560),
    [sym_ternary_expression] = STATE(8560),
    [sym_unary_expression] = STATE(8560),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8560),
    [sym_list_literal] = STATE(8560),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8560),
    [sym__literal_value] = STATE(8560),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11757),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11759),
    [sym_date_literal] = ACTIONS(11757),
    [sym_time_literal] = ACTIONS(11757),
    [sym_biginteger_literal] = ACTIONS(11759),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11759),
    [sym_verbatim_string] = ACTIONS(11759),
    [sym_integer] = ACTIONS(11757),
    [sym_continue_as_identifier] = ACTIONS(11759),
  },
  [STATE(4819)] = {
    [sym_boolean] = STATE(8561),
    [sym_assignment_expression] = STATE(8561),
    [sym__expression] = STATE(8561),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8561),
    [sym_multiplicative_expression] = STATE(8561),
    [sym_additive_expression] = STATE(8561),
    [sym_comparison_expression] = STATE(8561),
    [sym_logical_expression] = STATE(8561),
    [sym_ternary_expression] = STATE(8561),
    [sym_unary_expression] = STATE(8561),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8561),
    [sym_list_literal] = STATE(8561),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8561),
    [sym__literal_value] = STATE(8561),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11761),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11763),
    [sym_date_literal] = ACTIONS(11761),
    [sym_time_literal] = ACTIONS(11761),
    [sym_biginteger_literal] = ACTIONS(11763),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11763),
    [sym_verbatim_string] = ACTIONS(11763),
    [sym_integer] = ACTIONS(11761),
    [sym_continue_as_identifier] = ACTIONS(11763),
  },
  [STATE(4820)] = {
    [sym_boolean] = STATE(8562),
    [sym_assignment_expression] = STATE(8562),
    [sym__expression] = STATE(8562),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8562),
    [sym_multiplicative_expression] = STATE(8562),
    [sym_additive_expression] = STATE(8562),
    [sym_comparison_expression] = STATE(8562),
    [sym_logical_expression] = STATE(8562),
    [sym_ternary_expression] = STATE(8562),
    [sym_unary_expression] = STATE(8562),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8562),
    [sym_list_literal] = STATE(8562),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8562),
    [sym__literal_value] = STATE(8562),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11765),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11767),
    [sym_date_literal] = ACTIONS(11765),
    [sym_time_literal] = ACTIONS(11765),
    [sym_biginteger_literal] = ACTIONS(11767),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11767),
    [sym_verbatim_string] = ACTIONS(11767),
    [sym_integer] = ACTIONS(11765),
    [sym_continue_as_identifier] = ACTIONS(11767),
  },
  [STATE(4821)] = {
    [sym_boolean] = STATE(8563),
    [sym_assignment_expression] = STATE(8563),
    [sym__expression] = STATE(8563),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8563),
    [sym_multiplicative_expression] = STATE(8563),
    [sym_additive_expression] = STATE(8563),
    [sym_comparison_expression] = STATE(8563),
    [sym_logical_expression] = STATE(8563),
    [sym_ternary_expression] = STATE(8563),
    [sym_unary_expression] = STATE(8563),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8563),
    [sym_list_literal] = STATE(8563),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8563),
    [sym__literal_value] = STATE(8563),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11769),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11771),
    [sym_date_literal] = ACTIONS(11769),
    [sym_time_literal] = ACTIONS(11769),
    [sym_biginteger_literal] = ACTIONS(11771),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11771),
    [sym_verbatim_string] = ACTIONS(11771),
    [sym_integer] = ACTIONS(11769),
    [sym_continue_as_identifier] = ACTIONS(11771),
  },
  [STATE(4822)] = {
    [sym_boolean] = STATE(8564),
    [sym_assignment_expression] = STATE(8564),
    [sym__expression] = STATE(8564),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8564),
    [sym_multiplicative_expression] = STATE(8564),
    [sym_additive_expression] = STATE(8564),
    [sym_comparison_expression] = STATE(8564),
    [sym_logical_expression] = STATE(8564),
    [sym_ternary_expression] = STATE(8564),
    [sym_unary_expression] = STATE(8564),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8564),
    [sym_list_literal] = STATE(8564),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8564),
    [sym__literal_value] = STATE(8564),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11773),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11775),
    [sym_date_literal] = ACTIONS(11773),
    [sym_time_literal] = ACTIONS(11773),
    [sym_biginteger_literal] = ACTIONS(11775),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11775),
    [sym_verbatim_string] = ACTIONS(11775),
    [sym_integer] = ACTIONS(11773),
    [sym_continue_as_identifier] = ACTIONS(11775),
  },
  [STATE(4823)] = {
    [sym_boolean] = STATE(8565),
    [sym_assignment_expression] = STATE(8565),
    [sym__expression] = STATE(8565),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8565),
    [sym_multiplicative_expression] = STATE(8565),
    [sym_additive_expression] = STATE(8565),
    [sym_comparison_expression] = STATE(8565),
    [sym_logical_expression] = STATE(8565),
    [sym_ternary_expression] = STATE(8565),
    [sym_unary_expression] = STATE(8565),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8565),
    [sym_list_literal] = STATE(8565),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8565),
    [sym__literal_value] = STATE(8565),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11777),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11779),
    [sym_date_literal] = ACTIONS(11777),
    [sym_time_literal] = ACTIONS(11777),
    [sym_biginteger_literal] = ACTIONS(11779),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11779),
    [sym_verbatim_string] = ACTIONS(11779),
    [sym_integer] = ACTIONS(11777),
    [sym_continue_as_identifier] = ACTIONS(11779),
  },
  [STATE(4824)] = {
    [sym_boolean] = STATE(8566),
    [sym_assignment_expression] = STATE(8566),
    [sym__expression] = STATE(8566),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8566),
    [sym_multiplicative_expression] = STATE(8566),
    [sym_additive_expression] = STATE(8566),
    [sym_comparison_expression] = STATE(8566),
    [sym_logical_expression] = STATE(8566),
    [sym_ternary_expression] = STATE(8566),
    [sym_unary_expression] = STATE(8566),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8566),
    [sym_list_literal] = STATE(8566),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8566),
    [sym__literal_value] = STATE(8566),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11781),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11783),
    [sym_date_literal] = ACTIONS(11781),
    [sym_time_literal] = ACTIONS(11781),
    [sym_biginteger_literal] = ACTIONS(11783),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11783),
    [sym_verbatim_string] = ACTIONS(11783),
    [sym_integer] = ACTIONS(11781),
    [sym_continue_as_identifier] = ACTIONS(11783),
  },
  [STATE(4825)] = {
    [sym_boolean] = STATE(8567),
    [sym_assignment_expression] = STATE(8567),
    [sym__expression] = STATE(8567),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8567),
    [sym_multiplicative_expression] = STATE(8567),
    [sym_additive_expression] = STATE(8567),
    [sym_comparison_expression] = STATE(8567),
    [sym_logical_expression] = STATE(8567),
    [sym_ternary_expression] = STATE(8567),
    [sym_unary_expression] = STATE(8567),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8567),
    [sym_list_literal] = STATE(8567),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8567),
    [sym__literal_value] = STATE(8567),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11785),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11787),
    [sym_date_literal] = ACTIONS(11785),
    [sym_time_literal] = ACTIONS(11785),
    [sym_biginteger_literal] = ACTIONS(11787),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11787),
    [sym_verbatim_string] = ACTIONS(11787),
    [sym_integer] = ACTIONS(11785),
    [sym_continue_as_identifier] = ACTIONS(11787),
  },
  [STATE(4826)] = {
    [sym_boolean] = STATE(8568),
    [sym_assignment_expression] = STATE(8568),
    [sym__expression] = STATE(8568),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8568),
    [sym_multiplicative_expression] = STATE(8568),
    [sym_additive_expression] = STATE(8568),
    [sym_comparison_expression] = STATE(8568),
    [sym_logical_expression] = STATE(8568),
    [sym_ternary_expression] = STATE(8568),
    [sym_unary_expression] = STATE(8568),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8568),
    [sym_list_literal] = STATE(8568),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8568),
    [sym__literal_value] = STATE(8568),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11789),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11791),
    [sym_date_literal] = ACTIONS(11789),
    [sym_time_literal] = ACTIONS(11789),
    [sym_biginteger_literal] = ACTIONS(11791),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11791),
    [sym_verbatim_string] = ACTIONS(11791),
    [sym_integer] = ACTIONS(11789),
    [sym_continue_as_identifier] = ACTIONS(11791),
  },
  [STATE(4827)] = {
    [sym_boolean] = STATE(8569),
    [sym_assignment_expression] = STATE(8569),
    [sym__expression] = STATE(8569),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8569),
    [sym_multiplicative_expression] = STATE(8569),
    [sym_additive_expression] = STATE(8569),
    [sym_comparison_expression] = STATE(8569),
    [sym_logical_expression] = STATE(8569),
    [sym_ternary_expression] = STATE(8569),
    [sym_unary_expression] = STATE(8569),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8569),
    [sym_list_literal] = STATE(8569),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8569),
    [sym__literal_value] = STATE(8569),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11793),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11795),
    [sym_date_literal] = ACTIONS(11793),
    [sym_time_literal] = ACTIONS(11793),
    [sym_biginteger_literal] = ACTIONS(11795),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11795),
    [sym_verbatim_string] = ACTIONS(11795),
    [sym_integer] = ACTIONS(11793),
    [sym_continue_as_identifier] = ACTIONS(11795),
  },
  [STATE(4828)] = {
    [sym_boolean] = STATE(8570),
    [sym_assignment_expression] = STATE(8570),
    [sym__expression] = STATE(8570),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8570),
    [sym_multiplicative_expression] = STATE(8570),
    [sym_additive_expression] = STATE(8570),
    [sym_comparison_expression] = STATE(8570),
    [sym_logical_expression] = STATE(8570),
    [sym_ternary_expression] = STATE(8570),
    [sym_unary_expression] = STATE(8570),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8570),
    [sym_list_literal] = STATE(8570),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8570),
    [sym__literal_value] = STATE(8570),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11797),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11799),
    [sym_date_literal] = ACTIONS(11797),
    [sym_time_literal] = ACTIONS(11797),
    [sym_biginteger_literal] = ACTIONS(11799),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11799),
    [sym_verbatim_string] = ACTIONS(11799),
    [sym_integer] = ACTIONS(11797),
    [sym_continue_as_identifier] = ACTIONS(11799),
  },
  [STATE(4829)] = {
    [sym_boolean] = STATE(8571),
    [sym_assignment_expression] = STATE(8571),
    [sym__expression] = STATE(8571),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8571),
    [sym_multiplicative_expression] = STATE(8571),
    [sym_additive_expression] = STATE(8571),
    [sym_comparison_expression] = STATE(8571),
    [sym_logical_expression] = STATE(8571),
    [sym_ternary_expression] = STATE(8571),
    [sym_unary_expression] = STATE(8571),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8571),
    [sym_list_literal] = STATE(8571),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8571),
    [sym__literal_value] = STATE(8571),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11801),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11803),
    [sym_date_literal] = ACTIONS(11801),
    [sym_time_literal] = ACTIONS(11801),
    [sym_biginteger_literal] = ACTIONS(11803),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11803),
    [sym_verbatim_string] = ACTIONS(11803),
    [sym_integer] = ACTIONS(11801),
    [sym_continue_as_identifier] = ACTIONS(11803),
  },
  [STATE(4830)] = {
    [sym_boolean] = STATE(8572),
    [sym_assignment_expression] = STATE(8572),
    [sym__expression] = STATE(8572),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8572),
    [sym_multiplicative_expression] = STATE(8572),
    [sym_additive_expression] = STATE(8572),
    [sym_comparison_expression] = STATE(8572),
    [sym_logical_expression] = STATE(8572),
    [sym_ternary_expression] = STATE(8572),
    [sym_unary_expression] = STATE(8572),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8572),
    [sym_list_literal] = STATE(8572),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8572),
    [sym__literal_value] = STATE(8572),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11805),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11807),
    [sym_date_literal] = ACTIONS(11805),
    [sym_time_literal] = ACTIONS(11805),
    [sym_biginteger_literal] = ACTIONS(11807),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11807),
    [sym_verbatim_string] = ACTIONS(11807),
    [sym_integer] = ACTIONS(11805),
    [sym_continue_as_identifier] = ACTIONS(11807),
  },
  [STATE(4831)] = {
    [sym_boolean] = STATE(8573),
    [sym_assignment_expression] = STATE(8573),
    [sym__expression] = STATE(8573),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8573),
    [sym_multiplicative_expression] = STATE(8573),
    [sym_additive_expression] = STATE(8573),
    [sym_comparison_expression] = STATE(8573),
    [sym_logical_expression] = STATE(8573),
    [sym_ternary_expression] = STATE(8573),
    [sym_unary_expression] = STATE(8573),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8573),
    [sym_list_literal] = STATE(8573),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8573),
    [sym__literal_value] = STATE(8573),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11809),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11811),
    [sym_date_literal] = ACTIONS(11809),
    [sym_time_literal] = ACTIONS(11809),
    [sym_biginteger_literal] = ACTIONS(11811),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11811),
    [sym_verbatim_string] = ACTIONS(11811),
    [sym_integer] = ACTIONS(11809),
    [sym_continue_as_identifier] = ACTIONS(11811),
  },
  [STATE(4832)] = {
    [sym_boolean] = STATE(8574),
    [sym_assignment_expression] = STATE(8574),
    [sym__expression] = STATE(8574),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8574),
    [sym_multiplicative_expression] = STATE(8574),
    [sym_additive_expression] = STATE(8574),
    [sym_comparison_expression] = STATE(8574),
    [sym_logical_expression] = STATE(8574),
    [sym_ternary_expression] = STATE(8574),
    [sym_unary_expression] = STATE(8574),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8574),
    [sym_list_literal] = STATE(8574),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8574),
    [sym__literal_value] = STATE(8574),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11813),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11815),
    [sym_date_literal] = ACTIONS(11813),
    [sym_time_literal] = ACTIONS(11813),
    [sym_biginteger_literal] = ACTIONS(11815),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11815),
    [sym_verbatim_string] = ACTIONS(11815),
    [sym_integer] = ACTIONS(11813),
    [sym_continue_as_identifier] = ACTIONS(11815),
  },
  [STATE(4833)] = {
    [sym_boolean] = STATE(8575),
    [sym_assignment_expression] = STATE(8575),
    [sym__expression] = STATE(8575),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8575),
    [sym_multiplicative_expression] = STATE(8575),
    [sym_additive_expression] = STATE(8575),
    [sym_comparison_expression] = STATE(8575),
    [sym_logical_expression] = STATE(8575),
    [sym_ternary_expression] = STATE(8575),
    [sym_unary_expression] = STATE(8575),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8575),
    [sym_list_literal] = STATE(8575),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8575),
    [sym__literal_value] = STATE(8575),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11817),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11819),
    [sym_date_literal] = ACTIONS(11817),
    [sym_time_literal] = ACTIONS(11817),
    [sym_biginteger_literal] = ACTIONS(11819),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11819),
    [sym_verbatim_string] = ACTIONS(11819),
    [sym_integer] = ACTIONS(11817),
    [sym_continue_as_identifier] = ACTIONS(11819),
  },
  [STATE(4834)] = {
    [sym_boolean] = STATE(8576),
    [sym_assignment_expression] = STATE(8576),
    [sym__expression] = STATE(8576),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8576),
    [sym_multiplicative_expression] = STATE(8576),
    [sym_additive_expression] = STATE(8576),
    [sym_comparison_expression] = STATE(8576),
    [sym_logical_expression] = STATE(8576),
    [sym_ternary_expression] = STATE(8576),
    [sym_unary_expression] = STATE(8576),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8576),
    [sym_list_literal] = STATE(8576),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8576),
    [sym__literal_value] = STATE(8576),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11821),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11823),
    [sym_date_literal] = ACTIONS(11821),
    [sym_time_literal] = ACTIONS(11821),
    [sym_biginteger_literal] = ACTIONS(11823),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11823),
    [sym_verbatim_string] = ACTIONS(11823),
    [sym_integer] = ACTIONS(11821),
    [sym_continue_as_identifier] = ACTIONS(11823),
  },
  [STATE(4835)] = {
    [sym_boolean] = STATE(8577),
    [sym_assignment_expression] = STATE(8577),
    [sym__expression] = STATE(8577),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8577),
    [sym_multiplicative_expression] = STATE(8577),
    [sym_additive_expression] = STATE(8577),
    [sym_comparison_expression] = STATE(8577),
    [sym_logical_expression] = STATE(8577),
    [sym_ternary_expression] = STATE(8577),
    [sym_unary_expression] = STATE(8577),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8577),
    [sym_list_literal] = STATE(8577),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8577),
    [sym__literal_value] = STATE(8577),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11825),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11827),
    [sym_date_literal] = ACTIONS(11825),
    [sym_time_literal] = ACTIONS(11825),
    [sym_biginteger_literal] = ACTIONS(11827),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11827),
    [sym_verbatim_string] = ACTIONS(11827),
    [sym_integer] = ACTIONS(11825),
    [sym_continue_as_identifier] = ACTIONS(11827),
  },
  [STATE(4836)] = {
    [sym_boolean] = STATE(8578),
    [sym_assignment_expression] = STATE(8578),
    [sym__expression] = STATE(8578),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8578),
    [sym_multiplicative_expression] = STATE(8578),
    [sym_additive_expression] = STATE(8578),
    [sym_comparison_expression] = STATE(8578),
    [sym_logical_expression] = STATE(8578),
    [sym_ternary_expression] = STATE(8578),
    [sym_unary_expression] = STATE(8578),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8578),
    [sym_list_literal] = STATE(8578),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8578),
    [sym__literal_value] = STATE(8578),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11829),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11831),
    [sym_date_literal] = ACTIONS(11829),
    [sym_time_literal] = ACTIONS(11829),
    [sym_biginteger_literal] = ACTIONS(11831),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11831),
    [sym_verbatim_string] = ACTIONS(11831),
    [sym_integer] = ACTIONS(11829),
    [sym_continue_as_identifier] = ACTIONS(11831),
  },
  [STATE(4837)] = {
    [sym_boolean] = STATE(8579),
    [sym_assignment_expression] = STATE(8579),
    [sym__expression] = STATE(8579),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8579),
    [sym_multiplicative_expression] = STATE(8579),
    [sym_additive_expression] = STATE(8579),
    [sym_comparison_expression] = STATE(8579),
    [sym_logical_expression] = STATE(8579),
    [sym_ternary_expression] = STATE(8579),
    [sym_unary_expression] = STATE(8579),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8579),
    [sym_list_literal] = STATE(8579),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8579),
    [sym__literal_value] = STATE(8579),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11833),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11835),
    [sym_date_literal] = ACTIONS(11833),
    [sym_time_literal] = ACTIONS(11833),
    [sym_biginteger_literal] = ACTIONS(11835),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11835),
    [sym_verbatim_string] = ACTIONS(11835),
    [sym_integer] = ACTIONS(11833),
    [sym_continue_as_identifier] = ACTIONS(11835),
  },
  [STATE(4838)] = {
    [sym_boolean] = STATE(8580),
    [sym_assignment_expression] = STATE(8580),
    [sym__expression] = STATE(8580),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8580),
    [sym_multiplicative_expression] = STATE(8580),
    [sym_additive_expression] = STATE(8580),
    [sym_comparison_expression] = STATE(8580),
    [sym_logical_expression] = STATE(8580),
    [sym_ternary_expression] = STATE(8580),
    [sym_unary_expression] = STATE(8580),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8580),
    [sym_list_literal] = STATE(8580),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8580),
    [sym__literal_value] = STATE(8580),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11837),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11839),
    [sym_date_literal] = ACTIONS(11837),
    [sym_time_literal] = ACTIONS(11837),
    [sym_biginteger_literal] = ACTIONS(11839),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11839),
    [sym_verbatim_string] = ACTIONS(11839),
    [sym_integer] = ACTIONS(11837),
    [sym_continue_as_identifier] = ACTIONS(11839),
  },
  [STATE(4839)] = {
    [sym_boolean] = STATE(8581),
    [sym_assignment_expression] = STATE(8581),
    [sym__expression] = STATE(8581),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8581),
    [sym_multiplicative_expression] = STATE(8581),
    [sym_additive_expression] = STATE(8581),
    [sym_comparison_expression] = STATE(8581),
    [sym_logical_expression] = STATE(8581),
    [sym_ternary_expression] = STATE(8581),
    [sym_unary_expression] = STATE(8581),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8581),
    [sym_list_literal] = STATE(8581),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8581),
    [sym__literal_value] = STATE(8581),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11841),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11843),
    [sym_date_literal] = ACTIONS(11841),
    [sym_time_literal] = ACTIONS(11841),
    [sym_biginteger_literal] = ACTIONS(11843),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11843),
    [sym_verbatim_string] = ACTIONS(11843),
    [sym_integer] = ACTIONS(11841),
    [sym_continue_as_identifier] = ACTIONS(11843),
  },
  [STATE(4840)] = {
    [sym_boolean] = STATE(8582),
    [sym_assignment_expression] = STATE(8582),
    [sym__expression] = STATE(8582),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8582),
    [sym_multiplicative_expression] = STATE(8582),
    [sym_additive_expression] = STATE(8582),
    [sym_comparison_expression] = STATE(8582),
    [sym_logical_expression] = STATE(8582),
    [sym_ternary_expression] = STATE(8582),
    [sym_unary_expression] = STATE(8582),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8582),
    [sym_list_literal] = STATE(8582),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8582),
    [sym__literal_value] = STATE(8582),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11845),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11847),
    [sym_date_literal] = ACTIONS(11845),
    [sym_time_literal] = ACTIONS(11845),
    [sym_biginteger_literal] = ACTIONS(11847),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11847),
    [sym_verbatim_string] = ACTIONS(11847),
    [sym_integer] = ACTIONS(11845),
    [sym_continue_as_identifier] = ACTIONS(11847),
  },
  [STATE(4841)] = {
    [sym_boolean] = STATE(8583),
    [sym_assignment_expression] = STATE(8583),
    [sym__expression] = STATE(8583),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8583),
    [sym_multiplicative_expression] = STATE(8583),
    [sym_additive_expression] = STATE(8583),
    [sym_comparison_expression] = STATE(8583),
    [sym_logical_expression] = STATE(8583),
    [sym_ternary_expression] = STATE(8583),
    [sym_unary_expression] = STATE(8583),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8583),
    [sym_list_literal] = STATE(8583),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8583),
    [sym__literal_value] = STATE(8583),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11849),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11851),
    [sym_date_literal] = ACTIONS(11849),
    [sym_time_literal] = ACTIONS(11849),
    [sym_biginteger_literal] = ACTIONS(11851),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11851),
    [sym_verbatim_string] = ACTIONS(11851),
    [sym_integer] = ACTIONS(11849),
    [sym_continue_as_identifier] = ACTIONS(11851),
  },
  [STATE(4842)] = {
    [sym_boolean] = STATE(8584),
    [sym_assignment_expression] = STATE(8584),
    [sym__expression] = STATE(8584),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8584),
    [sym_multiplicative_expression] = STATE(8584),
    [sym_additive_expression] = STATE(8584),
    [sym_comparison_expression] = STATE(8584),
    [sym_logical_expression] = STATE(8584),
    [sym_ternary_expression] = STATE(8584),
    [sym_unary_expression] = STATE(8584),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8584),
    [sym_list_literal] = STATE(8584),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8584),
    [sym__literal_value] = STATE(8584),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11853),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11855),
    [sym_date_literal] = ACTIONS(11853),
    [sym_time_literal] = ACTIONS(11853),
    [sym_biginteger_literal] = ACTIONS(11855),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11855),
    [sym_verbatim_string] = ACTIONS(11855),
    [sym_integer] = ACTIONS(11853),
    [sym_continue_as_identifier] = ACTIONS(11855),
  },
  [STATE(4843)] = {
    [sym_boolean] = STATE(8585),
    [sym_assignment_expression] = STATE(8585),
    [sym__expression] = STATE(8585),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8585),
    [sym_multiplicative_expression] = STATE(8585),
    [sym_additive_expression] = STATE(8585),
    [sym_comparison_expression] = STATE(8585),
    [sym_logical_expression] = STATE(8585),
    [sym_ternary_expression] = STATE(8585),
    [sym_unary_expression] = STATE(8585),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8585),
    [sym_list_literal] = STATE(8585),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8585),
    [sym__literal_value] = STATE(8585),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11857),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11859),
    [sym_date_literal] = ACTIONS(11857),
    [sym_time_literal] = ACTIONS(11857),
    [sym_biginteger_literal] = ACTIONS(11859),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11859),
    [sym_verbatim_string] = ACTIONS(11859),
    [sym_integer] = ACTIONS(11857),
    [sym_continue_as_identifier] = ACTIONS(11859),
  },
  [STATE(4844)] = {
    [sym_boolean] = STATE(8492),
    [sym_assignment_expression] = STATE(8492),
    [sym__expression] = STATE(8492),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8492),
    [sym_multiplicative_expression] = STATE(8492),
    [sym_additive_expression] = STATE(8492),
    [sym_comparison_expression] = STATE(8492),
    [sym_logical_expression] = STATE(8492),
    [sym_ternary_expression] = STATE(8492),
    [sym_unary_expression] = STATE(8492),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8492),
    [sym_list_literal] = STATE(8492),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8492),
    [sym__literal_value] = STATE(8492),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11861),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11863),
    [sym_date_literal] = ACTIONS(11861),
    [sym_time_literal] = ACTIONS(11861),
    [sym_biginteger_literal] = ACTIONS(11863),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11863),
    [sym_verbatim_string] = ACTIONS(11863),
    [sym_integer] = ACTIONS(11861),
    [sym_continue_as_identifier] = ACTIONS(11863),
  },
  [STATE(4845)] = {
    [sym_boolean] = STATE(8493),
    [sym_assignment_expression] = STATE(8493),
    [sym__expression] = STATE(8493),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8493),
    [sym_multiplicative_expression] = STATE(8493),
    [sym_additive_expression] = STATE(8493),
    [sym_comparison_expression] = STATE(8493),
    [sym_logical_expression] = STATE(8493),
    [sym_ternary_expression] = STATE(8493),
    [sym_unary_expression] = STATE(8493),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8493),
    [sym_list_literal] = STATE(8493),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8493),
    [sym__literal_value] = STATE(8493),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11865),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11867),
    [sym_date_literal] = ACTIONS(11865),
    [sym_time_literal] = ACTIONS(11865),
    [sym_biginteger_literal] = ACTIONS(11867),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11867),
    [sym_verbatim_string] = ACTIONS(11867),
    [sym_integer] = ACTIONS(11865),
    [sym_continue_as_identifier] = ACTIONS(11867),
  },
  [STATE(4846)] = {
    [sym_boolean] = STATE(8833),
    [sym_assignment_expression] = STATE(8833),
    [sym__expression] = STATE(8833),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8833),
    [sym_multiplicative_expression] = STATE(8833),
    [sym_additive_expression] = STATE(8833),
    [sym_comparison_expression] = STATE(8833),
    [sym_logical_expression] = STATE(8833),
    [sym_ternary_expression] = STATE(8833),
    [sym_unary_expression] = STATE(8833),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8689),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8833),
    [sym_list_literal] = STATE(8833),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8833),
    [sym__literal_value] = STATE(8833),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(11869),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10938),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10940),
    [sym_date_literal] = ACTIONS(10938),
    [sym_time_literal] = ACTIONS(10938),
    [sym_biginteger_literal] = ACTIONS(10940),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(11871),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10940),
    [sym_verbatim_string] = ACTIONS(10940),
    [sym_integer] = ACTIONS(10938),
    [sym_continue_as_identifier] = ACTIONS(10940),
  },
  [STATE(4847)] = {
    [sym_boolean] = STATE(8586),
    [sym_assignment_expression] = STATE(8586),
    [sym__expression] = STATE(8586),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8586),
    [sym_multiplicative_expression] = STATE(8586),
    [sym_additive_expression] = STATE(8586),
    [sym_comparison_expression] = STATE(8586),
    [sym_logical_expression] = STATE(8586),
    [sym_ternary_expression] = STATE(8586),
    [sym_unary_expression] = STATE(8586),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8586),
    [sym_list_literal] = STATE(8586),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8586),
    [sym__literal_value] = STATE(8586),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11873),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11875),
    [sym_date_literal] = ACTIONS(11873),
    [sym_time_literal] = ACTIONS(11873),
    [sym_biginteger_literal] = ACTIONS(11875),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11875),
    [sym_verbatim_string] = ACTIONS(11875),
    [sym_integer] = ACTIONS(11873),
    [sym_continue_as_identifier] = ACTIONS(11875),
  },
  [STATE(4848)] = {
    [sym_boolean] = STATE(8587),
    [sym_assignment_expression] = STATE(8587),
    [sym__expression] = STATE(8587),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8587),
    [sym_multiplicative_expression] = STATE(8587),
    [sym_additive_expression] = STATE(8587),
    [sym_comparison_expression] = STATE(8587),
    [sym_logical_expression] = STATE(8587),
    [sym_ternary_expression] = STATE(8587),
    [sym_unary_expression] = STATE(8587),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8587),
    [sym_list_literal] = STATE(8587),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8587),
    [sym__literal_value] = STATE(8587),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11877),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11879),
    [sym_date_literal] = ACTIONS(11877),
    [sym_time_literal] = ACTIONS(11877),
    [sym_biginteger_literal] = ACTIONS(11879),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11879),
    [sym_verbatim_string] = ACTIONS(11879),
    [sym_integer] = ACTIONS(11877),
    [sym_continue_as_identifier] = ACTIONS(11879),
  },
  [STATE(4849)] = {
    [sym_boolean] = STATE(8588),
    [sym_assignment_expression] = STATE(8588),
    [sym__expression] = STATE(8588),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8588),
    [sym_multiplicative_expression] = STATE(8588),
    [sym_additive_expression] = STATE(8588),
    [sym_comparison_expression] = STATE(8588),
    [sym_logical_expression] = STATE(8588),
    [sym_ternary_expression] = STATE(8588),
    [sym_unary_expression] = STATE(8588),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8588),
    [sym_list_literal] = STATE(8588),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8588),
    [sym__literal_value] = STATE(8588),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11881),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11883),
    [sym_date_literal] = ACTIONS(11881),
    [sym_time_literal] = ACTIONS(11881),
    [sym_biginteger_literal] = ACTIONS(11883),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11883),
    [sym_verbatim_string] = ACTIONS(11883),
    [sym_integer] = ACTIONS(11881),
    [sym_continue_as_identifier] = ACTIONS(11883),
  },
  [STATE(4850)] = {
    [sym_boolean] = STATE(8589),
    [sym_assignment_expression] = STATE(8589),
    [sym__expression] = STATE(8589),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8589),
    [sym_multiplicative_expression] = STATE(8589),
    [sym_additive_expression] = STATE(8589),
    [sym_comparison_expression] = STATE(8589),
    [sym_logical_expression] = STATE(8589),
    [sym_ternary_expression] = STATE(8589),
    [sym_unary_expression] = STATE(8589),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8589),
    [sym_list_literal] = STATE(8589),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8589),
    [sym__literal_value] = STATE(8589),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11885),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11887),
    [sym_date_literal] = ACTIONS(11885),
    [sym_time_literal] = ACTIONS(11885),
    [sym_biginteger_literal] = ACTIONS(11887),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11887),
    [sym_verbatim_string] = ACTIONS(11887),
    [sym_integer] = ACTIONS(11885),
    [sym_continue_as_identifier] = ACTIONS(11887),
  },
  [STATE(4851)] = {
    [sym_boolean] = STATE(8590),
    [sym_assignment_expression] = STATE(8590),
    [sym__expression] = STATE(8590),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8590),
    [sym_multiplicative_expression] = STATE(8590),
    [sym_additive_expression] = STATE(8590),
    [sym_comparison_expression] = STATE(8590),
    [sym_logical_expression] = STATE(8590),
    [sym_ternary_expression] = STATE(8590),
    [sym_unary_expression] = STATE(8590),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8590),
    [sym_list_literal] = STATE(8590),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8590),
    [sym__literal_value] = STATE(8590),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11889),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11891),
    [sym_date_literal] = ACTIONS(11889),
    [sym_time_literal] = ACTIONS(11889),
    [sym_biginteger_literal] = ACTIONS(11891),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11891),
    [sym_verbatim_string] = ACTIONS(11891),
    [sym_integer] = ACTIONS(11889),
    [sym_continue_as_identifier] = ACTIONS(11891),
  },
  [STATE(4852)] = {
    [sym_boolean] = STATE(8591),
    [sym_assignment_expression] = STATE(8591),
    [sym__expression] = STATE(8591),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8591),
    [sym_multiplicative_expression] = STATE(8591),
    [sym_additive_expression] = STATE(8591),
    [sym_comparison_expression] = STATE(8591),
    [sym_logical_expression] = STATE(8591),
    [sym_ternary_expression] = STATE(8591),
    [sym_unary_expression] = STATE(8591),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8591),
    [sym_list_literal] = STATE(8591),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8591),
    [sym__literal_value] = STATE(8591),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11893),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11895),
    [sym_date_literal] = ACTIONS(11893),
    [sym_time_literal] = ACTIONS(11893),
    [sym_biginteger_literal] = ACTIONS(11895),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11895),
    [sym_verbatim_string] = ACTIONS(11895),
    [sym_integer] = ACTIONS(11893),
    [sym_continue_as_identifier] = ACTIONS(11895),
  },
  [STATE(4853)] = {
    [sym_boolean] = STATE(8592),
    [sym_assignment_expression] = STATE(8592),
    [sym__expression] = STATE(8592),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8592),
    [sym_multiplicative_expression] = STATE(8592),
    [sym_additive_expression] = STATE(8592),
    [sym_comparison_expression] = STATE(8592),
    [sym_logical_expression] = STATE(8592),
    [sym_ternary_expression] = STATE(8592),
    [sym_unary_expression] = STATE(8592),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8592),
    [sym_list_literal] = STATE(8592),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8592),
    [sym__literal_value] = STATE(8592),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11897),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11899),
    [sym_date_literal] = ACTIONS(11897),
    [sym_time_literal] = ACTIONS(11897),
    [sym_biginteger_literal] = ACTIONS(11899),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11899),
    [sym_verbatim_string] = ACTIONS(11899),
    [sym_integer] = ACTIONS(11897),
    [sym_continue_as_identifier] = ACTIONS(11899),
  },
  [STATE(4854)] = {
    [sym_boolean] = STATE(8593),
    [sym_assignment_expression] = STATE(8593),
    [sym__expression] = STATE(8593),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8593),
    [sym_multiplicative_expression] = STATE(8593),
    [sym_additive_expression] = STATE(8593),
    [sym_comparison_expression] = STATE(8593),
    [sym_logical_expression] = STATE(8593),
    [sym_ternary_expression] = STATE(8593),
    [sym_unary_expression] = STATE(8593),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8593),
    [sym_list_literal] = STATE(8593),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8593),
    [sym__literal_value] = STATE(8593),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11901),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11903),
    [sym_date_literal] = ACTIONS(11901),
    [sym_time_literal] = ACTIONS(11901),
    [sym_biginteger_literal] = ACTIONS(11903),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11903),
    [sym_verbatim_string] = ACTIONS(11903),
    [sym_integer] = ACTIONS(11901),
    [sym_continue_as_identifier] = ACTIONS(11903),
  },
  [STATE(4855)] = {
    [sym_boolean] = STATE(8833),
    [sym_assignment_expression] = STATE(8833),
    [sym__expression] = STATE(8833),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8833),
    [sym_multiplicative_expression] = STATE(8833),
    [sym_additive_expression] = STATE(8833),
    [sym_comparison_expression] = STATE(8833),
    [sym_logical_expression] = STATE(8833),
    [sym_ternary_expression] = STATE(8833),
    [sym_unary_expression] = STATE(8833),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8692),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8833),
    [sym_list_literal] = STATE(8833),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8833),
    [sym__literal_value] = STATE(8833),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(11905),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10938),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10940),
    [sym_date_literal] = ACTIONS(10938),
    [sym_time_literal] = ACTIONS(10938),
    [sym_biginteger_literal] = ACTIONS(10940),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(11907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10940),
    [sym_verbatim_string] = ACTIONS(10940),
    [sym_integer] = ACTIONS(10938),
    [sym_continue_as_identifier] = ACTIONS(10940),
  },
  [STATE(4856)] = {
    [sym_boolean] = STATE(8594),
    [sym_assignment_expression] = STATE(8594),
    [sym__expression] = STATE(8594),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8594),
    [sym_multiplicative_expression] = STATE(8594),
    [sym_additive_expression] = STATE(8594),
    [sym_comparison_expression] = STATE(8594),
    [sym_logical_expression] = STATE(8594),
    [sym_ternary_expression] = STATE(8594),
    [sym_unary_expression] = STATE(8594),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8594),
    [sym_list_literal] = STATE(8594),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8594),
    [sym__literal_value] = STATE(8594),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11909),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11911),
    [sym_date_literal] = ACTIONS(11909),
    [sym_time_literal] = ACTIONS(11909),
    [sym_biginteger_literal] = ACTIONS(11911),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11911),
    [sym_verbatim_string] = ACTIONS(11911),
    [sym_integer] = ACTIONS(11909),
    [sym_continue_as_identifier] = ACTIONS(11911),
  },
  [STATE(4857)] = {
    [sym_boolean] = STATE(8595),
    [sym_assignment_expression] = STATE(8595),
    [sym__expression] = STATE(8595),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8595),
    [sym_multiplicative_expression] = STATE(8595),
    [sym_additive_expression] = STATE(8595),
    [sym_comparison_expression] = STATE(8595),
    [sym_logical_expression] = STATE(8595),
    [sym_ternary_expression] = STATE(8595),
    [sym_unary_expression] = STATE(8595),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8595),
    [sym_list_literal] = STATE(8595),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8595),
    [sym__literal_value] = STATE(8595),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11913),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11915),
    [sym_date_literal] = ACTIONS(11913),
    [sym_time_literal] = ACTIONS(11913),
    [sym_biginteger_literal] = ACTIONS(11915),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11915),
    [sym_verbatim_string] = ACTIONS(11915),
    [sym_integer] = ACTIONS(11913),
    [sym_continue_as_identifier] = ACTIONS(11915),
  },
  [STATE(4858)] = {
    [sym_boolean] = STATE(8596),
    [sym_assignment_expression] = STATE(8596),
    [sym__expression] = STATE(8596),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8596),
    [sym_multiplicative_expression] = STATE(8596),
    [sym_additive_expression] = STATE(8596),
    [sym_comparison_expression] = STATE(8596),
    [sym_logical_expression] = STATE(8596),
    [sym_ternary_expression] = STATE(8596),
    [sym_unary_expression] = STATE(8596),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8596),
    [sym_list_literal] = STATE(8596),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8596),
    [sym__literal_value] = STATE(8596),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11917),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11919),
    [sym_date_literal] = ACTIONS(11917),
    [sym_time_literal] = ACTIONS(11917),
    [sym_biginteger_literal] = ACTIONS(11919),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11919),
    [sym_verbatim_string] = ACTIONS(11919),
    [sym_integer] = ACTIONS(11917),
    [sym_continue_as_identifier] = ACTIONS(11919),
  },
  [STATE(4859)] = {
    [sym_boolean] = STATE(8597),
    [sym_assignment_expression] = STATE(8597),
    [sym__expression] = STATE(8597),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8597),
    [sym_multiplicative_expression] = STATE(8597),
    [sym_additive_expression] = STATE(8597),
    [sym_comparison_expression] = STATE(8597),
    [sym_logical_expression] = STATE(8597),
    [sym_ternary_expression] = STATE(8597),
    [sym_unary_expression] = STATE(8597),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8597),
    [sym_list_literal] = STATE(8597),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8597),
    [sym__literal_value] = STATE(8597),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11921),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11923),
    [sym_date_literal] = ACTIONS(11921),
    [sym_time_literal] = ACTIONS(11921),
    [sym_biginteger_literal] = ACTIONS(11923),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11923),
    [sym_verbatim_string] = ACTIONS(11923),
    [sym_integer] = ACTIONS(11921),
    [sym_continue_as_identifier] = ACTIONS(11923),
  },
  [STATE(4860)] = {
    [sym_boolean] = STATE(8598),
    [sym_assignment_expression] = STATE(8598),
    [sym__expression] = STATE(8598),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8598),
    [sym_multiplicative_expression] = STATE(8598),
    [sym_additive_expression] = STATE(8598),
    [sym_comparison_expression] = STATE(8598),
    [sym_logical_expression] = STATE(8598),
    [sym_ternary_expression] = STATE(8598),
    [sym_unary_expression] = STATE(8598),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8598),
    [sym_list_literal] = STATE(8598),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8598),
    [sym__literal_value] = STATE(8598),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11925),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11927),
    [sym_date_literal] = ACTIONS(11925),
    [sym_time_literal] = ACTIONS(11925),
    [sym_biginteger_literal] = ACTIONS(11927),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11927),
    [sym_verbatim_string] = ACTIONS(11927),
    [sym_integer] = ACTIONS(11925),
    [sym_continue_as_identifier] = ACTIONS(11927),
  },
  [STATE(4861)] = {
    [sym_boolean] = STATE(8599),
    [sym_assignment_expression] = STATE(8599),
    [sym__expression] = STATE(8599),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8599),
    [sym_multiplicative_expression] = STATE(8599),
    [sym_additive_expression] = STATE(8599),
    [sym_comparison_expression] = STATE(8599),
    [sym_logical_expression] = STATE(8599),
    [sym_ternary_expression] = STATE(8599),
    [sym_unary_expression] = STATE(8599),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8599),
    [sym_list_literal] = STATE(8599),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8599),
    [sym__literal_value] = STATE(8599),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11929),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11931),
    [sym_date_literal] = ACTIONS(11929),
    [sym_time_literal] = ACTIONS(11929),
    [sym_biginteger_literal] = ACTIONS(11931),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11931),
    [sym_verbatim_string] = ACTIONS(11931),
    [sym_integer] = ACTIONS(11929),
    [sym_continue_as_identifier] = ACTIONS(11931),
  },
  [STATE(4862)] = {
    [sym_boolean] = STATE(8600),
    [sym_assignment_expression] = STATE(8600),
    [sym__expression] = STATE(8600),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8600),
    [sym_multiplicative_expression] = STATE(8600),
    [sym_additive_expression] = STATE(8600),
    [sym_comparison_expression] = STATE(8600),
    [sym_logical_expression] = STATE(8600),
    [sym_ternary_expression] = STATE(8600),
    [sym_unary_expression] = STATE(8600),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8600),
    [sym_list_literal] = STATE(8600),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8600),
    [sym__literal_value] = STATE(8600),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11933),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11935),
    [sym_date_literal] = ACTIONS(11933),
    [sym_time_literal] = ACTIONS(11933),
    [sym_biginteger_literal] = ACTIONS(11935),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11935),
    [sym_verbatim_string] = ACTIONS(11935),
    [sym_integer] = ACTIONS(11933),
    [sym_continue_as_identifier] = ACTIONS(11935),
  },
  [STATE(4863)] = {
    [sym_boolean] = STATE(8601),
    [sym_assignment_expression] = STATE(8601),
    [sym__expression] = STATE(8601),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8601),
    [sym_multiplicative_expression] = STATE(8601),
    [sym_additive_expression] = STATE(8601),
    [sym_comparison_expression] = STATE(8601),
    [sym_logical_expression] = STATE(8601),
    [sym_ternary_expression] = STATE(8601),
    [sym_unary_expression] = STATE(8601),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8601),
    [sym_list_literal] = STATE(8601),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8601),
    [sym__literal_value] = STATE(8601),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11937),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11939),
    [sym_date_literal] = ACTIONS(11937),
    [sym_time_literal] = ACTIONS(11937),
    [sym_biginteger_literal] = ACTIONS(11939),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11939),
    [sym_verbatim_string] = ACTIONS(11939),
    [sym_integer] = ACTIONS(11937),
    [sym_continue_as_identifier] = ACTIONS(11939),
  },
  [STATE(4864)] = {
    [sym_boolean] = STATE(8833),
    [sym_assignment_expression] = STATE(8833),
    [sym__expression] = STATE(8833),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8833),
    [sym_multiplicative_expression] = STATE(8833),
    [sym_additive_expression] = STATE(8833),
    [sym_comparison_expression] = STATE(8833),
    [sym_logical_expression] = STATE(8833),
    [sym_ternary_expression] = STATE(8833),
    [sym_unary_expression] = STATE(8833),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8696),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8833),
    [sym_list_literal] = STATE(8833),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8833),
    [sym__literal_value] = STATE(8833),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(11941),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10938),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10940),
    [sym_date_literal] = ACTIONS(10938),
    [sym_time_literal] = ACTIONS(10938),
    [sym_biginteger_literal] = ACTIONS(10940),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(11943),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10940),
    [sym_verbatim_string] = ACTIONS(10940),
    [sym_integer] = ACTIONS(10938),
    [sym_continue_as_identifier] = ACTIONS(10940),
  },
  [STATE(4865)] = {
    [sym_boolean] = STATE(8602),
    [sym_assignment_expression] = STATE(8602),
    [sym__expression] = STATE(8602),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8602),
    [sym_multiplicative_expression] = STATE(8602),
    [sym_additive_expression] = STATE(8602),
    [sym_comparison_expression] = STATE(8602),
    [sym_logical_expression] = STATE(8602),
    [sym_ternary_expression] = STATE(8602),
    [sym_unary_expression] = STATE(8602),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8602),
    [sym_list_literal] = STATE(8602),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8602),
    [sym__literal_value] = STATE(8602),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11945),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11947),
    [sym_date_literal] = ACTIONS(11945),
    [sym_time_literal] = ACTIONS(11945),
    [sym_biginteger_literal] = ACTIONS(11947),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11947),
    [sym_verbatim_string] = ACTIONS(11947),
    [sym_integer] = ACTIONS(11945),
    [sym_continue_as_identifier] = ACTIONS(11947),
  },
  [STATE(4866)] = {
    [sym_boolean] = STATE(8603),
    [sym_assignment_expression] = STATE(8603),
    [sym__expression] = STATE(8603),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8603),
    [sym_multiplicative_expression] = STATE(8603),
    [sym_additive_expression] = STATE(8603),
    [sym_comparison_expression] = STATE(8603),
    [sym_logical_expression] = STATE(8603),
    [sym_ternary_expression] = STATE(8603),
    [sym_unary_expression] = STATE(8603),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8603),
    [sym_list_literal] = STATE(8603),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8603),
    [sym__literal_value] = STATE(8603),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11949),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11951),
    [sym_date_literal] = ACTIONS(11949),
    [sym_time_literal] = ACTIONS(11949),
    [sym_biginteger_literal] = ACTIONS(11951),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11951),
    [sym_verbatim_string] = ACTIONS(11951),
    [sym_integer] = ACTIONS(11949),
    [sym_continue_as_identifier] = ACTIONS(11951),
  },
  [STATE(4867)] = {
    [sym_boolean] = STATE(8604),
    [sym_assignment_expression] = STATE(8604),
    [sym__expression] = STATE(8604),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8604),
    [sym_multiplicative_expression] = STATE(8604),
    [sym_additive_expression] = STATE(8604),
    [sym_comparison_expression] = STATE(8604),
    [sym_logical_expression] = STATE(8604),
    [sym_ternary_expression] = STATE(8604),
    [sym_unary_expression] = STATE(8604),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8604),
    [sym_list_literal] = STATE(8604),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8604),
    [sym__literal_value] = STATE(8604),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11953),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11955),
    [sym_date_literal] = ACTIONS(11953),
    [sym_time_literal] = ACTIONS(11953),
    [sym_biginteger_literal] = ACTIONS(11955),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11955),
    [sym_verbatim_string] = ACTIONS(11955),
    [sym_integer] = ACTIONS(11953),
    [sym_continue_as_identifier] = ACTIONS(11955),
  },
  [STATE(4868)] = {
    [sym_boolean] = STATE(8605),
    [sym_assignment_expression] = STATE(8605),
    [sym__expression] = STATE(8605),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8605),
    [sym_multiplicative_expression] = STATE(8605),
    [sym_additive_expression] = STATE(8605),
    [sym_comparison_expression] = STATE(8605),
    [sym_logical_expression] = STATE(8605),
    [sym_ternary_expression] = STATE(8605),
    [sym_unary_expression] = STATE(8605),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8605),
    [sym_list_literal] = STATE(8605),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8605),
    [sym__literal_value] = STATE(8605),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11957),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11959),
    [sym_date_literal] = ACTIONS(11957),
    [sym_time_literal] = ACTIONS(11957),
    [sym_biginteger_literal] = ACTIONS(11959),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11959),
    [sym_verbatim_string] = ACTIONS(11959),
    [sym_integer] = ACTIONS(11957),
    [sym_continue_as_identifier] = ACTIONS(11959),
  },
  [STATE(4869)] = {
    [sym_boolean] = STATE(8606),
    [sym_assignment_expression] = STATE(8606),
    [sym__expression] = STATE(8606),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8606),
    [sym_multiplicative_expression] = STATE(8606),
    [sym_additive_expression] = STATE(8606),
    [sym_comparison_expression] = STATE(8606),
    [sym_logical_expression] = STATE(8606),
    [sym_ternary_expression] = STATE(8606),
    [sym_unary_expression] = STATE(8606),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8606),
    [sym_list_literal] = STATE(8606),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8606),
    [sym__literal_value] = STATE(8606),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11961),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11963),
    [sym_date_literal] = ACTIONS(11961),
    [sym_time_literal] = ACTIONS(11961),
    [sym_biginteger_literal] = ACTIONS(11963),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11963),
    [sym_verbatim_string] = ACTIONS(11963),
    [sym_integer] = ACTIONS(11961),
    [sym_continue_as_identifier] = ACTIONS(11963),
  },
  [STATE(4870)] = {
    [sym_boolean] = STATE(8607),
    [sym_assignment_expression] = STATE(8607),
    [sym__expression] = STATE(8607),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8607),
    [sym_multiplicative_expression] = STATE(8607),
    [sym_additive_expression] = STATE(8607),
    [sym_comparison_expression] = STATE(8607),
    [sym_logical_expression] = STATE(8607),
    [sym_ternary_expression] = STATE(8607),
    [sym_unary_expression] = STATE(8607),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8607),
    [sym_list_literal] = STATE(8607),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8607),
    [sym__literal_value] = STATE(8607),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11965),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11967),
    [sym_date_literal] = ACTIONS(11965),
    [sym_time_literal] = ACTIONS(11965),
    [sym_biginteger_literal] = ACTIONS(11967),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11967),
    [sym_verbatim_string] = ACTIONS(11967),
    [sym_integer] = ACTIONS(11965),
    [sym_continue_as_identifier] = ACTIONS(11967),
  },
  [STATE(4871)] = {
    [sym_boolean] = STATE(8608),
    [sym_assignment_expression] = STATE(8608),
    [sym__expression] = STATE(8608),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8608),
    [sym_multiplicative_expression] = STATE(8608),
    [sym_additive_expression] = STATE(8608),
    [sym_comparison_expression] = STATE(8608),
    [sym_logical_expression] = STATE(8608),
    [sym_ternary_expression] = STATE(8608),
    [sym_unary_expression] = STATE(8608),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8608),
    [sym_list_literal] = STATE(8608),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8608),
    [sym__literal_value] = STATE(8608),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11969),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11971),
    [sym_date_literal] = ACTIONS(11969),
    [sym_time_literal] = ACTIONS(11969),
    [sym_biginteger_literal] = ACTIONS(11971),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11971),
    [sym_verbatim_string] = ACTIONS(11971),
    [sym_integer] = ACTIONS(11969),
    [sym_continue_as_identifier] = ACTIONS(11971),
  },
  [STATE(4872)] = {
    [sym_boolean] = STATE(8609),
    [sym_assignment_expression] = STATE(8609),
    [sym__expression] = STATE(8609),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8609),
    [sym_multiplicative_expression] = STATE(8609),
    [sym_additive_expression] = STATE(8609),
    [sym_comparison_expression] = STATE(8609),
    [sym_logical_expression] = STATE(8609),
    [sym_ternary_expression] = STATE(8609),
    [sym_unary_expression] = STATE(8609),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8609),
    [sym_list_literal] = STATE(8609),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8609),
    [sym__literal_value] = STATE(8609),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11973),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11975),
    [sym_date_literal] = ACTIONS(11973),
    [sym_time_literal] = ACTIONS(11973),
    [sym_biginteger_literal] = ACTIONS(11975),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11975),
    [sym_verbatim_string] = ACTIONS(11975),
    [sym_integer] = ACTIONS(11973),
    [sym_continue_as_identifier] = ACTIONS(11975),
  },
  [STATE(4873)] = {
    [sym_boolean] = STATE(8833),
    [sym_assignment_expression] = STATE(8833),
    [sym__expression] = STATE(8833),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8833),
    [sym_multiplicative_expression] = STATE(8833),
    [sym_additive_expression] = STATE(8833),
    [sym_comparison_expression] = STATE(8833),
    [sym_logical_expression] = STATE(8833),
    [sym_ternary_expression] = STATE(8833),
    [sym_unary_expression] = STATE(8833),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8698),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8833),
    [sym_list_literal] = STATE(8833),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8833),
    [sym__literal_value] = STATE(8833),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(11977),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10938),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10940),
    [sym_date_literal] = ACTIONS(10938),
    [sym_time_literal] = ACTIONS(10938),
    [sym_biginteger_literal] = ACTIONS(10940),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(11979),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10940),
    [sym_verbatim_string] = ACTIONS(10940),
    [sym_integer] = ACTIONS(10938),
    [sym_continue_as_identifier] = ACTIONS(10940),
  },
  [STATE(4874)] = {
    [sym_boolean] = STATE(8833),
    [sym_assignment_expression] = STATE(8833),
    [sym__expression] = STATE(8833),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8833),
    [sym_multiplicative_expression] = STATE(8833),
    [sym_additive_expression] = STATE(8833),
    [sym_comparison_expression] = STATE(8833),
    [sym_logical_expression] = STATE(8833),
    [sym_ternary_expression] = STATE(8833),
    [sym_unary_expression] = STATE(8833),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(8699),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8833),
    [sym_list_literal] = STATE(8833),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8833),
    [sym__literal_value] = STATE(8833),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(11981),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(10938),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(10940),
    [sym_date_literal] = ACTIONS(10938),
    [sym_time_literal] = ACTIONS(10938),
    [sym_biginteger_literal] = ACTIONS(10940),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(11983),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(10940),
    [sym_verbatim_string] = ACTIONS(10940),
    [sym_integer] = ACTIONS(10938),
    [sym_continue_as_identifier] = ACTIONS(10940),
  },
  [STATE(4875)] = {
    [sym_boolean] = STATE(8494),
    [sym_assignment_expression] = STATE(8494),
    [sym__expression] = STATE(8494),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8494),
    [sym_multiplicative_expression] = STATE(8494),
    [sym_additive_expression] = STATE(8494),
    [sym_comparison_expression] = STATE(8494),
    [sym_logical_expression] = STATE(8494),
    [sym_ternary_expression] = STATE(8494),
    [sym_unary_expression] = STATE(8494),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8494),
    [sym_list_literal] = STATE(8494),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8494),
    [sym__literal_value] = STATE(8494),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11985),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11987),
    [sym_date_literal] = ACTIONS(11985),
    [sym_time_literal] = ACTIONS(11985),
    [sym_biginteger_literal] = ACTIONS(11987),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11987),
    [sym_verbatim_string] = ACTIONS(11987),
    [sym_integer] = ACTIONS(11985),
    [sym_continue_as_identifier] = ACTIONS(11987),
  },
  [STATE(4876)] = {
    [sym_boolean] = STATE(8495),
    [sym_assignment_expression] = STATE(8495),
    [sym__expression] = STATE(8495),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8495),
    [sym_multiplicative_expression] = STATE(8495),
    [sym_additive_expression] = STATE(8495),
    [sym_comparison_expression] = STATE(8495),
    [sym_logical_expression] = STATE(8495),
    [sym_ternary_expression] = STATE(8495),
    [sym_unary_expression] = STATE(8495),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8495),
    [sym_list_literal] = STATE(8495),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8495),
    [sym__literal_value] = STATE(8495),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(4363),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11989),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(4379),
    [anon_sym_NOT] = ACTIONS(4379),
    [anon_sym_Not] = ACTIONS(4379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(4363),
    [sym_datetime_literal] = ACTIONS(11991),
    [sym_date_literal] = ACTIONS(11989),
    [sym_time_literal] = ACTIONS(11989),
    [sym_biginteger_literal] = ACTIONS(11991),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11991),
    [sym_verbatim_string] = ACTIONS(11991),
    [sym_integer] = ACTIONS(11989),
    [sym_continue_as_identifier] = ACTIONS(11991),
  },
  [STATE(4877)] = {
    [sym_boolean] = STATE(8756),
    [sym_assignment_expression] = STATE(8756),
    [sym__expression] = STATE(8756),
    [sym_keyword_identifier] = STATE(7223),
    [sym_range_expression] = STATE(8756),
    [sym_multiplicative_expression] = STATE(8756),
    [sym_additive_expression] = STATE(8756),
    [sym_comparison_expression] = STATE(8756),
    [sym_logical_expression] = STATE(8756),
    [sym_ternary_expression] = STATE(8756),
    [sym_unary_expression] = STATE(8756),
    [sym_call_expression] = STATE(7502),
    [sym_member_expression] = STATE(7223),
    [sym_subscript_expression] = STATE(7223),
    [sym_parenthesized_expression] = STATE(8756),
    [sym_list_literal] = STATE(8756),
    [sym_qualified_enum_value] = STATE(7223),
    [sym_database_reference] = STATE(8756),
    [sym__literal_value] = STATE(8756),
    [sym_codeunit_keyword] = STATE(7210),
    [sym_xmlport_keyword] = STATE(7210),
    [sym_enum_keyword] = STATE(6858),
    [sym_identifier] = ACTIONS(8081),
    [anon_sym_DASH] = ACTIONS(3983),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [sym_decimal] = ACTIONS(11993),
    [anon_sym_LPAREN] = ACTIONS(1380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_LBRACK] = ACTIONS(1384),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(1382),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [anon_sym_not] = ACTIONS(3979),
    [anon_sym_NOT] = ACTIONS(3979),
    [anon_sym_Not] = ACTIONS(3979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3983),
    [sym_datetime_literal] = ACTIONS(11995),
    [sym_date_literal] = ACTIONS(11993),
    [sym_time_literal] = ACTIONS(11993),
    [sym_biginteger_literal] = ACTIONS(11995),
    [sym_page_keyword] = ACTIONS(3981),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(3981),
    [sym_query_keyword] = ACTIONS(3981),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_quoted_identifier] = ACTIONS(8089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11995),
    [sym_verbatim_string] = ACTIONS(11995),
    [sym_integer] = ACTIONS(11993),
    [sym_continue_as_identifier] = ACTIONS(11995),
  },
  [STATE(4878)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6490),
    [sym_preproc_endif] = STATE(10154),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10691),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(992),
    [anon_sym_POUNDENDIF] = ACTIONS(992),
    [anon_sym_POUNDEndif] = ACTIONS(992),
    [anon_sym_POUNDendif2] = ACTIONS(992),
    [anon_sym_POUNDENDIF2] = ACTIONS(992),
    [anon_sym_POUNDEndif2] = ACTIONS(992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(992),
  },
  [STATE(4879)] = {
    [sym_preproc_split_procedure] = STATE(4879),
    [sym_var_attribute_item] = STATE(4879),
    [sym_preproc_conditional_var] = STATE(4879),
    [sym_variable_declaration] = STATE(4879),
    [sym_preproc_if] = STATE(3151),
    [sym__identifier_or_quoted] = STATE(15532),
    [sym_keyword_as_identifier] = STATE(15532),
    [aux_sym_var_section_repeat1] = STATE(4879),
    [sym_identifier] = ACTIONS(11997),
    [anon_sym_SEMI] = ACTIONS(8313),
    [anon_sym_RBRACE] = ACTIONS(8313),
    [aux_sym_where_condition_token1] = ACTIONS(8315),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8318),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8318),
    [anon_sym_LBRACK] = ACTIONS(8313),
    [aux_sym_basic_type_token6] = ACTIONS(8318),
    [aux_sym_basic_type_token22] = ACTIONS(8315),
    [aux_sym_basic_type_token53] = ACTIONS(8315),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8315),
    [aux_sym_addafter_modification_token1] = ACTIONS(8318),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8318),
    [aux_sym_modify_modification_token1] = ACTIONS(8318),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8318),
    [aux_sym_movelast_modification_token1] = ACTIONS(8318),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8318),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8318),
    [aux_sym_separator_action_token1] = ACTIONS(8315),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8315),
    [aux_sym_type_declaration_token1] = ACTIONS(8315),
    [anon_sym_POUNDif] = ACTIONS(8320),
    [anon_sym_POUNDIF] = ACTIONS(8320),
    [anon_sym_POUNDIf] = ACTIONS(8320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8315),
    [sym_procedure_keyword] = ACTIONS(8318),
    [sym_trigger_keyword] = ACTIONS(8318),
    [sym_var_keyword] = ACTIONS(8318),
    [sym_local_keyword] = ACTIONS(8318),
    [sym_internal_keyword] = ACTIONS(8318),
    [sym_protected_keyword] = ACTIONS(8318),
    [sym_event_keyword] = ACTIONS(8318),
    [sym_fields_keyword] = ACTIONS(8318),
    [sym_keys_keyword] = ACTIONS(8318),
    [sym_key_keyword] = ACTIONS(8315),
    [sym_fieldgroups_keyword] = ACTIONS(8318),
    [sym_actions_keyword] = ACTIONS(8318),
    [sym_layout_keyword] = ACTIONS(8318),
    [sym_area_keyword] = ACTIONS(8318),
    [sym_group_keyword] = ACTIONS(8318),
    [sym_repeater_keyword] = ACTIONS(8318),
    [sym_cuegroup_keyword] = ACTIONS(8318),
    [sym_fixed_keyword] = ACTIONS(8318),
    [sym_grid_keyword] = ACTIONS(8318),
    [sym_part_keyword] = ACTIONS(8318),
    [sym_systempart_keyword] = ACTIONS(8318),
    [sym_usercontrol_keyword] = ACTIONS(8318),
    [sym_dataset_keyword] = ACTIONS(8315),
    [sym_elements_keyword] = ACTIONS(8318),
    [sym_dataitem_keyword] = ACTIONS(8318),
    [sym_column_keyword] = ACTIONS(8318),
    [sym_filter_keyword] = ACTIONS(8318),
    [sym_labels_keyword] = ACTIONS(8318),
    [sym_rendering_keyword] = ACTIONS(8318),
    [sym_requestpage_keyword] = ACTIONS(8318),
    [sym_schema_keyword] = ACTIONS(8318),
    [sym_views_keyword] = ACTIONS(8318),
    [sym_quoted_identifier] = ACTIONS(12000),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8313),
    [sym_preproc_open] = ACTIONS(8320),
    [sym_var_attribute_open] = ACTIONS(12003),
  },
  [STATE(4880)] = {
    [sym_preproc_split_procedure] = STATE(4879),
    [sym_var_attribute_item] = STATE(4879),
    [sym_preproc_conditional_var] = STATE(4879),
    [sym_variable_declaration] = STATE(4879),
    [sym_preproc_if] = STATE(3151),
    [sym__identifier_or_quoted] = STATE(15532),
    [sym_keyword_as_identifier] = STATE(15532),
    [aux_sym_var_section_repeat1] = STATE(4879),
    [sym_identifier] = ACTIONS(12006),
    [anon_sym_SEMI] = ACTIONS(8306),
    [anon_sym_RBRACE] = ACTIONS(8306),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8308),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8308),
    [anon_sym_LBRACK] = ACTIONS(8306),
    [aux_sym_basic_type_token6] = ACTIONS(8308),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_addafter_modification_token1] = ACTIONS(8308),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8308),
    [aux_sym_modify_modification_token1] = ACTIONS(8308),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8308),
    [aux_sym_movelast_modification_token1] = ACTIONS(8308),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8308),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8308),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8308),
    [sym_trigger_keyword] = ACTIONS(8308),
    [sym_var_keyword] = ACTIONS(8308),
    [sym_local_keyword] = ACTIONS(8308),
    [sym_internal_keyword] = ACTIONS(8308),
    [sym_protected_keyword] = ACTIONS(8308),
    [sym_event_keyword] = ACTIONS(8308),
    [sym_fields_keyword] = ACTIONS(8308),
    [sym_keys_keyword] = ACTIONS(8308),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8308),
    [sym_actions_keyword] = ACTIONS(8308),
    [sym_layout_keyword] = ACTIONS(8308),
    [sym_area_keyword] = ACTIONS(8308),
    [sym_group_keyword] = ACTIONS(8308),
    [sym_repeater_keyword] = ACTIONS(8308),
    [sym_cuegroup_keyword] = ACTIONS(8308),
    [sym_fixed_keyword] = ACTIONS(8308),
    [sym_grid_keyword] = ACTIONS(8308),
    [sym_part_keyword] = ACTIONS(8308),
    [sym_systempart_keyword] = ACTIONS(8308),
    [sym_usercontrol_keyword] = ACTIONS(8308),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8308),
    [sym_dataitem_keyword] = ACTIONS(8308),
    [sym_column_keyword] = ACTIONS(8308),
    [sym_filter_keyword] = ACTIONS(8308),
    [sym_labels_keyword] = ACTIONS(8308),
    [sym_rendering_keyword] = ACTIONS(8308),
    [sym_requestpage_keyword] = ACTIONS(8308),
    [sym_schema_keyword] = ACTIONS(8308),
    [sym_views_keyword] = ACTIONS(8308),
    [sym_quoted_identifier] = ACTIONS(12008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8306),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_var_attribute_open] = ACTIONS(12010),
  },
  [STATE(4881)] = {
    [sym_preproc_split_procedure] = STATE(4880),
    [sym_var_attribute_item] = STATE(4880),
    [sym_preproc_conditional_var] = STATE(4880),
    [sym_variable_declaration] = STATE(4880),
    [sym_preproc_if] = STATE(3151),
    [sym__identifier_or_quoted] = STATE(15532),
    [sym_keyword_as_identifier] = STATE(15532),
    [aux_sym_var_section_repeat1] = STATE(4880),
    [sym_identifier] = ACTIONS(12006),
    [anon_sym_SEMI] = ACTIONS(8296),
    [anon_sym_RBRACE] = ACTIONS(8296),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8298),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8298),
    [anon_sym_LBRACK] = ACTIONS(8296),
    [aux_sym_basic_type_token6] = ACTIONS(8298),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_addafter_modification_token1] = ACTIONS(8298),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8298),
    [aux_sym_modify_modification_token1] = ACTIONS(8298),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8298),
    [aux_sym_movelast_modification_token1] = ACTIONS(8298),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8298),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8298),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8298),
    [sym_trigger_keyword] = ACTIONS(8298),
    [sym_var_keyword] = ACTIONS(8298),
    [sym_local_keyword] = ACTIONS(8298),
    [sym_internal_keyword] = ACTIONS(8298),
    [sym_protected_keyword] = ACTIONS(8298),
    [sym_event_keyword] = ACTIONS(8298),
    [sym_fields_keyword] = ACTIONS(8298),
    [sym_keys_keyword] = ACTIONS(8298),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8298),
    [sym_actions_keyword] = ACTIONS(8298),
    [sym_layout_keyword] = ACTIONS(8298),
    [sym_area_keyword] = ACTIONS(8298),
    [sym_group_keyword] = ACTIONS(8298),
    [sym_repeater_keyword] = ACTIONS(8298),
    [sym_cuegroup_keyword] = ACTIONS(8298),
    [sym_fixed_keyword] = ACTIONS(8298),
    [sym_grid_keyword] = ACTIONS(8298),
    [sym_part_keyword] = ACTIONS(8298),
    [sym_systempart_keyword] = ACTIONS(8298),
    [sym_usercontrol_keyword] = ACTIONS(8298),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8298),
    [sym_dataitem_keyword] = ACTIONS(8298),
    [sym_column_keyword] = ACTIONS(8298),
    [sym_filter_keyword] = ACTIONS(8298),
    [sym_labels_keyword] = ACTIONS(8298),
    [sym_rendering_keyword] = ACTIONS(8298),
    [sym_requestpage_keyword] = ACTIONS(8298),
    [sym_schema_keyword] = ACTIONS(8298),
    [sym_views_keyword] = ACTIONS(8298),
    [sym_quoted_identifier] = ACTIONS(12008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8296),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_var_attribute_open] = ACTIONS(12010),
  },
  [STATE(4882)] = {
    [sym_preproc_split_procedure] = STATE(4885),
    [sym_var_attribute_item] = STATE(4885),
    [sym_preproc_conditional_var] = STATE(4885),
    [sym_variable_declaration] = STATE(4885),
    [sym_preproc_if] = STATE(3151),
    [sym__identifier_or_quoted] = STATE(15532),
    [sym_keyword_as_identifier] = STATE(15532),
    [aux_sym_var_section_repeat1] = STATE(4885),
    [sym_identifier] = ACTIONS(12006),
    [anon_sym_SEMI] = ACTIONS(8329),
    [anon_sym_RBRACE] = ACTIONS(8329),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8331),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8331),
    [anon_sym_LBRACK] = ACTIONS(8329),
    [aux_sym_basic_type_token6] = ACTIONS(8331),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_addafter_modification_token1] = ACTIONS(8331),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8331),
    [aux_sym_modify_modification_token1] = ACTIONS(8331),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8331),
    [aux_sym_movelast_modification_token1] = ACTIONS(8331),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8331),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8331),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8331),
    [sym_trigger_keyword] = ACTIONS(8331),
    [sym_var_keyword] = ACTIONS(8331),
    [sym_local_keyword] = ACTIONS(8331),
    [sym_internal_keyword] = ACTIONS(8331),
    [sym_protected_keyword] = ACTIONS(8331),
    [sym_event_keyword] = ACTIONS(8331),
    [sym_fields_keyword] = ACTIONS(8331),
    [sym_keys_keyword] = ACTIONS(8331),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8331),
    [sym_actions_keyword] = ACTIONS(8331),
    [sym_layout_keyword] = ACTIONS(8331),
    [sym_area_keyword] = ACTIONS(8331),
    [sym_group_keyword] = ACTIONS(8331),
    [sym_repeater_keyword] = ACTIONS(8331),
    [sym_cuegroup_keyword] = ACTIONS(8331),
    [sym_fixed_keyword] = ACTIONS(8331),
    [sym_grid_keyword] = ACTIONS(8331),
    [sym_part_keyword] = ACTIONS(8331),
    [sym_systempart_keyword] = ACTIONS(8331),
    [sym_usercontrol_keyword] = ACTIONS(8331),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8331),
    [sym_dataitem_keyword] = ACTIONS(8331),
    [sym_column_keyword] = ACTIONS(8331),
    [sym_filter_keyword] = ACTIONS(8331),
    [sym_labels_keyword] = ACTIONS(8331),
    [sym_rendering_keyword] = ACTIONS(8331),
    [sym_requestpage_keyword] = ACTIONS(8331),
    [sym_schema_keyword] = ACTIONS(8331),
    [sym_views_keyword] = ACTIONS(8331),
    [sym_quoted_identifier] = ACTIONS(12008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8329),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_var_attribute_open] = ACTIONS(12010),
  },
  [STATE(4883)] = {
    [sym__body_element] = STATE(4883),
    [sym_empty_statement] = STATE(4883),
    [sym_property] = STATE(4883),
    [sym_permissions_property] = STATE(4883),
    [sym_table_relation_property] = STATE(4883),
    [sym_fields_section] = STATE(4883),
    [sym_keys_section] = STATE(4883),
    [sym_fieldgroups_section] = STATE(4883),
    [sym_enum_value_declaration] = STATE(4883),
    [sym_labels_section] = STATE(4883),
    [sym_layout_section] = STATE(4883),
    [sym_modify_modification] = STATE(4883),
    [sym_actions_section] = STATE(4883),
    [sym_views_section] = STATE(4883),
    [sym_dataset_section] = STATE(4883),
    [sym_requestpage_section] = STATE(4883),
    [sym_rendering_section] = STATE(4883),
    [sym_elements_section] = STATE(4883),
    [sym_query_dataitem] = STATE(4883),
    [sym__query_body_element] = STATE(4883),
    [sym_preproc_conditional_query] = STATE(4883),
    [sym_query_column] = STATE(4883),
    [sym_query_filter] = STATE(4883),
    [sym_schema_section] = STATE(4883),
    [sym_assembly_declaration] = STATE(4883),
    [sym_event_declaration] = STATE(4883),
    [sym_procedure] = STATE(4883),
    [sym_preproc_split_procedure] = STATE(4883),
    [sym_preproc_split_procedure_preamble] = STATE(4883),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(4883),
    [sym_var_section] = STATE(4883),
    [sym_attribute_item] = STATE(4883),
    [sym_preproc_conditional] = STATE(4883),
    [sym_preproc_if] = STATE(3457),
    [aux_sym_query_dataitem_repeat1] = STATE(4883),
    [anon_sym_SEMI] = ACTIONS(12012),
    [anon_sym_RBRACE] = ACTIONS(8228),
    [anon_sym_LBRACK] = ACTIONS(12015),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12018),
    [aux_sym_modify_modification_token1] = ACTIONS(12021),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12024),
    [anon_sym_POUNDif] = ACTIONS(8225),
    [anon_sym_POUNDIF] = ACTIONS(8225),
    [anon_sym_POUNDIf] = ACTIONS(8225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12027),
    [sym_trigger_keyword] = ACTIONS(12030),
    [sym_var_keyword] = ACTIONS(12033),
    [sym_local_keyword] = ACTIONS(12036),
    [sym_internal_keyword] = ACTIONS(8242),
    [sym_protected_keyword] = ACTIONS(12036),
    [sym_event_keyword] = ACTIONS(12039),
    [sym_fields_keyword] = ACTIONS(12042),
    [sym_keys_keyword] = ACTIONS(12045),
    [sym_fieldgroups_keyword] = ACTIONS(12048),
    [sym_actions_keyword] = ACTIONS(12051),
    [sym_layout_keyword] = ACTIONS(12054),
    [sym_dataset_keyword] = ACTIONS(12057),
    [sym_elements_keyword] = ACTIONS(12060),
    [sym_dataitem_keyword] = ACTIONS(12063),
    [sym_column_keyword] = ACTIONS(12066),
    [sym_filter_keyword] = ACTIONS(12069),
    [sym_labels_keyword] = ACTIONS(12072),
    [sym_rendering_keyword] = ACTIONS(12075),
    [sym_requestpage_keyword] = ACTIONS(12078),
    [sym_schema_keyword] = ACTIONS(12081),
    [sym_views_keyword] = ACTIONS(12084),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12087),
    [sym_preproc_open] = ACTIONS(8225),
  },
  [STATE(4884)] = {
    [sym__body_element] = STATE(4883),
    [sym_empty_statement] = STATE(4883),
    [sym_property] = STATE(4883),
    [sym_permissions_property] = STATE(4883),
    [sym_table_relation_property] = STATE(4883),
    [sym_fields_section] = STATE(4883),
    [sym_keys_section] = STATE(4883),
    [sym_fieldgroups_section] = STATE(4883),
    [sym_enum_value_declaration] = STATE(4883),
    [sym_labels_section] = STATE(4883),
    [sym_layout_section] = STATE(4883),
    [sym_modify_modification] = STATE(4883),
    [sym_actions_section] = STATE(4883),
    [sym_views_section] = STATE(4883),
    [sym_dataset_section] = STATE(4883),
    [sym_requestpage_section] = STATE(4883),
    [sym_rendering_section] = STATE(4883),
    [sym_elements_section] = STATE(4883),
    [sym_query_dataitem] = STATE(4883),
    [sym__query_body_element] = STATE(4883),
    [sym_preproc_conditional_query] = STATE(4883),
    [sym_query_column] = STATE(4883),
    [sym_query_filter] = STATE(4883),
    [sym_schema_section] = STATE(4883),
    [sym_assembly_declaration] = STATE(4883),
    [sym_event_declaration] = STATE(4883),
    [sym_procedure] = STATE(4883),
    [sym_preproc_split_procedure] = STATE(4883),
    [sym_preproc_split_procedure_preamble] = STATE(4883),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(4883),
    [sym_var_section] = STATE(4883),
    [sym_attribute_item] = STATE(4883),
    [sym_preproc_conditional] = STATE(4883),
    [sym_preproc_if] = STATE(3457),
    [aux_sym_query_dataitem_repeat1] = STATE(4883),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12090),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12096),
    [sym_column_keyword] = ACTIONS(12098),
    [sym_filter_keyword] = ACTIONS(12100),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(4885)] = {
    [sym_preproc_split_procedure] = STATE(4879),
    [sym_var_attribute_item] = STATE(4879),
    [sym_preproc_conditional_var] = STATE(4879),
    [sym_variable_declaration] = STATE(4879),
    [sym_preproc_if] = STATE(3151),
    [sym__identifier_or_quoted] = STATE(15532),
    [sym_keyword_as_identifier] = STATE(15532),
    [aux_sym_var_section_repeat1] = STATE(4879),
    [sym_identifier] = ACTIONS(12006),
    [anon_sym_SEMI] = ACTIONS(8296),
    [anon_sym_RBRACE] = ACTIONS(8296),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8298),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8298),
    [anon_sym_LBRACK] = ACTIONS(8296),
    [aux_sym_basic_type_token6] = ACTIONS(8298),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_addafter_modification_token1] = ACTIONS(8298),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8298),
    [aux_sym_modify_modification_token1] = ACTIONS(8298),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8298),
    [aux_sym_movelast_modification_token1] = ACTIONS(8298),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8298),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8298),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8298),
    [sym_trigger_keyword] = ACTIONS(8298),
    [sym_var_keyword] = ACTIONS(8298),
    [sym_local_keyword] = ACTIONS(8298),
    [sym_internal_keyword] = ACTIONS(8298),
    [sym_protected_keyword] = ACTIONS(8298),
    [sym_event_keyword] = ACTIONS(8298),
    [sym_fields_keyword] = ACTIONS(8298),
    [sym_keys_keyword] = ACTIONS(8298),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8298),
    [sym_actions_keyword] = ACTIONS(8298),
    [sym_layout_keyword] = ACTIONS(8298),
    [sym_area_keyword] = ACTIONS(8298),
    [sym_group_keyword] = ACTIONS(8298),
    [sym_repeater_keyword] = ACTIONS(8298),
    [sym_cuegroup_keyword] = ACTIONS(8298),
    [sym_fixed_keyword] = ACTIONS(8298),
    [sym_grid_keyword] = ACTIONS(8298),
    [sym_part_keyword] = ACTIONS(8298),
    [sym_systempart_keyword] = ACTIONS(8298),
    [sym_usercontrol_keyword] = ACTIONS(8298),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8298),
    [sym_dataitem_keyword] = ACTIONS(8298),
    [sym_column_keyword] = ACTIONS(8298),
    [sym_filter_keyword] = ACTIONS(8298),
    [sym_labels_keyword] = ACTIONS(8298),
    [sym_rendering_keyword] = ACTIONS(8298),
    [sym_requestpage_keyword] = ACTIONS(8298),
    [sym_schema_keyword] = ACTIONS(8298),
    [sym_views_keyword] = ACTIONS(8298),
    [sym_quoted_identifier] = ACTIONS(12008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8296),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_var_attribute_open] = ACTIONS(12010),
  },
  [STATE(4886)] = {
    [sym__body_element] = STATE(4892),
    [sym_empty_statement] = STATE(4892),
    [sym_property] = STATE(4892),
    [sym_permissions_property] = STATE(4892),
    [sym_table_relation_property] = STATE(4892),
    [sym_fields_section] = STATE(4892),
    [sym_keys_section] = STATE(4892),
    [sym_fieldgroups_section] = STATE(4892),
    [sym_enum_value_declaration] = STATE(4892),
    [sym_labels_section] = STATE(4892),
    [sym_layout_section] = STATE(4892),
    [sym_modify_modification] = STATE(4892),
    [sym_actions_section] = STATE(4892),
    [sym_views_section] = STATE(4892),
    [sym_dataset_section] = STATE(4892),
    [sym_requestpage_section] = STATE(4892),
    [sym_rendering_section] = STATE(4892),
    [sym_elements_section] = STATE(4892),
    [sym_query_dataitem] = STATE(4892),
    [sym__query_body_element] = STATE(4892),
    [sym_preproc_conditional_query] = STATE(4892),
    [sym_query_column] = STATE(4892),
    [sym_query_filter] = STATE(4892),
    [sym_schema_section] = STATE(4892),
    [sym_assembly_declaration] = STATE(4892),
    [sym_event_declaration] = STATE(4892),
    [sym_procedure] = STATE(4892),
    [sym_preproc_split_procedure] = STATE(4892),
    [sym_preproc_split_procedure_preamble] = STATE(4892),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(4892),
    [sym_var_section] = STATE(4892),
    [sym_attribute_item] = STATE(4892),
    [sym_preproc_conditional] = STATE(4892),
    [sym_preproc_if] = STATE(3457),
    [aux_sym_query_dataitem_repeat1] = STATE(4892),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12104),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12096),
    [sym_column_keyword] = ACTIONS(12098),
    [sym_filter_keyword] = ACTIONS(12100),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(4887)] = {
    [sym__body_element] = STATE(4888),
    [sym_empty_statement] = STATE(4888),
    [sym_property] = STATE(4888),
    [sym_permissions_property] = STATE(4888),
    [sym_table_relation_property] = STATE(4888),
    [sym_fields_section] = STATE(4888),
    [sym_keys_section] = STATE(4888),
    [sym_fieldgroups_section] = STATE(4888),
    [sym_enum_value_declaration] = STATE(4888),
    [sym_labels_section] = STATE(4888),
    [sym_layout_section] = STATE(4888),
    [sym_modify_modification] = STATE(4888),
    [sym_actions_section] = STATE(4888),
    [sym_views_section] = STATE(4888),
    [sym_dataset_section] = STATE(4888),
    [sym_requestpage_section] = STATE(4888),
    [sym_rendering_section] = STATE(4888),
    [sym_elements_section] = STATE(4888),
    [sym_query_dataitem] = STATE(4888),
    [sym__query_body_element] = STATE(4888),
    [sym_preproc_conditional_query] = STATE(4888),
    [sym_query_column] = STATE(4888),
    [sym_query_filter] = STATE(4888),
    [sym_schema_section] = STATE(4888),
    [sym_assembly_declaration] = STATE(4888),
    [sym_event_declaration] = STATE(4888),
    [sym_procedure] = STATE(4888),
    [sym_preproc_split_procedure] = STATE(4888),
    [sym_preproc_split_procedure_preamble] = STATE(4888),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(4888),
    [sym_var_section] = STATE(4888),
    [sym_attribute_item] = STATE(4888),
    [sym_preproc_conditional] = STATE(4888),
    [sym_preproc_if] = STATE(3457),
    [aux_sym_query_dataitem_repeat1] = STATE(4888),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12106),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12096),
    [sym_column_keyword] = ACTIONS(12098),
    [sym_filter_keyword] = ACTIONS(12100),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(4888)] = {
    [sym__body_element] = STATE(4883),
    [sym_empty_statement] = STATE(4883),
    [sym_property] = STATE(4883),
    [sym_permissions_property] = STATE(4883),
    [sym_table_relation_property] = STATE(4883),
    [sym_fields_section] = STATE(4883),
    [sym_keys_section] = STATE(4883),
    [sym_fieldgroups_section] = STATE(4883),
    [sym_enum_value_declaration] = STATE(4883),
    [sym_labels_section] = STATE(4883),
    [sym_layout_section] = STATE(4883),
    [sym_modify_modification] = STATE(4883),
    [sym_actions_section] = STATE(4883),
    [sym_views_section] = STATE(4883),
    [sym_dataset_section] = STATE(4883),
    [sym_requestpage_section] = STATE(4883),
    [sym_rendering_section] = STATE(4883),
    [sym_elements_section] = STATE(4883),
    [sym_query_dataitem] = STATE(4883),
    [sym__query_body_element] = STATE(4883),
    [sym_preproc_conditional_query] = STATE(4883),
    [sym_query_column] = STATE(4883),
    [sym_query_filter] = STATE(4883),
    [sym_schema_section] = STATE(4883),
    [sym_assembly_declaration] = STATE(4883),
    [sym_event_declaration] = STATE(4883),
    [sym_procedure] = STATE(4883),
    [sym_preproc_split_procedure] = STATE(4883),
    [sym_preproc_split_procedure_preamble] = STATE(4883),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(4883),
    [sym_var_section] = STATE(4883),
    [sym_attribute_item] = STATE(4883),
    [sym_preproc_conditional] = STATE(4883),
    [sym_preproc_if] = STATE(3457),
    [aux_sym_query_dataitem_repeat1] = STATE(4883),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12108),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12096),
    [sym_column_keyword] = ACTIONS(12098),
    [sym_filter_keyword] = ACTIONS(12100),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(4889)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6482),
    [sym_preproc_endif] = STATE(5411),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10839),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(4890)] = {
    [sym__body_element] = STATE(4884),
    [sym_empty_statement] = STATE(4884),
    [sym_property] = STATE(4884),
    [sym_permissions_property] = STATE(4884),
    [sym_table_relation_property] = STATE(4884),
    [sym_fields_section] = STATE(4884),
    [sym_keys_section] = STATE(4884),
    [sym_fieldgroups_section] = STATE(4884),
    [sym_enum_value_declaration] = STATE(4884),
    [sym_labels_section] = STATE(4884),
    [sym_layout_section] = STATE(4884),
    [sym_modify_modification] = STATE(4884),
    [sym_actions_section] = STATE(4884),
    [sym_views_section] = STATE(4884),
    [sym_dataset_section] = STATE(4884),
    [sym_requestpage_section] = STATE(4884),
    [sym_rendering_section] = STATE(4884),
    [sym_elements_section] = STATE(4884),
    [sym_query_dataitem] = STATE(4884),
    [sym__query_body_element] = STATE(4884),
    [sym_preproc_conditional_query] = STATE(4884),
    [sym_query_column] = STATE(4884),
    [sym_query_filter] = STATE(4884),
    [sym_schema_section] = STATE(4884),
    [sym_assembly_declaration] = STATE(4884),
    [sym_event_declaration] = STATE(4884),
    [sym_procedure] = STATE(4884),
    [sym_preproc_split_procedure] = STATE(4884),
    [sym_preproc_split_procedure_preamble] = STATE(4884),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(4884),
    [sym_var_section] = STATE(4884),
    [sym_attribute_item] = STATE(4884),
    [sym_preproc_conditional] = STATE(4884),
    [sym_preproc_if] = STATE(3457),
    [aux_sym_query_dataitem_repeat1] = STATE(4884),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12110),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12096),
    [sym_column_keyword] = ACTIONS(12098),
    [sym_filter_keyword] = ACTIONS(12100),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(4891)] = {
    [anon_sym_SEMI] = ACTIONS(8379),
    [anon_sym_COMMA] = ACTIONS(12112),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8379),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8379),
    [anon_sym_LBRACK] = ACTIONS(8379),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8379),
    [aux_sym_modify_modification_token1] = ACTIONS(8379),
    [aux_sym_xmlport_element_token1] = ACTIONS(8379),
    [aux_sym_xmlport_element_token2] = ACTIONS(8379),
    [aux_sym_xmlport_element_token3] = ACTIONS(8379),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8379),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8379),
    [anon_sym_POUNDif] = ACTIONS(8379),
    [anon_sym_POUNDIF] = ACTIONS(8379),
    [anon_sym_POUNDIf] = ACTIONS(8379),
    [anon_sym_POUNDelif] = ACTIONS(8379),
    [anon_sym_POUNDELIF] = ACTIONS(8379),
    [anon_sym_POUNDElif] = ACTIONS(8379),
    [anon_sym_POUNDelse] = ACTIONS(8379),
    [anon_sym_POUNDELSE] = ACTIONS(8379),
    [anon_sym_POUNDElse] = ACTIONS(8379),
    [anon_sym_POUNDelse2] = ACTIONS(8379),
    [anon_sym_POUNDELSE2] = ACTIONS(8379),
    [anon_sym_POUNDElse2] = ACTIONS(8379),
    [anon_sym_POUNDendif] = ACTIONS(8379),
    [anon_sym_POUNDENDIF] = ACTIONS(8379),
    [anon_sym_POUNDEndif] = ACTIONS(8379),
    [anon_sym_POUNDendif2] = ACTIONS(8379),
    [anon_sym_POUNDENDIF2] = ACTIONS(8379),
    [anon_sym_POUNDEndif2] = ACTIONS(8379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8383),
    [sym_page_keyword] = ACTIONS(8379),
    [anon_sym_codeunit] = ACTIONS(8379),
    [anon_sym_CODEUNIT] = ACTIONS(8379),
    [anon_sym_Codeunit] = ACTIONS(8379),
    [anon_sym_CodeUnit] = ACTIONS(8379),
    [anon_sym_COdeunit] = ACTIONS(8379),
    [anon_sym_codeUnit] = ACTIONS(8379),
    [sym_report_keyword] = ACTIONS(8379),
    [sym_query_keyword] = ACTIONS(8379),
    [anon_sym_xmlport] = ACTIONS(8379),
    [anon_sym_XMLPORT] = ACTIONS(8379),
    [anon_sym_Xmlport] = ACTIONS(8379),
    [anon_sym_XMLport] = ACTIONS(8379),
    [anon_sym_XMLPort] = ACTIONS(8379),
    [anon_sym_XmlPort] = ACTIONS(8379),
    [sym_procedure_keyword] = ACTIONS(8379),
    [sym_trigger_keyword] = ACTIONS(8379),
    [sym_var_keyword] = ACTIONS(8379),
    [sym_local_keyword] = ACTIONS(8379),
    [sym_internal_keyword] = ACTIONS(8379),
    [sym_protected_keyword] = ACTIONS(8379),
    [sym_event_keyword] = ACTIONS(8379),
    [sym_fields_keyword] = ACTIONS(8379),
    [sym_keys_keyword] = ACTIONS(8379),
    [sym_fieldgroups_keyword] = ACTIONS(8379),
    [sym_actions_keyword] = ACTIONS(8379),
    [sym_layout_keyword] = ACTIONS(8379),
    [sym_dataset_keyword] = ACTIONS(8379),
    [sym_elements_keyword] = ACTIONS(8379),
    [sym_labels_keyword] = ACTIONS(8379),
    [sym_rendering_keyword] = ACTIONS(8379),
    [sym_requestpage_keyword] = ACTIONS(8379),
    [sym_schema_keyword] = ACTIONS(8379),
    [sym_views_keyword] = ACTIONS(8379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8379),
    [sym_preproc_open] = ACTIONS(8379),
    [sym_preproc_close] = ACTIONS(8379),
  },
  [STATE(4892)] = {
    [sym__body_element] = STATE(4883),
    [sym_empty_statement] = STATE(4883),
    [sym_property] = STATE(4883),
    [sym_permissions_property] = STATE(4883),
    [sym_table_relation_property] = STATE(4883),
    [sym_fields_section] = STATE(4883),
    [sym_keys_section] = STATE(4883),
    [sym_fieldgroups_section] = STATE(4883),
    [sym_enum_value_declaration] = STATE(4883),
    [sym_labels_section] = STATE(4883),
    [sym_layout_section] = STATE(4883),
    [sym_modify_modification] = STATE(4883),
    [sym_actions_section] = STATE(4883),
    [sym_views_section] = STATE(4883),
    [sym_dataset_section] = STATE(4883),
    [sym_requestpage_section] = STATE(4883),
    [sym_rendering_section] = STATE(4883),
    [sym_elements_section] = STATE(4883),
    [sym_query_dataitem] = STATE(4883),
    [sym__query_body_element] = STATE(4883),
    [sym_preproc_conditional_query] = STATE(4883),
    [sym_query_column] = STATE(4883),
    [sym_query_filter] = STATE(4883),
    [sym_schema_section] = STATE(4883),
    [sym_assembly_declaration] = STATE(4883),
    [sym_event_declaration] = STATE(4883),
    [sym_procedure] = STATE(4883),
    [sym_preproc_split_procedure] = STATE(4883),
    [sym_preproc_split_procedure_preamble] = STATE(4883),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(4883),
    [sym_var_section] = STATE(4883),
    [sym_attribute_item] = STATE(4883),
    [sym_preproc_conditional] = STATE(4883),
    [sym_preproc_if] = STATE(3457),
    [aux_sym_query_dataitem_repeat1] = STATE(4883),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12114),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12096),
    [sym_column_keyword] = ACTIONS(12098),
    [sym_filter_keyword] = ACTIONS(12100),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(4893)] = {
    [sym_identifier] = ACTIONS(12116),
    [anon_sym_COLON] = ACTIONS(12119),
    [anon_sym_DASH] = ACTIONS(12121),
    [aux_sym_boolean_token1] = ACTIONS(12116),
    [aux_sym_boolean_token2] = ACTIONS(12116),
    [sym_decimal] = ACTIONS(12116),
    [anon_sym_LPAREN] = ACTIONS(12121),
    [aux_sym_tabledata_permission_token2] = ACTIONS(12116),
    [anon_sym_LBRACK] = ACTIONS(12121),
    [aux_sym_record_type_token1] = ACTIONS(12116),
    [aux_sym_basic_type_token21] = ACTIONS(12116),
    [aux_sym_basic_type_token22] = ACTIONS(12116),
    [aux_sym_basic_type_token48] = ACTIONS(12116),
    [anon_sym_POUNDif] = ACTIONS(12119),
    [anon_sym_POUNDIF] = ACTIONS(12119),
    [anon_sym_POUNDIf] = ACTIONS(12119),
    [anon_sym_not] = ACTIONS(12116),
    [anon_sym_NOT] = ACTIONS(12116),
    [anon_sym_Not] = ACTIONS(12116),
    [anon_sym_POUNDelif] = ACTIONS(12124),
    [anon_sym_POUNDELIF] = ACTIONS(12124),
    [anon_sym_POUNDElif] = ACTIONS(12124),
    [anon_sym_POUNDelse] = ACTIONS(12124),
    [anon_sym_POUNDELSE] = ACTIONS(12124),
    [anon_sym_POUNDElse] = ACTIONS(12124),
    [anon_sym_POUNDelse2] = ACTIONS(12124),
    [anon_sym_POUNDELSE2] = ACTIONS(12124),
    [anon_sym_POUNDElse2] = ACTIONS(12124),
    [anon_sym_POUNDendif] = ACTIONS(12124),
    [anon_sym_POUNDENDIF] = ACTIONS(12124),
    [anon_sym_POUNDEndif] = ACTIONS(12124),
    [anon_sym_POUNDendif2] = ACTIONS(12124),
    [anon_sym_POUNDENDIF2] = ACTIONS(12124),
    [anon_sym_POUNDEndif2] = ACTIONS(12124),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(12116),
    [aux_sym_keyword_identifier_token2] = ACTIONS(12116),
    [anon_sym_PLUS] = ACTIONS(12121),
    [sym_datetime_literal] = ACTIONS(12121),
    [sym_date_literal] = ACTIONS(12116),
    [sym_time_literal] = ACTIONS(12116),
    [sym_biginteger_literal] = ACTIONS(12121),
    [sym_page_keyword] = ACTIONS(12116),
    [anon_sym_codeunit] = ACTIONS(12116),
    [anon_sym_CODEUNIT] = ACTIONS(12116),
    [anon_sym_Codeunit] = ACTIONS(12116),
    [anon_sym_CodeUnit] = ACTIONS(12116),
    [anon_sym_COdeunit] = ACTIONS(12116),
    [anon_sym_codeUnit] = ACTIONS(12116),
    [sym_report_keyword] = ACTIONS(12116),
    [sym_query_keyword] = ACTIONS(12116),
    [anon_sym_xmlport] = ACTIONS(12116),
    [anon_sym_XMLPORT] = ACTIONS(12116),
    [anon_sym_Xmlport] = ACTIONS(12116),
    [anon_sym_XMLport] = ACTIONS(12116),
    [anon_sym_XMLPort] = ACTIONS(12116),
    [anon_sym_XmlPort] = ACTIONS(12116),
    [anon_sym_enum] = ACTIONS(12116),
    [anon_sym_ENUM] = ACTIONS(12116),
    [anon_sym_Enum] = ACTIONS(12116),
    [anon_sym_eNUM] = ACTIONS(12116),
    [anon_sym_eNum] = ACTIONS(12116),
    [anon_sym_ENum] = ACTIONS(12116),
    [sym_quoted_identifier] = ACTIONS(12121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(12121),
    [sym_verbatim_string] = ACTIONS(12121),
    [sym_integer] = ACTIONS(12116),
    [sym_continue_as_identifier] = ACTIONS(12121),
    [sym_preproc_open] = ACTIONS(12119),
    [sym_preproc_close] = ACTIONS(12124),
  },
  [STATE(4894)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6505),
    [sym_preproc_endif] = STATE(7988),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10908),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(4895)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_elif] = STATE(5341),
    [sym_preproc_else] = STATE(6515),
    [sym_preproc_endif] = STATE(8610),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_preproc_conditional_layout_repeat1] = STATE(10988),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(9798),
    [anon_sym_POUNDELIF] = ACTIONS(9798),
    [anon_sym_POUNDElif] = ACTIONS(9798),
    [anon_sym_POUNDelse] = ACTIONS(9800),
    [anon_sym_POUNDELSE] = ACTIONS(9800),
    [anon_sym_POUNDElse] = ACTIONS(9800),
    [anon_sym_POUNDelse2] = ACTIONS(9800),
    [anon_sym_POUNDELSE2] = ACTIONS(9800),
    [anon_sym_POUNDElse2] = ACTIONS(9800),
    [anon_sym_POUNDendif] = ACTIONS(11226),
    [anon_sym_POUNDENDIF] = ACTIONS(11226),
    [anon_sym_POUNDEndif] = ACTIONS(11226),
    [anon_sym_POUNDendif2] = ACTIONS(11226),
    [anon_sym_POUNDENDIF2] = ACTIONS(11226),
    [anon_sym_POUNDEndif2] = ACTIONS(11226),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(11226),
  },
  [STATE(4896)] = {
    [anon_sym_SEMI] = ACTIONS(8333),
    [anon_sym_COMMA] = ACTIONS(8333),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8333),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8333),
    [anon_sym_LBRACK] = ACTIONS(8333),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8333),
    [aux_sym_modify_modification_token1] = ACTIONS(8333),
    [aux_sym_xmlport_element_token1] = ACTIONS(8333),
    [aux_sym_xmlport_element_token2] = ACTIONS(8333),
    [aux_sym_xmlport_element_token3] = ACTIONS(8333),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8333),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8333),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8333),
    [anon_sym_POUNDif] = ACTIONS(8333),
    [anon_sym_POUNDIF] = ACTIONS(8333),
    [anon_sym_POUNDIf] = ACTIONS(8333),
    [anon_sym_POUNDelif] = ACTIONS(8333),
    [anon_sym_POUNDELIF] = ACTIONS(8333),
    [anon_sym_POUNDElif] = ACTIONS(8333),
    [anon_sym_POUNDelse] = ACTIONS(8333),
    [anon_sym_POUNDELSE] = ACTIONS(8333),
    [anon_sym_POUNDElse] = ACTIONS(8333),
    [anon_sym_POUNDelse2] = ACTIONS(8333),
    [anon_sym_POUNDELSE2] = ACTIONS(8333),
    [anon_sym_POUNDElse2] = ACTIONS(8333),
    [anon_sym_POUNDendif] = ACTIONS(8333),
    [anon_sym_POUNDENDIF] = ACTIONS(8333),
    [anon_sym_POUNDEndif] = ACTIONS(8333),
    [anon_sym_POUNDendif2] = ACTIONS(8333),
    [anon_sym_POUNDENDIF2] = ACTIONS(8333),
    [anon_sym_POUNDEndif2] = ACTIONS(8333),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8335),
    [sym_page_keyword] = ACTIONS(8333),
    [anon_sym_codeunit] = ACTIONS(8333),
    [anon_sym_CODEUNIT] = ACTIONS(8333),
    [anon_sym_Codeunit] = ACTIONS(8333),
    [anon_sym_CodeUnit] = ACTIONS(8333),
    [anon_sym_COdeunit] = ACTIONS(8333),
    [anon_sym_codeUnit] = ACTIONS(8333),
    [sym_report_keyword] = ACTIONS(8333),
    [sym_query_keyword] = ACTIONS(8333),
    [anon_sym_xmlport] = ACTIONS(8333),
    [anon_sym_XMLPORT] = ACTIONS(8333),
    [anon_sym_Xmlport] = ACTIONS(8333),
    [anon_sym_XMLport] = ACTIONS(8333),
    [anon_sym_XMLPort] = ACTIONS(8333),
    [anon_sym_XmlPort] = ACTIONS(8333),
    [sym_procedure_keyword] = ACTIONS(8333),
    [sym_trigger_keyword] = ACTIONS(8333),
    [sym_var_keyword] = ACTIONS(8333),
    [sym_local_keyword] = ACTIONS(8333),
    [sym_internal_keyword] = ACTIONS(8333),
    [sym_protected_keyword] = ACTIONS(8333),
    [sym_event_keyword] = ACTIONS(8333),
    [sym_fields_keyword] = ACTIONS(8333),
    [sym_keys_keyword] = ACTIONS(8333),
    [sym_fieldgroups_keyword] = ACTIONS(8333),
    [sym_actions_keyword] = ACTIONS(8333),
    [sym_layout_keyword] = ACTIONS(8333),
    [sym_dataset_keyword] = ACTIONS(8333),
    [sym_elements_keyword] = ACTIONS(8333),
    [sym_labels_keyword] = ACTIONS(8333),
    [sym_rendering_keyword] = ACTIONS(8333),
    [sym_requestpage_keyword] = ACTIONS(8333),
    [sym_schema_keyword] = ACTIONS(8333),
    [sym_views_keyword] = ACTIONS(8333),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8333),
    [sym_preproc_open] = ACTIONS(8333),
    [sym_preproc_close] = ACTIONS(8333),
  },
  [STATE(4897)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5960),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4898)] = {
    [sym_identifier] = ACTIONS(5370),
    [anon_sym_DASH] = ACTIONS(5372),
    [aux_sym_boolean_token1] = ACTIONS(5370),
    [aux_sym_boolean_token2] = ACTIONS(5370),
    [sym_decimal] = ACTIONS(5370),
    [anon_sym_LPAREN] = ACTIONS(5372),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5370),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [aux_sym_record_type_token1] = ACTIONS(5370),
    [aux_sym_basic_type_token21] = ACTIONS(5370),
    [aux_sym_basic_type_token22] = ACTIONS(5370),
    [aux_sym_basic_type_token48] = ACTIONS(5370),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(12126),
    [anon_sym_PIPE_PIPE] = ACTIONS(12128),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(12130),
    [anon_sym_AMP_AMP] = ACTIONS(12132),
    [anon_sym_not] = ACTIONS(5370),
    [anon_sym_NOT] = ACTIONS(5370),
    [anon_sym_Not] = ACTIONS(5370),
    [anon_sym_POUNDelif] = ACTIONS(5372),
    [anon_sym_POUNDELIF] = ACTIONS(5372),
    [anon_sym_POUNDElif] = ACTIONS(5372),
    [anon_sym_POUNDelse] = ACTIONS(5372),
    [anon_sym_POUNDELSE] = ACTIONS(5372),
    [anon_sym_POUNDElse] = ACTIONS(5372),
    [anon_sym_POUNDelse2] = ACTIONS(5372),
    [anon_sym_POUNDELSE2] = ACTIONS(5372),
    [anon_sym_POUNDElse2] = ACTIONS(5372),
    [anon_sym_POUNDendif] = ACTIONS(5372),
    [anon_sym_POUNDENDIF] = ACTIONS(5372),
    [anon_sym_POUNDEndif] = ACTIONS(5372),
    [anon_sym_POUNDendif2] = ACTIONS(5372),
    [anon_sym_POUNDENDIF2] = ACTIONS(5372),
    [anon_sym_POUNDEndif2] = ACTIONS(5372),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5370),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5370),
    [anon_sym_PLUS] = ACTIONS(5372),
    [sym_datetime_literal] = ACTIONS(5372),
    [sym_date_literal] = ACTIONS(5370),
    [sym_time_literal] = ACTIONS(5370),
    [sym_biginteger_literal] = ACTIONS(5372),
    [sym_page_keyword] = ACTIONS(5370),
    [anon_sym_codeunit] = ACTIONS(5370),
    [anon_sym_CODEUNIT] = ACTIONS(5370),
    [anon_sym_Codeunit] = ACTIONS(5370),
    [anon_sym_CodeUnit] = ACTIONS(5370),
    [anon_sym_COdeunit] = ACTIONS(5370),
    [anon_sym_codeUnit] = ACTIONS(5370),
    [sym_report_keyword] = ACTIONS(5370),
    [sym_query_keyword] = ACTIONS(5370),
    [anon_sym_xmlport] = ACTIONS(5370),
    [anon_sym_XMLPORT] = ACTIONS(5370),
    [anon_sym_Xmlport] = ACTIONS(5370),
    [anon_sym_XMLport] = ACTIONS(5370),
    [anon_sym_XMLPort] = ACTIONS(5370),
    [anon_sym_XmlPort] = ACTIONS(5370),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_ENUM] = ACTIONS(5370),
    [anon_sym_Enum] = ACTIONS(5370),
    [anon_sym_eNUM] = ACTIONS(5370),
    [anon_sym_eNum] = ACTIONS(5370),
    [anon_sym_ENum] = ACTIONS(5370),
    [sym_quoted_identifier] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5372),
    [sym_verbatim_string] = ACTIONS(5372),
    [sym_integer] = ACTIONS(5370),
    [sym_continue_as_identifier] = ACTIONS(5372),
    [sym_preproc_close] = ACTIONS(5372),
  },
  [STATE(4899)] = {
    [sym_identifier] = ACTIONS(5374),
    [anon_sym_DASH] = ACTIONS(5376),
    [aux_sym_boolean_token1] = ACTIONS(5374),
    [aux_sym_boolean_token2] = ACTIONS(5374),
    [sym_decimal] = ACTIONS(5374),
    [anon_sym_LPAREN] = ACTIONS(5376),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5374),
    [anon_sym_LBRACK] = ACTIONS(5376),
    [aux_sym_record_type_token1] = ACTIONS(5374),
    [aux_sym_basic_type_token21] = ACTIONS(5374),
    [aux_sym_basic_type_token22] = ACTIONS(5374),
    [aux_sym_basic_type_token48] = ACTIONS(5374),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5374),
    [anon_sym_PIPE_PIPE] = ACTIONS(5376),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5374),
    [anon_sym_AMP_AMP] = ACTIONS(5376),
    [anon_sym_not] = ACTIONS(5374),
    [anon_sym_NOT] = ACTIONS(5374),
    [anon_sym_Not] = ACTIONS(5374),
    [anon_sym_POUNDelif] = ACTIONS(5376),
    [anon_sym_POUNDELIF] = ACTIONS(5376),
    [anon_sym_POUNDElif] = ACTIONS(5376),
    [anon_sym_POUNDelse] = ACTIONS(5376),
    [anon_sym_POUNDELSE] = ACTIONS(5376),
    [anon_sym_POUNDElse] = ACTIONS(5376),
    [anon_sym_POUNDelse2] = ACTIONS(5376),
    [anon_sym_POUNDELSE2] = ACTIONS(5376),
    [anon_sym_POUNDElse2] = ACTIONS(5376),
    [anon_sym_POUNDendif] = ACTIONS(5376),
    [anon_sym_POUNDENDIF] = ACTIONS(5376),
    [anon_sym_POUNDEndif] = ACTIONS(5376),
    [anon_sym_POUNDendif2] = ACTIONS(5376),
    [anon_sym_POUNDENDIF2] = ACTIONS(5376),
    [anon_sym_POUNDEndif2] = ACTIONS(5376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5374),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5374),
    [anon_sym_PLUS] = ACTIONS(5376),
    [sym_datetime_literal] = ACTIONS(5376),
    [sym_date_literal] = ACTIONS(5374),
    [sym_time_literal] = ACTIONS(5374),
    [sym_biginteger_literal] = ACTIONS(5376),
    [sym_page_keyword] = ACTIONS(5374),
    [anon_sym_codeunit] = ACTIONS(5374),
    [anon_sym_CODEUNIT] = ACTIONS(5374),
    [anon_sym_Codeunit] = ACTIONS(5374),
    [anon_sym_CodeUnit] = ACTIONS(5374),
    [anon_sym_COdeunit] = ACTIONS(5374),
    [anon_sym_codeUnit] = ACTIONS(5374),
    [sym_report_keyword] = ACTIONS(5374),
    [sym_query_keyword] = ACTIONS(5374),
    [anon_sym_xmlport] = ACTIONS(5374),
    [anon_sym_XMLPORT] = ACTIONS(5374),
    [anon_sym_Xmlport] = ACTIONS(5374),
    [anon_sym_XMLport] = ACTIONS(5374),
    [anon_sym_XMLPort] = ACTIONS(5374),
    [anon_sym_XmlPort] = ACTIONS(5374),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_ENUM] = ACTIONS(5374),
    [anon_sym_Enum] = ACTIONS(5374),
    [anon_sym_eNUM] = ACTIONS(5374),
    [anon_sym_eNum] = ACTIONS(5374),
    [anon_sym_ENum] = ACTIONS(5374),
    [sym_quoted_identifier] = ACTIONS(5376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5376),
    [sym_verbatim_string] = ACTIONS(5376),
    [sym_integer] = ACTIONS(5374),
    [sym_continue_as_identifier] = ACTIONS(5376),
    [sym_preproc_close] = ACTIONS(5376),
  },
  [STATE(4900)] = {
    [sym__object_header] = STATE(13586),
    [sym_preproc_if] = STATE(5429),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [anon_sym_POUNDif] = ACTIONS(12134),
    [anon_sym_POUNDIF] = ACTIONS(12134),
    [anon_sym_POUNDIf] = ACTIONS(12134),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(12134),
  },
  [STATE(4901)] = {
    [sym_preproc_split_procedure] = STATE(4901),
    [sym_var_attribute_item] = STATE(4901),
    [sym_preproc_conditional_var] = STATE(4901),
    [sym_variable_declaration] = STATE(4901),
    [sym_preproc_if] = STATE(3167),
    [sym__identifier_or_quoted] = STATE(15929),
    [sym_keyword_as_identifier] = STATE(15929),
    [aux_sym_var_section_repeat1] = STATE(4901),
    [sym_identifier] = ACTIONS(12142),
    [anon_sym_SEMI] = ACTIONS(8313),
    [aux_sym_where_condition_token1] = ACTIONS(8315),
    [anon_sym_LBRACK] = ACTIONS(8313),
    [aux_sym_basic_type_token22] = ACTIONS(8315),
    [aux_sym_basic_type_token53] = ACTIONS(8315),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8315),
    [aux_sym_modify_modification_token1] = ACTIONS(8318),
    [aux_sym_separator_action_token1] = ACTIONS(8315),
    [aux_sym_xmlport_element_token1] = ACTIONS(8318),
    [aux_sym_xmlport_element_token2] = ACTIONS(8318),
    [aux_sym_xmlport_element_token3] = ACTIONS(8318),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8318),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8318),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8315),
    [aux_sym_type_declaration_token1] = ACTIONS(8315),
    [anon_sym_POUNDif] = ACTIONS(8320),
    [anon_sym_POUNDIF] = ACTIONS(8320),
    [anon_sym_POUNDIf] = ACTIONS(8320),
    [anon_sym_POUNDelif] = ACTIONS(8313),
    [anon_sym_POUNDELIF] = ACTIONS(8313),
    [anon_sym_POUNDElif] = ACTIONS(8313),
    [anon_sym_POUNDelse] = ACTIONS(8313),
    [anon_sym_POUNDELSE] = ACTIONS(8313),
    [anon_sym_POUNDElse] = ACTIONS(8313),
    [anon_sym_POUNDelse2] = ACTIONS(8313),
    [anon_sym_POUNDELSE2] = ACTIONS(8313),
    [anon_sym_POUNDElse2] = ACTIONS(8313),
    [anon_sym_POUNDendif] = ACTIONS(8313),
    [anon_sym_POUNDENDIF] = ACTIONS(8313),
    [anon_sym_POUNDEndif] = ACTIONS(8313),
    [anon_sym_POUNDendif2] = ACTIONS(8313),
    [anon_sym_POUNDENDIF2] = ACTIONS(8313),
    [anon_sym_POUNDEndif2] = ACTIONS(8313),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8315),
    [sym_procedure_keyword] = ACTIONS(8318),
    [sym_trigger_keyword] = ACTIONS(8318),
    [sym_var_keyword] = ACTIONS(8318),
    [sym_local_keyword] = ACTIONS(8318),
    [sym_internal_keyword] = ACTIONS(8318),
    [sym_protected_keyword] = ACTIONS(8318),
    [sym_event_keyword] = ACTIONS(8318),
    [sym_fields_keyword] = ACTIONS(8318),
    [sym_keys_keyword] = ACTIONS(8318),
    [sym_key_keyword] = ACTIONS(8315),
    [sym_fieldgroups_keyword] = ACTIONS(8318),
    [sym_actions_keyword] = ACTIONS(8318),
    [sym_layout_keyword] = ACTIONS(8318),
    [sym_dataset_keyword] = ACTIONS(8315),
    [sym_elements_keyword] = ACTIONS(8318),
    [sym_labels_keyword] = ACTIONS(8318),
    [sym_rendering_keyword] = ACTIONS(8318),
    [sym_requestpage_keyword] = ACTIONS(8318),
    [sym_schema_keyword] = ACTIONS(8318),
    [sym_views_keyword] = ACTIONS(8318),
    [sym_quoted_identifier] = ACTIONS(12145),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8313),
    [sym_preproc_open] = ACTIONS(8320),
    [sym_preproc_close] = ACTIONS(8313),
    [sym_var_attribute_open] = ACTIONS(12148),
  },
  [STATE(4902)] = {
    [sym__body_element] = STATE(4938),
    [sym_empty_statement] = STATE(4938),
    [sym_property] = STATE(4938),
    [sym_permissions_property] = STATE(4938),
    [sym_table_relation_property] = STATE(4938),
    [sym_fields_section] = STATE(4938),
    [sym_keys_section] = STATE(4938),
    [sym_fieldgroups_section] = STATE(4938),
    [sym_enum_value_declaration] = STATE(4938),
    [sym_labels_section] = STATE(4938),
    [sym_layout_section] = STATE(4938),
    [sym_modify_modification] = STATE(4938),
    [sym_actions_section] = STATE(4938),
    [sym_views_section] = STATE(4938),
    [sym_dataset_section] = STATE(4938),
    [sym_requestpage_section] = STATE(4938),
    [sym_rendering_section] = STATE(4938),
    [sym_elements_section] = STATE(4938),
    [sym_schema_section] = STATE(4938),
    [sym_assembly_declaration] = STATE(4938),
    [sym_event_declaration] = STATE(4938),
    [sym_procedure] = STATE(4938),
    [sym_preproc_split_procedure] = STATE(4938),
    [sym_preproc_split_procedure_preamble] = STATE(4938),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4938),
    [sym_var_section] = STATE(4938),
    [sym_attribute_item] = STATE(4938),
    [sym_preproc_conditional] = STATE(4938),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6469),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4938),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4903)] = {
    [sym_identifier] = ACTIONS(5399),
    [anon_sym_DASH] = ACTIONS(5401),
    [aux_sym_boolean_token1] = ACTIONS(5399),
    [aux_sym_boolean_token2] = ACTIONS(5399),
    [sym_decimal] = ACTIONS(5399),
    [anon_sym_LPAREN] = ACTIONS(5401),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5399),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [aux_sym_record_type_token1] = ACTIONS(5399),
    [aux_sym_basic_type_token21] = ACTIONS(5399),
    [aux_sym_basic_type_token22] = ACTIONS(5399),
    [aux_sym_basic_type_token48] = ACTIONS(5399),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(12126),
    [anon_sym_PIPE_PIPE] = ACTIONS(12128),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(12130),
    [anon_sym_AMP_AMP] = ACTIONS(12132),
    [anon_sym_not] = ACTIONS(5399),
    [anon_sym_NOT] = ACTIONS(5399),
    [anon_sym_Not] = ACTIONS(5399),
    [anon_sym_POUNDelif] = ACTIONS(5401),
    [anon_sym_POUNDELIF] = ACTIONS(5401),
    [anon_sym_POUNDElif] = ACTIONS(5401),
    [anon_sym_POUNDelse] = ACTIONS(5401),
    [anon_sym_POUNDELSE] = ACTIONS(5401),
    [anon_sym_POUNDElse] = ACTIONS(5401),
    [anon_sym_POUNDelse2] = ACTIONS(5401),
    [anon_sym_POUNDELSE2] = ACTIONS(5401),
    [anon_sym_POUNDElse2] = ACTIONS(5401),
    [anon_sym_POUNDendif] = ACTIONS(5401),
    [anon_sym_POUNDENDIF] = ACTIONS(5401),
    [anon_sym_POUNDEndif] = ACTIONS(5401),
    [anon_sym_POUNDendif2] = ACTIONS(5401),
    [anon_sym_POUNDENDIF2] = ACTIONS(5401),
    [anon_sym_POUNDEndif2] = ACTIONS(5401),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5399),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5399),
    [anon_sym_PLUS] = ACTIONS(5401),
    [sym_datetime_literal] = ACTIONS(5401),
    [sym_date_literal] = ACTIONS(5399),
    [sym_time_literal] = ACTIONS(5399),
    [sym_biginteger_literal] = ACTIONS(5401),
    [sym_page_keyword] = ACTIONS(5399),
    [anon_sym_codeunit] = ACTIONS(5399),
    [anon_sym_CODEUNIT] = ACTIONS(5399),
    [anon_sym_Codeunit] = ACTIONS(5399),
    [anon_sym_CodeUnit] = ACTIONS(5399),
    [anon_sym_COdeunit] = ACTIONS(5399),
    [anon_sym_codeUnit] = ACTIONS(5399),
    [sym_report_keyword] = ACTIONS(5399),
    [sym_query_keyword] = ACTIONS(5399),
    [anon_sym_xmlport] = ACTIONS(5399),
    [anon_sym_XMLPORT] = ACTIONS(5399),
    [anon_sym_Xmlport] = ACTIONS(5399),
    [anon_sym_XMLport] = ACTIONS(5399),
    [anon_sym_XMLPort] = ACTIONS(5399),
    [anon_sym_XmlPort] = ACTIONS(5399),
    [anon_sym_enum] = ACTIONS(5399),
    [anon_sym_ENUM] = ACTIONS(5399),
    [anon_sym_Enum] = ACTIONS(5399),
    [anon_sym_eNUM] = ACTIONS(5399),
    [anon_sym_eNum] = ACTIONS(5399),
    [anon_sym_ENum] = ACTIONS(5399),
    [sym_quoted_identifier] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5401),
    [sym_verbatim_string] = ACTIONS(5401),
    [sym_integer] = ACTIONS(5399),
    [sym_continue_as_identifier] = ACTIONS(5401),
    [sym_preproc_close] = ACTIONS(5401),
  },
  [STATE(4904)] = {
    [sym_preproc_split_procedure] = STATE(4901),
    [sym_var_attribute_item] = STATE(4901),
    [sym_preproc_conditional_var] = STATE(4901),
    [sym_variable_declaration] = STATE(4901),
    [sym_preproc_if] = STATE(3167),
    [sym__identifier_or_quoted] = STATE(15929),
    [sym_keyword_as_identifier] = STATE(15929),
    [aux_sym_var_section_repeat1] = STATE(4901),
    [sym_identifier] = ACTIONS(12151),
    [anon_sym_SEMI] = ACTIONS(8306),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(8306),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_modify_modification_token1] = ACTIONS(8308),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_xmlport_element_token1] = ACTIONS(8308),
    [aux_sym_xmlport_element_token2] = ACTIONS(8308),
    [aux_sym_xmlport_element_token3] = ACTIONS(8308),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8308),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8308),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [anon_sym_POUNDelif] = ACTIONS(8306),
    [anon_sym_POUNDELIF] = ACTIONS(8306),
    [anon_sym_POUNDElif] = ACTIONS(8306),
    [anon_sym_POUNDelse] = ACTIONS(8306),
    [anon_sym_POUNDELSE] = ACTIONS(8306),
    [anon_sym_POUNDElse] = ACTIONS(8306),
    [anon_sym_POUNDelse2] = ACTIONS(8306),
    [anon_sym_POUNDELSE2] = ACTIONS(8306),
    [anon_sym_POUNDElse2] = ACTIONS(8306),
    [anon_sym_POUNDendif] = ACTIONS(8306),
    [anon_sym_POUNDENDIF] = ACTIONS(8306),
    [anon_sym_POUNDEndif] = ACTIONS(8306),
    [anon_sym_POUNDendif2] = ACTIONS(8306),
    [anon_sym_POUNDENDIF2] = ACTIONS(8306),
    [anon_sym_POUNDEndif2] = ACTIONS(8306),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8308),
    [sym_trigger_keyword] = ACTIONS(8308),
    [sym_var_keyword] = ACTIONS(8308),
    [sym_local_keyword] = ACTIONS(8308),
    [sym_internal_keyword] = ACTIONS(8308),
    [sym_protected_keyword] = ACTIONS(8308),
    [sym_event_keyword] = ACTIONS(8308),
    [sym_fields_keyword] = ACTIONS(8308),
    [sym_keys_keyword] = ACTIONS(8308),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8308),
    [sym_actions_keyword] = ACTIONS(8308),
    [sym_layout_keyword] = ACTIONS(8308),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8308),
    [sym_labels_keyword] = ACTIONS(8308),
    [sym_rendering_keyword] = ACTIONS(8308),
    [sym_requestpage_keyword] = ACTIONS(8308),
    [sym_schema_keyword] = ACTIONS(8308),
    [sym_views_keyword] = ACTIONS(8308),
    [sym_quoted_identifier] = ACTIONS(12153),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8306),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_preproc_close] = ACTIONS(8306),
    [sym_var_attribute_open] = ACTIONS(12155),
  },
  [STATE(4905)] = {
    [aux_sym_where_condition_token1] = ACTIONS(5401),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(5401),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(12157),
    [anon_sym_PIPE_PIPE] = ACTIONS(12157),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(12159),
    [anon_sym_AMP_AMP] = ACTIONS(12159),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_if] = ACTIONS(5401),
    [anon_sym_IF] = ACTIONS(5401),
    [anon_sym_If] = ACTIONS(5401),
    [sym_table_keyword] = ACTIONS(5399),
    [anon_sym_tableextension] = ACTIONS(5401),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5401),
    [anon_sym_Tableextension] = ACTIONS(5401),
    [anon_sym_TableExtension] = ACTIONS(5401),
    [anon_sym_tableExtension] = ACTIONS(5401),
    [sym_page_keyword] = ACTIONS(5399),
    [anon_sym_pageextension] = ACTIONS(5401),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5401),
    [anon_sym_Pageextension] = ACTIONS(5401),
    [anon_sym_PageExtension] = ACTIONS(5401),
    [anon_sym_pageExtension] = ACTIONS(5401),
    [anon_sym_codeunit] = ACTIONS(5401),
    [anon_sym_CODEUNIT] = ACTIONS(5401),
    [anon_sym_Codeunit] = ACTIONS(5401),
    [anon_sym_CodeUnit] = ACTIONS(5401),
    [anon_sym_COdeunit] = ACTIONS(5401),
    [anon_sym_codeUnit] = ACTIONS(5401),
    [sym_report_keyword] = ACTIONS(5399),
    [anon_sym_reportextension] = ACTIONS(5401),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5401),
    [anon_sym_Reportextension] = ACTIONS(5401),
    [anon_sym_ReportExtension] = ACTIONS(5401),
    [anon_sym_reportExtension] = ACTIONS(5401),
    [sym_query_keyword] = ACTIONS(5401),
    [anon_sym_xmlport] = ACTIONS(5401),
    [anon_sym_XMLPORT] = ACTIONS(5401),
    [anon_sym_Xmlport] = ACTIONS(5401),
    [anon_sym_XMLport] = ACTIONS(5401),
    [anon_sym_XMLPort] = ACTIONS(5401),
    [anon_sym_XmlPort] = ACTIONS(5401),
    [anon_sym_enum] = ACTIONS(5399),
    [anon_sym_ENUM] = ACTIONS(5399),
    [anon_sym_Enum] = ACTIONS(5399),
    [anon_sym_eNUM] = ACTIONS(5401),
    [anon_sym_eNum] = ACTIONS(5401),
    [anon_sym_ENum] = ACTIONS(5401),
    [anon_sym_enumextension] = ACTIONS(5401),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5401),
    [anon_sym_Enumextension] = ACTIONS(5401),
    [anon_sym_EnumExtension] = ACTIONS(5401),
    [anon_sym_enumExtension] = ACTIONS(5401),
    [sym_interface_keyword] = ACTIONS(5401),
    [anon_sym_permissionset] = ACTIONS(5399),
    [anon_sym_PERMISSIONSET] = ACTIONS(5399),
    [anon_sym_Permissionset] = ACTIONS(5399),
    [anon_sym_PermissionSet] = ACTIONS(5399),
    [anon_sym_permissionSet] = ACTIONS(5399),
    [anon_sym_permissionsetextension] = ACTIONS(5401),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5401),
    [anon_sym_Permissionsetextension] = ACTIONS(5401),
    [anon_sym_PermissionSetExtension] = ACTIONS(5401),
    [anon_sym_permissionSetExtension] = ACTIONS(5401),
    [sym_procedure_keyword] = ACTIONS(5401),
    [sym_var_keyword] = ACTIONS(5401),
    [sym_local_keyword] = ACTIONS(5401),
    [sym_internal_keyword] = ACTIONS(5401),
    [sym_protected_keyword] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(4906)] = {
    [sym_identifier] = ACTIONS(3651),
    [anon_sym_SEMI] = ACTIONS(3653),
    [anon_sym_DOT] = ACTIONS(3651),
    [anon_sym_EQ] = ACTIONS(3653),
    [anon_sym_COMMA] = ACTIONS(3653),
    [anon_sym_COLON] = ACTIONS(3651),
    [anon_sym_DASH] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3653),
    [anon_sym_RPAREN] = ACTIONS(3653),
    [aux_sym_where_clause_token1] = ACTIONS(3653),
    [aux_sym_where_condition_token1] = ACTIONS(3651),
    [anon_sym_DOT_DOT] = ACTIONS(3653),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_LBRACK] = ACTIONS(3653),
    [anon_sym_RBRACK] = ACTIONS(3653),
    [aux_sym_basic_type_token22] = ACTIONS(3651),
    [aux_sym_basic_type_token53] = ACTIONS(3651),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3651),
    [aux_sym_separator_action_token1] = ACTIONS(3651),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3651),
    [aux_sym_type_declaration_token1] = ACTIONS(3651),
    [anon_sym_COLON_COLON] = ACTIONS(3653),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3653),
    [aux_sym__expression_token1] = ACTIONS(3653),
    [aux_sym__expression_token2] = ACTIONS(3653),
    [anon_sym_SLASH] = ACTIONS(3651),
    [anon_sym_div] = ACTIONS(3651),
    [anon_sym_DIV] = ACTIONS(3651),
    [anon_sym_Div] = ACTIONS(3651),
    [anon_sym_mod] = ACTIONS(3651),
    [anon_sym_MOD] = ACTIONS(3651),
    [anon_sym_Mod] = ACTIONS(3651),
    [anon_sym_PLUS] = ACTIONS(3651),
    [anon_sym_GT_EQ] = ACTIONS(3653),
    [anon_sym_LT_EQ] = ACTIONS(3653),
    [anon_sym_GT] = ACTIONS(3651),
    [anon_sym_LT] = ACTIONS(3651),
    [anon_sym_LT_GT] = ACTIONS(3653),
    [anon_sym_and] = ACTIONS(3651),
    [anon_sym_AND] = ACTIONS(3651),
    [anon_sym_And] = ACTIONS(3651),
    [anon_sym_or] = ACTIONS(3651),
    [anon_sym_OR] = ACTIONS(3651),
    [anon_sym_Or] = ACTIONS(3651),
    [anon_sym_xor] = ACTIONS(3651),
    [anon_sym_XOR] = ACTIONS(3651),
    [anon_sym_Xor] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [anon_sym_then] = ACTIONS(3651),
    [anon_sym_THEN] = ACTIONS(3651),
    [anon_sym_Then] = ACTIONS(3651),
    [anon_sym_else] = ACTIONS(3651),
    [anon_sym_ELSE] = ACTIONS(3651),
    [anon_sym_Else] = ACTIONS(3651),
    [anon_sym_of] = ACTIONS(3651),
    [anon_sym_OF] = ACTIONS(3651),
    [anon_sym_Of] = ACTIONS(3651),
    [anon_sym_do] = ACTIONS(3651),
    [anon_sym_DO] = ACTIONS(3651),
    [anon_sym_Do] = ACTIONS(3651),
    [anon_sym_in] = ACTIONS(3651),
    [anon_sym_IN] = ACTIONS(3651),
    [anon_sym_In] = ACTIONS(3651),
    [sym_table_keyword] = ACTIONS(3651),
    [sym_key_keyword] = ACTIONS(3651),
    [sym_dataset_keyword] = ACTIONS(3651),
    [sym_quoted_identifier] = ACTIONS(3653),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_integer] = ACTIONS(3653),
  },
  [STATE(4907)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6900),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(4908)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5255),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4909)] = {
    [sym__body_element] = STATE(4920),
    [sym_empty_statement] = STATE(4920),
    [sym_property] = STATE(4920),
    [sym_permissions_property] = STATE(4920),
    [sym_table_relation_property] = STATE(4920),
    [sym_fields_section] = STATE(4920),
    [sym_keys_section] = STATE(4920),
    [sym_fieldgroups_section] = STATE(4920),
    [sym_enum_value_declaration] = STATE(4920),
    [sym_labels_section] = STATE(4920),
    [sym_layout_section] = STATE(4920),
    [sym_modify_modification] = STATE(4920),
    [sym_actions_section] = STATE(4920),
    [sym_views_section] = STATE(4920),
    [sym_dataset_section] = STATE(4920),
    [sym_requestpage_section] = STATE(4920),
    [sym_rendering_section] = STATE(4920),
    [sym_elements_section] = STATE(4920),
    [sym_schema_section] = STATE(4920),
    [sym_assembly_declaration] = STATE(4920),
    [sym_event_declaration] = STATE(4920),
    [sym_procedure] = STATE(4920),
    [sym_preproc_split_procedure] = STATE(4920),
    [sym_preproc_split_procedure_preamble] = STATE(4920),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4920),
    [sym_var_section] = STATE(4920),
    [sym_attribute_item] = STATE(4920),
    [sym_preproc_conditional] = STATE(4920),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5255),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4920),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4910)] = {
    [sym__object_header] = STATE(13738),
    [sym_preproc_if] = STATE(5422),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [anon_sym_POUNDif] = ACTIONS(12134),
    [anon_sym_POUNDIF] = ACTIONS(12134),
    [anon_sym_POUNDIf] = ACTIONS(12134),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(12134),
  },
  [STATE(4911)] = {
    [sym_identifier] = ACTIONS(5378),
    [anon_sym_DASH] = ACTIONS(5380),
    [aux_sym_boolean_token1] = ACTIONS(5378),
    [aux_sym_boolean_token2] = ACTIONS(5378),
    [sym_decimal] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5380),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5378),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [aux_sym_record_type_token1] = ACTIONS(5378),
    [aux_sym_basic_type_token21] = ACTIONS(5378),
    [aux_sym_basic_type_token22] = ACTIONS(5378),
    [aux_sym_basic_type_token48] = ACTIONS(5378),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5380),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(12130),
    [anon_sym_AMP_AMP] = ACTIONS(12132),
    [anon_sym_not] = ACTIONS(5378),
    [anon_sym_NOT] = ACTIONS(5378),
    [anon_sym_Not] = ACTIONS(5378),
    [anon_sym_POUNDelif] = ACTIONS(5380),
    [anon_sym_POUNDELIF] = ACTIONS(5380),
    [anon_sym_POUNDElif] = ACTIONS(5380),
    [anon_sym_POUNDelse] = ACTIONS(5380),
    [anon_sym_POUNDELSE] = ACTIONS(5380),
    [anon_sym_POUNDElse] = ACTIONS(5380),
    [anon_sym_POUNDelse2] = ACTIONS(5380),
    [anon_sym_POUNDELSE2] = ACTIONS(5380),
    [anon_sym_POUNDElse2] = ACTIONS(5380),
    [anon_sym_POUNDendif] = ACTIONS(5380),
    [anon_sym_POUNDENDIF] = ACTIONS(5380),
    [anon_sym_POUNDEndif] = ACTIONS(5380),
    [anon_sym_POUNDendif2] = ACTIONS(5380),
    [anon_sym_POUNDENDIF2] = ACTIONS(5380),
    [anon_sym_POUNDEndif2] = ACTIONS(5380),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5378),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [sym_datetime_literal] = ACTIONS(5380),
    [sym_date_literal] = ACTIONS(5378),
    [sym_time_literal] = ACTIONS(5378),
    [sym_biginteger_literal] = ACTIONS(5380),
    [sym_page_keyword] = ACTIONS(5378),
    [anon_sym_codeunit] = ACTIONS(5378),
    [anon_sym_CODEUNIT] = ACTIONS(5378),
    [anon_sym_Codeunit] = ACTIONS(5378),
    [anon_sym_CodeUnit] = ACTIONS(5378),
    [anon_sym_COdeunit] = ACTIONS(5378),
    [anon_sym_codeUnit] = ACTIONS(5378),
    [sym_report_keyword] = ACTIONS(5378),
    [sym_query_keyword] = ACTIONS(5378),
    [anon_sym_xmlport] = ACTIONS(5378),
    [anon_sym_XMLPORT] = ACTIONS(5378),
    [anon_sym_Xmlport] = ACTIONS(5378),
    [anon_sym_XMLport] = ACTIONS(5378),
    [anon_sym_XMLPort] = ACTIONS(5378),
    [anon_sym_XmlPort] = ACTIONS(5378),
    [anon_sym_enum] = ACTIONS(5378),
    [anon_sym_ENUM] = ACTIONS(5378),
    [anon_sym_Enum] = ACTIONS(5378),
    [anon_sym_eNUM] = ACTIONS(5378),
    [anon_sym_eNum] = ACTIONS(5378),
    [anon_sym_ENum] = ACTIONS(5378),
    [sym_quoted_identifier] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5380),
    [sym_verbatim_string] = ACTIONS(5380),
    [sym_integer] = ACTIONS(5378),
    [sym_continue_as_identifier] = ACTIONS(5380),
    [sym_preproc_close] = ACTIONS(5380),
  },
  [STATE(4912)] = {
    [aux_sym_where_condition_token1] = ACTIONS(5380),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(5380),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5380),
    [anon_sym_PIPE_PIPE] = ACTIONS(5380),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(12159),
    [anon_sym_AMP_AMP] = ACTIONS(12159),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_if] = ACTIONS(5380),
    [anon_sym_IF] = ACTIONS(5380),
    [anon_sym_If] = ACTIONS(5380),
    [sym_table_keyword] = ACTIONS(5378),
    [anon_sym_tableextension] = ACTIONS(5380),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5380),
    [anon_sym_Tableextension] = ACTIONS(5380),
    [anon_sym_TableExtension] = ACTIONS(5380),
    [anon_sym_tableExtension] = ACTIONS(5380),
    [sym_page_keyword] = ACTIONS(5378),
    [anon_sym_pageextension] = ACTIONS(5380),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5380),
    [anon_sym_Pageextension] = ACTIONS(5380),
    [anon_sym_PageExtension] = ACTIONS(5380),
    [anon_sym_pageExtension] = ACTIONS(5380),
    [anon_sym_codeunit] = ACTIONS(5380),
    [anon_sym_CODEUNIT] = ACTIONS(5380),
    [anon_sym_Codeunit] = ACTIONS(5380),
    [anon_sym_CodeUnit] = ACTIONS(5380),
    [anon_sym_COdeunit] = ACTIONS(5380),
    [anon_sym_codeUnit] = ACTIONS(5380),
    [sym_report_keyword] = ACTIONS(5378),
    [anon_sym_reportextension] = ACTIONS(5380),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5380),
    [anon_sym_Reportextension] = ACTIONS(5380),
    [anon_sym_ReportExtension] = ACTIONS(5380),
    [anon_sym_reportExtension] = ACTIONS(5380),
    [sym_query_keyword] = ACTIONS(5380),
    [anon_sym_xmlport] = ACTIONS(5380),
    [anon_sym_XMLPORT] = ACTIONS(5380),
    [anon_sym_Xmlport] = ACTIONS(5380),
    [anon_sym_XMLport] = ACTIONS(5380),
    [anon_sym_XMLPort] = ACTIONS(5380),
    [anon_sym_XmlPort] = ACTIONS(5380),
    [anon_sym_enum] = ACTIONS(5378),
    [anon_sym_ENUM] = ACTIONS(5378),
    [anon_sym_Enum] = ACTIONS(5378),
    [anon_sym_eNUM] = ACTIONS(5380),
    [anon_sym_eNum] = ACTIONS(5380),
    [anon_sym_ENum] = ACTIONS(5380),
    [anon_sym_enumextension] = ACTIONS(5380),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5380),
    [anon_sym_Enumextension] = ACTIONS(5380),
    [anon_sym_EnumExtension] = ACTIONS(5380),
    [anon_sym_enumExtension] = ACTIONS(5380),
    [sym_interface_keyword] = ACTIONS(5380),
    [anon_sym_permissionset] = ACTIONS(5378),
    [anon_sym_PERMISSIONSET] = ACTIONS(5378),
    [anon_sym_Permissionset] = ACTIONS(5378),
    [anon_sym_PermissionSet] = ACTIONS(5378),
    [anon_sym_permissionSet] = ACTIONS(5378),
    [anon_sym_permissionsetextension] = ACTIONS(5380),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5380),
    [anon_sym_Permissionsetextension] = ACTIONS(5380),
    [anon_sym_PermissionSetExtension] = ACTIONS(5380),
    [anon_sym_permissionSetExtension] = ACTIONS(5380),
    [sym_procedure_keyword] = ACTIONS(5380),
    [sym_var_keyword] = ACTIONS(5380),
    [sym_local_keyword] = ACTIONS(5380),
    [sym_internal_keyword] = ACTIONS(5380),
    [sym_protected_keyword] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(4913)] = {
    [aux_sym_where_condition_token1] = ACTIONS(5376),
    [anon_sym_LBRACK] = ACTIONS(5376),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(5376),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(5376),
    [anon_sym_PIPE_PIPE] = ACTIONS(5376),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(5376),
    [anon_sym_AMP_AMP] = ACTIONS(5376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_if] = ACTIONS(5376),
    [anon_sym_IF] = ACTIONS(5376),
    [anon_sym_If] = ACTIONS(5376),
    [sym_table_keyword] = ACTIONS(5374),
    [anon_sym_tableextension] = ACTIONS(5376),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5376),
    [anon_sym_Tableextension] = ACTIONS(5376),
    [anon_sym_TableExtension] = ACTIONS(5376),
    [anon_sym_tableExtension] = ACTIONS(5376),
    [sym_page_keyword] = ACTIONS(5374),
    [anon_sym_pageextension] = ACTIONS(5376),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5376),
    [anon_sym_Pageextension] = ACTIONS(5376),
    [anon_sym_PageExtension] = ACTIONS(5376),
    [anon_sym_pageExtension] = ACTIONS(5376),
    [anon_sym_codeunit] = ACTIONS(5376),
    [anon_sym_CODEUNIT] = ACTIONS(5376),
    [anon_sym_Codeunit] = ACTIONS(5376),
    [anon_sym_CodeUnit] = ACTIONS(5376),
    [anon_sym_COdeunit] = ACTIONS(5376),
    [anon_sym_codeUnit] = ACTIONS(5376),
    [sym_report_keyword] = ACTIONS(5374),
    [anon_sym_reportextension] = ACTIONS(5376),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5376),
    [anon_sym_Reportextension] = ACTIONS(5376),
    [anon_sym_ReportExtension] = ACTIONS(5376),
    [anon_sym_reportExtension] = ACTIONS(5376),
    [sym_query_keyword] = ACTIONS(5376),
    [anon_sym_xmlport] = ACTIONS(5376),
    [anon_sym_XMLPORT] = ACTIONS(5376),
    [anon_sym_Xmlport] = ACTIONS(5376),
    [anon_sym_XMLport] = ACTIONS(5376),
    [anon_sym_XMLPort] = ACTIONS(5376),
    [anon_sym_XmlPort] = ACTIONS(5376),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_ENUM] = ACTIONS(5374),
    [anon_sym_Enum] = ACTIONS(5374),
    [anon_sym_eNUM] = ACTIONS(5376),
    [anon_sym_eNum] = ACTIONS(5376),
    [anon_sym_ENum] = ACTIONS(5376),
    [anon_sym_enumextension] = ACTIONS(5376),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5376),
    [anon_sym_Enumextension] = ACTIONS(5376),
    [anon_sym_EnumExtension] = ACTIONS(5376),
    [anon_sym_enumExtension] = ACTIONS(5376),
    [sym_interface_keyword] = ACTIONS(5376),
    [anon_sym_permissionset] = ACTIONS(5374),
    [anon_sym_PERMISSIONSET] = ACTIONS(5374),
    [anon_sym_Permissionset] = ACTIONS(5374),
    [anon_sym_PermissionSet] = ACTIONS(5374),
    [anon_sym_permissionSet] = ACTIONS(5374),
    [anon_sym_permissionsetextension] = ACTIONS(5376),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5376),
    [anon_sym_Permissionsetextension] = ACTIONS(5376),
    [anon_sym_PermissionSetExtension] = ACTIONS(5376),
    [anon_sym_permissionSetExtension] = ACTIONS(5376),
    [sym_procedure_keyword] = ACTIONS(5376),
    [sym_var_keyword] = ACTIONS(5376),
    [sym_local_keyword] = ACTIONS(5376),
    [sym_internal_keyword] = ACTIONS(5376),
    [sym_protected_keyword] = ACTIONS(5376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(4914)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5213),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4915)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6469),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4916)] = {
    [sym__body_element] = STATE(4924),
    [sym_empty_statement] = STATE(4924),
    [sym_property] = STATE(4924),
    [sym_permissions_property] = STATE(4924),
    [sym_table_relation_property] = STATE(4924),
    [sym_fields_section] = STATE(4924),
    [sym_keys_section] = STATE(4924),
    [sym_fieldgroups_section] = STATE(4924),
    [sym_enum_value_declaration] = STATE(4924),
    [sym_labels_section] = STATE(4924),
    [sym_layout_section] = STATE(4924),
    [sym_modify_modification] = STATE(4924),
    [sym_actions_section] = STATE(4924),
    [sym_views_section] = STATE(4924),
    [sym_dataset_section] = STATE(4924),
    [sym_requestpage_section] = STATE(4924),
    [sym_rendering_section] = STATE(4924),
    [sym_elements_section] = STATE(4924),
    [sym_schema_section] = STATE(4924),
    [sym_assembly_declaration] = STATE(4924),
    [sym_event_declaration] = STATE(4924),
    [sym_procedure] = STATE(4924),
    [sym_preproc_split_procedure] = STATE(4924),
    [sym_preproc_split_procedure_preamble] = STATE(4924),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4924),
    [sym_var_section] = STATE(4924),
    [sym_attribute_item] = STATE(4924),
    [sym_preproc_conditional] = STATE(4924),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(7035),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4924),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(4917)] = {
    [anon_sym_SEMI] = ACTIONS(12161),
    [aux_sym_where_condition_token1] = ACTIONS(12163),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(12161),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12161),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12161),
    [anon_sym_LBRACK] = ACTIONS(12161),
    [aux_sym_basic_type_token6] = ACTIONS(12163),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12161),
    [aux_sym_addafter_modification_token1] = ACTIONS(12161),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12161),
    [aux_sym_modify_modification_token1] = ACTIONS(12161),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12161),
    [aux_sym_movelast_modification_token1] = ACTIONS(12161),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12161),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12161),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12161),
    [anon_sym_POUNDif] = ACTIONS(12161),
    [anon_sym_POUNDIF] = ACTIONS(12161),
    [anon_sym_POUNDIf] = ACTIONS(12161),
    [anon_sym_POUNDelif] = ACTIONS(12161),
    [anon_sym_POUNDELIF] = ACTIONS(12161),
    [anon_sym_POUNDElif] = ACTIONS(12161),
    [anon_sym_POUNDelse] = ACTIONS(12161),
    [anon_sym_POUNDELSE] = ACTIONS(12161),
    [anon_sym_POUNDElse] = ACTIONS(12161),
    [anon_sym_POUNDelse2] = ACTIONS(12161),
    [anon_sym_POUNDELSE2] = ACTIONS(12161),
    [anon_sym_POUNDElse2] = ACTIONS(12161),
    [anon_sym_POUNDendif] = ACTIONS(12161),
    [anon_sym_POUNDENDIF] = ACTIONS(12161),
    [anon_sym_POUNDEndif] = ACTIONS(12161),
    [anon_sym_POUNDendif2] = ACTIONS(12161),
    [anon_sym_POUNDENDIF2] = ACTIONS(12161),
    [anon_sym_POUNDEndif2] = ACTIONS(12161),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12161),
    [sym_trigger_keyword] = ACTIONS(12161),
    [sym_var_keyword] = ACTIONS(12161),
    [sym_local_keyword] = ACTIONS(12161),
    [sym_internal_keyword] = ACTIONS(12161),
    [sym_protected_keyword] = ACTIONS(12161),
    [sym_event_keyword] = ACTIONS(12161),
    [sym_fields_keyword] = ACTIONS(12161),
    [sym_keys_keyword] = ACTIONS(12161),
    [sym_fieldgroups_keyword] = ACTIONS(12161),
    [sym_actions_keyword] = ACTIONS(12161),
    [sym_layout_keyword] = ACTIONS(12161),
    [sym_area_keyword] = ACTIONS(12161),
    [sym_group_keyword] = ACTIONS(12161),
    [sym_repeater_keyword] = ACTIONS(12161),
    [sym_cuegroup_keyword] = ACTIONS(12161),
    [sym_fixed_keyword] = ACTIONS(12161),
    [sym_grid_keyword] = ACTIONS(12161),
    [sym_part_keyword] = ACTIONS(12161),
    [sym_systempart_keyword] = ACTIONS(12161),
    [sym_usercontrol_keyword] = ACTIONS(12161),
    [sym_dataset_keyword] = ACTIONS(12161),
    [sym_elements_keyword] = ACTIONS(12161),
    [sym_dataitem_keyword] = ACTIONS(12161),
    [sym_column_keyword] = ACTIONS(12161),
    [sym_filter_keyword] = ACTIONS(12161),
    [sym_labels_keyword] = ACTIONS(12161),
    [sym_rendering_keyword] = ACTIONS(12161),
    [sym_requestpage_keyword] = ACTIONS(12161),
    [sym_schema_keyword] = ACTIONS(12161),
    [sym_views_keyword] = ACTIONS(12161),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12161),
    [sym_preproc_open] = ACTIONS(12161),
    [sym_preproc_close] = ACTIONS(12161),
  },
  [STATE(4918)] = {
    [anon_sym_SEMI] = ACTIONS(8438),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8438),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8438),
    [anon_sym_LBRACK] = ACTIONS(8438),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8438),
    [aux_sym_modify_modification_token1] = ACTIONS(8438),
    [aux_sym_xmlport_element_token1] = ACTIONS(8438),
    [aux_sym_xmlport_element_token2] = ACTIONS(8438),
    [aux_sym_xmlport_element_token3] = ACTIONS(8438),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8438),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8438),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8438),
    [anon_sym_POUNDif] = ACTIONS(8438),
    [anon_sym_POUNDIF] = ACTIONS(8438),
    [anon_sym_POUNDIf] = ACTIONS(8438),
    [anon_sym_POUNDelif] = ACTIONS(8438),
    [anon_sym_POUNDELIF] = ACTIONS(8438),
    [anon_sym_POUNDElif] = ACTIONS(8438),
    [anon_sym_POUNDelse] = ACTIONS(8438),
    [anon_sym_POUNDELSE] = ACTIONS(8438),
    [anon_sym_POUNDElse] = ACTIONS(8438),
    [anon_sym_POUNDelse2] = ACTIONS(8438),
    [anon_sym_POUNDELSE2] = ACTIONS(8438),
    [anon_sym_POUNDElse2] = ACTIONS(8438),
    [anon_sym_POUNDendif] = ACTIONS(8438),
    [anon_sym_POUNDENDIF] = ACTIONS(8438),
    [anon_sym_POUNDEndif] = ACTIONS(8438),
    [anon_sym_POUNDendif2] = ACTIONS(8438),
    [anon_sym_POUNDENDIF2] = ACTIONS(8438),
    [anon_sym_POUNDEndif2] = ACTIONS(8438),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8440),
    [sym_page_keyword] = ACTIONS(8438),
    [anon_sym_codeunit] = ACTIONS(8438),
    [anon_sym_CODEUNIT] = ACTIONS(8438),
    [anon_sym_Codeunit] = ACTIONS(8438),
    [anon_sym_CodeUnit] = ACTIONS(8438),
    [anon_sym_COdeunit] = ACTIONS(8438),
    [anon_sym_codeUnit] = ACTIONS(8438),
    [sym_report_keyword] = ACTIONS(8438),
    [sym_query_keyword] = ACTIONS(8438),
    [anon_sym_xmlport] = ACTIONS(8438),
    [anon_sym_XMLPORT] = ACTIONS(8438),
    [anon_sym_Xmlport] = ACTIONS(8438),
    [anon_sym_XMLport] = ACTIONS(8438),
    [anon_sym_XMLPort] = ACTIONS(8438),
    [anon_sym_XmlPort] = ACTIONS(8438),
    [sym_procedure_keyword] = ACTIONS(8438),
    [sym_trigger_keyword] = ACTIONS(8438),
    [sym_var_keyword] = ACTIONS(8438),
    [sym_local_keyword] = ACTIONS(8438),
    [sym_internal_keyword] = ACTIONS(8438),
    [sym_protected_keyword] = ACTIONS(8438),
    [sym_event_keyword] = ACTIONS(8438),
    [sym_fields_keyword] = ACTIONS(8438),
    [sym_keys_keyword] = ACTIONS(8438),
    [sym_fieldgroups_keyword] = ACTIONS(8438),
    [sym_actions_keyword] = ACTIONS(8438),
    [sym_layout_keyword] = ACTIONS(8438),
    [sym_dataset_keyword] = ACTIONS(8438),
    [sym_elements_keyword] = ACTIONS(8438),
    [sym_labels_keyword] = ACTIONS(8438),
    [sym_rendering_keyword] = ACTIONS(8438),
    [sym_requestpage_keyword] = ACTIONS(8438),
    [sym_schema_keyword] = ACTIONS(8438),
    [sym_views_keyword] = ACTIONS(8438),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8438),
    [sym_preproc_open] = ACTIONS(8438),
    [sym_preproc_close] = ACTIONS(8438),
  },
  [STATE(4919)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6204),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(4920)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5271),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4921)] = {
    [sym_preproc_split_procedure_body] = STATE(5273),
    [sym_preproc_split_complete_body] = STATE(5273),
    [sym_interface_procedure_suffix] = STATE(8225),
    [sym__procedure_return_specification] = STATE(7159),
    [sym__procedure_named_return] = STATE(7160),
    [sym_code_block] = STATE(5273),
    [sym_preproc_conditional_var_block] = STATE(15853),
    [sym_var_section] = STATE(15853),
    [sym_preproc_if] = STATE(10131),
    [sym__identifier_or_quoted] = STATE(16513),
    [sym_keyword_as_identifier] = STATE(16513),
    [sym_identifier] = ACTIONS(12165),
    [anon_sym_SEMI] = ACTIONS(12167),
    [anon_sym_COLON] = ACTIONS(12169),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(12171),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_modify_modification_token1] = ACTIONS(12173),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(12175),
    [anon_sym_POUNDif] = ACTIONS(12177),
    [anon_sym_POUNDIF] = ACTIONS(12177),
    [anon_sym_POUNDIf] = ACTIONS(12177),
    [anon_sym_POUNDelif] = ACTIONS(12171),
    [anon_sym_POUNDELIF] = ACTIONS(12171),
    [anon_sym_POUNDElif] = ACTIONS(12171),
    [anon_sym_POUNDelse] = ACTIONS(12171),
    [anon_sym_POUNDELSE] = ACTIONS(12171),
    [anon_sym_POUNDElse] = ACTIONS(12171),
    [anon_sym_POUNDelse2] = ACTIONS(12171),
    [anon_sym_POUNDELSE2] = ACTIONS(12171),
    [anon_sym_POUNDElse2] = ACTIONS(12171),
    [anon_sym_POUNDendif] = ACTIONS(12171),
    [anon_sym_POUNDENDIF] = ACTIONS(12171),
    [anon_sym_POUNDEndif] = ACTIONS(12171),
    [anon_sym_POUNDendif2] = ACTIONS(12171),
    [anon_sym_POUNDENDIF2] = ACTIONS(12171),
    [anon_sym_POUNDEndif2] = ACTIONS(12171),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(12173),
    [sym_trigger_keyword] = ACTIONS(12173),
    [sym_var_keyword] = ACTIONS(12179),
    [sym_local_keyword] = ACTIONS(12181),
    [sym_internal_keyword] = ACTIONS(12173),
    [sym_protected_keyword] = ACTIONS(12181),
    [sym_event_keyword] = ACTIONS(12173),
    [sym_fields_keyword] = ACTIONS(12173),
    [sym_keys_keyword] = ACTIONS(12173),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(12173),
    [sym_actions_keyword] = ACTIONS(12173),
    [sym_layout_keyword] = ACTIONS(12173),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(12173),
    [sym_labels_keyword] = ACTIONS(12173),
    [sym_rendering_keyword] = ACTIONS(12173),
    [sym_requestpage_keyword] = ACTIONS(12173),
    [sym_schema_keyword] = ACTIONS(12173),
    [sym_views_keyword] = ACTIONS(12173),
    [sym_quoted_identifier] = ACTIONS(12183),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12171),
    [sym_preproc_open] = ACTIONS(12177),
    [sym_preproc_close] = ACTIONS(12171),
    [sym_begin_keyword] = ACTIONS(12185),
  },
  [STATE(4922)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5255),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(4923)] = {
    [sym__body_element] = STATE(4927),
    [sym_empty_statement] = STATE(4927),
    [sym_property] = STATE(4927),
    [sym_permissions_property] = STATE(4927),
    [sym_table_relation_property] = STATE(4927),
    [sym_fields_section] = STATE(4927),
    [sym_keys_section] = STATE(4927),
    [sym_fieldgroups_section] = STATE(4927),
    [sym_enum_value_declaration] = STATE(4927),
    [sym_labels_section] = STATE(4927),
    [sym_layout_section] = STATE(4927),
    [sym_modify_modification] = STATE(4927),
    [sym_actions_section] = STATE(4927),
    [sym_views_section] = STATE(4927),
    [sym_dataset_section] = STATE(4927),
    [sym_requestpage_section] = STATE(4927),
    [sym_rendering_section] = STATE(4927),
    [sym_elements_section] = STATE(4927),
    [sym_schema_section] = STATE(4927),
    [sym_assembly_declaration] = STATE(4927),
    [sym_event_declaration] = STATE(4927),
    [sym_procedure] = STATE(4927),
    [sym_preproc_split_procedure] = STATE(4927),
    [sym_preproc_split_procedure_preamble] = STATE(4927),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4927),
    [sym_var_section] = STATE(4927),
    [sym_attribute_item] = STATE(4927),
    [sym_preproc_conditional] = STATE(4927),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5255),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4927),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(4924)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6726),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(4925)] = {
    [sym_identifier] = ACTIONS(3655),
    [anon_sym_SEMI] = ACTIONS(3657),
    [anon_sym_DOT] = ACTIONS(3655),
    [anon_sym_EQ] = ACTIONS(3657),
    [anon_sym_COMMA] = ACTIONS(3657),
    [anon_sym_COLON] = ACTIONS(3655),
    [anon_sym_DASH] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3657),
    [anon_sym_RPAREN] = ACTIONS(3657),
    [aux_sym_where_clause_token1] = ACTIONS(3657),
    [aux_sym_where_condition_token1] = ACTIONS(3655),
    [anon_sym_DOT_DOT] = ACTIONS(3657),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [anon_sym_RBRACK] = ACTIONS(3657),
    [aux_sym_basic_type_token22] = ACTIONS(3655),
    [aux_sym_basic_type_token53] = ACTIONS(3655),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3655),
    [aux_sym_separator_action_token1] = ACTIONS(3655),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3655),
    [aux_sym_type_declaration_token1] = ACTIONS(3655),
    [anon_sym_COLON_COLON] = ACTIONS(3657),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3657),
    [aux_sym__expression_token1] = ACTIONS(3657),
    [aux_sym__expression_token2] = ACTIONS(3657),
    [anon_sym_SLASH] = ACTIONS(3655),
    [anon_sym_div] = ACTIONS(3655),
    [anon_sym_DIV] = ACTIONS(3655),
    [anon_sym_Div] = ACTIONS(3655),
    [anon_sym_mod] = ACTIONS(3655),
    [anon_sym_MOD] = ACTIONS(3655),
    [anon_sym_Mod] = ACTIONS(3655),
    [anon_sym_PLUS] = ACTIONS(3655),
    [anon_sym_GT_EQ] = ACTIONS(3657),
    [anon_sym_LT_EQ] = ACTIONS(3657),
    [anon_sym_GT] = ACTIONS(3655),
    [anon_sym_LT] = ACTIONS(3655),
    [anon_sym_LT_GT] = ACTIONS(3657),
    [anon_sym_and] = ACTIONS(3655),
    [anon_sym_AND] = ACTIONS(3655),
    [anon_sym_And] = ACTIONS(3655),
    [anon_sym_or] = ACTIONS(3655),
    [anon_sym_OR] = ACTIONS(3655),
    [anon_sym_Or] = ACTIONS(3655),
    [anon_sym_xor] = ACTIONS(3655),
    [anon_sym_XOR] = ACTIONS(3655),
    [anon_sym_Xor] = ACTIONS(3655),
    [anon_sym_QMARK] = ACTIONS(3657),
    [anon_sym_then] = ACTIONS(3655),
    [anon_sym_THEN] = ACTIONS(3655),
    [anon_sym_Then] = ACTIONS(3655),
    [anon_sym_else] = ACTIONS(3655),
    [anon_sym_ELSE] = ACTIONS(3655),
    [anon_sym_Else] = ACTIONS(3655),
    [anon_sym_of] = ACTIONS(3655),
    [anon_sym_OF] = ACTIONS(3655),
    [anon_sym_Of] = ACTIONS(3655),
    [anon_sym_do] = ACTIONS(3655),
    [anon_sym_DO] = ACTIONS(3655),
    [anon_sym_Do] = ACTIONS(3655),
    [anon_sym_in] = ACTIONS(3655),
    [anon_sym_IN] = ACTIONS(3655),
    [anon_sym_In] = ACTIONS(3655),
    [sym_table_keyword] = ACTIONS(3655),
    [sym_key_keyword] = ACTIONS(3655),
    [sym_dataset_keyword] = ACTIONS(3655),
    [sym_quoted_identifier] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_integer] = ACTIONS(3657),
  },
  [STATE(4926)] = {
    [sym__body_element] = STATE(4953),
    [sym_empty_statement] = STATE(4953),
    [sym_property] = STATE(4953),
    [sym_permissions_property] = STATE(4953),
    [sym_table_relation_property] = STATE(4953),
    [sym_fields_section] = STATE(4953),
    [sym_keys_section] = STATE(4953),
    [sym_fieldgroups_section] = STATE(4953),
    [sym_enum_value_declaration] = STATE(4953),
    [sym_labels_section] = STATE(4953),
    [sym_layout_section] = STATE(4953),
    [sym_modify_modification] = STATE(4953),
    [sym_actions_section] = STATE(4953),
    [sym_views_section] = STATE(4953),
    [sym_dataset_section] = STATE(4953),
    [sym_requestpage_section] = STATE(4953),
    [sym_rendering_section] = STATE(4953),
    [sym_elements_section] = STATE(4953),
    [sym_schema_section] = STATE(4953),
    [sym_assembly_declaration] = STATE(4953),
    [sym_event_declaration] = STATE(4953),
    [sym_procedure] = STATE(4953),
    [sym_preproc_split_procedure] = STATE(4953),
    [sym_preproc_split_procedure_preamble] = STATE(4953),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4953),
    [sym_var_section] = STATE(4953),
    [sym_attribute_item] = STATE(4953),
    [sym_preproc_conditional] = STATE(4953),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6726),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4953),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(4927)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5271),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(4928)] = {
    [sym__body_element] = STATE(4934),
    [sym_empty_statement] = STATE(4934),
    [sym_property] = STATE(4934),
    [sym_permissions_property] = STATE(4934),
    [sym_table_relation_property] = STATE(4934),
    [sym_fields_section] = STATE(4934),
    [sym_keys_section] = STATE(4934),
    [sym_fieldgroups_section] = STATE(4934),
    [sym_enum_value_declaration] = STATE(4934),
    [sym_labels_section] = STATE(4934),
    [sym_layout_section] = STATE(4934),
    [sym_modify_modification] = STATE(4934),
    [sym_actions_section] = STATE(4934),
    [sym_views_section] = STATE(4934),
    [sym_dataset_section] = STATE(4934),
    [sym_requestpage_section] = STATE(4934),
    [sym_rendering_section] = STATE(4934),
    [sym_elements_section] = STATE(4934),
    [sym_schema_section] = STATE(4934),
    [sym_assembly_declaration] = STATE(4934),
    [sym_event_declaration] = STATE(4934),
    [sym_procedure] = STATE(4934),
    [sym_preproc_split_procedure] = STATE(4934),
    [sym_preproc_split_procedure_preamble] = STATE(4934),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4934),
    [sym_var_section] = STATE(4934),
    [sym_attribute_item] = STATE(4934),
    [sym_preproc_conditional] = STATE(4934),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5271),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4934),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(4929)] = {
    [sym_identifier] = ACTIONS(3659),
    [anon_sym_SEMI] = ACTIONS(3661),
    [anon_sym_DOT] = ACTIONS(3659),
    [anon_sym_EQ] = ACTIONS(3661),
    [anon_sym_COMMA] = ACTIONS(3661),
    [anon_sym_COLON] = ACTIONS(3659),
    [anon_sym_DASH] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3661),
    [anon_sym_RPAREN] = ACTIONS(3661),
    [aux_sym_where_clause_token1] = ACTIONS(3661),
    [aux_sym_where_condition_token1] = ACTIONS(3659),
    [anon_sym_DOT_DOT] = ACTIONS(3661),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3661),
    [anon_sym_RBRACK] = ACTIONS(3661),
    [aux_sym_basic_type_token22] = ACTIONS(3659),
    [aux_sym_basic_type_token53] = ACTIONS(3659),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3659),
    [aux_sym_separator_action_token1] = ACTIONS(3659),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3659),
    [aux_sym_type_declaration_token1] = ACTIONS(3659),
    [anon_sym_COLON_COLON] = ACTIONS(3661),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym__assignment_operator] = ACTIONS(3661),
    [aux_sym__expression_token1] = ACTIONS(3661),
    [aux_sym__expression_token2] = ACTIONS(3661),
    [anon_sym_SLASH] = ACTIONS(3659),
    [anon_sym_div] = ACTIONS(3659),
    [anon_sym_DIV] = ACTIONS(3659),
    [anon_sym_Div] = ACTIONS(3659),
    [anon_sym_mod] = ACTIONS(3659),
    [anon_sym_MOD] = ACTIONS(3659),
    [anon_sym_Mod] = ACTIONS(3659),
    [anon_sym_PLUS] = ACTIONS(3659),
    [anon_sym_GT_EQ] = ACTIONS(3661),
    [anon_sym_LT_EQ] = ACTIONS(3661),
    [anon_sym_GT] = ACTIONS(3659),
    [anon_sym_LT] = ACTIONS(3659),
    [anon_sym_LT_GT] = ACTIONS(3661),
    [anon_sym_and] = ACTIONS(3659),
    [anon_sym_AND] = ACTIONS(3659),
    [anon_sym_And] = ACTIONS(3659),
    [anon_sym_or] = ACTIONS(3659),
    [anon_sym_OR] = ACTIONS(3659),
    [anon_sym_Or] = ACTIONS(3659),
    [anon_sym_xor] = ACTIONS(3659),
    [anon_sym_XOR] = ACTIONS(3659),
    [anon_sym_Xor] = ACTIONS(3659),
    [anon_sym_QMARK] = ACTIONS(3661),
    [anon_sym_then] = ACTIONS(3659),
    [anon_sym_THEN] = ACTIONS(3659),
    [anon_sym_Then] = ACTIONS(3659),
    [anon_sym_else] = ACTIONS(3659),
    [anon_sym_ELSE] = ACTIONS(3659),
    [anon_sym_Else] = ACTIONS(3659),
    [anon_sym_of] = ACTIONS(3659),
    [anon_sym_OF] = ACTIONS(3659),
    [anon_sym_Of] = ACTIONS(3659),
    [anon_sym_do] = ACTIONS(3659),
    [anon_sym_DO] = ACTIONS(3659),
    [anon_sym_Do] = ACTIONS(3659),
    [anon_sym_in] = ACTIONS(3659),
    [anon_sym_IN] = ACTIONS(3659),
    [anon_sym_In] = ACTIONS(3659),
    [sym_table_keyword] = ACTIONS(3659),
    [sym_key_keyword] = ACTIONS(3659),
    [sym_dataset_keyword] = ACTIONS(3659),
    [sym_quoted_identifier] = ACTIONS(3661),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_integer] = ACTIONS(3661),
  },
  [STATE(4930)] = {
    [sym_preproc_split_procedure] = STATE(4936),
    [sym_var_attribute_item] = STATE(4936),
    [sym_preproc_conditional_var] = STATE(4936),
    [sym_variable_declaration] = STATE(4936),
    [sym_preproc_if] = STATE(3167),
    [sym__identifier_or_quoted] = STATE(15929),
    [sym_keyword_as_identifier] = STATE(15929),
    [aux_sym_var_section_repeat1] = STATE(4936),
    [sym_identifier] = ACTIONS(12151),
    [anon_sym_SEMI] = ACTIONS(8329),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(8329),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_modify_modification_token1] = ACTIONS(8331),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_xmlport_element_token1] = ACTIONS(8331),
    [aux_sym_xmlport_element_token2] = ACTIONS(8331),
    [aux_sym_xmlport_element_token3] = ACTIONS(8331),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8331),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8331),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [anon_sym_POUNDelif] = ACTIONS(8329),
    [anon_sym_POUNDELIF] = ACTIONS(8329),
    [anon_sym_POUNDElif] = ACTIONS(8329),
    [anon_sym_POUNDelse] = ACTIONS(8329),
    [anon_sym_POUNDELSE] = ACTIONS(8329),
    [anon_sym_POUNDElse] = ACTIONS(8329),
    [anon_sym_POUNDelse2] = ACTIONS(8329),
    [anon_sym_POUNDELSE2] = ACTIONS(8329),
    [anon_sym_POUNDElse2] = ACTIONS(8329),
    [anon_sym_POUNDendif] = ACTIONS(8329),
    [anon_sym_POUNDENDIF] = ACTIONS(8329),
    [anon_sym_POUNDEndif] = ACTIONS(8329),
    [anon_sym_POUNDendif2] = ACTIONS(8329),
    [anon_sym_POUNDENDIF2] = ACTIONS(8329),
    [anon_sym_POUNDEndif2] = ACTIONS(8329),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8331),
    [sym_trigger_keyword] = ACTIONS(8331),
    [sym_var_keyword] = ACTIONS(8331),
    [sym_local_keyword] = ACTIONS(8331),
    [sym_internal_keyword] = ACTIONS(8331),
    [sym_protected_keyword] = ACTIONS(8331),
    [sym_event_keyword] = ACTIONS(8331),
    [sym_fields_keyword] = ACTIONS(8331),
    [sym_keys_keyword] = ACTIONS(8331),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8331),
    [sym_actions_keyword] = ACTIONS(8331),
    [sym_layout_keyword] = ACTIONS(8331),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8331),
    [sym_labels_keyword] = ACTIONS(8331),
    [sym_rendering_keyword] = ACTIONS(8331),
    [sym_requestpage_keyword] = ACTIONS(8331),
    [sym_schema_keyword] = ACTIONS(8331),
    [sym_views_keyword] = ACTIONS(8331),
    [sym_quoted_identifier] = ACTIONS(12153),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8329),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_preproc_close] = ACTIONS(8329),
    [sym_var_attribute_open] = ACTIONS(12155),
  },
  [STATE(4931)] = {
    [anon_sym_SEMI] = ACTIONS(8442),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8442),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8442),
    [anon_sym_LBRACK] = ACTIONS(8442),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8442),
    [aux_sym_modify_modification_token1] = ACTIONS(8442),
    [aux_sym_xmlport_element_token1] = ACTIONS(8442),
    [aux_sym_xmlport_element_token2] = ACTIONS(8442),
    [aux_sym_xmlport_element_token3] = ACTIONS(8442),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8442),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8442),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8442),
    [anon_sym_POUNDif] = ACTIONS(8442),
    [anon_sym_POUNDIF] = ACTIONS(8442),
    [anon_sym_POUNDIf] = ACTIONS(8442),
    [anon_sym_POUNDelif] = ACTIONS(8442),
    [anon_sym_POUNDELIF] = ACTIONS(8442),
    [anon_sym_POUNDElif] = ACTIONS(8442),
    [anon_sym_POUNDelse] = ACTIONS(8442),
    [anon_sym_POUNDELSE] = ACTIONS(8442),
    [anon_sym_POUNDElse] = ACTIONS(8442),
    [anon_sym_POUNDelse2] = ACTIONS(8442),
    [anon_sym_POUNDELSE2] = ACTIONS(8442),
    [anon_sym_POUNDElse2] = ACTIONS(8442),
    [anon_sym_POUNDendif] = ACTIONS(8442),
    [anon_sym_POUNDENDIF] = ACTIONS(8442),
    [anon_sym_POUNDEndif] = ACTIONS(8442),
    [anon_sym_POUNDendif2] = ACTIONS(8442),
    [anon_sym_POUNDENDIF2] = ACTIONS(8442),
    [anon_sym_POUNDEndif2] = ACTIONS(8442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8444),
    [sym_page_keyword] = ACTIONS(8442),
    [anon_sym_codeunit] = ACTIONS(8442),
    [anon_sym_CODEUNIT] = ACTIONS(8442),
    [anon_sym_Codeunit] = ACTIONS(8442),
    [anon_sym_CodeUnit] = ACTIONS(8442),
    [anon_sym_COdeunit] = ACTIONS(8442),
    [anon_sym_codeUnit] = ACTIONS(8442),
    [sym_report_keyword] = ACTIONS(8442),
    [sym_query_keyword] = ACTIONS(8442),
    [anon_sym_xmlport] = ACTIONS(8442),
    [anon_sym_XMLPORT] = ACTIONS(8442),
    [anon_sym_Xmlport] = ACTIONS(8442),
    [anon_sym_XMLport] = ACTIONS(8442),
    [anon_sym_XMLPort] = ACTIONS(8442),
    [anon_sym_XmlPort] = ACTIONS(8442),
    [sym_procedure_keyword] = ACTIONS(8442),
    [sym_trigger_keyword] = ACTIONS(8442),
    [sym_var_keyword] = ACTIONS(8442),
    [sym_local_keyword] = ACTIONS(8442),
    [sym_internal_keyword] = ACTIONS(8442),
    [sym_protected_keyword] = ACTIONS(8442),
    [sym_event_keyword] = ACTIONS(8442),
    [sym_fields_keyword] = ACTIONS(8442),
    [sym_keys_keyword] = ACTIONS(8442),
    [sym_fieldgroups_keyword] = ACTIONS(8442),
    [sym_actions_keyword] = ACTIONS(8442),
    [sym_layout_keyword] = ACTIONS(8442),
    [sym_dataset_keyword] = ACTIONS(8442),
    [sym_elements_keyword] = ACTIONS(8442),
    [sym_labels_keyword] = ACTIONS(8442),
    [sym_rendering_keyword] = ACTIONS(8442),
    [sym_requestpage_keyword] = ACTIONS(8442),
    [sym_schema_keyword] = ACTIONS(8442),
    [sym_views_keyword] = ACTIONS(8442),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8442),
    [sym_preproc_open] = ACTIONS(8442),
    [sym_preproc_close] = ACTIONS(8442),
  },
  [STATE(4932)] = {
    [sym_preproc_split_procedure_body] = STATE(5266),
    [sym_preproc_split_complete_body] = STATE(5266),
    [sym_interface_procedure_suffix] = STATE(8220),
    [sym__procedure_return_specification] = STATE(7135),
    [sym__procedure_named_return] = STATE(7136),
    [sym_code_block] = STATE(5266),
    [sym_preproc_conditional_var_block] = STATE(15459),
    [sym_var_section] = STATE(15459),
    [sym_preproc_if] = STATE(10131),
    [sym__identifier_or_quoted] = STATE(16513),
    [sym_keyword_as_identifier] = STATE(16513),
    [sym_identifier] = ACTIONS(12165),
    [anon_sym_SEMI] = ACTIONS(12187),
    [anon_sym_COLON] = ACTIONS(12169),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(12189),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_modify_modification_token1] = ACTIONS(12191),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(12175),
    [anon_sym_POUNDif] = ACTIONS(12193),
    [anon_sym_POUNDIF] = ACTIONS(12193),
    [anon_sym_POUNDIf] = ACTIONS(12193),
    [anon_sym_POUNDelif] = ACTIONS(12196),
    [anon_sym_POUNDELIF] = ACTIONS(12196),
    [anon_sym_POUNDElif] = ACTIONS(12196),
    [anon_sym_POUNDelse] = ACTIONS(12196),
    [anon_sym_POUNDELSE] = ACTIONS(12196),
    [anon_sym_POUNDElse] = ACTIONS(12196),
    [anon_sym_POUNDelse2] = ACTIONS(12196),
    [anon_sym_POUNDELSE2] = ACTIONS(12196),
    [anon_sym_POUNDElse2] = ACTIONS(12196),
    [anon_sym_POUNDendif] = ACTIONS(12196),
    [anon_sym_POUNDENDIF] = ACTIONS(12196),
    [anon_sym_POUNDEndif] = ACTIONS(12196),
    [anon_sym_POUNDendif2] = ACTIONS(12196),
    [anon_sym_POUNDENDIF2] = ACTIONS(12196),
    [anon_sym_POUNDEndif2] = ACTIONS(12196),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(12191),
    [sym_trigger_keyword] = ACTIONS(12191),
    [sym_var_keyword] = ACTIONS(12198),
    [sym_local_keyword] = ACTIONS(12201),
    [sym_internal_keyword] = ACTIONS(12191),
    [sym_protected_keyword] = ACTIONS(12201),
    [sym_event_keyword] = ACTIONS(12191),
    [sym_fields_keyword] = ACTIONS(12191),
    [sym_keys_keyword] = ACTIONS(12191),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(12191),
    [sym_actions_keyword] = ACTIONS(12191),
    [sym_layout_keyword] = ACTIONS(12191),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(12191),
    [sym_labels_keyword] = ACTIONS(12191),
    [sym_rendering_keyword] = ACTIONS(12191),
    [sym_requestpage_keyword] = ACTIONS(12191),
    [sym_schema_keyword] = ACTIONS(12191),
    [sym_views_keyword] = ACTIONS(12191),
    [sym_quoted_identifier] = ACTIONS(12183),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12189),
    [sym_preproc_open] = ACTIONS(12193),
    [sym_preproc_close] = ACTIONS(12196),
    [sym_begin_keyword] = ACTIONS(12185),
  },
  [STATE(4933)] = {
    [anon_sym_SEMI] = ACTIONS(12204),
    [aux_sym_where_condition_token1] = ACTIONS(12206),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(12204),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12204),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12204),
    [anon_sym_LBRACK] = ACTIONS(12204),
    [aux_sym_basic_type_token6] = ACTIONS(12206),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12204),
    [aux_sym_addafter_modification_token1] = ACTIONS(12204),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12204),
    [aux_sym_modify_modification_token1] = ACTIONS(12204),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12204),
    [aux_sym_movelast_modification_token1] = ACTIONS(12204),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12204),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12204),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12204),
    [anon_sym_POUNDif] = ACTIONS(12204),
    [anon_sym_POUNDIF] = ACTIONS(12204),
    [anon_sym_POUNDIf] = ACTIONS(12204),
    [anon_sym_POUNDelif] = ACTIONS(12204),
    [anon_sym_POUNDELIF] = ACTIONS(12204),
    [anon_sym_POUNDElif] = ACTIONS(12204),
    [anon_sym_POUNDelse] = ACTIONS(12204),
    [anon_sym_POUNDELSE] = ACTIONS(12204),
    [anon_sym_POUNDElse] = ACTIONS(12204),
    [anon_sym_POUNDelse2] = ACTIONS(12204),
    [anon_sym_POUNDELSE2] = ACTIONS(12204),
    [anon_sym_POUNDElse2] = ACTIONS(12204),
    [anon_sym_POUNDendif] = ACTIONS(12204),
    [anon_sym_POUNDENDIF] = ACTIONS(12204),
    [anon_sym_POUNDEndif] = ACTIONS(12204),
    [anon_sym_POUNDendif2] = ACTIONS(12204),
    [anon_sym_POUNDENDIF2] = ACTIONS(12204),
    [anon_sym_POUNDEndif2] = ACTIONS(12204),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12204),
    [sym_trigger_keyword] = ACTIONS(12204),
    [sym_var_keyword] = ACTIONS(12204),
    [sym_local_keyword] = ACTIONS(12204),
    [sym_internal_keyword] = ACTIONS(12204),
    [sym_protected_keyword] = ACTIONS(12204),
    [sym_event_keyword] = ACTIONS(12204),
    [sym_fields_keyword] = ACTIONS(12204),
    [sym_keys_keyword] = ACTIONS(12204),
    [sym_fieldgroups_keyword] = ACTIONS(12204),
    [sym_actions_keyword] = ACTIONS(12204),
    [sym_layout_keyword] = ACTIONS(12204),
    [sym_area_keyword] = ACTIONS(12204),
    [sym_group_keyword] = ACTIONS(12204),
    [sym_repeater_keyword] = ACTIONS(12204),
    [sym_cuegroup_keyword] = ACTIONS(12204),
    [sym_fixed_keyword] = ACTIONS(12204),
    [sym_grid_keyword] = ACTIONS(12204),
    [sym_part_keyword] = ACTIONS(12204),
    [sym_systempart_keyword] = ACTIONS(12204),
    [sym_usercontrol_keyword] = ACTIONS(12204),
    [sym_dataset_keyword] = ACTIONS(12204),
    [sym_elements_keyword] = ACTIONS(12204),
    [sym_dataitem_keyword] = ACTIONS(12204),
    [sym_column_keyword] = ACTIONS(12204),
    [sym_filter_keyword] = ACTIONS(12204),
    [sym_labels_keyword] = ACTIONS(12204),
    [sym_rendering_keyword] = ACTIONS(12204),
    [sym_requestpage_keyword] = ACTIONS(12204),
    [sym_schema_keyword] = ACTIONS(12204),
    [sym_views_keyword] = ACTIONS(12204),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12204),
    [sym_preproc_open] = ACTIONS(12204),
    [sym_preproc_close] = ACTIONS(12204),
  },
  [STATE(4934)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5213),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4457),
    [anon_sym_POUNDENDIF] = ACTIONS(4457),
    [anon_sym_POUNDEndif] = ACTIONS(4457),
    [anon_sym_POUNDendif2] = ACTIONS(4457),
    [anon_sym_POUNDENDIF2] = ACTIONS(4457),
    [anon_sym_POUNDEndif2] = ACTIONS(4457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4457),
  },
  [STATE(4935)] = {
    [anon_sym_SEMI] = ACTIONS(8333),
    [anon_sym_RBRACE] = ACTIONS(8333),
    [anon_sym_COMMA] = ACTIONS(8333),
    [aux_sym_where_condition_token1] = ACTIONS(8335),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8333),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8335),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8333),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8333),
    [anon_sym_LBRACK] = ACTIONS(8333),
    [aux_sym_basic_type_token6] = ACTIONS(8335),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8333),
    [aux_sym_addafter_modification_token1] = ACTIONS(8333),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8333),
    [aux_sym_modify_modification_token1] = ACTIONS(8333),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8333),
    [aux_sym_movelast_modification_token1] = ACTIONS(8333),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8333),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8333),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8333),
    [anon_sym_POUNDif] = ACTIONS(8333),
    [anon_sym_POUNDIF] = ACTIONS(8333),
    [anon_sym_POUNDIf] = ACTIONS(8333),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8335),
    [sym_page_keyword] = ACTIONS(8333),
    [anon_sym_codeunit] = ACTIONS(8333),
    [anon_sym_CODEUNIT] = ACTIONS(8333),
    [anon_sym_Codeunit] = ACTIONS(8333),
    [anon_sym_CodeUnit] = ACTIONS(8333),
    [anon_sym_COdeunit] = ACTIONS(8333),
    [anon_sym_codeUnit] = ACTIONS(8333),
    [sym_report_keyword] = ACTIONS(8333),
    [sym_query_keyword] = ACTIONS(8333),
    [anon_sym_xmlport] = ACTIONS(8333),
    [anon_sym_XMLPORT] = ACTIONS(8333),
    [anon_sym_Xmlport] = ACTIONS(8333),
    [anon_sym_XMLport] = ACTIONS(8333),
    [anon_sym_XMLPort] = ACTIONS(8333),
    [anon_sym_XmlPort] = ACTIONS(8333),
    [sym_procedure_keyword] = ACTIONS(8333),
    [sym_trigger_keyword] = ACTIONS(8333),
    [sym_var_keyword] = ACTIONS(8333),
    [sym_local_keyword] = ACTIONS(8333),
    [sym_internal_keyword] = ACTIONS(8333),
    [sym_protected_keyword] = ACTIONS(8333),
    [sym_event_keyword] = ACTIONS(8333),
    [sym_fields_keyword] = ACTIONS(8333),
    [sym_keys_keyword] = ACTIONS(8333),
    [sym_fieldgroups_keyword] = ACTIONS(8333),
    [sym_actions_keyword] = ACTIONS(8333),
    [sym_layout_keyword] = ACTIONS(8333),
    [sym_area_keyword] = ACTIONS(8333),
    [sym_group_keyword] = ACTIONS(8333),
    [sym_repeater_keyword] = ACTIONS(8333),
    [sym_cuegroup_keyword] = ACTIONS(8333),
    [sym_fixed_keyword] = ACTIONS(8333),
    [sym_grid_keyword] = ACTIONS(8333),
    [sym_part_keyword] = ACTIONS(8333),
    [sym_systempart_keyword] = ACTIONS(8333),
    [sym_usercontrol_keyword] = ACTIONS(8333),
    [sym_dataset_keyword] = ACTIONS(8333),
    [sym_elements_keyword] = ACTIONS(8333),
    [sym_labels_keyword] = ACTIONS(8333),
    [sym_rendering_keyword] = ACTIONS(8333),
    [sym_requestpage_keyword] = ACTIONS(8333),
    [sym_schema_keyword] = ACTIONS(8333),
    [sym_views_keyword] = ACTIONS(8333),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8333),
    [sym_preproc_open] = ACTIONS(8333),
  },
  [STATE(4936)] = {
    [sym_preproc_split_procedure] = STATE(4901),
    [sym_var_attribute_item] = STATE(4901),
    [sym_preproc_conditional_var] = STATE(4901),
    [sym_variable_declaration] = STATE(4901),
    [sym_preproc_if] = STATE(3167),
    [sym__identifier_or_quoted] = STATE(15929),
    [sym_keyword_as_identifier] = STATE(15929),
    [aux_sym_var_section_repeat1] = STATE(4901),
    [sym_identifier] = ACTIONS(12151),
    [anon_sym_SEMI] = ACTIONS(8296),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(8296),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_modify_modification_token1] = ACTIONS(8298),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_xmlport_element_token1] = ACTIONS(8298),
    [aux_sym_xmlport_element_token2] = ACTIONS(8298),
    [aux_sym_xmlport_element_token3] = ACTIONS(8298),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8298),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8298),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [anon_sym_POUNDelif] = ACTIONS(8296),
    [anon_sym_POUNDELIF] = ACTIONS(8296),
    [anon_sym_POUNDElif] = ACTIONS(8296),
    [anon_sym_POUNDelse] = ACTIONS(8296),
    [anon_sym_POUNDELSE] = ACTIONS(8296),
    [anon_sym_POUNDElse] = ACTIONS(8296),
    [anon_sym_POUNDelse2] = ACTIONS(8296),
    [anon_sym_POUNDELSE2] = ACTIONS(8296),
    [anon_sym_POUNDElse2] = ACTIONS(8296),
    [anon_sym_POUNDendif] = ACTIONS(8296),
    [anon_sym_POUNDENDIF] = ACTIONS(8296),
    [anon_sym_POUNDEndif] = ACTIONS(8296),
    [anon_sym_POUNDendif2] = ACTIONS(8296),
    [anon_sym_POUNDENDIF2] = ACTIONS(8296),
    [anon_sym_POUNDEndif2] = ACTIONS(8296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8298),
    [sym_trigger_keyword] = ACTIONS(8298),
    [sym_var_keyword] = ACTIONS(8298),
    [sym_local_keyword] = ACTIONS(8298),
    [sym_internal_keyword] = ACTIONS(8298),
    [sym_protected_keyword] = ACTIONS(8298),
    [sym_event_keyword] = ACTIONS(8298),
    [sym_fields_keyword] = ACTIONS(8298),
    [sym_keys_keyword] = ACTIONS(8298),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8298),
    [sym_actions_keyword] = ACTIONS(8298),
    [sym_layout_keyword] = ACTIONS(8298),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8298),
    [sym_labels_keyword] = ACTIONS(8298),
    [sym_rendering_keyword] = ACTIONS(8298),
    [sym_requestpage_keyword] = ACTIONS(8298),
    [sym_schema_keyword] = ACTIONS(8298),
    [sym_views_keyword] = ACTIONS(8298),
    [sym_quoted_identifier] = ACTIONS(12153),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8296),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_preproc_close] = ACTIONS(8296),
    [sym_var_attribute_open] = ACTIONS(12155),
  },
  [STATE(4937)] = {
    [sym_identifier] = ACTIONS(5358),
    [anon_sym_DASH] = ACTIONS(5360),
    [aux_sym_boolean_token1] = ACTIONS(5358),
    [aux_sym_boolean_token2] = ACTIONS(5358),
    [sym_decimal] = ACTIONS(5358),
    [anon_sym_LPAREN] = ACTIONS(5360),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5358),
    [anon_sym_LBRACK] = ACTIONS(5360),
    [aux_sym_record_type_token1] = ACTIONS(5358),
    [aux_sym_basic_type_token21] = ACTIONS(5358),
    [aux_sym_basic_type_token22] = ACTIONS(5358),
    [aux_sym_basic_type_token48] = ACTIONS(5358),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(12126),
    [anon_sym_PIPE_PIPE] = ACTIONS(12128),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(12130),
    [anon_sym_AMP_AMP] = ACTIONS(12132),
    [anon_sym_not] = ACTIONS(5358),
    [anon_sym_NOT] = ACTIONS(5358),
    [anon_sym_Not] = ACTIONS(5358),
    [anon_sym_POUNDelif] = ACTIONS(5360),
    [anon_sym_POUNDELIF] = ACTIONS(5360),
    [anon_sym_POUNDElif] = ACTIONS(5360),
    [anon_sym_POUNDelse] = ACTIONS(5360),
    [anon_sym_POUNDELSE] = ACTIONS(5360),
    [anon_sym_POUNDElse] = ACTIONS(5360),
    [anon_sym_POUNDelse2] = ACTIONS(5360),
    [anon_sym_POUNDELSE2] = ACTIONS(5360),
    [anon_sym_POUNDElse2] = ACTIONS(5360),
    [anon_sym_POUNDendif] = ACTIONS(5360),
    [anon_sym_POUNDENDIF] = ACTIONS(5360),
    [anon_sym_POUNDEndif] = ACTIONS(5360),
    [anon_sym_POUNDendif2] = ACTIONS(5360),
    [anon_sym_POUNDENDIF2] = ACTIONS(5360),
    [anon_sym_POUNDEndif2] = ACTIONS(5360),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(5358),
    [aux_sym_keyword_identifier_token2] = ACTIONS(5358),
    [anon_sym_PLUS] = ACTIONS(5360),
    [sym_datetime_literal] = ACTIONS(5360),
    [sym_date_literal] = ACTIONS(5358),
    [sym_time_literal] = ACTIONS(5358),
    [sym_biginteger_literal] = ACTIONS(5360),
    [sym_page_keyword] = ACTIONS(5358),
    [anon_sym_codeunit] = ACTIONS(5358),
    [anon_sym_CODEUNIT] = ACTIONS(5358),
    [anon_sym_Codeunit] = ACTIONS(5358),
    [anon_sym_CodeUnit] = ACTIONS(5358),
    [anon_sym_COdeunit] = ACTIONS(5358),
    [anon_sym_codeUnit] = ACTIONS(5358),
    [sym_report_keyword] = ACTIONS(5358),
    [sym_query_keyword] = ACTIONS(5358),
    [anon_sym_xmlport] = ACTIONS(5358),
    [anon_sym_XMLPORT] = ACTIONS(5358),
    [anon_sym_Xmlport] = ACTIONS(5358),
    [anon_sym_XMLport] = ACTIONS(5358),
    [anon_sym_XMLPort] = ACTIONS(5358),
    [anon_sym_XmlPort] = ACTIONS(5358),
    [anon_sym_enum] = ACTIONS(5358),
    [anon_sym_ENUM] = ACTIONS(5358),
    [anon_sym_Enum] = ACTIONS(5358),
    [anon_sym_eNUM] = ACTIONS(5358),
    [anon_sym_eNum] = ACTIONS(5358),
    [anon_sym_ENum] = ACTIONS(5358),
    [sym_quoted_identifier] = ACTIONS(5360),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(5360),
    [sym_verbatim_string] = ACTIONS(5360),
    [sym_integer] = ACTIONS(5358),
    [sym_continue_as_identifier] = ACTIONS(5360),
    [sym_preproc_close] = ACTIONS(5360),
  },
  [STATE(4938)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6204),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4939)] = {
    [sym__body_element] = STATE(4914),
    [sym_empty_statement] = STATE(4914),
    [sym_property] = STATE(4914),
    [sym_permissions_property] = STATE(4914),
    [sym_table_relation_property] = STATE(4914),
    [sym_fields_section] = STATE(4914),
    [sym_keys_section] = STATE(4914),
    [sym_fieldgroups_section] = STATE(4914),
    [sym_enum_value_declaration] = STATE(4914),
    [sym_labels_section] = STATE(4914),
    [sym_layout_section] = STATE(4914),
    [sym_modify_modification] = STATE(4914),
    [sym_actions_section] = STATE(4914),
    [sym_views_section] = STATE(4914),
    [sym_dataset_section] = STATE(4914),
    [sym_requestpage_section] = STATE(4914),
    [sym_rendering_section] = STATE(4914),
    [sym_elements_section] = STATE(4914),
    [sym_schema_section] = STATE(4914),
    [sym_assembly_declaration] = STATE(4914),
    [sym_event_declaration] = STATE(4914),
    [sym_procedure] = STATE(4914),
    [sym_preproc_split_procedure] = STATE(4914),
    [sym_preproc_split_procedure_preamble] = STATE(4914),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4914),
    [sym_var_section] = STATE(4914),
    [sym_attribute_item] = STATE(4914),
    [sym_preproc_conditional] = STATE(4914),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5271),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4914),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4940)] = {
    [sym_preproc_split_procedure] = STATE(4904),
    [sym_var_attribute_item] = STATE(4904),
    [sym_preproc_conditional_var] = STATE(4904),
    [sym_variable_declaration] = STATE(4904),
    [sym_preproc_if] = STATE(3167),
    [sym__identifier_or_quoted] = STATE(15929),
    [sym_keyword_as_identifier] = STATE(15929),
    [aux_sym_var_section_repeat1] = STATE(4904),
    [sym_identifier] = ACTIONS(12151),
    [anon_sym_SEMI] = ACTIONS(8296),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(8296),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_modify_modification_token1] = ACTIONS(8298),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_xmlport_element_token1] = ACTIONS(8298),
    [aux_sym_xmlport_element_token2] = ACTIONS(8298),
    [aux_sym_xmlport_element_token3] = ACTIONS(8298),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8298),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8298),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [anon_sym_POUNDif] = ACTIONS(8300),
    [anon_sym_POUNDIF] = ACTIONS(8300),
    [anon_sym_POUNDIf] = ACTIONS(8300),
    [anon_sym_POUNDelif] = ACTIONS(8296),
    [anon_sym_POUNDELIF] = ACTIONS(8296),
    [anon_sym_POUNDElif] = ACTIONS(8296),
    [anon_sym_POUNDelse] = ACTIONS(8296),
    [anon_sym_POUNDELSE] = ACTIONS(8296),
    [anon_sym_POUNDElse] = ACTIONS(8296),
    [anon_sym_POUNDelse2] = ACTIONS(8296),
    [anon_sym_POUNDELSE2] = ACTIONS(8296),
    [anon_sym_POUNDElse2] = ACTIONS(8296),
    [anon_sym_POUNDendif] = ACTIONS(8296),
    [anon_sym_POUNDENDIF] = ACTIONS(8296),
    [anon_sym_POUNDEndif] = ACTIONS(8296),
    [anon_sym_POUNDendif2] = ACTIONS(8296),
    [anon_sym_POUNDENDIF2] = ACTIONS(8296),
    [anon_sym_POUNDEndif2] = ACTIONS(8296),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(8298),
    [sym_trigger_keyword] = ACTIONS(8298),
    [sym_var_keyword] = ACTIONS(8298),
    [sym_local_keyword] = ACTIONS(8298),
    [sym_internal_keyword] = ACTIONS(8298),
    [sym_protected_keyword] = ACTIONS(8298),
    [sym_event_keyword] = ACTIONS(8298),
    [sym_fields_keyword] = ACTIONS(8298),
    [sym_keys_keyword] = ACTIONS(8298),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(8298),
    [sym_actions_keyword] = ACTIONS(8298),
    [sym_layout_keyword] = ACTIONS(8298),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(8298),
    [sym_labels_keyword] = ACTIONS(8298),
    [sym_rendering_keyword] = ACTIONS(8298),
    [sym_requestpage_keyword] = ACTIONS(8298),
    [sym_schema_keyword] = ACTIONS(8298),
    [sym_views_keyword] = ACTIONS(8298),
    [sym_quoted_identifier] = ACTIONS(12153),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8296),
    [sym_preproc_open] = ACTIONS(8300),
    [sym_preproc_close] = ACTIONS(8296),
    [sym_var_attribute_open] = ACTIONS(12155),
  },
  [STATE(4941)] = {
    [sym__body_element] = STATE(4908),
    [sym_empty_statement] = STATE(4908),
    [sym_property] = STATE(4908),
    [sym_permissions_property] = STATE(4908),
    [sym_table_relation_property] = STATE(4908),
    [sym_fields_section] = STATE(4908),
    [sym_keys_section] = STATE(4908),
    [sym_fieldgroups_section] = STATE(4908),
    [sym_enum_value_declaration] = STATE(4908),
    [sym_labels_section] = STATE(4908),
    [sym_layout_section] = STATE(4908),
    [sym_modify_modification] = STATE(4908),
    [sym_actions_section] = STATE(4908),
    [sym_views_section] = STATE(4908),
    [sym_dataset_section] = STATE(4908),
    [sym_requestpage_section] = STATE(4908),
    [sym_rendering_section] = STATE(4908),
    [sym_elements_section] = STATE(4908),
    [sym_schema_section] = STATE(4908),
    [sym_assembly_declaration] = STATE(4908),
    [sym_event_declaration] = STATE(4908),
    [sym_procedure] = STATE(4908),
    [sym_preproc_split_procedure] = STATE(4908),
    [sym_preproc_split_procedure_preamble] = STATE(4908),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4908),
    [sym_var_section] = STATE(4908),
    [sym_attribute_item] = STATE(4908),
    [sym_preproc_conditional] = STATE(4908),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5175),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4908),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4431),
    [anon_sym_POUNDENDIF] = ACTIONS(4431),
    [anon_sym_POUNDEndif] = ACTIONS(4431),
    [anon_sym_POUNDendif2] = ACTIONS(4431),
    [anon_sym_POUNDENDIF2] = ACTIONS(4431),
    [anon_sym_POUNDEndif2] = ACTIONS(4431),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4431),
  },
  [STATE(4942)] = {
    [anon_sym_SEMI] = ACTIONS(8379),
    [anon_sym_RBRACE] = ACTIONS(8379),
    [anon_sym_COMMA] = ACTIONS(12208),
    [aux_sym_where_condition_token1] = ACTIONS(8383),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8379),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8379),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8379),
    [anon_sym_LBRACK] = ACTIONS(8379),
    [aux_sym_basic_type_token6] = ACTIONS(8383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8379),
    [aux_sym_addafter_modification_token1] = ACTIONS(8379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8379),
    [aux_sym_modify_modification_token1] = ACTIONS(8379),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8379),
    [aux_sym_movelast_modification_token1] = ACTIONS(8379),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8379),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8379),
    [anon_sym_POUNDif] = ACTIONS(8379),
    [anon_sym_POUNDIF] = ACTIONS(8379),
    [anon_sym_POUNDIf] = ACTIONS(8379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8383),
    [sym_page_keyword] = ACTIONS(8379),
    [anon_sym_codeunit] = ACTIONS(8379),
    [anon_sym_CODEUNIT] = ACTIONS(8379),
    [anon_sym_Codeunit] = ACTIONS(8379),
    [anon_sym_CodeUnit] = ACTIONS(8379),
    [anon_sym_COdeunit] = ACTIONS(8379),
    [anon_sym_codeUnit] = ACTIONS(8379),
    [sym_report_keyword] = ACTIONS(8379),
    [sym_query_keyword] = ACTIONS(8379),
    [anon_sym_xmlport] = ACTIONS(8379),
    [anon_sym_XMLPORT] = ACTIONS(8379),
    [anon_sym_Xmlport] = ACTIONS(8379),
    [anon_sym_XMLport] = ACTIONS(8379),
    [anon_sym_XMLPort] = ACTIONS(8379),
    [anon_sym_XmlPort] = ACTIONS(8379),
    [sym_procedure_keyword] = ACTIONS(8379),
    [sym_trigger_keyword] = ACTIONS(8379),
    [sym_var_keyword] = ACTIONS(8379),
    [sym_local_keyword] = ACTIONS(8379),
    [sym_internal_keyword] = ACTIONS(8379),
    [sym_protected_keyword] = ACTIONS(8379),
    [sym_event_keyword] = ACTIONS(8379),
    [sym_fields_keyword] = ACTIONS(8379),
    [sym_keys_keyword] = ACTIONS(8379),
    [sym_fieldgroups_keyword] = ACTIONS(8379),
    [sym_actions_keyword] = ACTIONS(8379),
    [sym_layout_keyword] = ACTIONS(8379),
    [sym_area_keyword] = ACTIONS(8379),
    [sym_group_keyword] = ACTIONS(8379),
    [sym_repeater_keyword] = ACTIONS(8379),
    [sym_cuegroup_keyword] = ACTIONS(8379),
    [sym_fixed_keyword] = ACTIONS(8379),
    [sym_grid_keyword] = ACTIONS(8379),
    [sym_part_keyword] = ACTIONS(8379),
    [sym_systempart_keyword] = ACTIONS(8379),
    [sym_usercontrol_keyword] = ACTIONS(8379),
    [sym_dataset_keyword] = ACTIONS(8379),
    [sym_elements_keyword] = ACTIONS(8379),
    [sym_labels_keyword] = ACTIONS(8379),
    [sym_rendering_keyword] = ACTIONS(8379),
    [sym_requestpage_keyword] = ACTIONS(8379),
    [sym_schema_keyword] = ACTIONS(8379),
    [sym_views_keyword] = ACTIONS(8379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8379),
    [sym_preproc_open] = ACTIONS(8379),
  },
  [STATE(4943)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5960),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(4944)] = {
    [sym_preproc_split_procedure_body] = STATE(5266),
    [sym_preproc_split_complete_body] = STATE(5266),
    [sym_interface_procedure_suffix] = STATE(8220),
    [sym__procedure_return_specification] = STATE(7161),
    [sym__procedure_named_return] = STATE(7173),
    [sym_code_block] = STATE(5266),
    [sym_preproc_conditional_var_block] = STATE(15459),
    [sym_var_section] = STATE(15459),
    [sym_preproc_if] = STATE(10131),
    [sym__identifier_or_quoted] = STATE(16513),
    [sym_keyword_as_identifier] = STATE(16513),
    [sym_identifier] = ACTIONS(12165),
    [anon_sym_SEMI] = ACTIONS(12187),
    [anon_sym_COLON] = ACTIONS(12169),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(12189),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_modify_modification_token1] = ACTIONS(12191),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(12175),
    [anon_sym_POUNDif] = ACTIONS(12177),
    [anon_sym_POUNDIF] = ACTIONS(12177),
    [anon_sym_POUNDIf] = ACTIONS(12177),
    [anon_sym_POUNDelif] = ACTIONS(12189),
    [anon_sym_POUNDELIF] = ACTIONS(12189),
    [anon_sym_POUNDElif] = ACTIONS(12189),
    [anon_sym_POUNDelse] = ACTIONS(12189),
    [anon_sym_POUNDELSE] = ACTIONS(12189),
    [anon_sym_POUNDElse] = ACTIONS(12189),
    [anon_sym_POUNDelse2] = ACTIONS(12189),
    [anon_sym_POUNDELSE2] = ACTIONS(12189),
    [anon_sym_POUNDElse2] = ACTIONS(12189),
    [anon_sym_POUNDendif] = ACTIONS(12189),
    [anon_sym_POUNDENDIF] = ACTIONS(12189),
    [anon_sym_POUNDEndif] = ACTIONS(12189),
    [anon_sym_POUNDendif2] = ACTIONS(12189),
    [anon_sym_POUNDENDIF2] = ACTIONS(12189),
    [anon_sym_POUNDEndif2] = ACTIONS(12189),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(12191),
    [sym_trigger_keyword] = ACTIONS(12191),
    [sym_var_keyword] = ACTIONS(12179),
    [sym_local_keyword] = ACTIONS(12181),
    [sym_internal_keyword] = ACTIONS(12191),
    [sym_protected_keyword] = ACTIONS(12181),
    [sym_event_keyword] = ACTIONS(12191),
    [sym_fields_keyword] = ACTIONS(12191),
    [sym_keys_keyword] = ACTIONS(12191),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(12191),
    [sym_actions_keyword] = ACTIONS(12191),
    [sym_layout_keyword] = ACTIONS(12191),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(12191),
    [sym_labels_keyword] = ACTIONS(12191),
    [sym_rendering_keyword] = ACTIONS(12191),
    [sym_requestpage_keyword] = ACTIONS(12191),
    [sym_schema_keyword] = ACTIONS(12191),
    [sym_views_keyword] = ACTIONS(12191),
    [sym_quoted_identifier] = ACTIONS(12183),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12189),
    [sym_preproc_open] = ACTIONS(12177),
    [sym_preproc_close] = ACTIONS(12189),
    [sym_begin_keyword] = ACTIONS(12185),
  },
  [STATE(4945)] = {
    [sym__body_element] = STATE(4950),
    [sym_empty_statement] = STATE(4950),
    [sym_property] = STATE(4950),
    [sym_permissions_property] = STATE(4950),
    [sym_table_relation_property] = STATE(4950),
    [sym_fields_section] = STATE(4950),
    [sym_keys_section] = STATE(4950),
    [sym_fieldgroups_section] = STATE(4950),
    [sym_enum_value_declaration] = STATE(4950),
    [sym_labels_section] = STATE(4950),
    [sym_layout_section] = STATE(4950),
    [sym_modify_modification] = STATE(4950),
    [sym_actions_section] = STATE(4950),
    [sym_views_section] = STATE(4950),
    [sym_dataset_section] = STATE(4950),
    [sym_requestpage_section] = STATE(4950),
    [sym_rendering_section] = STATE(4950),
    [sym_elements_section] = STATE(4950),
    [sym_schema_section] = STATE(4950),
    [sym_assembly_declaration] = STATE(4950),
    [sym_event_declaration] = STATE(4950),
    [sym_procedure] = STATE(4950),
    [sym_preproc_split_procedure] = STATE(4950),
    [sym_preproc_split_procedure_preamble] = STATE(4950),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4950),
    [sym_var_section] = STATE(4950),
    [sym_attribute_item] = STATE(4950),
    [sym_preproc_conditional] = STATE(4950),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5960),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4950),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(4946)] = {
    [sym__object_header] = STATE(14184),
    [sym_preproc_if] = STATE(5423),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [anon_sym_POUNDif] = ACTIONS(12134),
    [anon_sym_POUNDIF] = ACTIONS(12134),
    [anon_sym_POUNDIf] = ACTIONS(12134),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(12134),
  },
  [STATE(4947)] = {
    [sym__object_header] = STATE(14187),
    [sym_preproc_if] = STATE(5424),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [anon_sym_POUNDif] = ACTIONS(12134),
    [anon_sym_POUNDIF] = ACTIONS(12134),
    [anon_sym_POUNDIf] = ACTIONS(12134),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(12134),
  },
  [STATE(4948)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(7623),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(4949)] = {
    [sym__body_element] = STATE(4959),
    [sym_empty_statement] = STATE(4959),
    [sym_property] = STATE(4959),
    [sym_permissions_property] = STATE(4959),
    [sym_table_relation_property] = STATE(4959),
    [sym_fields_section] = STATE(4959),
    [sym_keys_section] = STATE(4959),
    [sym_fieldgroups_section] = STATE(4959),
    [sym_enum_value_declaration] = STATE(4959),
    [sym_labels_section] = STATE(4959),
    [sym_layout_section] = STATE(4959),
    [sym_modify_modification] = STATE(4959),
    [sym_actions_section] = STATE(4959),
    [sym_views_section] = STATE(4959),
    [sym_dataset_section] = STATE(4959),
    [sym_requestpage_section] = STATE(4959),
    [sym_rendering_section] = STATE(4959),
    [sym_elements_section] = STATE(4959),
    [sym_schema_section] = STATE(4959),
    [sym_assembly_declaration] = STATE(4959),
    [sym_event_declaration] = STATE(4959),
    [sym_procedure] = STATE(4959),
    [sym_preproc_split_procedure] = STATE(4959),
    [sym_preproc_split_procedure_preamble] = STATE(4959),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4959),
    [sym_var_section] = STATE(4959),
    [sym_attribute_item] = STATE(4959),
    [sym_preproc_conditional] = STATE(4959),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(7623),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4959),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(4950)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6469),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(4951)] = {
    [anon_sym_SEMI] = ACTIONS(8426),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8426),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8426),
    [anon_sym_LBRACK] = ACTIONS(8426),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8426),
    [aux_sym_modify_modification_token1] = ACTIONS(8426),
    [aux_sym_xmlport_element_token1] = ACTIONS(8426),
    [aux_sym_xmlport_element_token2] = ACTIONS(8426),
    [aux_sym_xmlport_element_token3] = ACTIONS(8426),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8426),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8426),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8426),
    [anon_sym_POUNDif] = ACTIONS(8426),
    [anon_sym_POUNDIF] = ACTIONS(8426),
    [anon_sym_POUNDIf] = ACTIONS(8426),
    [anon_sym_POUNDelif] = ACTIONS(8426),
    [anon_sym_POUNDELIF] = ACTIONS(8426),
    [anon_sym_POUNDElif] = ACTIONS(8426),
    [anon_sym_POUNDelse] = ACTIONS(8426),
    [anon_sym_POUNDELSE] = ACTIONS(8426),
    [anon_sym_POUNDElse] = ACTIONS(8426),
    [anon_sym_POUNDelse2] = ACTIONS(8426),
    [anon_sym_POUNDELSE2] = ACTIONS(8426),
    [anon_sym_POUNDElse2] = ACTIONS(8426),
    [anon_sym_POUNDendif] = ACTIONS(8426),
    [anon_sym_POUNDENDIF] = ACTIONS(8426),
    [anon_sym_POUNDEndif] = ACTIONS(8426),
    [anon_sym_POUNDendif2] = ACTIONS(8426),
    [anon_sym_POUNDENDIF2] = ACTIONS(8426),
    [anon_sym_POUNDEndif2] = ACTIONS(8426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7770),
    [sym_page_keyword] = ACTIONS(8426),
    [anon_sym_codeunit] = ACTIONS(8426),
    [anon_sym_CODEUNIT] = ACTIONS(8426),
    [anon_sym_Codeunit] = ACTIONS(8426),
    [anon_sym_CodeUnit] = ACTIONS(8426),
    [anon_sym_COdeunit] = ACTIONS(8426),
    [anon_sym_codeUnit] = ACTIONS(8426),
    [sym_report_keyword] = ACTIONS(8426),
    [sym_query_keyword] = ACTIONS(8426),
    [anon_sym_xmlport] = ACTIONS(8426),
    [anon_sym_XMLPORT] = ACTIONS(8426),
    [anon_sym_Xmlport] = ACTIONS(8426),
    [anon_sym_XMLport] = ACTIONS(8426),
    [anon_sym_XMLPort] = ACTIONS(8426),
    [anon_sym_XmlPort] = ACTIONS(8426),
    [sym_procedure_keyword] = ACTIONS(8426),
    [sym_trigger_keyword] = ACTIONS(8426),
    [sym_var_keyword] = ACTIONS(8426),
    [sym_local_keyword] = ACTIONS(8426),
    [sym_internal_keyword] = ACTIONS(8426),
    [sym_protected_keyword] = ACTIONS(8426),
    [sym_event_keyword] = ACTIONS(8426),
    [sym_fields_keyword] = ACTIONS(8426),
    [sym_keys_keyword] = ACTIONS(8426),
    [sym_fieldgroups_keyword] = ACTIONS(8426),
    [sym_actions_keyword] = ACTIONS(8426),
    [sym_layout_keyword] = ACTIONS(8426),
    [sym_dataset_keyword] = ACTIONS(8426),
    [sym_elements_keyword] = ACTIONS(8426),
    [sym_labels_keyword] = ACTIONS(8426),
    [sym_rendering_keyword] = ACTIONS(8426),
    [sym_requestpage_keyword] = ACTIONS(8426),
    [sym_schema_keyword] = ACTIONS(8426),
    [sym_views_keyword] = ACTIONS(8426),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8426),
    [sym_preproc_open] = ACTIONS(8426),
    [sym_preproc_close] = ACTIONS(8426),
  },
  [STATE(4952)] = {
    [sym__body_element] = STATE(4919),
    [sym_empty_statement] = STATE(4919),
    [sym_property] = STATE(4919),
    [sym_permissions_property] = STATE(4919),
    [sym_table_relation_property] = STATE(4919),
    [sym_fields_section] = STATE(4919),
    [sym_keys_section] = STATE(4919),
    [sym_fieldgroups_section] = STATE(4919),
    [sym_enum_value_declaration] = STATE(4919),
    [sym_labels_section] = STATE(4919),
    [sym_layout_section] = STATE(4919),
    [sym_modify_modification] = STATE(4919),
    [sym_actions_section] = STATE(4919),
    [sym_views_section] = STATE(4919),
    [sym_dataset_section] = STATE(4919),
    [sym_requestpage_section] = STATE(4919),
    [sym_rendering_section] = STATE(4919),
    [sym_elements_section] = STATE(4919),
    [sym_schema_section] = STATE(4919),
    [sym_assembly_declaration] = STATE(4919),
    [sym_event_declaration] = STATE(4919),
    [sym_procedure] = STATE(4919),
    [sym_preproc_split_procedure] = STATE(4919),
    [sym_preproc_split_procedure_preamble] = STATE(4919),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4919),
    [sym_var_section] = STATE(4919),
    [sym_attribute_item] = STATE(4919),
    [sym_preproc_conditional] = STATE(4919),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6469),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4919),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(4953)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6845),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(4954)] = {
    [sym_preproc_split_procedure_body] = STATE(5273),
    [sym_preproc_split_complete_body] = STATE(5273),
    [sym_interface_procedure_suffix] = STATE(8225),
    [sym__procedure_return_specification] = STATE(7164),
    [sym__procedure_named_return] = STATE(7177),
    [sym_code_block] = STATE(5273),
    [sym_preproc_conditional_var_block] = STATE(15853),
    [sym_var_section] = STATE(15853),
    [sym_preproc_if] = STATE(10131),
    [sym__identifier_or_quoted] = STATE(16513),
    [sym_keyword_as_identifier] = STATE(16513),
    [sym_identifier] = ACTIONS(12165),
    [anon_sym_SEMI] = ACTIONS(12167),
    [anon_sym_COLON] = ACTIONS(12169),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [anon_sym_LBRACK] = ACTIONS(12171),
    [aux_sym_basic_type_token22] = ACTIONS(4043),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_modify_modification_token1] = ACTIONS(12173),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(12175),
    [anon_sym_POUNDif] = ACTIONS(12210),
    [anon_sym_POUNDIF] = ACTIONS(12210),
    [anon_sym_POUNDIf] = ACTIONS(12210),
    [anon_sym_POUNDelif] = ACTIONS(12213),
    [anon_sym_POUNDELIF] = ACTIONS(12213),
    [anon_sym_POUNDElif] = ACTIONS(12213),
    [anon_sym_POUNDelse] = ACTIONS(12213),
    [anon_sym_POUNDELSE] = ACTIONS(12213),
    [anon_sym_POUNDElse] = ACTIONS(12213),
    [anon_sym_POUNDelse2] = ACTIONS(12213),
    [anon_sym_POUNDELSE2] = ACTIONS(12213),
    [anon_sym_POUNDElse2] = ACTIONS(12213),
    [anon_sym_POUNDendif] = ACTIONS(12213),
    [anon_sym_POUNDENDIF] = ACTIONS(12213),
    [anon_sym_POUNDEndif] = ACTIONS(12213),
    [anon_sym_POUNDendif2] = ACTIONS(12213),
    [anon_sym_POUNDENDIF2] = ACTIONS(12213),
    [anon_sym_POUNDEndif2] = ACTIONS(12213),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_procedure_keyword] = ACTIONS(12173),
    [sym_trigger_keyword] = ACTIONS(12173),
    [sym_var_keyword] = ACTIONS(12215),
    [sym_local_keyword] = ACTIONS(12218),
    [sym_internal_keyword] = ACTIONS(12173),
    [sym_protected_keyword] = ACTIONS(12218),
    [sym_event_keyword] = ACTIONS(12173),
    [sym_fields_keyword] = ACTIONS(12173),
    [sym_keys_keyword] = ACTIONS(12173),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_fieldgroups_keyword] = ACTIONS(12173),
    [sym_actions_keyword] = ACTIONS(12173),
    [sym_layout_keyword] = ACTIONS(12173),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_elements_keyword] = ACTIONS(12173),
    [sym_labels_keyword] = ACTIONS(12173),
    [sym_rendering_keyword] = ACTIONS(12173),
    [sym_requestpage_keyword] = ACTIONS(12173),
    [sym_schema_keyword] = ACTIONS(12173),
    [sym_views_keyword] = ACTIONS(12173),
    [sym_quoted_identifier] = ACTIONS(12183),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12171),
    [sym_preproc_open] = ACTIONS(12210),
    [sym_preproc_close] = ACTIONS(12213),
    [sym_begin_keyword] = ACTIONS(12185),
  },
  [STATE(4955)] = {
    [anon_sym_SEMI] = ACTIONS(8428),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8428),
    [anon_sym_LBRACK] = ACTIONS(8428),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8428),
    [aux_sym_modify_modification_token1] = ACTIONS(8428),
    [aux_sym_xmlport_element_token1] = ACTIONS(8428),
    [aux_sym_xmlport_element_token2] = ACTIONS(8428),
    [aux_sym_xmlport_element_token3] = ACTIONS(8428),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8428),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8428),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8428),
    [anon_sym_POUNDif] = ACTIONS(8428),
    [anon_sym_POUNDIF] = ACTIONS(8428),
    [anon_sym_POUNDIf] = ACTIONS(8428),
    [anon_sym_POUNDelif] = ACTIONS(8428),
    [anon_sym_POUNDELIF] = ACTIONS(8428),
    [anon_sym_POUNDElif] = ACTIONS(8428),
    [anon_sym_POUNDelse] = ACTIONS(8428),
    [anon_sym_POUNDELSE] = ACTIONS(8428),
    [anon_sym_POUNDElse] = ACTIONS(8428),
    [anon_sym_POUNDelse2] = ACTIONS(8428),
    [anon_sym_POUNDELSE2] = ACTIONS(8428),
    [anon_sym_POUNDElse2] = ACTIONS(8428),
    [anon_sym_POUNDendif] = ACTIONS(8428),
    [anon_sym_POUNDENDIF] = ACTIONS(8428),
    [anon_sym_POUNDEndif] = ACTIONS(8428),
    [anon_sym_POUNDendif2] = ACTIONS(8428),
    [anon_sym_POUNDENDIF2] = ACTIONS(8428),
    [anon_sym_POUNDEndif2] = ACTIONS(8428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7725),
    [sym_page_keyword] = ACTIONS(8428),
    [anon_sym_codeunit] = ACTIONS(8428),
    [anon_sym_CODEUNIT] = ACTIONS(8428),
    [anon_sym_Codeunit] = ACTIONS(8428),
    [anon_sym_CodeUnit] = ACTIONS(8428),
    [anon_sym_COdeunit] = ACTIONS(8428),
    [anon_sym_codeUnit] = ACTIONS(8428),
    [sym_report_keyword] = ACTIONS(8428),
    [sym_query_keyword] = ACTIONS(8428),
    [anon_sym_xmlport] = ACTIONS(8428),
    [anon_sym_XMLPORT] = ACTIONS(8428),
    [anon_sym_Xmlport] = ACTIONS(8428),
    [anon_sym_XMLport] = ACTIONS(8428),
    [anon_sym_XMLPort] = ACTIONS(8428),
    [anon_sym_XmlPort] = ACTIONS(8428),
    [sym_procedure_keyword] = ACTIONS(8428),
    [sym_trigger_keyword] = ACTIONS(8428),
    [sym_var_keyword] = ACTIONS(8428),
    [sym_local_keyword] = ACTIONS(8428),
    [sym_internal_keyword] = ACTIONS(8428),
    [sym_protected_keyword] = ACTIONS(8428),
    [sym_event_keyword] = ACTIONS(8428),
    [sym_fields_keyword] = ACTIONS(8428),
    [sym_keys_keyword] = ACTIONS(8428),
    [sym_fieldgroups_keyword] = ACTIONS(8428),
    [sym_actions_keyword] = ACTIONS(8428),
    [sym_layout_keyword] = ACTIONS(8428),
    [sym_dataset_keyword] = ACTIONS(8428),
    [sym_elements_keyword] = ACTIONS(8428),
    [sym_labels_keyword] = ACTIONS(8428),
    [sym_rendering_keyword] = ACTIONS(8428),
    [sym_requestpage_keyword] = ACTIONS(8428),
    [sym_schema_keyword] = ACTIONS(8428),
    [sym_views_keyword] = ACTIONS(8428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8428),
    [sym_preproc_open] = ACTIONS(8428),
    [sym_preproc_close] = ACTIONS(8428),
  },
  [STATE(4956)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(9664),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(4957)] = {
    [sym__body_element] = STATE(4966),
    [sym_empty_statement] = STATE(4966),
    [sym_property] = STATE(4966),
    [sym_permissions_property] = STATE(4966),
    [sym_table_relation_property] = STATE(4966),
    [sym_fields_section] = STATE(4966),
    [sym_keys_section] = STATE(4966),
    [sym_fieldgroups_section] = STATE(4966),
    [sym_enum_value_declaration] = STATE(4966),
    [sym_labels_section] = STATE(4966),
    [sym_layout_section] = STATE(4966),
    [sym_modify_modification] = STATE(4966),
    [sym_actions_section] = STATE(4966),
    [sym_views_section] = STATE(4966),
    [sym_dataset_section] = STATE(4966),
    [sym_requestpage_section] = STATE(4966),
    [sym_rendering_section] = STATE(4966),
    [sym_elements_section] = STATE(4966),
    [sym_schema_section] = STATE(4966),
    [sym_assembly_declaration] = STATE(4966),
    [sym_event_declaration] = STATE(4966),
    [sym_procedure] = STATE(4966),
    [sym_preproc_split_procedure] = STATE(4966),
    [sym_preproc_split_procedure_preamble] = STATE(4966),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4966),
    [sym_var_section] = STATE(4966),
    [sym_attribute_item] = STATE(4966),
    [sym_preproc_conditional] = STATE(4966),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(9664),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4966),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(4958)] = {
    [anon_sym_SEMI] = ACTIONS(8446),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8446),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8446),
    [anon_sym_LBRACK] = ACTIONS(8446),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8446),
    [aux_sym_modify_modification_token1] = ACTIONS(8446),
    [aux_sym_xmlport_element_token1] = ACTIONS(8446),
    [aux_sym_xmlport_element_token2] = ACTIONS(8446),
    [aux_sym_xmlport_element_token3] = ACTIONS(8446),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8446),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8446),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8446),
    [anon_sym_POUNDif] = ACTIONS(8446),
    [anon_sym_POUNDIF] = ACTIONS(8446),
    [anon_sym_POUNDIf] = ACTIONS(8446),
    [anon_sym_POUNDelif] = ACTIONS(8446),
    [anon_sym_POUNDELIF] = ACTIONS(8446),
    [anon_sym_POUNDElif] = ACTIONS(8446),
    [anon_sym_POUNDelse] = ACTIONS(8446),
    [anon_sym_POUNDELSE] = ACTIONS(8446),
    [anon_sym_POUNDElse] = ACTIONS(8446),
    [anon_sym_POUNDelse2] = ACTIONS(8446),
    [anon_sym_POUNDELSE2] = ACTIONS(8446),
    [anon_sym_POUNDElse2] = ACTIONS(8446),
    [anon_sym_POUNDendif] = ACTIONS(8446),
    [anon_sym_POUNDENDIF] = ACTIONS(8446),
    [anon_sym_POUNDEndif] = ACTIONS(8446),
    [anon_sym_POUNDendif2] = ACTIONS(8446),
    [anon_sym_POUNDENDIF2] = ACTIONS(8446),
    [anon_sym_POUNDEndif2] = ACTIONS(8446),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8448),
    [sym_page_keyword] = ACTIONS(8446),
    [anon_sym_codeunit] = ACTIONS(8446),
    [anon_sym_CODEUNIT] = ACTIONS(8446),
    [anon_sym_Codeunit] = ACTIONS(8446),
    [anon_sym_CodeUnit] = ACTIONS(8446),
    [anon_sym_COdeunit] = ACTIONS(8446),
    [anon_sym_codeUnit] = ACTIONS(8446),
    [sym_report_keyword] = ACTIONS(8446),
    [sym_query_keyword] = ACTIONS(8446),
    [anon_sym_xmlport] = ACTIONS(8446),
    [anon_sym_XMLPORT] = ACTIONS(8446),
    [anon_sym_Xmlport] = ACTIONS(8446),
    [anon_sym_XMLport] = ACTIONS(8446),
    [anon_sym_XMLPort] = ACTIONS(8446),
    [anon_sym_XmlPort] = ACTIONS(8446),
    [sym_procedure_keyword] = ACTIONS(8446),
    [sym_trigger_keyword] = ACTIONS(8446),
    [sym_var_keyword] = ACTIONS(8446),
    [sym_local_keyword] = ACTIONS(8446),
    [sym_internal_keyword] = ACTIONS(8446),
    [sym_protected_keyword] = ACTIONS(8446),
    [sym_event_keyword] = ACTIONS(8446),
    [sym_fields_keyword] = ACTIONS(8446),
    [sym_keys_keyword] = ACTIONS(8446),
    [sym_fieldgroups_keyword] = ACTIONS(8446),
    [sym_actions_keyword] = ACTIONS(8446),
    [sym_layout_keyword] = ACTIONS(8446),
    [sym_dataset_keyword] = ACTIONS(8446),
    [sym_elements_keyword] = ACTIONS(8446),
    [sym_labels_keyword] = ACTIONS(8446),
    [sym_rendering_keyword] = ACTIONS(8446),
    [sym_requestpage_keyword] = ACTIONS(8446),
    [sym_schema_keyword] = ACTIONS(8446),
    [sym_views_keyword] = ACTIONS(8446),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8446),
    [sym_preproc_open] = ACTIONS(8446),
    [sym_preproc_close] = ACTIONS(8446),
  },
  [STATE(4959)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(7628),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(4960)] = {
    [sym__body_element] = STATE(4965),
    [sym_empty_statement] = STATE(4965),
    [sym_property] = STATE(4965),
    [sym_permissions_property] = STATE(4965),
    [sym_table_relation_property] = STATE(4965),
    [sym_fields_section] = STATE(4965),
    [sym_keys_section] = STATE(4965),
    [sym_fieldgroups_section] = STATE(4965),
    [sym_enum_value_declaration] = STATE(4965),
    [sym_labels_section] = STATE(4965),
    [sym_layout_section] = STATE(4965),
    [sym_modify_modification] = STATE(4965),
    [sym_actions_section] = STATE(4965),
    [sym_views_section] = STATE(4965),
    [sym_dataset_section] = STATE(4965),
    [sym_requestpage_section] = STATE(4965),
    [sym_rendering_section] = STATE(4965),
    [sym_elements_section] = STATE(4965),
    [sym_schema_section] = STATE(4965),
    [sym_assembly_declaration] = STATE(4965),
    [sym_event_declaration] = STATE(4965),
    [sym_procedure] = STATE(4965),
    [sym_preproc_split_procedure] = STATE(4965),
    [sym_preproc_split_procedure_preamble] = STATE(4965),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4965),
    [sym_var_section] = STATE(4965),
    [sym_attribute_item] = STATE(4965),
    [sym_preproc_conditional] = STATE(4965),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(7628),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4965),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(4961)] = {
    [anon_sym_SEMI] = ACTIONS(8434),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8434),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8434),
    [anon_sym_LBRACK] = ACTIONS(8434),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8434),
    [aux_sym_modify_modification_token1] = ACTIONS(8434),
    [aux_sym_xmlport_element_token1] = ACTIONS(8434),
    [aux_sym_xmlport_element_token2] = ACTIONS(8434),
    [aux_sym_xmlport_element_token3] = ACTIONS(8434),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8434),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8434),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8434),
    [anon_sym_POUNDif] = ACTIONS(8434),
    [anon_sym_POUNDIF] = ACTIONS(8434),
    [anon_sym_POUNDIf] = ACTIONS(8434),
    [anon_sym_POUNDelif] = ACTIONS(8434),
    [anon_sym_POUNDELIF] = ACTIONS(8434),
    [anon_sym_POUNDElif] = ACTIONS(8434),
    [anon_sym_POUNDelse] = ACTIONS(8434),
    [anon_sym_POUNDELSE] = ACTIONS(8434),
    [anon_sym_POUNDElse] = ACTIONS(8434),
    [anon_sym_POUNDelse2] = ACTIONS(8434),
    [anon_sym_POUNDELSE2] = ACTIONS(8434),
    [anon_sym_POUNDElse2] = ACTIONS(8434),
    [anon_sym_POUNDendif] = ACTIONS(8434),
    [anon_sym_POUNDENDIF] = ACTIONS(8434),
    [anon_sym_POUNDEndif] = ACTIONS(8434),
    [anon_sym_POUNDendif2] = ACTIONS(8434),
    [anon_sym_POUNDENDIF2] = ACTIONS(8434),
    [anon_sym_POUNDEndif2] = ACTIONS(8434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8436),
    [sym_page_keyword] = ACTIONS(8434),
    [anon_sym_codeunit] = ACTIONS(8434),
    [anon_sym_CODEUNIT] = ACTIONS(8434),
    [anon_sym_Codeunit] = ACTIONS(8434),
    [anon_sym_CodeUnit] = ACTIONS(8434),
    [anon_sym_COdeunit] = ACTIONS(8434),
    [anon_sym_codeUnit] = ACTIONS(8434),
    [sym_report_keyword] = ACTIONS(8434),
    [sym_query_keyword] = ACTIONS(8434),
    [anon_sym_xmlport] = ACTIONS(8434),
    [anon_sym_XMLPORT] = ACTIONS(8434),
    [anon_sym_Xmlport] = ACTIONS(8434),
    [anon_sym_XMLport] = ACTIONS(8434),
    [anon_sym_XMLPort] = ACTIONS(8434),
    [anon_sym_XmlPort] = ACTIONS(8434),
    [sym_procedure_keyword] = ACTIONS(8434),
    [sym_trigger_keyword] = ACTIONS(8434),
    [sym_var_keyword] = ACTIONS(8434),
    [sym_local_keyword] = ACTIONS(8434),
    [sym_internal_keyword] = ACTIONS(8434),
    [sym_protected_keyword] = ACTIONS(8434),
    [sym_event_keyword] = ACTIONS(8434),
    [sym_fields_keyword] = ACTIONS(8434),
    [sym_keys_keyword] = ACTIONS(8434),
    [sym_fieldgroups_keyword] = ACTIONS(8434),
    [sym_actions_keyword] = ACTIONS(8434),
    [sym_layout_keyword] = ACTIONS(8434),
    [sym_dataset_keyword] = ACTIONS(8434),
    [sym_elements_keyword] = ACTIONS(8434),
    [sym_labels_keyword] = ACTIONS(8434),
    [sym_rendering_keyword] = ACTIONS(8434),
    [sym_requestpage_keyword] = ACTIONS(8434),
    [sym_schema_keyword] = ACTIONS(8434),
    [sym_views_keyword] = ACTIONS(8434),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8434),
    [sym_preproc_open] = ACTIONS(8434),
    [sym_preproc_close] = ACTIONS(8434),
  },
  [STATE(4962)] = {
    [sym__body_element] = STATE(4915),
    [sym_empty_statement] = STATE(4915),
    [sym_property] = STATE(4915),
    [sym_permissions_property] = STATE(4915),
    [sym_table_relation_property] = STATE(4915),
    [sym_fields_section] = STATE(4915),
    [sym_keys_section] = STATE(4915),
    [sym_fieldgroups_section] = STATE(4915),
    [sym_enum_value_declaration] = STATE(4915),
    [sym_labels_section] = STATE(4915),
    [sym_layout_section] = STATE(4915),
    [sym_modify_modification] = STATE(4915),
    [sym_actions_section] = STATE(4915),
    [sym_views_section] = STATE(4915),
    [sym_dataset_section] = STATE(4915),
    [sym_requestpage_section] = STATE(4915),
    [sym_rendering_section] = STATE(4915),
    [sym_elements_section] = STATE(4915),
    [sym_schema_section] = STATE(4915),
    [sym_assembly_declaration] = STATE(4915),
    [sym_event_declaration] = STATE(4915),
    [sym_procedure] = STATE(4915),
    [sym_preproc_split_procedure] = STATE(4915),
    [sym_preproc_split_procedure_preamble] = STATE(4915),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4915),
    [sym_var_section] = STATE(4915),
    [sym_attribute_item] = STATE(4915),
    [sym_preproc_conditional] = STATE(4915),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(5960),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4915),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4963)] = {
    [sym__body_element] = STATE(4897),
    [sym_empty_statement] = STATE(4897),
    [sym_property] = STATE(4897),
    [sym_permissions_property] = STATE(4897),
    [sym_table_relation_property] = STATE(4897),
    [sym_fields_section] = STATE(4897),
    [sym_keys_section] = STATE(4897),
    [sym_fieldgroups_section] = STATE(4897),
    [sym_enum_value_declaration] = STATE(4897),
    [sym_labels_section] = STATE(4897),
    [sym_layout_section] = STATE(4897),
    [sym_modify_modification] = STATE(4897),
    [sym_actions_section] = STATE(4897),
    [sym_views_section] = STATE(4897),
    [sym_dataset_section] = STATE(4897),
    [sym_requestpage_section] = STATE(4897),
    [sym_rendering_section] = STATE(4897),
    [sym_elements_section] = STATE(4897),
    [sym_schema_section] = STATE(4897),
    [sym_assembly_declaration] = STATE(4897),
    [sym_event_declaration] = STATE(4897),
    [sym_procedure] = STATE(4897),
    [sym_preproc_split_procedure] = STATE(4897),
    [sym_preproc_split_procedure_preamble] = STATE(4897),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4897),
    [sym_var_section] = STATE(4897),
    [sym_attribute_item] = STATE(4897),
    [sym_preproc_conditional] = STATE(4897),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6214),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4897),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4489),
    [anon_sym_POUNDENDIF] = ACTIONS(4489),
    [anon_sym_POUNDEndif] = ACTIONS(4489),
    [anon_sym_POUNDendif2] = ACTIONS(4489),
    [anon_sym_POUNDENDIF2] = ACTIONS(4489),
    [anon_sym_POUNDEndif2] = ACTIONS(4489),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4489),
  },
  [STATE(4964)] = {
    [sym__body_element] = STATE(4907),
    [sym_empty_statement] = STATE(4907),
    [sym_property] = STATE(4907),
    [sym_permissions_property] = STATE(4907),
    [sym_table_relation_property] = STATE(4907),
    [sym_fields_section] = STATE(4907),
    [sym_keys_section] = STATE(4907),
    [sym_fieldgroups_section] = STATE(4907),
    [sym_enum_value_declaration] = STATE(4907),
    [sym_labels_section] = STATE(4907),
    [sym_layout_section] = STATE(4907),
    [sym_modify_modification] = STATE(4907),
    [sym_actions_section] = STATE(4907),
    [sym_views_section] = STATE(4907),
    [sym_dataset_section] = STATE(4907),
    [sym_requestpage_section] = STATE(4907),
    [sym_rendering_section] = STATE(4907),
    [sym_elements_section] = STATE(4907),
    [sym_schema_section] = STATE(4907),
    [sym_assembly_declaration] = STATE(4907),
    [sym_event_declaration] = STATE(4907),
    [sym_procedure] = STATE(4907),
    [sym_preproc_split_procedure] = STATE(4907),
    [sym_preproc_split_procedure_preamble] = STATE(4907),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4907),
    [sym_var_section] = STATE(4907),
    [sym_attribute_item] = STATE(4907),
    [sym_preproc_conditional] = STATE(4907),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(6845),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4907),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(5009),
    [anon_sym_POUNDENDIF] = ACTIONS(5009),
    [anon_sym_POUNDEndif] = ACTIONS(5009),
    [anon_sym_POUNDendif2] = ACTIONS(5009),
    [anon_sym_POUNDENDIF2] = ACTIONS(5009),
    [anon_sym_POUNDEndif2] = ACTIONS(5009),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(5009),
  },
  [STATE(4965)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(7639),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4385),
    [anon_sym_POUNDENDIF] = ACTIONS(4385),
    [anon_sym_POUNDEndif] = ACTIONS(4385),
    [anon_sym_POUNDendif2] = ACTIONS(4385),
    [anon_sym_POUNDENDIF2] = ACTIONS(4385),
    [anon_sym_POUNDEndif2] = ACTIONS(4385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4385),
  },
  [STATE(4966)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(9699),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(4967)] = {
    [aux_sym_where_condition_token1] = ACTIONS(5372),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(5372),
    [aux_sym_preproc_or_expression_token1] = ACTIONS(12157),
    [anon_sym_PIPE_PIPE] = ACTIONS(12157),
    [aux_sym_preproc_and_expression_token1] = ACTIONS(12159),
    [anon_sym_AMP_AMP] = ACTIONS(12159),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_if] = ACTIONS(5372),
    [anon_sym_IF] = ACTIONS(5372),
    [anon_sym_If] = ACTIONS(5372),
    [sym_table_keyword] = ACTIONS(5370),
    [anon_sym_tableextension] = ACTIONS(5372),
    [anon_sym_TABLEEXTENSION] = ACTIONS(5372),
    [anon_sym_Tableextension] = ACTIONS(5372),
    [anon_sym_TableExtension] = ACTIONS(5372),
    [anon_sym_tableExtension] = ACTIONS(5372),
    [sym_page_keyword] = ACTIONS(5370),
    [anon_sym_pageextension] = ACTIONS(5372),
    [anon_sym_PAGEEXTENSION] = ACTIONS(5372),
    [anon_sym_Pageextension] = ACTIONS(5372),
    [anon_sym_PageExtension] = ACTIONS(5372),
    [anon_sym_pageExtension] = ACTIONS(5372),
    [anon_sym_codeunit] = ACTIONS(5372),
    [anon_sym_CODEUNIT] = ACTIONS(5372),
    [anon_sym_Codeunit] = ACTIONS(5372),
    [anon_sym_CodeUnit] = ACTIONS(5372),
    [anon_sym_COdeunit] = ACTIONS(5372),
    [anon_sym_codeUnit] = ACTIONS(5372),
    [sym_report_keyword] = ACTIONS(5370),
    [anon_sym_reportextension] = ACTIONS(5372),
    [anon_sym_REPORTEXTENSION] = ACTIONS(5372),
    [anon_sym_Reportextension] = ACTIONS(5372),
    [anon_sym_ReportExtension] = ACTIONS(5372),
    [anon_sym_reportExtension] = ACTIONS(5372),
    [sym_query_keyword] = ACTIONS(5372),
    [anon_sym_xmlport] = ACTIONS(5372),
    [anon_sym_XMLPORT] = ACTIONS(5372),
    [anon_sym_Xmlport] = ACTIONS(5372),
    [anon_sym_XMLport] = ACTIONS(5372),
    [anon_sym_XMLPort] = ACTIONS(5372),
    [anon_sym_XmlPort] = ACTIONS(5372),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_ENUM] = ACTIONS(5370),
    [anon_sym_Enum] = ACTIONS(5370),
    [anon_sym_eNUM] = ACTIONS(5372),
    [anon_sym_eNum] = ACTIONS(5372),
    [anon_sym_ENum] = ACTIONS(5372),
    [anon_sym_enumextension] = ACTIONS(5372),
    [anon_sym_ENUMEXTENSION] = ACTIONS(5372),
    [anon_sym_Enumextension] = ACTIONS(5372),
    [anon_sym_EnumExtension] = ACTIONS(5372),
    [anon_sym_enumExtension] = ACTIONS(5372),
    [sym_interface_keyword] = ACTIONS(5372),
    [anon_sym_permissionset] = ACTIONS(5370),
    [anon_sym_PERMISSIONSET] = ACTIONS(5370),
    [anon_sym_Permissionset] = ACTIONS(5370),
    [anon_sym_PermissionSet] = ACTIONS(5370),
    [anon_sym_permissionSet] = ACTIONS(5370),
    [anon_sym_permissionsetextension] = ACTIONS(5372),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(5372),
    [anon_sym_Permissionsetextension] = ACTIONS(5372),
    [anon_sym_PermissionSetExtension] = ACTIONS(5372),
    [anon_sym_permissionSetExtension] = ACTIONS(5372),
    [sym_procedure_keyword] = ACTIONS(5372),
    [sym_var_keyword] = ACTIONS(5372),
    [sym_local_keyword] = ACTIONS(5372),
    [sym_internal_keyword] = ACTIONS(5372),
    [sym_protected_keyword] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(4968)] = {
    [anon_sym_SEMI] = ACTIONS(8430),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8430),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8430),
    [anon_sym_LBRACK] = ACTIONS(8430),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8430),
    [aux_sym_modify_modification_token1] = ACTIONS(8430),
    [aux_sym_xmlport_element_token1] = ACTIONS(8430),
    [aux_sym_xmlport_element_token2] = ACTIONS(8430),
    [aux_sym_xmlport_element_token3] = ACTIONS(8430),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8430),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8430),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8430),
    [anon_sym_POUNDif] = ACTIONS(8430),
    [anon_sym_POUNDIF] = ACTIONS(8430),
    [anon_sym_POUNDIf] = ACTIONS(8430),
    [anon_sym_POUNDelif] = ACTIONS(8430),
    [anon_sym_POUNDELIF] = ACTIONS(8430),
    [anon_sym_POUNDElif] = ACTIONS(8430),
    [anon_sym_POUNDelse] = ACTIONS(8430),
    [anon_sym_POUNDELSE] = ACTIONS(8430),
    [anon_sym_POUNDElse] = ACTIONS(8430),
    [anon_sym_POUNDelse2] = ACTIONS(8430),
    [anon_sym_POUNDELSE2] = ACTIONS(8430),
    [anon_sym_POUNDElse2] = ACTIONS(8430),
    [anon_sym_POUNDendif] = ACTIONS(8430),
    [anon_sym_POUNDENDIF] = ACTIONS(8430),
    [anon_sym_POUNDEndif] = ACTIONS(8430),
    [anon_sym_POUNDendif2] = ACTIONS(8430),
    [anon_sym_POUNDENDIF2] = ACTIONS(8430),
    [anon_sym_POUNDEndif2] = ACTIONS(8430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8432),
    [sym_page_keyword] = ACTIONS(8430),
    [anon_sym_codeunit] = ACTIONS(8430),
    [anon_sym_CODEUNIT] = ACTIONS(8430),
    [anon_sym_Codeunit] = ACTIONS(8430),
    [anon_sym_CodeUnit] = ACTIONS(8430),
    [anon_sym_COdeunit] = ACTIONS(8430),
    [anon_sym_codeUnit] = ACTIONS(8430),
    [sym_report_keyword] = ACTIONS(8430),
    [sym_query_keyword] = ACTIONS(8430),
    [anon_sym_xmlport] = ACTIONS(8430),
    [anon_sym_XMLPORT] = ACTIONS(8430),
    [anon_sym_Xmlport] = ACTIONS(8430),
    [anon_sym_XMLport] = ACTIONS(8430),
    [anon_sym_XMLPort] = ACTIONS(8430),
    [anon_sym_XmlPort] = ACTIONS(8430),
    [sym_procedure_keyword] = ACTIONS(8430),
    [sym_trigger_keyword] = ACTIONS(8430),
    [sym_var_keyword] = ACTIONS(8430),
    [sym_local_keyword] = ACTIONS(8430),
    [sym_internal_keyword] = ACTIONS(8430),
    [sym_protected_keyword] = ACTIONS(8430),
    [sym_event_keyword] = ACTIONS(8430),
    [sym_fields_keyword] = ACTIONS(8430),
    [sym_keys_keyword] = ACTIONS(8430),
    [sym_fieldgroups_keyword] = ACTIONS(8430),
    [sym_actions_keyword] = ACTIONS(8430),
    [sym_layout_keyword] = ACTIONS(8430),
    [sym_dataset_keyword] = ACTIONS(8430),
    [sym_elements_keyword] = ACTIONS(8430),
    [sym_labels_keyword] = ACTIONS(8430),
    [sym_rendering_keyword] = ACTIONS(8430),
    [sym_requestpage_keyword] = ACTIONS(8430),
    [sym_schema_keyword] = ACTIONS(8430),
    [sym_views_keyword] = ACTIONS(8430),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8430),
    [sym_preproc_open] = ACTIONS(8430),
    [sym_preproc_close] = ACTIONS(8430),
  },
  [STATE(4969)] = {
    [sym__body_element] = STATE(4970),
    [sym_empty_statement] = STATE(4970),
    [sym_property] = STATE(4970),
    [sym_permissions_property] = STATE(4970),
    [sym_table_relation_property] = STATE(4970),
    [sym_fields_section] = STATE(4970),
    [sym_keys_section] = STATE(4970),
    [sym_fieldgroups_section] = STATE(4970),
    [sym_enum_value_declaration] = STATE(4970),
    [sym_labels_section] = STATE(4970),
    [sym_layout_section] = STATE(4970),
    [sym_modify_modification] = STATE(4970),
    [sym_actions_section] = STATE(4970),
    [sym_views_section] = STATE(4970),
    [sym_dataset_section] = STATE(4970),
    [sym_requestpage_section] = STATE(4970),
    [sym_rendering_section] = STATE(4970),
    [sym_elements_section] = STATE(4970),
    [sym_schema_section] = STATE(4970),
    [sym_assembly_declaration] = STATE(4970),
    [sym_event_declaration] = STATE(4970),
    [sym_procedure] = STATE(4970),
    [sym_preproc_split_procedure] = STATE(4970),
    [sym_preproc_split_procedure_preamble] = STATE(4970),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4970),
    [sym_var_section] = STATE(4970),
    [sym_attribute_item] = STATE(4970),
    [sym_preproc_conditional] = STATE(4970),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(9699),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4970),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(4970)] = {
    [sym__body_element] = STATE(4009),
    [sym_empty_statement] = STATE(4009),
    [sym_property] = STATE(4009),
    [sym_permissions_property] = STATE(4009),
    [sym_table_relation_property] = STATE(4009),
    [sym_fields_section] = STATE(4009),
    [sym_keys_section] = STATE(4009),
    [sym_fieldgroups_section] = STATE(4009),
    [sym_enum_value_declaration] = STATE(4009),
    [sym_labels_section] = STATE(4009),
    [sym_layout_section] = STATE(4009),
    [sym_modify_modification] = STATE(4009),
    [sym_actions_section] = STATE(4009),
    [sym_views_section] = STATE(4009),
    [sym_dataset_section] = STATE(4009),
    [sym_requestpage_section] = STATE(4009),
    [sym_rendering_section] = STATE(4009),
    [sym_elements_section] = STATE(4009),
    [sym_schema_section] = STATE(4009),
    [sym_assembly_declaration] = STATE(4009),
    [sym_event_declaration] = STATE(4009),
    [sym_procedure] = STATE(4009),
    [sym_preproc_split_procedure] = STATE(4009),
    [sym_preproc_split_procedure_preamble] = STATE(4009),
    [sym_procedure_modifier] = STATE(17531),
    [sym_trigger_declaration] = STATE(4009),
    [sym_var_section] = STATE(4009),
    [sym_attribute_item] = STATE(4009),
    [sym_preproc_conditional] = STATE(4009),
    [sym_preproc_if] = STATE(3659),
    [sym_preproc_endif] = STATE(9185),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_LBRACK] = ACTIONS(4196),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4200),
    [aux_sym_modify_modification_token1] = ACTIONS(4206),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4216),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [anon_sym_POUNDendif] = ACTIONS(4427),
    [anon_sym_POUNDENDIF] = ACTIONS(4427),
    [anon_sym_POUNDEndif] = ACTIONS(4427),
    [anon_sym_POUNDendif2] = ACTIONS(4427),
    [anon_sym_POUNDENDIF2] = ACTIONS(4427),
    [anon_sym_POUNDEndif2] = ACTIONS(4427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(4609),
    [sym_trigger_keyword] = ACTIONS(4461),
    [sym_var_keyword] = ACTIONS(4230),
    [sym_local_keyword] = ACTIONS(4232),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(4232),
    [sym_event_keyword] = ACTIONS(4236),
    [sym_fields_keyword] = ACTIONS(4238),
    [sym_keys_keyword] = ACTIONS(4240),
    [sym_fieldgroups_keyword] = ACTIONS(4242),
    [sym_actions_keyword] = ACTIONS(4244),
    [sym_layout_keyword] = ACTIONS(4246),
    [sym_dataset_keyword] = ACTIONS(4266),
    [sym_elements_keyword] = ACTIONS(4268),
    [sym_labels_keyword] = ACTIONS(4270),
    [sym_rendering_keyword] = ACTIONS(4272),
    [sym_requestpage_keyword] = ACTIONS(4274),
    [sym_schema_keyword] = ACTIONS(4276),
    [sym_views_keyword] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(4481),
    [sym_preproc_open] = ACTIONS(4218),
    [sym_preproc_close] = ACTIONS(4427),
  },
  [STATE(4971)] = {
    [anon_sym_SEMI] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7785),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_xmlport_element_token1] = ACTIONS(7785),
    [aux_sym_xmlport_element_token2] = ACTIONS(7785),
    [aux_sym_xmlport_element_token3] = ACTIONS(7785),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7785),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7785),
    [anon_sym_POUNDIF] = ACTIONS(7785),
    [anon_sym_POUNDIf] = ACTIONS(7785),
    [anon_sym_POUNDelif] = ACTIONS(7785),
    [anon_sym_POUNDELIF] = ACTIONS(7785),
    [anon_sym_POUNDElif] = ACTIONS(7785),
    [anon_sym_POUNDelse] = ACTIONS(7785),
    [anon_sym_POUNDELSE] = ACTIONS(7785),
    [anon_sym_POUNDElse] = ACTIONS(7785),
    [anon_sym_POUNDelse2] = ACTIONS(7785),
    [anon_sym_POUNDELSE2] = ACTIONS(7785),
    [anon_sym_POUNDElse2] = ACTIONS(7785),
    [anon_sym_POUNDendif] = ACTIONS(7785),
    [anon_sym_POUNDENDIF] = ACTIONS(7785),
    [anon_sym_POUNDEndif] = ACTIONS(7785),
    [anon_sym_POUNDendif2] = ACTIONS(7785),
    [anon_sym_POUNDENDIF2] = ACTIONS(7785),
    [anon_sym_POUNDEndif2] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7787),
    [sym_page_keyword] = ACTIONS(7785),
    [anon_sym_codeunit] = ACTIONS(7785),
    [anon_sym_CODEUNIT] = ACTIONS(7785),
    [anon_sym_Codeunit] = ACTIONS(7785),
    [anon_sym_CodeUnit] = ACTIONS(7785),
    [anon_sym_COdeunit] = ACTIONS(7785),
    [anon_sym_codeUnit] = ACTIONS(7785),
    [sym_report_keyword] = ACTIONS(7785),
    [sym_query_keyword] = ACTIONS(7785),
    [anon_sym_xmlport] = ACTIONS(7785),
    [anon_sym_XMLPORT] = ACTIONS(7785),
    [anon_sym_Xmlport] = ACTIONS(7785),
    [anon_sym_XMLport] = ACTIONS(7785),
    [anon_sym_XMLPort] = ACTIONS(7785),
    [anon_sym_XmlPort] = ACTIONS(7785),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7785),
    [sym_preproc_close] = ACTIONS(7785),
  },
  [STATE(4972)] = {
    [anon_sym_SEMI] = ACTIONS(12221),
    [aux_sym_where_condition_token1] = ACTIONS(12223),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12225),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12225),
    [anon_sym_LBRACK] = ACTIONS(12225),
    [aux_sym_basic_type_token6] = ACTIONS(12223),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12225),
    [aux_sym_addafter_modification_token1] = ACTIONS(12225),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12225),
    [aux_sym_modify_modification_token1] = ACTIONS(12225),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12225),
    [aux_sym_movelast_modification_token1] = ACTIONS(12225),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12225),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12225),
    [anon_sym_POUNDif] = ACTIONS(12225),
    [anon_sym_POUNDIF] = ACTIONS(12225),
    [anon_sym_POUNDIf] = ACTIONS(12225),
    [anon_sym_POUNDelif] = ACTIONS(12225),
    [anon_sym_POUNDELIF] = ACTIONS(12225),
    [anon_sym_POUNDElif] = ACTIONS(12225),
    [anon_sym_POUNDelse] = ACTIONS(12225),
    [anon_sym_POUNDELSE] = ACTIONS(12225),
    [anon_sym_POUNDElse] = ACTIONS(12225),
    [anon_sym_POUNDelse2] = ACTIONS(12225),
    [anon_sym_POUNDELSE2] = ACTIONS(12225),
    [anon_sym_POUNDElse2] = ACTIONS(12225),
    [anon_sym_POUNDendif] = ACTIONS(12225),
    [anon_sym_POUNDENDIF] = ACTIONS(12225),
    [anon_sym_POUNDEndif] = ACTIONS(12225),
    [anon_sym_POUNDendif2] = ACTIONS(12225),
    [anon_sym_POUNDENDIF2] = ACTIONS(12225),
    [anon_sym_POUNDEndif2] = ACTIONS(12225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12225),
    [sym_trigger_keyword] = ACTIONS(12225),
    [sym_var_keyword] = ACTIONS(12225),
    [sym_local_keyword] = ACTIONS(12225),
    [sym_internal_keyword] = ACTIONS(12225),
    [sym_protected_keyword] = ACTIONS(12225),
    [sym_event_keyword] = ACTIONS(12225),
    [sym_fields_keyword] = ACTIONS(12225),
    [sym_keys_keyword] = ACTIONS(12225),
    [sym_fieldgroups_keyword] = ACTIONS(12225),
    [sym_actions_keyword] = ACTIONS(12225),
    [sym_layout_keyword] = ACTIONS(12225),
    [sym_area_keyword] = ACTIONS(12225),
    [sym_group_keyword] = ACTIONS(12225),
    [sym_repeater_keyword] = ACTIONS(12225),
    [sym_cuegroup_keyword] = ACTIONS(12225),
    [sym_fixed_keyword] = ACTIONS(12225),
    [sym_grid_keyword] = ACTIONS(12225),
    [sym_part_keyword] = ACTIONS(12225),
    [sym_systempart_keyword] = ACTIONS(12225),
    [sym_usercontrol_keyword] = ACTIONS(12225),
    [sym_dataset_keyword] = ACTIONS(12225),
    [sym_elements_keyword] = ACTIONS(12225),
    [sym_dataitem_keyword] = ACTIONS(12225),
    [sym_column_keyword] = ACTIONS(12225),
    [sym_filter_keyword] = ACTIONS(12225),
    [sym_labels_keyword] = ACTIONS(12225),
    [sym_rendering_keyword] = ACTIONS(12225),
    [sym_requestpage_keyword] = ACTIONS(12225),
    [sym_schema_keyword] = ACTIONS(12225),
    [sym_views_keyword] = ACTIONS(12225),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12225),
    [sym_preproc_open] = ACTIONS(12225),
    [sym_preproc_close] = ACTIONS(12225),
  },
  [STATE(4973)] = {
    [anon_sym_SEMI] = ACTIONS(12227),
    [aux_sym_where_condition_token1] = ACTIONS(12229),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12227),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12227),
    [anon_sym_LBRACK] = ACTIONS(12227),
    [aux_sym_basic_type_token6] = ACTIONS(12229),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12227),
    [aux_sym_addafter_modification_token1] = ACTIONS(12227),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12227),
    [aux_sym_modify_modification_token1] = ACTIONS(12227),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12227),
    [aux_sym_movelast_modification_token1] = ACTIONS(12227),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12227),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12227),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12227),
    [anon_sym_POUNDif] = ACTIONS(12227),
    [anon_sym_POUNDIF] = ACTIONS(12227),
    [anon_sym_POUNDIf] = ACTIONS(12227),
    [anon_sym_POUNDelif] = ACTIONS(12227),
    [anon_sym_POUNDELIF] = ACTIONS(12227),
    [anon_sym_POUNDElif] = ACTIONS(12227),
    [anon_sym_POUNDelse] = ACTIONS(12227),
    [anon_sym_POUNDELSE] = ACTIONS(12227),
    [anon_sym_POUNDElse] = ACTIONS(12227),
    [anon_sym_POUNDelse2] = ACTIONS(12227),
    [anon_sym_POUNDELSE2] = ACTIONS(12227),
    [anon_sym_POUNDElse2] = ACTIONS(12227),
    [anon_sym_POUNDendif] = ACTIONS(12227),
    [anon_sym_POUNDENDIF] = ACTIONS(12227),
    [anon_sym_POUNDEndif] = ACTIONS(12227),
    [anon_sym_POUNDendif2] = ACTIONS(12227),
    [anon_sym_POUNDENDIF2] = ACTIONS(12227),
    [anon_sym_POUNDEndif2] = ACTIONS(12227),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12227),
    [sym_trigger_keyword] = ACTIONS(12227),
    [sym_var_keyword] = ACTIONS(12227),
    [sym_local_keyword] = ACTIONS(12227),
    [sym_internal_keyword] = ACTIONS(12227),
    [sym_protected_keyword] = ACTIONS(12227),
    [sym_event_keyword] = ACTIONS(12227),
    [sym_fields_keyword] = ACTIONS(12227),
    [sym_keys_keyword] = ACTIONS(12227),
    [sym_fieldgroups_keyword] = ACTIONS(12227),
    [sym_actions_keyword] = ACTIONS(12227),
    [sym_layout_keyword] = ACTIONS(12227),
    [sym_area_keyword] = ACTIONS(12227),
    [sym_group_keyword] = ACTIONS(12227),
    [sym_repeater_keyword] = ACTIONS(12227),
    [sym_cuegroup_keyword] = ACTIONS(12227),
    [sym_fixed_keyword] = ACTIONS(12227),
    [sym_grid_keyword] = ACTIONS(12227),
    [sym_part_keyword] = ACTIONS(12227),
    [sym_systempart_keyword] = ACTIONS(12227),
    [sym_usercontrol_keyword] = ACTIONS(12227),
    [sym_dataset_keyword] = ACTIONS(12227),
    [sym_elements_keyword] = ACTIONS(12227),
    [sym_dataitem_keyword] = ACTIONS(12227),
    [sym_column_keyword] = ACTIONS(12227),
    [sym_filter_keyword] = ACTIONS(12227),
    [sym_labels_keyword] = ACTIONS(12227),
    [sym_rendering_keyword] = ACTIONS(12227),
    [sym_requestpage_keyword] = ACTIONS(12227),
    [sym_schema_keyword] = ACTIONS(12227),
    [sym_views_keyword] = ACTIONS(12227),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12227),
    [sym_preproc_open] = ACTIONS(12227),
    [sym_preproc_close] = ACTIONS(12227),
  },
  [STATE(4974)] = {
    [anon_sym_SEMI] = ACTIONS(12227),
    [aux_sym_where_condition_token1] = ACTIONS(12229),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12227),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12227),
    [anon_sym_LBRACK] = ACTIONS(12227),
    [aux_sym_basic_type_token6] = ACTIONS(12229),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12227),
    [aux_sym_addafter_modification_token1] = ACTIONS(12227),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12227),
    [aux_sym_modify_modification_token1] = ACTIONS(12227),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12227),
    [aux_sym_movelast_modification_token1] = ACTIONS(12227),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12227),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12227),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12227),
    [anon_sym_POUNDif] = ACTIONS(12227),
    [anon_sym_POUNDIF] = ACTIONS(12227),
    [anon_sym_POUNDIf] = ACTIONS(12227),
    [anon_sym_POUNDelif] = ACTIONS(12227),
    [anon_sym_POUNDELIF] = ACTIONS(12227),
    [anon_sym_POUNDElif] = ACTIONS(12227),
    [anon_sym_POUNDelse] = ACTIONS(12227),
    [anon_sym_POUNDELSE] = ACTIONS(12227),
    [anon_sym_POUNDElse] = ACTIONS(12227),
    [anon_sym_POUNDelse2] = ACTIONS(12227),
    [anon_sym_POUNDELSE2] = ACTIONS(12227),
    [anon_sym_POUNDElse2] = ACTIONS(12227),
    [anon_sym_POUNDendif] = ACTIONS(12227),
    [anon_sym_POUNDENDIF] = ACTIONS(12227),
    [anon_sym_POUNDEndif] = ACTIONS(12227),
    [anon_sym_POUNDendif2] = ACTIONS(12227),
    [anon_sym_POUNDENDIF2] = ACTIONS(12227),
    [anon_sym_POUNDEndif2] = ACTIONS(12227),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12227),
    [sym_trigger_keyword] = ACTIONS(12227),
    [sym_var_keyword] = ACTIONS(12227),
    [sym_local_keyword] = ACTIONS(12227),
    [sym_internal_keyword] = ACTIONS(12227),
    [sym_protected_keyword] = ACTIONS(12227),
    [sym_event_keyword] = ACTIONS(12227),
    [sym_fields_keyword] = ACTIONS(12227),
    [sym_keys_keyword] = ACTIONS(12227),
    [sym_fieldgroups_keyword] = ACTIONS(12227),
    [sym_actions_keyword] = ACTIONS(12227),
    [sym_layout_keyword] = ACTIONS(12227),
    [sym_area_keyword] = ACTIONS(12227),
    [sym_group_keyword] = ACTIONS(12227),
    [sym_repeater_keyword] = ACTIONS(12227),
    [sym_cuegroup_keyword] = ACTIONS(12227),
    [sym_fixed_keyword] = ACTIONS(12227),
    [sym_grid_keyword] = ACTIONS(12227),
    [sym_part_keyword] = ACTIONS(12227),
    [sym_systempart_keyword] = ACTIONS(12227),
    [sym_usercontrol_keyword] = ACTIONS(12227),
    [sym_dataset_keyword] = ACTIONS(12227),
    [sym_elements_keyword] = ACTIONS(12227),
    [sym_dataitem_keyword] = ACTIONS(12227),
    [sym_column_keyword] = ACTIONS(12227),
    [sym_filter_keyword] = ACTIONS(12227),
    [sym_labels_keyword] = ACTIONS(12227),
    [sym_rendering_keyword] = ACTIONS(12227),
    [sym_requestpage_keyword] = ACTIONS(12227),
    [sym_schema_keyword] = ACTIONS(12227),
    [sym_views_keyword] = ACTIONS(12227),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12227),
    [sym_preproc_open] = ACTIONS(12227),
    [sym_preproc_close] = ACTIONS(12227),
  },
  [STATE(4975)] = {
    [anon_sym_SEMI] = ACTIONS(12227),
    [aux_sym_where_condition_token1] = ACTIONS(12229),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12227),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12227),
    [anon_sym_LBRACK] = ACTIONS(12227),
    [aux_sym_basic_type_token6] = ACTIONS(12229),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12227),
    [aux_sym_addafter_modification_token1] = ACTIONS(12227),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12227),
    [aux_sym_modify_modification_token1] = ACTIONS(12227),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12227),
    [aux_sym_movelast_modification_token1] = ACTIONS(12227),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12227),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12227),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12227),
    [anon_sym_POUNDif] = ACTIONS(12227),
    [anon_sym_POUNDIF] = ACTIONS(12227),
    [anon_sym_POUNDIf] = ACTIONS(12227),
    [anon_sym_POUNDelif] = ACTIONS(12227),
    [anon_sym_POUNDELIF] = ACTIONS(12227),
    [anon_sym_POUNDElif] = ACTIONS(12227),
    [anon_sym_POUNDelse] = ACTIONS(12227),
    [anon_sym_POUNDELSE] = ACTIONS(12227),
    [anon_sym_POUNDElse] = ACTIONS(12227),
    [anon_sym_POUNDelse2] = ACTIONS(12227),
    [anon_sym_POUNDELSE2] = ACTIONS(12227),
    [anon_sym_POUNDElse2] = ACTIONS(12227),
    [anon_sym_POUNDendif] = ACTIONS(12227),
    [anon_sym_POUNDENDIF] = ACTIONS(12227),
    [anon_sym_POUNDEndif] = ACTIONS(12227),
    [anon_sym_POUNDendif2] = ACTIONS(12227),
    [anon_sym_POUNDENDIF2] = ACTIONS(12227),
    [anon_sym_POUNDEndif2] = ACTIONS(12227),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12227),
    [sym_trigger_keyword] = ACTIONS(12227),
    [sym_var_keyword] = ACTIONS(12227),
    [sym_local_keyword] = ACTIONS(12227),
    [sym_internal_keyword] = ACTIONS(12227),
    [sym_protected_keyword] = ACTIONS(12227),
    [sym_event_keyword] = ACTIONS(12227),
    [sym_fields_keyword] = ACTIONS(12227),
    [sym_keys_keyword] = ACTIONS(12227),
    [sym_fieldgroups_keyword] = ACTIONS(12227),
    [sym_actions_keyword] = ACTIONS(12227),
    [sym_layout_keyword] = ACTIONS(12227),
    [sym_area_keyword] = ACTIONS(12227),
    [sym_group_keyword] = ACTIONS(12227),
    [sym_repeater_keyword] = ACTIONS(12227),
    [sym_cuegroup_keyword] = ACTIONS(12227),
    [sym_fixed_keyword] = ACTIONS(12227),
    [sym_grid_keyword] = ACTIONS(12227),
    [sym_part_keyword] = ACTIONS(12227),
    [sym_systempart_keyword] = ACTIONS(12227),
    [sym_usercontrol_keyword] = ACTIONS(12227),
    [sym_dataset_keyword] = ACTIONS(12227),
    [sym_elements_keyword] = ACTIONS(12227),
    [sym_dataitem_keyword] = ACTIONS(12227),
    [sym_column_keyword] = ACTIONS(12227),
    [sym_filter_keyword] = ACTIONS(12227),
    [sym_labels_keyword] = ACTIONS(12227),
    [sym_rendering_keyword] = ACTIONS(12227),
    [sym_requestpage_keyword] = ACTIONS(12227),
    [sym_schema_keyword] = ACTIONS(12227),
    [sym_views_keyword] = ACTIONS(12227),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12227),
    [sym_preproc_open] = ACTIONS(12227),
    [sym_preproc_close] = ACTIONS(12227),
  },
  [STATE(4976)] = {
    [anon_sym_SEMI] = ACTIONS(12227),
    [aux_sym_where_condition_token1] = ACTIONS(12229),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12227),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12227),
    [anon_sym_LBRACK] = ACTIONS(12227),
    [aux_sym_basic_type_token6] = ACTIONS(12229),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12227),
    [aux_sym_addafter_modification_token1] = ACTIONS(12227),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12227),
    [aux_sym_modify_modification_token1] = ACTIONS(12227),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12227),
    [aux_sym_movelast_modification_token1] = ACTIONS(12227),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12227),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12227),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12227),
    [anon_sym_POUNDif] = ACTIONS(12227),
    [anon_sym_POUNDIF] = ACTIONS(12227),
    [anon_sym_POUNDIf] = ACTIONS(12227),
    [anon_sym_POUNDelif] = ACTIONS(12227),
    [anon_sym_POUNDELIF] = ACTIONS(12227),
    [anon_sym_POUNDElif] = ACTIONS(12227),
    [anon_sym_POUNDelse] = ACTIONS(12227),
    [anon_sym_POUNDELSE] = ACTIONS(12227),
    [anon_sym_POUNDElse] = ACTIONS(12227),
    [anon_sym_POUNDelse2] = ACTIONS(12227),
    [anon_sym_POUNDELSE2] = ACTIONS(12227),
    [anon_sym_POUNDElse2] = ACTIONS(12227),
    [anon_sym_POUNDendif] = ACTIONS(12227),
    [anon_sym_POUNDENDIF] = ACTIONS(12227),
    [anon_sym_POUNDEndif] = ACTIONS(12227),
    [anon_sym_POUNDendif2] = ACTIONS(12227),
    [anon_sym_POUNDENDIF2] = ACTIONS(12227),
    [anon_sym_POUNDEndif2] = ACTIONS(12227),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12227),
    [sym_trigger_keyword] = ACTIONS(12227),
    [sym_var_keyword] = ACTIONS(12227),
    [sym_local_keyword] = ACTIONS(12227),
    [sym_internal_keyword] = ACTIONS(12227),
    [sym_protected_keyword] = ACTIONS(12227),
    [sym_event_keyword] = ACTIONS(12227),
    [sym_fields_keyword] = ACTIONS(12227),
    [sym_keys_keyword] = ACTIONS(12227),
    [sym_fieldgroups_keyword] = ACTIONS(12227),
    [sym_actions_keyword] = ACTIONS(12227),
    [sym_layout_keyword] = ACTIONS(12227),
    [sym_area_keyword] = ACTIONS(12227),
    [sym_group_keyword] = ACTIONS(12227),
    [sym_repeater_keyword] = ACTIONS(12227),
    [sym_cuegroup_keyword] = ACTIONS(12227),
    [sym_fixed_keyword] = ACTIONS(12227),
    [sym_grid_keyword] = ACTIONS(12227),
    [sym_part_keyword] = ACTIONS(12227),
    [sym_systempart_keyword] = ACTIONS(12227),
    [sym_usercontrol_keyword] = ACTIONS(12227),
    [sym_dataset_keyword] = ACTIONS(12227),
    [sym_elements_keyword] = ACTIONS(12227),
    [sym_dataitem_keyword] = ACTIONS(12227),
    [sym_column_keyword] = ACTIONS(12227),
    [sym_filter_keyword] = ACTIONS(12227),
    [sym_labels_keyword] = ACTIONS(12227),
    [sym_rendering_keyword] = ACTIONS(12227),
    [sym_requestpage_keyword] = ACTIONS(12227),
    [sym_schema_keyword] = ACTIONS(12227),
    [sym_views_keyword] = ACTIONS(12227),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12227),
    [sym_preproc_open] = ACTIONS(12227),
    [sym_preproc_close] = ACTIONS(12227),
  },
  [STATE(4977)] = {
    [anon_sym_SEMI] = ACTIONS(12227),
    [aux_sym_where_condition_token1] = ACTIONS(12229),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12227),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12227),
    [anon_sym_LBRACK] = ACTIONS(12227),
    [aux_sym_basic_type_token6] = ACTIONS(12229),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12227),
    [aux_sym_addafter_modification_token1] = ACTIONS(12227),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12227),
    [aux_sym_modify_modification_token1] = ACTIONS(12227),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12227),
    [aux_sym_movelast_modification_token1] = ACTIONS(12227),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12227),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12227),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12227),
    [anon_sym_POUNDif] = ACTIONS(12227),
    [anon_sym_POUNDIF] = ACTIONS(12227),
    [anon_sym_POUNDIf] = ACTIONS(12227),
    [anon_sym_POUNDelif] = ACTIONS(12227),
    [anon_sym_POUNDELIF] = ACTIONS(12227),
    [anon_sym_POUNDElif] = ACTIONS(12227),
    [anon_sym_POUNDelse] = ACTIONS(12227),
    [anon_sym_POUNDELSE] = ACTIONS(12227),
    [anon_sym_POUNDElse] = ACTIONS(12227),
    [anon_sym_POUNDelse2] = ACTIONS(12227),
    [anon_sym_POUNDELSE2] = ACTIONS(12227),
    [anon_sym_POUNDElse2] = ACTIONS(12227),
    [anon_sym_POUNDendif] = ACTIONS(12227),
    [anon_sym_POUNDENDIF] = ACTIONS(12227),
    [anon_sym_POUNDEndif] = ACTIONS(12227),
    [anon_sym_POUNDendif2] = ACTIONS(12227),
    [anon_sym_POUNDENDIF2] = ACTIONS(12227),
    [anon_sym_POUNDEndif2] = ACTIONS(12227),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12227),
    [sym_trigger_keyword] = ACTIONS(12227),
    [sym_var_keyword] = ACTIONS(12227),
    [sym_local_keyword] = ACTIONS(12227),
    [sym_internal_keyword] = ACTIONS(12227),
    [sym_protected_keyword] = ACTIONS(12227),
    [sym_event_keyword] = ACTIONS(12227),
    [sym_fields_keyword] = ACTIONS(12227),
    [sym_keys_keyword] = ACTIONS(12227),
    [sym_fieldgroups_keyword] = ACTIONS(12227),
    [sym_actions_keyword] = ACTIONS(12227),
    [sym_layout_keyword] = ACTIONS(12227),
    [sym_area_keyword] = ACTIONS(12227),
    [sym_group_keyword] = ACTIONS(12227),
    [sym_repeater_keyword] = ACTIONS(12227),
    [sym_cuegroup_keyword] = ACTIONS(12227),
    [sym_fixed_keyword] = ACTIONS(12227),
    [sym_grid_keyword] = ACTIONS(12227),
    [sym_part_keyword] = ACTIONS(12227),
    [sym_systempart_keyword] = ACTIONS(12227),
    [sym_usercontrol_keyword] = ACTIONS(12227),
    [sym_dataset_keyword] = ACTIONS(12227),
    [sym_elements_keyword] = ACTIONS(12227),
    [sym_dataitem_keyword] = ACTIONS(12227),
    [sym_column_keyword] = ACTIONS(12227),
    [sym_filter_keyword] = ACTIONS(12227),
    [sym_labels_keyword] = ACTIONS(12227),
    [sym_rendering_keyword] = ACTIONS(12227),
    [sym_requestpage_keyword] = ACTIONS(12227),
    [sym_schema_keyword] = ACTIONS(12227),
    [sym_views_keyword] = ACTIONS(12227),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12227),
    [sym_preproc_open] = ACTIONS(12227),
    [sym_preproc_close] = ACTIONS(12227),
  },
  [STATE(4978)] = {
    [anon_sym_SEMI] = ACTIONS(12231),
    [aux_sym_where_condition_token1] = ACTIONS(12233),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12231),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12231),
    [anon_sym_LBRACK] = ACTIONS(12231),
    [aux_sym_basic_type_token6] = ACTIONS(12233),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12231),
    [aux_sym_addafter_modification_token1] = ACTIONS(12231),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12231),
    [aux_sym_modify_modification_token1] = ACTIONS(12231),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12231),
    [aux_sym_movelast_modification_token1] = ACTIONS(12231),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12231),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12231),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12231),
    [anon_sym_POUNDif] = ACTIONS(12231),
    [anon_sym_POUNDIF] = ACTIONS(12231),
    [anon_sym_POUNDIf] = ACTIONS(12231),
    [anon_sym_POUNDelif] = ACTIONS(12231),
    [anon_sym_POUNDELIF] = ACTIONS(12231),
    [anon_sym_POUNDElif] = ACTIONS(12231),
    [anon_sym_POUNDelse] = ACTIONS(12231),
    [anon_sym_POUNDELSE] = ACTIONS(12231),
    [anon_sym_POUNDElse] = ACTIONS(12231),
    [anon_sym_POUNDelse2] = ACTIONS(12231),
    [anon_sym_POUNDELSE2] = ACTIONS(12231),
    [anon_sym_POUNDElse2] = ACTIONS(12231),
    [anon_sym_POUNDendif] = ACTIONS(12231),
    [anon_sym_POUNDENDIF] = ACTIONS(12231),
    [anon_sym_POUNDEndif] = ACTIONS(12231),
    [anon_sym_POUNDendif2] = ACTIONS(12231),
    [anon_sym_POUNDENDIF2] = ACTIONS(12231),
    [anon_sym_POUNDEndif2] = ACTIONS(12231),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12231),
    [sym_trigger_keyword] = ACTIONS(12231),
    [sym_var_keyword] = ACTIONS(12231),
    [sym_local_keyword] = ACTIONS(12231),
    [sym_internal_keyword] = ACTIONS(12231),
    [sym_protected_keyword] = ACTIONS(12231),
    [sym_event_keyword] = ACTIONS(12231),
    [sym_fields_keyword] = ACTIONS(12231),
    [sym_keys_keyword] = ACTIONS(12231),
    [sym_fieldgroups_keyword] = ACTIONS(12231),
    [sym_actions_keyword] = ACTIONS(12231),
    [sym_layout_keyword] = ACTIONS(12231),
    [sym_area_keyword] = ACTIONS(12231),
    [sym_group_keyword] = ACTIONS(12231),
    [sym_repeater_keyword] = ACTIONS(12231),
    [sym_cuegroup_keyword] = ACTIONS(12231),
    [sym_fixed_keyword] = ACTIONS(12231),
    [sym_grid_keyword] = ACTIONS(12231),
    [sym_part_keyword] = ACTIONS(12231),
    [sym_systempart_keyword] = ACTIONS(12231),
    [sym_usercontrol_keyword] = ACTIONS(12231),
    [sym_dataset_keyword] = ACTIONS(12231),
    [sym_elements_keyword] = ACTIONS(12231),
    [sym_dataitem_keyword] = ACTIONS(12231),
    [sym_column_keyword] = ACTIONS(12231),
    [sym_filter_keyword] = ACTIONS(12231),
    [sym_labels_keyword] = ACTIONS(12231),
    [sym_rendering_keyword] = ACTIONS(12231),
    [sym_requestpage_keyword] = ACTIONS(12231),
    [sym_schema_keyword] = ACTIONS(12231),
    [sym_views_keyword] = ACTIONS(12231),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12231),
    [sym_preproc_open] = ACTIONS(12231),
    [sym_preproc_close] = ACTIONS(12231),
  },
  [STATE(4979)] = {
    [anon_sym_SEMI] = ACTIONS(12231),
    [aux_sym_where_condition_token1] = ACTIONS(12233),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12231),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12231),
    [anon_sym_LBRACK] = ACTIONS(12231),
    [aux_sym_basic_type_token6] = ACTIONS(12233),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12231),
    [aux_sym_addafter_modification_token1] = ACTIONS(12231),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12231),
    [aux_sym_modify_modification_token1] = ACTIONS(12231),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12231),
    [aux_sym_movelast_modification_token1] = ACTIONS(12231),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12231),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12231),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12231),
    [anon_sym_POUNDif] = ACTIONS(12231),
    [anon_sym_POUNDIF] = ACTIONS(12231),
    [anon_sym_POUNDIf] = ACTIONS(12231),
    [anon_sym_POUNDelif] = ACTIONS(12231),
    [anon_sym_POUNDELIF] = ACTIONS(12231),
    [anon_sym_POUNDElif] = ACTIONS(12231),
    [anon_sym_POUNDelse] = ACTIONS(12231),
    [anon_sym_POUNDELSE] = ACTIONS(12231),
    [anon_sym_POUNDElse] = ACTIONS(12231),
    [anon_sym_POUNDelse2] = ACTIONS(12231),
    [anon_sym_POUNDELSE2] = ACTIONS(12231),
    [anon_sym_POUNDElse2] = ACTIONS(12231),
    [anon_sym_POUNDendif] = ACTIONS(12231),
    [anon_sym_POUNDENDIF] = ACTIONS(12231),
    [anon_sym_POUNDEndif] = ACTIONS(12231),
    [anon_sym_POUNDendif2] = ACTIONS(12231),
    [anon_sym_POUNDENDIF2] = ACTIONS(12231),
    [anon_sym_POUNDEndif2] = ACTIONS(12231),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12231),
    [sym_trigger_keyword] = ACTIONS(12231),
    [sym_var_keyword] = ACTIONS(12231),
    [sym_local_keyword] = ACTIONS(12231),
    [sym_internal_keyword] = ACTIONS(12231),
    [sym_protected_keyword] = ACTIONS(12231),
    [sym_event_keyword] = ACTIONS(12231),
    [sym_fields_keyword] = ACTIONS(12231),
    [sym_keys_keyword] = ACTIONS(12231),
    [sym_fieldgroups_keyword] = ACTIONS(12231),
    [sym_actions_keyword] = ACTIONS(12231),
    [sym_layout_keyword] = ACTIONS(12231),
    [sym_area_keyword] = ACTIONS(12231),
    [sym_group_keyword] = ACTIONS(12231),
    [sym_repeater_keyword] = ACTIONS(12231),
    [sym_cuegroup_keyword] = ACTIONS(12231),
    [sym_fixed_keyword] = ACTIONS(12231),
    [sym_grid_keyword] = ACTIONS(12231),
    [sym_part_keyword] = ACTIONS(12231),
    [sym_systempart_keyword] = ACTIONS(12231),
    [sym_usercontrol_keyword] = ACTIONS(12231),
    [sym_dataset_keyword] = ACTIONS(12231),
    [sym_elements_keyword] = ACTIONS(12231),
    [sym_dataitem_keyword] = ACTIONS(12231),
    [sym_column_keyword] = ACTIONS(12231),
    [sym_filter_keyword] = ACTIONS(12231),
    [sym_labels_keyword] = ACTIONS(12231),
    [sym_rendering_keyword] = ACTIONS(12231),
    [sym_requestpage_keyword] = ACTIONS(12231),
    [sym_schema_keyword] = ACTIONS(12231),
    [sym_views_keyword] = ACTIONS(12231),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12231),
    [sym_preproc_open] = ACTIONS(12231),
    [sym_preproc_close] = ACTIONS(12231),
  },
  [STATE(4980)] = {
    [anon_sym_SEMI] = ACTIONS(12231),
    [aux_sym_where_condition_token1] = ACTIONS(12233),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12231),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12231),
    [anon_sym_LBRACK] = ACTIONS(12231),
    [aux_sym_basic_type_token6] = ACTIONS(12233),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12231),
    [aux_sym_addafter_modification_token1] = ACTIONS(12231),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12231),
    [aux_sym_modify_modification_token1] = ACTIONS(12231),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12231),
    [aux_sym_movelast_modification_token1] = ACTIONS(12231),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12231),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12231),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12231),
    [anon_sym_POUNDif] = ACTIONS(12231),
    [anon_sym_POUNDIF] = ACTIONS(12231),
    [anon_sym_POUNDIf] = ACTIONS(12231),
    [anon_sym_POUNDelif] = ACTIONS(12231),
    [anon_sym_POUNDELIF] = ACTIONS(12231),
    [anon_sym_POUNDElif] = ACTIONS(12231),
    [anon_sym_POUNDelse] = ACTIONS(12231),
    [anon_sym_POUNDELSE] = ACTIONS(12231),
    [anon_sym_POUNDElse] = ACTIONS(12231),
    [anon_sym_POUNDelse2] = ACTIONS(12231),
    [anon_sym_POUNDELSE2] = ACTIONS(12231),
    [anon_sym_POUNDElse2] = ACTIONS(12231),
    [anon_sym_POUNDendif] = ACTIONS(12231),
    [anon_sym_POUNDENDIF] = ACTIONS(12231),
    [anon_sym_POUNDEndif] = ACTIONS(12231),
    [anon_sym_POUNDendif2] = ACTIONS(12231),
    [anon_sym_POUNDENDIF2] = ACTIONS(12231),
    [anon_sym_POUNDEndif2] = ACTIONS(12231),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12231),
    [sym_trigger_keyword] = ACTIONS(12231),
    [sym_var_keyword] = ACTIONS(12231),
    [sym_local_keyword] = ACTIONS(12231),
    [sym_internal_keyword] = ACTIONS(12231),
    [sym_protected_keyword] = ACTIONS(12231),
    [sym_event_keyword] = ACTIONS(12231),
    [sym_fields_keyword] = ACTIONS(12231),
    [sym_keys_keyword] = ACTIONS(12231),
    [sym_fieldgroups_keyword] = ACTIONS(12231),
    [sym_actions_keyword] = ACTIONS(12231),
    [sym_layout_keyword] = ACTIONS(12231),
    [sym_area_keyword] = ACTIONS(12231),
    [sym_group_keyword] = ACTIONS(12231),
    [sym_repeater_keyword] = ACTIONS(12231),
    [sym_cuegroup_keyword] = ACTIONS(12231),
    [sym_fixed_keyword] = ACTIONS(12231),
    [sym_grid_keyword] = ACTIONS(12231),
    [sym_part_keyword] = ACTIONS(12231),
    [sym_systempart_keyword] = ACTIONS(12231),
    [sym_usercontrol_keyword] = ACTIONS(12231),
    [sym_dataset_keyword] = ACTIONS(12231),
    [sym_elements_keyword] = ACTIONS(12231),
    [sym_dataitem_keyword] = ACTIONS(12231),
    [sym_column_keyword] = ACTIONS(12231),
    [sym_filter_keyword] = ACTIONS(12231),
    [sym_labels_keyword] = ACTIONS(12231),
    [sym_rendering_keyword] = ACTIONS(12231),
    [sym_requestpage_keyword] = ACTIONS(12231),
    [sym_schema_keyword] = ACTIONS(12231),
    [sym_views_keyword] = ACTIONS(12231),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12231),
    [sym_preproc_open] = ACTIONS(12231),
    [sym_preproc_close] = ACTIONS(12231),
  },
  [STATE(4981)] = {
    [anon_sym_SEMI] = ACTIONS(12231),
    [aux_sym_where_condition_token1] = ACTIONS(12233),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12231),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12231),
    [anon_sym_LBRACK] = ACTIONS(12231),
    [aux_sym_basic_type_token6] = ACTIONS(12233),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12231),
    [aux_sym_addafter_modification_token1] = ACTIONS(12231),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12231),
    [aux_sym_modify_modification_token1] = ACTIONS(12231),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12231),
    [aux_sym_movelast_modification_token1] = ACTIONS(12231),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12231),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12231),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12231),
    [anon_sym_POUNDif] = ACTIONS(12231),
    [anon_sym_POUNDIF] = ACTIONS(12231),
    [anon_sym_POUNDIf] = ACTIONS(12231),
    [anon_sym_POUNDelif] = ACTIONS(12231),
    [anon_sym_POUNDELIF] = ACTIONS(12231),
    [anon_sym_POUNDElif] = ACTIONS(12231),
    [anon_sym_POUNDelse] = ACTIONS(12231),
    [anon_sym_POUNDELSE] = ACTIONS(12231),
    [anon_sym_POUNDElse] = ACTIONS(12231),
    [anon_sym_POUNDelse2] = ACTIONS(12231),
    [anon_sym_POUNDELSE2] = ACTIONS(12231),
    [anon_sym_POUNDElse2] = ACTIONS(12231),
    [anon_sym_POUNDendif] = ACTIONS(12231),
    [anon_sym_POUNDENDIF] = ACTIONS(12231),
    [anon_sym_POUNDEndif] = ACTIONS(12231),
    [anon_sym_POUNDendif2] = ACTIONS(12231),
    [anon_sym_POUNDENDIF2] = ACTIONS(12231),
    [anon_sym_POUNDEndif2] = ACTIONS(12231),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12231),
    [sym_trigger_keyword] = ACTIONS(12231),
    [sym_var_keyword] = ACTIONS(12231),
    [sym_local_keyword] = ACTIONS(12231),
    [sym_internal_keyword] = ACTIONS(12231),
    [sym_protected_keyword] = ACTIONS(12231),
    [sym_event_keyword] = ACTIONS(12231),
    [sym_fields_keyword] = ACTIONS(12231),
    [sym_keys_keyword] = ACTIONS(12231),
    [sym_fieldgroups_keyword] = ACTIONS(12231),
    [sym_actions_keyword] = ACTIONS(12231),
    [sym_layout_keyword] = ACTIONS(12231),
    [sym_area_keyword] = ACTIONS(12231),
    [sym_group_keyword] = ACTIONS(12231),
    [sym_repeater_keyword] = ACTIONS(12231),
    [sym_cuegroup_keyword] = ACTIONS(12231),
    [sym_fixed_keyword] = ACTIONS(12231),
    [sym_grid_keyword] = ACTIONS(12231),
    [sym_part_keyword] = ACTIONS(12231),
    [sym_systempart_keyword] = ACTIONS(12231),
    [sym_usercontrol_keyword] = ACTIONS(12231),
    [sym_dataset_keyword] = ACTIONS(12231),
    [sym_elements_keyword] = ACTIONS(12231),
    [sym_dataitem_keyword] = ACTIONS(12231),
    [sym_column_keyword] = ACTIONS(12231),
    [sym_filter_keyword] = ACTIONS(12231),
    [sym_labels_keyword] = ACTIONS(12231),
    [sym_rendering_keyword] = ACTIONS(12231),
    [sym_requestpage_keyword] = ACTIONS(12231),
    [sym_schema_keyword] = ACTIONS(12231),
    [sym_views_keyword] = ACTIONS(12231),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12231),
    [sym_preproc_open] = ACTIONS(12231),
    [sym_preproc_close] = ACTIONS(12231),
  },
  [STATE(4982)] = {
    [anon_sym_SEMI] = ACTIONS(12231),
    [aux_sym_where_condition_token1] = ACTIONS(12233),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12231),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12231),
    [anon_sym_LBRACK] = ACTIONS(12231),
    [aux_sym_basic_type_token6] = ACTIONS(12233),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12231),
    [aux_sym_addafter_modification_token1] = ACTIONS(12231),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12231),
    [aux_sym_modify_modification_token1] = ACTIONS(12231),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12231),
    [aux_sym_movelast_modification_token1] = ACTIONS(12231),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12231),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12231),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12231),
    [anon_sym_POUNDif] = ACTIONS(12231),
    [anon_sym_POUNDIF] = ACTIONS(12231),
    [anon_sym_POUNDIf] = ACTIONS(12231),
    [anon_sym_POUNDelif] = ACTIONS(12231),
    [anon_sym_POUNDELIF] = ACTIONS(12231),
    [anon_sym_POUNDElif] = ACTIONS(12231),
    [anon_sym_POUNDelse] = ACTIONS(12231),
    [anon_sym_POUNDELSE] = ACTIONS(12231),
    [anon_sym_POUNDElse] = ACTIONS(12231),
    [anon_sym_POUNDelse2] = ACTIONS(12231),
    [anon_sym_POUNDELSE2] = ACTIONS(12231),
    [anon_sym_POUNDElse2] = ACTIONS(12231),
    [anon_sym_POUNDendif] = ACTIONS(12231),
    [anon_sym_POUNDENDIF] = ACTIONS(12231),
    [anon_sym_POUNDEndif] = ACTIONS(12231),
    [anon_sym_POUNDendif2] = ACTIONS(12231),
    [anon_sym_POUNDENDIF2] = ACTIONS(12231),
    [anon_sym_POUNDEndif2] = ACTIONS(12231),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12231),
    [sym_trigger_keyword] = ACTIONS(12231),
    [sym_var_keyword] = ACTIONS(12231),
    [sym_local_keyword] = ACTIONS(12231),
    [sym_internal_keyword] = ACTIONS(12231),
    [sym_protected_keyword] = ACTIONS(12231),
    [sym_event_keyword] = ACTIONS(12231),
    [sym_fields_keyword] = ACTIONS(12231),
    [sym_keys_keyword] = ACTIONS(12231),
    [sym_fieldgroups_keyword] = ACTIONS(12231),
    [sym_actions_keyword] = ACTIONS(12231),
    [sym_layout_keyword] = ACTIONS(12231),
    [sym_area_keyword] = ACTIONS(12231),
    [sym_group_keyword] = ACTIONS(12231),
    [sym_repeater_keyword] = ACTIONS(12231),
    [sym_cuegroup_keyword] = ACTIONS(12231),
    [sym_fixed_keyword] = ACTIONS(12231),
    [sym_grid_keyword] = ACTIONS(12231),
    [sym_part_keyword] = ACTIONS(12231),
    [sym_systempart_keyword] = ACTIONS(12231),
    [sym_usercontrol_keyword] = ACTIONS(12231),
    [sym_dataset_keyword] = ACTIONS(12231),
    [sym_elements_keyword] = ACTIONS(12231),
    [sym_dataitem_keyword] = ACTIONS(12231),
    [sym_column_keyword] = ACTIONS(12231),
    [sym_filter_keyword] = ACTIONS(12231),
    [sym_labels_keyword] = ACTIONS(12231),
    [sym_rendering_keyword] = ACTIONS(12231),
    [sym_requestpage_keyword] = ACTIONS(12231),
    [sym_schema_keyword] = ACTIONS(12231),
    [sym_views_keyword] = ACTIONS(12231),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12231),
    [sym_preproc_open] = ACTIONS(12231),
    [sym_preproc_close] = ACTIONS(12231),
  },
  [STATE(4983)] = {
    [anon_sym_SEMI] = ACTIONS(12235),
    [aux_sym_where_condition_token1] = ACTIONS(12237),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12235),
    [anon_sym_LBRACK] = ACTIONS(12235),
    [aux_sym_basic_type_token6] = ACTIONS(12237),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12235),
    [aux_sym_addafter_modification_token1] = ACTIONS(12235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12235),
    [aux_sym_modify_modification_token1] = ACTIONS(12235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12235),
    [aux_sym_movelast_modification_token1] = ACTIONS(12235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12235),
    [anon_sym_POUNDif] = ACTIONS(12235),
    [anon_sym_POUNDIF] = ACTIONS(12235),
    [anon_sym_POUNDIf] = ACTIONS(12235),
    [anon_sym_POUNDelif] = ACTIONS(12235),
    [anon_sym_POUNDELIF] = ACTIONS(12235),
    [anon_sym_POUNDElif] = ACTIONS(12235),
    [anon_sym_POUNDelse] = ACTIONS(12235),
    [anon_sym_POUNDELSE] = ACTIONS(12235),
    [anon_sym_POUNDElse] = ACTIONS(12235),
    [anon_sym_POUNDelse2] = ACTIONS(12235),
    [anon_sym_POUNDELSE2] = ACTIONS(12235),
    [anon_sym_POUNDElse2] = ACTIONS(12235),
    [anon_sym_POUNDendif] = ACTIONS(12235),
    [anon_sym_POUNDENDIF] = ACTIONS(12235),
    [anon_sym_POUNDEndif] = ACTIONS(12235),
    [anon_sym_POUNDendif2] = ACTIONS(12235),
    [anon_sym_POUNDENDIF2] = ACTIONS(12235),
    [anon_sym_POUNDEndif2] = ACTIONS(12235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12235),
    [sym_trigger_keyword] = ACTIONS(12235),
    [sym_var_keyword] = ACTIONS(12235),
    [sym_local_keyword] = ACTIONS(12235),
    [sym_internal_keyword] = ACTIONS(12235),
    [sym_protected_keyword] = ACTIONS(12235),
    [sym_event_keyword] = ACTIONS(12235),
    [sym_fields_keyword] = ACTIONS(12235),
    [sym_keys_keyword] = ACTIONS(12235),
    [sym_fieldgroups_keyword] = ACTIONS(12235),
    [sym_actions_keyword] = ACTIONS(12235),
    [sym_layout_keyword] = ACTIONS(12235),
    [sym_area_keyword] = ACTIONS(12235),
    [sym_group_keyword] = ACTIONS(12235),
    [sym_repeater_keyword] = ACTIONS(12235),
    [sym_cuegroup_keyword] = ACTIONS(12235),
    [sym_fixed_keyword] = ACTIONS(12235),
    [sym_grid_keyword] = ACTIONS(12235),
    [sym_part_keyword] = ACTIONS(12235),
    [sym_systempart_keyword] = ACTIONS(12235),
    [sym_usercontrol_keyword] = ACTIONS(12235),
    [sym_dataset_keyword] = ACTIONS(12235),
    [sym_elements_keyword] = ACTIONS(12235),
    [sym_dataitem_keyword] = ACTIONS(12235),
    [sym_column_keyword] = ACTIONS(12235),
    [sym_filter_keyword] = ACTIONS(12235),
    [sym_labels_keyword] = ACTIONS(12235),
    [sym_rendering_keyword] = ACTIONS(12235),
    [sym_requestpage_keyword] = ACTIONS(12235),
    [sym_schema_keyword] = ACTIONS(12235),
    [sym_views_keyword] = ACTIONS(12235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12235),
    [sym_preproc_open] = ACTIONS(12235),
    [sym_preproc_close] = ACTIONS(12235),
  },
  [STATE(4984)] = {
    [anon_sym_SEMI] = ACTIONS(12239),
    [aux_sym_where_condition_token1] = ACTIONS(12241),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12239),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12239),
    [anon_sym_LBRACK] = ACTIONS(12239),
    [aux_sym_basic_type_token6] = ACTIONS(12241),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12239),
    [aux_sym_addafter_modification_token1] = ACTIONS(12239),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12239),
    [aux_sym_modify_modification_token1] = ACTIONS(12239),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12239),
    [aux_sym_movelast_modification_token1] = ACTIONS(12239),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12239),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12239),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12239),
    [anon_sym_POUNDif] = ACTIONS(12239),
    [anon_sym_POUNDIF] = ACTIONS(12239),
    [anon_sym_POUNDIf] = ACTIONS(12239),
    [anon_sym_POUNDelif] = ACTIONS(12239),
    [anon_sym_POUNDELIF] = ACTIONS(12239),
    [anon_sym_POUNDElif] = ACTIONS(12239),
    [anon_sym_POUNDelse] = ACTIONS(12239),
    [anon_sym_POUNDELSE] = ACTIONS(12239),
    [anon_sym_POUNDElse] = ACTIONS(12239),
    [anon_sym_POUNDelse2] = ACTIONS(12239),
    [anon_sym_POUNDELSE2] = ACTIONS(12239),
    [anon_sym_POUNDElse2] = ACTIONS(12239),
    [anon_sym_POUNDendif] = ACTIONS(12239),
    [anon_sym_POUNDENDIF] = ACTIONS(12239),
    [anon_sym_POUNDEndif] = ACTIONS(12239),
    [anon_sym_POUNDendif2] = ACTIONS(12239),
    [anon_sym_POUNDENDIF2] = ACTIONS(12239),
    [anon_sym_POUNDEndif2] = ACTIONS(12239),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12239),
    [sym_trigger_keyword] = ACTIONS(12239),
    [sym_var_keyword] = ACTIONS(12239),
    [sym_local_keyword] = ACTIONS(12239),
    [sym_internal_keyword] = ACTIONS(12239),
    [sym_protected_keyword] = ACTIONS(12239),
    [sym_event_keyword] = ACTIONS(12239),
    [sym_fields_keyword] = ACTIONS(12239),
    [sym_keys_keyword] = ACTIONS(12239),
    [sym_fieldgroups_keyword] = ACTIONS(12239),
    [sym_actions_keyword] = ACTIONS(12239),
    [sym_layout_keyword] = ACTIONS(12239),
    [sym_area_keyword] = ACTIONS(12239),
    [sym_group_keyword] = ACTIONS(12239),
    [sym_repeater_keyword] = ACTIONS(12239),
    [sym_cuegroup_keyword] = ACTIONS(12239),
    [sym_fixed_keyword] = ACTIONS(12239),
    [sym_grid_keyword] = ACTIONS(12239),
    [sym_part_keyword] = ACTIONS(12239),
    [sym_systempart_keyword] = ACTIONS(12239),
    [sym_usercontrol_keyword] = ACTIONS(12239),
    [sym_dataset_keyword] = ACTIONS(12239),
    [sym_elements_keyword] = ACTIONS(12239),
    [sym_dataitem_keyword] = ACTIONS(12239),
    [sym_column_keyword] = ACTIONS(12239),
    [sym_filter_keyword] = ACTIONS(12239),
    [sym_labels_keyword] = ACTIONS(12239),
    [sym_rendering_keyword] = ACTIONS(12239),
    [sym_requestpage_keyword] = ACTIONS(12239),
    [sym_schema_keyword] = ACTIONS(12239),
    [sym_views_keyword] = ACTIONS(12239),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12239),
    [sym_preproc_open] = ACTIONS(12239),
    [sym_preproc_close] = ACTIONS(12239),
  },
  [STATE(4985)] = {
    [anon_sym_SEMI] = ACTIONS(12239),
    [aux_sym_where_condition_token1] = ACTIONS(12241),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12239),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12239),
    [anon_sym_LBRACK] = ACTIONS(12239),
    [aux_sym_basic_type_token6] = ACTIONS(12241),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12239),
    [aux_sym_addafter_modification_token1] = ACTIONS(12239),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12239),
    [aux_sym_modify_modification_token1] = ACTIONS(12239),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12239),
    [aux_sym_movelast_modification_token1] = ACTIONS(12239),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12239),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12239),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12239),
    [anon_sym_POUNDif] = ACTIONS(12239),
    [anon_sym_POUNDIF] = ACTIONS(12239),
    [anon_sym_POUNDIf] = ACTIONS(12239),
    [anon_sym_POUNDelif] = ACTIONS(12239),
    [anon_sym_POUNDELIF] = ACTIONS(12239),
    [anon_sym_POUNDElif] = ACTIONS(12239),
    [anon_sym_POUNDelse] = ACTIONS(12239),
    [anon_sym_POUNDELSE] = ACTIONS(12239),
    [anon_sym_POUNDElse] = ACTIONS(12239),
    [anon_sym_POUNDelse2] = ACTIONS(12239),
    [anon_sym_POUNDELSE2] = ACTIONS(12239),
    [anon_sym_POUNDElse2] = ACTIONS(12239),
    [anon_sym_POUNDendif] = ACTIONS(12239),
    [anon_sym_POUNDENDIF] = ACTIONS(12239),
    [anon_sym_POUNDEndif] = ACTIONS(12239),
    [anon_sym_POUNDendif2] = ACTIONS(12239),
    [anon_sym_POUNDENDIF2] = ACTIONS(12239),
    [anon_sym_POUNDEndif2] = ACTIONS(12239),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12239),
    [sym_trigger_keyword] = ACTIONS(12239),
    [sym_var_keyword] = ACTIONS(12239),
    [sym_local_keyword] = ACTIONS(12239),
    [sym_internal_keyword] = ACTIONS(12239),
    [sym_protected_keyword] = ACTIONS(12239),
    [sym_event_keyword] = ACTIONS(12239),
    [sym_fields_keyword] = ACTIONS(12239),
    [sym_keys_keyword] = ACTIONS(12239),
    [sym_fieldgroups_keyword] = ACTIONS(12239),
    [sym_actions_keyword] = ACTIONS(12239),
    [sym_layout_keyword] = ACTIONS(12239),
    [sym_area_keyword] = ACTIONS(12239),
    [sym_group_keyword] = ACTIONS(12239),
    [sym_repeater_keyword] = ACTIONS(12239),
    [sym_cuegroup_keyword] = ACTIONS(12239),
    [sym_fixed_keyword] = ACTIONS(12239),
    [sym_grid_keyword] = ACTIONS(12239),
    [sym_part_keyword] = ACTIONS(12239),
    [sym_systempart_keyword] = ACTIONS(12239),
    [sym_usercontrol_keyword] = ACTIONS(12239),
    [sym_dataset_keyword] = ACTIONS(12239),
    [sym_elements_keyword] = ACTIONS(12239),
    [sym_dataitem_keyword] = ACTIONS(12239),
    [sym_column_keyword] = ACTIONS(12239),
    [sym_filter_keyword] = ACTIONS(12239),
    [sym_labels_keyword] = ACTIONS(12239),
    [sym_rendering_keyword] = ACTIONS(12239),
    [sym_requestpage_keyword] = ACTIONS(12239),
    [sym_schema_keyword] = ACTIONS(12239),
    [sym_views_keyword] = ACTIONS(12239),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12239),
    [sym_preproc_open] = ACTIONS(12239),
    [sym_preproc_close] = ACTIONS(12239),
  },
  [STATE(4986)] = {
    [anon_sym_SEMI] = ACTIONS(12239),
    [aux_sym_where_condition_token1] = ACTIONS(12241),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12239),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12239),
    [anon_sym_LBRACK] = ACTIONS(12239),
    [aux_sym_basic_type_token6] = ACTIONS(12241),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12239),
    [aux_sym_addafter_modification_token1] = ACTIONS(12239),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12239),
    [aux_sym_modify_modification_token1] = ACTIONS(12239),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12239),
    [aux_sym_movelast_modification_token1] = ACTIONS(12239),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12239),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12239),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12239),
    [anon_sym_POUNDif] = ACTIONS(12239),
    [anon_sym_POUNDIF] = ACTIONS(12239),
    [anon_sym_POUNDIf] = ACTIONS(12239),
    [anon_sym_POUNDelif] = ACTIONS(12239),
    [anon_sym_POUNDELIF] = ACTIONS(12239),
    [anon_sym_POUNDElif] = ACTIONS(12239),
    [anon_sym_POUNDelse] = ACTIONS(12239),
    [anon_sym_POUNDELSE] = ACTIONS(12239),
    [anon_sym_POUNDElse] = ACTIONS(12239),
    [anon_sym_POUNDelse2] = ACTIONS(12239),
    [anon_sym_POUNDELSE2] = ACTIONS(12239),
    [anon_sym_POUNDElse2] = ACTIONS(12239),
    [anon_sym_POUNDendif] = ACTIONS(12239),
    [anon_sym_POUNDENDIF] = ACTIONS(12239),
    [anon_sym_POUNDEndif] = ACTIONS(12239),
    [anon_sym_POUNDendif2] = ACTIONS(12239),
    [anon_sym_POUNDENDIF2] = ACTIONS(12239),
    [anon_sym_POUNDEndif2] = ACTIONS(12239),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12239),
    [sym_trigger_keyword] = ACTIONS(12239),
    [sym_var_keyword] = ACTIONS(12239),
    [sym_local_keyword] = ACTIONS(12239),
    [sym_internal_keyword] = ACTIONS(12239),
    [sym_protected_keyword] = ACTIONS(12239),
    [sym_event_keyword] = ACTIONS(12239),
    [sym_fields_keyword] = ACTIONS(12239),
    [sym_keys_keyword] = ACTIONS(12239),
    [sym_fieldgroups_keyword] = ACTIONS(12239),
    [sym_actions_keyword] = ACTIONS(12239),
    [sym_layout_keyword] = ACTIONS(12239),
    [sym_area_keyword] = ACTIONS(12239),
    [sym_group_keyword] = ACTIONS(12239),
    [sym_repeater_keyword] = ACTIONS(12239),
    [sym_cuegroup_keyword] = ACTIONS(12239),
    [sym_fixed_keyword] = ACTIONS(12239),
    [sym_grid_keyword] = ACTIONS(12239),
    [sym_part_keyword] = ACTIONS(12239),
    [sym_systempart_keyword] = ACTIONS(12239),
    [sym_usercontrol_keyword] = ACTIONS(12239),
    [sym_dataset_keyword] = ACTIONS(12239),
    [sym_elements_keyword] = ACTIONS(12239),
    [sym_dataitem_keyword] = ACTIONS(12239),
    [sym_column_keyword] = ACTIONS(12239),
    [sym_filter_keyword] = ACTIONS(12239),
    [sym_labels_keyword] = ACTIONS(12239),
    [sym_rendering_keyword] = ACTIONS(12239),
    [sym_requestpage_keyword] = ACTIONS(12239),
    [sym_schema_keyword] = ACTIONS(12239),
    [sym_views_keyword] = ACTIONS(12239),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12239),
    [sym_preproc_open] = ACTIONS(12239),
    [sym_preproc_close] = ACTIONS(12239),
  },
  [STATE(4987)] = {
    [anon_sym_SEMI] = ACTIONS(7785),
    [anon_sym_RBRACE] = ACTIONS(7785),
    [aux_sym_where_condition_token1] = ACTIONS(7787),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7787),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7785),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7785),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_basic_type_token6] = ACTIONS(7787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_addafter_modification_token1] = ACTIONS(7785),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7785),
    [aux_sym_movelast_modification_token1] = ACTIONS(7785),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7785),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7785),
    [anon_sym_POUNDIF] = ACTIONS(7785),
    [anon_sym_POUNDIf] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7787),
    [sym_page_keyword] = ACTIONS(7785),
    [anon_sym_codeunit] = ACTIONS(7785),
    [anon_sym_CODEUNIT] = ACTIONS(7785),
    [anon_sym_Codeunit] = ACTIONS(7785),
    [anon_sym_CodeUnit] = ACTIONS(7785),
    [anon_sym_COdeunit] = ACTIONS(7785),
    [anon_sym_codeUnit] = ACTIONS(7785),
    [sym_report_keyword] = ACTIONS(7785),
    [sym_query_keyword] = ACTIONS(7785),
    [anon_sym_xmlport] = ACTIONS(7785),
    [anon_sym_XMLPORT] = ACTIONS(7785),
    [anon_sym_Xmlport] = ACTIONS(7785),
    [anon_sym_XMLport] = ACTIONS(7785),
    [anon_sym_XMLPort] = ACTIONS(7785),
    [anon_sym_XmlPort] = ACTIONS(7785),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_area_keyword] = ACTIONS(7785),
    [sym_group_keyword] = ACTIONS(7785),
    [sym_repeater_keyword] = ACTIONS(7785),
    [sym_cuegroup_keyword] = ACTIONS(7785),
    [sym_fixed_keyword] = ACTIONS(7785),
    [sym_grid_keyword] = ACTIONS(7785),
    [sym_part_keyword] = ACTIONS(7785),
    [sym_systempart_keyword] = ACTIONS(7785),
    [sym_usercontrol_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7785),
  },
  [STATE(4988)] = {
    [anon_sym_SEMI] = ACTIONS(12243),
    [aux_sym_where_condition_token1] = ACTIONS(12245),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12247),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12247),
    [anon_sym_LBRACK] = ACTIONS(12247),
    [aux_sym_basic_type_token6] = ACTIONS(12245),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12247),
    [aux_sym_addafter_modification_token1] = ACTIONS(12247),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12247),
    [aux_sym_modify_modification_token1] = ACTIONS(12247),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12247),
    [aux_sym_movelast_modification_token1] = ACTIONS(12247),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12247),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12247),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12247),
    [anon_sym_POUNDif] = ACTIONS(12247),
    [anon_sym_POUNDIF] = ACTIONS(12247),
    [anon_sym_POUNDIf] = ACTIONS(12247),
    [anon_sym_POUNDelif] = ACTIONS(12247),
    [anon_sym_POUNDELIF] = ACTIONS(12247),
    [anon_sym_POUNDElif] = ACTIONS(12247),
    [anon_sym_POUNDelse] = ACTIONS(12247),
    [anon_sym_POUNDELSE] = ACTIONS(12247),
    [anon_sym_POUNDElse] = ACTIONS(12247),
    [anon_sym_POUNDelse2] = ACTIONS(12247),
    [anon_sym_POUNDELSE2] = ACTIONS(12247),
    [anon_sym_POUNDElse2] = ACTIONS(12247),
    [anon_sym_POUNDendif] = ACTIONS(12247),
    [anon_sym_POUNDENDIF] = ACTIONS(12247),
    [anon_sym_POUNDEndif] = ACTIONS(12247),
    [anon_sym_POUNDendif2] = ACTIONS(12247),
    [anon_sym_POUNDENDIF2] = ACTIONS(12247),
    [anon_sym_POUNDEndif2] = ACTIONS(12247),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12247),
    [sym_trigger_keyword] = ACTIONS(12247),
    [sym_var_keyword] = ACTIONS(12247),
    [sym_local_keyword] = ACTIONS(12247),
    [sym_internal_keyword] = ACTIONS(12247),
    [sym_protected_keyword] = ACTIONS(12247),
    [sym_event_keyword] = ACTIONS(12247),
    [sym_fields_keyword] = ACTIONS(12247),
    [sym_keys_keyword] = ACTIONS(12247),
    [sym_fieldgroups_keyword] = ACTIONS(12247),
    [sym_actions_keyword] = ACTIONS(12247),
    [sym_layout_keyword] = ACTIONS(12247),
    [sym_area_keyword] = ACTIONS(12247),
    [sym_group_keyword] = ACTIONS(12247),
    [sym_repeater_keyword] = ACTIONS(12247),
    [sym_cuegroup_keyword] = ACTIONS(12247),
    [sym_fixed_keyword] = ACTIONS(12247),
    [sym_grid_keyword] = ACTIONS(12247),
    [sym_part_keyword] = ACTIONS(12247),
    [sym_systempart_keyword] = ACTIONS(12247),
    [sym_usercontrol_keyword] = ACTIONS(12247),
    [sym_dataset_keyword] = ACTIONS(12247),
    [sym_elements_keyword] = ACTIONS(12247),
    [sym_dataitem_keyword] = ACTIONS(12247),
    [sym_column_keyword] = ACTIONS(12247),
    [sym_filter_keyword] = ACTIONS(12247),
    [sym_labels_keyword] = ACTIONS(12247),
    [sym_rendering_keyword] = ACTIONS(12247),
    [sym_requestpage_keyword] = ACTIONS(12247),
    [sym_schema_keyword] = ACTIONS(12247),
    [sym_views_keyword] = ACTIONS(12247),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12247),
    [sym_preproc_open] = ACTIONS(12247),
    [sym_preproc_close] = ACTIONS(12247),
  },
  [STATE(4989)] = {
    [anon_sym_SEMI] = ACTIONS(12249),
    [aux_sym_where_condition_token1] = ACTIONS(12251),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12249),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12249),
    [anon_sym_LBRACK] = ACTIONS(12249),
    [aux_sym_basic_type_token6] = ACTIONS(12251),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12249),
    [aux_sym_addafter_modification_token1] = ACTIONS(12249),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12249),
    [aux_sym_modify_modification_token1] = ACTIONS(12249),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12249),
    [aux_sym_movelast_modification_token1] = ACTIONS(12249),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12249),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12249),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12249),
    [anon_sym_POUNDif] = ACTIONS(12249),
    [anon_sym_POUNDIF] = ACTIONS(12249),
    [anon_sym_POUNDIf] = ACTIONS(12249),
    [anon_sym_POUNDelif] = ACTIONS(12249),
    [anon_sym_POUNDELIF] = ACTIONS(12249),
    [anon_sym_POUNDElif] = ACTIONS(12249),
    [anon_sym_POUNDelse] = ACTIONS(12249),
    [anon_sym_POUNDELSE] = ACTIONS(12249),
    [anon_sym_POUNDElse] = ACTIONS(12249),
    [anon_sym_POUNDelse2] = ACTIONS(12249),
    [anon_sym_POUNDELSE2] = ACTIONS(12249),
    [anon_sym_POUNDElse2] = ACTIONS(12249),
    [anon_sym_POUNDendif] = ACTIONS(12249),
    [anon_sym_POUNDENDIF] = ACTIONS(12249),
    [anon_sym_POUNDEndif] = ACTIONS(12249),
    [anon_sym_POUNDendif2] = ACTIONS(12249),
    [anon_sym_POUNDENDIF2] = ACTIONS(12249),
    [anon_sym_POUNDEndif2] = ACTIONS(12249),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12249),
    [sym_trigger_keyword] = ACTIONS(12249),
    [sym_var_keyword] = ACTIONS(12249),
    [sym_local_keyword] = ACTIONS(12249),
    [sym_internal_keyword] = ACTIONS(12249),
    [sym_protected_keyword] = ACTIONS(12249),
    [sym_event_keyword] = ACTIONS(12249),
    [sym_fields_keyword] = ACTIONS(12249),
    [sym_keys_keyword] = ACTIONS(12249),
    [sym_fieldgroups_keyword] = ACTIONS(12249),
    [sym_actions_keyword] = ACTIONS(12249),
    [sym_layout_keyword] = ACTIONS(12249),
    [sym_area_keyword] = ACTIONS(12249),
    [sym_group_keyword] = ACTIONS(12249),
    [sym_repeater_keyword] = ACTIONS(12249),
    [sym_cuegroup_keyword] = ACTIONS(12249),
    [sym_fixed_keyword] = ACTIONS(12249),
    [sym_grid_keyword] = ACTIONS(12249),
    [sym_part_keyword] = ACTIONS(12249),
    [sym_systempart_keyword] = ACTIONS(12249),
    [sym_usercontrol_keyword] = ACTIONS(12249),
    [sym_dataset_keyword] = ACTIONS(12249),
    [sym_elements_keyword] = ACTIONS(12249),
    [sym_dataitem_keyword] = ACTIONS(12249),
    [sym_column_keyword] = ACTIONS(12249),
    [sym_filter_keyword] = ACTIONS(12249),
    [sym_labels_keyword] = ACTIONS(12249),
    [sym_rendering_keyword] = ACTIONS(12249),
    [sym_requestpage_keyword] = ACTIONS(12249),
    [sym_schema_keyword] = ACTIONS(12249),
    [sym_views_keyword] = ACTIONS(12249),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12249),
    [sym_preproc_open] = ACTIONS(12249),
    [sym_preproc_close] = ACTIONS(12249),
  },
  [STATE(4990)] = {
    [anon_sym_SEMI] = ACTIONS(12249),
    [aux_sym_where_condition_token1] = ACTIONS(12251),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12249),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12249),
    [anon_sym_LBRACK] = ACTIONS(12249),
    [aux_sym_basic_type_token6] = ACTIONS(12251),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12249),
    [aux_sym_addafter_modification_token1] = ACTIONS(12249),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12249),
    [aux_sym_modify_modification_token1] = ACTIONS(12249),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12249),
    [aux_sym_movelast_modification_token1] = ACTIONS(12249),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12249),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12249),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12249),
    [anon_sym_POUNDif] = ACTIONS(12249),
    [anon_sym_POUNDIF] = ACTIONS(12249),
    [anon_sym_POUNDIf] = ACTIONS(12249),
    [anon_sym_POUNDelif] = ACTIONS(12249),
    [anon_sym_POUNDELIF] = ACTIONS(12249),
    [anon_sym_POUNDElif] = ACTIONS(12249),
    [anon_sym_POUNDelse] = ACTIONS(12249),
    [anon_sym_POUNDELSE] = ACTIONS(12249),
    [anon_sym_POUNDElse] = ACTIONS(12249),
    [anon_sym_POUNDelse2] = ACTIONS(12249),
    [anon_sym_POUNDELSE2] = ACTIONS(12249),
    [anon_sym_POUNDElse2] = ACTIONS(12249),
    [anon_sym_POUNDendif] = ACTIONS(12249),
    [anon_sym_POUNDENDIF] = ACTIONS(12249),
    [anon_sym_POUNDEndif] = ACTIONS(12249),
    [anon_sym_POUNDendif2] = ACTIONS(12249),
    [anon_sym_POUNDENDIF2] = ACTIONS(12249),
    [anon_sym_POUNDEndif2] = ACTIONS(12249),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12249),
    [sym_trigger_keyword] = ACTIONS(12249),
    [sym_var_keyword] = ACTIONS(12249),
    [sym_local_keyword] = ACTIONS(12249),
    [sym_internal_keyword] = ACTIONS(12249),
    [sym_protected_keyword] = ACTIONS(12249),
    [sym_event_keyword] = ACTIONS(12249),
    [sym_fields_keyword] = ACTIONS(12249),
    [sym_keys_keyword] = ACTIONS(12249),
    [sym_fieldgroups_keyword] = ACTIONS(12249),
    [sym_actions_keyword] = ACTIONS(12249),
    [sym_layout_keyword] = ACTIONS(12249),
    [sym_area_keyword] = ACTIONS(12249),
    [sym_group_keyword] = ACTIONS(12249),
    [sym_repeater_keyword] = ACTIONS(12249),
    [sym_cuegroup_keyword] = ACTIONS(12249),
    [sym_fixed_keyword] = ACTIONS(12249),
    [sym_grid_keyword] = ACTIONS(12249),
    [sym_part_keyword] = ACTIONS(12249),
    [sym_systempart_keyword] = ACTIONS(12249),
    [sym_usercontrol_keyword] = ACTIONS(12249),
    [sym_dataset_keyword] = ACTIONS(12249),
    [sym_elements_keyword] = ACTIONS(12249),
    [sym_dataitem_keyword] = ACTIONS(12249),
    [sym_column_keyword] = ACTIONS(12249),
    [sym_filter_keyword] = ACTIONS(12249),
    [sym_labels_keyword] = ACTIONS(12249),
    [sym_rendering_keyword] = ACTIONS(12249),
    [sym_requestpage_keyword] = ACTIONS(12249),
    [sym_schema_keyword] = ACTIONS(12249),
    [sym_views_keyword] = ACTIONS(12249),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12249),
    [sym_preproc_open] = ACTIONS(12249),
    [sym_preproc_close] = ACTIONS(12249),
  },
  [STATE(4991)] = {
    [anon_sym_SEMI] = ACTIONS(12253),
    [aux_sym_where_condition_token1] = ACTIONS(12255),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12253),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12253),
    [anon_sym_LBRACK] = ACTIONS(12253),
    [aux_sym_basic_type_token6] = ACTIONS(12255),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12253),
    [aux_sym_addafter_modification_token1] = ACTIONS(12253),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12253),
    [aux_sym_modify_modification_token1] = ACTIONS(12253),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12253),
    [aux_sym_movelast_modification_token1] = ACTIONS(12253),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12253),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12253),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12253),
    [anon_sym_POUNDif] = ACTIONS(12253),
    [anon_sym_POUNDIF] = ACTIONS(12253),
    [anon_sym_POUNDIf] = ACTIONS(12253),
    [anon_sym_POUNDelif] = ACTIONS(12253),
    [anon_sym_POUNDELIF] = ACTIONS(12253),
    [anon_sym_POUNDElif] = ACTIONS(12253),
    [anon_sym_POUNDelse] = ACTIONS(12253),
    [anon_sym_POUNDELSE] = ACTIONS(12253),
    [anon_sym_POUNDElse] = ACTIONS(12253),
    [anon_sym_POUNDelse2] = ACTIONS(12253),
    [anon_sym_POUNDELSE2] = ACTIONS(12253),
    [anon_sym_POUNDElse2] = ACTIONS(12253),
    [anon_sym_POUNDendif] = ACTIONS(12253),
    [anon_sym_POUNDENDIF] = ACTIONS(12253),
    [anon_sym_POUNDEndif] = ACTIONS(12253),
    [anon_sym_POUNDendif2] = ACTIONS(12253),
    [anon_sym_POUNDENDIF2] = ACTIONS(12253),
    [anon_sym_POUNDEndif2] = ACTIONS(12253),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12253),
    [sym_trigger_keyword] = ACTIONS(12253),
    [sym_var_keyword] = ACTIONS(12253),
    [sym_local_keyword] = ACTIONS(12253),
    [sym_internal_keyword] = ACTIONS(12253),
    [sym_protected_keyword] = ACTIONS(12253),
    [sym_event_keyword] = ACTIONS(12253),
    [sym_fields_keyword] = ACTIONS(12253),
    [sym_keys_keyword] = ACTIONS(12253),
    [sym_fieldgroups_keyword] = ACTIONS(12253),
    [sym_actions_keyword] = ACTIONS(12253),
    [sym_layout_keyword] = ACTIONS(12253),
    [sym_area_keyword] = ACTIONS(12253),
    [sym_group_keyword] = ACTIONS(12253),
    [sym_repeater_keyword] = ACTIONS(12253),
    [sym_cuegroup_keyword] = ACTIONS(12253),
    [sym_fixed_keyword] = ACTIONS(12253),
    [sym_grid_keyword] = ACTIONS(12253),
    [sym_part_keyword] = ACTIONS(12253),
    [sym_systempart_keyword] = ACTIONS(12253),
    [sym_usercontrol_keyword] = ACTIONS(12253),
    [sym_dataset_keyword] = ACTIONS(12253),
    [sym_elements_keyword] = ACTIONS(12253),
    [sym_dataitem_keyword] = ACTIONS(12253),
    [sym_column_keyword] = ACTIONS(12253),
    [sym_filter_keyword] = ACTIONS(12253),
    [sym_labels_keyword] = ACTIONS(12253),
    [sym_rendering_keyword] = ACTIONS(12253),
    [sym_requestpage_keyword] = ACTIONS(12253),
    [sym_schema_keyword] = ACTIONS(12253),
    [sym_views_keyword] = ACTIONS(12253),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12253),
    [sym_preproc_open] = ACTIONS(12253),
    [sym_preproc_close] = ACTIONS(12253),
  },
  [STATE(4992)] = {
    [anon_sym_SEMI] = ACTIONS(12253),
    [aux_sym_where_condition_token1] = ACTIONS(12255),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12253),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12253),
    [anon_sym_LBRACK] = ACTIONS(12253),
    [aux_sym_basic_type_token6] = ACTIONS(12255),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12253),
    [aux_sym_addafter_modification_token1] = ACTIONS(12253),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12253),
    [aux_sym_modify_modification_token1] = ACTIONS(12253),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12253),
    [aux_sym_movelast_modification_token1] = ACTIONS(12253),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12253),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12253),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12253),
    [anon_sym_POUNDif] = ACTIONS(12253),
    [anon_sym_POUNDIF] = ACTIONS(12253),
    [anon_sym_POUNDIf] = ACTIONS(12253),
    [anon_sym_POUNDelif] = ACTIONS(12253),
    [anon_sym_POUNDELIF] = ACTIONS(12253),
    [anon_sym_POUNDElif] = ACTIONS(12253),
    [anon_sym_POUNDelse] = ACTIONS(12253),
    [anon_sym_POUNDELSE] = ACTIONS(12253),
    [anon_sym_POUNDElse] = ACTIONS(12253),
    [anon_sym_POUNDelse2] = ACTIONS(12253),
    [anon_sym_POUNDELSE2] = ACTIONS(12253),
    [anon_sym_POUNDElse2] = ACTIONS(12253),
    [anon_sym_POUNDendif] = ACTIONS(12253),
    [anon_sym_POUNDENDIF] = ACTIONS(12253),
    [anon_sym_POUNDEndif] = ACTIONS(12253),
    [anon_sym_POUNDendif2] = ACTIONS(12253),
    [anon_sym_POUNDENDIF2] = ACTIONS(12253),
    [anon_sym_POUNDEndif2] = ACTIONS(12253),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12253),
    [sym_trigger_keyword] = ACTIONS(12253),
    [sym_var_keyword] = ACTIONS(12253),
    [sym_local_keyword] = ACTIONS(12253),
    [sym_internal_keyword] = ACTIONS(12253),
    [sym_protected_keyword] = ACTIONS(12253),
    [sym_event_keyword] = ACTIONS(12253),
    [sym_fields_keyword] = ACTIONS(12253),
    [sym_keys_keyword] = ACTIONS(12253),
    [sym_fieldgroups_keyword] = ACTIONS(12253),
    [sym_actions_keyword] = ACTIONS(12253),
    [sym_layout_keyword] = ACTIONS(12253),
    [sym_area_keyword] = ACTIONS(12253),
    [sym_group_keyword] = ACTIONS(12253),
    [sym_repeater_keyword] = ACTIONS(12253),
    [sym_cuegroup_keyword] = ACTIONS(12253),
    [sym_fixed_keyword] = ACTIONS(12253),
    [sym_grid_keyword] = ACTIONS(12253),
    [sym_part_keyword] = ACTIONS(12253),
    [sym_systempart_keyword] = ACTIONS(12253),
    [sym_usercontrol_keyword] = ACTIONS(12253),
    [sym_dataset_keyword] = ACTIONS(12253),
    [sym_elements_keyword] = ACTIONS(12253),
    [sym_dataitem_keyword] = ACTIONS(12253),
    [sym_column_keyword] = ACTIONS(12253),
    [sym_filter_keyword] = ACTIONS(12253),
    [sym_labels_keyword] = ACTIONS(12253),
    [sym_rendering_keyword] = ACTIONS(12253),
    [sym_requestpage_keyword] = ACTIONS(12253),
    [sym_schema_keyword] = ACTIONS(12253),
    [sym_views_keyword] = ACTIONS(12253),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12253),
    [sym_preproc_open] = ACTIONS(12253),
    [sym_preproc_close] = ACTIONS(12253),
  },
  [STATE(4993)] = {
    [anon_sym_SEMI] = ACTIONS(12257),
    [aux_sym_where_condition_token1] = ACTIONS(12259),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12257),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12257),
    [anon_sym_LBRACK] = ACTIONS(12257),
    [aux_sym_basic_type_token6] = ACTIONS(12259),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12257),
    [aux_sym_addafter_modification_token1] = ACTIONS(12257),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12257),
    [aux_sym_modify_modification_token1] = ACTIONS(12257),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12257),
    [aux_sym_movelast_modification_token1] = ACTIONS(12257),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12257),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12257),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12257),
    [anon_sym_POUNDif] = ACTIONS(12257),
    [anon_sym_POUNDIF] = ACTIONS(12257),
    [anon_sym_POUNDIf] = ACTIONS(12257),
    [anon_sym_POUNDelif] = ACTIONS(12257),
    [anon_sym_POUNDELIF] = ACTIONS(12257),
    [anon_sym_POUNDElif] = ACTIONS(12257),
    [anon_sym_POUNDelse] = ACTIONS(12257),
    [anon_sym_POUNDELSE] = ACTIONS(12257),
    [anon_sym_POUNDElse] = ACTIONS(12257),
    [anon_sym_POUNDelse2] = ACTIONS(12257),
    [anon_sym_POUNDELSE2] = ACTIONS(12257),
    [anon_sym_POUNDElse2] = ACTIONS(12257),
    [anon_sym_POUNDendif] = ACTIONS(12257),
    [anon_sym_POUNDENDIF] = ACTIONS(12257),
    [anon_sym_POUNDEndif] = ACTIONS(12257),
    [anon_sym_POUNDendif2] = ACTIONS(12257),
    [anon_sym_POUNDENDIF2] = ACTIONS(12257),
    [anon_sym_POUNDEndif2] = ACTIONS(12257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12257),
    [sym_trigger_keyword] = ACTIONS(12257),
    [sym_var_keyword] = ACTIONS(12257),
    [sym_local_keyword] = ACTIONS(12257),
    [sym_internal_keyword] = ACTIONS(12257),
    [sym_protected_keyword] = ACTIONS(12257),
    [sym_event_keyword] = ACTIONS(12257),
    [sym_fields_keyword] = ACTIONS(12257),
    [sym_keys_keyword] = ACTIONS(12257),
    [sym_fieldgroups_keyword] = ACTIONS(12257),
    [sym_actions_keyword] = ACTIONS(12257),
    [sym_layout_keyword] = ACTIONS(12257),
    [sym_area_keyword] = ACTIONS(12257),
    [sym_group_keyword] = ACTIONS(12257),
    [sym_repeater_keyword] = ACTIONS(12257),
    [sym_cuegroup_keyword] = ACTIONS(12257),
    [sym_fixed_keyword] = ACTIONS(12257),
    [sym_grid_keyword] = ACTIONS(12257),
    [sym_part_keyword] = ACTIONS(12257),
    [sym_systempart_keyword] = ACTIONS(12257),
    [sym_usercontrol_keyword] = ACTIONS(12257),
    [sym_dataset_keyword] = ACTIONS(12257),
    [sym_elements_keyword] = ACTIONS(12257),
    [sym_dataitem_keyword] = ACTIONS(12257),
    [sym_column_keyword] = ACTIONS(12257),
    [sym_filter_keyword] = ACTIONS(12257),
    [sym_labels_keyword] = ACTIONS(12257),
    [sym_rendering_keyword] = ACTIONS(12257),
    [sym_requestpage_keyword] = ACTIONS(12257),
    [sym_schema_keyword] = ACTIONS(12257),
    [sym_views_keyword] = ACTIONS(12257),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12257),
    [sym_preproc_open] = ACTIONS(12257),
    [sym_preproc_close] = ACTIONS(12257),
  },
  [STATE(4994)] = {
    [anon_sym_SEMI] = ACTIONS(12257),
    [aux_sym_where_condition_token1] = ACTIONS(12259),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12257),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12257),
    [anon_sym_LBRACK] = ACTIONS(12257),
    [aux_sym_basic_type_token6] = ACTIONS(12259),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12257),
    [aux_sym_addafter_modification_token1] = ACTIONS(12257),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12257),
    [aux_sym_modify_modification_token1] = ACTIONS(12257),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12257),
    [aux_sym_movelast_modification_token1] = ACTIONS(12257),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12257),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12257),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12257),
    [anon_sym_POUNDif] = ACTIONS(12257),
    [anon_sym_POUNDIF] = ACTIONS(12257),
    [anon_sym_POUNDIf] = ACTIONS(12257),
    [anon_sym_POUNDelif] = ACTIONS(12257),
    [anon_sym_POUNDELIF] = ACTIONS(12257),
    [anon_sym_POUNDElif] = ACTIONS(12257),
    [anon_sym_POUNDelse] = ACTIONS(12257),
    [anon_sym_POUNDELSE] = ACTIONS(12257),
    [anon_sym_POUNDElse] = ACTIONS(12257),
    [anon_sym_POUNDelse2] = ACTIONS(12257),
    [anon_sym_POUNDELSE2] = ACTIONS(12257),
    [anon_sym_POUNDElse2] = ACTIONS(12257),
    [anon_sym_POUNDendif] = ACTIONS(12257),
    [anon_sym_POUNDENDIF] = ACTIONS(12257),
    [anon_sym_POUNDEndif] = ACTIONS(12257),
    [anon_sym_POUNDendif2] = ACTIONS(12257),
    [anon_sym_POUNDENDIF2] = ACTIONS(12257),
    [anon_sym_POUNDEndif2] = ACTIONS(12257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12257),
    [sym_trigger_keyword] = ACTIONS(12257),
    [sym_var_keyword] = ACTIONS(12257),
    [sym_local_keyword] = ACTIONS(12257),
    [sym_internal_keyword] = ACTIONS(12257),
    [sym_protected_keyword] = ACTIONS(12257),
    [sym_event_keyword] = ACTIONS(12257),
    [sym_fields_keyword] = ACTIONS(12257),
    [sym_keys_keyword] = ACTIONS(12257),
    [sym_fieldgroups_keyword] = ACTIONS(12257),
    [sym_actions_keyword] = ACTIONS(12257),
    [sym_layout_keyword] = ACTIONS(12257),
    [sym_area_keyword] = ACTIONS(12257),
    [sym_group_keyword] = ACTIONS(12257),
    [sym_repeater_keyword] = ACTIONS(12257),
    [sym_cuegroup_keyword] = ACTIONS(12257),
    [sym_fixed_keyword] = ACTIONS(12257),
    [sym_grid_keyword] = ACTIONS(12257),
    [sym_part_keyword] = ACTIONS(12257),
    [sym_systempart_keyword] = ACTIONS(12257),
    [sym_usercontrol_keyword] = ACTIONS(12257),
    [sym_dataset_keyword] = ACTIONS(12257),
    [sym_elements_keyword] = ACTIONS(12257),
    [sym_dataitem_keyword] = ACTIONS(12257),
    [sym_column_keyword] = ACTIONS(12257),
    [sym_filter_keyword] = ACTIONS(12257),
    [sym_labels_keyword] = ACTIONS(12257),
    [sym_rendering_keyword] = ACTIONS(12257),
    [sym_requestpage_keyword] = ACTIONS(12257),
    [sym_schema_keyword] = ACTIONS(12257),
    [sym_views_keyword] = ACTIONS(12257),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12257),
    [sym_preproc_open] = ACTIONS(12257),
    [sym_preproc_close] = ACTIONS(12257),
  },
  [STATE(4995)] = {
    [anon_sym_SEMI] = ACTIONS(12261),
    [aux_sym_where_condition_token1] = ACTIONS(12263),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12261),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12261),
    [anon_sym_LBRACK] = ACTIONS(12261),
    [aux_sym_basic_type_token6] = ACTIONS(12263),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12261),
    [aux_sym_addafter_modification_token1] = ACTIONS(12261),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12261),
    [aux_sym_modify_modification_token1] = ACTIONS(12261),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12261),
    [aux_sym_movelast_modification_token1] = ACTIONS(12261),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12261),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12261),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12261),
    [anon_sym_POUNDif] = ACTIONS(12261),
    [anon_sym_POUNDIF] = ACTIONS(12261),
    [anon_sym_POUNDIf] = ACTIONS(12261),
    [anon_sym_POUNDelif] = ACTIONS(12261),
    [anon_sym_POUNDELIF] = ACTIONS(12261),
    [anon_sym_POUNDElif] = ACTIONS(12261),
    [anon_sym_POUNDelse] = ACTIONS(12261),
    [anon_sym_POUNDELSE] = ACTIONS(12261),
    [anon_sym_POUNDElse] = ACTIONS(12261),
    [anon_sym_POUNDelse2] = ACTIONS(12261),
    [anon_sym_POUNDELSE2] = ACTIONS(12261),
    [anon_sym_POUNDElse2] = ACTIONS(12261),
    [anon_sym_POUNDendif] = ACTIONS(12261),
    [anon_sym_POUNDENDIF] = ACTIONS(12261),
    [anon_sym_POUNDEndif] = ACTIONS(12261),
    [anon_sym_POUNDendif2] = ACTIONS(12261),
    [anon_sym_POUNDENDIF2] = ACTIONS(12261),
    [anon_sym_POUNDEndif2] = ACTIONS(12261),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12261),
    [sym_trigger_keyword] = ACTIONS(12261),
    [sym_var_keyword] = ACTIONS(12261),
    [sym_local_keyword] = ACTIONS(12261),
    [sym_internal_keyword] = ACTIONS(12261),
    [sym_protected_keyword] = ACTIONS(12261),
    [sym_event_keyword] = ACTIONS(12261),
    [sym_fields_keyword] = ACTIONS(12261),
    [sym_keys_keyword] = ACTIONS(12261),
    [sym_fieldgroups_keyword] = ACTIONS(12261),
    [sym_actions_keyword] = ACTIONS(12261),
    [sym_layout_keyword] = ACTIONS(12261),
    [sym_area_keyword] = ACTIONS(12261),
    [sym_group_keyword] = ACTIONS(12261),
    [sym_repeater_keyword] = ACTIONS(12261),
    [sym_cuegroup_keyword] = ACTIONS(12261),
    [sym_fixed_keyword] = ACTIONS(12261),
    [sym_grid_keyword] = ACTIONS(12261),
    [sym_part_keyword] = ACTIONS(12261),
    [sym_systempart_keyword] = ACTIONS(12261),
    [sym_usercontrol_keyword] = ACTIONS(12261),
    [sym_dataset_keyword] = ACTIONS(12261),
    [sym_elements_keyword] = ACTIONS(12261),
    [sym_dataitem_keyword] = ACTIONS(12261),
    [sym_column_keyword] = ACTIONS(12261),
    [sym_filter_keyword] = ACTIONS(12261),
    [sym_labels_keyword] = ACTIONS(12261),
    [sym_rendering_keyword] = ACTIONS(12261),
    [sym_requestpage_keyword] = ACTIONS(12261),
    [sym_schema_keyword] = ACTIONS(12261),
    [sym_views_keyword] = ACTIONS(12261),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12261),
    [sym_preproc_open] = ACTIONS(12261),
    [sym_preproc_close] = ACTIONS(12261),
  },
  [STATE(4996)] = {
    [anon_sym_SEMI] = ACTIONS(12261),
    [aux_sym_where_condition_token1] = ACTIONS(12263),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12261),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12261),
    [anon_sym_LBRACK] = ACTIONS(12261),
    [aux_sym_basic_type_token6] = ACTIONS(12263),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12261),
    [aux_sym_addafter_modification_token1] = ACTIONS(12261),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12261),
    [aux_sym_modify_modification_token1] = ACTIONS(12261),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12261),
    [aux_sym_movelast_modification_token1] = ACTIONS(12261),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12261),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12261),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12261),
    [anon_sym_POUNDif] = ACTIONS(12261),
    [anon_sym_POUNDIF] = ACTIONS(12261),
    [anon_sym_POUNDIf] = ACTIONS(12261),
    [anon_sym_POUNDelif] = ACTIONS(12261),
    [anon_sym_POUNDELIF] = ACTIONS(12261),
    [anon_sym_POUNDElif] = ACTIONS(12261),
    [anon_sym_POUNDelse] = ACTIONS(12261),
    [anon_sym_POUNDELSE] = ACTIONS(12261),
    [anon_sym_POUNDElse] = ACTIONS(12261),
    [anon_sym_POUNDelse2] = ACTIONS(12261),
    [anon_sym_POUNDELSE2] = ACTIONS(12261),
    [anon_sym_POUNDElse2] = ACTIONS(12261),
    [anon_sym_POUNDendif] = ACTIONS(12261),
    [anon_sym_POUNDENDIF] = ACTIONS(12261),
    [anon_sym_POUNDEndif] = ACTIONS(12261),
    [anon_sym_POUNDendif2] = ACTIONS(12261),
    [anon_sym_POUNDENDIF2] = ACTIONS(12261),
    [anon_sym_POUNDEndif2] = ACTIONS(12261),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12261),
    [sym_trigger_keyword] = ACTIONS(12261),
    [sym_var_keyword] = ACTIONS(12261),
    [sym_local_keyword] = ACTIONS(12261),
    [sym_internal_keyword] = ACTIONS(12261),
    [sym_protected_keyword] = ACTIONS(12261),
    [sym_event_keyword] = ACTIONS(12261),
    [sym_fields_keyword] = ACTIONS(12261),
    [sym_keys_keyword] = ACTIONS(12261),
    [sym_fieldgroups_keyword] = ACTIONS(12261),
    [sym_actions_keyword] = ACTIONS(12261),
    [sym_layout_keyword] = ACTIONS(12261),
    [sym_area_keyword] = ACTIONS(12261),
    [sym_group_keyword] = ACTIONS(12261),
    [sym_repeater_keyword] = ACTIONS(12261),
    [sym_cuegroup_keyword] = ACTIONS(12261),
    [sym_fixed_keyword] = ACTIONS(12261),
    [sym_grid_keyword] = ACTIONS(12261),
    [sym_part_keyword] = ACTIONS(12261),
    [sym_systempart_keyword] = ACTIONS(12261),
    [sym_usercontrol_keyword] = ACTIONS(12261),
    [sym_dataset_keyword] = ACTIONS(12261),
    [sym_elements_keyword] = ACTIONS(12261),
    [sym_dataitem_keyword] = ACTIONS(12261),
    [sym_column_keyword] = ACTIONS(12261),
    [sym_filter_keyword] = ACTIONS(12261),
    [sym_labels_keyword] = ACTIONS(12261),
    [sym_rendering_keyword] = ACTIONS(12261),
    [sym_requestpage_keyword] = ACTIONS(12261),
    [sym_schema_keyword] = ACTIONS(12261),
    [sym_views_keyword] = ACTIONS(12261),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12261),
    [sym_preproc_open] = ACTIONS(12261),
    [sym_preproc_close] = ACTIONS(12261),
  },
  [STATE(4997)] = {
    [anon_sym_SEMI] = ACTIONS(12265),
    [aux_sym_where_condition_token1] = ACTIONS(12267),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12265),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12265),
    [anon_sym_LBRACK] = ACTIONS(12265),
    [aux_sym_basic_type_token6] = ACTIONS(12267),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12265),
    [aux_sym_addafter_modification_token1] = ACTIONS(12265),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12265),
    [aux_sym_modify_modification_token1] = ACTIONS(12265),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12265),
    [aux_sym_movelast_modification_token1] = ACTIONS(12265),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12265),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12265),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12265),
    [anon_sym_POUNDif] = ACTIONS(12265),
    [anon_sym_POUNDIF] = ACTIONS(12265),
    [anon_sym_POUNDIf] = ACTIONS(12265),
    [anon_sym_POUNDelif] = ACTIONS(12265),
    [anon_sym_POUNDELIF] = ACTIONS(12265),
    [anon_sym_POUNDElif] = ACTIONS(12265),
    [anon_sym_POUNDelse] = ACTIONS(12265),
    [anon_sym_POUNDELSE] = ACTIONS(12265),
    [anon_sym_POUNDElse] = ACTIONS(12265),
    [anon_sym_POUNDelse2] = ACTIONS(12265),
    [anon_sym_POUNDELSE2] = ACTIONS(12265),
    [anon_sym_POUNDElse2] = ACTIONS(12265),
    [anon_sym_POUNDendif] = ACTIONS(12265),
    [anon_sym_POUNDENDIF] = ACTIONS(12265),
    [anon_sym_POUNDEndif] = ACTIONS(12265),
    [anon_sym_POUNDendif2] = ACTIONS(12265),
    [anon_sym_POUNDENDIF2] = ACTIONS(12265),
    [anon_sym_POUNDEndif2] = ACTIONS(12265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12265),
    [sym_trigger_keyword] = ACTIONS(12265),
    [sym_var_keyword] = ACTIONS(12265),
    [sym_local_keyword] = ACTIONS(12265),
    [sym_internal_keyword] = ACTIONS(12265),
    [sym_protected_keyword] = ACTIONS(12265),
    [sym_event_keyword] = ACTIONS(12265),
    [sym_fields_keyword] = ACTIONS(12265),
    [sym_keys_keyword] = ACTIONS(12265),
    [sym_fieldgroups_keyword] = ACTIONS(12265),
    [sym_actions_keyword] = ACTIONS(12265),
    [sym_layout_keyword] = ACTIONS(12265),
    [sym_area_keyword] = ACTIONS(12265),
    [sym_group_keyword] = ACTIONS(12265),
    [sym_repeater_keyword] = ACTIONS(12265),
    [sym_cuegroup_keyword] = ACTIONS(12265),
    [sym_fixed_keyword] = ACTIONS(12265),
    [sym_grid_keyword] = ACTIONS(12265),
    [sym_part_keyword] = ACTIONS(12265),
    [sym_systempart_keyword] = ACTIONS(12265),
    [sym_usercontrol_keyword] = ACTIONS(12265),
    [sym_dataset_keyword] = ACTIONS(12265),
    [sym_elements_keyword] = ACTIONS(12265),
    [sym_dataitem_keyword] = ACTIONS(12265),
    [sym_column_keyword] = ACTIONS(12265),
    [sym_filter_keyword] = ACTIONS(12265),
    [sym_labels_keyword] = ACTIONS(12265),
    [sym_rendering_keyword] = ACTIONS(12265),
    [sym_requestpage_keyword] = ACTIONS(12265),
    [sym_schema_keyword] = ACTIONS(12265),
    [sym_views_keyword] = ACTIONS(12265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12265),
    [sym_preproc_open] = ACTIONS(12265),
    [sym_preproc_close] = ACTIONS(12265),
  },
  [STATE(4998)] = {
    [anon_sym_SEMI] = ACTIONS(12265),
    [aux_sym_where_condition_token1] = ACTIONS(12267),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12265),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12265),
    [anon_sym_LBRACK] = ACTIONS(12265),
    [aux_sym_basic_type_token6] = ACTIONS(12267),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12265),
    [aux_sym_addafter_modification_token1] = ACTIONS(12265),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12265),
    [aux_sym_modify_modification_token1] = ACTIONS(12265),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12265),
    [aux_sym_movelast_modification_token1] = ACTIONS(12265),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12265),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12265),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12265),
    [anon_sym_POUNDif] = ACTIONS(12265),
    [anon_sym_POUNDIF] = ACTIONS(12265),
    [anon_sym_POUNDIf] = ACTIONS(12265),
    [anon_sym_POUNDelif] = ACTIONS(12265),
    [anon_sym_POUNDELIF] = ACTIONS(12265),
    [anon_sym_POUNDElif] = ACTIONS(12265),
    [anon_sym_POUNDelse] = ACTIONS(12265),
    [anon_sym_POUNDELSE] = ACTIONS(12265),
    [anon_sym_POUNDElse] = ACTIONS(12265),
    [anon_sym_POUNDelse2] = ACTIONS(12265),
    [anon_sym_POUNDELSE2] = ACTIONS(12265),
    [anon_sym_POUNDElse2] = ACTIONS(12265),
    [anon_sym_POUNDendif] = ACTIONS(12265),
    [anon_sym_POUNDENDIF] = ACTIONS(12265),
    [anon_sym_POUNDEndif] = ACTIONS(12265),
    [anon_sym_POUNDendif2] = ACTIONS(12265),
    [anon_sym_POUNDENDIF2] = ACTIONS(12265),
    [anon_sym_POUNDEndif2] = ACTIONS(12265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12265),
    [sym_trigger_keyword] = ACTIONS(12265),
    [sym_var_keyword] = ACTIONS(12265),
    [sym_local_keyword] = ACTIONS(12265),
    [sym_internal_keyword] = ACTIONS(12265),
    [sym_protected_keyword] = ACTIONS(12265),
    [sym_event_keyword] = ACTIONS(12265),
    [sym_fields_keyword] = ACTIONS(12265),
    [sym_keys_keyword] = ACTIONS(12265),
    [sym_fieldgroups_keyword] = ACTIONS(12265),
    [sym_actions_keyword] = ACTIONS(12265),
    [sym_layout_keyword] = ACTIONS(12265),
    [sym_area_keyword] = ACTIONS(12265),
    [sym_group_keyword] = ACTIONS(12265),
    [sym_repeater_keyword] = ACTIONS(12265),
    [sym_cuegroup_keyword] = ACTIONS(12265),
    [sym_fixed_keyword] = ACTIONS(12265),
    [sym_grid_keyword] = ACTIONS(12265),
    [sym_part_keyword] = ACTIONS(12265),
    [sym_systempart_keyword] = ACTIONS(12265),
    [sym_usercontrol_keyword] = ACTIONS(12265),
    [sym_dataset_keyword] = ACTIONS(12265),
    [sym_elements_keyword] = ACTIONS(12265),
    [sym_dataitem_keyword] = ACTIONS(12265),
    [sym_column_keyword] = ACTIONS(12265),
    [sym_filter_keyword] = ACTIONS(12265),
    [sym_labels_keyword] = ACTIONS(12265),
    [sym_rendering_keyword] = ACTIONS(12265),
    [sym_requestpage_keyword] = ACTIONS(12265),
    [sym_schema_keyword] = ACTIONS(12265),
    [sym_views_keyword] = ACTIONS(12265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12265),
    [sym_preproc_open] = ACTIONS(12265),
    [sym_preproc_close] = ACTIONS(12265),
  },
  [STATE(4999)] = {
    [anon_sym_SEMI] = ACTIONS(12265),
    [aux_sym_where_condition_token1] = ACTIONS(12267),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12265),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12265),
    [anon_sym_LBRACK] = ACTIONS(12265),
    [aux_sym_basic_type_token6] = ACTIONS(12267),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12265),
    [aux_sym_addafter_modification_token1] = ACTIONS(12265),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12265),
    [aux_sym_modify_modification_token1] = ACTIONS(12265),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12265),
    [aux_sym_movelast_modification_token1] = ACTIONS(12265),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12265),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12265),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12265),
    [anon_sym_POUNDif] = ACTIONS(12265),
    [anon_sym_POUNDIF] = ACTIONS(12265),
    [anon_sym_POUNDIf] = ACTIONS(12265),
    [anon_sym_POUNDelif] = ACTIONS(12265),
    [anon_sym_POUNDELIF] = ACTIONS(12265),
    [anon_sym_POUNDElif] = ACTIONS(12265),
    [anon_sym_POUNDelse] = ACTIONS(12265),
    [anon_sym_POUNDELSE] = ACTIONS(12265),
    [anon_sym_POUNDElse] = ACTIONS(12265),
    [anon_sym_POUNDelse2] = ACTIONS(12265),
    [anon_sym_POUNDELSE2] = ACTIONS(12265),
    [anon_sym_POUNDElse2] = ACTIONS(12265),
    [anon_sym_POUNDendif] = ACTIONS(12265),
    [anon_sym_POUNDENDIF] = ACTIONS(12265),
    [anon_sym_POUNDEndif] = ACTIONS(12265),
    [anon_sym_POUNDendif2] = ACTIONS(12265),
    [anon_sym_POUNDENDIF2] = ACTIONS(12265),
    [anon_sym_POUNDEndif2] = ACTIONS(12265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12265),
    [sym_trigger_keyword] = ACTIONS(12265),
    [sym_var_keyword] = ACTIONS(12265),
    [sym_local_keyword] = ACTIONS(12265),
    [sym_internal_keyword] = ACTIONS(12265),
    [sym_protected_keyword] = ACTIONS(12265),
    [sym_event_keyword] = ACTIONS(12265),
    [sym_fields_keyword] = ACTIONS(12265),
    [sym_keys_keyword] = ACTIONS(12265),
    [sym_fieldgroups_keyword] = ACTIONS(12265),
    [sym_actions_keyword] = ACTIONS(12265),
    [sym_layout_keyword] = ACTIONS(12265),
    [sym_area_keyword] = ACTIONS(12265),
    [sym_group_keyword] = ACTIONS(12265),
    [sym_repeater_keyword] = ACTIONS(12265),
    [sym_cuegroup_keyword] = ACTIONS(12265),
    [sym_fixed_keyword] = ACTIONS(12265),
    [sym_grid_keyword] = ACTIONS(12265),
    [sym_part_keyword] = ACTIONS(12265),
    [sym_systempart_keyword] = ACTIONS(12265),
    [sym_usercontrol_keyword] = ACTIONS(12265),
    [sym_dataset_keyword] = ACTIONS(12265),
    [sym_elements_keyword] = ACTIONS(12265),
    [sym_dataitem_keyword] = ACTIONS(12265),
    [sym_column_keyword] = ACTIONS(12265),
    [sym_filter_keyword] = ACTIONS(12265),
    [sym_labels_keyword] = ACTIONS(12265),
    [sym_rendering_keyword] = ACTIONS(12265),
    [sym_requestpage_keyword] = ACTIONS(12265),
    [sym_schema_keyword] = ACTIONS(12265),
    [sym_views_keyword] = ACTIONS(12265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12265),
    [sym_preproc_open] = ACTIONS(12265),
    [sym_preproc_close] = ACTIONS(12265),
  },
  [STATE(5000)] = {
    [anon_sym_SEMI] = ACTIONS(12265),
    [aux_sym_where_condition_token1] = ACTIONS(12267),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12265),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12265),
    [anon_sym_LBRACK] = ACTIONS(12265),
    [aux_sym_basic_type_token6] = ACTIONS(12267),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12265),
    [aux_sym_addafter_modification_token1] = ACTIONS(12265),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12265),
    [aux_sym_modify_modification_token1] = ACTIONS(12265),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12265),
    [aux_sym_movelast_modification_token1] = ACTIONS(12265),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12265),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12265),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12265),
    [anon_sym_POUNDif] = ACTIONS(12265),
    [anon_sym_POUNDIF] = ACTIONS(12265),
    [anon_sym_POUNDIf] = ACTIONS(12265),
    [anon_sym_POUNDelif] = ACTIONS(12265),
    [anon_sym_POUNDELIF] = ACTIONS(12265),
    [anon_sym_POUNDElif] = ACTIONS(12265),
    [anon_sym_POUNDelse] = ACTIONS(12265),
    [anon_sym_POUNDELSE] = ACTIONS(12265),
    [anon_sym_POUNDElse] = ACTIONS(12265),
    [anon_sym_POUNDelse2] = ACTIONS(12265),
    [anon_sym_POUNDELSE2] = ACTIONS(12265),
    [anon_sym_POUNDElse2] = ACTIONS(12265),
    [anon_sym_POUNDendif] = ACTIONS(12265),
    [anon_sym_POUNDENDIF] = ACTIONS(12265),
    [anon_sym_POUNDEndif] = ACTIONS(12265),
    [anon_sym_POUNDendif2] = ACTIONS(12265),
    [anon_sym_POUNDENDIF2] = ACTIONS(12265),
    [anon_sym_POUNDEndif2] = ACTIONS(12265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12265),
    [sym_trigger_keyword] = ACTIONS(12265),
    [sym_var_keyword] = ACTIONS(12265),
    [sym_local_keyword] = ACTIONS(12265),
    [sym_internal_keyword] = ACTIONS(12265),
    [sym_protected_keyword] = ACTIONS(12265),
    [sym_event_keyword] = ACTIONS(12265),
    [sym_fields_keyword] = ACTIONS(12265),
    [sym_keys_keyword] = ACTIONS(12265),
    [sym_fieldgroups_keyword] = ACTIONS(12265),
    [sym_actions_keyword] = ACTIONS(12265),
    [sym_layout_keyword] = ACTIONS(12265),
    [sym_area_keyword] = ACTIONS(12265),
    [sym_group_keyword] = ACTIONS(12265),
    [sym_repeater_keyword] = ACTIONS(12265),
    [sym_cuegroup_keyword] = ACTIONS(12265),
    [sym_fixed_keyword] = ACTIONS(12265),
    [sym_grid_keyword] = ACTIONS(12265),
    [sym_part_keyword] = ACTIONS(12265),
    [sym_systempart_keyword] = ACTIONS(12265),
    [sym_usercontrol_keyword] = ACTIONS(12265),
    [sym_dataset_keyword] = ACTIONS(12265),
    [sym_elements_keyword] = ACTIONS(12265),
    [sym_dataitem_keyword] = ACTIONS(12265),
    [sym_column_keyword] = ACTIONS(12265),
    [sym_filter_keyword] = ACTIONS(12265),
    [sym_labels_keyword] = ACTIONS(12265),
    [sym_rendering_keyword] = ACTIONS(12265),
    [sym_requestpage_keyword] = ACTIONS(12265),
    [sym_schema_keyword] = ACTIONS(12265),
    [sym_views_keyword] = ACTIONS(12265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12265),
    [sym_preproc_open] = ACTIONS(12265),
    [sym_preproc_close] = ACTIONS(12265),
  },
  [STATE(5001)] = {
    [anon_sym_SEMI] = ACTIONS(12265),
    [aux_sym_where_condition_token1] = ACTIONS(12267),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12265),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12265),
    [anon_sym_LBRACK] = ACTIONS(12265),
    [aux_sym_basic_type_token6] = ACTIONS(12267),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12265),
    [aux_sym_addafter_modification_token1] = ACTIONS(12265),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12265),
    [aux_sym_modify_modification_token1] = ACTIONS(12265),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12265),
    [aux_sym_movelast_modification_token1] = ACTIONS(12265),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12265),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12265),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12265),
    [anon_sym_POUNDif] = ACTIONS(12265),
    [anon_sym_POUNDIF] = ACTIONS(12265),
    [anon_sym_POUNDIf] = ACTIONS(12265),
    [anon_sym_POUNDelif] = ACTIONS(12265),
    [anon_sym_POUNDELIF] = ACTIONS(12265),
    [anon_sym_POUNDElif] = ACTIONS(12265),
    [anon_sym_POUNDelse] = ACTIONS(12265),
    [anon_sym_POUNDELSE] = ACTIONS(12265),
    [anon_sym_POUNDElse] = ACTIONS(12265),
    [anon_sym_POUNDelse2] = ACTIONS(12265),
    [anon_sym_POUNDELSE2] = ACTIONS(12265),
    [anon_sym_POUNDElse2] = ACTIONS(12265),
    [anon_sym_POUNDendif] = ACTIONS(12265),
    [anon_sym_POUNDENDIF] = ACTIONS(12265),
    [anon_sym_POUNDEndif] = ACTIONS(12265),
    [anon_sym_POUNDendif2] = ACTIONS(12265),
    [anon_sym_POUNDENDIF2] = ACTIONS(12265),
    [anon_sym_POUNDEndif2] = ACTIONS(12265),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12265),
    [sym_trigger_keyword] = ACTIONS(12265),
    [sym_var_keyword] = ACTIONS(12265),
    [sym_local_keyword] = ACTIONS(12265),
    [sym_internal_keyword] = ACTIONS(12265),
    [sym_protected_keyword] = ACTIONS(12265),
    [sym_event_keyword] = ACTIONS(12265),
    [sym_fields_keyword] = ACTIONS(12265),
    [sym_keys_keyword] = ACTIONS(12265),
    [sym_fieldgroups_keyword] = ACTIONS(12265),
    [sym_actions_keyword] = ACTIONS(12265),
    [sym_layout_keyword] = ACTIONS(12265),
    [sym_area_keyword] = ACTIONS(12265),
    [sym_group_keyword] = ACTIONS(12265),
    [sym_repeater_keyword] = ACTIONS(12265),
    [sym_cuegroup_keyword] = ACTIONS(12265),
    [sym_fixed_keyword] = ACTIONS(12265),
    [sym_grid_keyword] = ACTIONS(12265),
    [sym_part_keyword] = ACTIONS(12265),
    [sym_systempart_keyword] = ACTIONS(12265),
    [sym_usercontrol_keyword] = ACTIONS(12265),
    [sym_dataset_keyword] = ACTIONS(12265),
    [sym_elements_keyword] = ACTIONS(12265),
    [sym_dataitem_keyword] = ACTIONS(12265),
    [sym_column_keyword] = ACTIONS(12265),
    [sym_filter_keyword] = ACTIONS(12265),
    [sym_labels_keyword] = ACTIONS(12265),
    [sym_rendering_keyword] = ACTIONS(12265),
    [sym_requestpage_keyword] = ACTIONS(12265),
    [sym_schema_keyword] = ACTIONS(12265),
    [sym_views_keyword] = ACTIONS(12265),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12265),
    [sym_preproc_open] = ACTIONS(12265),
    [sym_preproc_close] = ACTIONS(12265),
  },
  [STATE(5002)] = {
    [anon_sym_SEMI] = ACTIONS(12269),
    [aux_sym_where_condition_token1] = ACTIONS(12271),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12269),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12269),
    [anon_sym_LBRACK] = ACTIONS(12269),
    [aux_sym_basic_type_token6] = ACTIONS(12271),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12269),
    [aux_sym_addafter_modification_token1] = ACTIONS(12269),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12269),
    [aux_sym_modify_modification_token1] = ACTIONS(12269),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12269),
    [aux_sym_movelast_modification_token1] = ACTIONS(12269),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12269),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12269),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12269),
    [anon_sym_POUNDif] = ACTIONS(12269),
    [anon_sym_POUNDIF] = ACTIONS(12269),
    [anon_sym_POUNDIf] = ACTIONS(12269),
    [anon_sym_POUNDelif] = ACTIONS(12269),
    [anon_sym_POUNDELIF] = ACTIONS(12269),
    [anon_sym_POUNDElif] = ACTIONS(12269),
    [anon_sym_POUNDelse] = ACTIONS(12269),
    [anon_sym_POUNDELSE] = ACTIONS(12269),
    [anon_sym_POUNDElse] = ACTIONS(12269),
    [anon_sym_POUNDelse2] = ACTIONS(12269),
    [anon_sym_POUNDELSE2] = ACTIONS(12269),
    [anon_sym_POUNDElse2] = ACTIONS(12269),
    [anon_sym_POUNDendif] = ACTIONS(12269),
    [anon_sym_POUNDENDIF] = ACTIONS(12269),
    [anon_sym_POUNDEndif] = ACTIONS(12269),
    [anon_sym_POUNDendif2] = ACTIONS(12269),
    [anon_sym_POUNDENDIF2] = ACTIONS(12269),
    [anon_sym_POUNDEndif2] = ACTIONS(12269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12269),
    [sym_trigger_keyword] = ACTIONS(12269),
    [sym_var_keyword] = ACTIONS(12269),
    [sym_local_keyword] = ACTIONS(12269),
    [sym_internal_keyword] = ACTIONS(12269),
    [sym_protected_keyword] = ACTIONS(12269),
    [sym_event_keyword] = ACTIONS(12269),
    [sym_fields_keyword] = ACTIONS(12269),
    [sym_keys_keyword] = ACTIONS(12269),
    [sym_fieldgroups_keyword] = ACTIONS(12269),
    [sym_actions_keyword] = ACTIONS(12269),
    [sym_layout_keyword] = ACTIONS(12269),
    [sym_area_keyword] = ACTIONS(12269),
    [sym_group_keyword] = ACTIONS(12269),
    [sym_repeater_keyword] = ACTIONS(12269),
    [sym_cuegroup_keyword] = ACTIONS(12269),
    [sym_fixed_keyword] = ACTIONS(12269),
    [sym_grid_keyword] = ACTIONS(12269),
    [sym_part_keyword] = ACTIONS(12269),
    [sym_systempart_keyword] = ACTIONS(12269),
    [sym_usercontrol_keyword] = ACTIONS(12269),
    [sym_dataset_keyword] = ACTIONS(12269),
    [sym_elements_keyword] = ACTIONS(12269),
    [sym_dataitem_keyword] = ACTIONS(12269),
    [sym_column_keyword] = ACTIONS(12269),
    [sym_filter_keyword] = ACTIONS(12269),
    [sym_labels_keyword] = ACTIONS(12269),
    [sym_rendering_keyword] = ACTIONS(12269),
    [sym_requestpage_keyword] = ACTIONS(12269),
    [sym_schema_keyword] = ACTIONS(12269),
    [sym_views_keyword] = ACTIONS(12269),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12269),
    [sym_preproc_open] = ACTIONS(12269),
    [sym_preproc_close] = ACTIONS(12269),
  },
  [STATE(5003)] = {
    [anon_sym_SEMI] = ACTIONS(12269),
    [aux_sym_where_condition_token1] = ACTIONS(12271),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12269),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12269),
    [anon_sym_LBRACK] = ACTIONS(12269),
    [aux_sym_basic_type_token6] = ACTIONS(12271),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12269),
    [aux_sym_addafter_modification_token1] = ACTIONS(12269),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12269),
    [aux_sym_modify_modification_token1] = ACTIONS(12269),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12269),
    [aux_sym_movelast_modification_token1] = ACTIONS(12269),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12269),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12269),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12269),
    [anon_sym_POUNDif] = ACTIONS(12269),
    [anon_sym_POUNDIF] = ACTIONS(12269),
    [anon_sym_POUNDIf] = ACTIONS(12269),
    [anon_sym_POUNDelif] = ACTIONS(12269),
    [anon_sym_POUNDELIF] = ACTIONS(12269),
    [anon_sym_POUNDElif] = ACTIONS(12269),
    [anon_sym_POUNDelse] = ACTIONS(12269),
    [anon_sym_POUNDELSE] = ACTIONS(12269),
    [anon_sym_POUNDElse] = ACTIONS(12269),
    [anon_sym_POUNDelse2] = ACTIONS(12269),
    [anon_sym_POUNDELSE2] = ACTIONS(12269),
    [anon_sym_POUNDElse2] = ACTIONS(12269),
    [anon_sym_POUNDendif] = ACTIONS(12269),
    [anon_sym_POUNDENDIF] = ACTIONS(12269),
    [anon_sym_POUNDEndif] = ACTIONS(12269),
    [anon_sym_POUNDendif2] = ACTIONS(12269),
    [anon_sym_POUNDENDIF2] = ACTIONS(12269),
    [anon_sym_POUNDEndif2] = ACTIONS(12269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12269),
    [sym_trigger_keyword] = ACTIONS(12269),
    [sym_var_keyword] = ACTIONS(12269),
    [sym_local_keyword] = ACTIONS(12269),
    [sym_internal_keyword] = ACTIONS(12269),
    [sym_protected_keyword] = ACTIONS(12269),
    [sym_event_keyword] = ACTIONS(12269),
    [sym_fields_keyword] = ACTIONS(12269),
    [sym_keys_keyword] = ACTIONS(12269),
    [sym_fieldgroups_keyword] = ACTIONS(12269),
    [sym_actions_keyword] = ACTIONS(12269),
    [sym_layout_keyword] = ACTIONS(12269),
    [sym_area_keyword] = ACTIONS(12269),
    [sym_group_keyword] = ACTIONS(12269),
    [sym_repeater_keyword] = ACTIONS(12269),
    [sym_cuegroup_keyword] = ACTIONS(12269),
    [sym_fixed_keyword] = ACTIONS(12269),
    [sym_grid_keyword] = ACTIONS(12269),
    [sym_part_keyword] = ACTIONS(12269),
    [sym_systempart_keyword] = ACTIONS(12269),
    [sym_usercontrol_keyword] = ACTIONS(12269),
    [sym_dataset_keyword] = ACTIONS(12269),
    [sym_elements_keyword] = ACTIONS(12269),
    [sym_dataitem_keyword] = ACTIONS(12269),
    [sym_column_keyword] = ACTIONS(12269),
    [sym_filter_keyword] = ACTIONS(12269),
    [sym_labels_keyword] = ACTIONS(12269),
    [sym_rendering_keyword] = ACTIONS(12269),
    [sym_requestpage_keyword] = ACTIONS(12269),
    [sym_schema_keyword] = ACTIONS(12269),
    [sym_views_keyword] = ACTIONS(12269),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12269),
    [sym_preproc_open] = ACTIONS(12269),
    [sym_preproc_close] = ACTIONS(12269),
  },
  [STATE(5004)] = {
    [anon_sym_SEMI] = ACTIONS(12269),
    [aux_sym_where_condition_token1] = ACTIONS(12271),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12269),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12269),
    [anon_sym_LBRACK] = ACTIONS(12269),
    [aux_sym_basic_type_token6] = ACTIONS(12271),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12269),
    [aux_sym_addafter_modification_token1] = ACTIONS(12269),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12269),
    [aux_sym_modify_modification_token1] = ACTIONS(12269),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12269),
    [aux_sym_movelast_modification_token1] = ACTIONS(12269),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12269),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12269),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12269),
    [anon_sym_POUNDif] = ACTIONS(12269),
    [anon_sym_POUNDIF] = ACTIONS(12269),
    [anon_sym_POUNDIf] = ACTIONS(12269),
    [anon_sym_POUNDelif] = ACTIONS(12269),
    [anon_sym_POUNDELIF] = ACTIONS(12269),
    [anon_sym_POUNDElif] = ACTIONS(12269),
    [anon_sym_POUNDelse] = ACTIONS(12269),
    [anon_sym_POUNDELSE] = ACTIONS(12269),
    [anon_sym_POUNDElse] = ACTIONS(12269),
    [anon_sym_POUNDelse2] = ACTIONS(12269),
    [anon_sym_POUNDELSE2] = ACTIONS(12269),
    [anon_sym_POUNDElse2] = ACTIONS(12269),
    [anon_sym_POUNDendif] = ACTIONS(12269),
    [anon_sym_POUNDENDIF] = ACTIONS(12269),
    [anon_sym_POUNDEndif] = ACTIONS(12269),
    [anon_sym_POUNDendif2] = ACTIONS(12269),
    [anon_sym_POUNDENDIF2] = ACTIONS(12269),
    [anon_sym_POUNDEndif2] = ACTIONS(12269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12269),
    [sym_trigger_keyword] = ACTIONS(12269),
    [sym_var_keyword] = ACTIONS(12269),
    [sym_local_keyword] = ACTIONS(12269),
    [sym_internal_keyword] = ACTIONS(12269),
    [sym_protected_keyword] = ACTIONS(12269),
    [sym_event_keyword] = ACTIONS(12269),
    [sym_fields_keyword] = ACTIONS(12269),
    [sym_keys_keyword] = ACTIONS(12269),
    [sym_fieldgroups_keyword] = ACTIONS(12269),
    [sym_actions_keyword] = ACTIONS(12269),
    [sym_layout_keyword] = ACTIONS(12269),
    [sym_area_keyword] = ACTIONS(12269),
    [sym_group_keyword] = ACTIONS(12269),
    [sym_repeater_keyword] = ACTIONS(12269),
    [sym_cuegroup_keyword] = ACTIONS(12269),
    [sym_fixed_keyword] = ACTIONS(12269),
    [sym_grid_keyword] = ACTIONS(12269),
    [sym_part_keyword] = ACTIONS(12269),
    [sym_systempart_keyword] = ACTIONS(12269),
    [sym_usercontrol_keyword] = ACTIONS(12269),
    [sym_dataset_keyword] = ACTIONS(12269),
    [sym_elements_keyword] = ACTIONS(12269),
    [sym_dataitem_keyword] = ACTIONS(12269),
    [sym_column_keyword] = ACTIONS(12269),
    [sym_filter_keyword] = ACTIONS(12269),
    [sym_labels_keyword] = ACTIONS(12269),
    [sym_rendering_keyword] = ACTIONS(12269),
    [sym_requestpage_keyword] = ACTIONS(12269),
    [sym_schema_keyword] = ACTIONS(12269),
    [sym_views_keyword] = ACTIONS(12269),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12269),
    [sym_preproc_open] = ACTIONS(12269),
    [sym_preproc_close] = ACTIONS(12269),
  },
  [STATE(5005)] = {
    [anon_sym_SEMI] = ACTIONS(12269),
    [aux_sym_where_condition_token1] = ACTIONS(12271),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12269),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12269),
    [anon_sym_LBRACK] = ACTIONS(12269),
    [aux_sym_basic_type_token6] = ACTIONS(12271),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12269),
    [aux_sym_addafter_modification_token1] = ACTIONS(12269),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12269),
    [aux_sym_modify_modification_token1] = ACTIONS(12269),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12269),
    [aux_sym_movelast_modification_token1] = ACTIONS(12269),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12269),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12269),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12269),
    [anon_sym_POUNDif] = ACTIONS(12269),
    [anon_sym_POUNDIF] = ACTIONS(12269),
    [anon_sym_POUNDIf] = ACTIONS(12269),
    [anon_sym_POUNDelif] = ACTIONS(12269),
    [anon_sym_POUNDELIF] = ACTIONS(12269),
    [anon_sym_POUNDElif] = ACTIONS(12269),
    [anon_sym_POUNDelse] = ACTIONS(12269),
    [anon_sym_POUNDELSE] = ACTIONS(12269),
    [anon_sym_POUNDElse] = ACTIONS(12269),
    [anon_sym_POUNDelse2] = ACTIONS(12269),
    [anon_sym_POUNDELSE2] = ACTIONS(12269),
    [anon_sym_POUNDElse2] = ACTIONS(12269),
    [anon_sym_POUNDendif] = ACTIONS(12269),
    [anon_sym_POUNDENDIF] = ACTIONS(12269),
    [anon_sym_POUNDEndif] = ACTIONS(12269),
    [anon_sym_POUNDendif2] = ACTIONS(12269),
    [anon_sym_POUNDENDIF2] = ACTIONS(12269),
    [anon_sym_POUNDEndif2] = ACTIONS(12269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12269),
    [sym_trigger_keyword] = ACTIONS(12269),
    [sym_var_keyword] = ACTIONS(12269),
    [sym_local_keyword] = ACTIONS(12269),
    [sym_internal_keyword] = ACTIONS(12269),
    [sym_protected_keyword] = ACTIONS(12269),
    [sym_event_keyword] = ACTIONS(12269),
    [sym_fields_keyword] = ACTIONS(12269),
    [sym_keys_keyword] = ACTIONS(12269),
    [sym_fieldgroups_keyword] = ACTIONS(12269),
    [sym_actions_keyword] = ACTIONS(12269),
    [sym_layout_keyword] = ACTIONS(12269),
    [sym_area_keyword] = ACTIONS(12269),
    [sym_group_keyword] = ACTIONS(12269),
    [sym_repeater_keyword] = ACTIONS(12269),
    [sym_cuegroup_keyword] = ACTIONS(12269),
    [sym_fixed_keyword] = ACTIONS(12269),
    [sym_grid_keyword] = ACTIONS(12269),
    [sym_part_keyword] = ACTIONS(12269),
    [sym_systempart_keyword] = ACTIONS(12269),
    [sym_usercontrol_keyword] = ACTIONS(12269),
    [sym_dataset_keyword] = ACTIONS(12269),
    [sym_elements_keyword] = ACTIONS(12269),
    [sym_dataitem_keyword] = ACTIONS(12269),
    [sym_column_keyword] = ACTIONS(12269),
    [sym_filter_keyword] = ACTIONS(12269),
    [sym_labels_keyword] = ACTIONS(12269),
    [sym_rendering_keyword] = ACTIONS(12269),
    [sym_requestpage_keyword] = ACTIONS(12269),
    [sym_schema_keyword] = ACTIONS(12269),
    [sym_views_keyword] = ACTIONS(12269),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12269),
    [sym_preproc_open] = ACTIONS(12269),
    [sym_preproc_close] = ACTIONS(12269),
  },
  [STATE(5006)] = {
    [anon_sym_SEMI] = ACTIONS(12269),
    [aux_sym_where_condition_token1] = ACTIONS(12271),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12269),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12269),
    [anon_sym_LBRACK] = ACTIONS(12269),
    [aux_sym_basic_type_token6] = ACTIONS(12271),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12269),
    [aux_sym_addafter_modification_token1] = ACTIONS(12269),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12269),
    [aux_sym_modify_modification_token1] = ACTIONS(12269),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12269),
    [aux_sym_movelast_modification_token1] = ACTIONS(12269),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12269),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12269),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12269),
    [anon_sym_POUNDif] = ACTIONS(12269),
    [anon_sym_POUNDIF] = ACTIONS(12269),
    [anon_sym_POUNDIf] = ACTIONS(12269),
    [anon_sym_POUNDelif] = ACTIONS(12269),
    [anon_sym_POUNDELIF] = ACTIONS(12269),
    [anon_sym_POUNDElif] = ACTIONS(12269),
    [anon_sym_POUNDelse] = ACTIONS(12269),
    [anon_sym_POUNDELSE] = ACTIONS(12269),
    [anon_sym_POUNDElse] = ACTIONS(12269),
    [anon_sym_POUNDelse2] = ACTIONS(12269),
    [anon_sym_POUNDELSE2] = ACTIONS(12269),
    [anon_sym_POUNDElse2] = ACTIONS(12269),
    [anon_sym_POUNDendif] = ACTIONS(12269),
    [anon_sym_POUNDENDIF] = ACTIONS(12269),
    [anon_sym_POUNDEndif] = ACTIONS(12269),
    [anon_sym_POUNDendif2] = ACTIONS(12269),
    [anon_sym_POUNDENDIF2] = ACTIONS(12269),
    [anon_sym_POUNDEndif2] = ACTIONS(12269),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12269),
    [sym_trigger_keyword] = ACTIONS(12269),
    [sym_var_keyword] = ACTIONS(12269),
    [sym_local_keyword] = ACTIONS(12269),
    [sym_internal_keyword] = ACTIONS(12269),
    [sym_protected_keyword] = ACTIONS(12269),
    [sym_event_keyword] = ACTIONS(12269),
    [sym_fields_keyword] = ACTIONS(12269),
    [sym_keys_keyword] = ACTIONS(12269),
    [sym_fieldgroups_keyword] = ACTIONS(12269),
    [sym_actions_keyword] = ACTIONS(12269),
    [sym_layout_keyword] = ACTIONS(12269),
    [sym_area_keyword] = ACTIONS(12269),
    [sym_group_keyword] = ACTIONS(12269),
    [sym_repeater_keyword] = ACTIONS(12269),
    [sym_cuegroup_keyword] = ACTIONS(12269),
    [sym_fixed_keyword] = ACTIONS(12269),
    [sym_grid_keyword] = ACTIONS(12269),
    [sym_part_keyword] = ACTIONS(12269),
    [sym_systempart_keyword] = ACTIONS(12269),
    [sym_usercontrol_keyword] = ACTIONS(12269),
    [sym_dataset_keyword] = ACTIONS(12269),
    [sym_elements_keyword] = ACTIONS(12269),
    [sym_dataitem_keyword] = ACTIONS(12269),
    [sym_column_keyword] = ACTIONS(12269),
    [sym_filter_keyword] = ACTIONS(12269),
    [sym_labels_keyword] = ACTIONS(12269),
    [sym_rendering_keyword] = ACTIONS(12269),
    [sym_requestpage_keyword] = ACTIONS(12269),
    [sym_schema_keyword] = ACTIONS(12269),
    [sym_views_keyword] = ACTIONS(12269),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12269),
    [sym_preproc_open] = ACTIONS(12269),
    [sym_preproc_close] = ACTIONS(12269),
  },
  [STATE(5007)] = {
    [sym__body_element] = STATE(5008),
    [sym_empty_statement] = STATE(5008),
    [sym_property] = STATE(5008),
    [sym_permissions_property] = STATE(5008),
    [sym_table_relation_property] = STATE(5008),
    [sym_fields_section] = STATE(5008),
    [sym_keys_section] = STATE(5008),
    [sym_fieldgroups_section] = STATE(5008),
    [sym_enum_value_declaration] = STATE(5008),
    [sym_labels_section] = STATE(5008),
    [sym_layout_section] = STATE(5008),
    [sym_modify_modification] = STATE(5008),
    [sym_actions_section] = STATE(5008),
    [sym_views_section] = STATE(5008),
    [sym_dataset_section] = STATE(5008),
    [sym_report_dataitem] = STATE(5008),
    [sym__report_body_element] = STATE(5008),
    [sym_preproc_conditional_report] = STATE(5008),
    [sym_report_column] = STATE(5008),
    [sym_requestpage_section] = STATE(5008),
    [sym_rendering_section] = STATE(5008),
    [sym_elements_section] = STATE(5008),
    [sym_schema_section] = STATE(5008),
    [sym_assembly_declaration] = STATE(5008),
    [sym_event_declaration] = STATE(5008),
    [sym_procedure] = STATE(5008),
    [sym_preproc_split_procedure] = STATE(5008),
    [sym_preproc_split_procedure_preamble] = STATE(5008),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5008),
    [sym_var_section] = STATE(5008),
    [sym_attribute_item] = STATE(5008),
    [sym_preproc_conditional] = STATE(5008),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5008),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12273),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5008)] = {
    [sym__body_element] = STATE(5097),
    [sym_empty_statement] = STATE(5097),
    [sym_property] = STATE(5097),
    [sym_permissions_property] = STATE(5097),
    [sym_table_relation_property] = STATE(5097),
    [sym_fields_section] = STATE(5097),
    [sym_keys_section] = STATE(5097),
    [sym_fieldgroups_section] = STATE(5097),
    [sym_enum_value_declaration] = STATE(5097),
    [sym_labels_section] = STATE(5097),
    [sym_layout_section] = STATE(5097),
    [sym_modify_modification] = STATE(5097),
    [sym_actions_section] = STATE(5097),
    [sym_views_section] = STATE(5097),
    [sym_dataset_section] = STATE(5097),
    [sym_report_dataitem] = STATE(5097),
    [sym__report_body_element] = STATE(5097),
    [sym_preproc_conditional_report] = STATE(5097),
    [sym_report_column] = STATE(5097),
    [sym_requestpage_section] = STATE(5097),
    [sym_rendering_section] = STATE(5097),
    [sym_elements_section] = STATE(5097),
    [sym_schema_section] = STATE(5097),
    [sym_assembly_declaration] = STATE(5097),
    [sym_event_declaration] = STATE(5097),
    [sym_procedure] = STATE(5097),
    [sym_preproc_split_procedure] = STATE(5097),
    [sym_preproc_split_procedure_preamble] = STATE(5097),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5097),
    [sym_var_section] = STATE(5097),
    [sym_attribute_item] = STATE(5097),
    [sym_preproc_conditional] = STATE(5097),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5097),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12279),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5009)] = {
    [anon_sym_SEMI] = ACTIONS(12281),
    [aux_sym_where_condition_token1] = ACTIONS(12283),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12281),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12281),
    [anon_sym_LBRACK] = ACTIONS(12281),
    [aux_sym_basic_type_token6] = ACTIONS(12283),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12281),
    [aux_sym_addafter_modification_token1] = ACTIONS(12281),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12281),
    [aux_sym_modify_modification_token1] = ACTIONS(12281),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12281),
    [aux_sym_movelast_modification_token1] = ACTIONS(12281),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12281),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12281),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12281),
    [anon_sym_POUNDif] = ACTIONS(12281),
    [anon_sym_POUNDIF] = ACTIONS(12281),
    [anon_sym_POUNDIf] = ACTIONS(12281),
    [anon_sym_POUNDelif] = ACTIONS(12281),
    [anon_sym_POUNDELIF] = ACTIONS(12281),
    [anon_sym_POUNDElif] = ACTIONS(12281),
    [anon_sym_POUNDelse] = ACTIONS(12281),
    [anon_sym_POUNDELSE] = ACTIONS(12281),
    [anon_sym_POUNDElse] = ACTIONS(12281),
    [anon_sym_POUNDelse2] = ACTIONS(12281),
    [anon_sym_POUNDELSE2] = ACTIONS(12281),
    [anon_sym_POUNDElse2] = ACTIONS(12281),
    [anon_sym_POUNDendif] = ACTIONS(12281),
    [anon_sym_POUNDENDIF] = ACTIONS(12281),
    [anon_sym_POUNDEndif] = ACTIONS(12281),
    [anon_sym_POUNDendif2] = ACTIONS(12281),
    [anon_sym_POUNDENDIF2] = ACTIONS(12281),
    [anon_sym_POUNDEndif2] = ACTIONS(12281),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12281),
    [sym_trigger_keyword] = ACTIONS(12281),
    [sym_var_keyword] = ACTIONS(12281),
    [sym_local_keyword] = ACTIONS(12281),
    [sym_internal_keyword] = ACTIONS(12281),
    [sym_protected_keyword] = ACTIONS(12281),
    [sym_event_keyword] = ACTIONS(12281),
    [sym_fields_keyword] = ACTIONS(12281),
    [sym_keys_keyword] = ACTIONS(12281),
    [sym_fieldgroups_keyword] = ACTIONS(12281),
    [sym_actions_keyword] = ACTIONS(12281),
    [sym_layout_keyword] = ACTIONS(12281),
    [sym_area_keyword] = ACTIONS(12281),
    [sym_group_keyword] = ACTIONS(12281),
    [sym_repeater_keyword] = ACTIONS(12281),
    [sym_cuegroup_keyword] = ACTIONS(12281),
    [sym_fixed_keyword] = ACTIONS(12281),
    [sym_grid_keyword] = ACTIONS(12281),
    [sym_part_keyword] = ACTIONS(12281),
    [sym_systempart_keyword] = ACTIONS(12281),
    [sym_usercontrol_keyword] = ACTIONS(12281),
    [sym_dataset_keyword] = ACTIONS(12281),
    [sym_elements_keyword] = ACTIONS(12281),
    [sym_dataitem_keyword] = ACTIONS(12281),
    [sym_column_keyword] = ACTIONS(12281),
    [sym_filter_keyword] = ACTIONS(12281),
    [sym_labels_keyword] = ACTIONS(12281),
    [sym_rendering_keyword] = ACTIONS(12281),
    [sym_requestpage_keyword] = ACTIONS(12281),
    [sym_schema_keyword] = ACTIONS(12281),
    [sym_views_keyword] = ACTIONS(12281),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12281),
    [sym_preproc_open] = ACTIONS(12281),
    [sym_preproc_close] = ACTIONS(12281),
  },
  [STATE(5010)] = {
    [anon_sym_SEMI] = ACTIONS(12285),
    [aux_sym_where_condition_token1] = ACTIONS(12287),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12285),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12285),
    [anon_sym_LBRACK] = ACTIONS(12285),
    [aux_sym_basic_type_token6] = ACTIONS(12287),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12285),
    [aux_sym_addafter_modification_token1] = ACTIONS(12285),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12285),
    [aux_sym_modify_modification_token1] = ACTIONS(12285),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12285),
    [aux_sym_movelast_modification_token1] = ACTIONS(12285),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12285),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12285),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12285),
    [anon_sym_POUNDif] = ACTIONS(12285),
    [anon_sym_POUNDIF] = ACTIONS(12285),
    [anon_sym_POUNDIf] = ACTIONS(12285),
    [anon_sym_POUNDelif] = ACTIONS(12285),
    [anon_sym_POUNDELIF] = ACTIONS(12285),
    [anon_sym_POUNDElif] = ACTIONS(12285),
    [anon_sym_POUNDelse] = ACTIONS(12285),
    [anon_sym_POUNDELSE] = ACTIONS(12285),
    [anon_sym_POUNDElse] = ACTIONS(12285),
    [anon_sym_POUNDelse2] = ACTIONS(12285),
    [anon_sym_POUNDELSE2] = ACTIONS(12285),
    [anon_sym_POUNDElse2] = ACTIONS(12285),
    [anon_sym_POUNDendif] = ACTIONS(12285),
    [anon_sym_POUNDENDIF] = ACTIONS(12285),
    [anon_sym_POUNDEndif] = ACTIONS(12285),
    [anon_sym_POUNDendif2] = ACTIONS(12285),
    [anon_sym_POUNDENDIF2] = ACTIONS(12285),
    [anon_sym_POUNDEndif2] = ACTIONS(12285),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12285),
    [sym_trigger_keyword] = ACTIONS(12285),
    [sym_var_keyword] = ACTIONS(12285),
    [sym_local_keyword] = ACTIONS(12285),
    [sym_internal_keyword] = ACTIONS(12285),
    [sym_protected_keyword] = ACTIONS(12285),
    [sym_event_keyword] = ACTIONS(12285),
    [sym_fields_keyword] = ACTIONS(12285),
    [sym_keys_keyword] = ACTIONS(12285),
    [sym_fieldgroups_keyword] = ACTIONS(12285),
    [sym_actions_keyword] = ACTIONS(12285),
    [sym_layout_keyword] = ACTIONS(12285),
    [sym_area_keyword] = ACTIONS(12285),
    [sym_group_keyword] = ACTIONS(12285),
    [sym_repeater_keyword] = ACTIONS(12285),
    [sym_cuegroup_keyword] = ACTIONS(12285),
    [sym_fixed_keyword] = ACTIONS(12285),
    [sym_grid_keyword] = ACTIONS(12285),
    [sym_part_keyword] = ACTIONS(12285),
    [sym_systempart_keyword] = ACTIONS(12285),
    [sym_usercontrol_keyword] = ACTIONS(12285),
    [sym_dataset_keyword] = ACTIONS(12285),
    [sym_elements_keyword] = ACTIONS(12285),
    [sym_dataitem_keyword] = ACTIONS(12285),
    [sym_column_keyword] = ACTIONS(12285),
    [sym_filter_keyword] = ACTIONS(12285),
    [sym_labels_keyword] = ACTIONS(12285),
    [sym_rendering_keyword] = ACTIONS(12285),
    [sym_requestpage_keyword] = ACTIONS(12285),
    [sym_schema_keyword] = ACTIONS(12285),
    [sym_views_keyword] = ACTIONS(12285),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12285),
    [sym_preproc_open] = ACTIONS(12285),
    [sym_preproc_close] = ACTIONS(12285),
  },
  [STATE(5011)] = {
    [anon_sym_SEMI] = ACTIONS(12289),
    [aux_sym_where_condition_token1] = ACTIONS(12291),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12293),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12293),
    [anon_sym_LBRACK] = ACTIONS(12293),
    [aux_sym_basic_type_token6] = ACTIONS(12291),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12293),
    [aux_sym_addafter_modification_token1] = ACTIONS(12293),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12293),
    [aux_sym_modify_modification_token1] = ACTIONS(12293),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12293),
    [aux_sym_movelast_modification_token1] = ACTIONS(12293),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12293),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12293),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12293),
    [anon_sym_POUNDif] = ACTIONS(12293),
    [anon_sym_POUNDIF] = ACTIONS(12293),
    [anon_sym_POUNDIf] = ACTIONS(12293),
    [anon_sym_POUNDelif] = ACTIONS(12293),
    [anon_sym_POUNDELIF] = ACTIONS(12293),
    [anon_sym_POUNDElif] = ACTIONS(12293),
    [anon_sym_POUNDelse] = ACTIONS(12293),
    [anon_sym_POUNDELSE] = ACTIONS(12293),
    [anon_sym_POUNDElse] = ACTIONS(12293),
    [anon_sym_POUNDelse2] = ACTIONS(12293),
    [anon_sym_POUNDELSE2] = ACTIONS(12293),
    [anon_sym_POUNDElse2] = ACTIONS(12293),
    [anon_sym_POUNDendif] = ACTIONS(12293),
    [anon_sym_POUNDENDIF] = ACTIONS(12293),
    [anon_sym_POUNDEndif] = ACTIONS(12293),
    [anon_sym_POUNDendif2] = ACTIONS(12293),
    [anon_sym_POUNDENDIF2] = ACTIONS(12293),
    [anon_sym_POUNDEndif2] = ACTIONS(12293),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12293),
    [sym_trigger_keyword] = ACTIONS(12293),
    [sym_var_keyword] = ACTIONS(12293),
    [sym_local_keyword] = ACTIONS(12293),
    [sym_internal_keyword] = ACTIONS(12293),
    [sym_protected_keyword] = ACTIONS(12293),
    [sym_event_keyword] = ACTIONS(12293),
    [sym_fields_keyword] = ACTIONS(12293),
    [sym_keys_keyword] = ACTIONS(12293),
    [sym_fieldgroups_keyword] = ACTIONS(12293),
    [sym_actions_keyword] = ACTIONS(12293),
    [sym_layout_keyword] = ACTIONS(12293),
    [sym_area_keyword] = ACTIONS(12293),
    [sym_group_keyword] = ACTIONS(12293),
    [sym_repeater_keyword] = ACTIONS(12293),
    [sym_cuegroup_keyword] = ACTIONS(12293),
    [sym_fixed_keyword] = ACTIONS(12293),
    [sym_grid_keyword] = ACTIONS(12293),
    [sym_part_keyword] = ACTIONS(12293),
    [sym_systempart_keyword] = ACTIONS(12293),
    [sym_usercontrol_keyword] = ACTIONS(12293),
    [sym_dataset_keyword] = ACTIONS(12293),
    [sym_elements_keyword] = ACTIONS(12293),
    [sym_dataitem_keyword] = ACTIONS(12293),
    [sym_column_keyword] = ACTIONS(12293),
    [sym_filter_keyword] = ACTIONS(12293),
    [sym_labels_keyword] = ACTIONS(12293),
    [sym_rendering_keyword] = ACTIONS(12293),
    [sym_requestpage_keyword] = ACTIONS(12293),
    [sym_schema_keyword] = ACTIONS(12293),
    [sym_views_keyword] = ACTIONS(12293),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12293),
    [sym_preproc_open] = ACTIONS(12293),
    [sym_preproc_close] = ACTIONS(12293),
  },
  [STATE(5012)] = {
    [anon_sym_SEMI] = ACTIONS(12295),
    [aux_sym_where_condition_token1] = ACTIONS(12291),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12293),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12293),
    [anon_sym_LBRACK] = ACTIONS(12293),
    [aux_sym_basic_type_token6] = ACTIONS(12291),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12293),
    [aux_sym_addafter_modification_token1] = ACTIONS(12293),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12293),
    [aux_sym_modify_modification_token1] = ACTIONS(12293),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12293),
    [aux_sym_movelast_modification_token1] = ACTIONS(12293),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12293),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12293),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12293),
    [anon_sym_POUNDif] = ACTIONS(12293),
    [anon_sym_POUNDIF] = ACTIONS(12293),
    [anon_sym_POUNDIf] = ACTIONS(12293),
    [anon_sym_POUNDelif] = ACTIONS(12293),
    [anon_sym_POUNDELIF] = ACTIONS(12293),
    [anon_sym_POUNDElif] = ACTIONS(12293),
    [anon_sym_POUNDelse] = ACTIONS(12293),
    [anon_sym_POUNDELSE] = ACTIONS(12293),
    [anon_sym_POUNDElse] = ACTIONS(12293),
    [anon_sym_POUNDelse2] = ACTIONS(12293),
    [anon_sym_POUNDELSE2] = ACTIONS(12293),
    [anon_sym_POUNDElse2] = ACTIONS(12293),
    [anon_sym_POUNDendif] = ACTIONS(12293),
    [anon_sym_POUNDENDIF] = ACTIONS(12293),
    [anon_sym_POUNDEndif] = ACTIONS(12293),
    [anon_sym_POUNDendif2] = ACTIONS(12293),
    [anon_sym_POUNDENDIF2] = ACTIONS(12293),
    [anon_sym_POUNDEndif2] = ACTIONS(12293),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12293),
    [sym_trigger_keyword] = ACTIONS(12293),
    [sym_var_keyword] = ACTIONS(12293),
    [sym_local_keyword] = ACTIONS(12293),
    [sym_internal_keyword] = ACTIONS(12293),
    [sym_protected_keyword] = ACTIONS(12293),
    [sym_event_keyword] = ACTIONS(12293),
    [sym_fields_keyword] = ACTIONS(12293),
    [sym_keys_keyword] = ACTIONS(12293),
    [sym_fieldgroups_keyword] = ACTIONS(12293),
    [sym_actions_keyword] = ACTIONS(12293),
    [sym_layout_keyword] = ACTIONS(12293),
    [sym_area_keyword] = ACTIONS(12293),
    [sym_group_keyword] = ACTIONS(12293),
    [sym_repeater_keyword] = ACTIONS(12293),
    [sym_cuegroup_keyword] = ACTIONS(12293),
    [sym_fixed_keyword] = ACTIONS(12293),
    [sym_grid_keyword] = ACTIONS(12293),
    [sym_part_keyword] = ACTIONS(12293),
    [sym_systempart_keyword] = ACTIONS(12293),
    [sym_usercontrol_keyword] = ACTIONS(12293),
    [sym_dataset_keyword] = ACTIONS(12293),
    [sym_elements_keyword] = ACTIONS(12293),
    [sym_dataitem_keyword] = ACTIONS(12293),
    [sym_column_keyword] = ACTIONS(12293),
    [sym_filter_keyword] = ACTIONS(12293),
    [sym_labels_keyword] = ACTIONS(12293),
    [sym_rendering_keyword] = ACTIONS(12293),
    [sym_requestpage_keyword] = ACTIONS(12293),
    [sym_schema_keyword] = ACTIONS(12293),
    [sym_views_keyword] = ACTIONS(12293),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12293),
    [sym_preproc_open] = ACTIONS(12293),
    [sym_preproc_close] = ACTIONS(12293),
  },
  [STATE(5013)] = {
    [anon_sym_SEMI] = ACTIONS(12297),
    [aux_sym_where_condition_token1] = ACTIONS(12287),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12285),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12285),
    [anon_sym_LBRACK] = ACTIONS(12285),
    [aux_sym_basic_type_token6] = ACTIONS(12287),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12285),
    [aux_sym_addafter_modification_token1] = ACTIONS(12285),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12285),
    [aux_sym_modify_modification_token1] = ACTIONS(12285),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12285),
    [aux_sym_movelast_modification_token1] = ACTIONS(12285),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12285),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12285),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12285),
    [anon_sym_POUNDif] = ACTIONS(12285),
    [anon_sym_POUNDIF] = ACTIONS(12285),
    [anon_sym_POUNDIf] = ACTIONS(12285),
    [anon_sym_POUNDelif] = ACTIONS(12285),
    [anon_sym_POUNDELIF] = ACTIONS(12285),
    [anon_sym_POUNDElif] = ACTIONS(12285),
    [anon_sym_POUNDelse] = ACTIONS(12285),
    [anon_sym_POUNDELSE] = ACTIONS(12285),
    [anon_sym_POUNDElse] = ACTIONS(12285),
    [anon_sym_POUNDelse2] = ACTIONS(12285),
    [anon_sym_POUNDELSE2] = ACTIONS(12285),
    [anon_sym_POUNDElse2] = ACTIONS(12285),
    [anon_sym_POUNDendif] = ACTIONS(12285),
    [anon_sym_POUNDENDIF] = ACTIONS(12285),
    [anon_sym_POUNDEndif] = ACTIONS(12285),
    [anon_sym_POUNDendif2] = ACTIONS(12285),
    [anon_sym_POUNDENDIF2] = ACTIONS(12285),
    [anon_sym_POUNDEndif2] = ACTIONS(12285),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12285),
    [sym_trigger_keyword] = ACTIONS(12285),
    [sym_var_keyword] = ACTIONS(12285),
    [sym_local_keyword] = ACTIONS(12285),
    [sym_internal_keyword] = ACTIONS(12285),
    [sym_protected_keyword] = ACTIONS(12285),
    [sym_event_keyword] = ACTIONS(12285),
    [sym_fields_keyword] = ACTIONS(12285),
    [sym_keys_keyword] = ACTIONS(12285),
    [sym_fieldgroups_keyword] = ACTIONS(12285),
    [sym_actions_keyword] = ACTIONS(12285),
    [sym_layout_keyword] = ACTIONS(12285),
    [sym_area_keyword] = ACTIONS(12285),
    [sym_group_keyword] = ACTIONS(12285),
    [sym_repeater_keyword] = ACTIONS(12285),
    [sym_cuegroup_keyword] = ACTIONS(12285),
    [sym_fixed_keyword] = ACTIONS(12285),
    [sym_grid_keyword] = ACTIONS(12285),
    [sym_part_keyword] = ACTIONS(12285),
    [sym_systempart_keyword] = ACTIONS(12285),
    [sym_usercontrol_keyword] = ACTIONS(12285),
    [sym_dataset_keyword] = ACTIONS(12285),
    [sym_elements_keyword] = ACTIONS(12285),
    [sym_dataitem_keyword] = ACTIONS(12285),
    [sym_column_keyword] = ACTIONS(12285),
    [sym_filter_keyword] = ACTIONS(12285),
    [sym_labels_keyword] = ACTIONS(12285),
    [sym_rendering_keyword] = ACTIONS(12285),
    [sym_requestpage_keyword] = ACTIONS(12285),
    [sym_schema_keyword] = ACTIONS(12285),
    [sym_views_keyword] = ACTIONS(12285),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12285),
    [sym_preproc_open] = ACTIONS(12285),
    [sym_preproc_close] = ACTIONS(12285),
  },
  [STATE(5014)] = {
    [anon_sym_SEMI] = ACTIONS(12299),
    [aux_sym_where_condition_token1] = ACTIONS(12301),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12303),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12303),
    [anon_sym_LBRACK] = ACTIONS(12303),
    [aux_sym_basic_type_token6] = ACTIONS(12301),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12303),
    [aux_sym_addafter_modification_token1] = ACTIONS(12303),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12303),
    [aux_sym_modify_modification_token1] = ACTIONS(12303),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12303),
    [aux_sym_movelast_modification_token1] = ACTIONS(12303),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12303),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12303),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12303),
    [anon_sym_POUNDif] = ACTIONS(12303),
    [anon_sym_POUNDIF] = ACTIONS(12303),
    [anon_sym_POUNDIf] = ACTIONS(12303),
    [anon_sym_POUNDelif] = ACTIONS(12303),
    [anon_sym_POUNDELIF] = ACTIONS(12303),
    [anon_sym_POUNDElif] = ACTIONS(12303),
    [anon_sym_POUNDelse] = ACTIONS(12303),
    [anon_sym_POUNDELSE] = ACTIONS(12303),
    [anon_sym_POUNDElse] = ACTIONS(12303),
    [anon_sym_POUNDelse2] = ACTIONS(12303),
    [anon_sym_POUNDELSE2] = ACTIONS(12303),
    [anon_sym_POUNDElse2] = ACTIONS(12303),
    [anon_sym_POUNDendif] = ACTIONS(12303),
    [anon_sym_POUNDENDIF] = ACTIONS(12303),
    [anon_sym_POUNDEndif] = ACTIONS(12303),
    [anon_sym_POUNDendif2] = ACTIONS(12303),
    [anon_sym_POUNDENDIF2] = ACTIONS(12303),
    [anon_sym_POUNDEndif2] = ACTIONS(12303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12303),
    [sym_trigger_keyword] = ACTIONS(12303),
    [sym_var_keyword] = ACTIONS(12303),
    [sym_local_keyword] = ACTIONS(12303),
    [sym_internal_keyword] = ACTIONS(12303),
    [sym_protected_keyword] = ACTIONS(12303),
    [sym_event_keyword] = ACTIONS(12303),
    [sym_fields_keyword] = ACTIONS(12303),
    [sym_keys_keyword] = ACTIONS(12303),
    [sym_fieldgroups_keyword] = ACTIONS(12303),
    [sym_actions_keyword] = ACTIONS(12303),
    [sym_layout_keyword] = ACTIONS(12303),
    [sym_area_keyword] = ACTIONS(12303),
    [sym_group_keyword] = ACTIONS(12303),
    [sym_repeater_keyword] = ACTIONS(12303),
    [sym_cuegroup_keyword] = ACTIONS(12303),
    [sym_fixed_keyword] = ACTIONS(12303),
    [sym_grid_keyword] = ACTIONS(12303),
    [sym_part_keyword] = ACTIONS(12303),
    [sym_systempart_keyword] = ACTIONS(12303),
    [sym_usercontrol_keyword] = ACTIONS(12303),
    [sym_dataset_keyword] = ACTIONS(12303),
    [sym_elements_keyword] = ACTIONS(12303),
    [sym_dataitem_keyword] = ACTIONS(12303),
    [sym_column_keyword] = ACTIONS(12303),
    [sym_filter_keyword] = ACTIONS(12303),
    [sym_labels_keyword] = ACTIONS(12303),
    [sym_rendering_keyword] = ACTIONS(12303),
    [sym_requestpage_keyword] = ACTIONS(12303),
    [sym_schema_keyword] = ACTIONS(12303),
    [sym_views_keyword] = ACTIONS(12303),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12303),
    [sym_preproc_open] = ACTIONS(12303),
    [sym_preproc_close] = ACTIONS(12303),
  },
  [STATE(5015)] = {
    [anon_sym_SEMI] = ACTIONS(12305),
    [aux_sym_where_condition_token1] = ACTIONS(12301),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12303),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12303),
    [anon_sym_LBRACK] = ACTIONS(12303),
    [aux_sym_basic_type_token6] = ACTIONS(12301),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12303),
    [aux_sym_addafter_modification_token1] = ACTIONS(12303),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12303),
    [aux_sym_modify_modification_token1] = ACTIONS(12303),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12303),
    [aux_sym_movelast_modification_token1] = ACTIONS(12303),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12303),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12303),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12303),
    [anon_sym_POUNDif] = ACTIONS(12303),
    [anon_sym_POUNDIF] = ACTIONS(12303),
    [anon_sym_POUNDIf] = ACTIONS(12303),
    [anon_sym_POUNDelif] = ACTIONS(12303),
    [anon_sym_POUNDELIF] = ACTIONS(12303),
    [anon_sym_POUNDElif] = ACTIONS(12303),
    [anon_sym_POUNDelse] = ACTIONS(12303),
    [anon_sym_POUNDELSE] = ACTIONS(12303),
    [anon_sym_POUNDElse] = ACTIONS(12303),
    [anon_sym_POUNDelse2] = ACTIONS(12303),
    [anon_sym_POUNDELSE2] = ACTIONS(12303),
    [anon_sym_POUNDElse2] = ACTIONS(12303),
    [anon_sym_POUNDendif] = ACTIONS(12303),
    [anon_sym_POUNDENDIF] = ACTIONS(12303),
    [anon_sym_POUNDEndif] = ACTIONS(12303),
    [anon_sym_POUNDendif2] = ACTIONS(12303),
    [anon_sym_POUNDENDIF2] = ACTIONS(12303),
    [anon_sym_POUNDEndif2] = ACTIONS(12303),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12303),
    [sym_trigger_keyword] = ACTIONS(12303),
    [sym_var_keyword] = ACTIONS(12303),
    [sym_local_keyword] = ACTIONS(12303),
    [sym_internal_keyword] = ACTIONS(12303),
    [sym_protected_keyword] = ACTIONS(12303),
    [sym_event_keyword] = ACTIONS(12303),
    [sym_fields_keyword] = ACTIONS(12303),
    [sym_keys_keyword] = ACTIONS(12303),
    [sym_fieldgroups_keyword] = ACTIONS(12303),
    [sym_actions_keyword] = ACTIONS(12303),
    [sym_layout_keyword] = ACTIONS(12303),
    [sym_area_keyword] = ACTIONS(12303),
    [sym_group_keyword] = ACTIONS(12303),
    [sym_repeater_keyword] = ACTIONS(12303),
    [sym_cuegroup_keyword] = ACTIONS(12303),
    [sym_fixed_keyword] = ACTIONS(12303),
    [sym_grid_keyword] = ACTIONS(12303),
    [sym_part_keyword] = ACTIONS(12303),
    [sym_systempart_keyword] = ACTIONS(12303),
    [sym_usercontrol_keyword] = ACTIONS(12303),
    [sym_dataset_keyword] = ACTIONS(12303),
    [sym_elements_keyword] = ACTIONS(12303),
    [sym_dataitem_keyword] = ACTIONS(12303),
    [sym_column_keyword] = ACTIONS(12303),
    [sym_filter_keyword] = ACTIONS(12303),
    [sym_labels_keyword] = ACTIONS(12303),
    [sym_rendering_keyword] = ACTIONS(12303),
    [sym_requestpage_keyword] = ACTIONS(12303),
    [sym_schema_keyword] = ACTIONS(12303),
    [sym_views_keyword] = ACTIONS(12303),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12303),
    [sym_preproc_open] = ACTIONS(12303),
    [sym_preproc_close] = ACTIONS(12303),
  },
  [STATE(5016)] = {
    [anon_sym_SEMI] = ACTIONS(12307),
    [aux_sym_where_condition_token1] = ACTIONS(12309),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12311),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12311),
    [anon_sym_LBRACK] = ACTIONS(12311),
    [aux_sym_basic_type_token6] = ACTIONS(12309),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12311),
    [aux_sym_addafter_modification_token1] = ACTIONS(12311),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12311),
    [aux_sym_modify_modification_token1] = ACTIONS(12311),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12311),
    [aux_sym_movelast_modification_token1] = ACTIONS(12311),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12311),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12311),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12311),
    [anon_sym_POUNDif] = ACTIONS(12311),
    [anon_sym_POUNDIF] = ACTIONS(12311),
    [anon_sym_POUNDIf] = ACTIONS(12311),
    [anon_sym_POUNDelif] = ACTIONS(12311),
    [anon_sym_POUNDELIF] = ACTIONS(12311),
    [anon_sym_POUNDElif] = ACTIONS(12311),
    [anon_sym_POUNDelse] = ACTIONS(12311),
    [anon_sym_POUNDELSE] = ACTIONS(12311),
    [anon_sym_POUNDElse] = ACTIONS(12311),
    [anon_sym_POUNDelse2] = ACTIONS(12311),
    [anon_sym_POUNDELSE2] = ACTIONS(12311),
    [anon_sym_POUNDElse2] = ACTIONS(12311),
    [anon_sym_POUNDendif] = ACTIONS(12311),
    [anon_sym_POUNDENDIF] = ACTIONS(12311),
    [anon_sym_POUNDEndif] = ACTIONS(12311),
    [anon_sym_POUNDendif2] = ACTIONS(12311),
    [anon_sym_POUNDENDIF2] = ACTIONS(12311),
    [anon_sym_POUNDEndif2] = ACTIONS(12311),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12311),
    [sym_trigger_keyword] = ACTIONS(12311),
    [sym_var_keyword] = ACTIONS(12311),
    [sym_local_keyword] = ACTIONS(12311),
    [sym_internal_keyword] = ACTIONS(12311),
    [sym_protected_keyword] = ACTIONS(12311),
    [sym_event_keyword] = ACTIONS(12311),
    [sym_fields_keyword] = ACTIONS(12311),
    [sym_keys_keyword] = ACTIONS(12311),
    [sym_fieldgroups_keyword] = ACTIONS(12311),
    [sym_actions_keyword] = ACTIONS(12311),
    [sym_layout_keyword] = ACTIONS(12311),
    [sym_area_keyword] = ACTIONS(12311),
    [sym_group_keyword] = ACTIONS(12311),
    [sym_repeater_keyword] = ACTIONS(12311),
    [sym_cuegroup_keyword] = ACTIONS(12311),
    [sym_fixed_keyword] = ACTIONS(12311),
    [sym_grid_keyword] = ACTIONS(12311),
    [sym_part_keyword] = ACTIONS(12311),
    [sym_systempart_keyword] = ACTIONS(12311),
    [sym_usercontrol_keyword] = ACTIONS(12311),
    [sym_dataset_keyword] = ACTIONS(12311),
    [sym_elements_keyword] = ACTIONS(12311),
    [sym_dataitem_keyword] = ACTIONS(12311),
    [sym_column_keyword] = ACTIONS(12311),
    [sym_filter_keyword] = ACTIONS(12311),
    [sym_labels_keyword] = ACTIONS(12311),
    [sym_rendering_keyword] = ACTIONS(12311),
    [sym_requestpage_keyword] = ACTIONS(12311),
    [sym_schema_keyword] = ACTIONS(12311),
    [sym_views_keyword] = ACTIONS(12311),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12311),
    [sym_preproc_open] = ACTIONS(12311),
    [sym_preproc_close] = ACTIONS(12311),
  },
  [STATE(5017)] = {
    [anon_sym_SEMI] = ACTIONS(12313),
    [aux_sym_where_condition_token1] = ACTIONS(12309),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12311),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12311),
    [anon_sym_LBRACK] = ACTIONS(12311),
    [aux_sym_basic_type_token6] = ACTIONS(12309),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12311),
    [aux_sym_addafter_modification_token1] = ACTIONS(12311),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12311),
    [aux_sym_modify_modification_token1] = ACTIONS(12311),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12311),
    [aux_sym_movelast_modification_token1] = ACTIONS(12311),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12311),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12311),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12311),
    [anon_sym_POUNDif] = ACTIONS(12311),
    [anon_sym_POUNDIF] = ACTIONS(12311),
    [anon_sym_POUNDIf] = ACTIONS(12311),
    [anon_sym_POUNDelif] = ACTIONS(12311),
    [anon_sym_POUNDELIF] = ACTIONS(12311),
    [anon_sym_POUNDElif] = ACTIONS(12311),
    [anon_sym_POUNDelse] = ACTIONS(12311),
    [anon_sym_POUNDELSE] = ACTIONS(12311),
    [anon_sym_POUNDElse] = ACTIONS(12311),
    [anon_sym_POUNDelse2] = ACTIONS(12311),
    [anon_sym_POUNDELSE2] = ACTIONS(12311),
    [anon_sym_POUNDElse2] = ACTIONS(12311),
    [anon_sym_POUNDendif] = ACTIONS(12311),
    [anon_sym_POUNDENDIF] = ACTIONS(12311),
    [anon_sym_POUNDEndif] = ACTIONS(12311),
    [anon_sym_POUNDendif2] = ACTIONS(12311),
    [anon_sym_POUNDENDIF2] = ACTIONS(12311),
    [anon_sym_POUNDEndif2] = ACTIONS(12311),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12311),
    [sym_trigger_keyword] = ACTIONS(12311),
    [sym_var_keyword] = ACTIONS(12311),
    [sym_local_keyword] = ACTIONS(12311),
    [sym_internal_keyword] = ACTIONS(12311),
    [sym_protected_keyword] = ACTIONS(12311),
    [sym_event_keyword] = ACTIONS(12311),
    [sym_fields_keyword] = ACTIONS(12311),
    [sym_keys_keyword] = ACTIONS(12311),
    [sym_fieldgroups_keyword] = ACTIONS(12311),
    [sym_actions_keyword] = ACTIONS(12311),
    [sym_layout_keyword] = ACTIONS(12311),
    [sym_area_keyword] = ACTIONS(12311),
    [sym_group_keyword] = ACTIONS(12311),
    [sym_repeater_keyword] = ACTIONS(12311),
    [sym_cuegroup_keyword] = ACTIONS(12311),
    [sym_fixed_keyword] = ACTIONS(12311),
    [sym_grid_keyword] = ACTIONS(12311),
    [sym_part_keyword] = ACTIONS(12311),
    [sym_systempart_keyword] = ACTIONS(12311),
    [sym_usercontrol_keyword] = ACTIONS(12311),
    [sym_dataset_keyword] = ACTIONS(12311),
    [sym_elements_keyword] = ACTIONS(12311),
    [sym_dataitem_keyword] = ACTIONS(12311),
    [sym_column_keyword] = ACTIONS(12311),
    [sym_filter_keyword] = ACTIONS(12311),
    [sym_labels_keyword] = ACTIONS(12311),
    [sym_rendering_keyword] = ACTIONS(12311),
    [sym_requestpage_keyword] = ACTIONS(12311),
    [sym_schema_keyword] = ACTIONS(12311),
    [sym_views_keyword] = ACTIONS(12311),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12311),
    [sym_preproc_open] = ACTIONS(12311),
    [sym_preproc_close] = ACTIONS(12311),
  },
  [STATE(5018)] = {
    [anon_sym_SEMI] = ACTIONS(12315),
    [aux_sym_where_condition_token1] = ACTIONS(12317),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12315),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12315),
    [anon_sym_LBRACK] = ACTIONS(12315),
    [aux_sym_basic_type_token6] = ACTIONS(12317),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12315),
    [aux_sym_addafter_modification_token1] = ACTIONS(12315),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12315),
    [aux_sym_modify_modification_token1] = ACTIONS(12315),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12315),
    [aux_sym_movelast_modification_token1] = ACTIONS(12315),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12315),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12315),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12315),
    [anon_sym_POUNDif] = ACTIONS(12315),
    [anon_sym_POUNDIF] = ACTIONS(12315),
    [anon_sym_POUNDIf] = ACTIONS(12315),
    [anon_sym_POUNDelif] = ACTIONS(12315),
    [anon_sym_POUNDELIF] = ACTIONS(12315),
    [anon_sym_POUNDElif] = ACTIONS(12315),
    [anon_sym_POUNDelse] = ACTIONS(12315),
    [anon_sym_POUNDELSE] = ACTIONS(12315),
    [anon_sym_POUNDElse] = ACTIONS(12315),
    [anon_sym_POUNDelse2] = ACTIONS(12315),
    [anon_sym_POUNDELSE2] = ACTIONS(12315),
    [anon_sym_POUNDElse2] = ACTIONS(12315),
    [anon_sym_POUNDendif] = ACTIONS(12315),
    [anon_sym_POUNDENDIF] = ACTIONS(12315),
    [anon_sym_POUNDEndif] = ACTIONS(12315),
    [anon_sym_POUNDendif2] = ACTIONS(12315),
    [anon_sym_POUNDENDIF2] = ACTIONS(12315),
    [anon_sym_POUNDEndif2] = ACTIONS(12315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12315),
    [sym_trigger_keyword] = ACTIONS(12315),
    [sym_var_keyword] = ACTIONS(12315),
    [sym_local_keyword] = ACTIONS(12315),
    [sym_internal_keyword] = ACTIONS(12315),
    [sym_protected_keyword] = ACTIONS(12315),
    [sym_event_keyword] = ACTIONS(12315),
    [sym_fields_keyword] = ACTIONS(12315),
    [sym_keys_keyword] = ACTIONS(12315),
    [sym_fieldgroups_keyword] = ACTIONS(12315),
    [sym_actions_keyword] = ACTIONS(12315),
    [sym_layout_keyword] = ACTIONS(12315),
    [sym_area_keyword] = ACTIONS(12315),
    [sym_group_keyword] = ACTIONS(12315),
    [sym_repeater_keyword] = ACTIONS(12315),
    [sym_cuegroup_keyword] = ACTIONS(12315),
    [sym_fixed_keyword] = ACTIONS(12315),
    [sym_grid_keyword] = ACTIONS(12315),
    [sym_part_keyword] = ACTIONS(12315),
    [sym_systempart_keyword] = ACTIONS(12315),
    [sym_usercontrol_keyword] = ACTIONS(12315),
    [sym_dataset_keyword] = ACTIONS(12315),
    [sym_elements_keyword] = ACTIONS(12315),
    [sym_dataitem_keyword] = ACTIONS(12315),
    [sym_column_keyword] = ACTIONS(12315),
    [sym_filter_keyword] = ACTIONS(12315),
    [sym_labels_keyword] = ACTIONS(12315),
    [sym_rendering_keyword] = ACTIONS(12315),
    [sym_requestpage_keyword] = ACTIONS(12315),
    [sym_schema_keyword] = ACTIONS(12315),
    [sym_views_keyword] = ACTIONS(12315),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12315),
    [sym_preproc_open] = ACTIONS(12315),
    [sym_preproc_close] = ACTIONS(12315),
  },
  [STATE(5019)] = {
    [anon_sym_SEMI] = ACTIONS(12315),
    [aux_sym_where_condition_token1] = ACTIONS(12317),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12315),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12315),
    [anon_sym_LBRACK] = ACTIONS(12315),
    [aux_sym_basic_type_token6] = ACTIONS(12317),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12315),
    [aux_sym_addafter_modification_token1] = ACTIONS(12315),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12315),
    [aux_sym_modify_modification_token1] = ACTIONS(12315),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12315),
    [aux_sym_movelast_modification_token1] = ACTIONS(12315),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12315),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12315),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12315),
    [anon_sym_POUNDif] = ACTIONS(12315),
    [anon_sym_POUNDIF] = ACTIONS(12315),
    [anon_sym_POUNDIf] = ACTIONS(12315),
    [anon_sym_POUNDelif] = ACTIONS(12315),
    [anon_sym_POUNDELIF] = ACTIONS(12315),
    [anon_sym_POUNDElif] = ACTIONS(12315),
    [anon_sym_POUNDelse] = ACTIONS(12315),
    [anon_sym_POUNDELSE] = ACTIONS(12315),
    [anon_sym_POUNDElse] = ACTIONS(12315),
    [anon_sym_POUNDelse2] = ACTIONS(12315),
    [anon_sym_POUNDELSE2] = ACTIONS(12315),
    [anon_sym_POUNDElse2] = ACTIONS(12315),
    [anon_sym_POUNDendif] = ACTIONS(12315),
    [anon_sym_POUNDENDIF] = ACTIONS(12315),
    [anon_sym_POUNDEndif] = ACTIONS(12315),
    [anon_sym_POUNDendif2] = ACTIONS(12315),
    [anon_sym_POUNDENDIF2] = ACTIONS(12315),
    [anon_sym_POUNDEndif2] = ACTIONS(12315),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12315),
    [sym_trigger_keyword] = ACTIONS(12315),
    [sym_var_keyword] = ACTIONS(12315),
    [sym_local_keyword] = ACTIONS(12315),
    [sym_internal_keyword] = ACTIONS(12315),
    [sym_protected_keyword] = ACTIONS(12315),
    [sym_event_keyword] = ACTIONS(12315),
    [sym_fields_keyword] = ACTIONS(12315),
    [sym_keys_keyword] = ACTIONS(12315),
    [sym_fieldgroups_keyword] = ACTIONS(12315),
    [sym_actions_keyword] = ACTIONS(12315),
    [sym_layout_keyword] = ACTIONS(12315),
    [sym_area_keyword] = ACTIONS(12315),
    [sym_group_keyword] = ACTIONS(12315),
    [sym_repeater_keyword] = ACTIONS(12315),
    [sym_cuegroup_keyword] = ACTIONS(12315),
    [sym_fixed_keyword] = ACTIONS(12315),
    [sym_grid_keyword] = ACTIONS(12315),
    [sym_part_keyword] = ACTIONS(12315),
    [sym_systempart_keyword] = ACTIONS(12315),
    [sym_usercontrol_keyword] = ACTIONS(12315),
    [sym_dataset_keyword] = ACTIONS(12315),
    [sym_elements_keyword] = ACTIONS(12315),
    [sym_dataitem_keyword] = ACTIONS(12315),
    [sym_column_keyword] = ACTIONS(12315),
    [sym_filter_keyword] = ACTIONS(12315),
    [sym_labels_keyword] = ACTIONS(12315),
    [sym_rendering_keyword] = ACTIONS(12315),
    [sym_requestpage_keyword] = ACTIONS(12315),
    [sym_schema_keyword] = ACTIONS(12315),
    [sym_views_keyword] = ACTIONS(12315),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12315),
    [sym_preproc_open] = ACTIONS(12315),
    [sym_preproc_close] = ACTIONS(12315),
  },
  [STATE(5020)] = {
    [anon_sym_SEMI] = ACTIONS(12319),
    [aux_sym_where_condition_token1] = ACTIONS(12321),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12319),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12319),
    [anon_sym_LBRACK] = ACTIONS(12319),
    [aux_sym_basic_type_token6] = ACTIONS(12321),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12319),
    [aux_sym_addafter_modification_token1] = ACTIONS(12319),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12319),
    [aux_sym_modify_modification_token1] = ACTIONS(12319),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12319),
    [aux_sym_movelast_modification_token1] = ACTIONS(12319),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12319),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12319),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12319),
    [anon_sym_POUNDif] = ACTIONS(12319),
    [anon_sym_POUNDIF] = ACTIONS(12319),
    [anon_sym_POUNDIf] = ACTIONS(12319),
    [anon_sym_POUNDelif] = ACTIONS(12319),
    [anon_sym_POUNDELIF] = ACTIONS(12319),
    [anon_sym_POUNDElif] = ACTIONS(12319),
    [anon_sym_POUNDelse] = ACTIONS(12319),
    [anon_sym_POUNDELSE] = ACTIONS(12319),
    [anon_sym_POUNDElse] = ACTIONS(12319),
    [anon_sym_POUNDelse2] = ACTIONS(12319),
    [anon_sym_POUNDELSE2] = ACTIONS(12319),
    [anon_sym_POUNDElse2] = ACTIONS(12319),
    [anon_sym_POUNDendif] = ACTIONS(12319),
    [anon_sym_POUNDENDIF] = ACTIONS(12319),
    [anon_sym_POUNDEndif] = ACTIONS(12319),
    [anon_sym_POUNDendif2] = ACTIONS(12319),
    [anon_sym_POUNDENDIF2] = ACTIONS(12319),
    [anon_sym_POUNDEndif2] = ACTIONS(12319),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12319),
    [sym_trigger_keyword] = ACTIONS(12319),
    [sym_var_keyword] = ACTIONS(12319),
    [sym_local_keyword] = ACTIONS(12319),
    [sym_internal_keyword] = ACTIONS(12319),
    [sym_protected_keyword] = ACTIONS(12319),
    [sym_event_keyword] = ACTIONS(12319),
    [sym_fields_keyword] = ACTIONS(12319),
    [sym_keys_keyword] = ACTIONS(12319),
    [sym_fieldgroups_keyword] = ACTIONS(12319),
    [sym_actions_keyword] = ACTIONS(12319),
    [sym_layout_keyword] = ACTIONS(12319),
    [sym_area_keyword] = ACTIONS(12319),
    [sym_group_keyword] = ACTIONS(12319),
    [sym_repeater_keyword] = ACTIONS(12319),
    [sym_cuegroup_keyword] = ACTIONS(12319),
    [sym_fixed_keyword] = ACTIONS(12319),
    [sym_grid_keyword] = ACTIONS(12319),
    [sym_part_keyword] = ACTIONS(12319),
    [sym_systempart_keyword] = ACTIONS(12319),
    [sym_usercontrol_keyword] = ACTIONS(12319),
    [sym_dataset_keyword] = ACTIONS(12319),
    [sym_elements_keyword] = ACTIONS(12319),
    [sym_dataitem_keyword] = ACTIONS(12319),
    [sym_column_keyword] = ACTIONS(12319),
    [sym_filter_keyword] = ACTIONS(12319),
    [sym_labels_keyword] = ACTIONS(12319),
    [sym_rendering_keyword] = ACTIONS(12319),
    [sym_requestpage_keyword] = ACTIONS(12319),
    [sym_schema_keyword] = ACTIONS(12319),
    [sym_views_keyword] = ACTIONS(12319),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12319),
    [sym_preproc_open] = ACTIONS(12319),
    [sym_preproc_close] = ACTIONS(12319),
  },
  [STATE(5021)] = {
    [anon_sym_SEMI] = ACTIONS(12319),
    [aux_sym_where_condition_token1] = ACTIONS(12321),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12319),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12319),
    [anon_sym_LBRACK] = ACTIONS(12319),
    [aux_sym_basic_type_token6] = ACTIONS(12321),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12319),
    [aux_sym_addafter_modification_token1] = ACTIONS(12319),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12319),
    [aux_sym_modify_modification_token1] = ACTIONS(12319),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12319),
    [aux_sym_movelast_modification_token1] = ACTIONS(12319),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12319),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12319),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12319),
    [anon_sym_POUNDif] = ACTIONS(12319),
    [anon_sym_POUNDIF] = ACTIONS(12319),
    [anon_sym_POUNDIf] = ACTIONS(12319),
    [anon_sym_POUNDelif] = ACTIONS(12319),
    [anon_sym_POUNDELIF] = ACTIONS(12319),
    [anon_sym_POUNDElif] = ACTIONS(12319),
    [anon_sym_POUNDelse] = ACTIONS(12319),
    [anon_sym_POUNDELSE] = ACTIONS(12319),
    [anon_sym_POUNDElse] = ACTIONS(12319),
    [anon_sym_POUNDelse2] = ACTIONS(12319),
    [anon_sym_POUNDELSE2] = ACTIONS(12319),
    [anon_sym_POUNDElse2] = ACTIONS(12319),
    [anon_sym_POUNDendif] = ACTIONS(12319),
    [anon_sym_POUNDENDIF] = ACTIONS(12319),
    [anon_sym_POUNDEndif] = ACTIONS(12319),
    [anon_sym_POUNDendif2] = ACTIONS(12319),
    [anon_sym_POUNDENDIF2] = ACTIONS(12319),
    [anon_sym_POUNDEndif2] = ACTIONS(12319),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12319),
    [sym_trigger_keyword] = ACTIONS(12319),
    [sym_var_keyword] = ACTIONS(12319),
    [sym_local_keyword] = ACTIONS(12319),
    [sym_internal_keyword] = ACTIONS(12319),
    [sym_protected_keyword] = ACTIONS(12319),
    [sym_event_keyword] = ACTIONS(12319),
    [sym_fields_keyword] = ACTIONS(12319),
    [sym_keys_keyword] = ACTIONS(12319),
    [sym_fieldgroups_keyword] = ACTIONS(12319),
    [sym_actions_keyword] = ACTIONS(12319),
    [sym_layout_keyword] = ACTIONS(12319),
    [sym_area_keyword] = ACTIONS(12319),
    [sym_group_keyword] = ACTIONS(12319),
    [sym_repeater_keyword] = ACTIONS(12319),
    [sym_cuegroup_keyword] = ACTIONS(12319),
    [sym_fixed_keyword] = ACTIONS(12319),
    [sym_grid_keyword] = ACTIONS(12319),
    [sym_part_keyword] = ACTIONS(12319),
    [sym_systempart_keyword] = ACTIONS(12319),
    [sym_usercontrol_keyword] = ACTIONS(12319),
    [sym_dataset_keyword] = ACTIONS(12319),
    [sym_elements_keyword] = ACTIONS(12319),
    [sym_dataitem_keyword] = ACTIONS(12319),
    [sym_column_keyword] = ACTIONS(12319),
    [sym_filter_keyword] = ACTIONS(12319),
    [sym_labels_keyword] = ACTIONS(12319),
    [sym_rendering_keyword] = ACTIONS(12319),
    [sym_requestpage_keyword] = ACTIONS(12319),
    [sym_schema_keyword] = ACTIONS(12319),
    [sym_views_keyword] = ACTIONS(12319),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12319),
    [sym_preproc_open] = ACTIONS(12319),
    [sym_preproc_close] = ACTIONS(12319),
  },
  [STATE(5022)] = {
    [anon_sym_SEMI] = ACTIONS(12323),
    [aux_sym_where_condition_token1] = ACTIONS(12325),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12323),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12323),
    [anon_sym_LBRACK] = ACTIONS(12323),
    [aux_sym_basic_type_token6] = ACTIONS(12325),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12323),
    [aux_sym_addafter_modification_token1] = ACTIONS(12323),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12323),
    [aux_sym_modify_modification_token1] = ACTIONS(12323),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12323),
    [aux_sym_movelast_modification_token1] = ACTIONS(12323),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12323),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12323),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12323),
    [anon_sym_POUNDif] = ACTIONS(12323),
    [anon_sym_POUNDIF] = ACTIONS(12323),
    [anon_sym_POUNDIf] = ACTIONS(12323),
    [anon_sym_POUNDelif] = ACTIONS(12323),
    [anon_sym_POUNDELIF] = ACTIONS(12323),
    [anon_sym_POUNDElif] = ACTIONS(12323),
    [anon_sym_POUNDelse] = ACTIONS(12323),
    [anon_sym_POUNDELSE] = ACTIONS(12323),
    [anon_sym_POUNDElse] = ACTIONS(12323),
    [anon_sym_POUNDelse2] = ACTIONS(12323),
    [anon_sym_POUNDELSE2] = ACTIONS(12323),
    [anon_sym_POUNDElse2] = ACTIONS(12323),
    [anon_sym_POUNDendif] = ACTIONS(12323),
    [anon_sym_POUNDENDIF] = ACTIONS(12323),
    [anon_sym_POUNDEndif] = ACTIONS(12323),
    [anon_sym_POUNDendif2] = ACTIONS(12323),
    [anon_sym_POUNDENDIF2] = ACTIONS(12323),
    [anon_sym_POUNDEndif2] = ACTIONS(12323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12323),
    [sym_trigger_keyword] = ACTIONS(12323),
    [sym_var_keyword] = ACTIONS(12323),
    [sym_local_keyword] = ACTIONS(12323),
    [sym_internal_keyword] = ACTIONS(12323),
    [sym_protected_keyword] = ACTIONS(12323),
    [sym_event_keyword] = ACTIONS(12323),
    [sym_fields_keyword] = ACTIONS(12323),
    [sym_keys_keyword] = ACTIONS(12323),
    [sym_fieldgroups_keyword] = ACTIONS(12323),
    [sym_actions_keyword] = ACTIONS(12323),
    [sym_layout_keyword] = ACTIONS(12323),
    [sym_area_keyword] = ACTIONS(12323),
    [sym_group_keyword] = ACTIONS(12323),
    [sym_repeater_keyword] = ACTIONS(12323),
    [sym_cuegroup_keyword] = ACTIONS(12323),
    [sym_fixed_keyword] = ACTIONS(12323),
    [sym_grid_keyword] = ACTIONS(12323),
    [sym_part_keyword] = ACTIONS(12323),
    [sym_systempart_keyword] = ACTIONS(12323),
    [sym_usercontrol_keyword] = ACTIONS(12323),
    [sym_dataset_keyword] = ACTIONS(12323),
    [sym_elements_keyword] = ACTIONS(12323),
    [sym_dataitem_keyword] = ACTIONS(12323),
    [sym_column_keyword] = ACTIONS(12323),
    [sym_filter_keyword] = ACTIONS(12323),
    [sym_labels_keyword] = ACTIONS(12323),
    [sym_rendering_keyword] = ACTIONS(12323),
    [sym_requestpage_keyword] = ACTIONS(12323),
    [sym_schema_keyword] = ACTIONS(12323),
    [sym_views_keyword] = ACTIONS(12323),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12323),
    [sym_preproc_open] = ACTIONS(12323),
    [sym_preproc_close] = ACTIONS(12323),
  },
  [STATE(5023)] = {
    [anon_sym_SEMI] = ACTIONS(12323),
    [aux_sym_where_condition_token1] = ACTIONS(12325),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12323),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12323),
    [anon_sym_LBRACK] = ACTIONS(12323),
    [aux_sym_basic_type_token6] = ACTIONS(12325),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12323),
    [aux_sym_addafter_modification_token1] = ACTIONS(12323),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12323),
    [aux_sym_modify_modification_token1] = ACTIONS(12323),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12323),
    [aux_sym_movelast_modification_token1] = ACTIONS(12323),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12323),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12323),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12323),
    [anon_sym_POUNDif] = ACTIONS(12323),
    [anon_sym_POUNDIF] = ACTIONS(12323),
    [anon_sym_POUNDIf] = ACTIONS(12323),
    [anon_sym_POUNDelif] = ACTIONS(12323),
    [anon_sym_POUNDELIF] = ACTIONS(12323),
    [anon_sym_POUNDElif] = ACTIONS(12323),
    [anon_sym_POUNDelse] = ACTIONS(12323),
    [anon_sym_POUNDELSE] = ACTIONS(12323),
    [anon_sym_POUNDElse] = ACTIONS(12323),
    [anon_sym_POUNDelse2] = ACTIONS(12323),
    [anon_sym_POUNDELSE2] = ACTIONS(12323),
    [anon_sym_POUNDElse2] = ACTIONS(12323),
    [anon_sym_POUNDendif] = ACTIONS(12323),
    [anon_sym_POUNDENDIF] = ACTIONS(12323),
    [anon_sym_POUNDEndif] = ACTIONS(12323),
    [anon_sym_POUNDendif2] = ACTIONS(12323),
    [anon_sym_POUNDENDIF2] = ACTIONS(12323),
    [anon_sym_POUNDEndif2] = ACTIONS(12323),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12323),
    [sym_trigger_keyword] = ACTIONS(12323),
    [sym_var_keyword] = ACTIONS(12323),
    [sym_local_keyword] = ACTIONS(12323),
    [sym_internal_keyword] = ACTIONS(12323),
    [sym_protected_keyword] = ACTIONS(12323),
    [sym_event_keyword] = ACTIONS(12323),
    [sym_fields_keyword] = ACTIONS(12323),
    [sym_keys_keyword] = ACTIONS(12323),
    [sym_fieldgroups_keyword] = ACTIONS(12323),
    [sym_actions_keyword] = ACTIONS(12323),
    [sym_layout_keyword] = ACTIONS(12323),
    [sym_area_keyword] = ACTIONS(12323),
    [sym_group_keyword] = ACTIONS(12323),
    [sym_repeater_keyword] = ACTIONS(12323),
    [sym_cuegroup_keyword] = ACTIONS(12323),
    [sym_fixed_keyword] = ACTIONS(12323),
    [sym_grid_keyword] = ACTIONS(12323),
    [sym_part_keyword] = ACTIONS(12323),
    [sym_systempart_keyword] = ACTIONS(12323),
    [sym_usercontrol_keyword] = ACTIONS(12323),
    [sym_dataset_keyword] = ACTIONS(12323),
    [sym_elements_keyword] = ACTIONS(12323),
    [sym_dataitem_keyword] = ACTIONS(12323),
    [sym_column_keyword] = ACTIONS(12323),
    [sym_filter_keyword] = ACTIONS(12323),
    [sym_labels_keyword] = ACTIONS(12323),
    [sym_rendering_keyword] = ACTIONS(12323),
    [sym_requestpage_keyword] = ACTIONS(12323),
    [sym_schema_keyword] = ACTIONS(12323),
    [sym_views_keyword] = ACTIONS(12323),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12323),
    [sym_preproc_open] = ACTIONS(12323),
    [sym_preproc_close] = ACTIONS(12323),
  },
  [STATE(5024)] = {
    [anon_sym_SEMI] = ACTIONS(12327),
    [aux_sym_where_condition_token1] = ACTIONS(12329),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12327),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12327),
    [anon_sym_LBRACK] = ACTIONS(12327),
    [aux_sym_basic_type_token6] = ACTIONS(12329),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12327),
    [aux_sym_addafter_modification_token1] = ACTIONS(12327),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12327),
    [aux_sym_modify_modification_token1] = ACTIONS(12327),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12327),
    [aux_sym_movelast_modification_token1] = ACTIONS(12327),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12327),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12327),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12327),
    [anon_sym_POUNDif] = ACTIONS(12327),
    [anon_sym_POUNDIF] = ACTIONS(12327),
    [anon_sym_POUNDIf] = ACTIONS(12327),
    [anon_sym_POUNDelif] = ACTIONS(12327),
    [anon_sym_POUNDELIF] = ACTIONS(12327),
    [anon_sym_POUNDElif] = ACTIONS(12327),
    [anon_sym_POUNDelse] = ACTIONS(12327),
    [anon_sym_POUNDELSE] = ACTIONS(12327),
    [anon_sym_POUNDElse] = ACTIONS(12327),
    [anon_sym_POUNDelse2] = ACTIONS(12327),
    [anon_sym_POUNDELSE2] = ACTIONS(12327),
    [anon_sym_POUNDElse2] = ACTIONS(12327),
    [anon_sym_POUNDendif] = ACTIONS(12327),
    [anon_sym_POUNDENDIF] = ACTIONS(12327),
    [anon_sym_POUNDEndif] = ACTIONS(12327),
    [anon_sym_POUNDendif2] = ACTIONS(12327),
    [anon_sym_POUNDENDIF2] = ACTIONS(12327),
    [anon_sym_POUNDEndif2] = ACTIONS(12327),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12327),
    [sym_trigger_keyword] = ACTIONS(12327),
    [sym_var_keyword] = ACTIONS(12327),
    [sym_local_keyword] = ACTIONS(12327),
    [sym_internal_keyword] = ACTIONS(12327),
    [sym_protected_keyword] = ACTIONS(12327),
    [sym_event_keyword] = ACTIONS(12327),
    [sym_fields_keyword] = ACTIONS(12327),
    [sym_keys_keyword] = ACTIONS(12327),
    [sym_fieldgroups_keyword] = ACTIONS(12327),
    [sym_actions_keyword] = ACTIONS(12327),
    [sym_layout_keyword] = ACTIONS(12327),
    [sym_area_keyword] = ACTIONS(12327),
    [sym_group_keyword] = ACTIONS(12327),
    [sym_repeater_keyword] = ACTIONS(12327),
    [sym_cuegroup_keyword] = ACTIONS(12327),
    [sym_fixed_keyword] = ACTIONS(12327),
    [sym_grid_keyword] = ACTIONS(12327),
    [sym_part_keyword] = ACTIONS(12327),
    [sym_systempart_keyword] = ACTIONS(12327),
    [sym_usercontrol_keyword] = ACTIONS(12327),
    [sym_dataset_keyword] = ACTIONS(12327),
    [sym_elements_keyword] = ACTIONS(12327),
    [sym_dataitem_keyword] = ACTIONS(12327),
    [sym_column_keyword] = ACTIONS(12327),
    [sym_filter_keyword] = ACTIONS(12327),
    [sym_labels_keyword] = ACTIONS(12327),
    [sym_rendering_keyword] = ACTIONS(12327),
    [sym_requestpage_keyword] = ACTIONS(12327),
    [sym_schema_keyword] = ACTIONS(12327),
    [sym_views_keyword] = ACTIONS(12327),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12327),
    [sym_preproc_open] = ACTIONS(12327),
    [sym_preproc_close] = ACTIONS(12327),
  },
  [STATE(5025)] = {
    [anon_sym_SEMI] = ACTIONS(12331),
    [aux_sym_where_condition_token1] = ACTIONS(12333),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12335),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12335),
    [anon_sym_LBRACK] = ACTIONS(12335),
    [aux_sym_basic_type_token6] = ACTIONS(12333),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12335),
    [aux_sym_addafter_modification_token1] = ACTIONS(12335),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12335),
    [aux_sym_modify_modification_token1] = ACTIONS(12335),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12335),
    [aux_sym_movelast_modification_token1] = ACTIONS(12335),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12335),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12335),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12335),
    [anon_sym_POUNDif] = ACTIONS(12335),
    [anon_sym_POUNDIF] = ACTIONS(12335),
    [anon_sym_POUNDIf] = ACTIONS(12335),
    [anon_sym_POUNDelif] = ACTIONS(12335),
    [anon_sym_POUNDELIF] = ACTIONS(12335),
    [anon_sym_POUNDElif] = ACTIONS(12335),
    [anon_sym_POUNDelse] = ACTIONS(12335),
    [anon_sym_POUNDELSE] = ACTIONS(12335),
    [anon_sym_POUNDElse] = ACTIONS(12335),
    [anon_sym_POUNDelse2] = ACTIONS(12335),
    [anon_sym_POUNDELSE2] = ACTIONS(12335),
    [anon_sym_POUNDElse2] = ACTIONS(12335),
    [anon_sym_POUNDendif] = ACTIONS(12335),
    [anon_sym_POUNDENDIF] = ACTIONS(12335),
    [anon_sym_POUNDEndif] = ACTIONS(12335),
    [anon_sym_POUNDendif2] = ACTIONS(12335),
    [anon_sym_POUNDENDIF2] = ACTIONS(12335),
    [anon_sym_POUNDEndif2] = ACTIONS(12335),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12335),
    [sym_trigger_keyword] = ACTIONS(12335),
    [sym_var_keyword] = ACTIONS(12335),
    [sym_local_keyword] = ACTIONS(12335),
    [sym_internal_keyword] = ACTIONS(12335),
    [sym_protected_keyword] = ACTIONS(12335),
    [sym_event_keyword] = ACTIONS(12335),
    [sym_fields_keyword] = ACTIONS(12335),
    [sym_keys_keyword] = ACTIONS(12335),
    [sym_fieldgroups_keyword] = ACTIONS(12335),
    [sym_actions_keyword] = ACTIONS(12335),
    [sym_layout_keyword] = ACTIONS(12335),
    [sym_area_keyword] = ACTIONS(12335),
    [sym_group_keyword] = ACTIONS(12335),
    [sym_repeater_keyword] = ACTIONS(12335),
    [sym_cuegroup_keyword] = ACTIONS(12335),
    [sym_fixed_keyword] = ACTIONS(12335),
    [sym_grid_keyword] = ACTIONS(12335),
    [sym_part_keyword] = ACTIONS(12335),
    [sym_systempart_keyword] = ACTIONS(12335),
    [sym_usercontrol_keyword] = ACTIONS(12335),
    [sym_dataset_keyword] = ACTIONS(12335),
    [sym_elements_keyword] = ACTIONS(12335),
    [sym_dataitem_keyword] = ACTIONS(12335),
    [sym_column_keyword] = ACTIONS(12335),
    [sym_filter_keyword] = ACTIONS(12335),
    [sym_labels_keyword] = ACTIONS(12335),
    [sym_rendering_keyword] = ACTIONS(12335),
    [sym_requestpage_keyword] = ACTIONS(12335),
    [sym_schema_keyword] = ACTIONS(12335),
    [sym_views_keyword] = ACTIONS(12335),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12335),
    [sym_preproc_open] = ACTIONS(12335),
    [sym_preproc_close] = ACTIONS(12335),
  },
  [STATE(5026)] = {
    [anon_sym_SEMI] = ACTIONS(12337),
    [aux_sym_where_condition_token1] = ACTIONS(12333),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12335),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12335),
    [anon_sym_LBRACK] = ACTIONS(12335),
    [aux_sym_basic_type_token6] = ACTIONS(12333),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12335),
    [aux_sym_addafter_modification_token1] = ACTIONS(12335),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12335),
    [aux_sym_modify_modification_token1] = ACTIONS(12335),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12335),
    [aux_sym_movelast_modification_token1] = ACTIONS(12335),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12335),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12335),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12335),
    [anon_sym_POUNDif] = ACTIONS(12335),
    [anon_sym_POUNDIF] = ACTIONS(12335),
    [anon_sym_POUNDIf] = ACTIONS(12335),
    [anon_sym_POUNDelif] = ACTIONS(12335),
    [anon_sym_POUNDELIF] = ACTIONS(12335),
    [anon_sym_POUNDElif] = ACTIONS(12335),
    [anon_sym_POUNDelse] = ACTIONS(12335),
    [anon_sym_POUNDELSE] = ACTIONS(12335),
    [anon_sym_POUNDElse] = ACTIONS(12335),
    [anon_sym_POUNDelse2] = ACTIONS(12335),
    [anon_sym_POUNDELSE2] = ACTIONS(12335),
    [anon_sym_POUNDElse2] = ACTIONS(12335),
    [anon_sym_POUNDendif] = ACTIONS(12335),
    [anon_sym_POUNDENDIF] = ACTIONS(12335),
    [anon_sym_POUNDEndif] = ACTIONS(12335),
    [anon_sym_POUNDendif2] = ACTIONS(12335),
    [anon_sym_POUNDENDIF2] = ACTIONS(12335),
    [anon_sym_POUNDEndif2] = ACTIONS(12335),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12335),
    [sym_trigger_keyword] = ACTIONS(12335),
    [sym_var_keyword] = ACTIONS(12335),
    [sym_local_keyword] = ACTIONS(12335),
    [sym_internal_keyword] = ACTIONS(12335),
    [sym_protected_keyword] = ACTIONS(12335),
    [sym_event_keyword] = ACTIONS(12335),
    [sym_fields_keyword] = ACTIONS(12335),
    [sym_keys_keyword] = ACTIONS(12335),
    [sym_fieldgroups_keyword] = ACTIONS(12335),
    [sym_actions_keyword] = ACTIONS(12335),
    [sym_layout_keyword] = ACTIONS(12335),
    [sym_area_keyword] = ACTIONS(12335),
    [sym_group_keyword] = ACTIONS(12335),
    [sym_repeater_keyword] = ACTIONS(12335),
    [sym_cuegroup_keyword] = ACTIONS(12335),
    [sym_fixed_keyword] = ACTIONS(12335),
    [sym_grid_keyword] = ACTIONS(12335),
    [sym_part_keyword] = ACTIONS(12335),
    [sym_systempart_keyword] = ACTIONS(12335),
    [sym_usercontrol_keyword] = ACTIONS(12335),
    [sym_dataset_keyword] = ACTIONS(12335),
    [sym_elements_keyword] = ACTIONS(12335),
    [sym_dataitem_keyword] = ACTIONS(12335),
    [sym_column_keyword] = ACTIONS(12335),
    [sym_filter_keyword] = ACTIONS(12335),
    [sym_labels_keyword] = ACTIONS(12335),
    [sym_rendering_keyword] = ACTIONS(12335),
    [sym_requestpage_keyword] = ACTIONS(12335),
    [sym_schema_keyword] = ACTIONS(12335),
    [sym_views_keyword] = ACTIONS(12335),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12335),
    [sym_preproc_open] = ACTIONS(12335),
    [sym_preproc_close] = ACTIONS(12335),
  },
  [STATE(5027)] = {
    [anon_sym_SEMI] = ACTIONS(12339),
    [aux_sym_where_condition_token1] = ACTIONS(12341),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12339),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12339),
    [anon_sym_LBRACK] = ACTIONS(12339),
    [aux_sym_basic_type_token6] = ACTIONS(12341),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12339),
    [aux_sym_addafter_modification_token1] = ACTIONS(12339),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12339),
    [aux_sym_modify_modification_token1] = ACTIONS(12339),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12339),
    [aux_sym_movelast_modification_token1] = ACTIONS(12339),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12339),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12339),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12339),
    [anon_sym_POUNDif] = ACTIONS(12339),
    [anon_sym_POUNDIF] = ACTIONS(12339),
    [anon_sym_POUNDIf] = ACTIONS(12339),
    [anon_sym_POUNDelif] = ACTIONS(12339),
    [anon_sym_POUNDELIF] = ACTIONS(12339),
    [anon_sym_POUNDElif] = ACTIONS(12339),
    [anon_sym_POUNDelse] = ACTIONS(12339),
    [anon_sym_POUNDELSE] = ACTIONS(12339),
    [anon_sym_POUNDElse] = ACTIONS(12339),
    [anon_sym_POUNDelse2] = ACTIONS(12339),
    [anon_sym_POUNDELSE2] = ACTIONS(12339),
    [anon_sym_POUNDElse2] = ACTIONS(12339),
    [anon_sym_POUNDendif] = ACTIONS(12339),
    [anon_sym_POUNDENDIF] = ACTIONS(12339),
    [anon_sym_POUNDEndif] = ACTIONS(12339),
    [anon_sym_POUNDendif2] = ACTIONS(12339),
    [anon_sym_POUNDENDIF2] = ACTIONS(12339),
    [anon_sym_POUNDEndif2] = ACTIONS(12339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12339),
    [sym_trigger_keyword] = ACTIONS(12339),
    [sym_var_keyword] = ACTIONS(12339),
    [sym_local_keyword] = ACTIONS(12339),
    [sym_internal_keyword] = ACTIONS(12339),
    [sym_protected_keyword] = ACTIONS(12339),
    [sym_event_keyword] = ACTIONS(12339),
    [sym_fields_keyword] = ACTIONS(12339),
    [sym_keys_keyword] = ACTIONS(12339),
    [sym_fieldgroups_keyword] = ACTIONS(12339),
    [sym_actions_keyword] = ACTIONS(12339),
    [sym_layout_keyword] = ACTIONS(12339),
    [sym_area_keyword] = ACTIONS(12339),
    [sym_group_keyword] = ACTIONS(12339),
    [sym_repeater_keyword] = ACTIONS(12339),
    [sym_cuegroup_keyword] = ACTIONS(12339),
    [sym_fixed_keyword] = ACTIONS(12339),
    [sym_grid_keyword] = ACTIONS(12339),
    [sym_part_keyword] = ACTIONS(12339),
    [sym_systempart_keyword] = ACTIONS(12339),
    [sym_usercontrol_keyword] = ACTIONS(12339),
    [sym_dataset_keyword] = ACTIONS(12339),
    [sym_elements_keyword] = ACTIONS(12339),
    [sym_dataitem_keyword] = ACTIONS(12339),
    [sym_column_keyword] = ACTIONS(12339),
    [sym_filter_keyword] = ACTIONS(12339),
    [sym_labels_keyword] = ACTIONS(12339),
    [sym_rendering_keyword] = ACTIONS(12339),
    [sym_requestpage_keyword] = ACTIONS(12339),
    [sym_schema_keyword] = ACTIONS(12339),
    [sym_views_keyword] = ACTIONS(12339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12339),
    [sym_preproc_open] = ACTIONS(12339),
    [sym_preproc_close] = ACTIONS(12339),
  },
  [STATE(5028)] = {
    [anon_sym_SEMI] = ACTIONS(12339),
    [aux_sym_where_condition_token1] = ACTIONS(12341),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12339),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12339),
    [anon_sym_LBRACK] = ACTIONS(12339),
    [aux_sym_basic_type_token6] = ACTIONS(12341),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12339),
    [aux_sym_addafter_modification_token1] = ACTIONS(12339),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12339),
    [aux_sym_modify_modification_token1] = ACTIONS(12339),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12339),
    [aux_sym_movelast_modification_token1] = ACTIONS(12339),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12339),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12339),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12339),
    [anon_sym_POUNDif] = ACTIONS(12339),
    [anon_sym_POUNDIF] = ACTIONS(12339),
    [anon_sym_POUNDIf] = ACTIONS(12339),
    [anon_sym_POUNDelif] = ACTIONS(12339),
    [anon_sym_POUNDELIF] = ACTIONS(12339),
    [anon_sym_POUNDElif] = ACTIONS(12339),
    [anon_sym_POUNDelse] = ACTIONS(12339),
    [anon_sym_POUNDELSE] = ACTIONS(12339),
    [anon_sym_POUNDElse] = ACTIONS(12339),
    [anon_sym_POUNDelse2] = ACTIONS(12339),
    [anon_sym_POUNDELSE2] = ACTIONS(12339),
    [anon_sym_POUNDElse2] = ACTIONS(12339),
    [anon_sym_POUNDendif] = ACTIONS(12339),
    [anon_sym_POUNDENDIF] = ACTIONS(12339),
    [anon_sym_POUNDEndif] = ACTIONS(12339),
    [anon_sym_POUNDendif2] = ACTIONS(12339),
    [anon_sym_POUNDENDIF2] = ACTIONS(12339),
    [anon_sym_POUNDEndif2] = ACTIONS(12339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12339),
    [sym_trigger_keyword] = ACTIONS(12339),
    [sym_var_keyword] = ACTIONS(12339),
    [sym_local_keyword] = ACTIONS(12339),
    [sym_internal_keyword] = ACTIONS(12339),
    [sym_protected_keyword] = ACTIONS(12339),
    [sym_event_keyword] = ACTIONS(12339),
    [sym_fields_keyword] = ACTIONS(12339),
    [sym_keys_keyword] = ACTIONS(12339),
    [sym_fieldgroups_keyword] = ACTIONS(12339),
    [sym_actions_keyword] = ACTIONS(12339),
    [sym_layout_keyword] = ACTIONS(12339),
    [sym_area_keyword] = ACTIONS(12339),
    [sym_group_keyword] = ACTIONS(12339),
    [sym_repeater_keyword] = ACTIONS(12339),
    [sym_cuegroup_keyword] = ACTIONS(12339),
    [sym_fixed_keyword] = ACTIONS(12339),
    [sym_grid_keyword] = ACTIONS(12339),
    [sym_part_keyword] = ACTIONS(12339),
    [sym_systempart_keyword] = ACTIONS(12339),
    [sym_usercontrol_keyword] = ACTIONS(12339),
    [sym_dataset_keyword] = ACTIONS(12339),
    [sym_elements_keyword] = ACTIONS(12339),
    [sym_dataitem_keyword] = ACTIONS(12339),
    [sym_column_keyword] = ACTIONS(12339),
    [sym_filter_keyword] = ACTIONS(12339),
    [sym_labels_keyword] = ACTIONS(12339),
    [sym_rendering_keyword] = ACTIONS(12339),
    [sym_requestpage_keyword] = ACTIONS(12339),
    [sym_schema_keyword] = ACTIONS(12339),
    [sym_views_keyword] = ACTIONS(12339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12339),
    [sym_preproc_open] = ACTIONS(12339),
    [sym_preproc_close] = ACTIONS(12339),
  },
  [STATE(5029)] = {
    [anon_sym_SEMI] = ACTIONS(12343),
    [aux_sym_where_condition_token1] = ACTIONS(12345),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12347),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12347),
    [anon_sym_LBRACK] = ACTIONS(12347),
    [aux_sym_basic_type_token6] = ACTIONS(12345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12347),
    [aux_sym_addafter_modification_token1] = ACTIONS(12347),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12347),
    [aux_sym_modify_modification_token1] = ACTIONS(12347),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12347),
    [aux_sym_movelast_modification_token1] = ACTIONS(12347),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12347),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12347),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12347),
    [anon_sym_POUNDif] = ACTIONS(12347),
    [anon_sym_POUNDIF] = ACTIONS(12347),
    [anon_sym_POUNDIf] = ACTIONS(12347),
    [anon_sym_POUNDelif] = ACTIONS(12347),
    [anon_sym_POUNDELIF] = ACTIONS(12347),
    [anon_sym_POUNDElif] = ACTIONS(12347),
    [anon_sym_POUNDelse] = ACTIONS(12347),
    [anon_sym_POUNDELSE] = ACTIONS(12347),
    [anon_sym_POUNDElse] = ACTIONS(12347),
    [anon_sym_POUNDelse2] = ACTIONS(12347),
    [anon_sym_POUNDELSE2] = ACTIONS(12347),
    [anon_sym_POUNDElse2] = ACTIONS(12347),
    [anon_sym_POUNDendif] = ACTIONS(12347),
    [anon_sym_POUNDENDIF] = ACTIONS(12347),
    [anon_sym_POUNDEndif] = ACTIONS(12347),
    [anon_sym_POUNDendif2] = ACTIONS(12347),
    [anon_sym_POUNDENDIF2] = ACTIONS(12347),
    [anon_sym_POUNDEndif2] = ACTIONS(12347),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12347),
    [sym_trigger_keyword] = ACTIONS(12347),
    [sym_var_keyword] = ACTIONS(12347),
    [sym_local_keyword] = ACTIONS(12347),
    [sym_internal_keyword] = ACTIONS(12347),
    [sym_protected_keyword] = ACTIONS(12347),
    [sym_event_keyword] = ACTIONS(12347),
    [sym_fields_keyword] = ACTIONS(12347),
    [sym_keys_keyword] = ACTIONS(12347),
    [sym_fieldgroups_keyword] = ACTIONS(12347),
    [sym_actions_keyword] = ACTIONS(12347),
    [sym_layout_keyword] = ACTIONS(12347),
    [sym_area_keyword] = ACTIONS(12347),
    [sym_group_keyword] = ACTIONS(12347),
    [sym_repeater_keyword] = ACTIONS(12347),
    [sym_cuegroup_keyword] = ACTIONS(12347),
    [sym_fixed_keyword] = ACTIONS(12347),
    [sym_grid_keyword] = ACTIONS(12347),
    [sym_part_keyword] = ACTIONS(12347),
    [sym_systempart_keyword] = ACTIONS(12347),
    [sym_usercontrol_keyword] = ACTIONS(12347),
    [sym_dataset_keyword] = ACTIONS(12347),
    [sym_elements_keyword] = ACTIONS(12347),
    [sym_dataitem_keyword] = ACTIONS(12347),
    [sym_column_keyword] = ACTIONS(12347),
    [sym_filter_keyword] = ACTIONS(12347),
    [sym_labels_keyword] = ACTIONS(12347),
    [sym_rendering_keyword] = ACTIONS(12347),
    [sym_requestpage_keyword] = ACTIONS(12347),
    [sym_schema_keyword] = ACTIONS(12347),
    [sym_views_keyword] = ACTIONS(12347),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12347),
    [sym_preproc_open] = ACTIONS(12347),
    [sym_preproc_close] = ACTIONS(12347),
  },
  [STATE(5030)] = {
    [anon_sym_SEMI] = ACTIONS(12349),
    [aux_sym_where_condition_token1] = ACTIONS(12345),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12347),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12347),
    [anon_sym_LBRACK] = ACTIONS(12347),
    [aux_sym_basic_type_token6] = ACTIONS(12345),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12347),
    [aux_sym_addafter_modification_token1] = ACTIONS(12347),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12347),
    [aux_sym_modify_modification_token1] = ACTIONS(12347),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12347),
    [aux_sym_movelast_modification_token1] = ACTIONS(12347),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12347),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12347),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12347),
    [anon_sym_POUNDif] = ACTIONS(12347),
    [anon_sym_POUNDIF] = ACTIONS(12347),
    [anon_sym_POUNDIf] = ACTIONS(12347),
    [anon_sym_POUNDelif] = ACTIONS(12347),
    [anon_sym_POUNDELIF] = ACTIONS(12347),
    [anon_sym_POUNDElif] = ACTIONS(12347),
    [anon_sym_POUNDelse] = ACTIONS(12347),
    [anon_sym_POUNDELSE] = ACTIONS(12347),
    [anon_sym_POUNDElse] = ACTIONS(12347),
    [anon_sym_POUNDelse2] = ACTIONS(12347),
    [anon_sym_POUNDELSE2] = ACTIONS(12347),
    [anon_sym_POUNDElse2] = ACTIONS(12347),
    [anon_sym_POUNDendif] = ACTIONS(12347),
    [anon_sym_POUNDENDIF] = ACTIONS(12347),
    [anon_sym_POUNDEndif] = ACTIONS(12347),
    [anon_sym_POUNDendif2] = ACTIONS(12347),
    [anon_sym_POUNDENDIF2] = ACTIONS(12347),
    [anon_sym_POUNDEndif2] = ACTIONS(12347),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12347),
    [sym_trigger_keyword] = ACTIONS(12347),
    [sym_var_keyword] = ACTIONS(12347),
    [sym_local_keyword] = ACTIONS(12347),
    [sym_internal_keyword] = ACTIONS(12347),
    [sym_protected_keyword] = ACTIONS(12347),
    [sym_event_keyword] = ACTIONS(12347),
    [sym_fields_keyword] = ACTIONS(12347),
    [sym_keys_keyword] = ACTIONS(12347),
    [sym_fieldgroups_keyword] = ACTIONS(12347),
    [sym_actions_keyword] = ACTIONS(12347),
    [sym_layout_keyword] = ACTIONS(12347),
    [sym_area_keyword] = ACTIONS(12347),
    [sym_group_keyword] = ACTIONS(12347),
    [sym_repeater_keyword] = ACTIONS(12347),
    [sym_cuegroup_keyword] = ACTIONS(12347),
    [sym_fixed_keyword] = ACTIONS(12347),
    [sym_grid_keyword] = ACTIONS(12347),
    [sym_part_keyword] = ACTIONS(12347),
    [sym_systempart_keyword] = ACTIONS(12347),
    [sym_usercontrol_keyword] = ACTIONS(12347),
    [sym_dataset_keyword] = ACTIONS(12347),
    [sym_elements_keyword] = ACTIONS(12347),
    [sym_dataitem_keyword] = ACTIONS(12347),
    [sym_column_keyword] = ACTIONS(12347),
    [sym_filter_keyword] = ACTIONS(12347),
    [sym_labels_keyword] = ACTIONS(12347),
    [sym_rendering_keyword] = ACTIONS(12347),
    [sym_requestpage_keyword] = ACTIONS(12347),
    [sym_schema_keyword] = ACTIONS(12347),
    [sym_views_keyword] = ACTIONS(12347),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12347),
    [sym_preproc_open] = ACTIONS(12347),
    [sym_preproc_close] = ACTIONS(12347),
  },
  [STATE(5031)] = {
    [anon_sym_SEMI] = ACTIONS(12351),
    [aux_sym_where_condition_token1] = ACTIONS(12341),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12339),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12339),
    [anon_sym_LBRACK] = ACTIONS(12339),
    [aux_sym_basic_type_token6] = ACTIONS(12341),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12339),
    [aux_sym_addafter_modification_token1] = ACTIONS(12339),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12339),
    [aux_sym_modify_modification_token1] = ACTIONS(12339),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12339),
    [aux_sym_movelast_modification_token1] = ACTIONS(12339),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12339),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12339),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12339),
    [anon_sym_POUNDif] = ACTIONS(12339),
    [anon_sym_POUNDIF] = ACTIONS(12339),
    [anon_sym_POUNDIf] = ACTIONS(12339),
    [anon_sym_POUNDelif] = ACTIONS(12339),
    [anon_sym_POUNDELIF] = ACTIONS(12339),
    [anon_sym_POUNDElif] = ACTIONS(12339),
    [anon_sym_POUNDelse] = ACTIONS(12339),
    [anon_sym_POUNDELSE] = ACTIONS(12339),
    [anon_sym_POUNDElse] = ACTIONS(12339),
    [anon_sym_POUNDelse2] = ACTIONS(12339),
    [anon_sym_POUNDELSE2] = ACTIONS(12339),
    [anon_sym_POUNDElse2] = ACTIONS(12339),
    [anon_sym_POUNDendif] = ACTIONS(12339),
    [anon_sym_POUNDENDIF] = ACTIONS(12339),
    [anon_sym_POUNDEndif] = ACTIONS(12339),
    [anon_sym_POUNDendif2] = ACTIONS(12339),
    [anon_sym_POUNDENDIF2] = ACTIONS(12339),
    [anon_sym_POUNDEndif2] = ACTIONS(12339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12339),
    [sym_trigger_keyword] = ACTIONS(12339),
    [sym_var_keyword] = ACTIONS(12339),
    [sym_local_keyword] = ACTIONS(12339),
    [sym_internal_keyword] = ACTIONS(12339),
    [sym_protected_keyword] = ACTIONS(12339),
    [sym_event_keyword] = ACTIONS(12339),
    [sym_fields_keyword] = ACTIONS(12339),
    [sym_keys_keyword] = ACTIONS(12339),
    [sym_fieldgroups_keyword] = ACTIONS(12339),
    [sym_actions_keyword] = ACTIONS(12339),
    [sym_layout_keyword] = ACTIONS(12339),
    [sym_area_keyword] = ACTIONS(12339),
    [sym_group_keyword] = ACTIONS(12339),
    [sym_repeater_keyword] = ACTIONS(12339),
    [sym_cuegroup_keyword] = ACTIONS(12339),
    [sym_fixed_keyword] = ACTIONS(12339),
    [sym_grid_keyword] = ACTIONS(12339),
    [sym_part_keyword] = ACTIONS(12339),
    [sym_systempart_keyword] = ACTIONS(12339),
    [sym_usercontrol_keyword] = ACTIONS(12339),
    [sym_dataset_keyword] = ACTIONS(12339),
    [sym_elements_keyword] = ACTIONS(12339),
    [sym_dataitem_keyword] = ACTIONS(12339),
    [sym_column_keyword] = ACTIONS(12339),
    [sym_filter_keyword] = ACTIONS(12339),
    [sym_labels_keyword] = ACTIONS(12339),
    [sym_rendering_keyword] = ACTIONS(12339),
    [sym_requestpage_keyword] = ACTIONS(12339),
    [sym_schema_keyword] = ACTIONS(12339),
    [sym_views_keyword] = ACTIONS(12339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12339),
    [sym_preproc_open] = ACTIONS(12339),
    [sym_preproc_close] = ACTIONS(12339),
  },
  [STATE(5032)] = {
    [anon_sym_SEMI] = ACTIONS(12353),
    [aux_sym_where_condition_token1] = ACTIONS(12341),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12339),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12339),
    [anon_sym_LBRACK] = ACTIONS(12339),
    [aux_sym_basic_type_token6] = ACTIONS(12341),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12339),
    [aux_sym_addafter_modification_token1] = ACTIONS(12339),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12339),
    [aux_sym_modify_modification_token1] = ACTIONS(12339),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12339),
    [aux_sym_movelast_modification_token1] = ACTIONS(12339),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12339),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12339),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12339),
    [anon_sym_POUNDif] = ACTIONS(12339),
    [anon_sym_POUNDIF] = ACTIONS(12339),
    [anon_sym_POUNDIf] = ACTIONS(12339),
    [anon_sym_POUNDelif] = ACTIONS(12339),
    [anon_sym_POUNDELIF] = ACTIONS(12339),
    [anon_sym_POUNDElif] = ACTIONS(12339),
    [anon_sym_POUNDelse] = ACTIONS(12339),
    [anon_sym_POUNDELSE] = ACTIONS(12339),
    [anon_sym_POUNDElse] = ACTIONS(12339),
    [anon_sym_POUNDelse2] = ACTIONS(12339),
    [anon_sym_POUNDELSE2] = ACTIONS(12339),
    [anon_sym_POUNDElse2] = ACTIONS(12339),
    [anon_sym_POUNDendif] = ACTIONS(12339),
    [anon_sym_POUNDENDIF] = ACTIONS(12339),
    [anon_sym_POUNDEndif] = ACTIONS(12339),
    [anon_sym_POUNDendif2] = ACTIONS(12339),
    [anon_sym_POUNDENDIF2] = ACTIONS(12339),
    [anon_sym_POUNDEndif2] = ACTIONS(12339),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12339),
    [sym_trigger_keyword] = ACTIONS(12339),
    [sym_var_keyword] = ACTIONS(12339),
    [sym_local_keyword] = ACTIONS(12339),
    [sym_internal_keyword] = ACTIONS(12339),
    [sym_protected_keyword] = ACTIONS(12339),
    [sym_event_keyword] = ACTIONS(12339),
    [sym_fields_keyword] = ACTIONS(12339),
    [sym_keys_keyword] = ACTIONS(12339),
    [sym_fieldgroups_keyword] = ACTIONS(12339),
    [sym_actions_keyword] = ACTIONS(12339),
    [sym_layout_keyword] = ACTIONS(12339),
    [sym_area_keyword] = ACTIONS(12339),
    [sym_group_keyword] = ACTIONS(12339),
    [sym_repeater_keyword] = ACTIONS(12339),
    [sym_cuegroup_keyword] = ACTIONS(12339),
    [sym_fixed_keyword] = ACTIONS(12339),
    [sym_grid_keyword] = ACTIONS(12339),
    [sym_part_keyword] = ACTIONS(12339),
    [sym_systempart_keyword] = ACTIONS(12339),
    [sym_usercontrol_keyword] = ACTIONS(12339),
    [sym_dataset_keyword] = ACTIONS(12339),
    [sym_elements_keyword] = ACTIONS(12339),
    [sym_dataitem_keyword] = ACTIONS(12339),
    [sym_column_keyword] = ACTIONS(12339),
    [sym_filter_keyword] = ACTIONS(12339),
    [sym_labels_keyword] = ACTIONS(12339),
    [sym_rendering_keyword] = ACTIONS(12339),
    [sym_requestpage_keyword] = ACTIONS(12339),
    [sym_schema_keyword] = ACTIONS(12339),
    [sym_views_keyword] = ACTIONS(12339),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12339),
    [sym_preproc_open] = ACTIONS(12339),
    [sym_preproc_close] = ACTIONS(12339),
  },
  [STATE(5033)] = {
    [anon_sym_SEMI] = ACTIONS(12355),
    [aux_sym_where_condition_token1] = ACTIONS(12357),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12355),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12355),
    [anon_sym_LBRACK] = ACTIONS(12355),
    [aux_sym_basic_type_token6] = ACTIONS(12357),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12355),
    [aux_sym_addafter_modification_token1] = ACTIONS(12355),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12355),
    [aux_sym_modify_modification_token1] = ACTIONS(12355),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12355),
    [aux_sym_movelast_modification_token1] = ACTIONS(12355),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12355),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12355),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12355),
    [anon_sym_POUNDif] = ACTIONS(12355),
    [anon_sym_POUNDIF] = ACTIONS(12355),
    [anon_sym_POUNDIf] = ACTIONS(12355),
    [anon_sym_POUNDelif] = ACTIONS(12355),
    [anon_sym_POUNDELIF] = ACTIONS(12355),
    [anon_sym_POUNDElif] = ACTIONS(12355),
    [anon_sym_POUNDelse] = ACTIONS(12355),
    [anon_sym_POUNDELSE] = ACTIONS(12355),
    [anon_sym_POUNDElse] = ACTIONS(12355),
    [anon_sym_POUNDelse2] = ACTIONS(12355),
    [anon_sym_POUNDELSE2] = ACTIONS(12355),
    [anon_sym_POUNDElse2] = ACTIONS(12355),
    [anon_sym_POUNDendif] = ACTIONS(12355),
    [anon_sym_POUNDENDIF] = ACTIONS(12355),
    [anon_sym_POUNDEndif] = ACTIONS(12355),
    [anon_sym_POUNDendif2] = ACTIONS(12355),
    [anon_sym_POUNDENDIF2] = ACTIONS(12355),
    [anon_sym_POUNDEndif2] = ACTIONS(12355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12355),
    [sym_trigger_keyword] = ACTIONS(12355),
    [sym_var_keyword] = ACTIONS(12355),
    [sym_local_keyword] = ACTIONS(12355),
    [sym_internal_keyword] = ACTIONS(12355),
    [sym_protected_keyword] = ACTIONS(12355),
    [sym_event_keyword] = ACTIONS(12355),
    [sym_fields_keyword] = ACTIONS(12355),
    [sym_keys_keyword] = ACTIONS(12355),
    [sym_fieldgroups_keyword] = ACTIONS(12355),
    [sym_actions_keyword] = ACTIONS(12355),
    [sym_layout_keyword] = ACTIONS(12355),
    [sym_area_keyword] = ACTIONS(12355),
    [sym_group_keyword] = ACTIONS(12355),
    [sym_repeater_keyword] = ACTIONS(12355),
    [sym_cuegroup_keyword] = ACTIONS(12355),
    [sym_fixed_keyword] = ACTIONS(12355),
    [sym_grid_keyword] = ACTIONS(12355),
    [sym_part_keyword] = ACTIONS(12355),
    [sym_systempart_keyword] = ACTIONS(12355),
    [sym_usercontrol_keyword] = ACTIONS(12355),
    [sym_dataset_keyword] = ACTIONS(12355),
    [sym_elements_keyword] = ACTIONS(12355),
    [sym_dataitem_keyword] = ACTIONS(12355),
    [sym_column_keyword] = ACTIONS(12355),
    [sym_filter_keyword] = ACTIONS(12355),
    [sym_labels_keyword] = ACTIONS(12355),
    [sym_rendering_keyword] = ACTIONS(12355),
    [sym_requestpage_keyword] = ACTIONS(12355),
    [sym_schema_keyword] = ACTIONS(12355),
    [sym_views_keyword] = ACTIONS(12355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12355),
    [sym_preproc_open] = ACTIONS(12355),
    [sym_preproc_close] = ACTIONS(12355),
  },
  [STATE(5034)] = {
    [anon_sym_SEMI] = ACTIONS(12359),
    [aux_sym_where_condition_token1] = ACTIONS(12361),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12359),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12359),
    [anon_sym_LBRACK] = ACTIONS(12359),
    [aux_sym_basic_type_token6] = ACTIONS(12361),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12359),
    [aux_sym_addafter_modification_token1] = ACTIONS(12359),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12359),
    [aux_sym_modify_modification_token1] = ACTIONS(12359),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12359),
    [aux_sym_movelast_modification_token1] = ACTIONS(12359),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12359),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12359),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12359),
    [anon_sym_POUNDif] = ACTIONS(12359),
    [anon_sym_POUNDIF] = ACTIONS(12359),
    [anon_sym_POUNDIf] = ACTIONS(12359),
    [anon_sym_POUNDelif] = ACTIONS(12359),
    [anon_sym_POUNDELIF] = ACTIONS(12359),
    [anon_sym_POUNDElif] = ACTIONS(12359),
    [anon_sym_POUNDelse] = ACTIONS(12359),
    [anon_sym_POUNDELSE] = ACTIONS(12359),
    [anon_sym_POUNDElse] = ACTIONS(12359),
    [anon_sym_POUNDelse2] = ACTIONS(12359),
    [anon_sym_POUNDELSE2] = ACTIONS(12359),
    [anon_sym_POUNDElse2] = ACTIONS(12359),
    [anon_sym_POUNDendif] = ACTIONS(12359),
    [anon_sym_POUNDENDIF] = ACTIONS(12359),
    [anon_sym_POUNDEndif] = ACTIONS(12359),
    [anon_sym_POUNDendif2] = ACTIONS(12359),
    [anon_sym_POUNDENDIF2] = ACTIONS(12359),
    [anon_sym_POUNDEndif2] = ACTIONS(12359),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12359),
    [sym_trigger_keyword] = ACTIONS(12359),
    [sym_var_keyword] = ACTIONS(12359),
    [sym_local_keyword] = ACTIONS(12359),
    [sym_internal_keyword] = ACTIONS(12359),
    [sym_protected_keyword] = ACTIONS(12359),
    [sym_event_keyword] = ACTIONS(12359),
    [sym_fields_keyword] = ACTIONS(12359),
    [sym_keys_keyword] = ACTIONS(12359),
    [sym_fieldgroups_keyword] = ACTIONS(12359),
    [sym_actions_keyword] = ACTIONS(12359),
    [sym_layout_keyword] = ACTIONS(12359),
    [sym_area_keyword] = ACTIONS(12359),
    [sym_group_keyword] = ACTIONS(12359),
    [sym_repeater_keyword] = ACTIONS(12359),
    [sym_cuegroup_keyword] = ACTIONS(12359),
    [sym_fixed_keyword] = ACTIONS(12359),
    [sym_grid_keyword] = ACTIONS(12359),
    [sym_part_keyword] = ACTIONS(12359),
    [sym_systempart_keyword] = ACTIONS(12359),
    [sym_usercontrol_keyword] = ACTIONS(12359),
    [sym_dataset_keyword] = ACTIONS(12359),
    [sym_elements_keyword] = ACTIONS(12359),
    [sym_dataitem_keyword] = ACTIONS(12359),
    [sym_column_keyword] = ACTIONS(12359),
    [sym_filter_keyword] = ACTIONS(12359),
    [sym_labels_keyword] = ACTIONS(12359),
    [sym_rendering_keyword] = ACTIONS(12359),
    [sym_requestpage_keyword] = ACTIONS(12359),
    [sym_schema_keyword] = ACTIONS(12359),
    [sym_views_keyword] = ACTIONS(12359),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12359),
    [sym_preproc_open] = ACTIONS(12359),
    [sym_preproc_close] = ACTIONS(12359),
  },
  [STATE(5035)] = {
    [anon_sym_SEMI] = ACTIONS(12355),
    [aux_sym_where_condition_token1] = ACTIONS(12357),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12355),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12355),
    [anon_sym_LBRACK] = ACTIONS(12355),
    [aux_sym_basic_type_token6] = ACTIONS(12357),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12355),
    [aux_sym_addafter_modification_token1] = ACTIONS(12355),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12355),
    [aux_sym_modify_modification_token1] = ACTIONS(12355),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12355),
    [aux_sym_movelast_modification_token1] = ACTIONS(12355),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12355),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12355),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12355),
    [anon_sym_POUNDif] = ACTIONS(12355),
    [anon_sym_POUNDIF] = ACTIONS(12355),
    [anon_sym_POUNDIf] = ACTIONS(12355),
    [anon_sym_POUNDelif] = ACTIONS(12355),
    [anon_sym_POUNDELIF] = ACTIONS(12355),
    [anon_sym_POUNDElif] = ACTIONS(12355),
    [anon_sym_POUNDelse] = ACTIONS(12355),
    [anon_sym_POUNDELSE] = ACTIONS(12355),
    [anon_sym_POUNDElse] = ACTIONS(12355),
    [anon_sym_POUNDelse2] = ACTIONS(12355),
    [anon_sym_POUNDELSE2] = ACTIONS(12355),
    [anon_sym_POUNDElse2] = ACTIONS(12355),
    [anon_sym_POUNDendif] = ACTIONS(12355),
    [anon_sym_POUNDENDIF] = ACTIONS(12355),
    [anon_sym_POUNDEndif] = ACTIONS(12355),
    [anon_sym_POUNDendif2] = ACTIONS(12355),
    [anon_sym_POUNDENDIF2] = ACTIONS(12355),
    [anon_sym_POUNDEndif2] = ACTIONS(12355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12355),
    [sym_trigger_keyword] = ACTIONS(12355),
    [sym_var_keyword] = ACTIONS(12355),
    [sym_local_keyword] = ACTIONS(12355),
    [sym_internal_keyword] = ACTIONS(12355),
    [sym_protected_keyword] = ACTIONS(12355),
    [sym_event_keyword] = ACTIONS(12355),
    [sym_fields_keyword] = ACTIONS(12355),
    [sym_keys_keyword] = ACTIONS(12355),
    [sym_fieldgroups_keyword] = ACTIONS(12355),
    [sym_actions_keyword] = ACTIONS(12355),
    [sym_layout_keyword] = ACTIONS(12355),
    [sym_area_keyword] = ACTIONS(12355),
    [sym_group_keyword] = ACTIONS(12355),
    [sym_repeater_keyword] = ACTIONS(12355),
    [sym_cuegroup_keyword] = ACTIONS(12355),
    [sym_fixed_keyword] = ACTIONS(12355),
    [sym_grid_keyword] = ACTIONS(12355),
    [sym_part_keyword] = ACTIONS(12355),
    [sym_systempart_keyword] = ACTIONS(12355),
    [sym_usercontrol_keyword] = ACTIONS(12355),
    [sym_dataset_keyword] = ACTIONS(12355),
    [sym_elements_keyword] = ACTIONS(12355),
    [sym_dataitem_keyword] = ACTIONS(12355),
    [sym_column_keyword] = ACTIONS(12355),
    [sym_filter_keyword] = ACTIONS(12355),
    [sym_labels_keyword] = ACTIONS(12355),
    [sym_rendering_keyword] = ACTIONS(12355),
    [sym_requestpage_keyword] = ACTIONS(12355),
    [sym_schema_keyword] = ACTIONS(12355),
    [sym_views_keyword] = ACTIONS(12355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12355),
    [sym_preproc_open] = ACTIONS(12355),
    [sym_preproc_close] = ACTIONS(12355),
  },
  [STATE(5036)] = {
    [anon_sym_SEMI] = ACTIONS(12363),
    [aux_sym_where_condition_token1] = ACTIONS(12365),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12363),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12363),
    [anon_sym_LBRACK] = ACTIONS(12363),
    [aux_sym_basic_type_token6] = ACTIONS(12365),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12363),
    [aux_sym_addafter_modification_token1] = ACTIONS(12363),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12363),
    [aux_sym_modify_modification_token1] = ACTIONS(12363),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12363),
    [aux_sym_movelast_modification_token1] = ACTIONS(12363),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12363),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12363),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12363),
    [anon_sym_POUNDif] = ACTIONS(12363),
    [anon_sym_POUNDIF] = ACTIONS(12363),
    [anon_sym_POUNDIf] = ACTIONS(12363),
    [anon_sym_POUNDelif] = ACTIONS(12363),
    [anon_sym_POUNDELIF] = ACTIONS(12363),
    [anon_sym_POUNDElif] = ACTIONS(12363),
    [anon_sym_POUNDelse] = ACTIONS(12363),
    [anon_sym_POUNDELSE] = ACTIONS(12363),
    [anon_sym_POUNDElse] = ACTIONS(12363),
    [anon_sym_POUNDelse2] = ACTIONS(12363),
    [anon_sym_POUNDELSE2] = ACTIONS(12363),
    [anon_sym_POUNDElse2] = ACTIONS(12363),
    [anon_sym_POUNDendif] = ACTIONS(12363),
    [anon_sym_POUNDENDIF] = ACTIONS(12363),
    [anon_sym_POUNDEndif] = ACTIONS(12363),
    [anon_sym_POUNDendif2] = ACTIONS(12363),
    [anon_sym_POUNDENDIF2] = ACTIONS(12363),
    [anon_sym_POUNDEndif2] = ACTIONS(12363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12363),
    [sym_trigger_keyword] = ACTIONS(12363),
    [sym_var_keyword] = ACTIONS(12363),
    [sym_local_keyword] = ACTIONS(12363),
    [sym_internal_keyword] = ACTIONS(12363),
    [sym_protected_keyword] = ACTIONS(12363),
    [sym_event_keyword] = ACTIONS(12363),
    [sym_fields_keyword] = ACTIONS(12363),
    [sym_keys_keyword] = ACTIONS(12363),
    [sym_fieldgroups_keyword] = ACTIONS(12363),
    [sym_actions_keyword] = ACTIONS(12363),
    [sym_layout_keyword] = ACTIONS(12363),
    [sym_area_keyword] = ACTIONS(12363),
    [sym_group_keyword] = ACTIONS(12363),
    [sym_repeater_keyword] = ACTIONS(12363),
    [sym_cuegroup_keyword] = ACTIONS(12363),
    [sym_fixed_keyword] = ACTIONS(12363),
    [sym_grid_keyword] = ACTIONS(12363),
    [sym_part_keyword] = ACTIONS(12363),
    [sym_systempart_keyword] = ACTIONS(12363),
    [sym_usercontrol_keyword] = ACTIONS(12363),
    [sym_dataset_keyword] = ACTIONS(12363),
    [sym_elements_keyword] = ACTIONS(12363),
    [sym_dataitem_keyword] = ACTIONS(12363),
    [sym_column_keyword] = ACTIONS(12363),
    [sym_filter_keyword] = ACTIONS(12363),
    [sym_labels_keyword] = ACTIONS(12363),
    [sym_rendering_keyword] = ACTIONS(12363),
    [sym_requestpage_keyword] = ACTIONS(12363),
    [sym_schema_keyword] = ACTIONS(12363),
    [sym_views_keyword] = ACTIONS(12363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12363),
    [sym_preproc_open] = ACTIONS(12363),
    [sym_preproc_close] = ACTIONS(12363),
  },
  [STATE(5037)] = {
    [anon_sym_SEMI] = ACTIONS(12363),
    [aux_sym_where_condition_token1] = ACTIONS(12365),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12363),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12363),
    [anon_sym_LBRACK] = ACTIONS(12363),
    [aux_sym_basic_type_token6] = ACTIONS(12365),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12363),
    [aux_sym_addafter_modification_token1] = ACTIONS(12363),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12363),
    [aux_sym_modify_modification_token1] = ACTIONS(12363),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12363),
    [aux_sym_movelast_modification_token1] = ACTIONS(12363),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12363),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12363),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12363),
    [anon_sym_POUNDif] = ACTIONS(12363),
    [anon_sym_POUNDIF] = ACTIONS(12363),
    [anon_sym_POUNDIf] = ACTIONS(12363),
    [anon_sym_POUNDelif] = ACTIONS(12363),
    [anon_sym_POUNDELIF] = ACTIONS(12363),
    [anon_sym_POUNDElif] = ACTIONS(12363),
    [anon_sym_POUNDelse] = ACTIONS(12363),
    [anon_sym_POUNDELSE] = ACTIONS(12363),
    [anon_sym_POUNDElse] = ACTIONS(12363),
    [anon_sym_POUNDelse2] = ACTIONS(12363),
    [anon_sym_POUNDELSE2] = ACTIONS(12363),
    [anon_sym_POUNDElse2] = ACTIONS(12363),
    [anon_sym_POUNDendif] = ACTIONS(12363),
    [anon_sym_POUNDENDIF] = ACTIONS(12363),
    [anon_sym_POUNDEndif] = ACTIONS(12363),
    [anon_sym_POUNDendif2] = ACTIONS(12363),
    [anon_sym_POUNDENDIF2] = ACTIONS(12363),
    [anon_sym_POUNDEndif2] = ACTIONS(12363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12363),
    [sym_trigger_keyword] = ACTIONS(12363),
    [sym_var_keyword] = ACTIONS(12363),
    [sym_local_keyword] = ACTIONS(12363),
    [sym_internal_keyword] = ACTIONS(12363),
    [sym_protected_keyword] = ACTIONS(12363),
    [sym_event_keyword] = ACTIONS(12363),
    [sym_fields_keyword] = ACTIONS(12363),
    [sym_keys_keyword] = ACTIONS(12363),
    [sym_fieldgroups_keyword] = ACTIONS(12363),
    [sym_actions_keyword] = ACTIONS(12363),
    [sym_layout_keyword] = ACTIONS(12363),
    [sym_area_keyword] = ACTIONS(12363),
    [sym_group_keyword] = ACTIONS(12363),
    [sym_repeater_keyword] = ACTIONS(12363),
    [sym_cuegroup_keyword] = ACTIONS(12363),
    [sym_fixed_keyword] = ACTIONS(12363),
    [sym_grid_keyword] = ACTIONS(12363),
    [sym_part_keyword] = ACTIONS(12363),
    [sym_systempart_keyword] = ACTIONS(12363),
    [sym_usercontrol_keyword] = ACTIONS(12363),
    [sym_dataset_keyword] = ACTIONS(12363),
    [sym_elements_keyword] = ACTIONS(12363),
    [sym_dataitem_keyword] = ACTIONS(12363),
    [sym_column_keyword] = ACTIONS(12363),
    [sym_filter_keyword] = ACTIONS(12363),
    [sym_labels_keyword] = ACTIONS(12363),
    [sym_rendering_keyword] = ACTIONS(12363),
    [sym_requestpage_keyword] = ACTIONS(12363),
    [sym_schema_keyword] = ACTIONS(12363),
    [sym_views_keyword] = ACTIONS(12363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12363),
    [sym_preproc_open] = ACTIONS(12363),
    [sym_preproc_close] = ACTIONS(12363),
  },
  [STATE(5038)] = {
    [anon_sym_SEMI] = ACTIONS(12367),
    [aux_sym_where_condition_token1] = ACTIONS(12369),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12371),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12371),
    [anon_sym_LBRACK] = ACTIONS(12371),
    [aux_sym_basic_type_token6] = ACTIONS(12369),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12371),
    [aux_sym_addafter_modification_token1] = ACTIONS(12371),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12371),
    [aux_sym_modify_modification_token1] = ACTIONS(12371),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12371),
    [aux_sym_movelast_modification_token1] = ACTIONS(12371),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12371),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12371),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12371),
    [anon_sym_POUNDif] = ACTIONS(12371),
    [anon_sym_POUNDIF] = ACTIONS(12371),
    [anon_sym_POUNDIf] = ACTIONS(12371),
    [anon_sym_POUNDelif] = ACTIONS(12371),
    [anon_sym_POUNDELIF] = ACTIONS(12371),
    [anon_sym_POUNDElif] = ACTIONS(12371),
    [anon_sym_POUNDelse] = ACTIONS(12371),
    [anon_sym_POUNDELSE] = ACTIONS(12371),
    [anon_sym_POUNDElse] = ACTIONS(12371),
    [anon_sym_POUNDelse2] = ACTIONS(12371),
    [anon_sym_POUNDELSE2] = ACTIONS(12371),
    [anon_sym_POUNDElse2] = ACTIONS(12371),
    [anon_sym_POUNDendif] = ACTIONS(12371),
    [anon_sym_POUNDENDIF] = ACTIONS(12371),
    [anon_sym_POUNDEndif] = ACTIONS(12371),
    [anon_sym_POUNDendif2] = ACTIONS(12371),
    [anon_sym_POUNDENDIF2] = ACTIONS(12371),
    [anon_sym_POUNDEndif2] = ACTIONS(12371),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12371),
    [sym_trigger_keyword] = ACTIONS(12371),
    [sym_var_keyword] = ACTIONS(12371),
    [sym_local_keyword] = ACTIONS(12371),
    [sym_internal_keyword] = ACTIONS(12371),
    [sym_protected_keyword] = ACTIONS(12371),
    [sym_event_keyword] = ACTIONS(12371),
    [sym_fields_keyword] = ACTIONS(12371),
    [sym_keys_keyword] = ACTIONS(12371),
    [sym_fieldgroups_keyword] = ACTIONS(12371),
    [sym_actions_keyword] = ACTIONS(12371),
    [sym_layout_keyword] = ACTIONS(12371),
    [sym_area_keyword] = ACTIONS(12371),
    [sym_group_keyword] = ACTIONS(12371),
    [sym_repeater_keyword] = ACTIONS(12371),
    [sym_cuegroup_keyword] = ACTIONS(12371),
    [sym_fixed_keyword] = ACTIONS(12371),
    [sym_grid_keyword] = ACTIONS(12371),
    [sym_part_keyword] = ACTIONS(12371),
    [sym_systempart_keyword] = ACTIONS(12371),
    [sym_usercontrol_keyword] = ACTIONS(12371),
    [sym_dataset_keyword] = ACTIONS(12371),
    [sym_elements_keyword] = ACTIONS(12371),
    [sym_dataitem_keyword] = ACTIONS(12371),
    [sym_column_keyword] = ACTIONS(12371),
    [sym_filter_keyword] = ACTIONS(12371),
    [sym_labels_keyword] = ACTIONS(12371),
    [sym_rendering_keyword] = ACTIONS(12371),
    [sym_requestpage_keyword] = ACTIONS(12371),
    [sym_schema_keyword] = ACTIONS(12371),
    [sym_views_keyword] = ACTIONS(12371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12371),
    [sym_preproc_open] = ACTIONS(12371),
    [sym_preproc_close] = ACTIONS(12371),
  },
  [STATE(5039)] = {
    [anon_sym_SEMI] = ACTIONS(12373),
    [aux_sym_where_condition_token1] = ACTIONS(12369),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12371),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12371),
    [anon_sym_LBRACK] = ACTIONS(12371),
    [aux_sym_basic_type_token6] = ACTIONS(12369),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12371),
    [aux_sym_addafter_modification_token1] = ACTIONS(12371),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12371),
    [aux_sym_modify_modification_token1] = ACTIONS(12371),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12371),
    [aux_sym_movelast_modification_token1] = ACTIONS(12371),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12371),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12371),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12371),
    [anon_sym_POUNDif] = ACTIONS(12371),
    [anon_sym_POUNDIF] = ACTIONS(12371),
    [anon_sym_POUNDIf] = ACTIONS(12371),
    [anon_sym_POUNDelif] = ACTIONS(12371),
    [anon_sym_POUNDELIF] = ACTIONS(12371),
    [anon_sym_POUNDElif] = ACTIONS(12371),
    [anon_sym_POUNDelse] = ACTIONS(12371),
    [anon_sym_POUNDELSE] = ACTIONS(12371),
    [anon_sym_POUNDElse] = ACTIONS(12371),
    [anon_sym_POUNDelse2] = ACTIONS(12371),
    [anon_sym_POUNDELSE2] = ACTIONS(12371),
    [anon_sym_POUNDElse2] = ACTIONS(12371),
    [anon_sym_POUNDendif] = ACTIONS(12371),
    [anon_sym_POUNDENDIF] = ACTIONS(12371),
    [anon_sym_POUNDEndif] = ACTIONS(12371),
    [anon_sym_POUNDendif2] = ACTIONS(12371),
    [anon_sym_POUNDENDIF2] = ACTIONS(12371),
    [anon_sym_POUNDEndif2] = ACTIONS(12371),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12371),
    [sym_trigger_keyword] = ACTIONS(12371),
    [sym_var_keyword] = ACTIONS(12371),
    [sym_local_keyword] = ACTIONS(12371),
    [sym_internal_keyword] = ACTIONS(12371),
    [sym_protected_keyword] = ACTIONS(12371),
    [sym_event_keyword] = ACTIONS(12371),
    [sym_fields_keyword] = ACTIONS(12371),
    [sym_keys_keyword] = ACTIONS(12371),
    [sym_fieldgroups_keyword] = ACTIONS(12371),
    [sym_actions_keyword] = ACTIONS(12371),
    [sym_layout_keyword] = ACTIONS(12371),
    [sym_area_keyword] = ACTIONS(12371),
    [sym_group_keyword] = ACTIONS(12371),
    [sym_repeater_keyword] = ACTIONS(12371),
    [sym_cuegroup_keyword] = ACTIONS(12371),
    [sym_fixed_keyword] = ACTIONS(12371),
    [sym_grid_keyword] = ACTIONS(12371),
    [sym_part_keyword] = ACTIONS(12371),
    [sym_systempart_keyword] = ACTIONS(12371),
    [sym_usercontrol_keyword] = ACTIONS(12371),
    [sym_dataset_keyword] = ACTIONS(12371),
    [sym_elements_keyword] = ACTIONS(12371),
    [sym_dataitem_keyword] = ACTIONS(12371),
    [sym_column_keyword] = ACTIONS(12371),
    [sym_filter_keyword] = ACTIONS(12371),
    [sym_labels_keyword] = ACTIONS(12371),
    [sym_rendering_keyword] = ACTIONS(12371),
    [sym_requestpage_keyword] = ACTIONS(12371),
    [sym_schema_keyword] = ACTIONS(12371),
    [sym_views_keyword] = ACTIONS(12371),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12371),
    [sym_preproc_open] = ACTIONS(12371),
    [sym_preproc_close] = ACTIONS(12371),
  },
  [STATE(5040)] = {
    [anon_sym_SEMI] = ACTIONS(12375),
    [aux_sym_where_condition_token1] = ACTIONS(12357),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12355),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12355),
    [anon_sym_LBRACK] = ACTIONS(12355),
    [aux_sym_basic_type_token6] = ACTIONS(12357),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12355),
    [aux_sym_addafter_modification_token1] = ACTIONS(12355),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12355),
    [aux_sym_modify_modification_token1] = ACTIONS(12355),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12355),
    [aux_sym_movelast_modification_token1] = ACTIONS(12355),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12355),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12355),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12355),
    [anon_sym_POUNDif] = ACTIONS(12355),
    [anon_sym_POUNDIF] = ACTIONS(12355),
    [anon_sym_POUNDIf] = ACTIONS(12355),
    [anon_sym_POUNDelif] = ACTIONS(12355),
    [anon_sym_POUNDELIF] = ACTIONS(12355),
    [anon_sym_POUNDElif] = ACTIONS(12355),
    [anon_sym_POUNDelse] = ACTIONS(12355),
    [anon_sym_POUNDELSE] = ACTIONS(12355),
    [anon_sym_POUNDElse] = ACTIONS(12355),
    [anon_sym_POUNDelse2] = ACTIONS(12355),
    [anon_sym_POUNDELSE2] = ACTIONS(12355),
    [anon_sym_POUNDElse2] = ACTIONS(12355),
    [anon_sym_POUNDendif] = ACTIONS(12355),
    [anon_sym_POUNDENDIF] = ACTIONS(12355),
    [anon_sym_POUNDEndif] = ACTIONS(12355),
    [anon_sym_POUNDendif2] = ACTIONS(12355),
    [anon_sym_POUNDENDIF2] = ACTIONS(12355),
    [anon_sym_POUNDEndif2] = ACTIONS(12355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12355),
    [sym_trigger_keyword] = ACTIONS(12355),
    [sym_var_keyword] = ACTIONS(12355),
    [sym_local_keyword] = ACTIONS(12355),
    [sym_internal_keyword] = ACTIONS(12355),
    [sym_protected_keyword] = ACTIONS(12355),
    [sym_event_keyword] = ACTIONS(12355),
    [sym_fields_keyword] = ACTIONS(12355),
    [sym_keys_keyword] = ACTIONS(12355),
    [sym_fieldgroups_keyword] = ACTIONS(12355),
    [sym_actions_keyword] = ACTIONS(12355),
    [sym_layout_keyword] = ACTIONS(12355),
    [sym_area_keyword] = ACTIONS(12355),
    [sym_group_keyword] = ACTIONS(12355),
    [sym_repeater_keyword] = ACTIONS(12355),
    [sym_cuegroup_keyword] = ACTIONS(12355),
    [sym_fixed_keyword] = ACTIONS(12355),
    [sym_grid_keyword] = ACTIONS(12355),
    [sym_part_keyword] = ACTIONS(12355),
    [sym_systempart_keyword] = ACTIONS(12355),
    [sym_usercontrol_keyword] = ACTIONS(12355),
    [sym_dataset_keyword] = ACTIONS(12355),
    [sym_elements_keyword] = ACTIONS(12355),
    [sym_dataitem_keyword] = ACTIONS(12355),
    [sym_column_keyword] = ACTIONS(12355),
    [sym_filter_keyword] = ACTIONS(12355),
    [sym_labels_keyword] = ACTIONS(12355),
    [sym_rendering_keyword] = ACTIONS(12355),
    [sym_requestpage_keyword] = ACTIONS(12355),
    [sym_schema_keyword] = ACTIONS(12355),
    [sym_views_keyword] = ACTIONS(12355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12355),
    [sym_preproc_open] = ACTIONS(12355),
    [sym_preproc_close] = ACTIONS(12355),
  },
  [STATE(5041)] = {
    [anon_sym_SEMI] = ACTIONS(12377),
    [aux_sym_where_condition_token1] = ACTIONS(12357),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12355),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12355),
    [anon_sym_LBRACK] = ACTIONS(12355),
    [aux_sym_basic_type_token6] = ACTIONS(12357),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12355),
    [aux_sym_addafter_modification_token1] = ACTIONS(12355),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12355),
    [aux_sym_modify_modification_token1] = ACTIONS(12355),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12355),
    [aux_sym_movelast_modification_token1] = ACTIONS(12355),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12355),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12355),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12355),
    [anon_sym_POUNDif] = ACTIONS(12355),
    [anon_sym_POUNDIF] = ACTIONS(12355),
    [anon_sym_POUNDIf] = ACTIONS(12355),
    [anon_sym_POUNDelif] = ACTIONS(12355),
    [anon_sym_POUNDELIF] = ACTIONS(12355),
    [anon_sym_POUNDElif] = ACTIONS(12355),
    [anon_sym_POUNDelse] = ACTIONS(12355),
    [anon_sym_POUNDELSE] = ACTIONS(12355),
    [anon_sym_POUNDElse] = ACTIONS(12355),
    [anon_sym_POUNDelse2] = ACTIONS(12355),
    [anon_sym_POUNDELSE2] = ACTIONS(12355),
    [anon_sym_POUNDElse2] = ACTIONS(12355),
    [anon_sym_POUNDendif] = ACTIONS(12355),
    [anon_sym_POUNDENDIF] = ACTIONS(12355),
    [anon_sym_POUNDEndif] = ACTIONS(12355),
    [anon_sym_POUNDendif2] = ACTIONS(12355),
    [anon_sym_POUNDENDIF2] = ACTIONS(12355),
    [anon_sym_POUNDEndif2] = ACTIONS(12355),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12355),
    [sym_trigger_keyword] = ACTIONS(12355),
    [sym_var_keyword] = ACTIONS(12355),
    [sym_local_keyword] = ACTIONS(12355),
    [sym_internal_keyword] = ACTIONS(12355),
    [sym_protected_keyword] = ACTIONS(12355),
    [sym_event_keyword] = ACTIONS(12355),
    [sym_fields_keyword] = ACTIONS(12355),
    [sym_keys_keyword] = ACTIONS(12355),
    [sym_fieldgroups_keyword] = ACTIONS(12355),
    [sym_actions_keyword] = ACTIONS(12355),
    [sym_layout_keyword] = ACTIONS(12355),
    [sym_area_keyword] = ACTIONS(12355),
    [sym_group_keyword] = ACTIONS(12355),
    [sym_repeater_keyword] = ACTIONS(12355),
    [sym_cuegroup_keyword] = ACTIONS(12355),
    [sym_fixed_keyword] = ACTIONS(12355),
    [sym_grid_keyword] = ACTIONS(12355),
    [sym_part_keyword] = ACTIONS(12355),
    [sym_systempart_keyword] = ACTIONS(12355),
    [sym_usercontrol_keyword] = ACTIONS(12355),
    [sym_dataset_keyword] = ACTIONS(12355),
    [sym_elements_keyword] = ACTIONS(12355),
    [sym_dataitem_keyword] = ACTIONS(12355),
    [sym_column_keyword] = ACTIONS(12355),
    [sym_filter_keyword] = ACTIONS(12355),
    [sym_labels_keyword] = ACTIONS(12355),
    [sym_rendering_keyword] = ACTIONS(12355),
    [sym_requestpage_keyword] = ACTIONS(12355),
    [sym_schema_keyword] = ACTIONS(12355),
    [sym_views_keyword] = ACTIONS(12355),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12355),
    [sym_preproc_open] = ACTIONS(12355),
    [sym_preproc_close] = ACTIONS(12355),
  },
  [STATE(5042)] = {
    [anon_sym_SEMI] = ACTIONS(12363),
    [aux_sym_where_condition_token1] = ACTIONS(12365),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12363),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12363),
    [anon_sym_LBRACK] = ACTIONS(12363),
    [aux_sym_basic_type_token6] = ACTIONS(12365),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12363),
    [aux_sym_addafter_modification_token1] = ACTIONS(12363),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12363),
    [aux_sym_modify_modification_token1] = ACTIONS(12363),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12363),
    [aux_sym_movelast_modification_token1] = ACTIONS(12363),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12363),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12363),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12363),
    [anon_sym_POUNDif] = ACTIONS(12363),
    [anon_sym_POUNDIF] = ACTIONS(12363),
    [anon_sym_POUNDIf] = ACTIONS(12363),
    [anon_sym_POUNDelif] = ACTIONS(12363),
    [anon_sym_POUNDELIF] = ACTIONS(12363),
    [anon_sym_POUNDElif] = ACTIONS(12363),
    [anon_sym_POUNDelse] = ACTIONS(12363),
    [anon_sym_POUNDELSE] = ACTIONS(12363),
    [anon_sym_POUNDElse] = ACTIONS(12363),
    [anon_sym_POUNDelse2] = ACTIONS(12363),
    [anon_sym_POUNDELSE2] = ACTIONS(12363),
    [anon_sym_POUNDElse2] = ACTIONS(12363),
    [anon_sym_POUNDendif] = ACTIONS(12363),
    [anon_sym_POUNDENDIF] = ACTIONS(12363),
    [anon_sym_POUNDEndif] = ACTIONS(12363),
    [anon_sym_POUNDendif2] = ACTIONS(12363),
    [anon_sym_POUNDENDIF2] = ACTIONS(12363),
    [anon_sym_POUNDEndif2] = ACTIONS(12363),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12363),
    [sym_trigger_keyword] = ACTIONS(12363),
    [sym_var_keyword] = ACTIONS(12363),
    [sym_local_keyword] = ACTIONS(12363),
    [sym_internal_keyword] = ACTIONS(12363),
    [sym_protected_keyword] = ACTIONS(12363),
    [sym_event_keyword] = ACTIONS(12363),
    [sym_fields_keyword] = ACTIONS(12363),
    [sym_keys_keyword] = ACTIONS(12363),
    [sym_fieldgroups_keyword] = ACTIONS(12363),
    [sym_actions_keyword] = ACTIONS(12363),
    [sym_layout_keyword] = ACTIONS(12363),
    [sym_area_keyword] = ACTIONS(12363),
    [sym_group_keyword] = ACTIONS(12363),
    [sym_repeater_keyword] = ACTIONS(12363),
    [sym_cuegroup_keyword] = ACTIONS(12363),
    [sym_fixed_keyword] = ACTIONS(12363),
    [sym_grid_keyword] = ACTIONS(12363),
    [sym_part_keyword] = ACTIONS(12363),
    [sym_systempart_keyword] = ACTIONS(12363),
    [sym_usercontrol_keyword] = ACTIONS(12363),
    [sym_dataset_keyword] = ACTIONS(12363),
    [sym_elements_keyword] = ACTIONS(12363),
    [sym_dataitem_keyword] = ACTIONS(12363),
    [sym_column_keyword] = ACTIONS(12363),
    [sym_filter_keyword] = ACTIONS(12363),
    [sym_labels_keyword] = ACTIONS(12363),
    [sym_rendering_keyword] = ACTIONS(12363),
    [sym_requestpage_keyword] = ACTIONS(12363),
    [sym_schema_keyword] = ACTIONS(12363),
    [sym_views_keyword] = ACTIONS(12363),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12363),
    [sym_preproc_open] = ACTIONS(12363),
    [sym_preproc_close] = ACTIONS(12363),
  },
  [STATE(5043)] = {
    [anon_sym_SEMI] = ACTIONS(12379),
    [aux_sym_where_condition_token1] = ACTIONS(12381),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12383),
    [anon_sym_LBRACK] = ACTIONS(12383),
    [aux_sym_basic_type_token6] = ACTIONS(12381),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12383),
    [aux_sym_addafter_modification_token1] = ACTIONS(12383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12383),
    [aux_sym_modify_modification_token1] = ACTIONS(12383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12383),
    [aux_sym_movelast_modification_token1] = ACTIONS(12383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12383),
    [anon_sym_POUNDif] = ACTIONS(12383),
    [anon_sym_POUNDIF] = ACTIONS(12383),
    [anon_sym_POUNDIf] = ACTIONS(12383),
    [anon_sym_POUNDelif] = ACTIONS(12383),
    [anon_sym_POUNDELIF] = ACTIONS(12383),
    [anon_sym_POUNDElif] = ACTIONS(12383),
    [anon_sym_POUNDelse] = ACTIONS(12383),
    [anon_sym_POUNDELSE] = ACTIONS(12383),
    [anon_sym_POUNDElse] = ACTIONS(12383),
    [anon_sym_POUNDelse2] = ACTIONS(12383),
    [anon_sym_POUNDELSE2] = ACTIONS(12383),
    [anon_sym_POUNDElse2] = ACTIONS(12383),
    [anon_sym_POUNDendif] = ACTIONS(12383),
    [anon_sym_POUNDENDIF] = ACTIONS(12383),
    [anon_sym_POUNDEndif] = ACTIONS(12383),
    [anon_sym_POUNDendif2] = ACTIONS(12383),
    [anon_sym_POUNDENDIF2] = ACTIONS(12383),
    [anon_sym_POUNDEndif2] = ACTIONS(12383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12383),
    [sym_trigger_keyword] = ACTIONS(12383),
    [sym_var_keyword] = ACTIONS(12383),
    [sym_local_keyword] = ACTIONS(12383),
    [sym_internal_keyword] = ACTIONS(12383),
    [sym_protected_keyword] = ACTIONS(12383),
    [sym_event_keyword] = ACTIONS(12383),
    [sym_fields_keyword] = ACTIONS(12383),
    [sym_keys_keyword] = ACTIONS(12383),
    [sym_fieldgroups_keyword] = ACTIONS(12383),
    [sym_actions_keyword] = ACTIONS(12383),
    [sym_layout_keyword] = ACTIONS(12383),
    [sym_area_keyword] = ACTIONS(12383),
    [sym_group_keyword] = ACTIONS(12383),
    [sym_repeater_keyword] = ACTIONS(12383),
    [sym_cuegroup_keyword] = ACTIONS(12383),
    [sym_fixed_keyword] = ACTIONS(12383),
    [sym_grid_keyword] = ACTIONS(12383),
    [sym_part_keyword] = ACTIONS(12383),
    [sym_systempart_keyword] = ACTIONS(12383),
    [sym_usercontrol_keyword] = ACTIONS(12383),
    [sym_dataset_keyword] = ACTIONS(12383),
    [sym_elements_keyword] = ACTIONS(12383),
    [sym_dataitem_keyword] = ACTIONS(12383),
    [sym_column_keyword] = ACTIONS(12383),
    [sym_filter_keyword] = ACTIONS(12383),
    [sym_labels_keyword] = ACTIONS(12383),
    [sym_rendering_keyword] = ACTIONS(12383),
    [sym_requestpage_keyword] = ACTIONS(12383),
    [sym_schema_keyword] = ACTIONS(12383),
    [sym_views_keyword] = ACTIONS(12383),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12383),
    [sym_preproc_open] = ACTIONS(12383),
    [sym_preproc_close] = ACTIONS(12383),
  },
  [STATE(5044)] = {
    [anon_sym_SEMI] = ACTIONS(12385),
    [aux_sym_where_condition_token1] = ACTIONS(12387),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12385),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12385),
    [anon_sym_LBRACK] = ACTIONS(12385),
    [aux_sym_basic_type_token6] = ACTIONS(12387),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12385),
    [aux_sym_addafter_modification_token1] = ACTIONS(12385),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12385),
    [aux_sym_modify_modification_token1] = ACTIONS(12385),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12385),
    [aux_sym_movelast_modification_token1] = ACTIONS(12385),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12385),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12385),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12385),
    [anon_sym_POUNDif] = ACTIONS(12385),
    [anon_sym_POUNDIF] = ACTIONS(12385),
    [anon_sym_POUNDIf] = ACTIONS(12385),
    [anon_sym_POUNDelif] = ACTIONS(12385),
    [anon_sym_POUNDELIF] = ACTIONS(12385),
    [anon_sym_POUNDElif] = ACTIONS(12385),
    [anon_sym_POUNDelse] = ACTIONS(12385),
    [anon_sym_POUNDELSE] = ACTIONS(12385),
    [anon_sym_POUNDElse] = ACTIONS(12385),
    [anon_sym_POUNDelse2] = ACTIONS(12385),
    [anon_sym_POUNDELSE2] = ACTIONS(12385),
    [anon_sym_POUNDElse2] = ACTIONS(12385),
    [anon_sym_POUNDendif] = ACTIONS(12385),
    [anon_sym_POUNDENDIF] = ACTIONS(12385),
    [anon_sym_POUNDEndif] = ACTIONS(12385),
    [anon_sym_POUNDendif2] = ACTIONS(12385),
    [anon_sym_POUNDENDIF2] = ACTIONS(12385),
    [anon_sym_POUNDEndif2] = ACTIONS(12385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12385),
    [sym_trigger_keyword] = ACTIONS(12385),
    [sym_var_keyword] = ACTIONS(12385),
    [sym_local_keyword] = ACTIONS(12385),
    [sym_internal_keyword] = ACTIONS(12385),
    [sym_protected_keyword] = ACTIONS(12385),
    [sym_event_keyword] = ACTIONS(12385),
    [sym_fields_keyword] = ACTIONS(12385),
    [sym_keys_keyword] = ACTIONS(12385),
    [sym_fieldgroups_keyword] = ACTIONS(12385),
    [sym_actions_keyword] = ACTIONS(12385),
    [sym_layout_keyword] = ACTIONS(12385),
    [sym_area_keyword] = ACTIONS(12385),
    [sym_group_keyword] = ACTIONS(12385),
    [sym_repeater_keyword] = ACTIONS(12385),
    [sym_cuegroup_keyword] = ACTIONS(12385),
    [sym_fixed_keyword] = ACTIONS(12385),
    [sym_grid_keyword] = ACTIONS(12385),
    [sym_part_keyword] = ACTIONS(12385),
    [sym_systempart_keyword] = ACTIONS(12385),
    [sym_usercontrol_keyword] = ACTIONS(12385),
    [sym_dataset_keyword] = ACTIONS(12385),
    [sym_elements_keyword] = ACTIONS(12385),
    [sym_dataitem_keyword] = ACTIONS(12385),
    [sym_column_keyword] = ACTIONS(12385),
    [sym_filter_keyword] = ACTIONS(12385),
    [sym_labels_keyword] = ACTIONS(12385),
    [sym_rendering_keyword] = ACTIONS(12385),
    [sym_requestpage_keyword] = ACTIONS(12385),
    [sym_schema_keyword] = ACTIONS(12385),
    [sym_views_keyword] = ACTIONS(12385),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12385),
    [sym_preproc_open] = ACTIONS(12385),
    [sym_preproc_close] = ACTIONS(12385),
  },
  [STATE(5045)] = {
    [anon_sym_SEMI] = ACTIONS(12389),
    [aux_sym_where_condition_token1] = ACTIONS(12381),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12383),
    [anon_sym_LBRACK] = ACTIONS(12383),
    [aux_sym_basic_type_token6] = ACTIONS(12381),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12383),
    [aux_sym_addafter_modification_token1] = ACTIONS(12383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12383),
    [aux_sym_modify_modification_token1] = ACTIONS(12383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12383),
    [aux_sym_movelast_modification_token1] = ACTIONS(12383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12383),
    [anon_sym_POUNDif] = ACTIONS(12383),
    [anon_sym_POUNDIF] = ACTIONS(12383),
    [anon_sym_POUNDIf] = ACTIONS(12383),
    [anon_sym_POUNDelif] = ACTIONS(12383),
    [anon_sym_POUNDELIF] = ACTIONS(12383),
    [anon_sym_POUNDElif] = ACTIONS(12383),
    [anon_sym_POUNDelse] = ACTIONS(12383),
    [anon_sym_POUNDELSE] = ACTIONS(12383),
    [anon_sym_POUNDElse] = ACTIONS(12383),
    [anon_sym_POUNDelse2] = ACTIONS(12383),
    [anon_sym_POUNDELSE2] = ACTIONS(12383),
    [anon_sym_POUNDElse2] = ACTIONS(12383),
    [anon_sym_POUNDendif] = ACTIONS(12383),
    [anon_sym_POUNDENDIF] = ACTIONS(12383),
    [anon_sym_POUNDEndif] = ACTIONS(12383),
    [anon_sym_POUNDendif2] = ACTIONS(12383),
    [anon_sym_POUNDENDIF2] = ACTIONS(12383),
    [anon_sym_POUNDEndif2] = ACTIONS(12383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12383),
    [sym_trigger_keyword] = ACTIONS(12383),
    [sym_var_keyword] = ACTIONS(12383),
    [sym_local_keyword] = ACTIONS(12383),
    [sym_internal_keyword] = ACTIONS(12383),
    [sym_protected_keyword] = ACTIONS(12383),
    [sym_event_keyword] = ACTIONS(12383),
    [sym_fields_keyword] = ACTIONS(12383),
    [sym_keys_keyword] = ACTIONS(12383),
    [sym_fieldgroups_keyword] = ACTIONS(12383),
    [sym_actions_keyword] = ACTIONS(12383),
    [sym_layout_keyword] = ACTIONS(12383),
    [sym_area_keyword] = ACTIONS(12383),
    [sym_group_keyword] = ACTIONS(12383),
    [sym_repeater_keyword] = ACTIONS(12383),
    [sym_cuegroup_keyword] = ACTIONS(12383),
    [sym_fixed_keyword] = ACTIONS(12383),
    [sym_grid_keyword] = ACTIONS(12383),
    [sym_part_keyword] = ACTIONS(12383),
    [sym_systempart_keyword] = ACTIONS(12383),
    [sym_usercontrol_keyword] = ACTIONS(12383),
    [sym_dataset_keyword] = ACTIONS(12383),
    [sym_elements_keyword] = ACTIONS(12383),
    [sym_dataitem_keyword] = ACTIONS(12383),
    [sym_column_keyword] = ACTIONS(12383),
    [sym_filter_keyword] = ACTIONS(12383),
    [sym_labels_keyword] = ACTIONS(12383),
    [sym_rendering_keyword] = ACTIONS(12383),
    [sym_requestpage_keyword] = ACTIONS(12383),
    [sym_schema_keyword] = ACTIONS(12383),
    [sym_views_keyword] = ACTIONS(12383),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12383),
    [sym_preproc_open] = ACTIONS(12383),
    [sym_preproc_close] = ACTIONS(12383),
  },
  [STATE(5046)] = {
    [anon_sym_SEMI] = ACTIONS(12391),
    [aux_sym_where_condition_token1] = ACTIONS(12329),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12327),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12327),
    [anon_sym_LBRACK] = ACTIONS(12327),
    [aux_sym_basic_type_token6] = ACTIONS(12329),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12327),
    [aux_sym_addafter_modification_token1] = ACTIONS(12327),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12327),
    [aux_sym_modify_modification_token1] = ACTIONS(12327),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12327),
    [aux_sym_movelast_modification_token1] = ACTIONS(12327),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12327),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12327),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12327),
    [anon_sym_POUNDif] = ACTIONS(12327),
    [anon_sym_POUNDIF] = ACTIONS(12327),
    [anon_sym_POUNDIf] = ACTIONS(12327),
    [anon_sym_POUNDelif] = ACTIONS(12327),
    [anon_sym_POUNDELIF] = ACTIONS(12327),
    [anon_sym_POUNDElif] = ACTIONS(12327),
    [anon_sym_POUNDelse] = ACTIONS(12327),
    [anon_sym_POUNDELSE] = ACTIONS(12327),
    [anon_sym_POUNDElse] = ACTIONS(12327),
    [anon_sym_POUNDelse2] = ACTIONS(12327),
    [anon_sym_POUNDELSE2] = ACTIONS(12327),
    [anon_sym_POUNDElse2] = ACTIONS(12327),
    [anon_sym_POUNDendif] = ACTIONS(12327),
    [anon_sym_POUNDENDIF] = ACTIONS(12327),
    [anon_sym_POUNDEndif] = ACTIONS(12327),
    [anon_sym_POUNDendif2] = ACTIONS(12327),
    [anon_sym_POUNDENDIF2] = ACTIONS(12327),
    [anon_sym_POUNDEndif2] = ACTIONS(12327),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12327),
    [sym_trigger_keyword] = ACTIONS(12327),
    [sym_var_keyword] = ACTIONS(12327),
    [sym_local_keyword] = ACTIONS(12327),
    [sym_internal_keyword] = ACTIONS(12327),
    [sym_protected_keyword] = ACTIONS(12327),
    [sym_event_keyword] = ACTIONS(12327),
    [sym_fields_keyword] = ACTIONS(12327),
    [sym_keys_keyword] = ACTIONS(12327),
    [sym_fieldgroups_keyword] = ACTIONS(12327),
    [sym_actions_keyword] = ACTIONS(12327),
    [sym_layout_keyword] = ACTIONS(12327),
    [sym_area_keyword] = ACTIONS(12327),
    [sym_group_keyword] = ACTIONS(12327),
    [sym_repeater_keyword] = ACTIONS(12327),
    [sym_cuegroup_keyword] = ACTIONS(12327),
    [sym_fixed_keyword] = ACTIONS(12327),
    [sym_grid_keyword] = ACTIONS(12327),
    [sym_part_keyword] = ACTIONS(12327),
    [sym_systempart_keyword] = ACTIONS(12327),
    [sym_usercontrol_keyword] = ACTIONS(12327),
    [sym_dataset_keyword] = ACTIONS(12327),
    [sym_elements_keyword] = ACTIONS(12327),
    [sym_dataitem_keyword] = ACTIONS(12327),
    [sym_column_keyword] = ACTIONS(12327),
    [sym_filter_keyword] = ACTIONS(12327),
    [sym_labels_keyword] = ACTIONS(12327),
    [sym_rendering_keyword] = ACTIONS(12327),
    [sym_requestpage_keyword] = ACTIONS(12327),
    [sym_schema_keyword] = ACTIONS(12327),
    [sym_views_keyword] = ACTIONS(12327),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12327),
    [sym_preproc_open] = ACTIONS(12327),
    [sym_preproc_close] = ACTIONS(12327),
  },
  [STATE(5047)] = {
    [anon_sym_SEMI] = ACTIONS(12393),
    [aux_sym_where_condition_token1] = ACTIONS(12395),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12397),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12397),
    [anon_sym_LBRACK] = ACTIONS(12397),
    [aux_sym_basic_type_token6] = ACTIONS(12395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12397),
    [aux_sym_addafter_modification_token1] = ACTIONS(12397),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12397),
    [aux_sym_modify_modification_token1] = ACTIONS(12397),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12397),
    [aux_sym_movelast_modification_token1] = ACTIONS(12397),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12397),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12397),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12397),
    [anon_sym_POUNDif] = ACTIONS(12397),
    [anon_sym_POUNDIF] = ACTIONS(12397),
    [anon_sym_POUNDIf] = ACTIONS(12397),
    [anon_sym_POUNDelif] = ACTIONS(12397),
    [anon_sym_POUNDELIF] = ACTIONS(12397),
    [anon_sym_POUNDElif] = ACTIONS(12397),
    [anon_sym_POUNDelse] = ACTIONS(12397),
    [anon_sym_POUNDELSE] = ACTIONS(12397),
    [anon_sym_POUNDElse] = ACTIONS(12397),
    [anon_sym_POUNDelse2] = ACTIONS(12397),
    [anon_sym_POUNDELSE2] = ACTIONS(12397),
    [anon_sym_POUNDElse2] = ACTIONS(12397),
    [anon_sym_POUNDendif] = ACTIONS(12397),
    [anon_sym_POUNDENDIF] = ACTIONS(12397),
    [anon_sym_POUNDEndif] = ACTIONS(12397),
    [anon_sym_POUNDendif2] = ACTIONS(12397),
    [anon_sym_POUNDENDIF2] = ACTIONS(12397),
    [anon_sym_POUNDEndif2] = ACTIONS(12397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12397),
    [sym_trigger_keyword] = ACTIONS(12397),
    [sym_var_keyword] = ACTIONS(12397),
    [sym_local_keyword] = ACTIONS(12397),
    [sym_internal_keyword] = ACTIONS(12397),
    [sym_protected_keyword] = ACTIONS(12397),
    [sym_event_keyword] = ACTIONS(12397),
    [sym_fields_keyword] = ACTIONS(12397),
    [sym_keys_keyword] = ACTIONS(12397),
    [sym_fieldgroups_keyword] = ACTIONS(12397),
    [sym_actions_keyword] = ACTIONS(12397),
    [sym_layout_keyword] = ACTIONS(12397),
    [sym_area_keyword] = ACTIONS(12397),
    [sym_group_keyword] = ACTIONS(12397),
    [sym_repeater_keyword] = ACTIONS(12397),
    [sym_cuegroup_keyword] = ACTIONS(12397),
    [sym_fixed_keyword] = ACTIONS(12397),
    [sym_grid_keyword] = ACTIONS(12397),
    [sym_part_keyword] = ACTIONS(12397),
    [sym_systempart_keyword] = ACTIONS(12397),
    [sym_usercontrol_keyword] = ACTIONS(12397),
    [sym_dataset_keyword] = ACTIONS(12397),
    [sym_elements_keyword] = ACTIONS(12397),
    [sym_dataitem_keyword] = ACTIONS(12397),
    [sym_column_keyword] = ACTIONS(12397),
    [sym_filter_keyword] = ACTIONS(12397),
    [sym_labels_keyword] = ACTIONS(12397),
    [sym_rendering_keyword] = ACTIONS(12397),
    [sym_requestpage_keyword] = ACTIONS(12397),
    [sym_schema_keyword] = ACTIONS(12397),
    [sym_views_keyword] = ACTIONS(12397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12397),
    [sym_preproc_open] = ACTIONS(12397),
    [sym_preproc_close] = ACTIONS(12397),
  },
  [STATE(5048)] = {
    [anon_sym_SEMI] = ACTIONS(12385),
    [aux_sym_where_condition_token1] = ACTIONS(12387),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12385),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12385),
    [anon_sym_LBRACK] = ACTIONS(12385),
    [aux_sym_basic_type_token6] = ACTIONS(12387),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12385),
    [aux_sym_addafter_modification_token1] = ACTIONS(12385),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12385),
    [aux_sym_modify_modification_token1] = ACTIONS(12385),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12385),
    [aux_sym_movelast_modification_token1] = ACTIONS(12385),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12385),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12385),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12385),
    [anon_sym_POUNDif] = ACTIONS(12385),
    [anon_sym_POUNDIF] = ACTIONS(12385),
    [anon_sym_POUNDIf] = ACTIONS(12385),
    [anon_sym_POUNDelif] = ACTIONS(12385),
    [anon_sym_POUNDELIF] = ACTIONS(12385),
    [anon_sym_POUNDElif] = ACTIONS(12385),
    [anon_sym_POUNDelse] = ACTIONS(12385),
    [anon_sym_POUNDELSE] = ACTIONS(12385),
    [anon_sym_POUNDElse] = ACTIONS(12385),
    [anon_sym_POUNDelse2] = ACTIONS(12385),
    [anon_sym_POUNDELSE2] = ACTIONS(12385),
    [anon_sym_POUNDElse2] = ACTIONS(12385),
    [anon_sym_POUNDendif] = ACTIONS(12385),
    [anon_sym_POUNDENDIF] = ACTIONS(12385),
    [anon_sym_POUNDEndif] = ACTIONS(12385),
    [anon_sym_POUNDendif2] = ACTIONS(12385),
    [anon_sym_POUNDENDIF2] = ACTIONS(12385),
    [anon_sym_POUNDEndif2] = ACTIONS(12385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12385),
    [sym_trigger_keyword] = ACTIONS(12385),
    [sym_var_keyword] = ACTIONS(12385),
    [sym_local_keyword] = ACTIONS(12385),
    [sym_internal_keyword] = ACTIONS(12385),
    [sym_protected_keyword] = ACTIONS(12385),
    [sym_event_keyword] = ACTIONS(12385),
    [sym_fields_keyword] = ACTIONS(12385),
    [sym_keys_keyword] = ACTIONS(12385),
    [sym_fieldgroups_keyword] = ACTIONS(12385),
    [sym_actions_keyword] = ACTIONS(12385),
    [sym_layout_keyword] = ACTIONS(12385),
    [sym_area_keyword] = ACTIONS(12385),
    [sym_group_keyword] = ACTIONS(12385),
    [sym_repeater_keyword] = ACTIONS(12385),
    [sym_cuegroup_keyword] = ACTIONS(12385),
    [sym_fixed_keyword] = ACTIONS(12385),
    [sym_grid_keyword] = ACTIONS(12385),
    [sym_part_keyword] = ACTIONS(12385),
    [sym_systempart_keyword] = ACTIONS(12385),
    [sym_usercontrol_keyword] = ACTIONS(12385),
    [sym_dataset_keyword] = ACTIONS(12385),
    [sym_elements_keyword] = ACTIONS(12385),
    [sym_dataitem_keyword] = ACTIONS(12385),
    [sym_column_keyword] = ACTIONS(12385),
    [sym_filter_keyword] = ACTIONS(12385),
    [sym_labels_keyword] = ACTIONS(12385),
    [sym_rendering_keyword] = ACTIONS(12385),
    [sym_requestpage_keyword] = ACTIONS(12385),
    [sym_schema_keyword] = ACTIONS(12385),
    [sym_views_keyword] = ACTIONS(12385),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12385),
    [sym_preproc_open] = ACTIONS(12385),
    [sym_preproc_close] = ACTIONS(12385),
  },
  [STATE(5049)] = {
    [anon_sym_SEMI] = ACTIONS(12385),
    [aux_sym_where_condition_token1] = ACTIONS(12387),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12385),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12385),
    [anon_sym_LBRACK] = ACTIONS(12385),
    [aux_sym_basic_type_token6] = ACTIONS(12387),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12385),
    [aux_sym_addafter_modification_token1] = ACTIONS(12385),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12385),
    [aux_sym_modify_modification_token1] = ACTIONS(12385),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12385),
    [aux_sym_movelast_modification_token1] = ACTIONS(12385),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12385),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12385),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12385),
    [anon_sym_POUNDif] = ACTIONS(12385),
    [anon_sym_POUNDIF] = ACTIONS(12385),
    [anon_sym_POUNDIf] = ACTIONS(12385),
    [anon_sym_POUNDelif] = ACTIONS(12385),
    [anon_sym_POUNDELIF] = ACTIONS(12385),
    [anon_sym_POUNDElif] = ACTIONS(12385),
    [anon_sym_POUNDelse] = ACTIONS(12385),
    [anon_sym_POUNDELSE] = ACTIONS(12385),
    [anon_sym_POUNDElse] = ACTIONS(12385),
    [anon_sym_POUNDelse2] = ACTIONS(12385),
    [anon_sym_POUNDELSE2] = ACTIONS(12385),
    [anon_sym_POUNDElse2] = ACTIONS(12385),
    [anon_sym_POUNDendif] = ACTIONS(12385),
    [anon_sym_POUNDENDIF] = ACTIONS(12385),
    [anon_sym_POUNDEndif] = ACTIONS(12385),
    [anon_sym_POUNDendif2] = ACTIONS(12385),
    [anon_sym_POUNDENDIF2] = ACTIONS(12385),
    [anon_sym_POUNDEndif2] = ACTIONS(12385),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12385),
    [sym_trigger_keyword] = ACTIONS(12385),
    [sym_var_keyword] = ACTIONS(12385),
    [sym_local_keyword] = ACTIONS(12385),
    [sym_internal_keyword] = ACTIONS(12385),
    [sym_protected_keyword] = ACTIONS(12385),
    [sym_event_keyword] = ACTIONS(12385),
    [sym_fields_keyword] = ACTIONS(12385),
    [sym_keys_keyword] = ACTIONS(12385),
    [sym_fieldgroups_keyword] = ACTIONS(12385),
    [sym_actions_keyword] = ACTIONS(12385),
    [sym_layout_keyword] = ACTIONS(12385),
    [sym_area_keyword] = ACTIONS(12385),
    [sym_group_keyword] = ACTIONS(12385),
    [sym_repeater_keyword] = ACTIONS(12385),
    [sym_cuegroup_keyword] = ACTIONS(12385),
    [sym_fixed_keyword] = ACTIONS(12385),
    [sym_grid_keyword] = ACTIONS(12385),
    [sym_part_keyword] = ACTIONS(12385),
    [sym_systempart_keyword] = ACTIONS(12385),
    [sym_usercontrol_keyword] = ACTIONS(12385),
    [sym_dataset_keyword] = ACTIONS(12385),
    [sym_elements_keyword] = ACTIONS(12385),
    [sym_dataitem_keyword] = ACTIONS(12385),
    [sym_column_keyword] = ACTIONS(12385),
    [sym_filter_keyword] = ACTIONS(12385),
    [sym_labels_keyword] = ACTIONS(12385),
    [sym_rendering_keyword] = ACTIONS(12385),
    [sym_requestpage_keyword] = ACTIONS(12385),
    [sym_schema_keyword] = ACTIONS(12385),
    [sym_views_keyword] = ACTIONS(12385),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12385),
    [sym_preproc_open] = ACTIONS(12385),
    [sym_preproc_close] = ACTIONS(12385),
  },
  [STATE(5050)] = {
    [anon_sym_SEMI] = ACTIONS(12399),
    [aux_sym_where_condition_token1] = ACTIONS(12395),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12397),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12397),
    [anon_sym_LBRACK] = ACTIONS(12397),
    [aux_sym_basic_type_token6] = ACTIONS(12395),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12397),
    [aux_sym_addafter_modification_token1] = ACTIONS(12397),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12397),
    [aux_sym_modify_modification_token1] = ACTIONS(12397),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12397),
    [aux_sym_movelast_modification_token1] = ACTIONS(12397),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12397),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12397),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12397),
    [anon_sym_POUNDif] = ACTIONS(12397),
    [anon_sym_POUNDIF] = ACTIONS(12397),
    [anon_sym_POUNDIf] = ACTIONS(12397),
    [anon_sym_POUNDelif] = ACTIONS(12397),
    [anon_sym_POUNDELIF] = ACTIONS(12397),
    [anon_sym_POUNDElif] = ACTIONS(12397),
    [anon_sym_POUNDelse] = ACTIONS(12397),
    [anon_sym_POUNDELSE] = ACTIONS(12397),
    [anon_sym_POUNDElse] = ACTIONS(12397),
    [anon_sym_POUNDelse2] = ACTIONS(12397),
    [anon_sym_POUNDELSE2] = ACTIONS(12397),
    [anon_sym_POUNDElse2] = ACTIONS(12397),
    [anon_sym_POUNDendif] = ACTIONS(12397),
    [anon_sym_POUNDENDIF] = ACTIONS(12397),
    [anon_sym_POUNDEndif] = ACTIONS(12397),
    [anon_sym_POUNDendif2] = ACTIONS(12397),
    [anon_sym_POUNDENDIF2] = ACTIONS(12397),
    [anon_sym_POUNDEndif2] = ACTIONS(12397),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12397),
    [sym_trigger_keyword] = ACTIONS(12397),
    [sym_var_keyword] = ACTIONS(12397),
    [sym_local_keyword] = ACTIONS(12397),
    [sym_internal_keyword] = ACTIONS(12397),
    [sym_protected_keyword] = ACTIONS(12397),
    [sym_event_keyword] = ACTIONS(12397),
    [sym_fields_keyword] = ACTIONS(12397),
    [sym_keys_keyword] = ACTIONS(12397),
    [sym_fieldgroups_keyword] = ACTIONS(12397),
    [sym_actions_keyword] = ACTIONS(12397),
    [sym_layout_keyword] = ACTIONS(12397),
    [sym_area_keyword] = ACTIONS(12397),
    [sym_group_keyword] = ACTIONS(12397),
    [sym_repeater_keyword] = ACTIONS(12397),
    [sym_cuegroup_keyword] = ACTIONS(12397),
    [sym_fixed_keyword] = ACTIONS(12397),
    [sym_grid_keyword] = ACTIONS(12397),
    [sym_part_keyword] = ACTIONS(12397),
    [sym_systempart_keyword] = ACTIONS(12397),
    [sym_usercontrol_keyword] = ACTIONS(12397),
    [sym_dataset_keyword] = ACTIONS(12397),
    [sym_elements_keyword] = ACTIONS(12397),
    [sym_dataitem_keyword] = ACTIONS(12397),
    [sym_column_keyword] = ACTIONS(12397),
    [sym_filter_keyword] = ACTIONS(12397),
    [sym_labels_keyword] = ACTIONS(12397),
    [sym_rendering_keyword] = ACTIONS(12397),
    [sym_requestpage_keyword] = ACTIONS(12397),
    [sym_schema_keyword] = ACTIONS(12397),
    [sym_views_keyword] = ACTIONS(12397),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12397),
    [sym_preproc_open] = ACTIONS(12397),
    [sym_preproc_close] = ACTIONS(12397),
  },
  [STATE(5051)] = {
    [anon_sym_SEMI] = ACTIONS(12401),
    [aux_sym_where_condition_token1] = ACTIONS(12403),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12405),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12405),
    [anon_sym_LBRACK] = ACTIONS(12405),
    [aux_sym_basic_type_token6] = ACTIONS(12403),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12405),
    [aux_sym_addafter_modification_token1] = ACTIONS(12405),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12405),
    [aux_sym_modify_modification_token1] = ACTIONS(12405),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12405),
    [aux_sym_movelast_modification_token1] = ACTIONS(12405),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12405),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12405),
    [anon_sym_POUNDif] = ACTIONS(12405),
    [anon_sym_POUNDIF] = ACTIONS(12405),
    [anon_sym_POUNDIf] = ACTIONS(12405),
    [anon_sym_POUNDelif] = ACTIONS(12405),
    [anon_sym_POUNDELIF] = ACTIONS(12405),
    [anon_sym_POUNDElif] = ACTIONS(12405),
    [anon_sym_POUNDelse] = ACTIONS(12405),
    [anon_sym_POUNDELSE] = ACTIONS(12405),
    [anon_sym_POUNDElse] = ACTIONS(12405),
    [anon_sym_POUNDelse2] = ACTIONS(12405),
    [anon_sym_POUNDELSE2] = ACTIONS(12405),
    [anon_sym_POUNDElse2] = ACTIONS(12405),
    [anon_sym_POUNDendif] = ACTIONS(12405),
    [anon_sym_POUNDENDIF] = ACTIONS(12405),
    [anon_sym_POUNDEndif] = ACTIONS(12405),
    [anon_sym_POUNDendif2] = ACTIONS(12405),
    [anon_sym_POUNDENDIF2] = ACTIONS(12405),
    [anon_sym_POUNDEndif2] = ACTIONS(12405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12405),
    [sym_trigger_keyword] = ACTIONS(12405),
    [sym_var_keyword] = ACTIONS(12405),
    [sym_local_keyword] = ACTIONS(12405),
    [sym_internal_keyword] = ACTIONS(12405),
    [sym_protected_keyword] = ACTIONS(12405),
    [sym_event_keyword] = ACTIONS(12405),
    [sym_fields_keyword] = ACTIONS(12405),
    [sym_keys_keyword] = ACTIONS(12405),
    [sym_fieldgroups_keyword] = ACTIONS(12405),
    [sym_actions_keyword] = ACTIONS(12405),
    [sym_layout_keyword] = ACTIONS(12405),
    [sym_area_keyword] = ACTIONS(12405),
    [sym_group_keyword] = ACTIONS(12405),
    [sym_repeater_keyword] = ACTIONS(12405),
    [sym_cuegroup_keyword] = ACTIONS(12405),
    [sym_fixed_keyword] = ACTIONS(12405),
    [sym_grid_keyword] = ACTIONS(12405),
    [sym_part_keyword] = ACTIONS(12405),
    [sym_systempart_keyword] = ACTIONS(12405),
    [sym_usercontrol_keyword] = ACTIONS(12405),
    [sym_dataset_keyword] = ACTIONS(12405),
    [sym_elements_keyword] = ACTIONS(12405),
    [sym_dataitem_keyword] = ACTIONS(12405),
    [sym_column_keyword] = ACTIONS(12405),
    [sym_filter_keyword] = ACTIONS(12405),
    [sym_labels_keyword] = ACTIONS(12405),
    [sym_rendering_keyword] = ACTIONS(12405),
    [sym_requestpage_keyword] = ACTIONS(12405),
    [sym_schema_keyword] = ACTIONS(12405),
    [sym_views_keyword] = ACTIONS(12405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12405),
    [sym_preproc_open] = ACTIONS(12405),
    [sym_preproc_close] = ACTIONS(12405),
  },
  [STATE(5052)] = {
    [anon_sym_SEMI] = ACTIONS(12407),
    [aux_sym_where_condition_token1] = ACTIONS(12403),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12405),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12405),
    [anon_sym_LBRACK] = ACTIONS(12405),
    [aux_sym_basic_type_token6] = ACTIONS(12403),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12405),
    [aux_sym_addafter_modification_token1] = ACTIONS(12405),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12405),
    [aux_sym_modify_modification_token1] = ACTIONS(12405),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12405),
    [aux_sym_movelast_modification_token1] = ACTIONS(12405),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12405),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12405),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12405),
    [anon_sym_POUNDif] = ACTIONS(12405),
    [anon_sym_POUNDIF] = ACTIONS(12405),
    [anon_sym_POUNDIf] = ACTIONS(12405),
    [anon_sym_POUNDelif] = ACTIONS(12405),
    [anon_sym_POUNDELIF] = ACTIONS(12405),
    [anon_sym_POUNDElif] = ACTIONS(12405),
    [anon_sym_POUNDelse] = ACTIONS(12405),
    [anon_sym_POUNDELSE] = ACTIONS(12405),
    [anon_sym_POUNDElse] = ACTIONS(12405),
    [anon_sym_POUNDelse2] = ACTIONS(12405),
    [anon_sym_POUNDELSE2] = ACTIONS(12405),
    [anon_sym_POUNDElse2] = ACTIONS(12405),
    [anon_sym_POUNDendif] = ACTIONS(12405),
    [anon_sym_POUNDENDIF] = ACTIONS(12405),
    [anon_sym_POUNDEndif] = ACTIONS(12405),
    [anon_sym_POUNDendif2] = ACTIONS(12405),
    [anon_sym_POUNDENDIF2] = ACTIONS(12405),
    [anon_sym_POUNDEndif2] = ACTIONS(12405),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12405),
    [sym_trigger_keyword] = ACTIONS(12405),
    [sym_var_keyword] = ACTIONS(12405),
    [sym_local_keyword] = ACTIONS(12405),
    [sym_internal_keyword] = ACTIONS(12405),
    [sym_protected_keyword] = ACTIONS(12405),
    [sym_event_keyword] = ACTIONS(12405),
    [sym_fields_keyword] = ACTIONS(12405),
    [sym_keys_keyword] = ACTIONS(12405),
    [sym_fieldgroups_keyword] = ACTIONS(12405),
    [sym_actions_keyword] = ACTIONS(12405),
    [sym_layout_keyword] = ACTIONS(12405),
    [sym_area_keyword] = ACTIONS(12405),
    [sym_group_keyword] = ACTIONS(12405),
    [sym_repeater_keyword] = ACTIONS(12405),
    [sym_cuegroup_keyword] = ACTIONS(12405),
    [sym_fixed_keyword] = ACTIONS(12405),
    [sym_grid_keyword] = ACTIONS(12405),
    [sym_part_keyword] = ACTIONS(12405),
    [sym_systempart_keyword] = ACTIONS(12405),
    [sym_usercontrol_keyword] = ACTIONS(12405),
    [sym_dataset_keyword] = ACTIONS(12405),
    [sym_elements_keyword] = ACTIONS(12405),
    [sym_dataitem_keyword] = ACTIONS(12405),
    [sym_column_keyword] = ACTIONS(12405),
    [sym_filter_keyword] = ACTIONS(12405),
    [sym_labels_keyword] = ACTIONS(12405),
    [sym_rendering_keyword] = ACTIONS(12405),
    [sym_requestpage_keyword] = ACTIONS(12405),
    [sym_schema_keyword] = ACTIONS(12405),
    [sym_views_keyword] = ACTIONS(12405),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12405),
    [sym_preproc_open] = ACTIONS(12405),
    [sym_preproc_close] = ACTIONS(12405),
  },
  [STATE(5053)] = {
    [anon_sym_SEMI] = ACTIONS(12409),
    [aux_sym_where_condition_token1] = ACTIONS(12411),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12409),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12409),
    [anon_sym_LBRACK] = ACTIONS(12409),
    [aux_sym_basic_type_token6] = ACTIONS(12411),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12409),
    [aux_sym_addafter_modification_token1] = ACTIONS(12409),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12409),
    [aux_sym_modify_modification_token1] = ACTIONS(12409),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12409),
    [aux_sym_movelast_modification_token1] = ACTIONS(12409),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12409),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12409),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12409),
    [anon_sym_POUNDif] = ACTIONS(12409),
    [anon_sym_POUNDIF] = ACTIONS(12409),
    [anon_sym_POUNDIf] = ACTIONS(12409),
    [anon_sym_POUNDelif] = ACTIONS(12409),
    [anon_sym_POUNDELIF] = ACTIONS(12409),
    [anon_sym_POUNDElif] = ACTIONS(12409),
    [anon_sym_POUNDelse] = ACTIONS(12409),
    [anon_sym_POUNDELSE] = ACTIONS(12409),
    [anon_sym_POUNDElse] = ACTIONS(12409),
    [anon_sym_POUNDelse2] = ACTIONS(12409),
    [anon_sym_POUNDELSE2] = ACTIONS(12409),
    [anon_sym_POUNDElse2] = ACTIONS(12409),
    [anon_sym_POUNDendif] = ACTIONS(12409),
    [anon_sym_POUNDENDIF] = ACTIONS(12409),
    [anon_sym_POUNDEndif] = ACTIONS(12409),
    [anon_sym_POUNDendif2] = ACTIONS(12409),
    [anon_sym_POUNDENDIF2] = ACTIONS(12409),
    [anon_sym_POUNDEndif2] = ACTIONS(12409),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12409),
    [sym_trigger_keyword] = ACTIONS(12409),
    [sym_var_keyword] = ACTIONS(12409),
    [sym_local_keyword] = ACTIONS(12409),
    [sym_internal_keyword] = ACTIONS(12409),
    [sym_protected_keyword] = ACTIONS(12409),
    [sym_event_keyword] = ACTIONS(12409),
    [sym_fields_keyword] = ACTIONS(12409),
    [sym_keys_keyword] = ACTIONS(12409),
    [sym_fieldgroups_keyword] = ACTIONS(12409),
    [sym_actions_keyword] = ACTIONS(12409),
    [sym_layout_keyword] = ACTIONS(12409),
    [sym_area_keyword] = ACTIONS(12409),
    [sym_group_keyword] = ACTIONS(12409),
    [sym_repeater_keyword] = ACTIONS(12409),
    [sym_cuegroup_keyword] = ACTIONS(12409),
    [sym_fixed_keyword] = ACTIONS(12409),
    [sym_grid_keyword] = ACTIONS(12409),
    [sym_part_keyword] = ACTIONS(12409),
    [sym_systempart_keyword] = ACTIONS(12409),
    [sym_usercontrol_keyword] = ACTIONS(12409),
    [sym_dataset_keyword] = ACTIONS(12409),
    [sym_elements_keyword] = ACTIONS(12409),
    [sym_dataitem_keyword] = ACTIONS(12409),
    [sym_column_keyword] = ACTIONS(12409),
    [sym_filter_keyword] = ACTIONS(12409),
    [sym_labels_keyword] = ACTIONS(12409),
    [sym_rendering_keyword] = ACTIONS(12409),
    [sym_requestpage_keyword] = ACTIONS(12409),
    [sym_schema_keyword] = ACTIONS(12409),
    [sym_views_keyword] = ACTIONS(12409),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12409),
    [sym_preproc_open] = ACTIONS(12409),
    [sym_preproc_close] = ACTIONS(12409),
  },
  [STATE(5054)] = {
    [sym__body_element] = STATE(5077),
    [sym_empty_statement] = STATE(5077),
    [sym_property] = STATE(5077),
    [sym_permissions_property] = STATE(5077),
    [sym_table_relation_property] = STATE(5077),
    [sym_fields_section] = STATE(5077),
    [sym_keys_section] = STATE(5077),
    [sym_fieldgroups_section] = STATE(5077),
    [sym_enum_value_declaration] = STATE(5077),
    [sym_labels_section] = STATE(5077),
    [sym_layout_section] = STATE(5077),
    [sym_modify_modification] = STATE(5077),
    [sym_actions_section] = STATE(5077),
    [sym_views_section] = STATE(5077),
    [sym_dataset_section] = STATE(5077),
    [sym_report_dataitem] = STATE(5077),
    [sym__report_body_element] = STATE(5077),
    [sym_preproc_conditional_report] = STATE(5077),
    [sym_report_column] = STATE(5077),
    [sym_requestpage_section] = STATE(5077),
    [sym_rendering_section] = STATE(5077),
    [sym_elements_section] = STATE(5077),
    [sym_schema_section] = STATE(5077),
    [sym_assembly_declaration] = STATE(5077),
    [sym_event_declaration] = STATE(5077),
    [sym_procedure] = STATE(5077),
    [sym_preproc_split_procedure] = STATE(5077),
    [sym_preproc_split_procedure_preamble] = STATE(5077),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5077),
    [sym_var_section] = STATE(5077),
    [sym_attribute_item] = STATE(5077),
    [sym_preproc_conditional] = STATE(5077),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5077),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12413),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5055)] = {
    [anon_sym_SEMI] = ACTIONS(12415),
    [aux_sym_where_condition_token1] = ACTIONS(12417),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12415),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12415),
    [anon_sym_LBRACK] = ACTIONS(12415),
    [aux_sym_basic_type_token6] = ACTIONS(12417),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12415),
    [aux_sym_addafter_modification_token1] = ACTIONS(12415),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12415),
    [aux_sym_modify_modification_token1] = ACTIONS(12415),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12415),
    [aux_sym_movelast_modification_token1] = ACTIONS(12415),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12415),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12415),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12415),
    [anon_sym_POUNDif] = ACTIONS(12415),
    [anon_sym_POUNDIF] = ACTIONS(12415),
    [anon_sym_POUNDIf] = ACTIONS(12415),
    [anon_sym_POUNDelif] = ACTIONS(12415),
    [anon_sym_POUNDELIF] = ACTIONS(12415),
    [anon_sym_POUNDElif] = ACTIONS(12415),
    [anon_sym_POUNDelse] = ACTIONS(12415),
    [anon_sym_POUNDELSE] = ACTIONS(12415),
    [anon_sym_POUNDElse] = ACTIONS(12415),
    [anon_sym_POUNDelse2] = ACTIONS(12415),
    [anon_sym_POUNDELSE2] = ACTIONS(12415),
    [anon_sym_POUNDElse2] = ACTIONS(12415),
    [anon_sym_POUNDendif] = ACTIONS(12415),
    [anon_sym_POUNDENDIF] = ACTIONS(12415),
    [anon_sym_POUNDEndif] = ACTIONS(12415),
    [anon_sym_POUNDendif2] = ACTIONS(12415),
    [anon_sym_POUNDENDIF2] = ACTIONS(12415),
    [anon_sym_POUNDEndif2] = ACTIONS(12415),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12415),
    [sym_trigger_keyword] = ACTIONS(12415),
    [sym_var_keyword] = ACTIONS(12415),
    [sym_local_keyword] = ACTIONS(12415),
    [sym_internal_keyword] = ACTIONS(12415),
    [sym_protected_keyword] = ACTIONS(12415),
    [sym_event_keyword] = ACTIONS(12415),
    [sym_fields_keyword] = ACTIONS(12415),
    [sym_keys_keyword] = ACTIONS(12415),
    [sym_fieldgroups_keyword] = ACTIONS(12415),
    [sym_actions_keyword] = ACTIONS(12415),
    [sym_layout_keyword] = ACTIONS(12415),
    [sym_area_keyword] = ACTIONS(12415),
    [sym_group_keyword] = ACTIONS(12415),
    [sym_repeater_keyword] = ACTIONS(12415),
    [sym_cuegroup_keyword] = ACTIONS(12415),
    [sym_fixed_keyword] = ACTIONS(12415),
    [sym_grid_keyword] = ACTIONS(12415),
    [sym_part_keyword] = ACTIONS(12415),
    [sym_systempart_keyword] = ACTIONS(12415),
    [sym_usercontrol_keyword] = ACTIONS(12415),
    [sym_dataset_keyword] = ACTIONS(12415),
    [sym_elements_keyword] = ACTIONS(12415),
    [sym_dataitem_keyword] = ACTIONS(12415),
    [sym_column_keyword] = ACTIONS(12415),
    [sym_filter_keyword] = ACTIONS(12415),
    [sym_labels_keyword] = ACTIONS(12415),
    [sym_rendering_keyword] = ACTIONS(12415),
    [sym_requestpage_keyword] = ACTIONS(12415),
    [sym_schema_keyword] = ACTIONS(12415),
    [sym_views_keyword] = ACTIONS(12415),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12415),
    [sym_preproc_open] = ACTIONS(12415),
    [sym_preproc_close] = ACTIONS(12415),
  },
  [STATE(5056)] = {
    [anon_sym_SEMI] = ACTIONS(8426),
    [anon_sym_RBRACE] = ACTIONS(8426),
    [aux_sym_where_condition_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8426),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8426),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8426),
    [anon_sym_LBRACK] = ACTIONS(8426),
    [aux_sym_basic_type_token6] = ACTIONS(7770),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8426),
    [aux_sym_addafter_modification_token1] = ACTIONS(8426),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8426),
    [aux_sym_modify_modification_token1] = ACTIONS(8426),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8426),
    [aux_sym_movelast_modification_token1] = ACTIONS(8426),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8426),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8426),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8426),
    [anon_sym_POUNDif] = ACTIONS(8426),
    [anon_sym_POUNDIF] = ACTIONS(8426),
    [anon_sym_POUNDIf] = ACTIONS(8426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7770),
    [sym_page_keyword] = ACTIONS(8426),
    [anon_sym_codeunit] = ACTIONS(8426),
    [anon_sym_CODEUNIT] = ACTIONS(8426),
    [anon_sym_Codeunit] = ACTIONS(8426),
    [anon_sym_CodeUnit] = ACTIONS(8426),
    [anon_sym_COdeunit] = ACTIONS(8426),
    [anon_sym_codeUnit] = ACTIONS(8426),
    [sym_report_keyword] = ACTIONS(8426),
    [sym_query_keyword] = ACTIONS(8426),
    [anon_sym_xmlport] = ACTIONS(8426),
    [anon_sym_XMLPORT] = ACTIONS(8426),
    [anon_sym_Xmlport] = ACTIONS(8426),
    [anon_sym_XMLport] = ACTIONS(8426),
    [anon_sym_XMLPort] = ACTIONS(8426),
    [anon_sym_XmlPort] = ACTIONS(8426),
    [sym_procedure_keyword] = ACTIONS(8426),
    [sym_trigger_keyword] = ACTIONS(8426),
    [sym_var_keyword] = ACTIONS(8426),
    [sym_local_keyword] = ACTIONS(8426),
    [sym_internal_keyword] = ACTIONS(8426),
    [sym_protected_keyword] = ACTIONS(8426),
    [sym_event_keyword] = ACTIONS(8426),
    [sym_fields_keyword] = ACTIONS(8426),
    [sym_keys_keyword] = ACTIONS(8426),
    [sym_fieldgroups_keyword] = ACTIONS(8426),
    [sym_actions_keyword] = ACTIONS(8426),
    [sym_layout_keyword] = ACTIONS(8426),
    [sym_area_keyword] = ACTIONS(8426),
    [sym_group_keyword] = ACTIONS(8426),
    [sym_repeater_keyword] = ACTIONS(8426),
    [sym_cuegroup_keyword] = ACTIONS(8426),
    [sym_fixed_keyword] = ACTIONS(8426),
    [sym_grid_keyword] = ACTIONS(8426),
    [sym_part_keyword] = ACTIONS(8426),
    [sym_systempart_keyword] = ACTIONS(8426),
    [sym_usercontrol_keyword] = ACTIONS(8426),
    [sym_dataset_keyword] = ACTIONS(8426),
    [sym_elements_keyword] = ACTIONS(8426),
    [sym_labels_keyword] = ACTIONS(8426),
    [sym_rendering_keyword] = ACTIONS(8426),
    [sym_requestpage_keyword] = ACTIONS(8426),
    [sym_schema_keyword] = ACTIONS(8426),
    [sym_views_keyword] = ACTIONS(8426),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8426),
    [sym_preproc_open] = ACTIONS(8426),
  },
  [STATE(5057)] = {
    [anon_sym_SEMI] = ACTIONS(12419),
    [aux_sym_where_condition_token1] = ACTIONS(12421),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12419),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12419),
    [anon_sym_LBRACK] = ACTIONS(12419),
    [aux_sym_basic_type_token6] = ACTIONS(12421),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12419),
    [aux_sym_addafter_modification_token1] = ACTIONS(12419),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12419),
    [aux_sym_modify_modification_token1] = ACTIONS(12419),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12419),
    [aux_sym_movelast_modification_token1] = ACTIONS(12419),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12419),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12419),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12419),
    [anon_sym_POUNDif] = ACTIONS(12419),
    [anon_sym_POUNDIF] = ACTIONS(12419),
    [anon_sym_POUNDIf] = ACTIONS(12419),
    [anon_sym_POUNDelif] = ACTIONS(12419),
    [anon_sym_POUNDELIF] = ACTIONS(12419),
    [anon_sym_POUNDElif] = ACTIONS(12419),
    [anon_sym_POUNDelse] = ACTIONS(12419),
    [anon_sym_POUNDELSE] = ACTIONS(12419),
    [anon_sym_POUNDElse] = ACTIONS(12419),
    [anon_sym_POUNDelse2] = ACTIONS(12419),
    [anon_sym_POUNDELSE2] = ACTIONS(12419),
    [anon_sym_POUNDElse2] = ACTIONS(12419),
    [anon_sym_POUNDendif] = ACTIONS(12419),
    [anon_sym_POUNDENDIF] = ACTIONS(12419),
    [anon_sym_POUNDEndif] = ACTIONS(12419),
    [anon_sym_POUNDendif2] = ACTIONS(12419),
    [anon_sym_POUNDENDIF2] = ACTIONS(12419),
    [anon_sym_POUNDEndif2] = ACTIONS(12419),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12419),
    [sym_trigger_keyword] = ACTIONS(12419),
    [sym_var_keyword] = ACTIONS(12419),
    [sym_local_keyword] = ACTIONS(12419),
    [sym_internal_keyword] = ACTIONS(12419),
    [sym_protected_keyword] = ACTIONS(12419),
    [sym_event_keyword] = ACTIONS(12419),
    [sym_fields_keyword] = ACTIONS(12419),
    [sym_keys_keyword] = ACTIONS(12419),
    [sym_fieldgroups_keyword] = ACTIONS(12419),
    [sym_actions_keyword] = ACTIONS(12419),
    [sym_layout_keyword] = ACTIONS(12419),
    [sym_area_keyword] = ACTIONS(12419),
    [sym_group_keyword] = ACTIONS(12419),
    [sym_repeater_keyword] = ACTIONS(12419),
    [sym_cuegroup_keyword] = ACTIONS(12419),
    [sym_fixed_keyword] = ACTIONS(12419),
    [sym_grid_keyword] = ACTIONS(12419),
    [sym_part_keyword] = ACTIONS(12419),
    [sym_systempart_keyword] = ACTIONS(12419),
    [sym_usercontrol_keyword] = ACTIONS(12419),
    [sym_dataset_keyword] = ACTIONS(12419),
    [sym_elements_keyword] = ACTIONS(12419),
    [sym_dataitem_keyword] = ACTIONS(12419),
    [sym_column_keyword] = ACTIONS(12419),
    [sym_filter_keyword] = ACTIONS(12419),
    [sym_labels_keyword] = ACTIONS(12419),
    [sym_rendering_keyword] = ACTIONS(12419),
    [sym_requestpage_keyword] = ACTIONS(12419),
    [sym_schema_keyword] = ACTIONS(12419),
    [sym_views_keyword] = ACTIONS(12419),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12419),
    [sym_preproc_open] = ACTIONS(12419),
    [sym_preproc_close] = ACTIONS(12419),
  },
  [STATE(5058)] = {
    [anon_sym_SEMI] = ACTIONS(12419),
    [aux_sym_where_condition_token1] = ACTIONS(12421),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12419),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12419),
    [anon_sym_LBRACK] = ACTIONS(12419),
    [aux_sym_basic_type_token6] = ACTIONS(12421),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12419),
    [aux_sym_addafter_modification_token1] = ACTIONS(12419),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12419),
    [aux_sym_modify_modification_token1] = ACTIONS(12419),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12419),
    [aux_sym_movelast_modification_token1] = ACTIONS(12419),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12419),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12419),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12419),
    [anon_sym_POUNDif] = ACTIONS(12419),
    [anon_sym_POUNDIF] = ACTIONS(12419),
    [anon_sym_POUNDIf] = ACTIONS(12419),
    [anon_sym_POUNDelif] = ACTIONS(12419),
    [anon_sym_POUNDELIF] = ACTIONS(12419),
    [anon_sym_POUNDElif] = ACTIONS(12419),
    [anon_sym_POUNDelse] = ACTIONS(12419),
    [anon_sym_POUNDELSE] = ACTIONS(12419),
    [anon_sym_POUNDElse] = ACTIONS(12419),
    [anon_sym_POUNDelse2] = ACTIONS(12419),
    [anon_sym_POUNDELSE2] = ACTIONS(12419),
    [anon_sym_POUNDElse2] = ACTIONS(12419),
    [anon_sym_POUNDendif] = ACTIONS(12419),
    [anon_sym_POUNDENDIF] = ACTIONS(12419),
    [anon_sym_POUNDEndif] = ACTIONS(12419),
    [anon_sym_POUNDendif2] = ACTIONS(12419),
    [anon_sym_POUNDENDIF2] = ACTIONS(12419),
    [anon_sym_POUNDEndif2] = ACTIONS(12419),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12419),
    [sym_trigger_keyword] = ACTIONS(12419),
    [sym_var_keyword] = ACTIONS(12419),
    [sym_local_keyword] = ACTIONS(12419),
    [sym_internal_keyword] = ACTIONS(12419),
    [sym_protected_keyword] = ACTIONS(12419),
    [sym_event_keyword] = ACTIONS(12419),
    [sym_fields_keyword] = ACTIONS(12419),
    [sym_keys_keyword] = ACTIONS(12419),
    [sym_fieldgroups_keyword] = ACTIONS(12419),
    [sym_actions_keyword] = ACTIONS(12419),
    [sym_layout_keyword] = ACTIONS(12419),
    [sym_area_keyword] = ACTIONS(12419),
    [sym_group_keyword] = ACTIONS(12419),
    [sym_repeater_keyword] = ACTIONS(12419),
    [sym_cuegroup_keyword] = ACTIONS(12419),
    [sym_fixed_keyword] = ACTIONS(12419),
    [sym_grid_keyword] = ACTIONS(12419),
    [sym_part_keyword] = ACTIONS(12419),
    [sym_systempart_keyword] = ACTIONS(12419),
    [sym_usercontrol_keyword] = ACTIONS(12419),
    [sym_dataset_keyword] = ACTIONS(12419),
    [sym_elements_keyword] = ACTIONS(12419),
    [sym_dataitem_keyword] = ACTIONS(12419),
    [sym_column_keyword] = ACTIONS(12419),
    [sym_filter_keyword] = ACTIONS(12419),
    [sym_labels_keyword] = ACTIONS(12419),
    [sym_rendering_keyword] = ACTIONS(12419),
    [sym_requestpage_keyword] = ACTIONS(12419),
    [sym_schema_keyword] = ACTIONS(12419),
    [sym_views_keyword] = ACTIONS(12419),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12419),
    [sym_preproc_open] = ACTIONS(12419),
    [sym_preproc_close] = ACTIONS(12419),
  },
  [STATE(5059)] = {
    [anon_sym_SEMI] = ACTIONS(12423),
    [aux_sym_where_condition_token1] = ACTIONS(12425),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12423),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12423),
    [anon_sym_LBRACK] = ACTIONS(12423),
    [aux_sym_basic_type_token6] = ACTIONS(12425),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12423),
    [aux_sym_addafter_modification_token1] = ACTIONS(12423),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12423),
    [aux_sym_modify_modification_token1] = ACTIONS(12423),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12423),
    [aux_sym_movelast_modification_token1] = ACTIONS(12423),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12423),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12423),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12423),
    [anon_sym_POUNDif] = ACTIONS(12423),
    [anon_sym_POUNDIF] = ACTIONS(12423),
    [anon_sym_POUNDIf] = ACTIONS(12423),
    [anon_sym_POUNDelif] = ACTIONS(12423),
    [anon_sym_POUNDELIF] = ACTIONS(12423),
    [anon_sym_POUNDElif] = ACTIONS(12423),
    [anon_sym_POUNDelse] = ACTIONS(12423),
    [anon_sym_POUNDELSE] = ACTIONS(12423),
    [anon_sym_POUNDElse] = ACTIONS(12423),
    [anon_sym_POUNDelse2] = ACTIONS(12423),
    [anon_sym_POUNDELSE2] = ACTIONS(12423),
    [anon_sym_POUNDElse2] = ACTIONS(12423),
    [anon_sym_POUNDendif] = ACTIONS(12423),
    [anon_sym_POUNDENDIF] = ACTIONS(12423),
    [anon_sym_POUNDEndif] = ACTIONS(12423),
    [anon_sym_POUNDendif2] = ACTIONS(12423),
    [anon_sym_POUNDENDIF2] = ACTIONS(12423),
    [anon_sym_POUNDEndif2] = ACTIONS(12423),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12423),
    [sym_trigger_keyword] = ACTIONS(12423),
    [sym_var_keyword] = ACTIONS(12423),
    [sym_local_keyword] = ACTIONS(12423),
    [sym_internal_keyword] = ACTIONS(12423),
    [sym_protected_keyword] = ACTIONS(12423),
    [sym_event_keyword] = ACTIONS(12423),
    [sym_fields_keyword] = ACTIONS(12423),
    [sym_keys_keyword] = ACTIONS(12423),
    [sym_fieldgroups_keyword] = ACTIONS(12423),
    [sym_actions_keyword] = ACTIONS(12423),
    [sym_layout_keyword] = ACTIONS(12423),
    [sym_area_keyword] = ACTIONS(12423),
    [sym_group_keyword] = ACTIONS(12423),
    [sym_repeater_keyword] = ACTIONS(12423),
    [sym_cuegroup_keyword] = ACTIONS(12423),
    [sym_fixed_keyword] = ACTIONS(12423),
    [sym_grid_keyword] = ACTIONS(12423),
    [sym_part_keyword] = ACTIONS(12423),
    [sym_systempart_keyword] = ACTIONS(12423),
    [sym_usercontrol_keyword] = ACTIONS(12423),
    [sym_dataset_keyword] = ACTIONS(12423),
    [sym_elements_keyword] = ACTIONS(12423),
    [sym_dataitem_keyword] = ACTIONS(12423),
    [sym_column_keyword] = ACTIONS(12423),
    [sym_filter_keyword] = ACTIONS(12423),
    [sym_labels_keyword] = ACTIONS(12423),
    [sym_rendering_keyword] = ACTIONS(12423),
    [sym_requestpage_keyword] = ACTIONS(12423),
    [sym_schema_keyword] = ACTIONS(12423),
    [sym_views_keyword] = ACTIONS(12423),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12423),
    [sym_preproc_open] = ACTIONS(12423),
    [sym_preproc_close] = ACTIONS(12423),
  },
  [STATE(5060)] = {
    [anon_sym_SEMI] = ACTIONS(12423),
    [aux_sym_where_condition_token1] = ACTIONS(12425),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12423),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12423),
    [anon_sym_LBRACK] = ACTIONS(12423),
    [aux_sym_basic_type_token6] = ACTIONS(12425),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12423),
    [aux_sym_addafter_modification_token1] = ACTIONS(12423),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12423),
    [aux_sym_modify_modification_token1] = ACTIONS(12423),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12423),
    [aux_sym_movelast_modification_token1] = ACTIONS(12423),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12423),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12423),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12423),
    [anon_sym_POUNDif] = ACTIONS(12423),
    [anon_sym_POUNDIF] = ACTIONS(12423),
    [anon_sym_POUNDIf] = ACTIONS(12423),
    [anon_sym_POUNDelif] = ACTIONS(12423),
    [anon_sym_POUNDELIF] = ACTIONS(12423),
    [anon_sym_POUNDElif] = ACTIONS(12423),
    [anon_sym_POUNDelse] = ACTIONS(12423),
    [anon_sym_POUNDELSE] = ACTIONS(12423),
    [anon_sym_POUNDElse] = ACTIONS(12423),
    [anon_sym_POUNDelse2] = ACTIONS(12423),
    [anon_sym_POUNDELSE2] = ACTIONS(12423),
    [anon_sym_POUNDElse2] = ACTIONS(12423),
    [anon_sym_POUNDendif] = ACTIONS(12423),
    [anon_sym_POUNDENDIF] = ACTIONS(12423),
    [anon_sym_POUNDEndif] = ACTIONS(12423),
    [anon_sym_POUNDendif2] = ACTIONS(12423),
    [anon_sym_POUNDENDIF2] = ACTIONS(12423),
    [anon_sym_POUNDEndif2] = ACTIONS(12423),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12423),
    [sym_trigger_keyword] = ACTIONS(12423),
    [sym_var_keyword] = ACTIONS(12423),
    [sym_local_keyword] = ACTIONS(12423),
    [sym_internal_keyword] = ACTIONS(12423),
    [sym_protected_keyword] = ACTIONS(12423),
    [sym_event_keyword] = ACTIONS(12423),
    [sym_fields_keyword] = ACTIONS(12423),
    [sym_keys_keyword] = ACTIONS(12423),
    [sym_fieldgroups_keyword] = ACTIONS(12423),
    [sym_actions_keyword] = ACTIONS(12423),
    [sym_layout_keyword] = ACTIONS(12423),
    [sym_area_keyword] = ACTIONS(12423),
    [sym_group_keyword] = ACTIONS(12423),
    [sym_repeater_keyword] = ACTIONS(12423),
    [sym_cuegroup_keyword] = ACTIONS(12423),
    [sym_fixed_keyword] = ACTIONS(12423),
    [sym_grid_keyword] = ACTIONS(12423),
    [sym_part_keyword] = ACTIONS(12423),
    [sym_systempart_keyword] = ACTIONS(12423),
    [sym_usercontrol_keyword] = ACTIONS(12423),
    [sym_dataset_keyword] = ACTIONS(12423),
    [sym_elements_keyword] = ACTIONS(12423),
    [sym_dataitem_keyword] = ACTIONS(12423),
    [sym_column_keyword] = ACTIONS(12423),
    [sym_filter_keyword] = ACTIONS(12423),
    [sym_labels_keyword] = ACTIONS(12423),
    [sym_rendering_keyword] = ACTIONS(12423),
    [sym_requestpage_keyword] = ACTIONS(12423),
    [sym_schema_keyword] = ACTIONS(12423),
    [sym_views_keyword] = ACTIONS(12423),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12423),
    [sym_preproc_open] = ACTIONS(12423),
    [sym_preproc_close] = ACTIONS(12423),
  },
  [STATE(5061)] = {
    [anon_sym_SEMI] = ACTIONS(12427),
    [aux_sym_where_condition_token1] = ACTIONS(12429),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12427),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12427),
    [anon_sym_LBRACK] = ACTIONS(12427),
    [aux_sym_basic_type_token6] = ACTIONS(12429),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12427),
    [aux_sym_addafter_modification_token1] = ACTIONS(12427),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12427),
    [aux_sym_modify_modification_token1] = ACTIONS(12427),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12427),
    [aux_sym_movelast_modification_token1] = ACTIONS(12427),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12427),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12427),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12427),
    [anon_sym_POUNDif] = ACTIONS(12427),
    [anon_sym_POUNDIF] = ACTIONS(12427),
    [anon_sym_POUNDIf] = ACTIONS(12427),
    [anon_sym_POUNDelif] = ACTIONS(12427),
    [anon_sym_POUNDELIF] = ACTIONS(12427),
    [anon_sym_POUNDElif] = ACTIONS(12427),
    [anon_sym_POUNDelse] = ACTIONS(12427),
    [anon_sym_POUNDELSE] = ACTIONS(12427),
    [anon_sym_POUNDElse] = ACTIONS(12427),
    [anon_sym_POUNDelse2] = ACTIONS(12427),
    [anon_sym_POUNDELSE2] = ACTIONS(12427),
    [anon_sym_POUNDElse2] = ACTIONS(12427),
    [anon_sym_POUNDendif] = ACTIONS(12427),
    [anon_sym_POUNDENDIF] = ACTIONS(12427),
    [anon_sym_POUNDEndif] = ACTIONS(12427),
    [anon_sym_POUNDendif2] = ACTIONS(12427),
    [anon_sym_POUNDENDIF2] = ACTIONS(12427),
    [anon_sym_POUNDEndif2] = ACTIONS(12427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12427),
    [sym_trigger_keyword] = ACTIONS(12427),
    [sym_var_keyword] = ACTIONS(12427),
    [sym_local_keyword] = ACTIONS(12427),
    [sym_internal_keyword] = ACTIONS(12427),
    [sym_protected_keyword] = ACTIONS(12427),
    [sym_event_keyword] = ACTIONS(12427),
    [sym_fields_keyword] = ACTIONS(12427),
    [sym_keys_keyword] = ACTIONS(12427),
    [sym_fieldgroups_keyword] = ACTIONS(12427),
    [sym_actions_keyword] = ACTIONS(12427),
    [sym_layout_keyword] = ACTIONS(12427),
    [sym_area_keyword] = ACTIONS(12427),
    [sym_group_keyword] = ACTIONS(12427),
    [sym_repeater_keyword] = ACTIONS(12427),
    [sym_cuegroup_keyword] = ACTIONS(12427),
    [sym_fixed_keyword] = ACTIONS(12427),
    [sym_grid_keyword] = ACTIONS(12427),
    [sym_part_keyword] = ACTIONS(12427),
    [sym_systempart_keyword] = ACTIONS(12427),
    [sym_usercontrol_keyword] = ACTIONS(12427),
    [sym_dataset_keyword] = ACTIONS(12427),
    [sym_elements_keyword] = ACTIONS(12427),
    [sym_dataitem_keyword] = ACTIONS(12427),
    [sym_column_keyword] = ACTIONS(12427),
    [sym_filter_keyword] = ACTIONS(12427),
    [sym_labels_keyword] = ACTIONS(12427),
    [sym_rendering_keyword] = ACTIONS(12427),
    [sym_requestpage_keyword] = ACTIONS(12427),
    [sym_schema_keyword] = ACTIONS(12427),
    [sym_views_keyword] = ACTIONS(12427),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12427),
    [sym_preproc_open] = ACTIONS(12427),
    [sym_preproc_close] = ACTIONS(12427),
  },
  [STATE(5062)] = {
    [anon_sym_SEMI] = ACTIONS(12427),
    [aux_sym_where_condition_token1] = ACTIONS(12429),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12427),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12427),
    [anon_sym_LBRACK] = ACTIONS(12427),
    [aux_sym_basic_type_token6] = ACTIONS(12429),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12427),
    [aux_sym_addafter_modification_token1] = ACTIONS(12427),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12427),
    [aux_sym_modify_modification_token1] = ACTIONS(12427),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12427),
    [aux_sym_movelast_modification_token1] = ACTIONS(12427),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12427),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12427),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12427),
    [anon_sym_POUNDif] = ACTIONS(12427),
    [anon_sym_POUNDIF] = ACTIONS(12427),
    [anon_sym_POUNDIf] = ACTIONS(12427),
    [anon_sym_POUNDelif] = ACTIONS(12427),
    [anon_sym_POUNDELIF] = ACTIONS(12427),
    [anon_sym_POUNDElif] = ACTIONS(12427),
    [anon_sym_POUNDelse] = ACTIONS(12427),
    [anon_sym_POUNDELSE] = ACTIONS(12427),
    [anon_sym_POUNDElse] = ACTIONS(12427),
    [anon_sym_POUNDelse2] = ACTIONS(12427),
    [anon_sym_POUNDELSE2] = ACTIONS(12427),
    [anon_sym_POUNDElse2] = ACTIONS(12427),
    [anon_sym_POUNDendif] = ACTIONS(12427),
    [anon_sym_POUNDENDIF] = ACTIONS(12427),
    [anon_sym_POUNDEndif] = ACTIONS(12427),
    [anon_sym_POUNDendif2] = ACTIONS(12427),
    [anon_sym_POUNDENDIF2] = ACTIONS(12427),
    [anon_sym_POUNDEndif2] = ACTIONS(12427),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12427),
    [sym_trigger_keyword] = ACTIONS(12427),
    [sym_var_keyword] = ACTIONS(12427),
    [sym_local_keyword] = ACTIONS(12427),
    [sym_internal_keyword] = ACTIONS(12427),
    [sym_protected_keyword] = ACTIONS(12427),
    [sym_event_keyword] = ACTIONS(12427),
    [sym_fields_keyword] = ACTIONS(12427),
    [sym_keys_keyword] = ACTIONS(12427),
    [sym_fieldgroups_keyword] = ACTIONS(12427),
    [sym_actions_keyword] = ACTIONS(12427),
    [sym_layout_keyword] = ACTIONS(12427),
    [sym_area_keyword] = ACTIONS(12427),
    [sym_group_keyword] = ACTIONS(12427),
    [sym_repeater_keyword] = ACTIONS(12427),
    [sym_cuegroup_keyword] = ACTIONS(12427),
    [sym_fixed_keyword] = ACTIONS(12427),
    [sym_grid_keyword] = ACTIONS(12427),
    [sym_part_keyword] = ACTIONS(12427),
    [sym_systempart_keyword] = ACTIONS(12427),
    [sym_usercontrol_keyword] = ACTIONS(12427),
    [sym_dataset_keyword] = ACTIONS(12427),
    [sym_elements_keyword] = ACTIONS(12427),
    [sym_dataitem_keyword] = ACTIONS(12427),
    [sym_column_keyword] = ACTIONS(12427),
    [sym_filter_keyword] = ACTIONS(12427),
    [sym_labels_keyword] = ACTIONS(12427),
    [sym_rendering_keyword] = ACTIONS(12427),
    [sym_requestpage_keyword] = ACTIONS(12427),
    [sym_schema_keyword] = ACTIONS(12427),
    [sym_views_keyword] = ACTIONS(12427),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12427),
    [sym_preproc_open] = ACTIONS(12427),
    [sym_preproc_close] = ACTIONS(12427),
  },
  [STATE(5063)] = {
    [anon_sym_SEMI] = ACTIONS(12431),
    [aux_sym_where_condition_token1] = ACTIONS(12433),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12435),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12435),
    [anon_sym_LBRACK] = ACTIONS(12435),
    [aux_sym_basic_type_token6] = ACTIONS(12433),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12435),
    [aux_sym_addafter_modification_token1] = ACTIONS(12435),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12435),
    [aux_sym_modify_modification_token1] = ACTIONS(12435),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12435),
    [aux_sym_movelast_modification_token1] = ACTIONS(12435),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12435),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12435),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12435),
    [anon_sym_POUNDif] = ACTIONS(12435),
    [anon_sym_POUNDIF] = ACTIONS(12435),
    [anon_sym_POUNDIf] = ACTIONS(12435),
    [anon_sym_POUNDelif] = ACTIONS(12435),
    [anon_sym_POUNDELIF] = ACTIONS(12435),
    [anon_sym_POUNDElif] = ACTIONS(12435),
    [anon_sym_POUNDelse] = ACTIONS(12435),
    [anon_sym_POUNDELSE] = ACTIONS(12435),
    [anon_sym_POUNDElse] = ACTIONS(12435),
    [anon_sym_POUNDelse2] = ACTIONS(12435),
    [anon_sym_POUNDELSE2] = ACTIONS(12435),
    [anon_sym_POUNDElse2] = ACTIONS(12435),
    [anon_sym_POUNDendif] = ACTIONS(12435),
    [anon_sym_POUNDENDIF] = ACTIONS(12435),
    [anon_sym_POUNDEndif] = ACTIONS(12435),
    [anon_sym_POUNDendif2] = ACTIONS(12435),
    [anon_sym_POUNDENDIF2] = ACTIONS(12435),
    [anon_sym_POUNDEndif2] = ACTIONS(12435),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12435),
    [sym_trigger_keyword] = ACTIONS(12435),
    [sym_var_keyword] = ACTIONS(12435),
    [sym_local_keyword] = ACTIONS(12435),
    [sym_internal_keyword] = ACTIONS(12435),
    [sym_protected_keyword] = ACTIONS(12435),
    [sym_event_keyword] = ACTIONS(12435),
    [sym_fields_keyword] = ACTIONS(12435),
    [sym_keys_keyword] = ACTIONS(12435),
    [sym_fieldgroups_keyword] = ACTIONS(12435),
    [sym_actions_keyword] = ACTIONS(12435),
    [sym_layout_keyword] = ACTIONS(12435),
    [sym_area_keyword] = ACTIONS(12435),
    [sym_group_keyword] = ACTIONS(12435),
    [sym_repeater_keyword] = ACTIONS(12435),
    [sym_cuegroup_keyword] = ACTIONS(12435),
    [sym_fixed_keyword] = ACTIONS(12435),
    [sym_grid_keyword] = ACTIONS(12435),
    [sym_part_keyword] = ACTIONS(12435),
    [sym_systempart_keyword] = ACTIONS(12435),
    [sym_usercontrol_keyword] = ACTIONS(12435),
    [sym_dataset_keyword] = ACTIONS(12435),
    [sym_elements_keyword] = ACTIONS(12435),
    [sym_dataitem_keyword] = ACTIONS(12435),
    [sym_column_keyword] = ACTIONS(12435),
    [sym_filter_keyword] = ACTIONS(12435),
    [sym_labels_keyword] = ACTIONS(12435),
    [sym_rendering_keyword] = ACTIONS(12435),
    [sym_requestpage_keyword] = ACTIONS(12435),
    [sym_schema_keyword] = ACTIONS(12435),
    [sym_views_keyword] = ACTIONS(12435),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12435),
    [sym_preproc_open] = ACTIONS(12435),
    [sym_preproc_close] = ACTIONS(12435),
  },
  [STATE(5064)] = {
    [anon_sym_SEMI] = ACTIONS(12437),
    [aux_sym_where_condition_token1] = ACTIONS(12433),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12435),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12435),
    [anon_sym_LBRACK] = ACTIONS(12435),
    [aux_sym_basic_type_token6] = ACTIONS(12433),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12435),
    [aux_sym_addafter_modification_token1] = ACTIONS(12435),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12435),
    [aux_sym_modify_modification_token1] = ACTIONS(12435),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12435),
    [aux_sym_movelast_modification_token1] = ACTIONS(12435),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12435),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12435),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12435),
    [anon_sym_POUNDif] = ACTIONS(12435),
    [anon_sym_POUNDIF] = ACTIONS(12435),
    [anon_sym_POUNDIf] = ACTIONS(12435),
    [anon_sym_POUNDelif] = ACTIONS(12435),
    [anon_sym_POUNDELIF] = ACTIONS(12435),
    [anon_sym_POUNDElif] = ACTIONS(12435),
    [anon_sym_POUNDelse] = ACTIONS(12435),
    [anon_sym_POUNDELSE] = ACTIONS(12435),
    [anon_sym_POUNDElse] = ACTIONS(12435),
    [anon_sym_POUNDelse2] = ACTIONS(12435),
    [anon_sym_POUNDELSE2] = ACTIONS(12435),
    [anon_sym_POUNDElse2] = ACTIONS(12435),
    [anon_sym_POUNDendif] = ACTIONS(12435),
    [anon_sym_POUNDENDIF] = ACTIONS(12435),
    [anon_sym_POUNDEndif] = ACTIONS(12435),
    [anon_sym_POUNDendif2] = ACTIONS(12435),
    [anon_sym_POUNDENDIF2] = ACTIONS(12435),
    [anon_sym_POUNDEndif2] = ACTIONS(12435),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12435),
    [sym_trigger_keyword] = ACTIONS(12435),
    [sym_var_keyword] = ACTIONS(12435),
    [sym_local_keyword] = ACTIONS(12435),
    [sym_internal_keyword] = ACTIONS(12435),
    [sym_protected_keyword] = ACTIONS(12435),
    [sym_event_keyword] = ACTIONS(12435),
    [sym_fields_keyword] = ACTIONS(12435),
    [sym_keys_keyword] = ACTIONS(12435),
    [sym_fieldgroups_keyword] = ACTIONS(12435),
    [sym_actions_keyword] = ACTIONS(12435),
    [sym_layout_keyword] = ACTIONS(12435),
    [sym_area_keyword] = ACTIONS(12435),
    [sym_group_keyword] = ACTIONS(12435),
    [sym_repeater_keyword] = ACTIONS(12435),
    [sym_cuegroup_keyword] = ACTIONS(12435),
    [sym_fixed_keyword] = ACTIONS(12435),
    [sym_grid_keyword] = ACTIONS(12435),
    [sym_part_keyword] = ACTIONS(12435),
    [sym_systempart_keyword] = ACTIONS(12435),
    [sym_usercontrol_keyword] = ACTIONS(12435),
    [sym_dataset_keyword] = ACTIONS(12435),
    [sym_elements_keyword] = ACTIONS(12435),
    [sym_dataitem_keyword] = ACTIONS(12435),
    [sym_column_keyword] = ACTIONS(12435),
    [sym_filter_keyword] = ACTIONS(12435),
    [sym_labels_keyword] = ACTIONS(12435),
    [sym_rendering_keyword] = ACTIONS(12435),
    [sym_requestpage_keyword] = ACTIONS(12435),
    [sym_schema_keyword] = ACTIONS(12435),
    [sym_views_keyword] = ACTIONS(12435),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12435),
    [sym_preproc_open] = ACTIONS(12435),
    [sym_preproc_close] = ACTIONS(12435),
  },
  [STATE(5065)] = {
    [anon_sym_SEMI] = ACTIONS(12439),
    [aux_sym_where_condition_token1] = ACTIONS(12441),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12439),
    [anon_sym_LBRACK] = ACTIONS(12439),
    [aux_sym_basic_type_token6] = ACTIONS(12441),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12439),
    [aux_sym_addafter_modification_token1] = ACTIONS(12439),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12439),
    [aux_sym_modify_modification_token1] = ACTIONS(12439),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12439),
    [aux_sym_movelast_modification_token1] = ACTIONS(12439),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12439),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12439),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12439),
    [anon_sym_POUNDif] = ACTIONS(12439),
    [anon_sym_POUNDIF] = ACTIONS(12439),
    [anon_sym_POUNDIf] = ACTIONS(12439),
    [anon_sym_POUNDelif] = ACTIONS(12439),
    [anon_sym_POUNDELIF] = ACTIONS(12439),
    [anon_sym_POUNDElif] = ACTIONS(12439),
    [anon_sym_POUNDelse] = ACTIONS(12439),
    [anon_sym_POUNDELSE] = ACTIONS(12439),
    [anon_sym_POUNDElse] = ACTIONS(12439),
    [anon_sym_POUNDelse2] = ACTIONS(12439),
    [anon_sym_POUNDELSE2] = ACTIONS(12439),
    [anon_sym_POUNDElse2] = ACTIONS(12439),
    [anon_sym_POUNDendif] = ACTIONS(12439),
    [anon_sym_POUNDENDIF] = ACTIONS(12439),
    [anon_sym_POUNDEndif] = ACTIONS(12439),
    [anon_sym_POUNDendif2] = ACTIONS(12439),
    [anon_sym_POUNDENDIF2] = ACTIONS(12439),
    [anon_sym_POUNDEndif2] = ACTIONS(12439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12439),
    [sym_trigger_keyword] = ACTIONS(12439),
    [sym_var_keyword] = ACTIONS(12439),
    [sym_local_keyword] = ACTIONS(12439),
    [sym_internal_keyword] = ACTIONS(12439),
    [sym_protected_keyword] = ACTIONS(12439),
    [sym_event_keyword] = ACTIONS(12439),
    [sym_fields_keyword] = ACTIONS(12439),
    [sym_keys_keyword] = ACTIONS(12439),
    [sym_fieldgroups_keyword] = ACTIONS(12439),
    [sym_actions_keyword] = ACTIONS(12439),
    [sym_layout_keyword] = ACTIONS(12439),
    [sym_area_keyword] = ACTIONS(12439),
    [sym_group_keyword] = ACTIONS(12439),
    [sym_repeater_keyword] = ACTIONS(12439),
    [sym_cuegroup_keyword] = ACTIONS(12439),
    [sym_fixed_keyword] = ACTIONS(12439),
    [sym_grid_keyword] = ACTIONS(12439),
    [sym_part_keyword] = ACTIONS(12439),
    [sym_systempart_keyword] = ACTIONS(12439),
    [sym_usercontrol_keyword] = ACTIONS(12439),
    [sym_dataset_keyword] = ACTIONS(12439),
    [sym_elements_keyword] = ACTIONS(12439),
    [sym_dataitem_keyword] = ACTIONS(12439),
    [sym_column_keyword] = ACTIONS(12439),
    [sym_filter_keyword] = ACTIONS(12439),
    [sym_labels_keyword] = ACTIONS(12439),
    [sym_rendering_keyword] = ACTIONS(12439),
    [sym_requestpage_keyword] = ACTIONS(12439),
    [sym_schema_keyword] = ACTIONS(12439),
    [sym_views_keyword] = ACTIONS(12439),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12439),
    [sym_preproc_open] = ACTIONS(12439),
    [sym_preproc_close] = ACTIONS(12439),
  },
  [STATE(5066)] = {
    [anon_sym_SEMI] = ACTIONS(12439),
    [aux_sym_where_condition_token1] = ACTIONS(12441),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12439),
    [anon_sym_LBRACK] = ACTIONS(12439),
    [aux_sym_basic_type_token6] = ACTIONS(12441),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12439),
    [aux_sym_addafter_modification_token1] = ACTIONS(12439),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12439),
    [aux_sym_modify_modification_token1] = ACTIONS(12439),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12439),
    [aux_sym_movelast_modification_token1] = ACTIONS(12439),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12439),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12439),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12439),
    [anon_sym_POUNDif] = ACTIONS(12439),
    [anon_sym_POUNDIF] = ACTIONS(12439),
    [anon_sym_POUNDIf] = ACTIONS(12439),
    [anon_sym_POUNDelif] = ACTIONS(12439),
    [anon_sym_POUNDELIF] = ACTIONS(12439),
    [anon_sym_POUNDElif] = ACTIONS(12439),
    [anon_sym_POUNDelse] = ACTIONS(12439),
    [anon_sym_POUNDELSE] = ACTIONS(12439),
    [anon_sym_POUNDElse] = ACTIONS(12439),
    [anon_sym_POUNDelse2] = ACTIONS(12439),
    [anon_sym_POUNDELSE2] = ACTIONS(12439),
    [anon_sym_POUNDElse2] = ACTIONS(12439),
    [anon_sym_POUNDendif] = ACTIONS(12439),
    [anon_sym_POUNDENDIF] = ACTIONS(12439),
    [anon_sym_POUNDEndif] = ACTIONS(12439),
    [anon_sym_POUNDendif2] = ACTIONS(12439),
    [anon_sym_POUNDENDIF2] = ACTIONS(12439),
    [anon_sym_POUNDEndif2] = ACTIONS(12439),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12439),
    [sym_trigger_keyword] = ACTIONS(12439),
    [sym_var_keyword] = ACTIONS(12439),
    [sym_local_keyword] = ACTIONS(12439),
    [sym_internal_keyword] = ACTIONS(12439),
    [sym_protected_keyword] = ACTIONS(12439),
    [sym_event_keyword] = ACTIONS(12439),
    [sym_fields_keyword] = ACTIONS(12439),
    [sym_keys_keyword] = ACTIONS(12439),
    [sym_fieldgroups_keyword] = ACTIONS(12439),
    [sym_actions_keyword] = ACTIONS(12439),
    [sym_layout_keyword] = ACTIONS(12439),
    [sym_area_keyword] = ACTIONS(12439),
    [sym_group_keyword] = ACTIONS(12439),
    [sym_repeater_keyword] = ACTIONS(12439),
    [sym_cuegroup_keyword] = ACTIONS(12439),
    [sym_fixed_keyword] = ACTIONS(12439),
    [sym_grid_keyword] = ACTIONS(12439),
    [sym_part_keyword] = ACTIONS(12439),
    [sym_systempart_keyword] = ACTIONS(12439),
    [sym_usercontrol_keyword] = ACTIONS(12439),
    [sym_dataset_keyword] = ACTIONS(12439),
    [sym_elements_keyword] = ACTIONS(12439),
    [sym_dataitem_keyword] = ACTIONS(12439),
    [sym_column_keyword] = ACTIONS(12439),
    [sym_filter_keyword] = ACTIONS(12439),
    [sym_labels_keyword] = ACTIONS(12439),
    [sym_rendering_keyword] = ACTIONS(12439),
    [sym_requestpage_keyword] = ACTIONS(12439),
    [sym_schema_keyword] = ACTIONS(12439),
    [sym_views_keyword] = ACTIONS(12439),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12439),
    [sym_preproc_open] = ACTIONS(12439),
    [sym_preproc_close] = ACTIONS(12439),
  },
  [STATE(5067)] = {
    [anon_sym_SEMI] = ACTIONS(12443),
    [aux_sym_where_condition_token1] = ACTIONS(12445),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12443),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12443),
    [anon_sym_LBRACK] = ACTIONS(12443),
    [aux_sym_basic_type_token6] = ACTIONS(12445),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12443),
    [aux_sym_addafter_modification_token1] = ACTIONS(12443),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12443),
    [aux_sym_modify_modification_token1] = ACTIONS(12443),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12443),
    [aux_sym_movelast_modification_token1] = ACTIONS(12443),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12443),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12443),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12443),
    [anon_sym_POUNDif] = ACTIONS(12443),
    [anon_sym_POUNDIF] = ACTIONS(12443),
    [anon_sym_POUNDIf] = ACTIONS(12443),
    [anon_sym_POUNDelif] = ACTIONS(12443),
    [anon_sym_POUNDELIF] = ACTIONS(12443),
    [anon_sym_POUNDElif] = ACTIONS(12443),
    [anon_sym_POUNDelse] = ACTIONS(12443),
    [anon_sym_POUNDELSE] = ACTIONS(12443),
    [anon_sym_POUNDElse] = ACTIONS(12443),
    [anon_sym_POUNDelse2] = ACTIONS(12443),
    [anon_sym_POUNDELSE2] = ACTIONS(12443),
    [anon_sym_POUNDElse2] = ACTIONS(12443),
    [anon_sym_POUNDendif] = ACTIONS(12443),
    [anon_sym_POUNDENDIF] = ACTIONS(12443),
    [anon_sym_POUNDEndif] = ACTIONS(12443),
    [anon_sym_POUNDendif2] = ACTIONS(12443),
    [anon_sym_POUNDENDIF2] = ACTIONS(12443),
    [anon_sym_POUNDEndif2] = ACTIONS(12443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12443),
    [sym_trigger_keyword] = ACTIONS(12443),
    [sym_var_keyword] = ACTIONS(12443),
    [sym_local_keyword] = ACTIONS(12443),
    [sym_internal_keyword] = ACTIONS(12443),
    [sym_protected_keyword] = ACTIONS(12443),
    [sym_event_keyword] = ACTIONS(12443),
    [sym_fields_keyword] = ACTIONS(12443),
    [sym_keys_keyword] = ACTIONS(12443),
    [sym_fieldgroups_keyword] = ACTIONS(12443),
    [sym_actions_keyword] = ACTIONS(12443),
    [sym_layout_keyword] = ACTIONS(12443),
    [sym_area_keyword] = ACTIONS(12443),
    [sym_group_keyword] = ACTIONS(12443),
    [sym_repeater_keyword] = ACTIONS(12443),
    [sym_cuegroup_keyword] = ACTIONS(12443),
    [sym_fixed_keyword] = ACTIONS(12443),
    [sym_grid_keyword] = ACTIONS(12443),
    [sym_part_keyword] = ACTIONS(12443),
    [sym_systempart_keyword] = ACTIONS(12443),
    [sym_usercontrol_keyword] = ACTIONS(12443),
    [sym_dataset_keyword] = ACTIONS(12443),
    [sym_elements_keyword] = ACTIONS(12443),
    [sym_dataitem_keyword] = ACTIONS(12443),
    [sym_column_keyword] = ACTIONS(12443),
    [sym_filter_keyword] = ACTIONS(12443),
    [sym_labels_keyword] = ACTIONS(12443),
    [sym_rendering_keyword] = ACTIONS(12443),
    [sym_requestpage_keyword] = ACTIONS(12443),
    [sym_schema_keyword] = ACTIONS(12443),
    [sym_views_keyword] = ACTIONS(12443),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12443),
    [sym_preproc_open] = ACTIONS(12443),
    [sym_preproc_close] = ACTIONS(12443),
  },
  [STATE(5068)] = {
    [anon_sym_SEMI] = ACTIONS(12443),
    [aux_sym_where_condition_token1] = ACTIONS(12445),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12443),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12443),
    [anon_sym_LBRACK] = ACTIONS(12443),
    [aux_sym_basic_type_token6] = ACTIONS(12445),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12443),
    [aux_sym_addafter_modification_token1] = ACTIONS(12443),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12443),
    [aux_sym_modify_modification_token1] = ACTIONS(12443),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12443),
    [aux_sym_movelast_modification_token1] = ACTIONS(12443),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12443),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12443),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12443),
    [anon_sym_POUNDif] = ACTIONS(12443),
    [anon_sym_POUNDIF] = ACTIONS(12443),
    [anon_sym_POUNDIf] = ACTIONS(12443),
    [anon_sym_POUNDelif] = ACTIONS(12443),
    [anon_sym_POUNDELIF] = ACTIONS(12443),
    [anon_sym_POUNDElif] = ACTIONS(12443),
    [anon_sym_POUNDelse] = ACTIONS(12443),
    [anon_sym_POUNDELSE] = ACTIONS(12443),
    [anon_sym_POUNDElse] = ACTIONS(12443),
    [anon_sym_POUNDelse2] = ACTIONS(12443),
    [anon_sym_POUNDELSE2] = ACTIONS(12443),
    [anon_sym_POUNDElse2] = ACTIONS(12443),
    [anon_sym_POUNDendif] = ACTIONS(12443),
    [anon_sym_POUNDENDIF] = ACTIONS(12443),
    [anon_sym_POUNDEndif] = ACTIONS(12443),
    [anon_sym_POUNDendif2] = ACTIONS(12443),
    [anon_sym_POUNDENDIF2] = ACTIONS(12443),
    [anon_sym_POUNDEndif2] = ACTIONS(12443),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12443),
    [sym_trigger_keyword] = ACTIONS(12443),
    [sym_var_keyword] = ACTIONS(12443),
    [sym_local_keyword] = ACTIONS(12443),
    [sym_internal_keyword] = ACTIONS(12443),
    [sym_protected_keyword] = ACTIONS(12443),
    [sym_event_keyword] = ACTIONS(12443),
    [sym_fields_keyword] = ACTIONS(12443),
    [sym_keys_keyword] = ACTIONS(12443),
    [sym_fieldgroups_keyword] = ACTIONS(12443),
    [sym_actions_keyword] = ACTIONS(12443),
    [sym_layout_keyword] = ACTIONS(12443),
    [sym_area_keyword] = ACTIONS(12443),
    [sym_group_keyword] = ACTIONS(12443),
    [sym_repeater_keyword] = ACTIONS(12443),
    [sym_cuegroup_keyword] = ACTIONS(12443),
    [sym_fixed_keyword] = ACTIONS(12443),
    [sym_grid_keyword] = ACTIONS(12443),
    [sym_part_keyword] = ACTIONS(12443),
    [sym_systempart_keyword] = ACTIONS(12443),
    [sym_usercontrol_keyword] = ACTIONS(12443),
    [sym_dataset_keyword] = ACTIONS(12443),
    [sym_elements_keyword] = ACTIONS(12443),
    [sym_dataitem_keyword] = ACTIONS(12443),
    [sym_column_keyword] = ACTIONS(12443),
    [sym_filter_keyword] = ACTIONS(12443),
    [sym_labels_keyword] = ACTIONS(12443),
    [sym_rendering_keyword] = ACTIONS(12443),
    [sym_requestpage_keyword] = ACTIONS(12443),
    [sym_schema_keyword] = ACTIONS(12443),
    [sym_views_keyword] = ACTIONS(12443),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12443),
    [sym_preproc_open] = ACTIONS(12443),
    [sym_preproc_close] = ACTIONS(12443),
  },
  [STATE(5069)] = {
    [anon_sym_SEMI] = ACTIONS(12447),
    [aux_sym_where_condition_token1] = ACTIONS(12449),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12451),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12451),
    [anon_sym_LBRACK] = ACTIONS(12451),
    [aux_sym_basic_type_token6] = ACTIONS(12449),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12451),
    [aux_sym_addafter_modification_token1] = ACTIONS(12451),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12451),
    [aux_sym_modify_modification_token1] = ACTIONS(12451),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12451),
    [aux_sym_movelast_modification_token1] = ACTIONS(12451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12451),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12451),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12451),
    [anon_sym_POUNDif] = ACTIONS(12451),
    [anon_sym_POUNDIF] = ACTIONS(12451),
    [anon_sym_POUNDIf] = ACTIONS(12451),
    [anon_sym_POUNDelif] = ACTIONS(12451),
    [anon_sym_POUNDELIF] = ACTIONS(12451),
    [anon_sym_POUNDElif] = ACTIONS(12451),
    [anon_sym_POUNDelse] = ACTIONS(12451),
    [anon_sym_POUNDELSE] = ACTIONS(12451),
    [anon_sym_POUNDElse] = ACTIONS(12451),
    [anon_sym_POUNDelse2] = ACTIONS(12451),
    [anon_sym_POUNDELSE2] = ACTIONS(12451),
    [anon_sym_POUNDElse2] = ACTIONS(12451),
    [anon_sym_POUNDendif] = ACTIONS(12451),
    [anon_sym_POUNDENDIF] = ACTIONS(12451),
    [anon_sym_POUNDEndif] = ACTIONS(12451),
    [anon_sym_POUNDendif2] = ACTIONS(12451),
    [anon_sym_POUNDENDIF2] = ACTIONS(12451),
    [anon_sym_POUNDEndif2] = ACTIONS(12451),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12451),
    [sym_trigger_keyword] = ACTIONS(12451),
    [sym_var_keyword] = ACTIONS(12451),
    [sym_local_keyword] = ACTIONS(12451),
    [sym_internal_keyword] = ACTIONS(12451),
    [sym_protected_keyword] = ACTIONS(12451),
    [sym_event_keyword] = ACTIONS(12451),
    [sym_fields_keyword] = ACTIONS(12451),
    [sym_keys_keyword] = ACTIONS(12451),
    [sym_fieldgroups_keyword] = ACTIONS(12451),
    [sym_actions_keyword] = ACTIONS(12451),
    [sym_layout_keyword] = ACTIONS(12451),
    [sym_area_keyword] = ACTIONS(12451),
    [sym_group_keyword] = ACTIONS(12451),
    [sym_repeater_keyword] = ACTIONS(12451),
    [sym_cuegroup_keyword] = ACTIONS(12451),
    [sym_fixed_keyword] = ACTIONS(12451),
    [sym_grid_keyword] = ACTIONS(12451),
    [sym_part_keyword] = ACTIONS(12451),
    [sym_systempart_keyword] = ACTIONS(12451),
    [sym_usercontrol_keyword] = ACTIONS(12451),
    [sym_dataset_keyword] = ACTIONS(12451),
    [sym_elements_keyword] = ACTIONS(12451),
    [sym_dataitem_keyword] = ACTIONS(12451),
    [sym_column_keyword] = ACTIONS(12451),
    [sym_filter_keyword] = ACTIONS(12451),
    [sym_labels_keyword] = ACTIONS(12451),
    [sym_rendering_keyword] = ACTIONS(12451),
    [sym_requestpage_keyword] = ACTIONS(12451),
    [sym_schema_keyword] = ACTIONS(12451),
    [sym_views_keyword] = ACTIONS(12451),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12451),
    [sym_preproc_open] = ACTIONS(12451),
    [sym_preproc_close] = ACTIONS(12451),
  },
  [STATE(5070)] = {
    [anon_sym_SEMI] = ACTIONS(12453),
    [aux_sym_where_condition_token1] = ACTIONS(12449),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12451),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12451),
    [anon_sym_LBRACK] = ACTIONS(12451),
    [aux_sym_basic_type_token6] = ACTIONS(12449),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12451),
    [aux_sym_addafter_modification_token1] = ACTIONS(12451),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12451),
    [aux_sym_modify_modification_token1] = ACTIONS(12451),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12451),
    [aux_sym_movelast_modification_token1] = ACTIONS(12451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12451),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12451),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12451),
    [anon_sym_POUNDif] = ACTIONS(12451),
    [anon_sym_POUNDIF] = ACTIONS(12451),
    [anon_sym_POUNDIf] = ACTIONS(12451),
    [anon_sym_POUNDelif] = ACTIONS(12451),
    [anon_sym_POUNDELIF] = ACTIONS(12451),
    [anon_sym_POUNDElif] = ACTIONS(12451),
    [anon_sym_POUNDelse] = ACTIONS(12451),
    [anon_sym_POUNDELSE] = ACTIONS(12451),
    [anon_sym_POUNDElse] = ACTIONS(12451),
    [anon_sym_POUNDelse2] = ACTIONS(12451),
    [anon_sym_POUNDELSE2] = ACTIONS(12451),
    [anon_sym_POUNDElse2] = ACTIONS(12451),
    [anon_sym_POUNDendif] = ACTIONS(12451),
    [anon_sym_POUNDENDIF] = ACTIONS(12451),
    [anon_sym_POUNDEndif] = ACTIONS(12451),
    [anon_sym_POUNDendif2] = ACTIONS(12451),
    [anon_sym_POUNDENDIF2] = ACTIONS(12451),
    [anon_sym_POUNDEndif2] = ACTIONS(12451),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12451),
    [sym_trigger_keyword] = ACTIONS(12451),
    [sym_var_keyword] = ACTIONS(12451),
    [sym_local_keyword] = ACTIONS(12451),
    [sym_internal_keyword] = ACTIONS(12451),
    [sym_protected_keyword] = ACTIONS(12451),
    [sym_event_keyword] = ACTIONS(12451),
    [sym_fields_keyword] = ACTIONS(12451),
    [sym_keys_keyword] = ACTIONS(12451),
    [sym_fieldgroups_keyword] = ACTIONS(12451),
    [sym_actions_keyword] = ACTIONS(12451),
    [sym_layout_keyword] = ACTIONS(12451),
    [sym_area_keyword] = ACTIONS(12451),
    [sym_group_keyword] = ACTIONS(12451),
    [sym_repeater_keyword] = ACTIONS(12451),
    [sym_cuegroup_keyword] = ACTIONS(12451),
    [sym_fixed_keyword] = ACTIONS(12451),
    [sym_grid_keyword] = ACTIONS(12451),
    [sym_part_keyword] = ACTIONS(12451),
    [sym_systempart_keyword] = ACTIONS(12451),
    [sym_usercontrol_keyword] = ACTIONS(12451),
    [sym_dataset_keyword] = ACTIONS(12451),
    [sym_elements_keyword] = ACTIONS(12451),
    [sym_dataitem_keyword] = ACTIONS(12451),
    [sym_column_keyword] = ACTIONS(12451),
    [sym_filter_keyword] = ACTIONS(12451),
    [sym_labels_keyword] = ACTIONS(12451),
    [sym_rendering_keyword] = ACTIONS(12451),
    [sym_requestpage_keyword] = ACTIONS(12451),
    [sym_schema_keyword] = ACTIONS(12451),
    [sym_views_keyword] = ACTIONS(12451),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12451),
    [sym_preproc_open] = ACTIONS(12451),
    [sym_preproc_close] = ACTIONS(12451),
  },
  [STATE(5071)] = {
    [anon_sym_SEMI] = ACTIONS(12455),
    [aux_sym_where_condition_token1] = ACTIONS(12457),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12455),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12455),
    [anon_sym_LBRACK] = ACTIONS(12455),
    [aux_sym_basic_type_token6] = ACTIONS(12457),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12455),
    [aux_sym_addafter_modification_token1] = ACTIONS(12455),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12455),
    [aux_sym_modify_modification_token1] = ACTIONS(12455),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12455),
    [aux_sym_movelast_modification_token1] = ACTIONS(12455),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12455),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12455),
    [anon_sym_POUNDif] = ACTIONS(12455),
    [anon_sym_POUNDIF] = ACTIONS(12455),
    [anon_sym_POUNDIf] = ACTIONS(12455),
    [anon_sym_POUNDelif] = ACTIONS(12455),
    [anon_sym_POUNDELIF] = ACTIONS(12455),
    [anon_sym_POUNDElif] = ACTIONS(12455),
    [anon_sym_POUNDelse] = ACTIONS(12455),
    [anon_sym_POUNDELSE] = ACTIONS(12455),
    [anon_sym_POUNDElse] = ACTIONS(12455),
    [anon_sym_POUNDelse2] = ACTIONS(12455),
    [anon_sym_POUNDELSE2] = ACTIONS(12455),
    [anon_sym_POUNDElse2] = ACTIONS(12455),
    [anon_sym_POUNDendif] = ACTIONS(12455),
    [anon_sym_POUNDENDIF] = ACTIONS(12455),
    [anon_sym_POUNDEndif] = ACTIONS(12455),
    [anon_sym_POUNDendif2] = ACTIONS(12455),
    [anon_sym_POUNDENDIF2] = ACTIONS(12455),
    [anon_sym_POUNDEndif2] = ACTIONS(12455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12455),
    [sym_trigger_keyword] = ACTIONS(12455),
    [sym_var_keyword] = ACTIONS(12455),
    [sym_local_keyword] = ACTIONS(12455),
    [sym_internal_keyword] = ACTIONS(12455),
    [sym_protected_keyword] = ACTIONS(12455),
    [sym_event_keyword] = ACTIONS(12455),
    [sym_fields_keyword] = ACTIONS(12455),
    [sym_keys_keyword] = ACTIONS(12455),
    [sym_fieldgroups_keyword] = ACTIONS(12455),
    [sym_actions_keyword] = ACTIONS(12455),
    [sym_layout_keyword] = ACTIONS(12455),
    [sym_area_keyword] = ACTIONS(12455),
    [sym_group_keyword] = ACTIONS(12455),
    [sym_repeater_keyword] = ACTIONS(12455),
    [sym_cuegroup_keyword] = ACTIONS(12455),
    [sym_fixed_keyword] = ACTIONS(12455),
    [sym_grid_keyword] = ACTIONS(12455),
    [sym_part_keyword] = ACTIONS(12455),
    [sym_systempart_keyword] = ACTIONS(12455),
    [sym_usercontrol_keyword] = ACTIONS(12455),
    [sym_dataset_keyword] = ACTIONS(12455),
    [sym_elements_keyword] = ACTIONS(12455),
    [sym_dataitem_keyword] = ACTIONS(12455),
    [sym_column_keyword] = ACTIONS(12455),
    [sym_filter_keyword] = ACTIONS(12455),
    [sym_labels_keyword] = ACTIONS(12455),
    [sym_rendering_keyword] = ACTIONS(12455),
    [sym_requestpage_keyword] = ACTIONS(12455),
    [sym_schema_keyword] = ACTIONS(12455),
    [sym_views_keyword] = ACTIONS(12455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12455),
    [sym_preproc_open] = ACTIONS(12455),
    [sym_preproc_close] = ACTIONS(12455),
  },
  [STATE(5072)] = {
    [anon_sym_SEMI] = ACTIONS(12455),
    [aux_sym_where_condition_token1] = ACTIONS(12457),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12455),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12455),
    [anon_sym_LBRACK] = ACTIONS(12455),
    [aux_sym_basic_type_token6] = ACTIONS(12457),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12455),
    [aux_sym_addafter_modification_token1] = ACTIONS(12455),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12455),
    [aux_sym_modify_modification_token1] = ACTIONS(12455),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12455),
    [aux_sym_movelast_modification_token1] = ACTIONS(12455),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12455),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12455),
    [anon_sym_POUNDif] = ACTIONS(12455),
    [anon_sym_POUNDIF] = ACTIONS(12455),
    [anon_sym_POUNDIf] = ACTIONS(12455),
    [anon_sym_POUNDelif] = ACTIONS(12455),
    [anon_sym_POUNDELIF] = ACTIONS(12455),
    [anon_sym_POUNDElif] = ACTIONS(12455),
    [anon_sym_POUNDelse] = ACTIONS(12455),
    [anon_sym_POUNDELSE] = ACTIONS(12455),
    [anon_sym_POUNDElse] = ACTIONS(12455),
    [anon_sym_POUNDelse2] = ACTIONS(12455),
    [anon_sym_POUNDELSE2] = ACTIONS(12455),
    [anon_sym_POUNDElse2] = ACTIONS(12455),
    [anon_sym_POUNDendif] = ACTIONS(12455),
    [anon_sym_POUNDENDIF] = ACTIONS(12455),
    [anon_sym_POUNDEndif] = ACTIONS(12455),
    [anon_sym_POUNDendif2] = ACTIONS(12455),
    [anon_sym_POUNDENDIF2] = ACTIONS(12455),
    [anon_sym_POUNDEndif2] = ACTIONS(12455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12455),
    [sym_trigger_keyword] = ACTIONS(12455),
    [sym_var_keyword] = ACTIONS(12455),
    [sym_local_keyword] = ACTIONS(12455),
    [sym_internal_keyword] = ACTIONS(12455),
    [sym_protected_keyword] = ACTIONS(12455),
    [sym_event_keyword] = ACTIONS(12455),
    [sym_fields_keyword] = ACTIONS(12455),
    [sym_keys_keyword] = ACTIONS(12455),
    [sym_fieldgroups_keyword] = ACTIONS(12455),
    [sym_actions_keyword] = ACTIONS(12455),
    [sym_layout_keyword] = ACTIONS(12455),
    [sym_area_keyword] = ACTIONS(12455),
    [sym_group_keyword] = ACTIONS(12455),
    [sym_repeater_keyword] = ACTIONS(12455),
    [sym_cuegroup_keyword] = ACTIONS(12455),
    [sym_fixed_keyword] = ACTIONS(12455),
    [sym_grid_keyword] = ACTIONS(12455),
    [sym_part_keyword] = ACTIONS(12455),
    [sym_systempart_keyword] = ACTIONS(12455),
    [sym_usercontrol_keyword] = ACTIONS(12455),
    [sym_dataset_keyword] = ACTIONS(12455),
    [sym_elements_keyword] = ACTIONS(12455),
    [sym_dataitem_keyword] = ACTIONS(12455),
    [sym_column_keyword] = ACTIONS(12455),
    [sym_filter_keyword] = ACTIONS(12455),
    [sym_labels_keyword] = ACTIONS(12455),
    [sym_rendering_keyword] = ACTIONS(12455),
    [sym_requestpage_keyword] = ACTIONS(12455),
    [sym_schema_keyword] = ACTIONS(12455),
    [sym_views_keyword] = ACTIONS(12455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12455),
    [sym_preproc_open] = ACTIONS(12455),
    [sym_preproc_close] = ACTIONS(12455),
  },
  [STATE(5073)] = {
    [anon_sym_SEMI] = ACTIONS(12459),
    [aux_sym_where_condition_token1] = ACTIONS(12461),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12463),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12463),
    [anon_sym_LBRACK] = ACTIONS(12463),
    [aux_sym_basic_type_token6] = ACTIONS(12461),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12463),
    [aux_sym_addafter_modification_token1] = ACTIONS(12463),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12463),
    [aux_sym_modify_modification_token1] = ACTIONS(12463),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12463),
    [aux_sym_movelast_modification_token1] = ACTIONS(12463),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12463),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12463),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12463),
    [anon_sym_POUNDif] = ACTIONS(12463),
    [anon_sym_POUNDIF] = ACTIONS(12463),
    [anon_sym_POUNDIf] = ACTIONS(12463),
    [anon_sym_POUNDelif] = ACTIONS(12463),
    [anon_sym_POUNDELIF] = ACTIONS(12463),
    [anon_sym_POUNDElif] = ACTIONS(12463),
    [anon_sym_POUNDelse] = ACTIONS(12463),
    [anon_sym_POUNDELSE] = ACTIONS(12463),
    [anon_sym_POUNDElse] = ACTIONS(12463),
    [anon_sym_POUNDelse2] = ACTIONS(12463),
    [anon_sym_POUNDELSE2] = ACTIONS(12463),
    [anon_sym_POUNDElse2] = ACTIONS(12463),
    [anon_sym_POUNDendif] = ACTIONS(12463),
    [anon_sym_POUNDENDIF] = ACTIONS(12463),
    [anon_sym_POUNDEndif] = ACTIONS(12463),
    [anon_sym_POUNDendif2] = ACTIONS(12463),
    [anon_sym_POUNDENDIF2] = ACTIONS(12463),
    [anon_sym_POUNDEndif2] = ACTIONS(12463),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12463),
    [sym_trigger_keyword] = ACTIONS(12463),
    [sym_var_keyword] = ACTIONS(12463),
    [sym_local_keyword] = ACTIONS(12463),
    [sym_internal_keyword] = ACTIONS(12463),
    [sym_protected_keyword] = ACTIONS(12463),
    [sym_event_keyword] = ACTIONS(12463),
    [sym_fields_keyword] = ACTIONS(12463),
    [sym_keys_keyword] = ACTIONS(12463),
    [sym_fieldgroups_keyword] = ACTIONS(12463),
    [sym_actions_keyword] = ACTIONS(12463),
    [sym_layout_keyword] = ACTIONS(12463),
    [sym_area_keyword] = ACTIONS(12463),
    [sym_group_keyword] = ACTIONS(12463),
    [sym_repeater_keyword] = ACTIONS(12463),
    [sym_cuegroup_keyword] = ACTIONS(12463),
    [sym_fixed_keyword] = ACTIONS(12463),
    [sym_grid_keyword] = ACTIONS(12463),
    [sym_part_keyword] = ACTIONS(12463),
    [sym_systempart_keyword] = ACTIONS(12463),
    [sym_usercontrol_keyword] = ACTIONS(12463),
    [sym_dataset_keyword] = ACTIONS(12463),
    [sym_elements_keyword] = ACTIONS(12463),
    [sym_dataitem_keyword] = ACTIONS(12463),
    [sym_column_keyword] = ACTIONS(12463),
    [sym_filter_keyword] = ACTIONS(12463),
    [sym_labels_keyword] = ACTIONS(12463),
    [sym_rendering_keyword] = ACTIONS(12463),
    [sym_requestpage_keyword] = ACTIONS(12463),
    [sym_schema_keyword] = ACTIONS(12463),
    [sym_views_keyword] = ACTIONS(12463),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12463),
    [sym_preproc_open] = ACTIONS(12463),
    [sym_preproc_close] = ACTIONS(12463),
  },
  [STATE(5074)] = {
    [anon_sym_SEMI] = ACTIONS(12465),
    [aux_sym_where_condition_token1] = ACTIONS(12461),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12463),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12463),
    [anon_sym_LBRACK] = ACTIONS(12463),
    [aux_sym_basic_type_token6] = ACTIONS(12461),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12463),
    [aux_sym_addafter_modification_token1] = ACTIONS(12463),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12463),
    [aux_sym_modify_modification_token1] = ACTIONS(12463),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12463),
    [aux_sym_movelast_modification_token1] = ACTIONS(12463),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12463),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12463),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12463),
    [anon_sym_POUNDif] = ACTIONS(12463),
    [anon_sym_POUNDIF] = ACTIONS(12463),
    [anon_sym_POUNDIf] = ACTIONS(12463),
    [anon_sym_POUNDelif] = ACTIONS(12463),
    [anon_sym_POUNDELIF] = ACTIONS(12463),
    [anon_sym_POUNDElif] = ACTIONS(12463),
    [anon_sym_POUNDelse] = ACTIONS(12463),
    [anon_sym_POUNDELSE] = ACTIONS(12463),
    [anon_sym_POUNDElse] = ACTIONS(12463),
    [anon_sym_POUNDelse2] = ACTIONS(12463),
    [anon_sym_POUNDELSE2] = ACTIONS(12463),
    [anon_sym_POUNDElse2] = ACTIONS(12463),
    [anon_sym_POUNDendif] = ACTIONS(12463),
    [anon_sym_POUNDENDIF] = ACTIONS(12463),
    [anon_sym_POUNDEndif] = ACTIONS(12463),
    [anon_sym_POUNDendif2] = ACTIONS(12463),
    [anon_sym_POUNDENDIF2] = ACTIONS(12463),
    [anon_sym_POUNDEndif2] = ACTIONS(12463),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12463),
    [sym_trigger_keyword] = ACTIONS(12463),
    [sym_var_keyword] = ACTIONS(12463),
    [sym_local_keyword] = ACTIONS(12463),
    [sym_internal_keyword] = ACTIONS(12463),
    [sym_protected_keyword] = ACTIONS(12463),
    [sym_event_keyword] = ACTIONS(12463),
    [sym_fields_keyword] = ACTIONS(12463),
    [sym_keys_keyword] = ACTIONS(12463),
    [sym_fieldgroups_keyword] = ACTIONS(12463),
    [sym_actions_keyword] = ACTIONS(12463),
    [sym_layout_keyword] = ACTIONS(12463),
    [sym_area_keyword] = ACTIONS(12463),
    [sym_group_keyword] = ACTIONS(12463),
    [sym_repeater_keyword] = ACTIONS(12463),
    [sym_cuegroup_keyword] = ACTIONS(12463),
    [sym_fixed_keyword] = ACTIONS(12463),
    [sym_grid_keyword] = ACTIONS(12463),
    [sym_part_keyword] = ACTIONS(12463),
    [sym_systempart_keyword] = ACTIONS(12463),
    [sym_usercontrol_keyword] = ACTIONS(12463),
    [sym_dataset_keyword] = ACTIONS(12463),
    [sym_elements_keyword] = ACTIONS(12463),
    [sym_dataitem_keyword] = ACTIONS(12463),
    [sym_column_keyword] = ACTIONS(12463),
    [sym_filter_keyword] = ACTIONS(12463),
    [sym_labels_keyword] = ACTIONS(12463),
    [sym_rendering_keyword] = ACTIONS(12463),
    [sym_requestpage_keyword] = ACTIONS(12463),
    [sym_schema_keyword] = ACTIONS(12463),
    [sym_views_keyword] = ACTIONS(12463),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12463),
    [sym_preproc_open] = ACTIONS(12463),
    [sym_preproc_close] = ACTIONS(12463),
  },
  [STATE(5075)] = {
    [anon_sym_SEMI] = ACTIONS(12467),
    [aux_sym_where_condition_token1] = ACTIONS(12457),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12455),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12455),
    [anon_sym_LBRACK] = ACTIONS(12455),
    [aux_sym_basic_type_token6] = ACTIONS(12457),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12455),
    [aux_sym_addafter_modification_token1] = ACTIONS(12455),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12455),
    [aux_sym_modify_modification_token1] = ACTIONS(12455),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12455),
    [aux_sym_movelast_modification_token1] = ACTIONS(12455),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12455),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12455),
    [anon_sym_POUNDif] = ACTIONS(12455),
    [anon_sym_POUNDIF] = ACTIONS(12455),
    [anon_sym_POUNDIf] = ACTIONS(12455),
    [anon_sym_POUNDelif] = ACTIONS(12455),
    [anon_sym_POUNDELIF] = ACTIONS(12455),
    [anon_sym_POUNDElif] = ACTIONS(12455),
    [anon_sym_POUNDelse] = ACTIONS(12455),
    [anon_sym_POUNDELSE] = ACTIONS(12455),
    [anon_sym_POUNDElse] = ACTIONS(12455),
    [anon_sym_POUNDelse2] = ACTIONS(12455),
    [anon_sym_POUNDELSE2] = ACTIONS(12455),
    [anon_sym_POUNDElse2] = ACTIONS(12455),
    [anon_sym_POUNDendif] = ACTIONS(12455),
    [anon_sym_POUNDENDIF] = ACTIONS(12455),
    [anon_sym_POUNDEndif] = ACTIONS(12455),
    [anon_sym_POUNDendif2] = ACTIONS(12455),
    [anon_sym_POUNDENDIF2] = ACTIONS(12455),
    [anon_sym_POUNDEndif2] = ACTIONS(12455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12455),
    [sym_trigger_keyword] = ACTIONS(12455),
    [sym_var_keyword] = ACTIONS(12455),
    [sym_local_keyword] = ACTIONS(12455),
    [sym_internal_keyword] = ACTIONS(12455),
    [sym_protected_keyword] = ACTIONS(12455),
    [sym_event_keyword] = ACTIONS(12455),
    [sym_fields_keyword] = ACTIONS(12455),
    [sym_keys_keyword] = ACTIONS(12455),
    [sym_fieldgroups_keyword] = ACTIONS(12455),
    [sym_actions_keyword] = ACTIONS(12455),
    [sym_layout_keyword] = ACTIONS(12455),
    [sym_area_keyword] = ACTIONS(12455),
    [sym_group_keyword] = ACTIONS(12455),
    [sym_repeater_keyword] = ACTIONS(12455),
    [sym_cuegroup_keyword] = ACTIONS(12455),
    [sym_fixed_keyword] = ACTIONS(12455),
    [sym_grid_keyword] = ACTIONS(12455),
    [sym_part_keyword] = ACTIONS(12455),
    [sym_systempart_keyword] = ACTIONS(12455),
    [sym_usercontrol_keyword] = ACTIONS(12455),
    [sym_dataset_keyword] = ACTIONS(12455),
    [sym_elements_keyword] = ACTIONS(12455),
    [sym_dataitem_keyword] = ACTIONS(12455),
    [sym_column_keyword] = ACTIONS(12455),
    [sym_filter_keyword] = ACTIONS(12455),
    [sym_labels_keyword] = ACTIONS(12455),
    [sym_rendering_keyword] = ACTIONS(12455),
    [sym_requestpage_keyword] = ACTIONS(12455),
    [sym_schema_keyword] = ACTIONS(12455),
    [sym_views_keyword] = ACTIONS(12455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12455),
    [sym_preproc_open] = ACTIONS(12455),
    [sym_preproc_close] = ACTIONS(12455),
  },
  [STATE(5076)] = {
    [anon_sym_SEMI] = ACTIONS(12469),
    [aux_sym_where_condition_token1] = ACTIONS(12457),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12455),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12455),
    [anon_sym_LBRACK] = ACTIONS(12455),
    [aux_sym_basic_type_token6] = ACTIONS(12457),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12455),
    [aux_sym_addafter_modification_token1] = ACTIONS(12455),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12455),
    [aux_sym_modify_modification_token1] = ACTIONS(12455),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12455),
    [aux_sym_movelast_modification_token1] = ACTIONS(12455),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12455),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12455),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12455),
    [anon_sym_POUNDif] = ACTIONS(12455),
    [anon_sym_POUNDIF] = ACTIONS(12455),
    [anon_sym_POUNDIf] = ACTIONS(12455),
    [anon_sym_POUNDelif] = ACTIONS(12455),
    [anon_sym_POUNDELIF] = ACTIONS(12455),
    [anon_sym_POUNDElif] = ACTIONS(12455),
    [anon_sym_POUNDelse] = ACTIONS(12455),
    [anon_sym_POUNDELSE] = ACTIONS(12455),
    [anon_sym_POUNDElse] = ACTIONS(12455),
    [anon_sym_POUNDelse2] = ACTIONS(12455),
    [anon_sym_POUNDELSE2] = ACTIONS(12455),
    [anon_sym_POUNDElse2] = ACTIONS(12455),
    [anon_sym_POUNDendif] = ACTIONS(12455),
    [anon_sym_POUNDENDIF] = ACTIONS(12455),
    [anon_sym_POUNDEndif] = ACTIONS(12455),
    [anon_sym_POUNDendif2] = ACTIONS(12455),
    [anon_sym_POUNDENDIF2] = ACTIONS(12455),
    [anon_sym_POUNDEndif2] = ACTIONS(12455),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12455),
    [sym_trigger_keyword] = ACTIONS(12455),
    [sym_var_keyword] = ACTIONS(12455),
    [sym_local_keyword] = ACTIONS(12455),
    [sym_internal_keyword] = ACTIONS(12455),
    [sym_protected_keyword] = ACTIONS(12455),
    [sym_event_keyword] = ACTIONS(12455),
    [sym_fields_keyword] = ACTIONS(12455),
    [sym_keys_keyword] = ACTIONS(12455),
    [sym_fieldgroups_keyword] = ACTIONS(12455),
    [sym_actions_keyword] = ACTIONS(12455),
    [sym_layout_keyword] = ACTIONS(12455),
    [sym_area_keyword] = ACTIONS(12455),
    [sym_group_keyword] = ACTIONS(12455),
    [sym_repeater_keyword] = ACTIONS(12455),
    [sym_cuegroup_keyword] = ACTIONS(12455),
    [sym_fixed_keyword] = ACTIONS(12455),
    [sym_grid_keyword] = ACTIONS(12455),
    [sym_part_keyword] = ACTIONS(12455),
    [sym_systempart_keyword] = ACTIONS(12455),
    [sym_usercontrol_keyword] = ACTIONS(12455),
    [sym_dataset_keyword] = ACTIONS(12455),
    [sym_elements_keyword] = ACTIONS(12455),
    [sym_dataitem_keyword] = ACTIONS(12455),
    [sym_column_keyword] = ACTIONS(12455),
    [sym_filter_keyword] = ACTIONS(12455),
    [sym_labels_keyword] = ACTIONS(12455),
    [sym_rendering_keyword] = ACTIONS(12455),
    [sym_requestpage_keyword] = ACTIONS(12455),
    [sym_schema_keyword] = ACTIONS(12455),
    [sym_views_keyword] = ACTIONS(12455),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12455),
    [sym_preproc_open] = ACTIONS(12455),
    [sym_preproc_close] = ACTIONS(12455),
  },
  [STATE(5077)] = {
    [sym__body_element] = STATE(5097),
    [sym_empty_statement] = STATE(5097),
    [sym_property] = STATE(5097),
    [sym_permissions_property] = STATE(5097),
    [sym_table_relation_property] = STATE(5097),
    [sym_fields_section] = STATE(5097),
    [sym_keys_section] = STATE(5097),
    [sym_fieldgroups_section] = STATE(5097),
    [sym_enum_value_declaration] = STATE(5097),
    [sym_labels_section] = STATE(5097),
    [sym_layout_section] = STATE(5097),
    [sym_modify_modification] = STATE(5097),
    [sym_actions_section] = STATE(5097),
    [sym_views_section] = STATE(5097),
    [sym_dataset_section] = STATE(5097),
    [sym_report_dataitem] = STATE(5097),
    [sym__report_body_element] = STATE(5097),
    [sym_preproc_conditional_report] = STATE(5097),
    [sym_report_column] = STATE(5097),
    [sym_requestpage_section] = STATE(5097),
    [sym_rendering_section] = STATE(5097),
    [sym_elements_section] = STATE(5097),
    [sym_schema_section] = STATE(5097),
    [sym_assembly_declaration] = STATE(5097),
    [sym_event_declaration] = STATE(5097),
    [sym_procedure] = STATE(5097),
    [sym_preproc_split_procedure] = STATE(5097),
    [sym_preproc_split_procedure_preamble] = STATE(5097),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5097),
    [sym_var_section] = STATE(5097),
    [sym_attribute_item] = STATE(5097),
    [sym_preproc_conditional] = STATE(5097),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5097),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12471),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5078)] = {
    [anon_sym_SEMI] = ACTIONS(12473),
    [aux_sym_where_condition_token1] = ACTIONS(12475),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12473),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12473),
    [anon_sym_LBRACK] = ACTIONS(12473),
    [aux_sym_basic_type_token6] = ACTIONS(12475),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12473),
    [aux_sym_addafter_modification_token1] = ACTIONS(12473),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12473),
    [aux_sym_modify_modification_token1] = ACTIONS(12473),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12473),
    [aux_sym_movelast_modification_token1] = ACTIONS(12473),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12473),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12473),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12473),
    [anon_sym_POUNDif] = ACTIONS(12473),
    [anon_sym_POUNDIF] = ACTIONS(12473),
    [anon_sym_POUNDIf] = ACTIONS(12473),
    [anon_sym_POUNDelif] = ACTIONS(12473),
    [anon_sym_POUNDELIF] = ACTIONS(12473),
    [anon_sym_POUNDElif] = ACTIONS(12473),
    [anon_sym_POUNDelse] = ACTIONS(12473),
    [anon_sym_POUNDELSE] = ACTIONS(12473),
    [anon_sym_POUNDElse] = ACTIONS(12473),
    [anon_sym_POUNDelse2] = ACTIONS(12473),
    [anon_sym_POUNDELSE2] = ACTIONS(12473),
    [anon_sym_POUNDElse2] = ACTIONS(12473),
    [anon_sym_POUNDendif] = ACTIONS(12473),
    [anon_sym_POUNDENDIF] = ACTIONS(12473),
    [anon_sym_POUNDEndif] = ACTIONS(12473),
    [anon_sym_POUNDendif2] = ACTIONS(12473),
    [anon_sym_POUNDENDIF2] = ACTIONS(12473),
    [anon_sym_POUNDEndif2] = ACTIONS(12473),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12473),
    [sym_trigger_keyword] = ACTIONS(12473),
    [sym_var_keyword] = ACTIONS(12473),
    [sym_local_keyword] = ACTIONS(12473),
    [sym_internal_keyword] = ACTIONS(12473),
    [sym_protected_keyword] = ACTIONS(12473),
    [sym_event_keyword] = ACTIONS(12473),
    [sym_fields_keyword] = ACTIONS(12473),
    [sym_keys_keyword] = ACTIONS(12473),
    [sym_fieldgroups_keyword] = ACTIONS(12473),
    [sym_actions_keyword] = ACTIONS(12473),
    [sym_layout_keyword] = ACTIONS(12473),
    [sym_area_keyword] = ACTIONS(12473),
    [sym_group_keyword] = ACTIONS(12473),
    [sym_repeater_keyword] = ACTIONS(12473),
    [sym_cuegroup_keyword] = ACTIONS(12473),
    [sym_fixed_keyword] = ACTIONS(12473),
    [sym_grid_keyword] = ACTIONS(12473),
    [sym_part_keyword] = ACTIONS(12473),
    [sym_systempart_keyword] = ACTIONS(12473),
    [sym_usercontrol_keyword] = ACTIONS(12473),
    [sym_dataset_keyword] = ACTIONS(12473),
    [sym_elements_keyword] = ACTIONS(12473),
    [sym_dataitem_keyword] = ACTIONS(12473),
    [sym_column_keyword] = ACTIONS(12473),
    [sym_filter_keyword] = ACTIONS(12473),
    [sym_labels_keyword] = ACTIONS(12473),
    [sym_rendering_keyword] = ACTIONS(12473),
    [sym_requestpage_keyword] = ACTIONS(12473),
    [sym_schema_keyword] = ACTIONS(12473),
    [sym_views_keyword] = ACTIONS(12473),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12473),
    [sym_preproc_open] = ACTIONS(12473),
    [sym_preproc_close] = ACTIONS(12473),
  },
  [STATE(5079)] = {
    [anon_sym_SEMI] = ACTIONS(12477),
    [aux_sym_where_condition_token1] = ACTIONS(12479),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12481),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12481),
    [anon_sym_LBRACK] = ACTIONS(12481),
    [aux_sym_basic_type_token6] = ACTIONS(12479),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12481),
    [aux_sym_addafter_modification_token1] = ACTIONS(12481),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12481),
    [aux_sym_modify_modification_token1] = ACTIONS(12481),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12481),
    [aux_sym_movelast_modification_token1] = ACTIONS(12481),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12481),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12481),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12481),
    [anon_sym_POUNDif] = ACTIONS(12481),
    [anon_sym_POUNDIF] = ACTIONS(12481),
    [anon_sym_POUNDIf] = ACTIONS(12481),
    [anon_sym_POUNDelif] = ACTIONS(12481),
    [anon_sym_POUNDELIF] = ACTIONS(12481),
    [anon_sym_POUNDElif] = ACTIONS(12481),
    [anon_sym_POUNDelse] = ACTIONS(12481),
    [anon_sym_POUNDELSE] = ACTIONS(12481),
    [anon_sym_POUNDElse] = ACTIONS(12481),
    [anon_sym_POUNDelse2] = ACTIONS(12481),
    [anon_sym_POUNDELSE2] = ACTIONS(12481),
    [anon_sym_POUNDElse2] = ACTIONS(12481),
    [anon_sym_POUNDendif] = ACTIONS(12481),
    [anon_sym_POUNDENDIF] = ACTIONS(12481),
    [anon_sym_POUNDEndif] = ACTIONS(12481),
    [anon_sym_POUNDendif2] = ACTIONS(12481),
    [anon_sym_POUNDENDIF2] = ACTIONS(12481),
    [anon_sym_POUNDEndif2] = ACTIONS(12481),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12481),
    [sym_trigger_keyword] = ACTIONS(12481),
    [sym_var_keyword] = ACTIONS(12481),
    [sym_local_keyword] = ACTIONS(12481),
    [sym_internal_keyword] = ACTIONS(12481),
    [sym_protected_keyword] = ACTIONS(12481),
    [sym_event_keyword] = ACTIONS(12481),
    [sym_fields_keyword] = ACTIONS(12481),
    [sym_keys_keyword] = ACTIONS(12481),
    [sym_fieldgroups_keyword] = ACTIONS(12481),
    [sym_actions_keyword] = ACTIONS(12481),
    [sym_layout_keyword] = ACTIONS(12481),
    [sym_area_keyword] = ACTIONS(12481),
    [sym_group_keyword] = ACTIONS(12481),
    [sym_repeater_keyword] = ACTIONS(12481),
    [sym_cuegroup_keyword] = ACTIONS(12481),
    [sym_fixed_keyword] = ACTIONS(12481),
    [sym_grid_keyword] = ACTIONS(12481),
    [sym_part_keyword] = ACTIONS(12481),
    [sym_systempart_keyword] = ACTIONS(12481),
    [sym_usercontrol_keyword] = ACTIONS(12481),
    [sym_dataset_keyword] = ACTIONS(12481),
    [sym_elements_keyword] = ACTIONS(12481),
    [sym_dataitem_keyword] = ACTIONS(12481),
    [sym_column_keyword] = ACTIONS(12481),
    [sym_filter_keyword] = ACTIONS(12481),
    [sym_labels_keyword] = ACTIONS(12481),
    [sym_rendering_keyword] = ACTIONS(12481),
    [sym_requestpage_keyword] = ACTIONS(12481),
    [sym_schema_keyword] = ACTIONS(12481),
    [sym_views_keyword] = ACTIONS(12481),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12481),
    [sym_preproc_open] = ACTIONS(12481),
    [sym_preproc_close] = ACTIONS(12481),
  },
  [STATE(5080)] = {
    [anon_sym_SEMI] = ACTIONS(12483),
    [aux_sym_where_condition_token1] = ACTIONS(12479),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12481),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12481),
    [anon_sym_LBRACK] = ACTIONS(12481),
    [aux_sym_basic_type_token6] = ACTIONS(12479),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12481),
    [aux_sym_addafter_modification_token1] = ACTIONS(12481),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12481),
    [aux_sym_modify_modification_token1] = ACTIONS(12481),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12481),
    [aux_sym_movelast_modification_token1] = ACTIONS(12481),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12481),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12481),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12481),
    [anon_sym_POUNDif] = ACTIONS(12481),
    [anon_sym_POUNDIF] = ACTIONS(12481),
    [anon_sym_POUNDIf] = ACTIONS(12481),
    [anon_sym_POUNDelif] = ACTIONS(12481),
    [anon_sym_POUNDELIF] = ACTIONS(12481),
    [anon_sym_POUNDElif] = ACTIONS(12481),
    [anon_sym_POUNDelse] = ACTIONS(12481),
    [anon_sym_POUNDELSE] = ACTIONS(12481),
    [anon_sym_POUNDElse] = ACTIONS(12481),
    [anon_sym_POUNDelse2] = ACTIONS(12481),
    [anon_sym_POUNDELSE2] = ACTIONS(12481),
    [anon_sym_POUNDElse2] = ACTIONS(12481),
    [anon_sym_POUNDendif] = ACTIONS(12481),
    [anon_sym_POUNDENDIF] = ACTIONS(12481),
    [anon_sym_POUNDEndif] = ACTIONS(12481),
    [anon_sym_POUNDendif2] = ACTIONS(12481),
    [anon_sym_POUNDENDIF2] = ACTIONS(12481),
    [anon_sym_POUNDEndif2] = ACTIONS(12481),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12481),
    [sym_trigger_keyword] = ACTIONS(12481),
    [sym_var_keyword] = ACTIONS(12481),
    [sym_local_keyword] = ACTIONS(12481),
    [sym_internal_keyword] = ACTIONS(12481),
    [sym_protected_keyword] = ACTIONS(12481),
    [sym_event_keyword] = ACTIONS(12481),
    [sym_fields_keyword] = ACTIONS(12481),
    [sym_keys_keyword] = ACTIONS(12481),
    [sym_fieldgroups_keyword] = ACTIONS(12481),
    [sym_actions_keyword] = ACTIONS(12481),
    [sym_layout_keyword] = ACTIONS(12481),
    [sym_area_keyword] = ACTIONS(12481),
    [sym_group_keyword] = ACTIONS(12481),
    [sym_repeater_keyword] = ACTIONS(12481),
    [sym_cuegroup_keyword] = ACTIONS(12481),
    [sym_fixed_keyword] = ACTIONS(12481),
    [sym_grid_keyword] = ACTIONS(12481),
    [sym_part_keyword] = ACTIONS(12481),
    [sym_systempart_keyword] = ACTIONS(12481),
    [sym_usercontrol_keyword] = ACTIONS(12481),
    [sym_dataset_keyword] = ACTIONS(12481),
    [sym_elements_keyword] = ACTIONS(12481),
    [sym_dataitem_keyword] = ACTIONS(12481),
    [sym_column_keyword] = ACTIONS(12481),
    [sym_filter_keyword] = ACTIONS(12481),
    [sym_labels_keyword] = ACTIONS(12481),
    [sym_rendering_keyword] = ACTIONS(12481),
    [sym_requestpage_keyword] = ACTIONS(12481),
    [sym_schema_keyword] = ACTIONS(12481),
    [sym_views_keyword] = ACTIONS(12481),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12481),
    [sym_preproc_open] = ACTIONS(12481),
    [sym_preproc_close] = ACTIONS(12481),
  },
  [STATE(5081)] = {
    [anon_sym_SEMI] = ACTIONS(12485),
    [aux_sym_where_condition_token1] = ACTIONS(12487),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12485),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12485),
    [anon_sym_LBRACK] = ACTIONS(12485),
    [aux_sym_basic_type_token6] = ACTIONS(12487),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12485),
    [aux_sym_addafter_modification_token1] = ACTIONS(12485),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12485),
    [aux_sym_modify_modification_token1] = ACTIONS(12485),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12485),
    [aux_sym_movelast_modification_token1] = ACTIONS(12485),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12485),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12485),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12485),
    [anon_sym_POUNDif] = ACTIONS(12485),
    [anon_sym_POUNDIF] = ACTIONS(12485),
    [anon_sym_POUNDIf] = ACTIONS(12485),
    [anon_sym_POUNDelif] = ACTIONS(12485),
    [anon_sym_POUNDELIF] = ACTIONS(12485),
    [anon_sym_POUNDElif] = ACTIONS(12485),
    [anon_sym_POUNDelse] = ACTIONS(12485),
    [anon_sym_POUNDELSE] = ACTIONS(12485),
    [anon_sym_POUNDElse] = ACTIONS(12485),
    [anon_sym_POUNDelse2] = ACTIONS(12485),
    [anon_sym_POUNDELSE2] = ACTIONS(12485),
    [anon_sym_POUNDElse2] = ACTIONS(12485),
    [anon_sym_POUNDendif] = ACTIONS(12485),
    [anon_sym_POUNDENDIF] = ACTIONS(12485),
    [anon_sym_POUNDEndif] = ACTIONS(12485),
    [anon_sym_POUNDendif2] = ACTIONS(12485),
    [anon_sym_POUNDENDIF2] = ACTIONS(12485),
    [anon_sym_POUNDEndif2] = ACTIONS(12485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12485),
    [sym_trigger_keyword] = ACTIONS(12485),
    [sym_var_keyword] = ACTIONS(12485),
    [sym_local_keyword] = ACTIONS(12485),
    [sym_internal_keyword] = ACTIONS(12485),
    [sym_protected_keyword] = ACTIONS(12485),
    [sym_event_keyword] = ACTIONS(12485),
    [sym_fields_keyword] = ACTIONS(12485),
    [sym_keys_keyword] = ACTIONS(12485),
    [sym_fieldgroups_keyword] = ACTIONS(12485),
    [sym_actions_keyword] = ACTIONS(12485),
    [sym_layout_keyword] = ACTIONS(12485),
    [sym_area_keyword] = ACTIONS(12485),
    [sym_group_keyword] = ACTIONS(12485),
    [sym_repeater_keyword] = ACTIONS(12485),
    [sym_cuegroup_keyword] = ACTIONS(12485),
    [sym_fixed_keyword] = ACTIONS(12485),
    [sym_grid_keyword] = ACTIONS(12485),
    [sym_part_keyword] = ACTIONS(12485),
    [sym_systempart_keyword] = ACTIONS(12485),
    [sym_usercontrol_keyword] = ACTIONS(12485),
    [sym_dataset_keyword] = ACTIONS(12485),
    [sym_elements_keyword] = ACTIONS(12485),
    [sym_dataitem_keyword] = ACTIONS(12485),
    [sym_column_keyword] = ACTIONS(12485),
    [sym_filter_keyword] = ACTIONS(12485),
    [sym_labels_keyword] = ACTIONS(12485),
    [sym_rendering_keyword] = ACTIONS(12485),
    [sym_requestpage_keyword] = ACTIONS(12485),
    [sym_schema_keyword] = ACTIONS(12485),
    [sym_views_keyword] = ACTIONS(12485),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12485),
    [sym_preproc_open] = ACTIONS(12485),
    [sym_preproc_close] = ACTIONS(12485),
  },
  [STATE(5082)] = {
    [anon_sym_SEMI] = ACTIONS(12485),
    [aux_sym_where_condition_token1] = ACTIONS(12487),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12485),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12485),
    [anon_sym_LBRACK] = ACTIONS(12485),
    [aux_sym_basic_type_token6] = ACTIONS(12487),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12485),
    [aux_sym_addafter_modification_token1] = ACTIONS(12485),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12485),
    [aux_sym_modify_modification_token1] = ACTIONS(12485),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12485),
    [aux_sym_movelast_modification_token1] = ACTIONS(12485),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12485),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12485),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12485),
    [anon_sym_POUNDif] = ACTIONS(12485),
    [anon_sym_POUNDIF] = ACTIONS(12485),
    [anon_sym_POUNDIf] = ACTIONS(12485),
    [anon_sym_POUNDelif] = ACTIONS(12485),
    [anon_sym_POUNDELIF] = ACTIONS(12485),
    [anon_sym_POUNDElif] = ACTIONS(12485),
    [anon_sym_POUNDelse] = ACTIONS(12485),
    [anon_sym_POUNDELSE] = ACTIONS(12485),
    [anon_sym_POUNDElse] = ACTIONS(12485),
    [anon_sym_POUNDelse2] = ACTIONS(12485),
    [anon_sym_POUNDELSE2] = ACTIONS(12485),
    [anon_sym_POUNDElse2] = ACTIONS(12485),
    [anon_sym_POUNDendif] = ACTIONS(12485),
    [anon_sym_POUNDENDIF] = ACTIONS(12485),
    [anon_sym_POUNDEndif] = ACTIONS(12485),
    [anon_sym_POUNDendif2] = ACTIONS(12485),
    [anon_sym_POUNDENDIF2] = ACTIONS(12485),
    [anon_sym_POUNDEndif2] = ACTIONS(12485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12485),
    [sym_trigger_keyword] = ACTIONS(12485),
    [sym_var_keyword] = ACTIONS(12485),
    [sym_local_keyword] = ACTIONS(12485),
    [sym_internal_keyword] = ACTIONS(12485),
    [sym_protected_keyword] = ACTIONS(12485),
    [sym_event_keyword] = ACTIONS(12485),
    [sym_fields_keyword] = ACTIONS(12485),
    [sym_keys_keyword] = ACTIONS(12485),
    [sym_fieldgroups_keyword] = ACTIONS(12485),
    [sym_actions_keyword] = ACTIONS(12485),
    [sym_layout_keyword] = ACTIONS(12485),
    [sym_area_keyword] = ACTIONS(12485),
    [sym_group_keyword] = ACTIONS(12485),
    [sym_repeater_keyword] = ACTIONS(12485),
    [sym_cuegroup_keyword] = ACTIONS(12485),
    [sym_fixed_keyword] = ACTIONS(12485),
    [sym_grid_keyword] = ACTIONS(12485),
    [sym_part_keyword] = ACTIONS(12485),
    [sym_systempart_keyword] = ACTIONS(12485),
    [sym_usercontrol_keyword] = ACTIONS(12485),
    [sym_dataset_keyword] = ACTIONS(12485),
    [sym_elements_keyword] = ACTIONS(12485),
    [sym_dataitem_keyword] = ACTIONS(12485),
    [sym_column_keyword] = ACTIONS(12485),
    [sym_filter_keyword] = ACTIONS(12485),
    [sym_labels_keyword] = ACTIONS(12485),
    [sym_rendering_keyword] = ACTIONS(12485),
    [sym_requestpage_keyword] = ACTIONS(12485),
    [sym_schema_keyword] = ACTIONS(12485),
    [sym_views_keyword] = ACTIONS(12485),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12485),
    [sym_preproc_open] = ACTIONS(12485),
    [sym_preproc_close] = ACTIONS(12485),
  },
  [STATE(5083)] = {
    [anon_sym_SEMI] = ACTIONS(12489),
    [aux_sym_where_condition_token1] = ACTIONS(12491),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12493),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12493),
    [anon_sym_LBRACK] = ACTIONS(12493),
    [aux_sym_basic_type_token6] = ACTIONS(12491),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12493),
    [aux_sym_addafter_modification_token1] = ACTIONS(12493),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12493),
    [aux_sym_modify_modification_token1] = ACTIONS(12493),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12493),
    [aux_sym_movelast_modification_token1] = ACTIONS(12493),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12493),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12493),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12493),
    [anon_sym_POUNDif] = ACTIONS(12493),
    [anon_sym_POUNDIF] = ACTIONS(12493),
    [anon_sym_POUNDIf] = ACTIONS(12493),
    [anon_sym_POUNDelif] = ACTIONS(12493),
    [anon_sym_POUNDELIF] = ACTIONS(12493),
    [anon_sym_POUNDElif] = ACTIONS(12493),
    [anon_sym_POUNDelse] = ACTIONS(12493),
    [anon_sym_POUNDELSE] = ACTIONS(12493),
    [anon_sym_POUNDElse] = ACTIONS(12493),
    [anon_sym_POUNDelse2] = ACTIONS(12493),
    [anon_sym_POUNDELSE2] = ACTIONS(12493),
    [anon_sym_POUNDElse2] = ACTIONS(12493),
    [anon_sym_POUNDendif] = ACTIONS(12493),
    [anon_sym_POUNDENDIF] = ACTIONS(12493),
    [anon_sym_POUNDEndif] = ACTIONS(12493),
    [anon_sym_POUNDendif2] = ACTIONS(12493),
    [anon_sym_POUNDENDIF2] = ACTIONS(12493),
    [anon_sym_POUNDEndif2] = ACTIONS(12493),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12493),
    [sym_trigger_keyword] = ACTIONS(12493),
    [sym_var_keyword] = ACTIONS(12493),
    [sym_local_keyword] = ACTIONS(12493),
    [sym_internal_keyword] = ACTIONS(12493),
    [sym_protected_keyword] = ACTIONS(12493),
    [sym_event_keyword] = ACTIONS(12493),
    [sym_fields_keyword] = ACTIONS(12493),
    [sym_keys_keyword] = ACTIONS(12493),
    [sym_fieldgroups_keyword] = ACTIONS(12493),
    [sym_actions_keyword] = ACTIONS(12493),
    [sym_layout_keyword] = ACTIONS(12493),
    [sym_area_keyword] = ACTIONS(12493),
    [sym_group_keyword] = ACTIONS(12493),
    [sym_repeater_keyword] = ACTIONS(12493),
    [sym_cuegroup_keyword] = ACTIONS(12493),
    [sym_fixed_keyword] = ACTIONS(12493),
    [sym_grid_keyword] = ACTIONS(12493),
    [sym_part_keyword] = ACTIONS(12493),
    [sym_systempart_keyword] = ACTIONS(12493),
    [sym_usercontrol_keyword] = ACTIONS(12493),
    [sym_dataset_keyword] = ACTIONS(12493),
    [sym_elements_keyword] = ACTIONS(12493),
    [sym_dataitem_keyword] = ACTIONS(12493),
    [sym_column_keyword] = ACTIONS(12493),
    [sym_filter_keyword] = ACTIONS(12493),
    [sym_labels_keyword] = ACTIONS(12493),
    [sym_rendering_keyword] = ACTIONS(12493),
    [sym_requestpage_keyword] = ACTIONS(12493),
    [sym_schema_keyword] = ACTIONS(12493),
    [sym_views_keyword] = ACTIONS(12493),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12493),
    [sym_preproc_open] = ACTIONS(12493),
    [sym_preproc_close] = ACTIONS(12493),
  },
  [STATE(5084)] = {
    [anon_sym_SEMI] = ACTIONS(12495),
    [aux_sym_where_condition_token1] = ACTIONS(12491),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12493),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12493),
    [anon_sym_LBRACK] = ACTIONS(12493),
    [aux_sym_basic_type_token6] = ACTIONS(12491),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12493),
    [aux_sym_addafter_modification_token1] = ACTIONS(12493),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12493),
    [aux_sym_modify_modification_token1] = ACTIONS(12493),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12493),
    [aux_sym_movelast_modification_token1] = ACTIONS(12493),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12493),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12493),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12493),
    [anon_sym_POUNDif] = ACTIONS(12493),
    [anon_sym_POUNDIF] = ACTIONS(12493),
    [anon_sym_POUNDIf] = ACTIONS(12493),
    [anon_sym_POUNDelif] = ACTIONS(12493),
    [anon_sym_POUNDELIF] = ACTIONS(12493),
    [anon_sym_POUNDElif] = ACTIONS(12493),
    [anon_sym_POUNDelse] = ACTIONS(12493),
    [anon_sym_POUNDELSE] = ACTIONS(12493),
    [anon_sym_POUNDElse] = ACTIONS(12493),
    [anon_sym_POUNDelse2] = ACTIONS(12493),
    [anon_sym_POUNDELSE2] = ACTIONS(12493),
    [anon_sym_POUNDElse2] = ACTIONS(12493),
    [anon_sym_POUNDendif] = ACTIONS(12493),
    [anon_sym_POUNDENDIF] = ACTIONS(12493),
    [anon_sym_POUNDEndif] = ACTIONS(12493),
    [anon_sym_POUNDendif2] = ACTIONS(12493),
    [anon_sym_POUNDENDIF2] = ACTIONS(12493),
    [anon_sym_POUNDEndif2] = ACTIONS(12493),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12493),
    [sym_trigger_keyword] = ACTIONS(12493),
    [sym_var_keyword] = ACTIONS(12493),
    [sym_local_keyword] = ACTIONS(12493),
    [sym_internal_keyword] = ACTIONS(12493),
    [sym_protected_keyword] = ACTIONS(12493),
    [sym_event_keyword] = ACTIONS(12493),
    [sym_fields_keyword] = ACTIONS(12493),
    [sym_keys_keyword] = ACTIONS(12493),
    [sym_fieldgroups_keyword] = ACTIONS(12493),
    [sym_actions_keyword] = ACTIONS(12493),
    [sym_layout_keyword] = ACTIONS(12493),
    [sym_area_keyword] = ACTIONS(12493),
    [sym_group_keyword] = ACTIONS(12493),
    [sym_repeater_keyword] = ACTIONS(12493),
    [sym_cuegroup_keyword] = ACTIONS(12493),
    [sym_fixed_keyword] = ACTIONS(12493),
    [sym_grid_keyword] = ACTIONS(12493),
    [sym_part_keyword] = ACTIONS(12493),
    [sym_systempart_keyword] = ACTIONS(12493),
    [sym_usercontrol_keyword] = ACTIONS(12493),
    [sym_dataset_keyword] = ACTIONS(12493),
    [sym_elements_keyword] = ACTIONS(12493),
    [sym_dataitem_keyword] = ACTIONS(12493),
    [sym_column_keyword] = ACTIONS(12493),
    [sym_filter_keyword] = ACTIONS(12493),
    [sym_labels_keyword] = ACTIONS(12493),
    [sym_rendering_keyword] = ACTIONS(12493),
    [sym_requestpage_keyword] = ACTIONS(12493),
    [sym_schema_keyword] = ACTIONS(12493),
    [sym_views_keyword] = ACTIONS(12493),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12493),
    [sym_preproc_open] = ACTIONS(12493),
    [sym_preproc_close] = ACTIONS(12493),
  },
  [STATE(5085)] = {
    [anon_sym_SEMI] = ACTIONS(12497),
    [aux_sym_where_condition_token1] = ACTIONS(12487),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12485),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12485),
    [anon_sym_LBRACK] = ACTIONS(12485),
    [aux_sym_basic_type_token6] = ACTIONS(12487),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12485),
    [aux_sym_addafter_modification_token1] = ACTIONS(12485),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12485),
    [aux_sym_modify_modification_token1] = ACTIONS(12485),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12485),
    [aux_sym_movelast_modification_token1] = ACTIONS(12485),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12485),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12485),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12485),
    [anon_sym_POUNDif] = ACTIONS(12485),
    [anon_sym_POUNDIF] = ACTIONS(12485),
    [anon_sym_POUNDIf] = ACTIONS(12485),
    [anon_sym_POUNDelif] = ACTIONS(12485),
    [anon_sym_POUNDELIF] = ACTIONS(12485),
    [anon_sym_POUNDElif] = ACTIONS(12485),
    [anon_sym_POUNDelse] = ACTIONS(12485),
    [anon_sym_POUNDELSE] = ACTIONS(12485),
    [anon_sym_POUNDElse] = ACTIONS(12485),
    [anon_sym_POUNDelse2] = ACTIONS(12485),
    [anon_sym_POUNDELSE2] = ACTIONS(12485),
    [anon_sym_POUNDElse2] = ACTIONS(12485),
    [anon_sym_POUNDendif] = ACTIONS(12485),
    [anon_sym_POUNDENDIF] = ACTIONS(12485),
    [anon_sym_POUNDEndif] = ACTIONS(12485),
    [anon_sym_POUNDendif2] = ACTIONS(12485),
    [anon_sym_POUNDENDIF2] = ACTIONS(12485),
    [anon_sym_POUNDEndif2] = ACTIONS(12485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12485),
    [sym_trigger_keyword] = ACTIONS(12485),
    [sym_var_keyword] = ACTIONS(12485),
    [sym_local_keyword] = ACTIONS(12485),
    [sym_internal_keyword] = ACTIONS(12485),
    [sym_protected_keyword] = ACTIONS(12485),
    [sym_event_keyword] = ACTIONS(12485),
    [sym_fields_keyword] = ACTIONS(12485),
    [sym_keys_keyword] = ACTIONS(12485),
    [sym_fieldgroups_keyword] = ACTIONS(12485),
    [sym_actions_keyword] = ACTIONS(12485),
    [sym_layout_keyword] = ACTIONS(12485),
    [sym_area_keyword] = ACTIONS(12485),
    [sym_group_keyword] = ACTIONS(12485),
    [sym_repeater_keyword] = ACTIONS(12485),
    [sym_cuegroup_keyword] = ACTIONS(12485),
    [sym_fixed_keyword] = ACTIONS(12485),
    [sym_grid_keyword] = ACTIONS(12485),
    [sym_part_keyword] = ACTIONS(12485),
    [sym_systempart_keyword] = ACTIONS(12485),
    [sym_usercontrol_keyword] = ACTIONS(12485),
    [sym_dataset_keyword] = ACTIONS(12485),
    [sym_elements_keyword] = ACTIONS(12485),
    [sym_dataitem_keyword] = ACTIONS(12485),
    [sym_column_keyword] = ACTIONS(12485),
    [sym_filter_keyword] = ACTIONS(12485),
    [sym_labels_keyword] = ACTIONS(12485),
    [sym_rendering_keyword] = ACTIONS(12485),
    [sym_requestpage_keyword] = ACTIONS(12485),
    [sym_schema_keyword] = ACTIONS(12485),
    [sym_views_keyword] = ACTIONS(12485),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12485),
    [sym_preproc_open] = ACTIONS(12485),
    [sym_preproc_close] = ACTIONS(12485),
  },
  [STATE(5086)] = {
    [anon_sym_SEMI] = ACTIONS(12499),
    [aux_sym_where_condition_token1] = ACTIONS(12487),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12485),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12485),
    [anon_sym_LBRACK] = ACTIONS(12485),
    [aux_sym_basic_type_token6] = ACTIONS(12487),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12485),
    [aux_sym_addafter_modification_token1] = ACTIONS(12485),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12485),
    [aux_sym_modify_modification_token1] = ACTIONS(12485),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12485),
    [aux_sym_movelast_modification_token1] = ACTIONS(12485),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12485),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12485),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12485),
    [anon_sym_POUNDif] = ACTIONS(12485),
    [anon_sym_POUNDIF] = ACTIONS(12485),
    [anon_sym_POUNDIf] = ACTIONS(12485),
    [anon_sym_POUNDelif] = ACTIONS(12485),
    [anon_sym_POUNDELIF] = ACTIONS(12485),
    [anon_sym_POUNDElif] = ACTIONS(12485),
    [anon_sym_POUNDelse] = ACTIONS(12485),
    [anon_sym_POUNDELSE] = ACTIONS(12485),
    [anon_sym_POUNDElse] = ACTIONS(12485),
    [anon_sym_POUNDelse2] = ACTIONS(12485),
    [anon_sym_POUNDELSE2] = ACTIONS(12485),
    [anon_sym_POUNDElse2] = ACTIONS(12485),
    [anon_sym_POUNDendif] = ACTIONS(12485),
    [anon_sym_POUNDENDIF] = ACTIONS(12485),
    [anon_sym_POUNDEndif] = ACTIONS(12485),
    [anon_sym_POUNDendif2] = ACTIONS(12485),
    [anon_sym_POUNDENDIF2] = ACTIONS(12485),
    [anon_sym_POUNDEndif2] = ACTIONS(12485),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12485),
    [sym_trigger_keyword] = ACTIONS(12485),
    [sym_var_keyword] = ACTIONS(12485),
    [sym_local_keyword] = ACTIONS(12485),
    [sym_internal_keyword] = ACTIONS(12485),
    [sym_protected_keyword] = ACTIONS(12485),
    [sym_event_keyword] = ACTIONS(12485),
    [sym_fields_keyword] = ACTIONS(12485),
    [sym_keys_keyword] = ACTIONS(12485),
    [sym_fieldgroups_keyword] = ACTIONS(12485),
    [sym_actions_keyword] = ACTIONS(12485),
    [sym_layout_keyword] = ACTIONS(12485),
    [sym_area_keyword] = ACTIONS(12485),
    [sym_group_keyword] = ACTIONS(12485),
    [sym_repeater_keyword] = ACTIONS(12485),
    [sym_cuegroup_keyword] = ACTIONS(12485),
    [sym_fixed_keyword] = ACTIONS(12485),
    [sym_grid_keyword] = ACTIONS(12485),
    [sym_part_keyword] = ACTIONS(12485),
    [sym_systempart_keyword] = ACTIONS(12485),
    [sym_usercontrol_keyword] = ACTIONS(12485),
    [sym_dataset_keyword] = ACTIONS(12485),
    [sym_elements_keyword] = ACTIONS(12485),
    [sym_dataitem_keyword] = ACTIONS(12485),
    [sym_column_keyword] = ACTIONS(12485),
    [sym_filter_keyword] = ACTIONS(12485),
    [sym_labels_keyword] = ACTIONS(12485),
    [sym_rendering_keyword] = ACTIONS(12485),
    [sym_requestpage_keyword] = ACTIONS(12485),
    [sym_schema_keyword] = ACTIONS(12485),
    [sym_views_keyword] = ACTIONS(12485),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12485),
    [sym_preproc_open] = ACTIONS(12485),
    [sym_preproc_close] = ACTIONS(12485),
  },
  [STATE(5087)] = {
    [anon_sym_SEMI] = ACTIONS(8428),
    [anon_sym_RBRACE] = ACTIONS(8428),
    [aux_sym_where_condition_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8428),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8428),
    [anon_sym_LBRACK] = ACTIONS(8428),
    [aux_sym_basic_type_token6] = ACTIONS(7725),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8428),
    [aux_sym_addafter_modification_token1] = ACTIONS(8428),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8428),
    [aux_sym_modify_modification_token1] = ACTIONS(8428),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8428),
    [aux_sym_movelast_modification_token1] = ACTIONS(8428),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8428),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8428),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8428),
    [anon_sym_POUNDif] = ACTIONS(8428),
    [anon_sym_POUNDIF] = ACTIONS(8428),
    [anon_sym_POUNDIf] = ACTIONS(8428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7725),
    [sym_page_keyword] = ACTIONS(8428),
    [anon_sym_codeunit] = ACTIONS(8428),
    [anon_sym_CODEUNIT] = ACTIONS(8428),
    [anon_sym_Codeunit] = ACTIONS(8428),
    [anon_sym_CodeUnit] = ACTIONS(8428),
    [anon_sym_COdeunit] = ACTIONS(8428),
    [anon_sym_codeUnit] = ACTIONS(8428),
    [sym_report_keyword] = ACTIONS(8428),
    [sym_query_keyword] = ACTIONS(8428),
    [anon_sym_xmlport] = ACTIONS(8428),
    [anon_sym_XMLPORT] = ACTIONS(8428),
    [anon_sym_Xmlport] = ACTIONS(8428),
    [anon_sym_XMLport] = ACTIONS(8428),
    [anon_sym_XMLPort] = ACTIONS(8428),
    [anon_sym_XmlPort] = ACTIONS(8428),
    [sym_procedure_keyword] = ACTIONS(8428),
    [sym_trigger_keyword] = ACTIONS(8428),
    [sym_var_keyword] = ACTIONS(8428),
    [sym_local_keyword] = ACTIONS(8428),
    [sym_internal_keyword] = ACTIONS(8428),
    [sym_protected_keyword] = ACTIONS(8428),
    [sym_event_keyword] = ACTIONS(8428),
    [sym_fields_keyword] = ACTIONS(8428),
    [sym_keys_keyword] = ACTIONS(8428),
    [sym_fieldgroups_keyword] = ACTIONS(8428),
    [sym_actions_keyword] = ACTIONS(8428),
    [sym_layout_keyword] = ACTIONS(8428),
    [sym_area_keyword] = ACTIONS(8428),
    [sym_group_keyword] = ACTIONS(8428),
    [sym_repeater_keyword] = ACTIONS(8428),
    [sym_cuegroup_keyword] = ACTIONS(8428),
    [sym_fixed_keyword] = ACTIONS(8428),
    [sym_grid_keyword] = ACTIONS(8428),
    [sym_part_keyword] = ACTIONS(8428),
    [sym_systempart_keyword] = ACTIONS(8428),
    [sym_usercontrol_keyword] = ACTIONS(8428),
    [sym_dataset_keyword] = ACTIONS(8428),
    [sym_elements_keyword] = ACTIONS(8428),
    [sym_labels_keyword] = ACTIONS(8428),
    [sym_rendering_keyword] = ACTIONS(8428),
    [sym_requestpage_keyword] = ACTIONS(8428),
    [sym_schema_keyword] = ACTIONS(8428),
    [sym_views_keyword] = ACTIONS(8428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8428),
    [sym_preproc_open] = ACTIONS(8428),
  },
  [STATE(5088)] = {
    [anon_sym_SEMI] = ACTIONS(12501),
    [aux_sym_where_condition_token1] = ACTIONS(12503),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12501),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12501),
    [anon_sym_LBRACK] = ACTIONS(12501),
    [aux_sym_basic_type_token6] = ACTIONS(12503),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12501),
    [aux_sym_addafter_modification_token1] = ACTIONS(12501),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12501),
    [aux_sym_modify_modification_token1] = ACTIONS(12501),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12501),
    [aux_sym_movelast_modification_token1] = ACTIONS(12501),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12501),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12501),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12501),
    [anon_sym_POUNDif] = ACTIONS(12501),
    [anon_sym_POUNDIF] = ACTIONS(12501),
    [anon_sym_POUNDIf] = ACTIONS(12501),
    [anon_sym_POUNDelif] = ACTIONS(12501),
    [anon_sym_POUNDELIF] = ACTIONS(12501),
    [anon_sym_POUNDElif] = ACTIONS(12501),
    [anon_sym_POUNDelse] = ACTIONS(12501),
    [anon_sym_POUNDELSE] = ACTIONS(12501),
    [anon_sym_POUNDElse] = ACTIONS(12501),
    [anon_sym_POUNDelse2] = ACTIONS(12501),
    [anon_sym_POUNDELSE2] = ACTIONS(12501),
    [anon_sym_POUNDElse2] = ACTIONS(12501),
    [anon_sym_POUNDendif] = ACTIONS(12501),
    [anon_sym_POUNDENDIF] = ACTIONS(12501),
    [anon_sym_POUNDEndif] = ACTIONS(12501),
    [anon_sym_POUNDendif2] = ACTIONS(12501),
    [anon_sym_POUNDENDIF2] = ACTIONS(12501),
    [anon_sym_POUNDEndif2] = ACTIONS(12501),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12501),
    [sym_trigger_keyword] = ACTIONS(12501),
    [sym_var_keyword] = ACTIONS(12501),
    [sym_local_keyword] = ACTIONS(12501),
    [sym_internal_keyword] = ACTIONS(12501),
    [sym_protected_keyword] = ACTIONS(12501),
    [sym_event_keyword] = ACTIONS(12501),
    [sym_fields_keyword] = ACTIONS(12501),
    [sym_keys_keyword] = ACTIONS(12501),
    [sym_fieldgroups_keyword] = ACTIONS(12501),
    [sym_actions_keyword] = ACTIONS(12501),
    [sym_layout_keyword] = ACTIONS(12501),
    [sym_area_keyword] = ACTIONS(12501),
    [sym_group_keyword] = ACTIONS(12501),
    [sym_repeater_keyword] = ACTIONS(12501),
    [sym_cuegroup_keyword] = ACTIONS(12501),
    [sym_fixed_keyword] = ACTIONS(12501),
    [sym_grid_keyword] = ACTIONS(12501),
    [sym_part_keyword] = ACTIONS(12501),
    [sym_systempart_keyword] = ACTIONS(12501),
    [sym_usercontrol_keyword] = ACTIONS(12501),
    [sym_dataset_keyword] = ACTIONS(12501),
    [sym_elements_keyword] = ACTIONS(12501),
    [sym_dataitem_keyword] = ACTIONS(12501),
    [sym_column_keyword] = ACTIONS(12501),
    [sym_filter_keyword] = ACTIONS(12501),
    [sym_labels_keyword] = ACTIONS(12501),
    [sym_rendering_keyword] = ACTIONS(12501),
    [sym_requestpage_keyword] = ACTIONS(12501),
    [sym_schema_keyword] = ACTIONS(12501),
    [sym_views_keyword] = ACTIONS(12501),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12501),
    [sym_preproc_open] = ACTIONS(12501),
    [sym_preproc_close] = ACTIONS(12501),
  },
  [STATE(5089)] = {
    [anon_sym_SEMI] = ACTIONS(12225),
    [aux_sym_where_condition_token1] = ACTIONS(12223),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12225),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12225),
    [anon_sym_LBRACK] = ACTIONS(12225),
    [aux_sym_basic_type_token6] = ACTIONS(12223),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12225),
    [aux_sym_addafter_modification_token1] = ACTIONS(12225),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12225),
    [aux_sym_modify_modification_token1] = ACTIONS(12225),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12225),
    [aux_sym_movelast_modification_token1] = ACTIONS(12225),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12225),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12225),
    [anon_sym_POUNDif] = ACTIONS(12225),
    [anon_sym_POUNDIF] = ACTIONS(12225),
    [anon_sym_POUNDIf] = ACTIONS(12225),
    [anon_sym_POUNDelif] = ACTIONS(12225),
    [anon_sym_POUNDELIF] = ACTIONS(12225),
    [anon_sym_POUNDElif] = ACTIONS(12225),
    [anon_sym_POUNDelse] = ACTIONS(12225),
    [anon_sym_POUNDELSE] = ACTIONS(12225),
    [anon_sym_POUNDElse] = ACTIONS(12225),
    [anon_sym_POUNDelse2] = ACTIONS(12225),
    [anon_sym_POUNDELSE2] = ACTIONS(12225),
    [anon_sym_POUNDElse2] = ACTIONS(12225),
    [anon_sym_POUNDendif] = ACTIONS(12225),
    [anon_sym_POUNDENDIF] = ACTIONS(12225),
    [anon_sym_POUNDEndif] = ACTIONS(12225),
    [anon_sym_POUNDendif2] = ACTIONS(12225),
    [anon_sym_POUNDENDIF2] = ACTIONS(12225),
    [anon_sym_POUNDEndif2] = ACTIONS(12225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12225),
    [sym_trigger_keyword] = ACTIONS(12225),
    [sym_var_keyword] = ACTIONS(12225),
    [sym_local_keyword] = ACTIONS(12225),
    [sym_internal_keyword] = ACTIONS(12225),
    [sym_protected_keyword] = ACTIONS(12225),
    [sym_event_keyword] = ACTIONS(12225),
    [sym_fields_keyword] = ACTIONS(12225),
    [sym_keys_keyword] = ACTIONS(12225),
    [sym_fieldgroups_keyword] = ACTIONS(12225),
    [sym_actions_keyword] = ACTIONS(12225),
    [sym_layout_keyword] = ACTIONS(12225),
    [sym_area_keyword] = ACTIONS(12225),
    [sym_group_keyword] = ACTIONS(12225),
    [sym_repeater_keyword] = ACTIONS(12225),
    [sym_cuegroup_keyword] = ACTIONS(12225),
    [sym_fixed_keyword] = ACTIONS(12225),
    [sym_grid_keyword] = ACTIONS(12225),
    [sym_part_keyword] = ACTIONS(12225),
    [sym_systempart_keyword] = ACTIONS(12225),
    [sym_usercontrol_keyword] = ACTIONS(12225),
    [sym_dataset_keyword] = ACTIONS(12225),
    [sym_elements_keyword] = ACTIONS(12225),
    [sym_dataitem_keyword] = ACTIONS(12225),
    [sym_column_keyword] = ACTIONS(12225),
    [sym_filter_keyword] = ACTIONS(12225),
    [sym_labels_keyword] = ACTIONS(12225),
    [sym_rendering_keyword] = ACTIONS(12225),
    [sym_requestpage_keyword] = ACTIONS(12225),
    [sym_schema_keyword] = ACTIONS(12225),
    [sym_views_keyword] = ACTIONS(12225),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12225),
    [sym_preproc_open] = ACTIONS(12225),
    [sym_preproc_close] = ACTIONS(12225),
  },
  [STATE(5090)] = {
    [anon_sym_SEMI] = ACTIONS(12225),
    [aux_sym_where_condition_token1] = ACTIONS(12223),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12225),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12225),
    [anon_sym_LBRACK] = ACTIONS(12225),
    [aux_sym_basic_type_token6] = ACTIONS(12223),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12225),
    [aux_sym_addafter_modification_token1] = ACTIONS(12225),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12225),
    [aux_sym_modify_modification_token1] = ACTIONS(12225),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12225),
    [aux_sym_movelast_modification_token1] = ACTIONS(12225),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12225),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12225),
    [anon_sym_POUNDif] = ACTIONS(12225),
    [anon_sym_POUNDIF] = ACTIONS(12225),
    [anon_sym_POUNDIf] = ACTIONS(12225),
    [anon_sym_POUNDelif] = ACTIONS(12225),
    [anon_sym_POUNDELIF] = ACTIONS(12225),
    [anon_sym_POUNDElif] = ACTIONS(12225),
    [anon_sym_POUNDelse] = ACTIONS(12225),
    [anon_sym_POUNDELSE] = ACTIONS(12225),
    [anon_sym_POUNDElse] = ACTIONS(12225),
    [anon_sym_POUNDelse2] = ACTIONS(12225),
    [anon_sym_POUNDELSE2] = ACTIONS(12225),
    [anon_sym_POUNDElse2] = ACTIONS(12225),
    [anon_sym_POUNDendif] = ACTIONS(12225),
    [anon_sym_POUNDENDIF] = ACTIONS(12225),
    [anon_sym_POUNDEndif] = ACTIONS(12225),
    [anon_sym_POUNDendif2] = ACTIONS(12225),
    [anon_sym_POUNDENDIF2] = ACTIONS(12225),
    [anon_sym_POUNDEndif2] = ACTIONS(12225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12225),
    [sym_trigger_keyword] = ACTIONS(12225),
    [sym_var_keyword] = ACTIONS(12225),
    [sym_local_keyword] = ACTIONS(12225),
    [sym_internal_keyword] = ACTIONS(12225),
    [sym_protected_keyword] = ACTIONS(12225),
    [sym_event_keyword] = ACTIONS(12225),
    [sym_fields_keyword] = ACTIONS(12225),
    [sym_keys_keyword] = ACTIONS(12225),
    [sym_fieldgroups_keyword] = ACTIONS(12225),
    [sym_actions_keyword] = ACTIONS(12225),
    [sym_layout_keyword] = ACTIONS(12225),
    [sym_area_keyword] = ACTIONS(12225),
    [sym_group_keyword] = ACTIONS(12225),
    [sym_repeater_keyword] = ACTIONS(12225),
    [sym_cuegroup_keyword] = ACTIONS(12225),
    [sym_fixed_keyword] = ACTIONS(12225),
    [sym_grid_keyword] = ACTIONS(12225),
    [sym_part_keyword] = ACTIONS(12225),
    [sym_systempart_keyword] = ACTIONS(12225),
    [sym_usercontrol_keyword] = ACTIONS(12225),
    [sym_dataset_keyword] = ACTIONS(12225),
    [sym_elements_keyword] = ACTIONS(12225),
    [sym_dataitem_keyword] = ACTIONS(12225),
    [sym_column_keyword] = ACTIONS(12225),
    [sym_filter_keyword] = ACTIONS(12225),
    [sym_labels_keyword] = ACTIONS(12225),
    [sym_rendering_keyword] = ACTIONS(12225),
    [sym_requestpage_keyword] = ACTIONS(12225),
    [sym_schema_keyword] = ACTIONS(12225),
    [sym_views_keyword] = ACTIONS(12225),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12225),
    [sym_preproc_open] = ACTIONS(12225),
    [sym_preproc_close] = ACTIONS(12225),
  },
  [STATE(5091)] = {
    [anon_sym_SEMI] = ACTIONS(12505),
    [aux_sym_where_condition_token1] = ACTIONS(12507),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12509),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12509),
    [anon_sym_LBRACK] = ACTIONS(12509),
    [aux_sym_basic_type_token6] = ACTIONS(12507),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12509),
    [aux_sym_addafter_modification_token1] = ACTIONS(12509),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12509),
    [aux_sym_modify_modification_token1] = ACTIONS(12509),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12509),
    [aux_sym_movelast_modification_token1] = ACTIONS(12509),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12509),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12509),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12509),
    [anon_sym_POUNDif] = ACTIONS(12509),
    [anon_sym_POUNDIF] = ACTIONS(12509),
    [anon_sym_POUNDIf] = ACTIONS(12509),
    [anon_sym_POUNDelif] = ACTIONS(12509),
    [anon_sym_POUNDELIF] = ACTIONS(12509),
    [anon_sym_POUNDElif] = ACTIONS(12509),
    [anon_sym_POUNDelse] = ACTIONS(12509),
    [anon_sym_POUNDELSE] = ACTIONS(12509),
    [anon_sym_POUNDElse] = ACTIONS(12509),
    [anon_sym_POUNDelse2] = ACTIONS(12509),
    [anon_sym_POUNDELSE2] = ACTIONS(12509),
    [anon_sym_POUNDElse2] = ACTIONS(12509),
    [anon_sym_POUNDendif] = ACTIONS(12509),
    [anon_sym_POUNDENDIF] = ACTIONS(12509),
    [anon_sym_POUNDEndif] = ACTIONS(12509),
    [anon_sym_POUNDendif2] = ACTIONS(12509),
    [anon_sym_POUNDENDIF2] = ACTIONS(12509),
    [anon_sym_POUNDEndif2] = ACTIONS(12509),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12509),
    [sym_trigger_keyword] = ACTIONS(12509),
    [sym_var_keyword] = ACTIONS(12509),
    [sym_local_keyword] = ACTIONS(12509),
    [sym_internal_keyword] = ACTIONS(12509),
    [sym_protected_keyword] = ACTIONS(12509),
    [sym_event_keyword] = ACTIONS(12509),
    [sym_fields_keyword] = ACTIONS(12509),
    [sym_keys_keyword] = ACTIONS(12509),
    [sym_fieldgroups_keyword] = ACTIONS(12509),
    [sym_actions_keyword] = ACTIONS(12509),
    [sym_layout_keyword] = ACTIONS(12509),
    [sym_area_keyword] = ACTIONS(12509),
    [sym_group_keyword] = ACTIONS(12509),
    [sym_repeater_keyword] = ACTIONS(12509),
    [sym_cuegroup_keyword] = ACTIONS(12509),
    [sym_fixed_keyword] = ACTIONS(12509),
    [sym_grid_keyword] = ACTIONS(12509),
    [sym_part_keyword] = ACTIONS(12509),
    [sym_systempart_keyword] = ACTIONS(12509),
    [sym_usercontrol_keyword] = ACTIONS(12509),
    [sym_dataset_keyword] = ACTIONS(12509),
    [sym_elements_keyword] = ACTIONS(12509),
    [sym_dataitem_keyword] = ACTIONS(12509),
    [sym_column_keyword] = ACTIONS(12509),
    [sym_filter_keyword] = ACTIONS(12509),
    [sym_labels_keyword] = ACTIONS(12509),
    [sym_rendering_keyword] = ACTIONS(12509),
    [sym_requestpage_keyword] = ACTIONS(12509),
    [sym_schema_keyword] = ACTIONS(12509),
    [sym_views_keyword] = ACTIONS(12509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12509),
    [sym_preproc_open] = ACTIONS(12509),
    [sym_preproc_close] = ACTIONS(12509),
  },
  [STATE(5092)] = {
    [anon_sym_SEMI] = ACTIONS(12511),
    [aux_sym_where_condition_token1] = ACTIONS(12507),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12509),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12509),
    [anon_sym_LBRACK] = ACTIONS(12509),
    [aux_sym_basic_type_token6] = ACTIONS(12507),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12509),
    [aux_sym_addafter_modification_token1] = ACTIONS(12509),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12509),
    [aux_sym_modify_modification_token1] = ACTIONS(12509),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12509),
    [aux_sym_movelast_modification_token1] = ACTIONS(12509),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12509),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12509),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12509),
    [anon_sym_POUNDif] = ACTIONS(12509),
    [anon_sym_POUNDIF] = ACTIONS(12509),
    [anon_sym_POUNDIf] = ACTIONS(12509),
    [anon_sym_POUNDelif] = ACTIONS(12509),
    [anon_sym_POUNDELIF] = ACTIONS(12509),
    [anon_sym_POUNDElif] = ACTIONS(12509),
    [anon_sym_POUNDelse] = ACTIONS(12509),
    [anon_sym_POUNDELSE] = ACTIONS(12509),
    [anon_sym_POUNDElse] = ACTIONS(12509),
    [anon_sym_POUNDelse2] = ACTIONS(12509),
    [anon_sym_POUNDELSE2] = ACTIONS(12509),
    [anon_sym_POUNDElse2] = ACTIONS(12509),
    [anon_sym_POUNDendif] = ACTIONS(12509),
    [anon_sym_POUNDENDIF] = ACTIONS(12509),
    [anon_sym_POUNDEndif] = ACTIONS(12509),
    [anon_sym_POUNDendif2] = ACTIONS(12509),
    [anon_sym_POUNDENDIF2] = ACTIONS(12509),
    [anon_sym_POUNDEndif2] = ACTIONS(12509),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12509),
    [sym_trigger_keyword] = ACTIONS(12509),
    [sym_var_keyword] = ACTIONS(12509),
    [sym_local_keyword] = ACTIONS(12509),
    [sym_internal_keyword] = ACTIONS(12509),
    [sym_protected_keyword] = ACTIONS(12509),
    [sym_event_keyword] = ACTIONS(12509),
    [sym_fields_keyword] = ACTIONS(12509),
    [sym_keys_keyword] = ACTIONS(12509),
    [sym_fieldgroups_keyword] = ACTIONS(12509),
    [sym_actions_keyword] = ACTIONS(12509),
    [sym_layout_keyword] = ACTIONS(12509),
    [sym_area_keyword] = ACTIONS(12509),
    [sym_group_keyword] = ACTIONS(12509),
    [sym_repeater_keyword] = ACTIONS(12509),
    [sym_cuegroup_keyword] = ACTIONS(12509),
    [sym_fixed_keyword] = ACTIONS(12509),
    [sym_grid_keyword] = ACTIONS(12509),
    [sym_part_keyword] = ACTIONS(12509),
    [sym_systempart_keyword] = ACTIONS(12509),
    [sym_usercontrol_keyword] = ACTIONS(12509),
    [sym_dataset_keyword] = ACTIONS(12509),
    [sym_elements_keyword] = ACTIONS(12509),
    [sym_dataitem_keyword] = ACTIONS(12509),
    [sym_column_keyword] = ACTIONS(12509),
    [sym_filter_keyword] = ACTIONS(12509),
    [sym_labels_keyword] = ACTIONS(12509),
    [sym_rendering_keyword] = ACTIONS(12509),
    [sym_requestpage_keyword] = ACTIONS(12509),
    [sym_schema_keyword] = ACTIONS(12509),
    [sym_views_keyword] = ACTIONS(12509),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12509),
    [sym_preproc_open] = ACTIONS(12509),
    [sym_preproc_close] = ACTIONS(12509),
  },
  [STATE(5093)] = {
    [anon_sym_SEMI] = ACTIONS(12513),
    [aux_sym_where_condition_token1] = ACTIONS(12223),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12225),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12225),
    [anon_sym_LBRACK] = ACTIONS(12225),
    [aux_sym_basic_type_token6] = ACTIONS(12223),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12225),
    [aux_sym_addafter_modification_token1] = ACTIONS(12225),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12225),
    [aux_sym_modify_modification_token1] = ACTIONS(12225),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12225),
    [aux_sym_movelast_modification_token1] = ACTIONS(12225),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12225),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12225),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12225),
    [anon_sym_POUNDif] = ACTIONS(12225),
    [anon_sym_POUNDIF] = ACTIONS(12225),
    [anon_sym_POUNDIf] = ACTIONS(12225),
    [anon_sym_POUNDelif] = ACTIONS(12225),
    [anon_sym_POUNDELIF] = ACTIONS(12225),
    [anon_sym_POUNDElif] = ACTIONS(12225),
    [anon_sym_POUNDelse] = ACTIONS(12225),
    [anon_sym_POUNDELSE] = ACTIONS(12225),
    [anon_sym_POUNDElse] = ACTIONS(12225),
    [anon_sym_POUNDelse2] = ACTIONS(12225),
    [anon_sym_POUNDELSE2] = ACTIONS(12225),
    [anon_sym_POUNDElse2] = ACTIONS(12225),
    [anon_sym_POUNDendif] = ACTIONS(12225),
    [anon_sym_POUNDENDIF] = ACTIONS(12225),
    [anon_sym_POUNDEndif] = ACTIONS(12225),
    [anon_sym_POUNDendif2] = ACTIONS(12225),
    [anon_sym_POUNDENDIF2] = ACTIONS(12225),
    [anon_sym_POUNDEndif2] = ACTIONS(12225),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12225),
    [sym_trigger_keyword] = ACTIONS(12225),
    [sym_var_keyword] = ACTIONS(12225),
    [sym_local_keyword] = ACTIONS(12225),
    [sym_internal_keyword] = ACTIONS(12225),
    [sym_protected_keyword] = ACTIONS(12225),
    [sym_event_keyword] = ACTIONS(12225),
    [sym_fields_keyword] = ACTIONS(12225),
    [sym_keys_keyword] = ACTIONS(12225),
    [sym_fieldgroups_keyword] = ACTIONS(12225),
    [sym_actions_keyword] = ACTIONS(12225),
    [sym_layout_keyword] = ACTIONS(12225),
    [sym_area_keyword] = ACTIONS(12225),
    [sym_group_keyword] = ACTIONS(12225),
    [sym_repeater_keyword] = ACTIONS(12225),
    [sym_cuegroup_keyword] = ACTIONS(12225),
    [sym_fixed_keyword] = ACTIONS(12225),
    [sym_grid_keyword] = ACTIONS(12225),
    [sym_part_keyword] = ACTIONS(12225),
    [sym_systempart_keyword] = ACTIONS(12225),
    [sym_usercontrol_keyword] = ACTIONS(12225),
    [sym_dataset_keyword] = ACTIONS(12225),
    [sym_elements_keyword] = ACTIONS(12225),
    [sym_dataitem_keyword] = ACTIONS(12225),
    [sym_column_keyword] = ACTIONS(12225),
    [sym_filter_keyword] = ACTIONS(12225),
    [sym_labels_keyword] = ACTIONS(12225),
    [sym_rendering_keyword] = ACTIONS(12225),
    [sym_requestpage_keyword] = ACTIONS(12225),
    [sym_schema_keyword] = ACTIONS(12225),
    [sym_views_keyword] = ACTIONS(12225),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12225),
    [sym_preproc_open] = ACTIONS(12225),
    [sym_preproc_close] = ACTIONS(12225),
  },
  [STATE(5094)] = {
    [anon_sym_SEMI] = ACTIONS(12515),
    [aux_sym_where_condition_token1] = ACTIONS(12517),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12519),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12519),
    [anon_sym_LBRACK] = ACTIONS(12519),
    [aux_sym_basic_type_token6] = ACTIONS(12517),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12519),
    [aux_sym_addafter_modification_token1] = ACTIONS(12519),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12519),
    [aux_sym_modify_modification_token1] = ACTIONS(12519),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12519),
    [aux_sym_movelast_modification_token1] = ACTIONS(12519),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12519),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12519),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12519),
    [anon_sym_POUNDif] = ACTIONS(12519),
    [anon_sym_POUNDIF] = ACTIONS(12519),
    [anon_sym_POUNDIf] = ACTIONS(12519),
    [anon_sym_POUNDelif] = ACTIONS(12519),
    [anon_sym_POUNDELIF] = ACTIONS(12519),
    [anon_sym_POUNDElif] = ACTIONS(12519),
    [anon_sym_POUNDelse] = ACTIONS(12519),
    [anon_sym_POUNDELSE] = ACTIONS(12519),
    [anon_sym_POUNDElse] = ACTIONS(12519),
    [anon_sym_POUNDelse2] = ACTIONS(12519),
    [anon_sym_POUNDELSE2] = ACTIONS(12519),
    [anon_sym_POUNDElse2] = ACTIONS(12519),
    [anon_sym_POUNDendif] = ACTIONS(12519),
    [anon_sym_POUNDENDIF] = ACTIONS(12519),
    [anon_sym_POUNDEndif] = ACTIONS(12519),
    [anon_sym_POUNDendif2] = ACTIONS(12519),
    [anon_sym_POUNDENDIF2] = ACTIONS(12519),
    [anon_sym_POUNDEndif2] = ACTIONS(12519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12519),
    [sym_trigger_keyword] = ACTIONS(12519),
    [sym_var_keyword] = ACTIONS(12519),
    [sym_local_keyword] = ACTIONS(12519),
    [sym_internal_keyword] = ACTIONS(12519),
    [sym_protected_keyword] = ACTIONS(12519),
    [sym_event_keyword] = ACTIONS(12519),
    [sym_fields_keyword] = ACTIONS(12519),
    [sym_keys_keyword] = ACTIONS(12519),
    [sym_fieldgroups_keyword] = ACTIONS(12519),
    [sym_actions_keyword] = ACTIONS(12519),
    [sym_layout_keyword] = ACTIONS(12519),
    [sym_area_keyword] = ACTIONS(12519),
    [sym_group_keyword] = ACTIONS(12519),
    [sym_repeater_keyword] = ACTIONS(12519),
    [sym_cuegroup_keyword] = ACTIONS(12519),
    [sym_fixed_keyword] = ACTIONS(12519),
    [sym_grid_keyword] = ACTIONS(12519),
    [sym_part_keyword] = ACTIONS(12519),
    [sym_systempart_keyword] = ACTIONS(12519),
    [sym_usercontrol_keyword] = ACTIONS(12519),
    [sym_dataset_keyword] = ACTIONS(12519),
    [sym_elements_keyword] = ACTIONS(12519),
    [sym_dataitem_keyword] = ACTIONS(12519),
    [sym_column_keyword] = ACTIONS(12519),
    [sym_filter_keyword] = ACTIONS(12519),
    [sym_labels_keyword] = ACTIONS(12519),
    [sym_rendering_keyword] = ACTIONS(12519),
    [sym_requestpage_keyword] = ACTIONS(12519),
    [sym_schema_keyword] = ACTIONS(12519),
    [sym_views_keyword] = ACTIONS(12519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12519),
    [sym_preproc_open] = ACTIONS(12519),
    [sym_preproc_close] = ACTIONS(12519),
  },
  [STATE(5095)] = {
    [anon_sym_SEMI] = ACTIONS(12521),
    [aux_sym_where_condition_token1] = ACTIONS(12517),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12519),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12519),
    [anon_sym_LBRACK] = ACTIONS(12519),
    [aux_sym_basic_type_token6] = ACTIONS(12517),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12519),
    [aux_sym_addafter_modification_token1] = ACTIONS(12519),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12519),
    [aux_sym_modify_modification_token1] = ACTIONS(12519),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12519),
    [aux_sym_movelast_modification_token1] = ACTIONS(12519),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12519),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12519),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12519),
    [anon_sym_POUNDif] = ACTIONS(12519),
    [anon_sym_POUNDIF] = ACTIONS(12519),
    [anon_sym_POUNDIf] = ACTIONS(12519),
    [anon_sym_POUNDelif] = ACTIONS(12519),
    [anon_sym_POUNDELIF] = ACTIONS(12519),
    [anon_sym_POUNDElif] = ACTIONS(12519),
    [anon_sym_POUNDelse] = ACTIONS(12519),
    [anon_sym_POUNDELSE] = ACTIONS(12519),
    [anon_sym_POUNDElse] = ACTIONS(12519),
    [anon_sym_POUNDelse2] = ACTIONS(12519),
    [anon_sym_POUNDELSE2] = ACTIONS(12519),
    [anon_sym_POUNDElse2] = ACTIONS(12519),
    [anon_sym_POUNDendif] = ACTIONS(12519),
    [anon_sym_POUNDENDIF] = ACTIONS(12519),
    [anon_sym_POUNDEndif] = ACTIONS(12519),
    [anon_sym_POUNDendif2] = ACTIONS(12519),
    [anon_sym_POUNDENDIF2] = ACTIONS(12519),
    [anon_sym_POUNDEndif2] = ACTIONS(12519),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12519),
    [sym_trigger_keyword] = ACTIONS(12519),
    [sym_var_keyword] = ACTIONS(12519),
    [sym_local_keyword] = ACTIONS(12519),
    [sym_internal_keyword] = ACTIONS(12519),
    [sym_protected_keyword] = ACTIONS(12519),
    [sym_event_keyword] = ACTIONS(12519),
    [sym_fields_keyword] = ACTIONS(12519),
    [sym_keys_keyword] = ACTIONS(12519),
    [sym_fieldgroups_keyword] = ACTIONS(12519),
    [sym_actions_keyword] = ACTIONS(12519),
    [sym_layout_keyword] = ACTIONS(12519),
    [sym_area_keyword] = ACTIONS(12519),
    [sym_group_keyword] = ACTIONS(12519),
    [sym_repeater_keyword] = ACTIONS(12519),
    [sym_cuegroup_keyword] = ACTIONS(12519),
    [sym_fixed_keyword] = ACTIONS(12519),
    [sym_grid_keyword] = ACTIONS(12519),
    [sym_part_keyword] = ACTIONS(12519),
    [sym_systempart_keyword] = ACTIONS(12519),
    [sym_usercontrol_keyword] = ACTIONS(12519),
    [sym_dataset_keyword] = ACTIONS(12519),
    [sym_elements_keyword] = ACTIONS(12519),
    [sym_dataitem_keyword] = ACTIONS(12519),
    [sym_column_keyword] = ACTIONS(12519),
    [sym_filter_keyword] = ACTIONS(12519),
    [sym_labels_keyword] = ACTIONS(12519),
    [sym_rendering_keyword] = ACTIONS(12519),
    [sym_requestpage_keyword] = ACTIONS(12519),
    [sym_schema_keyword] = ACTIONS(12519),
    [sym_views_keyword] = ACTIONS(12519),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12519),
    [sym_preproc_open] = ACTIONS(12519),
    [sym_preproc_close] = ACTIONS(12519),
  },
  [STATE(5096)] = {
    [anon_sym_SEMI] = ACTIONS(8430),
    [anon_sym_RBRACE] = ACTIONS(8430),
    [aux_sym_where_condition_token1] = ACTIONS(8432),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8430),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8432),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8430),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8430),
    [anon_sym_LBRACK] = ACTIONS(8430),
    [aux_sym_basic_type_token6] = ACTIONS(8432),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8430),
    [aux_sym_addafter_modification_token1] = ACTIONS(8430),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8430),
    [aux_sym_modify_modification_token1] = ACTIONS(8430),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8430),
    [aux_sym_movelast_modification_token1] = ACTIONS(8430),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8430),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8430),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8430),
    [anon_sym_POUNDif] = ACTIONS(8430),
    [anon_sym_POUNDIF] = ACTIONS(8430),
    [anon_sym_POUNDIf] = ACTIONS(8430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8432),
    [sym_page_keyword] = ACTIONS(8430),
    [anon_sym_codeunit] = ACTIONS(8430),
    [anon_sym_CODEUNIT] = ACTIONS(8430),
    [anon_sym_Codeunit] = ACTIONS(8430),
    [anon_sym_CodeUnit] = ACTIONS(8430),
    [anon_sym_COdeunit] = ACTIONS(8430),
    [anon_sym_codeUnit] = ACTIONS(8430),
    [sym_report_keyword] = ACTIONS(8430),
    [sym_query_keyword] = ACTIONS(8430),
    [anon_sym_xmlport] = ACTIONS(8430),
    [anon_sym_XMLPORT] = ACTIONS(8430),
    [anon_sym_Xmlport] = ACTIONS(8430),
    [anon_sym_XMLport] = ACTIONS(8430),
    [anon_sym_XMLPort] = ACTIONS(8430),
    [anon_sym_XmlPort] = ACTIONS(8430),
    [sym_procedure_keyword] = ACTIONS(8430),
    [sym_trigger_keyword] = ACTIONS(8430),
    [sym_var_keyword] = ACTIONS(8430),
    [sym_local_keyword] = ACTIONS(8430),
    [sym_internal_keyword] = ACTIONS(8430),
    [sym_protected_keyword] = ACTIONS(8430),
    [sym_event_keyword] = ACTIONS(8430),
    [sym_fields_keyword] = ACTIONS(8430),
    [sym_keys_keyword] = ACTIONS(8430),
    [sym_fieldgroups_keyword] = ACTIONS(8430),
    [sym_actions_keyword] = ACTIONS(8430),
    [sym_layout_keyword] = ACTIONS(8430),
    [sym_area_keyword] = ACTIONS(8430),
    [sym_group_keyword] = ACTIONS(8430),
    [sym_repeater_keyword] = ACTIONS(8430),
    [sym_cuegroup_keyword] = ACTIONS(8430),
    [sym_fixed_keyword] = ACTIONS(8430),
    [sym_grid_keyword] = ACTIONS(8430),
    [sym_part_keyword] = ACTIONS(8430),
    [sym_systempart_keyword] = ACTIONS(8430),
    [sym_usercontrol_keyword] = ACTIONS(8430),
    [sym_dataset_keyword] = ACTIONS(8430),
    [sym_elements_keyword] = ACTIONS(8430),
    [sym_labels_keyword] = ACTIONS(8430),
    [sym_rendering_keyword] = ACTIONS(8430),
    [sym_requestpage_keyword] = ACTIONS(8430),
    [sym_schema_keyword] = ACTIONS(8430),
    [sym_views_keyword] = ACTIONS(8430),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8430),
    [sym_preproc_open] = ACTIONS(8430),
  },
  [STATE(5097)] = {
    [sym__body_element] = STATE(5097),
    [sym_empty_statement] = STATE(5097),
    [sym_property] = STATE(5097),
    [sym_permissions_property] = STATE(5097),
    [sym_table_relation_property] = STATE(5097),
    [sym_fields_section] = STATE(5097),
    [sym_keys_section] = STATE(5097),
    [sym_fieldgroups_section] = STATE(5097),
    [sym_enum_value_declaration] = STATE(5097),
    [sym_labels_section] = STATE(5097),
    [sym_layout_section] = STATE(5097),
    [sym_modify_modification] = STATE(5097),
    [sym_actions_section] = STATE(5097),
    [sym_views_section] = STATE(5097),
    [sym_dataset_section] = STATE(5097),
    [sym_report_dataitem] = STATE(5097),
    [sym__report_body_element] = STATE(5097),
    [sym_preproc_conditional_report] = STATE(5097),
    [sym_report_column] = STATE(5097),
    [sym_requestpage_section] = STATE(5097),
    [sym_rendering_section] = STATE(5097),
    [sym_elements_section] = STATE(5097),
    [sym_schema_section] = STATE(5097),
    [sym_assembly_declaration] = STATE(5097),
    [sym_event_declaration] = STATE(5097),
    [sym_procedure] = STATE(5097),
    [sym_preproc_split_procedure] = STATE(5097),
    [sym_preproc_split_procedure_preamble] = STATE(5097),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5097),
    [sym_var_section] = STATE(5097),
    [sym_attribute_item] = STATE(5097),
    [sym_preproc_conditional] = STATE(5097),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5097),
    [anon_sym_SEMI] = ACTIONS(12523),
    [anon_sym_RBRACE] = ACTIONS(8482),
    [anon_sym_LBRACK] = ACTIONS(12526),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12529),
    [aux_sym_modify_modification_token1] = ACTIONS(12532),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12535),
    [anon_sym_POUNDif] = ACTIONS(8479),
    [anon_sym_POUNDIF] = ACTIONS(8479),
    [anon_sym_POUNDIf] = ACTIONS(8479),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12538),
    [sym_trigger_keyword] = ACTIONS(12541),
    [sym_var_keyword] = ACTIONS(12544),
    [sym_local_keyword] = ACTIONS(12547),
    [sym_internal_keyword] = ACTIONS(8496),
    [sym_protected_keyword] = ACTIONS(12547),
    [sym_event_keyword] = ACTIONS(12550),
    [sym_fields_keyword] = ACTIONS(12553),
    [sym_keys_keyword] = ACTIONS(12556),
    [sym_fieldgroups_keyword] = ACTIONS(12559),
    [sym_actions_keyword] = ACTIONS(12562),
    [sym_layout_keyword] = ACTIONS(12565),
    [sym_dataset_keyword] = ACTIONS(12568),
    [sym_elements_keyword] = ACTIONS(12571),
    [sym_dataitem_keyword] = ACTIONS(12574),
    [sym_column_keyword] = ACTIONS(12577),
    [sym_labels_keyword] = ACTIONS(12580),
    [sym_rendering_keyword] = ACTIONS(12583),
    [sym_requestpage_keyword] = ACTIONS(12586),
    [sym_schema_keyword] = ACTIONS(12589),
    [sym_views_keyword] = ACTIONS(12592),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12595),
    [sym_preproc_open] = ACTIONS(8479),
  },
  [STATE(5098)] = {
    [anon_sym_SEMI] = ACTIONS(8434),
    [anon_sym_RBRACE] = ACTIONS(8434),
    [aux_sym_where_condition_token1] = ACTIONS(8436),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8434),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8436),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8434),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8434),
    [anon_sym_LBRACK] = ACTIONS(8434),
    [aux_sym_basic_type_token6] = ACTIONS(8436),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8434),
    [aux_sym_addafter_modification_token1] = ACTIONS(8434),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8434),
    [aux_sym_modify_modification_token1] = ACTIONS(8434),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8434),
    [aux_sym_movelast_modification_token1] = ACTIONS(8434),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8434),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8434),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8434),
    [anon_sym_POUNDif] = ACTIONS(8434),
    [anon_sym_POUNDIF] = ACTIONS(8434),
    [anon_sym_POUNDIf] = ACTIONS(8434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8436),
    [sym_page_keyword] = ACTIONS(8434),
    [anon_sym_codeunit] = ACTIONS(8434),
    [anon_sym_CODEUNIT] = ACTIONS(8434),
    [anon_sym_Codeunit] = ACTIONS(8434),
    [anon_sym_CodeUnit] = ACTIONS(8434),
    [anon_sym_COdeunit] = ACTIONS(8434),
    [anon_sym_codeUnit] = ACTIONS(8434),
    [sym_report_keyword] = ACTIONS(8434),
    [sym_query_keyword] = ACTIONS(8434),
    [anon_sym_xmlport] = ACTIONS(8434),
    [anon_sym_XMLPORT] = ACTIONS(8434),
    [anon_sym_Xmlport] = ACTIONS(8434),
    [anon_sym_XMLport] = ACTIONS(8434),
    [anon_sym_XMLPort] = ACTIONS(8434),
    [anon_sym_XmlPort] = ACTIONS(8434),
    [sym_procedure_keyword] = ACTIONS(8434),
    [sym_trigger_keyword] = ACTIONS(8434),
    [sym_var_keyword] = ACTIONS(8434),
    [sym_local_keyword] = ACTIONS(8434),
    [sym_internal_keyword] = ACTIONS(8434),
    [sym_protected_keyword] = ACTIONS(8434),
    [sym_event_keyword] = ACTIONS(8434),
    [sym_fields_keyword] = ACTIONS(8434),
    [sym_keys_keyword] = ACTIONS(8434),
    [sym_fieldgroups_keyword] = ACTIONS(8434),
    [sym_actions_keyword] = ACTIONS(8434),
    [sym_layout_keyword] = ACTIONS(8434),
    [sym_area_keyword] = ACTIONS(8434),
    [sym_group_keyword] = ACTIONS(8434),
    [sym_repeater_keyword] = ACTIONS(8434),
    [sym_cuegroup_keyword] = ACTIONS(8434),
    [sym_fixed_keyword] = ACTIONS(8434),
    [sym_grid_keyword] = ACTIONS(8434),
    [sym_part_keyword] = ACTIONS(8434),
    [sym_systempart_keyword] = ACTIONS(8434),
    [sym_usercontrol_keyword] = ACTIONS(8434),
    [sym_dataset_keyword] = ACTIONS(8434),
    [sym_elements_keyword] = ACTIONS(8434),
    [sym_labels_keyword] = ACTIONS(8434),
    [sym_rendering_keyword] = ACTIONS(8434),
    [sym_requestpage_keyword] = ACTIONS(8434),
    [sym_schema_keyword] = ACTIONS(8434),
    [sym_views_keyword] = ACTIONS(8434),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8434),
    [sym_preproc_open] = ACTIONS(8434),
  },
  [STATE(5099)] = {
    [anon_sym_SEMI] = ACTIONS(12598),
    [aux_sym_where_condition_token1] = ACTIONS(12600),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12598),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12598),
    [anon_sym_LBRACK] = ACTIONS(12598),
    [aux_sym_basic_type_token6] = ACTIONS(12600),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12598),
    [aux_sym_addafter_modification_token1] = ACTIONS(12598),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12598),
    [aux_sym_modify_modification_token1] = ACTIONS(12598),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12598),
    [aux_sym_movelast_modification_token1] = ACTIONS(12598),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12598),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12598),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12598),
    [anon_sym_POUNDif] = ACTIONS(12598),
    [anon_sym_POUNDIF] = ACTIONS(12598),
    [anon_sym_POUNDIf] = ACTIONS(12598),
    [anon_sym_POUNDelif] = ACTIONS(12598),
    [anon_sym_POUNDELIF] = ACTIONS(12598),
    [anon_sym_POUNDElif] = ACTIONS(12598),
    [anon_sym_POUNDelse] = ACTIONS(12598),
    [anon_sym_POUNDELSE] = ACTIONS(12598),
    [anon_sym_POUNDElse] = ACTIONS(12598),
    [anon_sym_POUNDelse2] = ACTIONS(12598),
    [anon_sym_POUNDELSE2] = ACTIONS(12598),
    [anon_sym_POUNDElse2] = ACTIONS(12598),
    [anon_sym_POUNDendif] = ACTIONS(12598),
    [anon_sym_POUNDENDIF] = ACTIONS(12598),
    [anon_sym_POUNDEndif] = ACTIONS(12598),
    [anon_sym_POUNDendif2] = ACTIONS(12598),
    [anon_sym_POUNDENDIF2] = ACTIONS(12598),
    [anon_sym_POUNDEndif2] = ACTIONS(12598),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12598),
    [sym_trigger_keyword] = ACTIONS(12598),
    [sym_var_keyword] = ACTIONS(12598),
    [sym_local_keyword] = ACTIONS(12598),
    [sym_internal_keyword] = ACTIONS(12598),
    [sym_protected_keyword] = ACTIONS(12598),
    [sym_event_keyword] = ACTIONS(12598),
    [sym_fields_keyword] = ACTIONS(12598),
    [sym_keys_keyword] = ACTIONS(12598),
    [sym_fieldgroups_keyword] = ACTIONS(12598),
    [sym_actions_keyword] = ACTIONS(12598),
    [sym_layout_keyword] = ACTIONS(12598),
    [sym_area_keyword] = ACTIONS(12598),
    [sym_group_keyword] = ACTIONS(12598),
    [sym_repeater_keyword] = ACTIONS(12598),
    [sym_cuegroup_keyword] = ACTIONS(12598),
    [sym_fixed_keyword] = ACTIONS(12598),
    [sym_grid_keyword] = ACTIONS(12598),
    [sym_part_keyword] = ACTIONS(12598),
    [sym_systempart_keyword] = ACTIONS(12598),
    [sym_usercontrol_keyword] = ACTIONS(12598),
    [sym_dataset_keyword] = ACTIONS(12598),
    [sym_elements_keyword] = ACTIONS(12598),
    [sym_dataitem_keyword] = ACTIONS(12598),
    [sym_column_keyword] = ACTIONS(12598),
    [sym_filter_keyword] = ACTIONS(12598),
    [sym_labels_keyword] = ACTIONS(12598),
    [sym_rendering_keyword] = ACTIONS(12598),
    [sym_requestpage_keyword] = ACTIONS(12598),
    [sym_schema_keyword] = ACTIONS(12598),
    [sym_views_keyword] = ACTIONS(12598),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12598),
    [sym_preproc_open] = ACTIONS(12598),
    [sym_preproc_close] = ACTIONS(12598),
  },
  [STATE(5100)] = {
    [anon_sym_SEMI] = ACTIONS(12602),
    [aux_sym_where_condition_token1] = ACTIONS(12604),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12602),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12602),
    [anon_sym_LBRACK] = ACTIONS(12602),
    [aux_sym_basic_type_token6] = ACTIONS(12604),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12602),
    [aux_sym_addafter_modification_token1] = ACTIONS(12602),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12602),
    [aux_sym_modify_modification_token1] = ACTIONS(12602),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12602),
    [aux_sym_movelast_modification_token1] = ACTIONS(12602),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12602),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12602),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12602),
    [anon_sym_POUNDif] = ACTIONS(12602),
    [anon_sym_POUNDIF] = ACTIONS(12602),
    [anon_sym_POUNDIf] = ACTIONS(12602),
    [anon_sym_POUNDelif] = ACTIONS(12602),
    [anon_sym_POUNDELIF] = ACTIONS(12602),
    [anon_sym_POUNDElif] = ACTIONS(12602),
    [anon_sym_POUNDelse] = ACTIONS(12602),
    [anon_sym_POUNDELSE] = ACTIONS(12602),
    [anon_sym_POUNDElse] = ACTIONS(12602),
    [anon_sym_POUNDelse2] = ACTIONS(12602),
    [anon_sym_POUNDELSE2] = ACTIONS(12602),
    [anon_sym_POUNDElse2] = ACTIONS(12602),
    [anon_sym_POUNDendif] = ACTIONS(12602),
    [anon_sym_POUNDENDIF] = ACTIONS(12602),
    [anon_sym_POUNDEndif] = ACTIONS(12602),
    [anon_sym_POUNDendif2] = ACTIONS(12602),
    [anon_sym_POUNDENDIF2] = ACTIONS(12602),
    [anon_sym_POUNDEndif2] = ACTIONS(12602),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12602),
    [sym_trigger_keyword] = ACTIONS(12602),
    [sym_var_keyword] = ACTIONS(12602),
    [sym_local_keyword] = ACTIONS(12602),
    [sym_internal_keyword] = ACTIONS(12602),
    [sym_protected_keyword] = ACTIONS(12602),
    [sym_event_keyword] = ACTIONS(12602),
    [sym_fields_keyword] = ACTIONS(12602),
    [sym_keys_keyword] = ACTIONS(12602),
    [sym_fieldgroups_keyword] = ACTIONS(12602),
    [sym_actions_keyword] = ACTIONS(12602),
    [sym_layout_keyword] = ACTIONS(12602),
    [sym_area_keyword] = ACTIONS(12602),
    [sym_group_keyword] = ACTIONS(12602),
    [sym_repeater_keyword] = ACTIONS(12602),
    [sym_cuegroup_keyword] = ACTIONS(12602),
    [sym_fixed_keyword] = ACTIONS(12602),
    [sym_grid_keyword] = ACTIONS(12602),
    [sym_part_keyword] = ACTIONS(12602),
    [sym_systempart_keyword] = ACTIONS(12602),
    [sym_usercontrol_keyword] = ACTIONS(12602),
    [sym_dataset_keyword] = ACTIONS(12602),
    [sym_elements_keyword] = ACTIONS(12602),
    [sym_dataitem_keyword] = ACTIONS(12602),
    [sym_column_keyword] = ACTIONS(12602),
    [sym_filter_keyword] = ACTIONS(12602),
    [sym_labels_keyword] = ACTIONS(12602),
    [sym_rendering_keyword] = ACTIONS(12602),
    [sym_requestpage_keyword] = ACTIONS(12602),
    [sym_schema_keyword] = ACTIONS(12602),
    [sym_views_keyword] = ACTIONS(12602),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12602),
    [sym_preproc_open] = ACTIONS(12602),
    [sym_preproc_close] = ACTIONS(12602),
  },
  [STATE(5101)] = {
    [anon_sym_SEMI] = ACTIONS(12602),
    [aux_sym_where_condition_token1] = ACTIONS(12604),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12602),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12602),
    [anon_sym_LBRACK] = ACTIONS(12602),
    [aux_sym_basic_type_token6] = ACTIONS(12604),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12602),
    [aux_sym_addafter_modification_token1] = ACTIONS(12602),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12602),
    [aux_sym_modify_modification_token1] = ACTIONS(12602),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12602),
    [aux_sym_movelast_modification_token1] = ACTIONS(12602),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12602),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12602),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12602),
    [anon_sym_POUNDif] = ACTIONS(12602),
    [anon_sym_POUNDIF] = ACTIONS(12602),
    [anon_sym_POUNDIf] = ACTIONS(12602),
    [anon_sym_POUNDelif] = ACTIONS(12602),
    [anon_sym_POUNDELIF] = ACTIONS(12602),
    [anon_sym_POUNDElif] = ACTIONS(12602),
    [anon_sym_POUNDelse] = ACTIONS(12602),
    [anon_sym_POUNDELSE] = ACTIONS(12602),
    [anon_sym_POUNDElse] = ACTIONS(12602),
    [anon_sym_POUNDelse2] = ACTIONS(12602),
    [anon_sym_POUNDELSE2] = ACTIONS(12602),
    [anon_sym_POUNDElse2] = ACTIONS(12602),
    [anon_sym_POUNDendif] = ACTIONS(12602),
    [anon_sym_POUNDENDIF] = ACTIONS(12602),
    [anon_sym_POUNDEndif] = ACTIONS(12602),
    [anon_sym_POUNDendif2] = ACTIONS(12602),
    [anon_sym_POUNDENDIF2] = ACTIONS(12602),
    [anon_sym_POUNDEndif2] = ACTIONS(12602),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12602),
    [sym_trigger_keyword] = ACTIONS(12602),
    [sym_var_keyword] = ACTIONS(12602),
    [sym_local_keyword] = ACTIONS(12602),
    [sym_internal_keyword] = ACTIONS(12602),
    [sym_protected_keyword] = ACTIONS(12602),
    [sym_event_keyword] = ACTIONS(12602),
    [sym_fields_keyword] = ACTIONS(12602),
    [sym_keys_keyword] = ACTIONS(12602),
    [sym_fieldgroups_keyword] = ACTIONS(12602),
    [sym_actions_keyword] = ACTIONS(12602),
    [sym_layout_keyword] = ACTIONS(12602),
    [sym_area_keyword] = ACTIONS(12602),
    [sym_group_keyword] = ACTIONS(12602),
    [sym_repeater_keyword] = ACTIONS(12602),
    [sym_cuegroup_keyword] = ACTIONS(12602),
    [sym_fixed_keyword] = ACTIONS(12602),
    [sym_grid_keyword] = ACTIONS(12602),
    [sym_part_keyword] = ACTIONS(12602),
    [sym_systempart_keyword] = ACTIONS(12602),
    [sym_usercontrol_keyword] = ACTIONS(12602),
    [sym_dataset_keyword] = ACTIONS(12602),
    [sym_elements_keyword] = ACTIONS(12602),
    [sym_dataitem_keyword] = ACTIONS(12602),
    [sym_column_keyword] = ACTIONS(12602),
    [sym_filter_keyword] = ACTIONS(12602),
    [sym_labels_keyword] = ACTIONS(12602),
    [sym_rendering_keyword] = ACTIONS(12602),
    [sym_requestpage_keyword] = ACTIONS(12602),
    [sym_schema_keyword] = ACTIONS(12602),
    [sym_views_keyword] = ACTIONS(12602),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12602),
    [sym_preproc_open] = ACTIONS(12602),
    [sym_preproc_close] = ACTIONS(12602),
  },
  [STATE(5102)] = {
    [anon_sym_SEMI] = ACTIONS(8438),
    [anon_sym_RBRACE] = ACTIONS(8438),
    [aux_sym_where_condition_token1] = ACTIONS(8440),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8438),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8440),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8438),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8438),
    [anon_sym_LBRACK] = ACTIONS(8438),
    [aux_sym_basic_type_token6] = ACTIONS(8440),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8438),
    [aux_sym_addafter_modification_token1] = ACTIONS(8438),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8438),
    [aux_sym_modify_modification_token1] = ACTIONS(8438),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8438),
    [aux_sym_movelast_modification_token1] = ACTIONS(8438),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8438),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8438),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8438),
    [anon_sym_POUNDif] = ACTIONS(8438),
    [anon_sym_POUNDIF] = ACTIONS(8438),
    [anon_sym_POUNDIf] = ACTIONS(8438),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8440),
    [sym_page_keyword] = ACTIONS(8438),
    [anon_sym_codeunit] = ACTIONS(8438),
    [anon_sym_CODEUNIT] = ACTIONS(8438),
    [anon_sym_Codeunit] = ACTIONS(8438),
    [anon_sym_CodeUnit] = ACTIONS(8438),
    [anon_sym_COdeunit] = ACTIONS(8438),
    [anon_sym_codeUnit] = ACTIONS(8438),
    [sym_report_keyword] = ACTIONS(8438),
    [sym_query_keyword] = ACTIONS(8438),
    [anon_sym_xmlport] = ACTIONS(8438),
    [anon_sym_XMLPORT] = ACTIONS(8438),
    [anon_sym_Xmlport] = ACTIONS(8438),
    [anon_sym_XMLport] = ACTIONS(8438),
    [anon_sym_XMLPort] = ACTIONS(8438),
    [anon_sym_XmlPort] = ACTIONS(8438),
    [sym_procedure_keyword] = ACTIONS(8438),
    [sym_trigger_keyword] = ACTIONS(8438),
    [sym_var_keyword] = ACTIONS(8438),
    [sym_local_keyword] = ACTIONS(8438),
    [sym_internal_keyword] = ACTIONS(8438),
    [sym_protected_keyword] = ACTIONS(8438),
    [sym_event_keyword] = ACTIONS(8438),
    [sym_fields_keyword] = ACTIONS(8438),
    [sym_keys_keyword] = ACTIONS(8438),
    [sym_fieldgroups_keyword] = ACTIONS(8438),
    [sym_actions_keyword] = ACTIONS(8438),
    [sym_layout_keyword] = ACTIONS(8438),
    [sym_area_keyword] = ACTIONS(8438),
    [sym_group_keyword] = ACTIONS(8438),
    [sym_repeater_keyword] = ACTIONS(8438),
    [sym_cuegroup_keyword] = ACTIONS(8438),
    [sym_fixed_keyword] = ACTIONS(8438),
    [sym_grid_keyword] = ACTIONS(8438),
    [sym_part_keyword] = ACTIONS(8438),
    [sym_systempart_keyword] = ACTIONS(8438),
    [sym_usercontrol_keyword] = ACTIONS(8438),
    [sym_dataset_keyword] = ACTIONS(8438),
    [sym_elements_keyword] = ACTIONS(8438),
    [sym_labels_keyword] = ACTIONS(8438),
    [sym_rendering_keyword] = ACTIONS(8438),
    [sym_requestpage_keyword] = ACTIONS(8438),
    [sym_schema_keyword] = ACTIONS(8438),
    [sym_views_keyword] = ACTIONS(8438),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8438),
    [sym_preproc_open] = ACTIONS(8438),
  },
  [STATE(5103)] = {
    [anon_sym_SEMI] = ACTIONS(12602),
    [aux_sym_where_condition_token1] = ACTIONS(12604),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12602),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12602),
    [anon_sym_LBRACK] = ACTIONS(12602),
    [aux_sym_basic_type_token6] = ACTIONS(12604),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12602),
    [aux_sym_addafter_modification_token1] = ACTIONS(12602),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12602),
    [aux_sym_modify_modification_token1] = ACTIONS(12602),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12602),
    [aux_sym_movelast_modification_token1] = ACTIONS(12602),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12602),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12602),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12602),
    [anon_sym_POUNDif] = ACTIONS(12602),
    [anon_sym_POUNDIF] = ACTIONS(12602),
    [anon_sym_POUNDIf] = ACTIONS(12602),
    [anon_sym_POUNDelif] = ACTIONS(12602),
    [anon_sym_POUNDELIF] = ACTIONS(12602),
    [anon_sym_POUNDElif] = ACTIONS(12602),
    [anon_sym_POUNDelse] = ACTIONS(12602),
    [anon_sym_POUNDELSE] = ACTIONS(12602),
    [anon_sym_POUNDElse] = ACTIONS(12602),
    [anon_sym_POUNDelse2] = ACTIONS(12602),
    [anon_sym_POUNDELSE2] = ACTIONS(12602),
    [anon_sym_POUNDElse2] = ACTIONS(12602),
    [anon_sym_POUNDendif] = ACTIONS(12602),
    [anon_sym_POUNDENDIF] = ACTIONS(12602),
    [anon_sym_POUNDEndif] = ACTIONS(12602),
    [anon_sym_POUNDendif2] = ACTIONS(12602),
    [anon_sym_POUNDENDIF2] = ACTIONS(12602),
    [anon_sym_POUNDEndif2] = ACTIONS(12602),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12602),
    [sym_trigger_keyword] = ACTIONS(12602),
    [sym_var_keyword] = ACTIONS(12602),
    [sym_local_keyword] = ACTIONS(12602),
    [sym_internal_keyword] = ACTIONS(12602),
    [sym_protected_keyword] = ACTIONS(12602),
    [sym_event_keyword] = ACTIONS(12602),
    [sym_fields_keyword] = ACTIONS(12602),
    [sym_keys_keyword] = ACTIONS(12602),
    [sym_fieldgroups_keyword] = ACTIONS(12602),
    [sym_actions_keyword] = ACTIONS(12602),
    [sym_layout_keyword] = ACTIONS(12602),
    [sym_area_keyword] = ACTIONS(12602),
    [sym_group_keyword] = ACTIONS(12602),
    [sym_repeater_keyword] = ACTIONS(12602),
    [sym_cuegroup_keyword] = ACTIONS(12602),
    [sym_fixed_keyword] = ACTIONS(12602),
    [sym_grid_keyword] = ACTIONS(12602),
    [sym_part_keyword] = ACTIONS(12602),
    [sym_systempart_keyword] = ACTIONS(12602),
    [sym_usercontrol_keyword] = ACTIONS(12602),
    [sym_dataset_keyword] = ACTIONS(12602),
    [sym_elements_keyword] = ACTIONS(12602),
    [sym_dataitem_keyword] = ACTIONS(12602),
    [sym_column_keyword] = ACTIONS(12602),
    [sym_filter_keyword] = ACTIONS(12602),
    [sym_labels_keyword] = ACTIONS(12602),
    [sym_rendering_keyword] = ACTIONS(12602),
    [sym_requestpage_keyword] = ACTIONS(12602),
    [sym_schema_keyword] = ACTIONS(12602),
    [sym_views_keyword] = ACTIONS(12602),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12602),
    [sym_preproc_open] = ACTIONS(12602),
    [sym_preproc_close] = ACTIONS(12602),
  },
  [STATE(5104)] = {
    [anon_sym_SEMI] = ACTIONS(12602),
    [aux_sym_where_condition_token1] = ACTIONS(12604),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12602),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12602),
    [anon_sym_LBRACK] = ACTIONS(12602),
    [aux_sym_basic_type_token6] = ACTIONS(12604),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12602),
    [aux_sym_addafter_modification_token1] = ACTIONS(12602),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12602),
    [aux_sym_modify_modification_token1] = ACTIONS(12602),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12602),
    [aux_sym_movelast_modification_token1] = ACTIONS(12602),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12602),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12602),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12602),
    [anon_sym_POUNDif] = ACTIONS(12602),
    [anon_sym_POUNDIF] = ACTIONS(12602),
    [anon_sym_POUNDIf] = ACTIONS(12602),
    [anon_sym_POUNDelif] = ACTIONS(12602),
    [anon_sym_POUNDELIF] = ACTIONS(12602),
    [anon_sym_POUNDElif] = ACTIONS(12602),
    [anon_sym_POUNDelse] = ACTIONS(12602),
    [anon_sym_POUNDELSE] = ACTIONS(12602),
    [anon_sym_POUNDElse] = ACTIONS(12602),
    [anon_sym_POUNDelse2] = ACTIONS(12602),
    [anon_sym_POUNDELSE2] = ACTIONS(12602),
    [anon_sym_POUNDElse2] = ACTIONS(12602),
    [anon_sym_POUNDendif] = ACTIONS(12602),
    [anon_sym_POUNDENDIF] = ACTIONS(12602),
    [anon_sym_POUNDEndif] = ACTIONS(12602),
    [anon_sym_POUNDendif2] = ACTIONS(12602),
    [anon_sym_POUNDENDIF2] = ACTIONS(12602),
    [anon_sym_POUNDEndif2] = ACTIONS(12602),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12602),
    [sym_trigger_keyword] = ACTIONS(12602),
    [sym_var_keyword] = ACTIONS(12602),
    [sym_local_keyword] = ACTIONS(12602),
    [sym_internal_keyword] = ACTIONS(12602),
    [sym_protected_keyword] = ACTIONS(12602),
    [sym_event_keyword] = ACTIONS(12602),
    [sym_fields_keyword] = ACTIONS(12602),
    [sym_keys_keyword] = ACTIONS(12602),
    [sym_fieldgroups_keyword] = ACTIONS(12602),
    [sym_actions_keyword] = ACTIONS(12602),
    [sym_layout_keyword] = ACTIONS(12602),
    [sym_area_keyword] = ACTIONS(12602),
    [sym_group_keyword] = ACTIONS(12602),
    [sym_repeater_keyword] = ACTIONS(12602),
    [sym_cuegroup_keyword] = ACTIONS(12602),
    [sym_fixed_keyword] = ACTIONS(12602),
    [sym_grid_keyword] = ACTIONS(12602),
    [sym_part_keyword] = ACTIONS(12602),
    [sym_systempart_keyword] = ACTIONS(12602),
    [sym_usercontrol_keyword] = ACTIONS(12602),
    [sym_dataset_keyword] = ACTIONS(12602),
    [sym_elements_keyword] = ACTIONS(12602),
    [sym_dataitem_keyword] = ACTIONS(12602),
    [sym_column_keyword] = ACTIONS(12602),
    [sym_filter_keyword] = ACTIONS(12602),
    [sym_labels_keyword] = ACTIONS(12602),
    [sym_rendering_keyword] = ACTIONS(12602),
    [sym_requestpage_keyword] = ACTIONS(12602),
    [sym_schema_keyword] = ACTIONS(12602),
    [sym_views_keyword] = ACTIONS(12602),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12602),
    [sym_preproc_open] = ACTIONS(12602),
    [sym_preproc_close] = ACTIONS(12602),
  },
  [STATE(5105)] = {
    [anon_sym_SEMI] = ACTIONS(8442),
    [anon_sym_RBRACE] = ACTIONS(8442),
    [aux_sym_where_condition_token1] = ACTIONS(8444),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8442),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8444),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8442),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8442),
    [anon_sym_LBRACK] = ACTIONS(8442),
    [aux_sym_basic_type_token6] = ACTIONS(8444),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8442),
    [aux_sym_addafter_modification_token1] = ACTIONS(8442),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8442),
    [aux_sym_modify_modification_token1] = ACTIONS(8442),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8442),
    [aux_sym_movelast_modification_token1] = ACTIONS(8442),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8442),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8442),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8442),
    [anon_sym_POUNDif] = ACTIONS(8442),
    [anon_sym_POUNDIF] = ACTIONS(8442),
    [anon_sym_POUNDIf] = ACTIONS(8442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8444),
    [sym_page_keyword] = ACTIONS(8442),
    [anon_sym_codeunit] = ACTIONS(8442),
    [anon_sym_CODEUNIT] = ACTIONS(8442),
    [anon_sym_Codeunit] = ACTIONS(8442),
    [anon_sym_CodeUnit] = ACTIONS(8442),
    [anon_sym_COdeunit] = ACTIONS(8442),
    [anon_sym_codeUnit] = ACTIONS(8442),
    [sym_report_keyword] = ACTIONS(8442),
    [sym_query_keyword] = ACTIONS(8442),
    [anon_sym_xmlport] = ACTIONS(8442),
    [anon_sym_XMLPORT] = ACTIONS(8442),
    [anon_sym_Xmlport] = ACTIONS(8442),
    [anon_sym_XMLport] = ACTIONS(8442),
    [anon_sym_XMLPort] = ACTIONS(8442),
    [anon_sym_XmlPort] = ACTIONS(8442),
    [sym_procedure_keyword] = ACTIONS(8442),
    [sym_trigger_keyword] = ACTIONS(8442),
    [sym_var_keyword] = ACTIONS(8442),
    [sym_local_keyword] = ACTIONS(8442),
    [sym_internal_keyword] = ACTIONS(8442),
    [sym_protected_keyword] = ACTIONS(8442),
    [sym_event_keyword] = ACTIONS(8442),
    [sym_fields_keyword] = ACTIONS(8442),
    [sym_keys_keyword] = ACTIONS(8442),
    [sym_fieldgroups_keyword] = ACTIONS(8442),
    [sym_actions_keyword] = ACTIONS(8442),
    [sym_layout_keyword] = ACTIONS(8442),
    [sym_area_keyword] = ACTIONS(8442),
    [sym_group_keyword] = ACTIONS(8442),
    [sym_repeater_keyword] = ACTIONS(8442),
    [sym_cuegroup_keyword] = ACTIONS(8442),
    [sym_fixed_keyword] = ACTIONS(8442),
    [sym_grid_keyword] = ACTIONS(8442),
    [sym_part_keyword] = ACTIONS(8442),
    [sym_systempart_keyword] = ACTIONS(8442),
    [sym_usercontrol_keyword] = ACTIONS(8442),
    [sym_dataset_keyword] = ACTIONS(8442),
    [sym_elements_keyword] = ACTIONS(8442),
    [sym_labels_keyword] = ACTIONS(8442),
    [sym_rendering_keyword] = ACTIONS(8442),
    [sym_requestpage_keyword] = ACTIONS(8442),
    [sym_schema_keyword] = ACTIONS(8442),
    [sym_views_keyword] = ACTIONS(8442),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8442),
    [sym_preproc_open] = ACTIONS(8442),
  },
  [STATE(5106)] = {
    [anon_sym_SEMI] = ACTIONS(12602),
    [aux_sym_where_condition_token1] = ACTIONS(12604),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12602),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12602),
    [anon_sym_LBRACK] = ACTIONS(12602),
    [aux_sym_basic_type_token6] = ACTIONS(12604),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12602),
    [aux_sym_addafter_modification_token1] = ACTIONS(12602),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12602),
    [aux_sym_modify_modification_token1] = ACTIONS(12602),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12602),
    [aux_sym_movelast_modification_token1] = ACTIONS(12602),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12602),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12602),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12602),
    [anon_sym_POUNDif] = ACTIONS(12602),
    [anon_sym_POUNDIF] = ACTIONS(12602),
    [anon_sym_POUNDIf] = ACTIONS(12602),
    [anon_sym_POUNDelif] = ACTIONS(12602),
    [anon_sym_POUNDELIF] = ACTIONS(12602),
    [anon_sym_POUNDElif] = ACTIONS(12602),
    [anon_sym_POUNDelse] = ACTIONS(12602),
    [anon_sym_POUNDELSE] = ACTIONS(12602),
    [anon_sym_POUNDElse] = ACTIONS(12602),
    [anon_sym_POUNDelse2] = ACTIONS(12602),
    [anon_sym_POUNDELSE2] = ACTIONS(12602),
    [anon_sym_POUNDElse2] = ACTIONS(12602),
    [anon_sym_POUNDendif] = ACTIONS(12602),
    [anon_sym_POUNDENDIF] = ACTIONS(12602),
    [anon_sym_POUNDEndif] = ACTIONS(12602),
    [anon_sym_POUNDendif2] = ACTIONS(12602),
    [anon_sym_POUNDENDIF2] = ACTIONS(12602),
    [anon_sym_POUNDEndif2] = ACTIONS(12602),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12602),
    [sym_trigger_keyword] = ACTIONS(12602),
    [sym_var_keyword] = ACTIONS(12602),
    [sym_local_keyword] = ACTIONS(12602),
    [sym_internal_keyword] = ACTIONS(12602),
    [sym_protected_keyword] = ACTIONS(12602),
    [sym_event_keyword] = ACTIONS(12602),
    [sym_fields_keyword] = ACTIONS(12602),
    [sym_keys_keyword] = ACTIONS(12602),
    [sym_fieldgroups_keyword] = ACTIONS(12602),
    [sym_actions_keyword] = ACTIONS(12602),
    [sym_layout_keyword] = ACTIONS(12602),
    [sym_area_keyword] = ACTIONS(12602),
    [sym_group_keyword] = ACTIONS(12602),
    [sym_repeater_keyword] = ACTIONS(12602),
    [sym_cuegroup_keyword] = ACTIONS(12602),
    [sym_fixed_keyword] = ACTIONS(12602),
    [sym_grid_keyword] = ACTIONS(12602),
    [sym_part_keyword] = ACTIONS(12602),
    [sym_systempart_keyword] = ACTIONS(12602),
    [sym_usercontrol_keyword] = ACTIONS(12602),
    [sym_dataset_keyword] = ACTIONS(12602),
    [sym_elements_keyword] = ACTIONS(12602),
    [sym_dataitem_keyword] = ACTIONS(12602),
    [sym_column_keyword] = ACTIONS(12602),
    [sym_filter_keyword] = ACTIONS(12602),
    [sym_labels_keyword] = ACTIONS(12602),
    [sym_rendering_keyword] = ACTIONS(12602),
    [sym_requestpage_keyword] = ACTIONS(12602),
    [sym_schema_keyword] = ACTIONS(12602),
    [sym_views_keyword] = ACTIONS(12602),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12602),
    [sym_preproc_open] = ACTIONS(12602),
    [sym_preproc_close] = ACTIONS(12602),
  },
  [STATE(5107)] = {
    [anon_sym_SEMI] = ACTIONS(8446),
    [anon_sym_RBRACE] = ACTIONS(8446),
    [aux_sym_where_condition_token1] = ACTIONS(8448),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8446),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8448),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8446),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8446),
    [anon_sym_LBRACK] = ACTIONS(8446),
    [aux_sym_basic_type_token6] = ACTIONS(8448),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8446),
    [aux_sym_addafter_modification_token1] = ACTIONS(8446),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8446),
    [aux_sym_modify_modification_token1] = ACTIONS(8446),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8446),
    [aux_sym_movelast_modification_token1] = ACTIONS(8446),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8446),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8446),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8446),
    [anon_sym_POUNDif] = ACTIONS(8446),
    [anon_sym_POUNDIF] = ACTIONS(8446),
    [anon_sym_POUNDIf] = ACTIONS(8446),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8448),
    [sym_page_keyword] = ACTIONS(8446),
    [anon_sym_codeunit] = ACTIONS(8446),
    [anon_sym_CODEUNIT] = ACTIONS(8446),
    [anon_sym_Codeunit] = ACTIONS(8446),
    [anon_sym_CodeUnit] = ACTIONS(8446),
    [anon_sym_COdeunit] = ACTIONS(8446),
    [anon_sym_codeUnit] = ACTIONS(8446),
    [sym_report_keyword] = ACTIONS(8446),
    [sym_query_keyword] = ACTIONS(8446),
    [anon_sym_xmlport] = ACTIONS(8446),
    [anon_sym_XMLPORT] = ACTIONS(8446),
    [anon_sym_Xmlport] = ACTIONS(8446),
    [anon_sym_XMLport] = ACTIONS(8446),
    [anon_sym_XMLPort] = ACTIONS(8446),
    [anon_sym_XmlPort] = ACTIONS(8446),
    [sym_procedure_keyword] = ACTIONS(8446),
    [sym_trigger_keyword] = ACTIONS(8446),
    [sym_var_keyword] = ACTIONS(8446),
    [sym_local_keyword] = ACTIONS(8446),
    [sym_internal_keyword] = ACTIONS(8446),
    [sym_protected_keyword] = ACTIONS(8446),
    [sym_event_keyword] = ACTIONS(8446),
    [sym_fields_keyword] = ACTIONS(8446),
    [sym_keys_keyword] = ACTIONS(8446),
    [sym_fieldgroups_keyword] = ACTIONS(8446),
    [sym_actions_keyword] = ACTIONS(8446),
    [sym_layout_keyword] = ACTIONS(8446),
    [sym_area_keyword] = ACTIONS(8446),
    [sym_group_keyword] = ACTIONS(8446),
    [sym_repeater_keyword] = ACTIONS(8446),
    [sym_cuegroup_keyword] = ACTIONS(8446),
    [sym_fixed_keyword] = ACTIONS(8446),
    [sym_grid_keyword] = ACTIONS(8446),
    [sym_part_keyword] = ACTIONS(8446),
    [sym_systempart_keyword] = ACTIONS(8446),
    [sym_usercontrol_keyword] = ACTIONS(8446),
    [sym_dataset_keyword] = ACTIONS(8446),
    [sym_elements_keyword] = ACTIONS(8446),
    [sym_labels_keyword] = ACTIONS(8446),
    [sym_rendering_keyword] = ACTIONS(8446),
    [sym_requestpage_keyword] = ACTIONS(8446),
    [sym_schema_keyword] = ACTIONS(8446),
    [sym_views_keyword] = ACTIONS(8446),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8446),
    [sym_preproc_open] = ACTIONS(8446),
  },
  [STATE(5108)] = {
    [anon_sym_SEMI] = ACTIONS(12606),
    [aux_sym_where_condition_token1] = ACTIONS(12608),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12606),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12606),
    [anon_sym_LBRACK] = ACTIONS(12606),
    [aux_sym_basic_type_token6] = ACTIONS(12608),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12606),
    [aux_sym_addafter_modification_token1] = ACTIONS(12606),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12606),
    [aux_sym_modify_modification_token1] = ACTIONS(12606),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12606),
    [aux_sym_movelast_modification_token1] = ACTIONS(12606),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12606),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12606),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12606),
    [anon_sym_POUNDif] = ACTIONS(12606),
    [anon_sym_POUNDIF] = ACTIONS(12606),
    [anon_sym_POUNDIf] = ACTIONS(12606),
    [anon_sym_POUNDelif] = ACTIONS(12606),
    [anon_sym_POUNDELIF] = ACTIONS(12606),
    [anon_sym_POUNDElif] = ACTIONS(12606),
    [anon_sym_POUNDelse] = ACTIONS(12606),
    [anon_sym_POUNDELSE] = ACTIONS(12606),
    [anon_sym_POUNDElse] = ACTIONS(12606),
    [anon_sym_POUNDelse2] = ACTIONS(12606),
    [anon_sym_POUNDELSE2] = ACTIONS(12606),
    [anon_sym_POUNDElse2] = ACTIONS(12606),
    [anon_sym_POUNDendif] = ACTIONS(12606),
    [anon_sym_POUNDENDIF] = ACTIONS(12606),
    [anon_sym_POUNDEndif] = ACTIONS(12606),
    [anon_sym_POUNDendif2] = ACTIONS(12606),
    [anon_sym_POUNDENDIF2] = ACTIONS(12606),
    [anon_sym_POUNDEndif2] = ACTIONS(12606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12606),
    [sym_trigger_keyword] = ACTIONS(12606),
    [sym_var_keyword] = ACTIONS(12606),
    [sym_local_keyword] = ACTIONS(12606),
    [sym_internal_keyword] = ACTIONS(12606),
    [sym_protected_keyword] = ACTIONS(12606),
    [sym_event_keyword] = ACTIONS(12606),
    [sym_fields_keyword] = ACTIONS(12606),
    [sym_keys_keyword] = ACTIONS(12606),
    [sym_fieldgroups_keyword] = ACTIONS(12606),
    [sym_actions_keyword] = ACTIONS(12606),
    [sym_layout_keyword] = ACTIONS(12606),
    [sym_area_keyword] = ACTIONS(12606),
    [sym_group_keyword] = ACTIONS(12606),
    [sym_repeater_keyword] = ACTIONS(12606),
    [sym_cuegroup_keyword] = ACTIONS(12606),
    [sym_fixed_keyword] = ACTIONS(12606),
    [sym_grid_keyword] = ACTIONS(12606),
    [sym_part_keyword] = ACTIONS(12606),
    [sym_systempart_keyword] = ACTIONS(12606),
    [sym_usercontrol_keyword] = ACTIONS(12606),
    [sym_dataset_keyword] = ACTIONS(12606),
    [sym_elements_keyword] = ACTIONS(12606),
    [sym_dataitem_keyword] = ACTIONS(12606),
    [sym_column_keyword] = ACTIONS(12606),
    [sym_filter_keyword] = ACTIONS(12606),
    [sym_labels_keyword] = ACTIONS(12606),
    [sym_rendering_keyword] = ACTIONS(12606),
    [sym_requestpage_keyword] = ACTIONS(12606),
    [sym_schema_keyword] = ACTIONS(12606),
    [sym_views_keyword] = ACTIONS(12606),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12606),
    [sym_preproc_open] = ACTIONS(12606),
    [sym_preproc_close] = ACTIONS(12606),
  },
  [STATE(5109)] = {
    [anon_sym_SEMI] = ACTIONS(12606),
    [aux_sym_where_condition_token1] = ACTIONS(12608),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12606),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12606),
    [anon_sym_LBRACK] = ACTIONS(12606),
    [aux_sym_basic_type_token6] = ACTIONS(12608),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12606),
    [aux_sym_addafter_modification_token1] = ACTIONS(12606),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12606),
    [aux_sym_modify_modification_token1] = ACTIONS(12606),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12606),
    [aux_sym_movelast_modification_token1] = ACTIONS(12606),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12606),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12606),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12606),
    [anon_sym_POUNDif] = ACTIONS(12606),
    [anon_sym_POUNDIF] = ACTIONS(12606),
    [anon_sym_POUNDIf] = ACTIONS(12606),
    [anon_sym_POUNDelif] = ACTIONS(12606),
    [anon_sym_POUNDELIF] = ACTIONS(12606),
    [anon_sym_POUNDElif] = ACTIONS(12606),
    [anon_sym_POUNDelse] = ACTIONS(12606),
    [anon_sym_POUNDELSE] = ACTIONS(12606),
    [anon_sym_POUNDElse] = ACTIONS(12606),
    [anon_sym_POUNDelse2] = ACTIONS(12606),
    [anon_sym_POUNDELSE2] = ACTIONS(12606),
    [anon_sym_POUNDElse2] = ACTIONS(12606),
    [anon_sym_POUNDendif] = ACTIONS(12606),
    [anon_sym_POUNDENDIF] = ACTIONS(12606),
    [anon_sym_POUNDEndif] = ACTIONS(12606),
    [anon_sym_POUNDendif2] = ACTIONS(12606),
    [anon_sym_POUNDENDIF2] = ACTIONS(12606),
    [anon_sym_POUNDEndif2] = ACTIONS(12606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12606),
    [sym_trigger_keyword] = ACTIONS(12606),
    [sym_var_keyword] = ACTIONS(12606),
    [sym_local_keyword] = ACTIONS(12606),
    [sym_internal_keyword] = ACTIONS(12606),
    [sym_protected_keyword] = ACTIONS(12606),
    [sym_event_keyword] = ACTIONS(12606),
    [sym_fields_keyword] = ACTIONS(12606),
    [sym_keys_keyword] = ACTIONS(12606),
    [sym_fieldgroups_keyword] = ACTIONS(12606),
    [sym_actions_keyword] = ACTIONS(12606),
    [sym_layout_keyword] = ACTIONS(12606),
    [sym_area_keyword] = ACTIONS(12606),
    [sym_group_keyword] = ACTIONS(12606),
    [sym_repeater_keyword] = ACTIONS(12606),
    [sym_cuegroup_keyword] = ACTIONS(12606),
    [sym_fixed_keyword] = ACTIONS(12606),
    [sym_grid_keyword] = ACTIONS(12606),
    [sym_part_keyword] = ACTIONS(12606),
    [sym_systempart_keyword] = ACTIONS(12606),
    [sym_usercontrol_keyword] = ACTIONS(12606),
    [sym_dataset_keyword] = ACTIONS(12606),
    [sym_elements_keyword] = ACTIONS(12606),
    [sym_dataitem_keyword] = ACTIONS(12606),
    [sym_column_keyword] = ACTIONS(12606),
    [sym_filter_keyword] = ACTIONS(12606),
    [sym_labels_keyword] = ACTIONS(12606),
    [sym_rendering_keyword] = ACTIONS(12606),
    [sym_requestpage_keyword] = ACTIONS(12606),
    [sym_schema_keyword] = ACTIONS(12606),
    [sym_views_keyword] = ACTIONS(12606),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12606),
    [sym_preproc_open] = ACTIONS(12606),
    [sym_preproc_close] = ACTIONS(12606),
  },
  [STATE(5110)] = {
    [anon_sym_SEMI] = ACTIONS(12606),
    [aux_sym_where_condition_token1] = ACTIONS(12608),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12606),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12606),
    [anon_sym_LBRACK] = ACTIONS(12606),
    [aux_sym_basic_type_token6] = ACTIONS(12608),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12606),
    [aux_sym_addafter_modification_token1] = ACTIONS(12606),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12606),
    [aux_sym_modify_modification_token1] = ACTIONS(12606),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12606),
    [aux_sym_movelast_modification_token1] = ACTIONS(12606),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12606),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12606),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12606),
    [anon_sym_POUNDif] = ACTIONS(12606),
    [anon_sym_POUNDIF] = ACTIONS(12606),
    [anon_sym_POUNDIf] = ACTIONS(12606),
    [anon_sym_POUNDelif] = ACTIONS(12606),
    [anon_sym_POUNDELIF] = ACTIONS(12606),
    [anon_sym_POUNDElif] = ACTIONS(12606),
    [anon_sym_POUNDelse] = ACTIONS(12606),
    [anon_sym_POUNDELSE] = ACTIONS(12606),
    [anon_sym_POUNDElse] = ACTIONS(12606),
    [anon_sym_POUNDelse2] = ACTIONS(12606),
    [anon_sym_POUNDELSE2] = ACTIONS(12606),
    [anon_sym_POUNDElse2] = ACTIONS(12606),
    [anon_sym_POUNDendif] = ACTIONS(12606),
    [anon_sym_POUNDENDIF] = ACTIONS(12606),
    [anon_sym_POUNDEndif] = ACTIONS(12606),
    [anon_sym_POUNDendif2] = ACTIONS(12606),
    [anon_sym_POUNDENDIF2] = ACTIONS(12606),
    [anon_sym_POUNDEndif2] = ACTIONS(12606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12606),
    [sym_trigger_keyword] = ACTIONS(12606),
    [sym_var_keyword] = ACTIONS(12606),
    [sym_local_keyword] = ACTIONS(12606),
    [sym_internal_keyword] = ACTIONS(12606),
    [sym_protected_keyword] = ACTIONS(12606),
    [sym_event_keyword] = ACTIONS(12606),
    [sym_fields_keyword] = ACTIONS(12606),
    [sym_keys_keyword] = ACTIONS(12606),
    [sym_fieldgroups_keyword] = ACTIONS(12606),
    [sym_actions_keyword] = ACTIONS(12606),
    [sym_layout_keyword] = ACTIONS(12606),
    [sym_area_keyword] = ACTIONS(12606),
    [sym_group_keyword] = ACTIONS(12606),
    [sym_repeater_keyword] = ACTIONS(12606),
    [sym_cuegroup_keyword] = ACTIONS(12606),
    [sym_fixed_keyword] = ACTIONS(12606),
    [sym_grid_keyword] = ACTIONS(12606),
    [sym_part_keyword] = ACTIONS(12606),
    [sym_systempart_keyword] = ACTIONS(12606),
    [sym_usercontrol_keyword] = ACTIONS(12606),
    [sym_dataset_keyword] = ACTIONS(12606),
    [sym_elements_keyword] = ACTIONS(12606),
    [sym_dataitem_keyword] = ACTIONS(12606),
    [sym_column_keyword] = ACTIONS(12606),
    [sym_filter_keyword] = ACTIONS(12606),
    [sym_labels_keyword] = ACTIONS(12606),
    [sym_rendering_keyword] = ACTIONS(12606),
    [sym_requestpage_keyword] = ACTIONS(12606),
    [sym_schema_keyword] = ACTIONS(12606),
    [sym_views_keyword] = ACTIONS(12606),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12606),
    [sym_preproc_open] = ACTIONS(12606),
    [sym_preproc_close] = ACTIONS(12606),
  },
  [STATE(5111)] = {
    [anon_sym_SEMI] = ACTIONS(12606),
    [aux_sym_where_condition_token1] = ACTIONS(12608),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12606),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12606),
    [anon_sym_LBRACK] = ACTIONS(12606),
    [aux_sym_basic_type_token6] = ACTIONS(12608),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12606),
    [aux_sym_addafter_modification_token1] = ACTIONS(12606),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12606),
    [aux_sym_modify_modification_token1] = ACTIONS(12606),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12606),
    [aux_sym_movelast_modification_token1] = ACTIONS(12606),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12606),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12606),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12606),
    [anon_sym_POUNDif] = ACTIONS(12606),
    [anon_sym_POUNDIF] = ACTIONS(12606),
    [anon_sym_POUNDIf] = ACTIONS(12606),
    [anon_sym_POUNDelif] = ACTIONS(12606),
    [anon_sym_POUNDELIF] = ACTIONS(12606),
    [anon_sym_POUNDElif] = ACTIONS(12606),
    [anon_sym_POUNDelse] = ACTIONS(12606),
    [anon_sym_POUNDELSE] = ACTIONS(12606),
    [anon_sym_POUNDElse] = ACTIONS(12606),
    [anon_sym_POUNDelse2] = ACTIONS(12606),
    [anon_sym_POUNDELSE2] = ACTIONS(12606),
    [anon_sym_POUNDElse2] = ACTIONS(12606),
    [anon_sym_POUNDendif] = ACTIONS(12606),
    [anon_sym_POUNDENDIF] = ACTIONS(12606),
    [anon_sym_POUNDEndif] = ACTIONS(12606),
    [anon_sym_POUNDendif2] = ACTIONS(12606),
    [anon_sym_POUNDENDIF2] = ACTIONS(12606),
    [anon_sym_POUNDEndif2] = ACTIONS(12606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12606),
    [sym_trigger_keyword] = ACTIONS(12606),
    [sym_var_keyword] = ACTIONS(12606),
    [sym_local_keyword] = ACTIONS(12606),
    [sym_internal_keyword] = ACTIONS(12606),
    [sym_protected_keyword] = ACTIONS(12606),
    [sym_event_keyword] = ACTIONS(12606),
    [sym_fields_keyword] = ACTIONS(12606),
    [sym_keys_keyword] = ACTIONS(12606),
    [sym_fieldgroups_keyword] = ACTIONS(12606),
    [sym_actions_keyword] = ACTIONS(12606),
    [sym_layout_keyword] = ACTIONS(12606),
    [sym_area_keyword] = ACTIONS(12606),
    [sym_group_keyword] = ACTIONS(12606),
    [sym_repeater_keyword] = ACTIONS(12606),
    [sym_cuegroup_keyword] = ACTIONS(12606),
    [sym_fixed_keyword] = ACTIONS(12606),
    [sym_grid_keyword] = ACTIONS(12606),
    [sym_part_keyword] = ACTIONS(12606),
    [sym_systempart_keyword] = ACTIONS(12606),
    [sym_usercontrol_keyword] = ACTIONS(12606),
    [sym_dataset_keyword] = ACTIONS(12606),
    [sym_elements_keyword] = ACTIONS(12606),
    [sym_dataitem_keyword] = ACTIONS(12606),
    [sym_column_keyword] = ACTIONS(12606),
    [sym_filter_keyword] = ACTIONS(12606),
    [sym_labels_keyword] = ACTIONS(12606),
    [sym_rendering_keyword] = ACTIONS(12606),
    [sym_requestpage_keyword] = ACTIONS(12606),
    [sym_schema_keyword] = ACTIONS(12606),
    [sym_views_keyword] = ACTIONS(12606),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12606),
    [sym_preproc_open] = ACTIONS(12606),
    [sym_preproc_close] = ACTIONS(12606),
  },
  [STATE(5112)] = {
    [anon_sym_SEMI] = ACTIONS(12606),
    [aux_sym_where_condition_token1] = ACTIONS(12608),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12606),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12606),
    [anon_sym_LBRACK] = ACTIONS(12606),
    [aux_sym_basic_type_token6] = ACTIONS(12608),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12606),
    [aux_sym_addafter_modification_token1] = ACTIONS(12606),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12606),
    [aux_sym_modify_modification_token1] = ACTIONS(12606),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12606),
    [aux_sym_movelast_modification_token1] = ACTIONS(12606),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12606),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12606),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12606),
    [anon_sym_POUNDif] = ACTIONS(12606),
    [anon_sym_POUNDIF] = ACTIONS(12606),
    [anon_sym_POUNDIf] = ACTIONS(12606),
    [anon_sym_POUNDelif] = ACTIONS(12606),
    [anon_sym_POUNDELIF] = ACTIONS(12606),
    [anon_sym_POUNDElif] = ACTIONS(12606),
    [anon_sym_POUNDelse] = ACTIONS(12606),
    [anon_sym_POUNDELSE] = ACTIONS(12606),
    [anon_sym_POUNDElse] = ACTIONS(12606),
    [anon_sym_POUNDelse2] = ACTIONS(12606),
    [anon_sym_POUNDELSE2] = ACTIONS(12606),
    [anon_sym_POUNDElse2] = ACTIONS(12606),
    [anon_sym_POUNDendif] = ACTIONS(12606),
    [anon_sym_POUNDENDIF] = ACTIONS(12606),
    [anon_sym_POUNDEndif] = ACTIONS(12606),
    [anon_sym_POUNDendif2] = ACTIONS(12606),
    [anon_sym_POUNDENDIF2] = ACTIONS(12606),
    [anon_sym_POUNDEndif2] = ACTIONS(12606),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12606),
    [sym_trigger_keyword] = ACTIONS(12606),
    [sym_var_keyword] = ACTIONS(12606),
    [sym_local_keyword] = ACTIONS(12606),
    [sym_internal_keyword] = ACTIONS(12606),
    [sym_protected_keyword] = ACTIONS(12606),
    [sym_event_keyword] = ACTIONS(12606),
    [sym_fields_keyword] = ACTIONS(12606),
    [sym_keys_keyword] = ACTIONS(12606),
    [sym_fieldgroups_keyword] = ACTIONS(12606),
    [sym_actions_keyword] = ACTIONS(12606),
    [sym_layout_keyword] = ACTIONS(12606),
    [sym_area_keyword] = ACTIONS(12606),
    [sym_group_keyword] = ACTIONS(12606),
    [sym_repeater_keyword] = ACTIONS(12606),
    [sym_cuegroup_keyword] = ACTIONS(12606),
    [sym_fixed_keyword] = ACTIONS(12606),
    [sym_grid_keyword] = ACTIONS(12606),
    [sym_part_keyword] = ACTIONS(12606),
    [sym_systempart_keyword] = ACTIONS(12606),
    [sym_usercontrol_keyword] = ACTIONS(12606),
    [sym_dataset_keyword] = ACTIONS(12606),
    [sym_elements_keyword] = ACTIONS(12606),
    [sym_dataitem_keyword] = ACTIONS(12606),
    [sym_column_keyword] = ACTIONS(12606),
    [sym_filter_keyword] = ACTIONS(12606),
    [sym_labels_keyword] = ACTIONS(12606),
    [sym_rendering_keyword] = ACTIONS(12606),
    [sym_requestpage_keyword] = ACTIONS(12606),
    [sym_schema_keyword] = ACTIONS(12606),
    [sym_views_keyword] = ACTIONS(12606),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12606),
    [sym_preproc_open] = ACTIONS(12606),
    [sym_preproc_close] = ACTIONS(12606),
  },
  [STATE(5113)] = {
    [anon_sym_SEMI] = ACTIONS(12610),
    [aux_sym_where_condition_token1] = ACTIONS(12612),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12610),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12610),
    [anon_sym_LBRACK] = ACTIONS(12610),
    [aux_sym_basic_type_token6] = ACTIONS(12612),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12610),
    [aux_sym_addafter_modification_token1] = ACTIONS(12610),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12610),
    [aux_sym_modify_modification_token1] = ACTIONS(12610),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12610),
    [aux_sym_movelast_modification_token1] = ACTIONS(12610),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12610),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12610),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12610),
    [anon_sym_POUNDif] = ACTIONS(12610),
    [anon_sym_POUNDIF] = ACTIONS(12610),
    [anon_sym_POUNDIf] = ACTIONS(12610),
    [anon_sym_POUNDelif] = ACTIONS(12610),
    [anon_sym_POUNDELIF] = ACTIONS(12610),
    [anon_sym_POUNDElif] = ACTIONS(12610),
    [anon_sym_POUNDelse] = ACTIONS(12610),
    [anon_sym_POUNDELSE] = ACTIONS(12610),
    [anon_sym_POUNDElse] = ACTIONS(12610),
    [anon_sym_POUNDelse2] = ACTIONS(12610),
    [anon_sym_POUNDELSE2] = ACTIONS(12610),
    [anon_sym_POUNDElse2] = ACTIONS(12610),
    [anon_sym_POUNDendif] = ACTIONS(12610),
    [anon_sym_POUNDENDIF] = ACTIONS(12610),
    [anon_sym_POUNDEndif] = ACTIONS(12610),
    [anon_sym_POUNDendif2] = ACTIONS(12610),
    [anon_sym_POUNDENDIF2] = ACTIONS(12610),
    [anon_sym_POUNDEndif2] = ACTIONS(12610),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12610),
    [sym_trigger_keyword] = ACTIONS(12610),
    [sym_var_keyword] = ACTIONS(12610),
    [sym_local_keyword] = ACTIONS(12610),
    [sym_internal_keyword] = ACTIONS(12610),
    [sym_protected_keyword] = ACTIONS(12610),
    [sym_event_keyword] = ACTIONS(12610),
    [sym_fields_keyword] = ACTIONS(12610),
    [sym_keys_keyword] = ACTIONS(12610),
    [sym_fieldgroups_keyword] = ACTIONS(12610),
    [sym_actions_keyword] = ACTIONS(12610),
    [sym_layout_keyword] = ACTIONS(12610),
    [sym_area_keyword] = ACTIONS(12610),
    [sym_group_keyword] = ACTIONS(12610),
    [sym_repeater_keyword] = ACTIONS(12610),
    [sym_cuegroup_keyword] = ACTIONS(12610),
    [sym_fixed_keyword] = ACTIONS(12610),
    [sym_grid_keyword] = ACTIONS(12610),
    [sym_part_keyword] = ACTIONS(12610),
    [sym_systempart_keyword] = ACTIONS(12610),
    [sym_usercontrol_keyword] = ACTIONS(12610),
    [sym_dataset_keyword] = ACTIONS(12610),
    [sym_elements_keyword] = ACTIONS(12610),
    [sym_dataitem_keyword] = ACTIONS(12610),
    [sym_column_keyword] = ACTIONS(12610),
    [sym_filter_keyword] = ACTIONS(12610),
    [sym_labels_keyword] = ACTIONS(12610),
    [sym_rendering_keyword] = ACTIONS(12610),
    [sym_requestpage_keyword] = ACTIONS(12610),
    [sym_schema_keyword] = ACTIONS(12610),
    [sym_views_keyword] = ACTIONS(12610),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12610),
    [sym_preproc_open] = ACTIONS(12610),
    [sym_preproc_close] = ACTIONS(12610),
  },
  [STATE(5114)] = {
    [anon_sym_SEMI] = ACTIONS(12610),
    [aux_sym_where_condition_token1] = ACTIONS(12612),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12610),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12610),
    [anon_sym_LBRACK] = ACTIONS(12610),
    [aux_sym_basic_type_token6] = ACTIONS(12612),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12610),
    [aux_sym_addafter_modification_token1] = ACTIONS(12610),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12610),
    [aux_sym_modify_modification_token1] = ACTIONS(12610),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12610),
    [aux_sym_movelast_modification_token1] = ACTIONS(12610),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12610),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12610),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12610),
    [anon_sym_POUNDif] = ACTIONS(12610),
    [anon_sym_POUNDIF] = ACTIONS(12610),
    [anon_sym_POUNDIf] = ACTIONS(12610),
    [anon_sym_POUNDelif] = ACTIONS(12610),
    [anon_sym_POUNDELIF] = ACTIONS(12610),
    [anon_sym_POUNDElif] = ACTIONS(12610),
    [anon_sym_POUNDelse] = ACTIONS(12610),
    [anon_sym_POUNDELSE] = ACTIONS(12610),
    [anon_sym_POUNDElse] = ACTIONS(12610),
    [anon_sym_POUNDelse2] = ACTIONS(12610),
    [anon_sym_POUNDELSE2] = ACTIONS(12610),
    [anon_sym_POUNDElse2] = ACTIONS(12610),
    [anon_sym_POUNDendif] = ACTIONS(12610),
    [anon_sym_POUNDENDIF] = ACTIONS(12610),
    [anon_sym_POUNDEndif] = ACTIONS(12610),
    [anon_sym_POUNDendif2] = ACTIONS(12610),
    [anon_sym_POUNDENDIF2] = ACTIONS(12610),
    [anon_sym_POUNDEndif2] = ACTIONS(12610),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12610),
    [sym_trigger_keyword] = ACTIONS(12610),
    [sym_var_keyword] = ACTIONS(12610),
    [sym_local_keyword] = ACTIONS(12610),
    [sym_internal_keyword] = ACTIONS(12610),
    [sym_protected_keyword] = ACTIONS(12610),
    [sym_event_keyword] = ACTIONS(12610),
    [sym_fields_keyword] = ACTIONS(12610),
    [sym_keys_keyword] = ACTIONS(12610),
    [sym_fieldgroups_keyword] = ACTIONS(12610),
    [sym_actions_keyword] = ACTIONS(12610),
    [sym_layout_keyword] = ACTIONS(12610),
    [sym_area_keyword] = ACTIONS(12610),
    [sym_group_keyword] = ACTIONS(12610),
    [sym_repeater_keyword] = ACTIONS(12610),
    [sym_cuegroup_keyword] = ACTIONS(12610),
    [sym_fixed_keyword] = ACTIONS(12610),
    [sym_grid_keyword] = ACTIONS(12610),
    [sym_part_keyword] = ACTIONS(12610),
    [sym_systempart_keyword] = ACTIONS(12610),
    [sym_usercontrol_keyword] = ACTIONS(12610),
    [sym_dataset_keyword] = ACTIONS(12610),
    [sym_elements_keyword] = ACTIONS(12610),
    [sym_dataitem_keyword] = ACTIONS(12610),
    [sym_column_keyword] = ACTIONS(12610),
    [sym_filter_keyword] = ACTIONS(12610),
    [sym_labels_keyword] = ACTIONS(12610),
    [sym_rendering_keyword] = ACTIONS(12610),
    [sym_requestpage_keyword] = ACTIONS(12610),
    [sym_schema_keyword] = ACTIONS(12610),
    [sym_views_keyword] = ACTIONS(12610),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12610),
    [sym_preproc_open] = ACTIONS(12610),
    [sym_preproc_close] = ACTIONS(12610),
  },
  [STATE(5115)] = {
    [anon_sym_SEMI] = ACTIONS(12614),
    [aux_sym_where_condition_token1] = ACTIONS(12616),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12614),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12614),
    [anon_sym_LBRACK] = ACTIONS(12614),
    [aux_sym_basic_type_token6] = ACTIONS(12616),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12614),
    [aux_sym_addafter_modification_token1] = ACTIONS(12614),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12614),
    [aux_sym_modify_modification_token1] = ACTIONS(12614),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12614),
    [aux_sym_movelast_modification_token1] = ACTIONS(12614),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12614),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12614),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12614),
    [anon_sym_POUNDif] = ACTIONS(12614),
    [anon_sym_POUNDIF] = ACTIONS(12614),
    [anon_sym_POUNDIf] = ACTIONS(12614),
    [anon_sym_POUNDelif] = ACTIONS(12614),
    [anon_sym_POUNDELIF] = ACTIONS(12614),
    [anon_sym_POUNDElif] = ACTIONS(12614),
    [anon_sym_POUNDelse] = ACTIONS(12614),
    [anon_sym_POUNDELSE] = ACTIONS(12614),
    [anon_sym_POUNDElse] = ACTIONS(12614),
    [anon_sym_POUNDelse2] = ACTIONS(12614),
    [anon_sym_POUNDELSE2] = ACTIONS(12614),
    [anon_sym_POUNDElse2] = ACTIONS(12614),
    [anon_sym_POUNDendif] = ACTIONS(12614),
    [anon_sym_POUNDENDIF] = ACTIONS(12614),
    [anon_sym_POUNDEndif] = ACTIONS(12614),
    [anon_sym_POUNDendif2] = ACTIONS(12614),
    [anon_sym_POUNDENDIF2] = ACTIONS(12614),
    [anon_sym_POUNDEndif2] = ACTIONS(12614),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12614),
    [sym_trigger_keyword] = ACTIONS(12614),
    [sym_var_keyword] = ACTIONS(12614),
    [sym_local_keyword] = ACTIONS(12614),
    [sym_internal_keyword] = ACTIONS(12614),
    [sym_protected_keyword] = ACTIONS(12614),
    [sym_event_keyword] = ACTIONS(12614),
    [sym_fields_keyword] = ACTIONS(12614),
    [sym_keys_keyword] = ACTIONS(12614),
    [sym_fieldgroups_keyword] = ACTIONS(12614),
    [sym_actions_keyword] = ACTIONS(12614),
    [sym_layout_keyword] = ACTIONS(12614),
    [sym_area_keyword] = ACTIONS(12614),
    [sym_group_keyword] = ACTIONS(12614),
    [sym_repeater_keyword] = ACTIONS(12614),
    [sym_cuegroup_keyword] = ACTIONS(12614),
    [sym_fixed_keyword] = ACTIONS(12614),
    [sym_grid_keyword] = ACTIONS(12614),
    [sym_part_keyword] = ACTIONS(12614),
    [sym_systempart_keyword] = ACTIONS(12614),
    [sym_usercontrol_keyword] = ACTIONS(12614),
    [sym_dataset_keyword] = ACTIONS(12614),
    [sym_elements_keyword] = ACTIONS(12614),
    [sym_dataitem_keyword] = ACTIONS(12614),
    [sym_column_keyword] = ACTIONS(12614),
    [sym_filter_keyword] = ACTIONS(12614),
    [sym_labels_keyword] = ACTIONS(12614),
    [sym_rendering_keyword] = ACTIONS(12614),
    [sym_requestpage_keyword] = ACTIONS(12614),
    [sym_schema_keyword] = ACTIONS(12614),
    [sym_views_keyword] = ACTIONS(12614),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12614),
    [sym_preproc_open] = ACTIONS(12614),
    [sym_preproc_close] = ACTIONS(12614),
  },
  [STATE(5116)] = {
    [anon_sym_SEMI] = ACTIONS(12618),
    [aux_sym_where_condition_token1] = ACTIONS(12620),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12618),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12618),
    [anon_sym_LBRACK] = ACTIONS(12618),
    [aux_sym_basic_type_token6] = ACTIONS(12620),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12618),
    [aux_sym_addafter_modification_token1] = ACTIONS(12618),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12618),
    [aux_sym_modify_modification_token1] = ACTIONS(12618),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12618),
    [aux_sym_movelast_modification_token1] = ACTIONS(12618),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12618),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12618),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12618),
    [anon_sym_POUNDif] = ACTIONS(12618),
    [anon_sym_POUNDIF] = ACTIONS(12618),
    [anon_sym_POUNDIf] = ACTIONS(12618),
    [anon_sym_POUNDelif] = ACTIONS(12618),
    [anon_sym_POUNDELIF] = ACTIONS(12618),
    [anon_sym_POUNDElif] = ACTIONS(12618),
    [anon_sym_POUNDelse] = ACTIONS(12618),
    [anon_sym_POUNDELSE] = ACTIONS(12618),
    [anon_sym_POUNDElse] = ACTIONS(12618),
    [anon_sym_POUNDelse2] = ACTIONS(12618),
    [anon_sym_POUNDELSE2] = ACTIONS(12618),
    [anon_sym_POUNDElse2] = ACTIONS(12618),
    [anon_sym_POUNDendif] = ACTIONS(12618),
    [anon_sym_POUNDENDIF] = ACTIONS(12618),
    [anon_sym_POUNDEndif] = ACTIONS(12618),
    [anon_sym_POUNDendif2] = ACTIONS(12618),
    [anon_sym_POUNDENDIF2] = ACTIONS(12618),
    [anon_sym_POUNDEndif2] = ACTIONS(12618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12618),
    [sym_trigger_keyword] = ACTIONS(12618),
    [sym_var_keyword] = ACTIONS(12618),
    [sym_local_keyword] = ACTIONS(12618),
    [sym_internal_keyword] = ACTIONS(12618),
    [sym_protected_keyword] = ACTIONS(12618),
    [sym_event_keyword] = ACTIONS(12618),
    [sym_fields_keyword] = ACTIONS(12618),
    [sym_keys_keyword] = ACTIONS(12618),
    [sym_fieldgroups_keyword] = ACTIONS(12618),
    [sym_actions_keyword] = ACTIONS(12618),
    [sym_layout_keyword] = ACTIONS(12618),
    [sym_area_keyword] = ACTIONS(12618),
    [sym_group_keyword] = ACTIONS(12618),
    [sym_repeater_keyword] = ACTIONS(12618),
    [sym_cuegroup_keyword] = ACTIONS(12618),
    [sym_fixed_keyword] = ACTIONS(12618),
    [sym_grid_keyword] = ACTIONS(12618),
    [sym_part_keyword] = ACTIONS(12618),
    [sym_systempart_keyword] = ACTIONS(12618),
    [sym_usercontrol_keyword] = ACTIONS(12618),
    [sym_dataset_keyword] = ACTIONS(12618),
    [sym_elements_keyword] = ACTIONS(12618),
    [sym_dataitem_keyword] = ACTIONS(12618),
    [sym_column_keyword] = ACTIONS(12618),
    [sym_filter_keyword] = ACTIONS(12618),
    [sym_labels_keyword] = ACTIONS(12618),
    [sym_rendering_keyword] = ACTIONS(12618),
    [sym_requestpage_keyword] = ACTIONS(12618),
    [sym_schema_keyword] = ACTIONS(12618),
    [sym_views_keyword] = ACTIONS(12618),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12618),
    [sym_preproc_open] = ACTIONS(12618),
    [sym_preproc_close] = ACTIONS(12618),
  },
  [STATE(5117)] = {
    [anon_sym_SEMI] = ACTIONS(12622),
    [aux_sym_where_condition_token1] = ACTIONS(12624),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12622),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12622),
    [anon_sym_LBRACK] = ACTIONS(12622),
    [aux_sym_basic_type_token6] = ACTIONS(12624),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12622),
    [aux_sym_addafter_modification_token1] = ACTIONS(12622),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12622),
    [aux_sym_modify_modification_token1] = ACTIONS(12622),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12622),
    [aux_sym_movelast_modification_token1] = ACTIONS(12622),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12622),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12622),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12622),
    [anon_sym_POUNDif] = ACTIONS(12622),
    [anon_sym_POUNDIF] = ACTIONS(12622),
    [anon_sym_POUNDIf] = ACTIONS(12622),
    [anon_sym_POUNDelif] = ACTIONS(12622),
    [anon_sym_POUNDELIF] = ACTIONS(12622),
    [anon_sym_POUNDElif] = ACTIONS(12622),
    [anon_sym_POUNDelse] = ACTIONS(12622),
    [anon_sym_POUNDELSE] = ACTIONS(12622),
    [anon_sym_POUNDElse] = ACTIONS(12622),
    [anon_sym_POUNDelse2] = ACTIONS(12622),
    [anon_sym_POUNDELSE2] = ACTIONS(12622),
    [anon_sym_POUNDElse2] = ACTIONS(12622),
    [anon_sym_POUNDendif] = ACTIONS(12622),
    [anon_sym_POUNDENDIF] = ACTIONS(12622),
    [anon_sym_POUNDEndif] = ACTIONS(12622),
    [anon_sym_POUNDendif2] = ACTIONS(12622),
    [anon_sym_POUNDENDIF2] = ACTIONS(12622),
    [anon_sym_POUNDEndif2] = ACTIONS(12622),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12622),
    [sym_trigger_keyword] = ACTIONS(12622),
    [sym_var_keyword] = ACTIONS(12622),
    [sym_local_keyword] = ACTIONS(12622),
    [sym_internal_keyword] = ACTIONS(12622),
    [sym_protected_keyword] = ACTIONS(12622),
    [sym_event_keyword] = ACTIONS(12622),
    [sym_fields_keyword] = ACTIONS(12622),
    [sym_keys_keyword] = ACTIONS(12622),
    [sym_fieldgroups_keyword] = ACTIONS(12622),
    [sym_actions_keyword] = ACTIONS(12622),
    [sym_layout_keyword] = ACTIONS(12622),
    [sym_area_keyword] = ACTIONS(12622),
    [sym_group_keyword] = ACTIONS(12622),
    [sym_repeater_keyword] = ACTIONS(12622),
    [sym_cuegroup_keyword] = ACTIONS(12622),
    [sym_fixed_keyword] = ACTIONS(12622),
    [sym_grid_keyword] = ACTIONS(12622),
    [sym_part_keyword] = ACTIONS(12622),
    [sym_systempart_keyword] = ACTIONS(12622),
    [sym_usercontrol_keyword] = ACTIONS(12622),
    [sym_dataset_keyword] = ACTIONS(12622),
    [sym_elements_keyword] = ACTIONS(12622),
    [sym_dataitem_keyword] = ACTIONS(12622),
    [sym_column_keyword] = ACTIONS(12622),
    [sym_filter_keyword] = ACTIONS(12622),
    [sym_labels_keyword] = ACTIONS(12622),
    [sym_rendering_keyword] = ACTIONS(12622),
    [sym_requestpage_keyword] = ACTIONS(12622),
    [sym_schema_keyword] = ACTIONS(12622),
    [sym_views_keyword] = ACTIONS(12622),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12622),
    [sym_preproc_open] = ACTIONS(12622),
    [sym_preproc_close] = ACTIONS(12622),
  },
  [STATE(5118)] = {
    [anon_sym_SEMI] = ACTIONS(12622),
    [aux_sym_where_condition_token1] = ACTIONS(12624),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12622),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12622),
    [anon_sym_LBRACK] = ACTIONS(12622),
    [aux_sym_basic_type_token6] = ACTIONS(12624),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12622),
    [aux_sym_addafter_modification_token1] = ACTIONS(12622),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12622),
    [aux_sym_modify_modification_token1] = ACTIONS(12622),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12622),
    [aux_sym_movelast_modification_token1] = ACTIONS(12622),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12622),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12622),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12622),
    [anon_sym_POUNDif] = ACTIONS(12622),
    [anon_sym_POUNDIF] = ACTIONS(12622),
    [anon_sym_POUNDIf] = ACTIONS(12622),
    [anon_sym_POUNDelif] = ACTIONS(12622),
    [anon_sym_POUNDELIF] = ACTIONS(12622),
    [anon_sym_POUNDElif] = ACTIONS(12622),
    [anon_sym_POUNDelse] = ACTIONS(12622),
    [anon_sym_POUNDELSE] = ACTIONS(12622),
    [anon_sym_POUNDElse] = ACTIONS(12622),
    [anon_sym_POUNDelse2] = ACTIONS(12622),
    [anon_sym_POUNDELSE2] = ACTIONS(12622),
    [anon_sym_POUNDElse2] = ACTIONS(12622),
    [anon_sym_POUNDendif] = ACTIONS(12622),
    [anon_sym_POUNDENDIF] = ACTIONS(12622),
    [anon_sym_POUNDEndif] = ACTIONS(12622),
    [anon_sym_POUNDendif2] = ACTIONS(12622),
    [anon_sym_POUNDENDIF2] = ACTIONS(12622),
    [anon_sym_POUNDEndif2] = ACTIONS(12622),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12622),
    [sym_trigger_keyword] = ACTIONS(12622),
    [sym_var_keyword] = ACTIONS(12622),
    [sym_local_keyword] = ACTIONS(12622),
    [sym_internal_keyword] = ACTIONS(12622),
    [sym_protected_keyword] = ACTIONS(12622),
    [sym_event_keyword] = ACTIONS(12622),
    [sym_fields_keyword] = ACTIONS(12622),
    [sym_keys_keyword] = ACTIONS(12622),
    [sym_fieldgroups_keyword] = ACTIONS(12622),
    [sym_actions_keyword] = ACTIONS(12622),
    [sym_layout_keyword] = ACTIONS(12622),
    [sym_area_keyword] = ACTIONS(12622),
    [sym_group_keyword] = ACTIONS(12622),
    [sym_repeater_keyword] = ACTIONS(12622),
    [sym_cuegroup_keyword] = ACTIONS(12622),
    [sym_fixed_keyword] = ACTIONS(12622),
    [sym_grid_keyword] = ACTIONS(12622),
    [sym_part_keyword] = ACTIONS(12622),
    [sym_systempart_keyword] = ACTIONS(12622),
    [sym_usercontrol_keyword] = ACTIONS(12622),
    [sym_dataset_keyword] = ACTIONS(12622),
    [sym_elements_keyword] = ACTIONS(12622),
    [sym_dataitem_keyword] = ACTIONS(12622),
    [sym_column_keyword] = ACTIONS(12622),
    [sym_filter_keyword] = ACTIONS(12622),
    [sym_labels_keyword] = ACTIONS(12622),
    [sym_rendering_keyword] = ACTIONS(12622),
    [sym_requestpage_keyword] = ACTIONS(12622),
    [sym_schema_keyword] = ACTIONS(12622),
    [sym_views_keyword] = ACTIONS(12622),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12622),
    [sym_preproc_open] = ACTIONS(12622),
    [sym_preproc_close] = ACTIONS(12622),
  },
  [STATE(5119)] = {
    [anon_sym_SEMI] = ACTIONS(12626),
    [aux_sym_where_condition_token1] = ACTIONS(12628),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12626),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12626),
    [anon_sym_LBRACK] = ACTIONS(12626),
    [aux_sym_basic_type_token6] = ACTIONS(12628),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12626),
    [aux_sym_addafter_modification_token1] = ACTIONS(12626),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12626),
    [aux_sym_modify_modification_token1] = ACTIONS(12626),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12626),
    [aux_sym_movelast_modification_token1] = ACTIONS(12626),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12626),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12626),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12626),
    [anon_sym_POUNDif] = ACTIONS(12626),
    [anon_sym_POUNDIF] = ACTIONS(12626),
    [anon_sym_POUNDIf] = ACTIONS(12626),
    [anon_sym_POUNDelif] = ACTIONS(12626),
    [anon_sym_POUNDELIF] = ACTIONS(12626),
    [anon_sym_POUNDElif] = ACTIONS(12626),
    [anon_sym_POUNDelse] = ACTIONS(12626),
    [anon_sym_POUNDELSE] = ACTIONS(12626),
    [anon_sym_POUNDElse] = ACTIONS(12626),
    [anon_sym_POUNDelse2] = ACTIONS(12626),
    [anon_sym_POUNDELSE2] = ACTIONS(12626),
    [anon_sym_POUNDElse2] = ACTIONS(12626),
    [anon_sym_POUNDendif] = ACTIONS(12626),
    [anon_sym_POUNDENDIF] = ACTIONS(12626),
    [anon_sym_POUNDEndif] = ACTIONS(12626),
    [anon_sym_POUNDendif2] = ACTIONS(12626),
    [anon_sym_POUNDENDIF2] = ACTIONS(12626),
    [anon_sym_POUNDEndif2] = ACTIONS(12626),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12626),
    [sym_trigger_keyword] = ACTIONS(12626),
    [sym_var_keyword] = ACTIONS(12626),
    [sym_local_keyword] = ACTIONS(12626),
    [sym_internal_keyword] = ACTIONS(12626),
    [sym_protected_keyword] = ACTIONS(12626),
    [sym_event_keyword] = ACTIONS(12626),
    [sym_fields_keyword] = ACTIONS(12626),
    [sym_keys_keyword] = ACTIONS(12626),
    [sym_fieldgroups_keyword] = ACTIONS(12626),
    [sym_actions_keyword] = ACTIONS(12626),
    [sym_layout_keyword] = ACTIONS(12626),
    [sym_area_keyword] = ACTIONS(12626),
    [sym_group_keyword] = ACTIONS(12626),
    [sym_repeater_keyword] = ACTIONS(12626),
    [sym_cuegroup_keyword] = ACTIONS(12626),
    [sym_fixed_keyword] = ACTIONS(12626),
    [sym_grid_keyword] = ACTIONS(12626),
    [sym_part_keyword] = ACTIONS(12626),
    [sym_systempart_keyword] = ACTIONS(12626),
    [sym_usercontrol_keyword] = ACTIONS(12626),
    [sym_dataset_keyword] = ACTIONS(12626),
    [sym_elements_keyword] = ACTIONS(12626),
    [sym_dataitem_keyword] = ACTIONS(12626),
    [sym_column_keyword] = ACTIONS(12626),
    [sym_filter_keyword] = ACTIONS(12626),
    [sym_labels_keyword] = ACTIONS(12626),
    [sym_rendering_keyword] = ACTIONS(12626),
    [sym_requestpage_keyword] = ACTIONS(12626),
    [sym_schema_keyword] = ACTIONS(12626),
    [sym_views_keyword] = ACTIONS(12626),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12626),
    [sym_preproc_open] = ACTIONS(12626),
    [sym_preproc_close] = ACTIONS(12626),
  },
  [STATE(5120)] = {
    [anon_sym_SEMI] = ACTIONS(12626),
    [aux_sym_where_condition_token1] = ACTIONS(12628),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12626),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12626),
    [anon_sym_LBRACK] = ACTIONS(12626),
    [aux_sym_basic_type_token6] = ACTIONS(12628),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12626),
    [aux_sym_addafter_modification_token1] = ACTIONS(12626),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12626),
    [aux_sym_modify_modification_token1] = ACTIONS(12626),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12626),
    [aux_sym_movelast_modification_token1] = ACTIONS(12626),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12626),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12626),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12626),
    [anon_sym_POUNDif] = ACTIONS(12626),
    [anon_sym_POUNDIF] = ACTIONS(12626),
    [anon_sym_POUNDIf] = ACTIONS(12626),
    [anon_sym_POUNDelif] = ACTIONS(12626),
    [anon_sym_POUNDELIF] = ACTIONS(12626),
    [anon_sym_POUNDElif] = ACTIONS(12626),
    [anon_sym_POUNDelse] = ACTIONS(12626),
    [anon_sym_POUNDELSE] = ACTIONS(12626),
    [anon_sym_POUNDElse] = ACTIONS(12626),
    [anon_sym_POUNDelse2] = ACTIONS(12626),
    [anon_sym_POUNDELSE2] = ACTIONS(12626),
    [anon_sym_POUNDElse2] = ACTIONS(12626),
    [anon_sym_POUNDendif] = ACTIONS(12626),
    [anon_sym_POUNDENDIF] = ACTIONS(12626),
    [anon_sym_POUNDEndif] = ACTIONS(12626),
    [anon_sym_POUNDendif2] = ACTIONS(12626),
    [anon_sym_POUNDENDIF2] = ACTIONS(12626),
    [anon_sym_POUNDEndif2] = ACTIONS(12626),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12626),
    [sym_trigger_keyword] = ACTIONS(12626),
    [sym_var_keyword] = ACTIONS(12626),
    [sym_local_keyword] = ACTIONS(12626),
    [sym_internal_keyword] = ACTIONS(12626),
    [sym_protected_keyword] = ACTIONS(12626),
    [sym_event_keyword] = ACTIONS(12626),
    [sym_fields_keyword] = ACTIONS(12626),
    [sym_keys_keyword] = ACTIONS(12626),
    [sym_fieldgroups_keyword] = ACTIONS(12626),
    [sym_actions_keyword] = ACTIONS(12626),
    [sym_layout_keyword] = ACTIONS(12626),
    [sym_area_keyword] = ACTIONS(12626),
    [sym_group_keyword] = ACTIONS(12626),
    [sym_repeater_keyword] = ACTIONS(12626),
    [sym_cuegroup_keyword] = ACTIONS(12626),
    [sym_fixed_keyword] = ACTIONS(12626),
    [sym_grid_keyword] = ACTIONS(12626),
    [sym_part_keyword] = ACTIONS(12626),
    [sym_systempart_keyword] = ACTIONS(12626),
    [sym_usercontrol_keyword] = ACTIONS(12626),
    [sym_dataset_keyword] = ACTIONS(12626),
    [sym_elements_keyword] = ACTIONS(12626),
    [sym_dataitem_keyword] = ACTIONS(12626),
    [sym_column_keyword] = ACTIONS(12626),
    [sym_filter_keyword] = ACTIONS(12626),
    [sym_labels_keyword] = ACTIONS(12626),
    [sym_rendering_keyword] = ACTIONS(12626),
    [sym_requestpage_keyword] = ACTIONS(12626),
    [sym_schema_keyword] = ACTIONS(12626),
    [sym_views_keyword] = ACTIONS(12626),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12626),
    [sym_preproc_open] = ACTIONS(12626),
    [sym_preproc_close] = ACTIONS(12626),
  },
  [STATE(5121)] = {
    [anon_sym_SEMI] = ACTIONS(12630),
    [aux_sym_where_condition_token1] = ACTIONS(12632),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12630),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12630),
    [anon_sym_LBRACK] = ACTIONS(12630),
    [aux_sym_basic_type_token6] = ACTIONS(12632),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12630),
    [aux_sym_addafter_modification_token1] = ACTIONS(12630),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12630),
    [aux_sym_modify_modification_token1] = ACTIONS(12630),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12630),
    [aux_sym_movelast_modification_token1] = ACTIONS(12630),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12630),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12630),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12630),
    [anon_sym_POUNDif] = ACTIONS(12630),
    [anon_sym_POUNDIF] = ACTIONS(12630),
    [anon_sym_POUNDIf] = ACTIONS(12630),
    [anon_sym_POUNDelif] = ACTIONS(12630),
    [anon_sym_POUNDELIF] = ACTIONS(12630),
    [anon_sym_POUNDElif] = ACTIONS(12630),
    [anon_sym_POUNDelse] = ACTIONS(12630),
    [anon_sym_POUNDELSE] = ACTIONS(12630),
    [anon_sym_POUNDElse] = ACTIONS(12630),
    [anon_sym_POUNDelse2] = ACTIONS(12630),
    [anon_sym_POUNDELSE2] = ACTIONS(12630),
    [anon_sym_POUNDElse2] = ACTIONS(12630),
    [anon_sym_POUNDendif] = ACTIONS(12630),
    [anon_sym_POUNDENDIF] = ACTIONS(12630),
    [anon_sym_POUNDEndif] = ACTIONS(12630),
    [anon_sym_POUNDendif2] = ACTIONS(12630),
    [anon_sym_POUNDENDIF2] = ACTIONS(12630),
    [anon_sym_POUNDEndif2] = ACTIONS(12630),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12630),
    [sym_trigger_keyword] = ACTIONS(12630),
    [sym_var_keyword] = ACTIONS(12630),
    [sym_local_keyword] = ACTIONS(12630),
    [sym_internal_keyword] = ACTIONS(12630),
    [sym_protected_keyword] = ACTIONS(12630),
    [sym_event_keyword] = ACTIONS(12630),
    [sym_fields_keyword] = ACTIONS(12630),
    [sym_keys_keyword] = ACTIONS(12630),
    [sym_fieldgroups_keyword] = ACTIONS(12630),
    [sym_actions_keyword] = ACTIONS(12630),
    [sym_layout_keyword] = ACTIONS(12630),
    [sym_area_keyword] = ACTIONS(12630),
    [sym_group_keyword] = ACTIONS(12630),
    [sym_repeater_keyword] = ACTIONS(12630),
    [sym_cuegroup_keyword] = ACTIONS(12630),
    [sym_fixed_keyword] = ACTIONS(12630),
    [sym_grid_keyword] = ACTIONS(12630),
    [sym_part_keyword] = ACTIONS(12630),
    [sym_systempart_keyword] = ACTIONS(12630),
    [sym_usercontrol_keyword] = ACTIONS(12630),
    [sym_dataset_keyword] = ACTIONS(12630),
    [sym_elements_keyword] = ACTIONS(12630),
    [sym_dataitem_keyword] = ACTIONS(12630),
    [sym_column_keyword] = ACTIONS(12630),
    [sym_filter_keyword] = ACTIONS(12630),
    [sym_labels_keyword] = ACTIONS(12630),
    [sym_rendering_keyword] = ACTIONS(12630),
    [sym_requestpage_keyword] = ACTIONS(12630),
    [sym_schema_keyword] = ACTIONS(12630),
    [sym_views_keyword] = ACTIONS(12630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12630),
    [sym_preproc_open] = ACTIONS(12630),
    [sym_preproc_close] = ACTIONS(12630),
  },
  [STATE(5122)] = {
    [anon_sym_SEMI] = ACTIONS(12630),
    [aux_sym_where_condition_token1] = ACTIONS(12632),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12630),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12630),
    [anon_sym_LBRACK] = ACTIONS(12630),
    [aux_sym_basic_type_token6] = ACTIONS(12632),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12630),
    [aux_sym_addafter_modification_token1] = ACTIONS(12630),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12630),
    [aux_sym_modify_modification_token1] = ACTIONS(12630),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12630),
    [aux_sym_movelast_modification_token1] = ACTIONS(12630),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12630),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12630),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12630),
    [anon_sym_POUNDif] = ACTIONS(12630),
    [anon_sym_POUNDIF] = ACTIONS(12630),
    [anon_sym_POUNDIf] = ACTIONS(12630),
    [anon_sym_POUNDelif] = ACTIONS(12630),
    [anon_sym_POUNDELIF] = ACTIONS(12630),
    [anon_sym_POUNDElif] = ACTIONS(12630),
    [anon_sym_POUNDelse] = ACTIONS(12630),
    [anon_sym_POUNDELSE] = ACTIONS(12630),
    [anon_sym_POUNDElse] = ACTIONS(12630),
    [anon_sym_POUNDelse2] = ACTIONS(12630),
    [anon_sym_POUNDELSE2] = ACTIONS(12630),
    [anon_sym_POUNDElse2] = ACTIONS(12630),
    [anon_sym_POUNDendif] = ACTIONS(12630),
    [anon_sym_POUNDENDIF] = ACTIONS(12630),
    [anon_sym_POUNDEndif] = ACTIONS(12630),
    [anon_sym_POUNDendif2] = ACTIONS(12630),
    [anon_sym_POUNDENDIF2] = ACTIONS(12630),
    [anon_sym_POUNDEndif2] = ACTIONS(12630),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12630),
    [sym_trigger_keyword] = ACTIONS(12630),
    [sym_var_keyword] = ACTIONS(12630),
    [sym_local_keyword] = ACTIONS(12630),
    [sym_internal_keyword] = ACTIONS(12630),
    [sym_protected_keyword] = ACTIONS(12630),
    [sym_event_keyword] = ACTIONS(12630),
    [sym_fields_keyword] = ACTIONS(12630),
    [sym_keys_keyword] = ACTIONS(12630),
    [sym_fieldgroups_keyword] = ACTIONS(12630),
    [sym_actions_keyword] = ACTIONS(12630),
    [sym_layout_keyword] = ACTIONS(12630),
    [sym_area_keyword] = ACTIONS(12630),
    [sym_group_keyword] = ACTIONS(12630),
    [sym_repeater_keyword] = ACTIONS(12630),
    [sym_cuegroup_keyword] = ACTIONS(12630),
    [sym_fixed_keyword] = ACTIONS(12630),
    [sym_grid_keyword] = ACTIONS(12630),
    [sym_part_keyword] = ACTIONS(12630),
    [sym_systempart_keyword] = ACTIONS(12630),
    [sym_usercontrol_keyword] = ACTIONS(12630),
    [sym_dataset_keyword] = ACTIONS(12630),
    [sym_elements_keyword] = ACTIONS(12630),
    [sym_dataitem_keyword] = ACTIONS(12630),
    [sym_column_keyword] = ACTIONS(12630),
    [sym_filter_keyword] = ACTIONS(12630),
    [sym_labels_keyword] = ACTIONS(12630),
    [sym_rendering_keyword] = ACTIONS(12630),
    [sym_requestpage_keyword] = ACTIONS(12630),
    [sym_schema_keyword] = ACTIONS(12630),
    [sym_views_keyword] = ACTIONS(12630),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12630),
    [sym_preproc_open] = ACTIONS(12630),
    [sym_preproc_close] = ACTIONS(12630),
  },
  [STATE(5123)] = {
    [anon_sym_SEMI] = ACTIONS(12634),
    [aux_sym_where_condition_token1] = ACTIONS(12636),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12638),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12638),
    [anon_sym_LBRACK] = ACTIONS(12638),
    [aux_sym_basic_type_token6] = ACTIONS(12636),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12638),
    [aux_sym_addafter_modification_token1] = ACTIONS(12638),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12638),
    [aux_sym_modify_modification_token1] = ACTIONS(12638),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12638),
    [aux_sym_movelast_modification_token1] = ACTIONS(12638),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12638),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12638),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12638),
    [anon_sym_POUNDif] = ACTIONS(12638),
    [anon_sym_POUNDIF] = ACTIONS(12638),
    [anon_sym_POUNDIf] = ACTIONS(12638),
    [anon_sym_POUNDelif] = ACTIONS(12638),
    [anon_sym_POUNDELIF] = ACTIONS(12638),
    [anon_sym_POUNDElif] = ACTIONS(12638),
    [anon_sym_POUNDelse] = ACTIONS(12638),
    [anon_sym_POUNDELSE] = ACTIONS(12638),
    [anon_sym_POUNDElse] = ACTIONS(12638),
    [anon_sym_POUNDelse2] = ACTIONS(12638),
    [anon_sym_POUNDELSE2] = ACTIONS(12638),
    [anon_sym_POUNDElse2] = ACTIONS(12638),
    [anon_sym_POUNDendif] = ACTIONS(12638),
    [anon_sym_POUNDENDIF] = ACTIONS(12638),
    [anon_sym_POUNDEndif] = ACTIONS(12638),
    [anon_sym_POUNDendif2] = ACTIONS(12638),
    [anon_sym_POUNDENDIF2] = ACTIONS(12638),
    [anon_sym_POUNDEndif2] = ACTIONS(12638),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12638),
    [sym_trigger_keyword] = ACTIONS(12638),
    [sym_var_keyword] = ACTIONS(12638),
    [sym_local_keyword] = ACTIONS(12638),
    [sym_internal_keyword] = ACTIONS(12638),
    [sym_protected_keyword] = ACTIONS(12638),
    [sym_event_keyword] = ACTIONS(12638),
    [sym_fields_keyword] = ACTIONS(12638),
    [sym_keys_keyword] = ACTIONS(12638),
    [sym_fieldgroups_keyword] = ACTIONS(12638),
    [sym_actions_keyword] = ACTIONS(12638),
    [sym_layout_keyword] = ACTIONS(12638),
    [sym_area_keyword] = ACTIONS(12638),
    [sym_group_keyword] = ACTIONS(12638),
    [sym_repeater_keyword] = ACTIONS(12638),
    [sym_cuegroup_keyword] = ACTIONS(12638),
    [sym_fixed_keyword] = ACTIONS(12638),
    [sym_grid_keyword] = ACTIONS(12638),
    [sym_part_keyword] = ACTIONS(12638),
    [sym_systempart_keyword] = ACTIONS(12638),
    [sym_usercontrol_keyword] = ACTIONS(12638),
    [sym_dataset_keyword] = ACTIONS(12638),
    [sym_elements_keyword] = ACTIONS(12638),
    [sym_dataitem_keyword] = ACTIONS(12638),
    [sym_column_keyword] = ACTIONS(12638),
    [sym_filter_keyword] = ACTIONS(12638),
    [sym_labels_keyword] = ACTIONS(12638),
    [sym_rendering_keyword] = ACTIONS(12638),
    [sym_requestpage_keyword] = ACTIONS(12638),
    [sym_schema_keyword] = ACTIONS(12638),
    [sym_views_keyword] = ACTIONS(12638),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12638),
    [sym_preproc_open] = ACTIONS(12638),
    [sym_preproc_close] = ACTIONS(12638),
  },
  [STATE(5124)] = {
    [anon_sym_SEMI] = ACTIONS(12640),
    [aux_sym_where_condition_token1] = ACTIONS(12636),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12638),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12638),
    [anon_sym_LBRACK] = ACTIONS(12638),
    [aux_sym_basic_type_token6] = ACTIONS(12636),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12638),
    [aux_sym_addafter_modification_token1] = ACTIONS(12638),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12638),
    [aux_sym_modify_modification_token1] = ACTIONS(12638),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12638),
    [aux_sym_movelast_modification_token1] = ACTIONS(12638),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12638),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12638),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12638),
    [anon_sym_POUNDif] = ACTIONS(12638),
    [anon_sym_POUNDIF] = ACTIONS(12638),
    [anon_sym_POUNDIf] = ACTIONS(12638),
    [anon_sym_POUNDelif] = ACTIONS(12638),
    [anon_sym_POUNDELIF] = ACTIONS(12638),
    [anon_sym_POUNDElif] = ACTIONS(12638),
    [anon_sym_POUNDelse] = ACTIONS(12638),
    [anon_sym_POUNDELSE] = ACTIONS(12638),
    [anon_sym_POUNDElse] = ACTIONS(12638),
    [anon_sym_POUNDelse2] = ACTIONS(12638),
    [anon_sym_POUNDELSE2] = ACTIONS(12638),
    [anon_sym_POUNDElse2] = ACTIONS(12638),
    [anon_sym_POUNDendif] = ACTIONS(12638),
    [anon_sym_POUNDENDIF] = ACTIONS(12638),
    [anon_sym_POUNDEndif] = ACTIONS(12638),
    [anon_sym_POUNDendif2] = ACTIONS(12638),
    [anon_sym_POUNDENDIF2] = ACTIONS(12638),
    [anon_sym_POUNDEndif2] = ACTIONS(12638),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12638),
    [sym_trigger_keyword] = ACTIONS(12638),
    [sym_var_keyword] = ACTIONS(12638),
    [sym_local_keyword] = ACTIONS(12638),
    [sym_internal_keyword] = ACTIONS(12638),
    [sym_protected_keyword] = ACTIONS(12638),
    [sym_event_keyword] = ACTIONS(12638),
    [sym_fields_keyword] = ACTIONS(12638),
    [sym_keys_keyword] = ACTIONS(12638),
    [sym_fieldgroups_keyword] = ACTIONS(12638),
    [sym_actions_keyword] = ACTIONS(12638),
    [sym_layout_keyword] = ACTIONS(12638),
    [sym_area_keyword] = ACTIONS(12638),
    [sym_group_keyword] = ACTIONS(12638),
    [sym_repeater_keyword] = ACTIONS(12638),
    [sym_cuegroup_keyword] = ACTIONS(12638),
    [sym_fixed_keyword] = ACTIONS(12638),
    [sym_grid_keyword] = ACTIONS(12638),
    [sym_part_keyword] = ACTIONS(12638),
    [sym_systempart_keyword] = ACTIONS(12638),
    [sym_usercontrol_keyword] = ACTIONS(12638),
    [sym_dataset_keyword] = ACTIONS(12638),
    [sym_elements_keyword] = ACTIONS(12638),
    [sym_dataitem_keyword] = ACTIONS(12638),
    [sym_column_keyword] = ACTIONS(12638),
    [sym_filter_keyword] = ACTIONS(12638),
    [sym_labels_keyword] = ACTIONS(12638),
    [sym_rendering_keyword] = ACTIONS(12638),
    [sym_requestpage_keyword] = ACTIONS(12638),
    [sym_schema_keyword] = ACTIONS(12638),
    [sym_views_keyword] = ACTIONS(12638),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12638),
    [sym_preproc_open] = ACTIONS(12638),
    [sym_preproc_close] = ACTIONS(12638),
  },
  [STATE(5125)] = {
    [anon_sym_SEMI] = ACTIONS(12642),
    [aux_sym_where_condition_token1] = ACTIONS(12644),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12642),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12642),
    [anon_sym_LBRACK] = ACTIONS(12642),
    [aux_sym_basic_type_token6] = ACTIONS(12644),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12642),
    [aux_sym_addafter_modification_token1] = ACTIONS(12642),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12642),
    [aux_sym_modify_modification_token1] = ACTIONS(12642),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12642),
    [aux_sym_movelast_modification_token1] = ACTIONS(12642),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12642),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12642),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12642),
    [anon_sym_POUNDif] = ACTIONS(12642),
    [anon_sym_POUNDIF] = ACTIONS(12642),
    [anon_sym_POUNDIf] = ACTIONS(12642),
    [anon_sym_POUNDelif] = ACTIONS(12642),
    [anon_sym_POUNDELIF] = ACTIONS(12642),
    [anon_sym_POUNDElif] = ACTIONS(12642),
    [anon_sym_POUNDelse] = ACTIONS(12642),
    [anon_sym_POUNDELSE] = ACTIONS(12642),
    [anon_sym_POUNDElse] = ACTIONS(12642),
    [anon_sym_POUNDelse2] = ACTIONS(12642),
    [anon_sym_POUNDELSE2] = ACTIONS(12642),
    [anon_sym_POUNDElse2] = ACTIONS(12642),
    [anon_sym_POUNDendif] = ACTIONS(12642),
    [anon_sym_POUNDENDIF] = ACTIONS(12642),
    [anon_sym_POUNDEndif] = ACTIONS(12642),
    [anon_sym_POUNDendif2] = ACTIONS(12642),
    [anon_sym_POUNDENDIF2] = ACTIONS(12642),
    [anon_sym_POUNDEndif2] = ACTIONS(12642),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12642),
    [sym_trigger_keyword] = ACTIONS(12642),
    [sym_var_keyword] = ACTIONS(12642),
    [sym_local_keyword] = ACTIONS(12642),
    [sym_internal_keyword] = ACTIONS(12642),
    [sym_protected_keyword] = ACTIONS(12642),
    [sym_event_keyword] = ACTIONS(12642),
    [sym_fields_keyword] = ACTIONS(12642),
    [sym_keys_keyword] = ACTIONS(12642),
    [sym_fieldgroups_keyword] = ACTIONS(12642),
    [sym_actions_keyword] = ACTIONS(12642),
    [sym_layout_keyword] = ACTIONS(12642),
    [sym_area_keyword] = ACTIONS(12642),
    [sym_group_keyword] = ACTIONS(12642),
    [sym_repeater_keyword] = ACTIONS(12642),
    [sym_cuegroup_keyword] = ACTIONS(12642),
    [sym_fixed_keyword] = ACTIONS(12642),
    [sym_grid_keyword] = ACTIONS(12642),
    [sym_part_keyword] = ACTIONS(12642),
    [sym_systempart_keyword] = ACTIONS(12642),
    [sym_usercontrol_keyword] = ACTIONS(12642),
    [sym_dataset_keyword] = ACTIONS(12642),
    [sym_elements_keyword] = ACTIONS(12642),
    [sym_dataitem_keyword] = ACTIONS(12642),
    [sym_column_keyword] = ACTIONS(12642),
    [sym_filter_keyword] = ACTIONS(12642),
    [sym_labels_keyword] = ACTIONS(12642),
    [sym_rendering_keyword] = ACTIONS(12642),
    [sym_requestpage_keyword] = ACTIONS(12642),
    [sym_schema_keyword] = ACTIONS(12642),
    [sym_views_keyword] = ACTIONS(12642),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12642),
    [sym_preproc_open] = ACTIONS(12642),
    [sym_preproc_close] = ACTIONS(12642),
  },
  [STATE(5126)] = {
    [anon_sym_SEMI] = ACTIONS(12642),
    [aux_sym_where_condition_token1] = ACTIONS(12644),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12642),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12642),
    [anon_sym_LBRACK] = ACTIONS(12642),
    [aux_sym_basic_type_token6] = ACTIONS(12644),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12642),
    [aux_sym_addafter_modification_token1] = ACTIONS(12642),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12642),
    [aux_sym_modify_modification_token1] = ACTIONS(12642),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12642),
    [aux_sym_movelast_modification_token1] = ACTIONS(12642),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12642),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12642),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12642),
    [anon_sym_POUNDif] = ACTIONS(12642),
    [anon_sym_POUNDIF] = ACTIONS(12642),
    [anon_sym_POUNDIf] = ACTIONS(12642),
    [anon_sym_POUNDelif] = ACTIONS(12642),
    [anon_sym_POUNDELIF] = ACTIONS(12642),
    [anon_sym_POUNDElif] = ACTIONS(12642),
    [anon_sym_POUNDelse] = ACTIONS(12642),
    [anon_sym_POUNDELSE] = ACTIONS(12642),
    [anon_sym_POUNDElse] = ACTIONS(12642),
    [anon_sym_POUNDelse2] = ACTIONS(12642),
    [anon_sym_POUNDELSE2] = ACTIONS(12642),
    [anon_sym_POUNDElse2] = ACTIONS(12642),
    [anon_sym_POUNDendif] = ACTIONS(12642),
    [anon_sym_POUNDENDIF] = ACTIONS(12642),
    [anon_sym_POUNDEndif] = ACTIONS(12642),
    [anon_sym_POUNDendif2] = ACTIONS(12642),
    [anon_sym_POUNDENDIF2] = ACTIONS(12642),
    [anon_sym_POUNDEndif2] = ACTIONS(12642),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12642),
    [sym_trigger_keyword] = ACTIONS(12642),
    [sym_var_keyword] = ACTIONS(12642),
    [sym_local_keyword] = ACTIONS(12642),
    [sym_internal_keyword] = ACTIONS(12642),
    [sym_protected_keyword] = ACTIONS(12642),
    [sym_event_keyword] = ACTIONS(12642),
    [sym_fields_keyword] = ACTIONS(12642),
    [sym_keys_keyword] = ACTIONS(12642),
    [sym_fieldgroups_keyword] = ACTIONS(12642),
    [sym_actions_keyword] = ACTIONS(12642),
    [sym_layout_keyword] = ACTIONS(12642),
    [sym_area_keyword] = ACTIONS(12642),
    [sym_group_keyword] = ACTIONS(12642),
    [sym_repeater_keyword] = ACTIONS(12642),
    [sym_cuegroup_keyword] = ACTIONS(12642),
    [sym_fixed_keyword] = ACTIONS(12642),
    [sym_grid_keyword] = ACTIONS(12642),
    [sym_part_keyword] = ACTIONS(12642),
    [sym_systempart_keyword] = ACTIONS(12642),
    [sym_usercontrol_keyword] = ACTIONS(12642),
    [sym_dataset_keyword] = ACTIONS(12642),
    [sym_elements_keyword] = ACTIONS(12642),
    [sym_dataitem_keyword] = ACTIONS(12642),
    [sym_column_keyword] = ACTIONS(12642),
    [sym_filter_keyword] = ACTIONS(12642),
    [sym_labels_keyword] = ACTIONS(12642),
    [sym_rendering_keyword] = ACTIONS(12642),
    [sym_requestpage_keyword] = ACTIONS(12642),
    [sym_schema_keyword] = ACTIONS(12642),
    [sym_views_keyword] = ACTIONS(12642),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12642),
    [sym_preproc_open] = ACTIONS(12642),
    [sym_preproc_close] = ACTIONS(12642),
  },
  [STATE(5127)] = {
    [anon_sym_SEMI] = ACTIONS(12646),
    [aux_sym_where_condition_token1] = ACTIONS(12648),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12646),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12646),
    [anon_sym_LBRACK] = ACTIONS(12646),
    [aux_sym_basic_type_token6] = ACTIONS(12648),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12646),
    [aux_sym_addafter_modification_token1] = ACTIONS(12646),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12646),
    [aux_sym_modify_modification_token1] = ACTIONS(12646),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12646),
    [aux_sym_movelast_modification_token1] = ACTIONS(12646),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12646),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12646),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12646),
    [anon_sym_POUNDif] = ACTIONS(12646),
    [anon_sym_POUNDIF] = ACTIONS(12646),
    [anon_sym_POUNDIf] = ACTIONS(12646),
    [anon_sym_POUNDelif] = ACTIONS(12646),
    [anon_sym_POUNDELIF] = ACTIONS(12646),
    [anon_sym_POUNDElif] = ACTIONS(12646),
    [anon_sym_POUNDelse] = ACTIONS(12646),
    [anon_sym_POUNDELSE] = ACTIONS(12646),
    [anon_sym_POUNDElse] = ACTIONS(12646),
    [anon_sym_POUNDelse2] = ACTIONS(12646),
    [anon_sym_POUNDELSE2] = ACTIONS(12646),
    [anon_sym_POUNDElse2] = ACTIONS(12646),
    [anon_sym_POUNDendif] = ACTIONS(12646),
    [anon_sym_POUNDENDIF] = ACTIONS(12646),
    [anon_sym_POUNDEndif] = ACTIONS(12646),
    [anon_sym_POUNDendif2] = ACTIONS(12646),
    [anon_sym_POUNDENDIF2] = ACTIONS(12646),
    [anon_sym_POUNDEndif2] = ACTIONS(12646),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12646),
    [sym_trigger_keyword] = ACTIONS(12646),
    [sym_var_keyword] = ACTIONS(12646),
    [sym_local_keyword] = ACTIONS(12646),
    [sym_internal_keyword] = ACTIONS(12646),
    [sym_protected_keyword] = ACTIONS(12646),
    [sym_event_keyword] = ACTIONS(12646),
    [sym_fields_keyword] = ACTIONS(12646),
    [sym_keys_keyword] = ACTIONS(12646),
    [sym_fieldgroups_keyword] = ACTIONS(12646),
    [sym_actions_keyword] = ACTIONS(12646),
    [sym_layout_keyword] = ACTIONS(12646),
    [sym_area_keyword] = ACTIONS(12646),
    [sym_group_keyword] = ACTIONS(12646),
    [sym_repeater_keyword] = ACTIONS(12646),
    [sym_cuegroup_keyword] = ACTIONS(12646),
    [sym_fixed_keyword] = ACTIONS(12646),
    [sym_grid_keyword] = ACTIONS(12646),
    [sym_part_keyword] = ACTIONS(12646),
    [sym_systempart_keyword] = ACTIONS(12646),
    [sym_usercontrol_keyword] = ACTIONS(12646),
    [sym_dataset_keyword] = ACTIONS(12646),
    [sym_elements_keyword] = ACTIONS(12646),
    [sym_dataitem_keyword] = ACTIONS(12646),
    [sym_column_keyword] = ACTIONS(12646),
    [sym_filter_keyword] = ACTIONS(12646),
    [sym_labels_keyword] = ACTIONS(12646),
    [sym_rendering_keyword] = ACTIONS(12646),
    [sym_requestpage_keyword] = ACTIONS(12646),
    [sym_schema_keyword] = ACTIONS(12646),
    [sym_views_keyword] = ACTIONS(12646),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12646),
    [sym_preproc_open] = ACTIONS(12646),
    [sym_preproc_close] = ACTIONS(12646),
  },
  [STATE(5128)] = {
    [anon_sym_SEMI] = ACTIONS(12646),
    [aux_sym_where_condition_token1] = ACTIONS(12648),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12646),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12646),
    [anon_sym_LBRACK] = ACTIONS(12646),
    [aux_sym_basic_type_token6] = ACTIONS(12648),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12646),
    [aux_sym_addafter_modification_token1] = ACTIONS(12646),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12646),
    [aux_sym_modify_modification_token1] = ACTIONS(12646),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12646),
    [aux_sym_movelast_modification_token1] = ACTIONS(12646),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12646),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12646),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12646),
    [anon_sym_POUNDif] = ACTIONS(12646),
    [anon_sym_POUNDIF] = ACTIONS(12646),
    [anon_sym_POUNDIf] = ACTIONS(12646),
    [anon_sym_POUNDelif] = ACTIONS(12646),
    [anon_sym_POUNDELIF] = ACTIONS(12646),
    [anon_sym_POUNDElif] = ACTIONS(12646),
    [anon_sym_POUNDelse] = ACTIONS(12646),
    [anon_sym_POUNDELSE] = ACTIONS(12646),
    [anon_sym_POUNDElse] = ACTIONS(12646),
    [anon_sym_POUNDelse2] = ACTIONS(12646),
    [anon_sym_POUNDELSE2] = ACTIONS(12646),
    [anon_sym_POUNDElse2] = ACTIONS(12646),
    [anon_sym_POUNDendif] = ACTIONS(12646),
    [anon_sym_POUNDENDIF] = ACTIONS(12646),
    [anon_sym_POUNDEndif] = ACTIONS(12646),
    [anon_sym_POUNDendif2] = ACTIONS(12646),
    [anon_sym_POUNDENDIF2] = ACTIONS(12646),
    [anon_sym_POUNDEndif2] = ACTIONS(12646),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12646),
    [sym_trigger_keyword] = ACTIONS(12646),
    [sym_var_keyword] = ACTIONS(12646),
    [sym_local_keyword] = ACTIONS(12646),
    [sym_internal_keyword] = ACTIONS(12646),
    [sym_protected_keyword] = ACTIONS(12646),
    [sym_event_keyword] = ACTIONS(12646),
    [sym_fields_keyword] = ACTIONS(12646),
    [sym_keys_keyword] = ACTIONS(12646),
    [sym_fieldgroups_keyword] = ACTIONS(12646),
    [sym_actions_keyword] = ACTIONS(12646),
    [sym_layout_keyword] = ACTIONS(12646),
    [sym_area_keyword] = ACTIONS(12646),
    [sym_group_keyword] = ACTIONS(12646),
    [sym_repeater_keyword] = ACTIONS(12646),
    [sym_cuegroup_keyword] = ACTIONS(12646),
    [sym_fixed_keyword] = ACTIONS(12646),
    [sym_grid_keyword] = ACTIONS(12646),
    [sym_part_keyword] = ACTIONS(12646),
    [sym_systempart_keyword] = ACTIONS(12646),
    [sym_usercontrol_keyword] = ACTIONS(12646),
    [sym_dataset_keyword] = ACTIONS(12646),
    [sym_elements_keyword] = ACTIONS(12646),
    [sym_dataitem_keyword] = ACTIONS(12646),
    [sym_column_keyword] = ACTIONS(12646),
    [sym_filter_keyword] = ACTIONS(12646),
    [sym_labels_keyword] = ACTIONS(12646),
    [sym_rendering_keyword] = ACTIONS(12646),
    [sym_requestpage_keyword] = ACTIONS(12646),
    [sym_schema_keyword] = ACTIONS(12646),
    [sym_views_keyword] = ACTIONS(12646),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12646),
    [sym_preproc_open] = ACTIONS(12646),
    [sym_preproc_close] = ACTIONS(12646),
  },
  [STATE(5129)] = {
    [anon_sym_SEMI] = ACTIONS(12650),
    [aux_sym_where_condition_token1] = ACTIONS(12652),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12650),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12650),
    [anon_sym_LBRACK] = ACTIONS(12650),
    [aux_sym_basic_type_token6] = ACTIONS(12652),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12650),
    [aux_sym_addafter_modification_token1] = ACTIONS(12650),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12650),
    [aux_sym_modify_modification_token1] = ACTIONS(12650),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12650),
    [aux_sym_movelast_modification_token1] = ACTIONS(12650),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12650),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12650),
    [anon_sym_POUNDif] = ACTIONS(12650),
    [anon_sym_POUNDIF] = ACTIONS(12650),
    [anon_sym_POUNDIf] = ACTIONS(12650),
    [anon_sym_POUNDelif] = ACTIONS(12650),
    [anon_sym_POUNDELIF] = ACTIONS(12650),
    [anon_sym_POUNDElif] = ACTIONS(12650),
    [anon_sym_POUNDelse] = ACTIONS(12650),
    [anon_sym_POUNDELSE] = ACTIONS(12650),
    [anon_sym_POUNDElse] = ACTIONS(12650),
    [anon_sym_POUNDelse2] = ACTIONS(12650),
    [anon_sym_POUNDELSE2] = ACTIONS(12650),
    [anon_sym_POUNDElse2] = ACTIONS(12650),
    [anon_sym_POUNDendif] = ACTIONS(12650),
    [anon_sym_POUNDENDIF] = ACTIONS(12650),
    [anon_sym_POUNDEndif] = ACTIONS(12650),
    [anon_sym_POUNDendif2] = ACTIONS(12650),
    [anon_sym_POUNDENDIF2] = ACTIONS(12650),
    [anon_sym_POUNDEndif2] = ACTIONS(12650),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12650),
    [sym_trigger_keyword] = ACTIONS(12650),
    [sym_var_keyword] = ACTIONS(12650),
    [sym_local_keyword] = ACTIONS(12650),
    [sym_internal_keyword] = ACTIONS(12650),
    [sym_protected_keyword] = ACTIONS(12650),
    [sym_event_keyword] = ACTIONS(12650),
    [sym_fields_keyword] = ACTIONS(12650),
    [sym_keys_keyword] = ACTIONS(12650),
    [sym_fieldgroups_keyword] = ACTIONS(12650),
    [sym_actions_keyword] = ACTIONS(12650),
    [sym_layout_keyword] = ACTIONS(12650),
    [sym_area_keyword] = ACTIONS(12650),
    [sym_group_keyword] = ACTIONS(12650),
    [sym_repeater_keyword] = ACTIONS(12650),
    [sym_cuegroup_keyword] = ACTIONS(12650),
    [sym_fixed_keyword] = ACTIONS(12650),
    [sym_grid_keyword] = ACTIONS(12650),
    [sym_part_keyword] = ACTIONS(12650),
    [sym_systempart_keyword] = ACTIONS(12650),
    [sym_usercontrol_keyword] = ACTIONS(12650),
    [sym_dataset_keyword] = ACTIONS(12650),
    [sym_elements_keyword] = ACTIONS(12650),
    [sym_dataitem_keyword] = ACTIONS(12650),
    [sym_column_keyword] = ACTIONS(12650),
    [sym_filter_keyword] = ACTIONS(12650),
    [sym_labels_keyword] = ACTIONS(12650),
    [sym_rendering_keyword] = ACTIONS(12650),
    [sym_requestpage_keyword] = ACTIONS(12650),
    [sym_schema_keyword] = ACTIONS(12650),
    [sym_views_keyword] = ACTIONS(12650),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12650),
    [sym_preproc_open] = ACTIONS(12650),
    [sym_preproc_close] = ACTIONS(12650),
  },
  [STATE(5130)] = {
    [anon_sym_SEMI] = ACTIONS(12650),
    [aux_sym_where_condition_token1] = ACTIONS(12652),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12650),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12650),
    [anon_sym_LBRACK] = ACTIONS(12650),
    [aux_sym_basic_type_token6] = ACTIONS(12652),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12650),
    [aux_sym_addafter_modification_token1] = ACTIONS(12650),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12650),
    [aux_sym_modify_modification_token1] = ACTIONS(12650),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12650),
    [aux_sym_movelast_modification_token1] = ACTIONS(12650),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12650),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12650),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12650),
    [anon_sym_POUNDif] = ACTIONS(12650),
    [anon_sym_POUNDIF] = ACTIONS(12650),
    [anon_sym_POUNDIf] = ACTIONS(12650),
    [anon_sym_POUNDelif] = ACTIONS(12650),
    [anon_sym_POUNDELIF] = ACTIONS(12650),
    [anon_sym_POUNDElif] = ACTIONS(12650),
    [anon_sym_POUNDelse] = ACTIONS(12650),
    [anon_sym_POUNDELSE] = ACTIONS(12650),
    [anon_sym_POUNDElse] = ACTIONS(12650),
    [anon_sym_POUNDelse2] = ACTIONS(12650),
    [anon_sym_POUNDELSE2] = ACTIONS(12650),
    [anon_sym_POUNDElse2] = ACTIONS(12650),
    [anon_sym_POUNDendif] = ACTIONS(12650),
    [anon_sym_POUNDENDIF] = ACTIONS(12650),
    [anon_sym_POUNDEndif] = ACTIONS(12650),
    [anon_sym_POUNDendif2] = ACTIONS(12650),
    [anon_sym_POUNDENDIF2] = ACTIONS(12650),
    [anon_sym_POUNDEndif2] = ACTIONS(12650),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12650),
    [sym_trigger_keyword] = ACTIONS(12650),
    [sym_var_keyword] = ACTIONS(12650),
    [sym_local_keyword] = ACTIONS(12650),
    [sym_internal_keyword] = ACTIONS(12650),
    [sym_protected_keyword] = ACTIONS(12650),
    [sym_event_keyword] = ACTIONS(12650),
    [sym_fields_keyword] = ACTIONS(12650),
    [sym_keys_keyword] = ACTIONS(12650),
    [sym_fieldgroups_keyword] = ACTIONS(12650),
    [sym_actions_keyword] = ACTIONS(12650),
    [sym_layout_keyword] = ACTIONS(12650),
    [sym_area_keyword] = ACTIONS(12650),
    [sym_group_keyword] = ACTIONS(12650),
    [sym_repeater_keyword] = ACTIONS(12650),
    [sym_cuegroup_keyword] = ACTIONS(12650),
    [sym_fixed_keyword] = ACTIONS(12650),
    [sym_grid_keyword] = ACTIONS(12650),
    [sym_part_keyword] = ACTIONS(12650),
    [sym_systempart_keyword] = ACTIONS(12650),
    [sym_usercontrol_keyword] = ACTIONS(12650),
    [sym_dataset_keyword] = ACTIONS(12650),
    [sym_elements_keyword] = ACTIONS(12650),
    [sym_dataitem_keyword] = ACTIONS(12650),
    [sym_column_keyword] = ACTIONS(12650),
    [sym_filter_keyword] = ACTIONS(12650),
    [sym_labels_keyword] = ACTIONS(12650),
    [sym_rendering_keyword] = ACTIONS(12650),
    [sym_requestpage_keyword] = ACTIONS(12650),
    [sym_schema_keyword] = ACTIONS(12650),
    [sym_views_keyword] = ACTIONS(12650),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12650),
    [sym_preproc_open] = ACTIONS(12650),
    [sym_preproc_close] = ACTIONS(12650),
  },
  [STATE(5131)] = {
    [anon_sym_SEMI] = ACTIONS(12654),
    [aux_sym_where_condition_token1] = ACTIONS(12656),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12658),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12658),
    [anon_sym_LBRACK] = ACTIONS(12658),
    [aux_sym_basic_type_token6] = ACTIONS(12656),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12658),
    [aux_sym_addafter_modification_token1] = ACTIONS(12658),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12658),
    [aux_sym_modify_modification_token1] = ACTIONS(12658),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12658),
    [aux_sym_movelast_modification_token1] = ACTIONS(12658),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12658),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12658),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12658),
    [anon_sym_POUNDif] = ACTIONS(12658),
    [anon_sym_POUNDIF] = ACTIONS(12658),
    [anon_sym_POUNDIf] = ACTIONS(12658),
    [anon_sym_POUNDelif] = ACTIONS(12658),
    [anon_sym_POUNDELIF] = ACTIONS(12658),
    [anon_sym_POUNDElif] = ACTIONS(12658),
    [anon_sym_POUNDelse] = ACTIONS(12658),
    [anon_sym_POUNDELSE] = ACTIONS(12658),
    [anon_sym_POUNDElse] = ACTIONS(12658),
    [anon_sym_POUNDelse2] = ACTIONS(12658),
    [anon_sym_POUNDELSE2] = ACTIONS(12658),
    [anon_sym_POUNDElse2] = ACTIONS(12658),
    [anon_sym_POUNDendif] = ACTIONS(12658),
    [anon_sym_POUNDENDIF] = ACTIONS(12658),
    [anon_sym_POUNDEndif] = ACTIONS(12658),
    [anon_sym_POUNDendif2] = ACTIONS(12658),
    [anon_sym_POUNDENDIF2] = ACTIONS(12658),
    [anon_sym_POUNDEndif2] = ACTIONS(12658),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12658),
    [sym_trigger_keyword] = ACTIONS(12658),
    [sym_var_keyword] = ACTIONS(12658),
    [sym_local_keyword] = ACTIONS(12658),
    [sym_internal_keyword] = ACTIONS(12658),
    [sym_protected_keyword] = ACTIONS(12658),
    [sym_event_keyword] = ACTIONS(12658),
    [sym_fields_keyword] = ACTIONS(12658),
    [sym_keys_keyword] = ACTIONS(12658),
    [sym_fieldgroups_keyword] = ACTIONS(12658),
    [sym_actions_keyword] = ACTIONS(12658),
    [sym_layout_keyword] = ACTIONS(12658),
    [sym_area_keyword] = ACTIONS(12658),
    [sym_group_keyword] = ACTIONS(12658),
    [sym_repeater_keyword] = ACTIONS(12658),
    [sym_cuegroup_keyword] = ACTIONS(12658),
    [sym_fixed_keyword] = ACTIONS(12658),
    [sym_grid_keyword] = ACTIONS(12658),
    [sym_part_keyword] = ACTIONS(12658),
    [sym_systempart_keyword] = ACTIONS(12658),
    [sym_usercontrol_keyword] = ACTIONS(12658),
    [sym_dataset_keyword] = ACTIONS(12658),
    [sym_elements_keyword] = ACTIONS(12658),
    [sym_dataitem_keyword] = ACTIONS(12658),
    [sym_column_keyword] = ACTIONS(12658),
    [sym_filter_keyword] = ACTIONS(12658),
    [sym_labels_keyword] = ACTIONS(12658),
    [sym_rendering_keyword] = ACTIONS(12658),
    [sym_requestpage_keyword] = ACTIONS(12658),
    [sym_schema_keyword] = ACTIONS(12658),
    [sym_views_keyword] = ACTIONS(12658),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12658),
    [sym_preproc_open] = ACTIONS(12658),
    [sym_preproc_close] = ACTIONS(12658),
  },
  [STATE(5132)] = {
    [anon_sym_SEMI] = ACTIONS(12660),
    [aux_sym_where_condition_token1] = ACTIONS(12656),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12658),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12658),
    [anon_sym_LBRACK] = ACTIONS(12658),
    [aux_sym_basic_type_token6] = ACTIONS(12656),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12658),
    [aux_sym_addafter_modification_token1] = ACTIONS(12658),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12658),
    [aux_sym_modify_modification_token1] = ACTIONS(12658),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12658),
    [aux_sym_movelast_modification_token1] = ACTIONS(12658),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12658),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12658),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12658),
    [anon_sym_POUNDif] = ACTIONS(12658),
    [anon_sym_POUNDIF] = ACTIONS(12658),
    [anon_sym_POUNDIf] = ACTIONS(12658),
    [anon_sym_POUNDelif] = ACTIONS(12658),
    [anon_sym_POUNDELIF] = ACTIONS(12658),
    [anon_sym_POUNDElif] = ACTIONS(12658),
    [anon_sym_POUNDelse] = ACTIONS(12658),
    [anon_sym_POUNDELSE] = ACTIONS(12658),
    [anon_sym_POUNDElse] = ACTIONS(12658),
    [anon_sym_POUNDelse2] = ACTIONS(12658),
    [anon_sym_POUNDELSE2] = ACTIONS(12658),
    [anon_sym_POUNDElse2] = ACTIONS(12658),
    [anon_sym_POUNDendif] = ACTIONS(12658),
    [anon_sym_POUNDENDIF] = ACTIONS(12658),
    [anon_sym_POUNDEndif] = ACTIONS(12658),
    [anon_sym_POUNDendif2] = ACTIONS(12658),
    [anon_sym_POUNDENDIF2] = ACTIONS(12658),
    [anon_sym_POUNDEndif2] = ACTIONS(12658),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12658),
    [sym_trigger_keyword] = ACTIONS(12658),
    [sym_var_keyword] = ACTIONS(12658),
    [sym_local_keyword] = ACTIONS(12658),
    [sym_internal_keyword] = ACTIONS(12658),
    [sym_protected_keyword] = ACTIONS(12658),
    [sym_event_keyword] = ACTIONS(12658),
    [sym_fields_keyword] = ACTIONS(12658),
    [sym_keys_keyword] = ACTIONS(12658),
    [sym_fieldgroups_keyword] = ACTIONS(12658),
    [sym_actions_keyword] = ACTIONS(12658),
    [sym_layout_keyword] = ACTIONS(12658),
    [sym_area_keyword] = ACTIONS(12658),
    [sym_group_keyword] = ACTIONS(12658),
    [sym_repeater_keyword] = ACTIONS(12658),
    [sym_cuegroup_keyword] = ACTIONS(12658),
    [sym_fixed_keyword] = ACTIONS(12658),
    [sym_grid_keyword] = ACTIONS(12658),
    [sym_part_keyword] = ACTIONS(12658),
    [sym_systempart_keyword] = ACTIONS(12658),
    [sym_usercontrol_keyword] = ACTIONS(12658),
    [sym_dataset_keyword] = ACTIONS(12658),
    [sym_elements_keyword] = ACTIONS(12658),
    [sym_dataitem_keyword] = ACTIONS(12658),
    [sym_column_keyword] = ACTIONS(12658),
    [sym_filter_keyword] = ACTIONS(12658),
    [sym_labels_keyword] = ACTIONS(12658),
    [sym_rendering_keyword] = ACTIONS(12658),
    [sym_requestpage_keyword] = ACTIONS(12658),
    [sym_schema_keyword] = ACTIONS(12658),
    [sym_views_keyword] = ACTIONS(12658),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12658),
    [sym_preproc_open] = ACTIONS(12658),
    [sym_preproc_close] = ACTIONS(12658),
  },
  [STATE(5133)] = {
    [anon_sym_SEMI] = ACTIONS(12662),
    [aux_sym_where_condition_token1] = ACTIONS(12664),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12662),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12662),
    [anon_sym_LBRACK] = ACTIONS(12662),
    [aux_sym_basic_type_token6] = ACTIONS(12664),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12662),
    [aux_sym_addafter_modification_token1] = ACTIONS(12662),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12662),
    [aux_sym_modify_modification_token1] = ACTIONS(12662),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12662),
    [aux_sym_movelast_modification_token1] = ACTIONS(12662),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12662),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12662),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12662),
    [anon_sym_POUNDif] = ACTIONS(12662),
    [anon_sym_POUNDIF] = ACTIONS(12662),
    [anon_sym_POUNDIf] = ACTIONS(12662),
    [anon_sym_POUNDelif] = ACTIONS(12662),
    [anon_sym_POUNDELIF] = ACTIONS(12662),
    [anon_sym_POUNDElif] = ACTIONS(12662),
    [anon_sym_POUNDelse] = ACTIONS(12662),
    [anon_sym_POUNDELSE] = ACTIONS(12662),
    [anon_sym_POUNDElse] = ACTIONS(12662),
    [anon_sym_POUNDelse2] = ACTIONS(12662),
    [anon_sym_POUNDELSE2] = ACTIONS(12662),
    [anon_sym_POUNDElse2] = ACTIONS(12662),
    [anon_sym_POUNDendif] = ACTIONS(12662),
    [anon_sym_POUNDENDIF] = ACTIONS(12662),
    [anon_sym_POUNDEndif] = ACTIONS(12662),
    [anon_sym_POUNDendif2] = ACTIONS(12662),
    [anon_sym_POUNDENDIF2] = ACTIONS(12662),
    [anon_sym_POUNDEndif2] = ACTIONS(12662),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12662),
    [sym_trigger_keyword] = ACTIONS(12662),
    [sym_var_keyword] = ACTIONS(12662),
    [sym_local_keyword] = ACTIONS(12662),
    [sym_internal_keyword] = ACTIONS(12662),
    [sym_protected_keyword] = ACTIONS(12662),
    [sym_event_keyword] = ACTIONS(12662),
    [sym_fields_keyword] = ACTIONS(12662),
    [sym_keys_keyword] = ACTIONS(12662),
    [sym_fieldgroups_keyword] = ACTIONS(12662),
    [sym_actions_keyword] = ACTIONS(12662),
    [sym_layout_keyword] = ACTIONS(12662),
    [sym_area_keyword] = ACTIONS(12662),
    [sym_group_keyword] = ACTIONS(12662),
    [sym_repeater_keyword] = ACTIONS(12662),
    [sym_cuegroup_keyword] = ACTIONS(12662),
    [sym_fixed_keyword] = ACTIONS(12662),
    [sym_grid_keyword] = ACTIONS(12662),
    [sym_part_keyword] = ACTIONS(12662),
    [sym_systempart_keyword] = ACTIONS(12662),
    [sym_usercontrol_keyword] = ACTIONS(12662),
    [sym_dataset_keyword] = ACTIONS(12662),
    [sym_elements_keyword] = ACTIONS(12662),
    [sym_dataitem_keyword] = ACTIONS(12662),
    [sym_column_keyword] = ACTIONS(12662),
    [sym_filter_keyword] = ACTIONS(12662),
    [sym_labels_keyword] = ACTIONS(12662),
    [sym_rendering_keyword] = ACTIONS(12662),
    [sym_requestpage_keyword] = ACTIONS(12662),
    [sym_schema_keyword] = ACTIONS(12662),
    [sym_views_keyword] = ACTIONS(12662),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12662),
    [sym_preproc_open] = ACTIONS(12662),
    [sym_preproc_close] = ACTIONS(12662),
  },
  [STATE(5134)] = {
    [anon_sym_SEMI] = ACTIONS(12666),
    [aux_sym_where_condition_token1] = ACTIONS(12668),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12666),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12666),
    [anon_sym_LBRACK] = ACTIONS(12666),
    [aux_sym_basic_type_token6] = ACTIONS(12668),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12666),
    [aux_sym_addafter_modification_token1] = ACTIONS(12666),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12666),
    [aux_sym_modify_modification_token1] = ACTIONS(12666),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12666),
    [aux_sym_movelast_modification_token1] = ACTIONS(12666),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12666),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12666),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12666),
    [anon_sym_POUNDif] = ACTIONS(12666),
    [anon_sym_POUNDIF] = ACTIONS(12666),
    [anon_sym_POUNDIf] = ACTIONS(12666),
    [anon_sym_POUNDelif] = ACTIONS(12666),
    [anon_sym_POUNDELIF] = ACTIONS(12666),
    [anon_sym_POUNDElif] = ACTIONS(12666),
    [anon_sym_POUNDelse] = ACTIONS(12666),
    [anon_sym_POUNDELSE] = ACTIONS(12666),
    [anon_sym_POUNDElse] = ACTIONS(12666),
    [anon_sym_POUNDelse2] = ACTIONS(12666),
    [anon_sym_POUNDELSE2] = ACTIONS(12666),
    [anon_sym_POUNDElse2] = ACTIONS(12666),
    [anon_sym_POUNDendif] = ACTIONS(12666),
    [anon_sym_POUNDENDIF] = ACTIONS(12666),
    [anon_sym_POUNDEndif] = ACTIONS(12666),
    [anon_sym_POUNDendif2] = ACTIONS(12666),
    [anon_sym_POUNDENDIF2] = ACTIONS(12666),
    [anon_sym_POUNDEndif2] = ACTIONS(12666),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12666),
    [sym_trigger_keyword] = ACTIONS(12666),
    [sym_var_keyword] = ACTIONS(12666),
    [sym_local_keyword] = ACTIONS(12666),
    [sym_internal_keyword] = ACTIONS(12666),
    [sym_protected_keyword] = ACTIONS(12666),
    [sym_event_keyword] = ACTIONS(12666),
    [sym_fields_keyword] = ACTIONS(12666),
    [sym_keys_keyword] = ACTIONS(12666),
    [sym_fieldgroups_keyword] = ACTIONS(12666),
    [sym_actions_keyword] = ACTIONS(12666),
    [sym_layout_keyword] = ACTIONS(12666),
    [sym_area_keyword] = ACTIONS(12666),
    [sym_group_keyword] = ACTIONS(12666),
    [sym_repeater_keyword] = ACTIONS(12666),
    [sym_cuegroup_keyword] = ACTIONS(12666),
    [sym_fixed_keyword] = ACTIONS(12666),
    [sym_grid_keyword] = ACTIONS(12666),
    [sym_part_keyword] = ACTIONS(12666),
    [sym_systempart_keyword] = ACTIONS(12666),
    [sym_usercontrol_keyword] = ACTIONS(12666),
    [sym_dataset_keyword] = ACTIONS(12666),
    [sym_elements_keyword] = ACTIONS(12666),
    [sym_dataitem_keyword] = ACTIONS(12666),
    [sym_column_keyword] = ACTIONS(12666),
    [sym_filter_keyword] = ACTIONS(12666),
    [sym_labels_keyword] = ACTIONS(12666),
    [sym_rendering_keyword] = ACTIONS(12666),
    [sym_requestpage_keyword] = ACTIONS(12666),
    [sym_schema_keyword] = ACTIONS(12666),
    [sym_views_keyword] = ACTIONS(12666),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12666),
    [sym_preproc_open] = ACTIONS(12666),
    [sym_preproc_close] = ACTIONS(12666),
  },
  [STATE(5135)] = {
    [anon_sym_SEMI] = ACTIONS(12666),
    [aux_sym_where_condition_token1] = ACTIONS(12668),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12666),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12666),
    [anon_sym_LBRACK] = ACTIONS(12666),
    [aux_sym_basic_type_token6] = ACTIONS(12668),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12666),
    [aux_sym_addafter_modification_token1] = ACTIONS(12666),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12666),
    [aux_sym_modify_modification_token1] = ACTIONS(12666),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12666),
    [aux_sym_movelast_modification_token1] = ACTIONS(12666),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12666),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12666),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12666),
    [anon_sym_POUNDif] = ACTIONS(12666),
    [anon_sym_POUNDIF] = ACTIONS(12666),
    [anon_sym_POUNDIf] = ACTIONS(12666),
    [anon_sym_POUNDelif] = ACTIONS(12666),
    [anon_sym_POUNDELIF] = ACTIONS(12666),
    [anon_sym_POUNDElif] = ACTIONS(12666),
    [anon_sym_POUNDelse] = ACTIONS(12666),
    [anon_sym_POUNDELSE] = ACTIONS(12666),
    [anon_sym_POUNDElse] = ACTIONS(12666),
    [anon_sym_POUNDelse2] = ACTIONS(12666),
    [anon_sym_POUNDELSE2] = ACTIONS(12666),
    [anon_sym_POUNDElse2] = ACTIONS(12666),
    [anon_sym_POUNDendif] = ACTIONS(12666),
    [anon_sym_POUNDENDIF] = ACTIONS(12666),
    [anon_sym_POUNDEndif] = ACTIONS(12666),
    [anon_sym_POUNDendif2] = ACTIONS(12666),
    [anon_sym_POUNDENDIF2] = ACTIONS(12666),
    [anon_sym_POUNDEndif2] = ACTIONS(12666),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12666),
    [sym_trigger_keyword] = ACTIONS(12666),
    [sym_var_keyword] = ACTIONS(12666),
    [sym_local_keyword] = ACTIONS(12666),
    [sym_internal_keyword] = ACTIONS(12666),
    [sym_protected_keyword] = ACTIONS(12666),
    [sym_event_keyword] = ACTIONS(12666),
    [sym_fields_keyword] = ACTIONS(12666),
    [sym_keys_keyword] = ACTIONS(12666),
    [sym_fieldgroups_keyword] = ACTIONS(12666),
    [sym_actions_keyword] = ACTIONS(12666),
    [sym_layout_keyword] = ACTIONS(12666),
    [sym_area_keyword] = ACTIONS(12666),
    [sym_group_keyword] = ACTIONS(12666),
    [sym_repeater_keyword] = ACTIONS(12666),
    [sym_cuegroup_keyword] = ACTIONS(12666),
    [sym_fixed_keyword] = ACTIONS(12666),
    [sym_grid_keyword] = ACTIONS(12666),
    [sym_part_keyword] = ACTIONS(12666),
    [sym_systempart_keyword] = ACTIONS(12666),
    [sym_usercontrol_keyword] = ACTIONS(12666),
    [sym_dataset_keyword] = ACTIONS(12666),
    [sym_elements_keyword] = ACTIONS(12666),
    [sym_dataitem_keyword] = ACTIONS(12666),
    [sym_column_keyword] = ACTIONS(12666),
    [sym_filter_keyword] = ACTIONS(12666),
    [sym_labels_keyword] = ACTIONS(12666),
    [sym_rendering_keyword] = ACTIONS(12666),
    [sym_requestpage_keyword] = ACTIONS(12666),
    [sym_schema_keyword] = ACTIONS(12666),
    [sym_views_keyword] = ACTIONS(12666),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12666),
    [sym_preproc_open] = ACTIONS(12666),
    [sym_preproc_close] = ACTIONS(12666),
  },
  [STATE(5136)] = {
    [anon_sym_SEMI] = ACTIONS(12670),
    [aux_sym_where_condition_token1] = ACTIONS(12672),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12670),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12670),
    [anon_sym_LBRACK] = ACTIONS(12670),
    [aux_sym_basic_type_token6] = ACTIONS(12672),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12670),
    [aux_sym_addafter_modification_token1] = ACTIONS(12670),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12670),
    [aux_sym_modify_modification_token1] = ACTIONS(12670),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12670),
    [aux_sym_movelast_modification_token1] = ACTIONS(12670),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12670),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12670),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12670),
    [anon_sym_POUNDif] = ACTIONS(12670),
    [anon_sym_POUNDIF] = ACTIONS(12670),
    [anon_sym_POUNDIf] = ACTIONS(12670),
    [anon_sym_POUNDelif] = ACTIONS(12670),
    [anon_sym_POUNDELIF] = ACTIONS(12670),
    [anon_sym_POUNDElif] = ACTIONS(12670),
    [anon_sym_POUNDelse] = ACTIONS(12670),
    [anon_sym_POUNDELSE] = ACTIONS(12670),
    [anon_sym_POUNDElse] = ACTIONS(12670),
    [anon_sym_POUNDelse2] = ACTIONS(12670),
    [anon_sym_POUNDELSE2] = ACTIONS(12670),
    [anon_sym_POUNDElse2] = ACTIONS(12670),
    [anon_sym_POUNDendif] = ACTIONS(12670),
    [anon_sym_POUNDENDIF] = ACTIONS(12670),
    [anon_sym_POUNDEndif] = ACTIONS(12670),
    [anon_sym_POUNDendif2] = ACTIONS(12670),
    [anon_sym_POUNDENDIF2] = ACTIONS(12670),
    [anon_sym_POUNDEndif2] = ACTIONS(12670),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12670),
    [sym_trigger_keyword] = ACTIONS(12670),
    [sym_var_keyword] = ACTIONS(12670),
    [sym_local_keyword] = ACTIONS(12670),
    [sym_internal_keyword] = ACTIONS(12670),
    [sym_protected_keyword] = ACTIONS(12670),
    [sym_event_keyword] = ACTIONS(12670),
    [sym_fields_keyword] = ACTIONS(12670),
    [sym_keys_keyword] = ACTIONS(12670),
    [sym_fieldgroups_keyword] = ACTIONS(12670),
    [sym_actions_keyword] = ACTIONS(12670),
    [sym_layout_keyword] = ACTIONS(12670),
    [sym_area_keyword] = ACTIONS(12670),
    [sym_group_keyword] = ACTIONS(12670),
    [sym_repeater_keyword] = ACTIONS(12670),
    [sym_cuegroup_keyword] = ACTIONS(12670),
    [sym_fixed_keyword] = ACTIONS(12670),
    [sym_grid_keyword] = ACTIONS(12670),
    [sym_part_keyword] = ACTIONS(12670),
    [sym_systempart_keyword] = ACTIONS(12670),
    [sym_usercontrol_keyword] = ACTIONS(12670),
    [sym_dataset_keyword] = ACTIONS(12670),
    [sym_elements_keyword] = ACTIONS(12670),
    [sym_dataitem_keyword] = ACTIONS(12670),
    [sym_column_keyword] = ACTIONS(12670),
    [sym_filter_keyword] = ACTIONS(12670),
    [sym_labels_keyword] = ACTIONS(12670),
    [sym_rendering_keyword] = ACTIONS(12670),
    [sym_requestpage_keyword] = ACTIONS(12670),
    [sym_schema_keyword] = ACTIONS(12670),
    [sym_views_keyword] = ACTIONS(12670),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12670),
    [sym_preproc_open] = ACTIONS(12670),
    [sym_preproc_close] = ACTIONS(12670),
  },
  [STATE(5137)] = {
    [anon_sym_SEMI] = ACTIONS(12670),
    [aux_sym_where_condition_token1] = ACTIONS(12672),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12670),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12670),
    [anon_sym_LBRACK] = ACTIONS(12670),
    [aux_sym_basic_type_token6] = ACTIONS(12672),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12670),
    [aux_sym_addafter_modification_token1] = ACTIONS(12670),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12670),
    [aux_sym_modify_modification_token1] = ACTIONS(12670),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12670),
    [aux_sym_movelast_modification_token1] = ACTIONS(12670),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12670),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12670),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12670),
    [anon_sym_POUNDif] = ACTIONS(12670),
    [anon_sym_POUNDIF] = ACTIONS(12670),
    [anon_sym_POUNDIf] = ACTIONS(12670),
    [anon_sym_POUNDelif] = ACTIONS(12670),
    [anon_sym_POUNDELIF] = ACTIONS(12670),
    [anon_sym_POUNDElif] = ACTIONS(12670),
    [anon_sym_POUNDelse] = ACTIONS(12670),
    [anon_sym_POUNDELSE] = ACTIONS(12670),
    [anon_sym_POUNDElse] = ACTIONS(12670),
    [anon_sym_POUNDelse2] = ACTIONS(12670),
    [anon_sym_POUNDELSE2] = ACTIONS(12670),
    [anon_sym_POUNDElse2] = ACTIONS(12670),
    [anon_sym_POUNDendif] = ACTIONS(12670),
    [anon_sym_POUNDENDIF] = ACTIONS(12670),
    [anon_sym_POUNDEndif] = ACTIONS(12670),
    [anon_sym_POUNDendif2] = ACTIONS(12670),
    [anon_sym_POUNDENDIF2] = ACTIONS(12670),
    [anon_sym_POUNDEndif2] = ACTIONS(12670),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12670),
    [sym_trigger_keyword] = ACTIONS(12670),
    [sym_var_keyword] = ACTIONS(12670),
    [sym_local_keyword] = ACTIONS(12670),
    [sym_internal_keyword] = ACTIONS(12670),
    [sym_protected_keyword] = ACTIONS(12670),
    [sym_event_keyword] = ACTIONS(12670),
    [sym_fields_keyword] = ACTIONS(12670),
    [sym_keys_keyword] = ACTIONS(12670),
    [sym_fieldgroups_keyword] = ACTIONS(12670),
    [sym_actions_keyword] = ACTIONS(12670),
    [sym_layout_keyword] = ACTIONS(12670),
    [sym_area_keyword] = ACTIONS(12670),
    [sym_group_keyword] = ACTIONS(12670),
    [sym_repeater_keyword] = ACTIONS(12670),
    [sym_cuegroup_keyword] = ACTIONS(12670),
    [sym_fixed_keyword] = ACTIONS(12670),
    [sym_grid_keyword] = ACTIONS(12670),
    [sym_part_keyword] = ACTIONS(12670),
    [sym_systempart_keyword] = ACTIONS(12670),
    [sym_usercontrol_keyword] = ACTIONS(12670),
    [sym_dataset_keyword] = ACTIONS(12670),
    [sym_elements_keyword] = ACTIONS(12670),
    [sym_dataitem_keyword] = ACTIONS(12670),
    [sym_column_keyword] = ACTIONS(12670),
    [sym_filter_keyword] = ACTIONS(12670),
    [sym_labels_keyword] = ACTIONS(12670),
    [sym_rendering_keyword] = ACTIONS(12670),
    [sym_requestpage_keyword] = ACTIONS(12670),
    [sym_schema_keyword] = ACTIONS(12670),
    [sym_views_keyword] = ACTIONS(12670),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12670),
    [sym_preproc_open] = ACTIONS(12670),
    [sym_preproc_close] = ACTIONS(12670),
  },
  [STATE(5138)] = {
    [anon_sym_SEMI] = ACTIONS(12674),
    [aux_sym_where_condition_token1] = ACTIONS(12676),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12678),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12678),
    [anon_sym_LBRACK] = ACTIONS(12678),
    [aux_sym_basic_type_token6] = ACTIONS(12676),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12678),
    [aux_sym_addafter_modification_token1] = ACTIONS(12678),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12678),
    [aux_sym_modify_modification_token1] = ACTIONS(12678),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12678),
    [aux_sym_movelast_modification_token1] = ACTIONS(12678),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12678),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12678),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12678),
    [anon_sym_POUNDif] = ACTIONS(12678),
    [anon_sym_POUNDIF] = ACTIONS(12678),
    [anon_sym_POUNDIf] = ACTIONS(12678),
    [anon_sym_POUNDelif] = ACTIONS(12678),
    [anon_sym_POUNDELIF] = ACTIONS(12678),
    [anon_sym_POUNDElif] = ACTIONS(12678),
    [anon_sym_POUNDelse] = ACTIONS(12678),
    [anon_sym_POUNDELSE] = ACTIONS(12678),
    [anon_sym_POUNDElse] = ACTIONS(12678),
    [anon_sym_POUNDelse2] = ACTIONS(12678),
    [anon_sym_POUNDELSE2] = ACTIONS(12678),
    [anon_sym_POUNDElse2] = ACTIONS(12678),
    [anon_sym_POUNDendif] = ACTIONS(12678),
    [anon_sym_POUNDENDIF] = ACTIONS(12678),
    [anon_sym_POUNDEndif] = ACTIONS(12678),
    [anon_sym_POUNDendif2] = ACTIONS(12678),
    [anon_sym_POUNDENDIF2] = ACTIONS(12678),
    [anon_sym_POUNDEndif2] = ACTIONS(12678),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12678),
    [sym_trigger_keyword] = ACTIONS(12678),
    [sym_var_keyword] = ACTIONS(12678),
    [sym_local_keyword] = ACTIONS(12678),
    [sym_internal_keyword] = ACTIONS(12678),
    [sym_protected_keyword] = ACTIONS(12678),
    [sym_event_keyword] = ACTIONS(12678),
    [sym_fields_keyword] = ACTIONS(12678),
    [sym_keys_keyword] = ACTIONS(12678),
    [sym_fieldgroups_keyword] = ACTIONS(12678),
    [sym_actions_keyword] = ACTIONS(12678),
    [sym_layout_keyword] = ACTIONS(12678),
    [sym_area_keyword] = ACTIONS(12678),
    [sym_group_keyword] = ACTIONS(12678),
    [sym_repeater_keyword] = ACTIONS(12678),
    [sym_cuegroup_keyword] = ACTIONS(12678),
    [sym_fixed_keyword] = ACTIONS(12678),
    [sym_grid_keyword] = ACTIONS(12678),
    [sym_part_keyword] = ACTIONS(12678),
    [sym_systempart_keyword] = ACTIONS(12678),
    [sym_usercontrol_keyword] = ACTIONS(12678),
    [sym_dataset_keyword] = ACTIONS(12678),
    [sym_elements_keyword] = ACTIONS(12678),
    [sym_dataitem_keyword] = ACTIONS(12678),
    [sym_column_keyword] = ACTIONS(12678),
    [sym_filter_keyword] = ACTIONS(12678),
    [sym_labels_keyword] = ACTIONS(12678),
    [sym_rendering_keyword] = ACTIONS(12678),
    [sym_requestpage_keyword] = ACTIONS(12678),
    [sym_schema_keyword] = ACTIONS(12678),
    [sym_views_keyword] = ACTIONS(12678),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12678),
    [sym_preproc_open] = ACTIONS(12678),
    [sym_preproc_close] = ACTIONS(12678),
  },
  [STATE(5139)] = {
    [anon_sym_SEMI] = ACTIONS(12680),
    [aux_sym_where_condition_token1] = ACTIONS(12676),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12678),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12678),
    [anon_sym_LBRACK] = ACTIONS(12678),
    [aux_sym_basic_type_token6] = ACTIONS(12676),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12678),
    [aux_sym_addafter_modification_token1] = ACTIONS(12678),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12678),
    [aux_sym_modify_modification_token1] = ACTIONS(12678),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12678),
    [aux_sym_movelast_modification_token1] = ACTIONS(12678),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12678),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12678),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12678),
    [anon_sym_POUNDif] = ACTIONS(12678),
    [anon_sym_POUNDIF] = ACTIONS(12678),
    [anon_sym_POUNDIf] = ACTIONS(12678),
    [anon_sym_POUNDelif] = ACTIONS(12678),
    [anon_sym_POUNDELIF] = ACTIONS(12678),
    [anon_sym_POUNDElif] = ACTIONS(12678),
    [anon_sym_POUNDelse] = ACTIONS(12678),
    [anon_sym_POUNDELSE] = ACTIONS(12678),
    [anon_sym_POUNDElse] = ACTIONS(12678),
    [anon_sym_POUNDelse2] = ACTIONS(12678),
    [anon_sym_POUNDELSE2] = ACTIONS(12678),
    [anon_sym_POUNDElse2] = ACTIONS(12678),
    [anon_sym_POUNDendif] = ACTIONS(12678),
    [anon_sym_POUNDENDIF] = ACTIONS(12678),
    [anon_sym_POUNDEndif] = ACTIONS(12678),
    [anon_sym_POUNDendif2] = ACTIONS(12678),
    [anon_sym_POUNDENDIF2] = ACTIONS(12678),
    [anon_sym_POUNDEndif2] = ACTIONS(12678),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12678),
    [sym_trigger_keyword] = ACTIONS(12678),
    [sym_var_keyword] = ACTIONS(12678),
    [sym_local_keyword] = ACTIONS(12678),
    [sym_internal_keyword] = ACTIONS(12678),
    [sym_protected_keyword] = ACTIONS(12678),
    [sym_event_keyword] = ACTIONS(12678),
    [sym_fields_keyword] = ACTIONS(12678),
    [sym_keys_keyword] = ACTIONS(12678),
    [sym_fieldgroups_keyword] = ACTIONS(12678),
    [sym_actions_keyword] = ACTIONS(12678),
    [sym_layout_keyword] = ACTIONS(12678),
    [sym_area_keyword] = ACTIONS(12678),
    [sym_group_keyword] = ACTIONS(12678),
    [sym_repeater_keyword] = ACTIONS(12678),
    [sym_cuegroup_keyword] = ACTIONS(12678),
    [sym_fixed_keyword] = ACTIONS(12678),
    [sym_grid_keyword] = ACTIONS(12678),
    [sym_part_keyword] = ACTIONS(12678),
    [sym_systempart_keyword] = ACTIONS(12678),
    [sym_usercontrol_keyword] = ACTIONS(12678),
    [sym_dataset_keyword] = ACTIONS(12678),
    [sym_elements_keyword] = ACTIONS(12678),
    [sym_dataitem_keyword] = ACTIONS(12678),
    [sym_column_keyword] = ACTIONS(12678),
    [sym_filter_keyword] = ACTIONS(12678),
    [sym_labels_keyword] = ACTIONS(12678),
    [sym_rendering_keyword] = ACTIONS(12678),
    [sym_requestpage_keyword] = ACTIONS(12678),
    [sym_schema_keyword] = ACTIONS(12678),
    [sym_views_keyword] = ACTIONS(12678),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12678),
    [sym_preproc_open] = ACTIONS(12678),
    [sym_preproc_close] = ACTIONS(12678),
  },
  [STATE(5140)] = {
    [anon_sym_SEMI] = ACTIONS(12682),
    [aux_sym_where_condition_token1] = ACTIONS(12684),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12682),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12682),
    [anon_sym_LBRACK] = ACTIONS(12682),
    [aux_sym_basic_type_token6] = ACTIONS(12684),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12682),
    [aux_sym_addafter_modification_token1] = ACTIONS(12682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12682),
    [aux_sym_modify_modification_token1] = ACTIONS(12682),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12682),
    [aux_sym_movelast_modification_token1] = ACTIONS(12682),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12682),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12682),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12682),
    [anon_sym_POUNDif] = ACTIONS(12682),
    [anon_sym_POUNDIF] = ACTIONS(12682),
    [anon_sym_POUNDIf] = ACTIONS(12682),
    [anon_sym_POUNDelif] = ACTIONS(12682),
    [anon_sym_POUNDELIF] = ACTIONS(12682),
    [anon_sym_POUNDElif] = ACTIONS(12682),
    [anon_sym_POUNDelse] = ACTIONS(12682),
    [anon_sym_POUNDELSE] = ACTIONS(12682),
    [anon_sym_POUNDElse] = ACTIONS(12682),
    [anon_sym_POUNDelse2] = ACTIONS(12682),
    [anon_sym_POUNDELSE2] = ACTIONS(12682),
    [anon_sym_POUNDElse2] = ACTIONS(12682),
    [anon_sym_POUNDendif] = ACTIONS(12682),
    [anon_sym_POUNDENDIF] = ACTIONS(12682),
    [anon_sym_POUNDEndif] = ACTIONS(12682),
    [anon_sym_POUNDendif2] = ACTIONS(12682),
    [anon_sym_POUNDENDIF2] = ACTIONS(12682),
    [anon_sym_POUNDEndif2] = ACTIONS(12682),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12682),
    [sym_trigger_keyword] = ACTIONS(12682),
    [sym_var_keyword] = ACTIONS(12682),
    [sym_local_keyword] = ACTIONS(12682),
    [sym_internal_keyword] = ACTIONS(12682),
    [sym_protected_keyword] = ACTIONS(12682),
    [sym_event_keyword] = ACTIONS(12682),
    [sym_fields_keyword] = ACTIONS(12682),
    [sym_keys_keyword] = ACTIONS(12682),
    [sym_fieldgroups_keyword] = ACTIONS(12682),
    [sym_actions_keyword] = ACTIONS(12682),
    [sym_layout_keyword] = ACTIONS(12682),
    [sym_area_keyword] = ACTIONS(12682),
    [sym_group_keyword] = ACTIONS(12682),
    [sym_repeater_keyword] = ACTIONS(12682),
    [sym_cuegroup_keyword] = ACTIONS(12682),
    [sym_fixed_keyword] = ACTIONS(12682),
    [sym_grid_keyword] = ACTIONS(12682),
    [sym_part_keyword] = ACTIONS(12682),
    [sym_systempart_keyword] = ACTIONS(12682),
    [sym_usercontrol_keyword] = ACTIONS(12682),
    [sym_dataset_keyword] = ACTIONS(12682),
    [sym_elements_keyword] = ACTIONS(12682),
    [sym_dataitem_keyword] = ACTIONS(12682),
    [sym_column_keyword] = ACTIONS(12682),
    [sym_filter_keyword] = ACTIONS(12682),
    [sym_labels_keyword] = ACTIONS(12682),
    [sym_rendering_keyword] = ACTIONS(12682),
    [sym_requestpage_keyword] = ACTIONS(12682),
    [sym_schema_keyword] = ACTIONS(12682),
    [sym_views_keyword] = ACTIONS(12682),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12682),
    [sym_preproc_open] = ACTIONS(12682),
    [sym_preproc_close] = ACTIONS(12682),
  },
  [STATE(5141)] = {
    [anon_sym_SEMI] = ACTIONS(12682),
    [aux_sym_where_condition_token1] = ACTIONS(12684),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12682),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12682),
    [anon_sym_LBRACK] = ACTIONS(12682),
    [aux_sym_basic_type_token6] = ACTIONS(12684),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12682),
    [aux_sym_addafter_modification_token1] = ACTIONS(12682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12682),
    [aux_sym_modify_modification_token1] = ACTIONS(12682),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12682),
    [aux_sym_movelast_modification_token1] = ACTIONS(12682),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12682),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12682),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12682),
    [anon_sym_POUNDif] = ACTIONS(12682),
    [anon_sym_POUNDIF] = ACTIONS(12682),
    [anon_sym_POUNDIf] = ACTIONS(12682),
    [anon_sym_POUNDelif] = ACTIONS(12682),
    [anon_sym_POUNDELIF] = ACTIONS(12682),
    [anon_sym_POUNDElif] = ACTIONS(12682),
    [anon_sym_POUNDelse] = ACTIONS(12682),
    [anon_sym_POUNDELSE] = ACTIONS(12682),
    [anon_sym_POUNDElse] = ACTIONS(12682),
    [anon_sym_POUNDelse2] = ACTIONS(12682),
    [anon_sym_POUNDELSE2] = ACTIONS(12682),
    [anon_sym_POUNDElse2] = ACTIONS(12682),
    [anon_sym_POUNDendif] = ACTIONS(12682),
    [anon_sym_POUNDENDIF] = ACTIONS(12682),
    [anon_sym_POUNDEndif] = ACTIONS(12682),
    [anon_sym_POUNDendif2] = ACTIONS(12682),
    [anon_sym_POUNDENDIF2] = ACTIONS(12682),
    [anon_sym_POUNDEndif2] = ACTIONS(12682),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12682),
    [sym_trigger_keyword] = ACTIONS(12682),
    [sym_var_keyword] = ACTIONS(12682),
    [sym_local_keyword] = ACTIONS(12682),
    [sym_internal_keyword] = ACTIONS(12682),
    [sym_protected_keyword] = ACTIONS(12682),
    [sym_event_keyword] = ACTIONS(12682),
    [sym_fields_keyword] = ACTIONS(12682),
    [sym_keys_keyword] = ACTIONS(12682),
    [sym_fieldgroups_keyword] = ACTIONS(12682),
    [sym_actions_keyword] = ACTIONS(12682),
    [sym_layout_keyword] = ACTIONS(12682),
    [sym_area_keyword] = ACTIONS(12682),
    [sym_group_keyword] = ACTIONS(12682),
    [sym_repeater_keyword] = ACTIONS(12682),
    [sym_cuegroup_keyword] = ACTIONS(12682),
    [sym_fixed_keyword] = ACTIONS(12682),
    [sym_grid_keyword] = ACTIONS(12682),
    [sym_part_keyword] = ACTIONS(12682),
    [sym_systempart_keyword] = ACTIONS(12682),
    [sym_usercontrol_keyword] = ACTIONS(12682),
    [sym_dataset_keyword] = ACTIONS(12682),
    [sym_elements_keyword] = ACTIONS(12682),
    [sym_dataitem_keyword] = ACTIONS(12682),
    [sym_column_keyword] = ACTIONS(12682),
    [sym_filter_keyword] = ACTIONS(12682),
    [sym_labels_keyword] = ACTIONS(12682),
    [sym_rendering_keyword] = ACTIONS(12682),
    [sym_requestpage_keyword] = ACTIONS(12682),
    [sym_schema_keyword] = ACTIONS(12682),
    [sym_views_keyword] = ACTIONS(12682),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12682),
    [sym_preproc_open] = ACTIONS(12682),
    [sym_preproc_close] = ACTIONS(12682),
  },
  [STATE(5142)] = {
    [anon_sym_SEMI] = ACTIONS(12686),
    [aux_sym_where_condition_token1] = ACTIONS(12688),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12690),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12690),
    [anon_sym_LBRACK] = ACTIONS(12690),
    [aux_sym_basic_type_token6] = ACTIONS(12688),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12690),
    [aux_sym_addafter_modification_token1] = ACTIONS(12690),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12690),
    [aux_sym_modify_modification_token1] = ACTIONS(12690),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12690),
    [aux_sym_movelast_modification_token1] = ACTIONS(12690),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12690),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12690),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12690),
    [anon_sym_POUNDif] = ACTIONS(12690),
    [anon_sym_POUNDIF] = ACTIONS(12690),
    [anon_sym_POUNDIf] = ACTIONS(12690),
    [anon_sym_POUNDelif] = ACTIONS(12690),
    [anon_sym_POUNDELIF] = ACTIONS(12690),
    [anon_sym_POUNDElif] = ACTIONS(12690),
    [anon_sym_POUNDelse] = ACTIONS(12690),
    [anon_sym_POUNDELSE] = ACTIONS(12690),
    [anon_sym_POUNDElse] = ACTIONS(12690),
    [anon_sym_POUNDelse2] = ACTIONS(12690),
    [anon_sym_POUNDELSE2] = ACTIONS(12690),
    [anon_sym_POUNDElse2] = ACTIONS(12690),
    [anon_sym_POUNDendif] = ACTIONS(12690),
    [anon_sym_POUNDENDIF] = ACTIONS(12690),
    [anon_sym_POUNDEndif] = ACTIONS(12690),
    [anon_sym_POUNDendif2] = ACTIONS(12690),
    [anon_sym_POUNDENDIF2] = ACTIONS(12690),
    [anon_sym_POUNDEndif2] = ACTIONS(12690),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12690),
    [sym_trigger_keyword] = ACTIONS(12690),
    [sym_var_keyword] = ACTIONS(12690),
    [sym_local_keyword] = ACTIONS(12690),
    [sym_internal_keyword] = ACTIONS(12690),
    [sym_protected_keyword] = ACTIONS(12690),
    [sym_event_keyword] = ACTIONS(12690),
    [sym_fields_keyword] = ACTIONS(12690),
    [sym_keys_keyword] = ACTIONS(12690),
    [sym_fieldgroups_keyword] = ACTIONS(12690),
    [sym_actions_keyword] = ACTIONS(12690),
    [sym_layout_keyword] = ACTIONS(12690),
    [sym_area_keyword] = ACTIONS(12690),
    [sym_group_keyword] = ACTIONS(12690),
    [sym_repeater_keyword] = ACTIONS(12690),
    [sym_cuegroup_keyword] = ACTIONS(12690),
    [sym_fixed_keyword] = ACTIONS(12690),
    [sym_grid_keyword] = ACTIONS(12690),
    [sym_part_keyword] = ACTIONS(12690),
    [sym_systempart_keyword] = ACTIONS(12690),
    [sym_usercontrol_keyword] = ACTIONS(12690),
    [sym_dataset_keyword] = ACTIONS(12690),
    [sym_elements_keyword] = ACTIONS(12690),
    [sym_dataitem_keyword] = ACTIONS(12690),
    [sym_column_keyword] = ACTIONS(12690),
    [sym_filter_keyword] = ACTIONS(12690),
    [sym_labels_keyword] = ACTIONS(12690),
    [sym_rendering_keyword] = ACTIONS(12690),
    [sym_requestpage_keyword] = ACTIONS(12690),
    [sym_schema_keyword] = ACTIONS(12690),
    [sym_views_keyword] = ACTIONS(12690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12690),
    [sym_preproc_open] = ACTIONS(12690),
    [sym_preproc_close] = ACTIONS(12690),
  },
  [STATE(5143)] = {
    [anon_sym_SEMI] = ACTIONS(12692),
    [aux_sym_where_condition_token1] = ACTIONS(12688),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12690),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12690),
    [anon_sym_LBRACK] = ACTIONS(12690),
    [aux_sym_basic_type_token6] = ACTIONS(12688),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12690),
    [aux_sym_addafter_modification_token1] = ACTIONS(12690),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12690),
    [aux_sym_modify_modification_token1] = ACTIONS(12690),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12690),
    [aux_sym_movelast_modification_token1] = ACTIONS(12690),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12690),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12690),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12690),
    [anon_sym_POUNDif] = ACTIONS(12690),
    [anon_sym_POUNDIF] = ACTIONS(12690),
    [anon_sym_POUNDIf] = ACTIONS(12690),
    [anon_sym_POUNDelif] = ACTIONS(12690),
    [anon_sym_POUNDELIF] = ACTIONS(12690),
    [anon_sym_POUNDElif] = ACTIONS(12690),
    [anon_sym_POUNDelse] = ACTIONS(12690),
    [anon_sym_POUNDELSE] = ACTIONS(12690),
    [anon_sym_POUNDElse] = ACTIONS(12690),
    [anon_sym_POUNDelse2] = ACTIONS(12690),
    [anon_sym_POUNDELSE2] = ACTIONS(12690),
    [anon_sym_POUNDElse2] = ACTIONS(12690),
    [anon_sym_POUNDendif] = ACTIONS(12690),
    [anon_sym_POUNDENDIF] = ACTIONS(12690),
    [anon_sym_POUNDEndif] = ACTIONS(12690),
    [anon_sym_POUNDendif2] = ACTIONS(12690),
    [anon_sym_POUNDENDIF2] = ACTIONS(12690),
    [anon_sym_POUNDEndif2] = ACTIONS(12690),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12690),
    [sym_trigger_keyword] = ACTIONS(12690),
    [sym_var_keyword] = ACTIONS(12690),
    [sym_local_keyword] = ACTIONS(12690),
    [sym_internal_keyword] = ACTIONS(12690),
    [sym_protected_keyword] = ACTIONS(12690),
    [sym_event_keyword] = ACTIONS(12690),
    [sym_fields_keyword] = ACTIONS(12690),
    [sym_keys_keyword] = ACTIONS(12690),
    [sym_fieldgroups_keyword] = ACTIONS(12690),
    [sym_actions_keyword] = ACTIONS(12690),
    [sym_layout_keyword] = ACTIONS(12690),
    [sym_area_keyword] = ACTIONS(12690),
    [sym_group_keyword] = ACTIONS(12690),
    [sym_repeater_keyword] = ACTIONS(12690),
    [sym_cuegroup_keyword] = ACTIONS(12690),
    [sym_fixed_keyword] = ACTIONS(12690),
    [sym_grid_keyword] = ACTIONS(12690),
    [sym_part_keyword] = ACTIONS(12690),
    [sym_systempart_keyword] = ACTIONS(12690),
    [sym_usercontrol_keyword] = ACTIONS(12690),
    [sym_dataset_keyword] = ACTIONS(12690),
    [sym_elements_keyword] = ACTIONS(12690),
    [sym_dataitem_keyword] = ACTIONS(12690),
    [sym_column_keyword] = ACTIONS(12690),
    [sym_filter_keyword] = ACTIONS(12690),
    [sym_labels_keyword] = ACTIONS(12690),
    [sym_rendering_keyword] = ACTIONS(12690),
    [sym_requestpage_keyword] = ACTIONS(12690),
    [sym_schema_keyword] = ACTIONS(12690),
    [sym_views_keyword] = ACTIONS(12690),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12690),
    [sym_preproc_open] = ACTIONS(12690),
    [sym_preproc_close] = ACTIONS(12690),
  },
  [STATE(5144)] = {
    [anon_sym_SEMI] = ACTIONS(12694),
    [aux_sym_where_condition_token1] = ACTIONS(12684),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12682),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12682),
    [anon_sym_LBRACK] = ACTIONS(12682),
    [aux_sym_basic_type_token6] = ACTIONS(12684),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12682),
    [aux_sym_addafter_modification_token1] = ACTIONS(12682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12682),
    [aux_sym_modify_modification_token1] = ACTIONS(12682),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12682),
    [aux_sym_movelast_modification_token1] = ACTIONS(12682),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12682),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12682),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12682),
    [anon_sym_POUNDif] = ACTIONS(12682),
    [anon_sym_POUNDIF] = ACTIONS(12682),
    [anon_sym_POUNDIf] = ACTIONS(12682),
    [anon_sym_POUNDelif] = ACTIONS(12682),
    [anon_sym_POUNDELIF] = ACTIONS(12682),
    [anon_sym_POUNDElif] = ACTIONS(12682),
    [anon_sym_POUNDelse] = ACTIONS(12682),
    [anon_sym_POUNDELSE] = ACTIONS(12682),
    [anon_sym_POUNDElse] = ACTIONS(12682),
    [anon_sym_POUNDelse2] = ACTIONS(12682),
    [anon_sym_POUNDELSE2] = ACTIONS(12682),
    [anon_sym_POUNDElse2] = ACTIONS(12682),
    [anon_sym_POUNDendif] = ACTIONS(12682),
    [anon_sym_POUNDENDIF] = ACTIONS(12682),
    [anon_sym_POUNDEndif] = ACTIONS(12682),
    [anon_sym_POUNDendif2] = ACTIONS(12682),
    [anon_sym_POUNDENDIF2] = ACTIONS(12682),
    [anon_sym_POUNDEndif2] = ACTIONS(12682),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12682),
    [sym_trigger_keyword] = ACTIONS(12682),
    [sym_var_keyword] = ACTIONS(12682),
    [sym_local_keyword] = ACTIONS(12682),
    [sym_internal_keyword] = ACTIONS(12682),
    [sym_protected_keyword] = ACTIONS(12682),
    [sym_event_keyword] = ACTIONS(12682),
    [sym_fields_keyword] = ACTIONS(12682),
    [sym_keys_keyword] = ACTIONS(12682),
    [sym_fieldgroups_keyword] = ACTIONS(12682),
    [sym_actions_keyword] = ACTIONS(12682),
    [sym_layout_keyword] = ACTIONS(12682),
    [sym_area_keyword] = ACTIONS(12682),
    [sym_group_keyword] = ACTIONS(12682),
    [sym_repeater_keyword] = ACTIONS(12682),
    [sym_cuegroup_keyword] = ACTIONS(12682),
    [sym_fixed_keyword] = ACTIONS(12682),
    [sym_grid_keyword] = ACTIONS(12682),
    [sym_part_keyword] = ACTIONS(12682),
    [sym_systempart_keyword] = ACTIONS(12682),
    [sym_usercontrol_keyword] = ACTIONS(12682),
    [sym_dataset_keyword] = ACTIONS(12682),
    [sym_elements_keyword] = ACTIONS(12682),
    [sym_dataitem_keyword] = ACTIONS(12682),
    [sym_column_keyword] = ACTIONS(12682),
    [sym_filter_keyword] = ACTIONS(12682),
    [sym_labels_keyword] = ACTIONS(12682),
    [sym_rendering_keyword] = ACTIONS(12682),
    [sym_requestpage_keyword] = ACTIONS(12682),
    [sym_schema_keyword] = ACTIONS(12682),
    [sym_views_keyword] = ACTIONS(12682),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12682),
    [sym_preproc_open] = ACTIONS(12682),
    [sym_preproc_close] = ACTIONS(12682),
  },
  [STATE(5145)] = {
    [anon_sym_SEMI] = ACTIONS(12696),
    [aux_sym_where_condition_token1] = ACTIONS(12684),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12682),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12682),
    [anon_sym_LBRACK] = ACTIONS(12682),
    [aux_sym_basic_type_token6] = ACTIONS(12684),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12682),
    [aux_sym_addafter_modification_token1] = ACTIONS(12682),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12682),
    [aux_sym_modify_modification_token1] = ACTIONS(12682),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12682),
    [aux_sym_movelast_modification_token1] = ACTIONS(12682),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12682),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12682),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12682),
    [anon_sym_POUNDif] = ACTIONS(12682),
    [anon_sym_POUNDIF] = ACTIONS(12682),
    [anon_sym_POUNDIf] = ACTIONS(12682),
    [anon_sym_POUNDelif] = ACTIONS(12682),
    [anon_sym_POUNDELIF] = ACTIONS(12682),
    [anon_sym_POUNDElif] = ACTIONS(12682),
    [anon_sym_POUNDelse] = ACTIONS(12682),
    [anon_sym_POUNDELSE] = ACTIONS(12682),
    [anon_sym_POUNDElse] = ACTIONS(12682),
    [anon_sym_POUNDelse2] = ACTIONS(12682),
    [anon_sym_POUNDELSE2] = ACTIONS(12682),
    [anon_sym_POUNDElse2] = ACTIONS(12682),
    [anon_sym_POUNDendif] = ACTIONS(12682),
    [anon_sym_POUNDENDIF] = ACTIONS(12682),
    [anon_sym_POUNDEndif] = ACTIONS(12682),
    [anon_sym_POUNDendif2] = ACTIONS(12682),
    [anon_sym_POUNDENDIF2] = ACTIONS(12682),
    [anon_sym_POUNDEndif2] = ACTIONS(12682),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12682),
    [sym_trigger_keyword] = ACTIONS(12682),
    [sym_var_keyword] = ACTIONS(12682),
    [sym_local_keyword] = ACTIONS(12682),
    [sym_internal_keyword] = ACTIONS(12682),
    [sym_protected_keyword] = ACTIONS(12682),
    [sym_event_keyword] = ACTIONS(12682),
    [sym_fields_keyword] = ACTIONS(12682),
    [sym_keys_keyword] = ACTIONS(12682),
    [sym_fieldgroups_keyword] = ACTIONS(12682),
    [sym_actions_keyword] = ACTIONS(12682),
    [sym_layout_keyword] = ACTIONS(12682),
    [sym_area_keyword] = ACTIONS(12682),
    [sym_group_keyword] = ACTIONS(12682),
    [sym_repeater_keyword] = ACTIONS(12682),
    [sym_cuegroup_keyword] = ACTIONS(12682),
    [sym_fixed_keyword] = ACTIONS(12682),
    [sym_grid_keyword] = ACTIONS(12682),
    [sym_part_keyword] = ACTIONS(12682),
    [sym_systempart_keyword] = ACTIONS(12682),
    [sym_usercontrol_keyword] = ACTIONS(12682),
    [sym_dataset_keyword] = ACTIONS(12682),
    [sym_elements_keyword] = ACTIONS(12682),
    [sym_dataitem_keyword] = ACTIONS(12682),
    [sym_column_keyword] = ACTIONS(12682),
    [sym_filter_keyword] = ACTIONS(12682),
    [sym_labels_keyword] = ACTIONS(12682),
    [sym_rendering_keyword] = ACTIONS(12682),
    [sym_requestpage_keyword] = ACTIONS(12682),
    [sym_schema_keyword] = ACTIONS(12682),
    [sym_views_keyword] = ACTIONS(12682),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12682),
    [sym_preproc_open] = ACTIONS(12682),
    [sym_preproc_close] = ACTIONS(12682),
  },
  [STATE(5146)] = {
    [anon_sym_SEMI] = ACTIONS(12618),
    [aux_sym_where_condition_token1] = ACTIONS(12620),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12618),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12618),
    [anon_sym_LBRACK] = ACTIONS(12618),
    [aux_sym_basic_type_token6] = ACTIONS(12620),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12618),
    [aux_sym_addafter_modification_token1] = ACTIONS(12618),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12618),
    [aux_sym_modify_modification_token1] = ACTIONS(12618),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12618),
    [aux_sym_movelast_modification_token1] = ACTIONS(12618),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12618),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12618),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12618),
    [anon_sym_POUNDif] = ACTIONS(12618),
    [anon_sym_POUNDIF] = ACTIONS(12618),
    [anon_sym_POUNDIf] = ACTIONS(12618),
    [anon_sym_POUNDelif] = ACTIONS(12618),
    [anon_sym_POUNDELIF] = ACTIONS(12618),
    [anon_sym_POUNDElif] = ACTIONS(12618),
    [anon_sym_POUNDelse] = ACTIONS(12618),
    [anon_sym_POUNDELSE] = ACTIONS(12618),
    [anon_sym_POUNDElse] = ACTIONS(12618),
    [anon_sym_POUNDelse2] = ACTIONS(12618),
    [anon_sym_POUNDELSE2] = ACTIONS(12618),
    [anon_sym_POUNDElse2] = ACTIONS(12618),
    [anon_sym_POUNDendif] = ACTIONS(12618),
    [anon_sym_POUNDENDIF] = ACTIONS(12618),
    [anon_sym_POUNDEndif] = ACTIONS(12618),
    [anon_sym_POUNDendif2] = ACTIONS(12618),
    [anon_sym_POUNDENDIF2] = ACTIONS(12618),
    [anon_sym_POUNDEndif2] = ACTIONS(12618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12618),
    [sym_trigger_keyword] = ACTIONS(12618),
    [sym_var_keyword] = ACTIONS(12618),
    [sym_local_keyword] = ACTIONS(12618),
    [sym_internal_keyword] = ACTIONS(12618),
    [sym_protected_keyword] = ACTIONS(12618),
    [sym_event_keyword] = ACTIONS(12618),
    [sym_fields_keyword] = ACTIONS(12618),
    [sym_keys_keyword] = ACTIONS(12618),
    [sym_fieldgroups_keyword] = ACTIONS(12618),
    [sym_actions_keyword] = ACTIONS(12618),
    [sym_layout_keyword] = ACTIONS(12618),
    [sym_area_keyword] = ACTIONS(12618),
    [sym_group_keyword] = ACTIONS(12618),
    [sym_repeater_keyword] = ACTIONS(12618),
    [sym_cuegroup_keyword] = ACTIONS(12618),
    [sym_fixed_keyword] = ACTIONS(12618),
    [sym_grid_keyword] = ACTIONS(12618),
    [sym_part_keyword] = ACTIONS(12618),
    [sym_systempart_keyword] = ACTIONS(12618),
    [sym_usercontrol_keyword] = ACTIONS(12618),
    [sym_dataset_keyword] = ACTIONS(12618),
    [sym_elements_keyword] = ACTIONS(12618),
    [sym_dataitem_keyword] = ACTIONS(12618),
    [sym_column_keyword] = ACTIONS(12618),
    [sym_filter_keyword] = ACTIONS(12618),
    [sym_labels_keyword] = ACTIONS(12618),
    [sym_rendering_keyword] = ACTIONS(12618),
    [sym_requestpage_keyword] = ACTIONS(12618),
    [sym_schema_keyword] = ACTIONS(12618),
    [sym_views_keyword] = ACTIONS(12618),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12618),
    [sym_preproc_open] = ACTIONS(12618),
    [sym_preproc_close] = ACTIONS(12618),
  },
  [STATE(5147)] = {
    [anon_sym_SEMI] = ACTIONS(12618),
    [aux_sym_where_condition_token1] = ACTIONS(12620),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12618),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12618),
    [anon_sym_LBRACK] = ACTIONS(12618),
    [aux_sym_basic_type_token6] = ACTIONS(12620),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12618),
    [aux_sym_addafter_modification_token1] = ACTIONS(12618),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12618),
    [aux_sym_modify_modification_token1] = ACTIONS(12618),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12618),
    [aux_sym_movelast_modification_token1] = ACTIONS(12618),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12618),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12618),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12618),
    [anon_sym_POUNDif] = ACTIONS(12618),
    [anon_sym_POUNDIF] = ACTIONS(12618),
    [anon_sym_POUNDIf] = ACTIONS(12618),
    [anon_sym_POUNDelif] = ACTIONS(12618),
    [anon_sym_POUNDELIF] = ACTIONS(12618),
    [anon_sym_POUNDElif] = ACTIONS(12618),
    [anon_sym_POUNDelse] = ACTIONS(12618),
    [anon_sym_POUNDELSE] = ACTIONS(12618),
    [anon_sym_POUNDElse] = ACTIONS(12618),
    [anon_sym_POUNDelse2] = ACTIONS(12618),
    [anon_sym_POUNDELSE2] = ACTIONS(12618),
    [anon_sym_POUNDElse2] = ACTIONS(12618),
    [anon_sym_POUNDendif] = ACTIONS(12618),
    [anon_sym_POUNDENDIF] = ACTIONS(12618),
    [anon_sym_POUNDEndif] = ACTIONS(12618),
    [anon_sym_POUNDendif2] = ACTIONS(12618),
    [anon_sym_POUNDENDIF2] = ACTIONS(12618),
    [anon_sym_POUNDEndif2] = ACTIONS(12618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12618),
    [sym_trigger_keyword] = ACTIONS(12618),
    [sym_var_keyword] = ACTIONS(12618),
    [sym_local_keyword] = ACTIONS(12618),
    [sym_internal_keyword] = ACTIONS(12618),
    [sym_protected_keyword] = ACTIONS(12618),
    [sym_event_keyword] = ACTIONS(12618),
    [sym_fields_keyword] = ACTIONS(12618),
    [sym_keys_keyword] = ACTIONS(12618),
    [sym_fieldgroups_keyword] = ACTIONS(12618),
    [sym_actions_keyword] = ACTIONS(12618),
    [sym_layout_keyword] = ACTIONS(12618),
    [sym_area_keyword] = ACTIONS(12618),
    [sym_group_keyword] = ACTIONS(12618),
    [sym_repeater_keyword] = ACTIONS(12618),
    [sym_cuegroup_keyword] = ACTIONS(12618),
    [sym_fixed_keyword] = ACTIONS(12618),
    [sym_grid_keyword] = ACTIONS(12618),
    [sym_part_keyword] = ACTIONS(12618),
    [sym_systempart_keyword] = ACTIONS(12618),
    [sym_usercontrol_keyword] = ACTIONS(12618),
    [sym_dataset_keyword] = ACTIONS(12618),
    [sym_elements_keyword] = ACTIONS(12618),
    [sym_dataitem_keyword] = ACTIONS(12618),
    [sym_column_keyword] = ACTIONS(12618),
    [sym_filter_keyword] = ACTIONS(12618),
    [sym_labels_keyword] = ACTIONS(12618),
    [sym_rendering_keyword] = ACTIONS(12618),
    [sym_requestpage_keyword] = ACTIONS(12618),
    [sym_schema_keyword] = ACTIONS(12618),
    [sym_views_keyword] = ACTIONS(12618),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12618),
    [sym_preproc_open] = ACTIONS(12618),
    [sym_preproc_close] = ACTIONS(12618),
  },
  [STATE(5148)] = {
    [anon_sym_SEMI] = ACTIONS(12618),
    [aux_sym_where_condition_token1] = ACTIONS(12620),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12618),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12618),
    [anon_sym_LBRACK] = ACTIONS(12618),
    [aux_sym_basic_type_token6] = ACTIONS(12620),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12618),
    [aux_sym_addafter_modification_token1] = ACTIONS(12618),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12618),
    [aux_sym_modify_modification_token1] = ACTIONS(12618),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12618),
    [aux_sym_movelast_modification_token1] = ACTIONS(12618),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12618),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12618),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12618),
    [anon_sym_POUNDif] = ACTIONS(12618),
    [anon_sym_POUNDIF] = ACTIONS(12618),
    [anon_sym_POUNDIf] = ACTIONS(12618),
    [anon_sym_POUNDelif] = ACTIONS(12618),
    [anon_sym_POUNDELIF] = ACTIONS(12618),
    [anon_sym_POUNDElif] = ACTIONS(12618),
    [anon_sym_POUNDelse] = ACTIONS(12618),
    [anon_sym_POUNDELSE] = ACTIONS(12618),
    [anon_sym_POUNDElse] = ACTIONS(12618),
    [anon_sym_POUNDelse2] = ACTIONS(12618),
    [anon_sym_POUNDELSE2] = ACTIONS(12618),
    [anon_sym_POUNDElse2] = ACTIONS(12618),
    [anon_sym_POUNDendif] = ACTIONS(12618),
    [anon_sym_POUNDENDIF] = ACTIONS(12618),
    [anon_sym_POUNDEndif] = ACTIONS(12618),
    [anon_sym_POUNDendif2] = ACTIONS(12618),
    [anon_sym_POUNDENDIF2] = ACTIONS(12618),
    [anon_sym_POUNDEndif2] = ACTIONS(12618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12618),
    [sym_trigger_keyword] = ACTIONS(12618),
    [sym_var_keyword] = ACTIONS(12618),
    [sym_local_keyword] = ACTIONS(12618),
    [sym_internal_keyword] = ACTIONS(12618),
    [sym_protected_keyword] = ACTIONS(12618),
    [sym_event_keyword] = ACTIONS(12618),
    [sym_fields_keyword] = ACTIONS(12618),
    [sym_keys_keyword] = ACTIONS(12618),
    [sym_fieldgroups_keyword] = ACTIONS(12618),
    [sym_actions_keyword] = ACTIONS(12618),
    [sym_layout_keyword] = ACTIONS(12618),
    [sym_area_keyword] = ACTIONS(12618),
    [sym_group_keyword] = ACTIONS(12618),
    [sym_repeater_keyword] = ACTIONS(12618),
    [sym_cuegroup_keyword] = ACTIONS(12618),
    [sym_fixed_keyword] = ACTIONS(12618),
    [sym_grid_keyword] = ACTIONS(12618),
    [sym_part_keyword] = ACTIONS(12618),
    [sym_systempart_keyword] = ACTIONS(12618),
    [sym_usercontrol_keyword] = ACTIONS(12618),
    [sym_dataset_keyword] = ACTIONS(12618),
    [sym_elements_keyword] = ACTIONS(12618),
    [sym_dataitem_keyword] = ACTIONS(12618),
    [sym_column_keyword] = ACTIONS(12618),
    [sym_filter_keyword] = ACTIONS(12618),
    [sym_labels_keyword] = ACTIONS(12618),
    [sym_rendering_keyword] = ACTIONS(12618),
    [sym_requestpage_keyword] = ACTIONS(12618),
    [sym_schema_keyword] = ACTIONS(12618),
    [sym_views_keyword] = ACTIONS(12618),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12618),
    [sym_preproc_open] = ACTIONS(12618),
    [sym_preproc_close] = ACTIONS(12618),
  },
  [STATE(5149)] = {
    [anon_sym_SEMI] = ACTIONS(12618),
    [aux_sym_where_condition_token1] = ACTIONS(12620),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12618),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12618),
    [anon_sym_LBRACK] = ACTIONS(12618),
    [aux_sym_basic_type_token6] = ACTIONS(12620),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12618),
    [aux_sym_addafter_modification_token1] = ACTIONS(12618),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12618),
    [aux_sym_modify_modification_token1] = ACTIONS(12618),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12618),
    [aux_sym_movelast_modification_token1] = ACTIONS(12618),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12618),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12618),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12618),
    [anon_sym_POUNDif] = ACTIONS(12618),
    [anon_sym_POUNDIF] = ACTIONS(12618),
    [anon_sym_POUNDIf] = ACTIONS(12618),
    [anon_sym_POUNDelif] = ACTIONS(12618),
    [anon_sym_POUNDELIF] = ACTIONS(12618),
    [anon_sym_POUNDElif] = ACTIONS(12618),
    [anon_sym_POUNDelse] = ACTIONS(12618),
    [anon_sym_POUNDELSE] = ACTIONS(12618),
    [anon_sym_POUNDElse] = ACTIONS(12618),
    [anon_sym_POUNDelse2] = ACTIONS(12618),
    [anon_sym_POUNDELSE2] = ACTIONS(12618),
    [anon_sym_POUNDElse2] = ACTIONS(12618),
    [anon_sym_POUNDendif] = ACTIONS(12618),
    [anon_sym_POUNDENDIF] = ACTIONS(12618),
    [anon_sym_POUNDEndif] = ACTIONS(12618),
    [anon_sym_POUNDendif2] = ACTIONS(12618),
    [anon_sym_POUNDENDIF2] = ACTIONS(12618),
    [anon_sym_POUNDEndif2] = ACTIONS(12618),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12618),
    [sym_trigger_keyword] = ACTIONS(12618),
    [sym_var_keyword] = ACTIONS(12618),
    [sym_local_keyword] = ACTIONS(12618),
    [sym_internal_keyword] = ACTIONS(12618),
    [sym_protected_keyword] = ACTIONS(12618),
    [sym_event_keyword] = ACTIONS(12618),
    [sym_fields_keyword] = ACTIONS(12618),
    [sym_keys_keyword] = ACTIONS(12618),
    [sym_fieldgroups_keyword] = ACTIONS(12618),
    [sym_actions_keyword] = ACTIONS(12618),
    [sym_layout_keyword] = ACTIONS(12618),
    [sym_area_keyword] = ACTIONS(12618),
    [sym_group_keyword] = ACTIONS(12618),
    [sym_repeater_keyword] = ACTIONS(12618),
    [sym_cuegroup_keyword] = ACTIONS(12618),
    [sym_fixed_keyword] = ACTIONS(12618),
    [sym_grid_keyword] = ACTIONS(12618),
    [sym_part_keyword] = ACTIONS(12618),
    [sym_systempart_keyword] = ACTIONS(12618),
    [sym_usercontrol_keyword] = ACTIONS(12618),
    [sym_dataset_keyword] = ACTIONS(12618),
    [sym_elements_keyword] = ACTIONS(12618),
    [sym_dataitem_keyword] = ACTIONS(12618),
    [sym_column_keyword] = ACTIONS(12618),
    [sym_filter_keyword] = ACTIONS(12618),
    [sym_labels_keyword] = ACTIONS(12618),
    [sym_rendering_keyword] = ACTIONS(12618),
    [sym_requestpage_keyword] = ACTIONS(12618),
    [sym_schema_keyword] = ACTIONS(12618),
    [sym_views_keyword] = ACTIONS(12618),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12618),
    [sym_preproc_open] = ACTIONS(12618),
    [sym_preproc_close] = ACTIONS(12618),
  },
  [STATE(5150)] = {
    [anon_sym_SEMI] = ACTIONS(6361),
    [aux_sym_where_condition_token1] = ACTIONS(6359),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6361),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6361),
    [anon_sym_LBRACK] = ACTIONS(6361),
    [aux_sym_basic_type_token6] = ACTIONS(6359),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6361),
    [aux_sym_addafter_modification_token1] = ACTIONS(6361),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6361),
    [aux_sym_modify_modification_token1] = ACTIONS(6361),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6361),
    [aux_sym_movelast_modification_token1] = ACTIONS(6361),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6361),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6361),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6361),
    [anon_sym_POUNDif] = ACTIONS(6361),
    [anon_sym_POUNDIF] = ACTIONS(6361),
    [anon_sym_POUNDIf] = ACTIONS(6361),
    [anon_sym_POUNDelif] = ACTIONS(6361),
    [anon_sym_POUNDELIF] = ACTIONS(6361),
    [anon_sym_POUNDElif] = ACTIONS(6361),
    [anon_sym_POUNDelse] = ACTIONS(6361),
    [anon_sym_POUNDELSE] = ACTIONS(6361),
    [anon_sym_POUNDElse] = ACTIONS(6361),
    [anon_sym_POUNDelse2] = ACTIONS(6361),
    [anon_sym_POUNDELSE2] = ACTIONS(6361),
    [anon_sym_POUNDElse2] = ACTIONS(6361),
    [anon_sym_POUNDendif] = ACTIONS(6361),
    [anon_sym_POUNDENDIF] = ACTIONS(6361),
    [anon_sym_POUNDEndif] = ACTIONS(6361),
    [anon_sym_POUNDendif2] = ACTIONS(6361),
    [anon_sym_POUNDENDIF2] = ACTIONS(6361),
    [anon_sym_POUNDEndif2] = ACTIONS(6361),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(6361),
    [sym_trigger_keyword] = ACTIONS(6361),
    [sym_var_keyword] = ACTIONS(6361),
    [sym_local_keyword] = ACTIONS(6361),
    [sym_internal_keyword] = ACTIONS(6361),
    [sym_protected_keyword] = ACTIONS(6361),
    [sym_event_keyword] = ACTIONS(6361),
    [sym_fields_keyword] = ACTIONS(6361),
    [sym_keys_keyword] = ACTIONS(6361),
    [sym_fieldgroups_keyword] = ACTIONS(6361),
    [sym_actions_keyword] = ACTIONS(6361),
    [sym_layout_keyword] = ACTIONS(6361),
    [sym_area_keyword] = ACTIONS(6361),
    [sym_group_keyword] = ACTIONS(6361),
    [sym_repeater_keyword] = ACTIONS(6361),
    [sym_cuegroup_keyword] = ACTIONS(6361),
    [sym_fixed_keyword] = ACTIONS(6361),
    [sym_grid_keyword] = ACTIONS(6361),
    [sym_part_keyword] = ACTIONS(6361),
    [sym_systempart_keyword] = ACTIONS(6361),
    [sym_usercontrol_keyword] = ACTIONS(6361),
    [sym_dataset_keyword] = ACTIONS(6361),
    [sym_elements_keyword] = ACTIONS(6361),
    [sym_dataitem_keyword] = ACTIONS(6361),
    [sym_column_keyword] = ACTIONS(6361),
    [sym_filter_keyword] = ACTIONS(6361),
    [sym_labels_keyword] = ACTIONS(6361),
    [sym_rendering_keyword] = ACTIONS(6361),
    [sym_requestpage_keyword] = ACTIONS(6361),
    [sym_schema_keyword] = ACTIONS(6361),
    [sym_views_keyword] = ACTIONS(6361),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6361),
    [sym_preproc_open] = ACTIONS(6361),
    [sym_preproc_close] = ACTIONS(6361),
  },
  [STATE(5151)] = {
    [anon_sym_SEMI] = ACTIONS(12698),
    [aux_sym_where_condition_token1] = ACTIONS(12700),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12698),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12698),
    [anon_sym_LBRACK] = ACTIONS(12698),
    [aux_sym_basic_type_token6] = ACTIONS(12700),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12698),
    [aux_sym_addafter_modification_token1] = ACTIONS(12698),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12698),
    [aux_sym_modify_modification_token1] = ACTIONS(12698),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12698),
    [aux_sym_movelast_modification_token1] = ACTIONS(12698),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12698),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12698),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12698),
    [anon_sym_POUNDif] = ACTIONS(12698),
    [anon_sym_POUNDIF] = ACTIONS(12698),
    [anon_sym_POUNDIf] = ACTIONS(12698),
    [anon_sym_POUNDelif] = ACTIONS(12698),
    [anon_sym_POUNDELIF] = ACTIONS(12698),
    [anon_sym_POUNDElif] = ACTIONS(12698),
    [anon_sym_POUNDelse] = ACTIONS(12698),
    [anon_sym_POUNDELSE] = ACTIONS(12698),
    [anon_sym_POUNDElse] = ACTIONS(12698),
    [anon_sym_POUNDelse2] = ACTIONS(12698),
    [anon_sym_POUNDELSE2] = ACTIONS(12698),
    [anon_sym_POUNDElse2] = ACTIONS(12698),
    [anon_sym_POUNDendif] = ACTIONS(12698),
    [anon_sym_POUNDENDIF] = ACTIONS(12698),
    [anon_sym_POUNDEndif] = ACTIONS(12698),
    [anon_sym_POUNDendif2] = ACTIONS(12698),
    [anon_sym_POUNDENDIF2] = ACTIONS(12698),
    [anon_sym_POUNDEndif2] = ACTIONS(12698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12698),
    [sym_trigger_keyword] = ACTIONS(12698),
    [sym_var_keyword] = ACTIONS(12698),
    [sym_local_keyword] = ACTIONS(12698),
    [sym_internal_keyword] = ACTIONS(12698),
    [sym_protected_keyword] = ACTIONS(12698),
    [sym_event_keyword] = ACTIONS(12698),
    [sym_fields_keyword] = ACTIONS(12698),
    [sym_keys_keyword] = ACTIONS(12698),
    [sym_fieldgroups_keyword] = ACTIONS(12698),
    [sym_actions_keyword] = ACTIONS(12698),
    [sym_layout_keyword] = ACTIONS(12698),
    [sym_area_keyword] = ACTIONS(12698),
    [sym_group_keyword] = ACTIONS(12698),
    [sym_repeater_keyword] = ACTIONS(12698),
    [sym_cuegroup_keyword] = ACTIONS(12698),
    [sym_fixed_keyword] = ACTIONS(12698),
    [sym_grid_keyword] = ACTIONS(12698),
    [sym_part_keyword] = ACTIONS(12698),
    [sym_systempart_keyword] = ACTIONS(12698),
    [sym_usercontrol_keyword] = ACTIONS(12698),
    [sym_dataset_keyword] = ACTIONS(12698),
    [sym_elements_keyword] = ACTIONS(12698),
    [sym_dataitem_keyword] = ACTIONS(12698),
    [sym_column_keyword] = ACTIONS(12698),
    [sym_filter_keyword] = ACTIONS(12698),
    [sym_labels_keyword] = ACTIONS(12698),
    [sym_rendering_keyword] = ACTIONS(12698),
    [sym_requestpage_keyword] = ACTIONS(12698),
    [sym_schema_keyword] = ACTIONS(12698),
    [sym_views_keyword] = ACTIONS(12698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12698),
    [sym_preproc_open] = ACTIONS(12698),
    [sym_preproc_close] = ACTIONS(12698),
  },
  [STATE(5152)] = {
    [anon_sym_SEMI] = ACTIONS(12698),
    [aux_sym_where_condition_token1] = ACTIONS(12700),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12698),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12698),
    [anon_sym_LBRACK] = ACTIONS(12698),
    [aux_sym_basic_type_token6] = ACTIONS(12700),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12698),
    [aux_sym_addafter_modification_token1] = ACTIONS(12698),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12698),
    [aux_sym_modify_modification_token1] = ACTIONS(12698),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12698),
    [aux_sym_movelast_modification_token1] = ACTIONS(12698),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12698),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12698),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12698),
    [anon_sym_POUNDif] = ACTIONS(12698),
    [anon_sym_POUNDIF] = ACTIONS(12698),
    [anon_sym_POUNDIf] = ACTIONS(12698),
    [anon_sym_POUNDelif] = ACTIONS(12698),
    [anon_sym_POUNDELIF] = ACTIONS(12698),
    [anon_sym_POUNDElif] = ACTIONS(12698),
    [anon_sym_POUNDelse] = ACTIONS(12698),
    [anon_sym_POUNDELSE] = ACTIONS(12698),
    [anon_sym_POUNDElse] = ACTIONS(12698),
    [anon_sym_POUNDelse2] = ACTIONS(12698),
    [anon_sym_POUNDELSE2] = ACTIONS(12698),
    [anon_sym_POUNDElse2] = ACTIONS(12698),
    [anon_sym_POUNDendif] = ACTIONS(12698),
    [anon_sym_POUNDENDIF] = ACTIONS(12698),
    [anon_sym_POUNDEndif] = ACTIONS(12698),
    [anon_sym_POUNDendif2] = ACTIONS(12698),
    [anon_sym_POUNDENDIF2] = ACTIONS(12698),
    [anon_sym_POUNDEndif2] = ACTIONS(12698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12698),
    [sym_trigger_keyword] = ACTIONS(12698),
    [sym_var_keyword] = ACTIONS(12698),
    [sym_local_keyword] = ACTIONS(12698),
    [sym_internal_keyword] = ACTIONS(12698),
    [sym_protected_keyword] = ACTIONS(12698),
    [sym_event_keyword] = ACTIONS(12698),
    [sym_fields_keyword] = ACTIONS(12698),
    [sym_keys_keyword] = ACTIONS(12698),
    [sym_fieldgroups_keyword] = ACTIONS(12698),
    [sym_actions_keyword] = ACTIONS(12698),
    [sym_layout_keyword] = ACTIONS(12698),
    [sym_area_keyword] = ACTIONS(12698),
    [sym_group_keyword] = ACTIONS(12698),
    [sym_repeater_keyword] = ACTIONS(12698),
    [sym_cuegroup_keyword] = ACTIONS(12698),
    [sym_fixed_keyword] = ACTIONS(12698),
    [sym_grid_keyword] = ACTIONS(12698),
    [sym_part_keyword] = ACTIONS(12698),
    [sym_systempart_keyword] = ACTIONS(12698),
    [sym_usercontrol_keyword] = ACTIONS(12698),
    [sym_dataset_keyword] = ACTIONS(12698),
    [sym_elements_keyword] = ACTIONS(12698),
    [sym_dataitem_keyword] = ACTIONS(12698),
    [sym_column_keyword] = ACTIONS(12698),
    [sym_filter_keyword] = ACTIONS(12698),
    [sym_labels_keyword] = ACTIONS(12698),
    [sym_rendering_keyword] = ACTIONS(12698),
    [sym_requestpage_keyword] = ACTIONS(12698),
    [sym_schema_keyword] = ACTIONS(12698),
    [sym_views_keyword] = ACTIONS(12698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12698),
    [sym_preproc_open] = ACTIONS(12698),
    [sym_preproc_close] = ACTIONS(12698),
  },
  [STATE(5153)] = {
    [anon_sym_SEMI] = ACTIONS(12698),
    [aux_sym_where_condition_token1] = ACTIONS(12700),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12698),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12698),
    [anon_sym_LBRACK] = ACTIONS(12698),
    [aux_sym_basic_type_token6] = ACTIONS(12700),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12698),
    [aux_sym_addafter_modification_token1] = ACTIONS(12698),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12698),
    [aux_sym_modify_modification_token1] = ACTIONS(12698),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12698),
    [aux_sym_movelast_modification_token1] = ACTIONS(12698),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12698),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12698),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12698),
    [anon_sym_POUNDif] = ACTIONS(12698),
    [anon_sym_POUNDIF] = ACTIONS(12698),
    [anon_sym_POUNDIf] = ACTIONS(12698),
    [anon_sym_POUNDelif] = ACTIONS(12698),
    [anon_sym_POUNDELIF] = ACTIONS(12698),
    [anon_sym_POUNDElif] = ACTIONS(12698),
    [anon_sym_POUNDelse] = ACTIONS(12698),
    [anon_sym_POUNDELSE] = ACTIONS(12698),
    [anon_sym_POUNDElse] = ACTIONS(12698),
    [anon_sym_POUNDelse2] = ACTIONS(12698),
    [anon_sym_POUNDELSE2] = ACTIONS(12698),
    [anon_sym_POUNDElse2] = ACTIONS(12698),
    [anon_sym_POUNDendif] = ACTIONS(12698),
    [anon_sym_POUNDENDIF] = ACTIONS(12698),
    [anon_sym_POUNDEndif] = ACTIONS(12698),
    [anon_sym_POUNDendif2] = ACTIONS(12698),
    [anon_sym_POUNDENDIF2] = ACTIONS(12698),
    [anon_sym_POUNDEndif2] = ACTIONS(12698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12698),
    [sym_trigger_keyword] = ACTIONS(12698),
    [sym_var_keyword] = ACTIONS(12698),
    [sym_local_keyword] = ACTIONS(12698),
    [sym_internal_keyword] = ACTIONS(12698),
    [sym_protected_keyword] = ACTIONS(12698),
    [sym_event_keyword] = ACTIONS(12698),
    [sym_fields_keyword] = ACTIONS(12698),
    [sym_keys_keyword] = ACTIONS(12698),
    [sym_fieldgroups_keyword] = ACTIONS(12698),
    [sym_actions_keyword] = ACTIONS(12698),
    [sym_layout_keyword] = ACTIONS(12698),
    [sym_area_keyword] = ACTIONS(12698),
    [sym_group_keyword] = ACTIONS(12698),
    [sym_repeater_keyword] = ACTIONS(12698),
    [sym_cuegroup_keyword] = ACTIONS(12698),
    [sym_fixed_keyword] = ACTIONS(12698),
    [sym_grid_keyword] = ACTIONS(12698),
    [sym_part_keyword] = ACTIONS(12698),
    [sym_systempart_keyword] = ACTIONS(12698),
    [sym_usercontrol_keyword] = ACTIONS(12698),
    [sym_dataset_keyword] = ACTIONS(12698),
    [sym_elements_keyword] = ACTIONS(12698),
    [sym_dataitem_keyword] = ACTIONS(12698),
    [sym_column_keyword] = ACTIONS(12698),
    [sym_filter_keyword] = ACTIONS(12698),
    [sym_labels_keyword] = ACTIONS(12698),
    [sym_rendering_keyword] = ACTIONS(12698),
    [sym_requestpage_keyword] = ACTIONS(12698),
    [sym_schema_keyword] = ACTIONS(12698),
    [sym_views_keyword] = ACTIONS(12698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12698),
    [sym_preproc_open] = ACTIONS(12698),
    [sym_preproc_close] = ACTIONS(12698),
  },
  [STATE(5154)] = {
    [anon_sym_SEMI] = ACTIONS(12698),
    [aux_sym_where_condition_token1] = ACTIONS(12700),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12698),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12698),
    [anon_sym_LBRACK] = ACTIONS(12698),
    [aux_sym_basic_type_token6] = ACTIONS(12700),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12698),
    [aux_sym_addafter_modification_token1] = ACTIONS(12698),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12698),
    [aux_sym_modify_modification_token1] = ACTIONS(12698),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12698),
    [aux_sym_movelast_modification_token1] = ACTIONS(12698),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12698),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12698),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12698),
    [anon_sym_POUNDif] = ACTIONS(12698),
    [anon_sym_POUNDIF] = ACTIONS(12698),
    [anon_sym_POUNDIf] = ACTIONS(12698),
    [anon_sym_POUNDelif] = ACTIONS(12698),
    [anon_sym_POUNDELIF] = ACTIONS(12698),
    [anon_sym_POUNDElif] = ACTIONS(12698),
    [anon_sym_POUNDelse] = ACTIONS(12698),
    [anon_sym_POUNDELSE] = ACTIONS(12698),
    [anon_sym_POUNDElse] = ACTIONS(12698),
    [anon_sym_POUNDelse2] = ACTIONS(12698),
    [anon_sym_POUNDELSE2] = ACTIONS(12698),
    [anon_sym_POUNDElse2] = ACTIONS(12698),
    [anon_sym_POUNDendif] = ACTIONS(12698),
    [anon_sym_POUNDENDIF] = ACTIONS(12698),
    [anon_sym_POUNDEndif] = ACTIONS(12698),
    [anon_sym_POUNDendif2] = ACTIONS(12698),
    [anon_sym_POUNDENDIF2] = ACTIONS(12698),
    [anon_sym_POUNDEndif2] = ACTIONS(12698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12698),
    [sym_trigger_keyword] = ACTIONS(12698),
    [sym_var_keyword] = ACTIONS(12698),
    [sym_local_keyword] = ACTIONS(12698),
    [sym_internal_keyword] = ACTIONS(12698),
    [sym_protected_keyword] = ACTIONS(12698),
    [sym_event_keyword] = ACTIONS(12698),
    [sym_fields_keyword] = ACTIONS(12698),
    [sym_keys_keyword] = ACTIONS(12698),
    [sym_fieldgroups_keyword] = ACTIONS(12698),
    [sym_actions_keyword] = ACTIONS(12698),
    [sym_layout_keyword] = ACTIONS(12698),
    [sym_area_keyword] = ACTIONS(12698),
    [sym_group_keyword] = ACTIONS(12698),
    [sym_repeater_keyword] = ACTIONS(12698),
    [sym_cuegroup_keyword] = ACTIONS(12698),
    [sym_fixed_keyword] = ACTIONS(12698),
    [sym_grid_keyword] = ACTIONS(12698),
    [sym_part_keyword] = ACTIONS(12698),
    [sym_systempart_keyword] = ACTIONS(12698),
    [sym_usercontrol_keyword] = ACTIONS(12698),
    [sym_dataset_keyword] = ACTIONS(12698),
    [sym_elements_keyword] = ACTIONS(12698),
    [sym_dataitem_keyword] = ACTIONS(12698),
    [sym_column_keyword] = ACTIONS(12698),
    [sym_filter_keyword] = ACTIONS(12698),
    [sym_labels_keyword] = ACTIONS(12698),
    [sym_rendering_keyword] = ACTIONS(12698),
    [sym_requestpage_keyword] = ACTIONS(12698),
    [sym_schema_keyword] = ACTIONS(12698),
    [sym_views_keyword] = ACTIONS(12698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12698),
    [sym_preproc_open] = ACTIONS(12698),
    [sym_preproc_close] = ACTIONS(12698),
  },
  [STATE(5155)] = {
    [anon_sym_SEMI] = ACTIONS(12698),
    [aux_sym_where_condition_token1] = ACTIONS(12700),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12698),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12698),
    [anon_sym_LBRACK] = ACTIONS(12698),
    [aux_sym_basic_type_token6] = ACTIONS(12700),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12698),
    [aux_sym_addafter_modification_token1] = ACTIONS(12698),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12698),
    [aux_sym_modify_modification_token1] = ACTIONS(12698),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12698),
    [aux_sym_movelast_modification_token1] = ACTIONS(12698),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12698),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12698),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12698),
    [anon_sym_POUNDif] = ACTIONS(12698),
    [anon_sym_POUNDIF] = ACTIONS(12698),
    [anon_sym_POUNDIf] = ACTIONS(12698),
    [anon_sym_POUNDelif] = ACTIONS(12698),
    [anon_sym_POUNDELIF] = ACTIONS(12698),
    [anon_sym_POUNDElif] = ACTIONS(12698),
    [anon_sym_POUNDelse] = ACTIONS(12698),
    [anon_sym_POUNDELSE] = ACTIONS(12698),
    [anon_sym_POUNDElse] = ACTIONS(12698),
    [anon_sym_POUNDelse2] = ACTIONS(12698),
    [anon_sym_POUNDELSE2] = ACTIONS(12698),
    [anon_sym_POUNDElse2] = ACTIONS(12698),
    [anon_sym_POUNDendif] = ACTIONS(12698),
    [anon_sym_POUNDENDIF] = ACTIONS(12698),
    [anon_sym_POUNDEndif] = ACTIONS(12698),
    [anon_sym_POUNDendif2] = ACTIONS(12698),
    [anon_sym_POUNDENDIF2] = ACTIONS(12698),
    [anon_sym_POUNDEndif2] = ACTIONS(12698),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12698),
    [sym_trigger_keyword] = ACTIONS(12698),
    [sym_var_keyword] = ACTIONS(12698),
    [sym_local_keyword] = ACTIONS(12698),
    [sym_internal_keyword] = ACTIONS(12698),
    [sym_protected_keyword] = ACTIONS(12698),
    [sym_event_keyword] = ACTIONS(12698),
    [sym_fields_keyword] = ACTIONS(12698),
    [sym_keys_keyword] = ACTIONS(12698),
    [sym_fieldgroups_keyword] = ACTIONS(12698),
    [sym_actions_keyword] = ACTIONS(12698),
    [sym_layout_keyword] = ACTIONS(12698),
    [sym_area_keyword] = ACTIONS(12698),
    [sym_group_keyword] = ACTIONS(12698),
    [sym_repeater_keyword] = ACTIONS(12698),
    [sym_cuegroup_keyword] = ACTIONS(12698),
    [sym_fixed_keyword] = ACTIONS(12698),
    [sym_grid_keyword] = ACTIONS(12698),
    [sym_part_keyword] = ACTIONS(12698),
    [sym_systempart_keyword] = ACTIONS(12698),
    [sym_usercontrol_keyword] = ACTIONS(12698),
    [sym_dataset_keyword] = ACTIONS(12698),
    [sym_elements_keyword] = ACTIONS(12698),
    [sym_dataitem_keyword] = ACTIONS(12698),
    [sym_column_keyword] = ACTIONS(12698),
    [sym_filter_keyword] = ACTIONS(12698),
    [sym_labels_keyword] = ACTIONS(12698),
    [sym_rendering_keyword] = ACTIONS(12698),
    [sym_requestpage_keyword] = ACTIONS(12698),
    [sym_schema_keyword] = ACTIONS(12698),
    [sym_views_keyword] = ACTIONS(12698),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12698),
    [sym_preproc_open] = ACTIONS(12698),
    [sym_preproc_close] = ACTIONS(12698),
  },
  [STATE(5156)] = {
    [anon_sym_SEMI] = ACTIONS(12662),
    [aux_sym_where_condition_token1] = ACTIONS(12664),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12662),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12662),
    [anon_sym_LBRACK] = ACTIONS(12662),
    [aux_sym_basic_type_token6] = ACTIONS(12664),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12662),
    [aux_sym_addafter_modification_token1] = ACTIONS(12662),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12662),
    [aux_sym_modify_modification_token1] = ACTIONS(12662),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12662),
    [aux_sym_movelast_modification_token1] = ACTIONS(12662),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12662),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12662),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12662),
    [anon_sym_POUNDif] = ACTIONS(12662),
    [anon_sym_POUNDIF] = ACTIONS(12662),
    [anon_sym_POUNDIf] = ACTIONS(12662),
    [anon_sym_POUNDelif] = ACTIONS(12662),
    [anon_sym_POUNDELIF] = ACTIONS(12662),
    [anon_sym_POUNDElif] = ACTIONS(12662),
    [anon_sym_POUNDelse] = ACTIONS(12662),
    [anon_sym_POUNDELSE] = ACTIONS(12662),
    [anon_sym_POUNDElse] = ACTIONS(12662),
    [anon_sym_POUNDelse2] = ACTIONS(12662),
    [anon_sym_POUNDELSE2] = ACTIONS(12662),
    [anon_sym_POUNDElse2] = ACTIONS(12662),
    [anon_sym_POUNDendif] = ACTIONS(12662),
    [anon_sym_POUNDENDIF] = ACTIONS(12662),
    [anon_sym_POUNDEndif] = ACTIONS(12662),
    [anon_sym_POUNDendif2] = ACTIONS(12662),
    [anon_sym_POUNDENDIF2] = ACTIONS(12662),
    [anon_sym_POUNDEndif2] = ACTIONS(12662),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12662),
    [sym_trigger_keyword] = ACTIONS(12662),
    [sym_var_keyword] = ACTIONS(12662),
    [sym_local_keyword] = ACTIONS(12662),
    [sym_internal_keyword] = ACTIONS(12662),
    [sym_protected_keyword] = ACTIONS(12662),
    [sym_event_keyword] = ACTIONS(12662),
    [sym_fields_keyword] = ACTIONS(12662),
    [sym_keys_keyword] = ACTIONS(12662),
    [sym_fieldgroups_keyword] = ACTIONS(12662),
    [sym_actions_keyword] = ACTIONS(12662),
    [sym_layout_keyword] = ACTIONS(12662),
    [sym_area_keyword] = ACTIONS(12662),
    [sym_group_keyword] = ACTIONS(12662),
    [sym_repeater_keyword] = ACTIONS(12662),
    [sym_cuegroup_keyword] = ACTIONS(12662),
    [sym_fixed_keyword] = ACTIONS(12662),
    [sym_grid_keyword] = ACTIONS(12662),
    [sym_part_keyword] = ACTIONS(12662),
    [sym_systempart_keyword] = ACTIONS(12662),
    [sym_usercontrol_keyword] = ACTIONS(12662),
    [sym_dataset_keyword] = ACTIONS(12662),
    [sym_elements_keyword] = ACTIONS(12662),
    [sym_dataitem_keyword] = ACTIONS(12662),
    [sym_column_keyword] = ACTIONS(12662),
    [sym_filter_keyword] = ACTIONS(12662),
    [sym_labels_keyword] = ACTIONS(12662),
    [sym_rendering_keyword] = ACTIONS(12662),
    [sym_requestpage_keyword] = ACTIONS(12662),
    [sym_schema_keyword] = ACTIONS(12662),
    [sym_views_keyword] = ACTIONS(12662),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12662),
    [sym_preproc_open] = ACTIONS(12662),
    [sym_preproc_close] = ACTIONS(12662),
  },
  [STATE(5157)] = {
    [anon_sym_SEMI] = ACTIONS(12702),
    [aux_sym_where_condition_token1] = ACTIONS(12704),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12706),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12706),
    [anon_sym_LBRACK] = ACTIONS(12706),
    [aux_sym_basic_type_token6] = ACTIONS(12704),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12706),
    [aux_sym_addafter_modification_token1] = ACTIONS(12706),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12706),
    [aux_sym_modify_modification_token1] = ACTIONS(12706),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12706),
    [aux_sym_movelast_modification_token1] = ACTIONS(12706),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12706),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12706),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12706),
    [anon_sym_POUNDif] = ACTIONS(12281),
    [anon_sym_POUNDIF] = ACTIONS(12281),
    [anon_sym_POUNDIf] = ACTIONS(12281),
    [anon_sym_POUNDelif] = ACTIONS(12706),
    [anon_sym_POUNDELIF] = ACTIONS(12706),
    [anon_sym_POUNDElif] = ACTIONS(12706),
    [anon_sym_POUNDelse] = ACTIONS(12706),
    [anon_sym_POUNDELSE] = ACTIONS(12706),
    [anon_sym_POUNDElse] = ACTIONS(12706),
    [anon_sym_POUNDelse2] = ACTIONS(12706),
    [anon_sym_POUNDELSE2] = ACTIONS(12706),
    [anon_sym_POUNDElse2] = ACTIONS(12706),
    [anon_sym_POUNDendif] = ACTIONS(12706),
    [anon_sym_POUNDENDIF] = ACTIONS(12706),
    [anon_sym_POUNDEndif] = ACTIONS(12706),
    [anon_sym_POUNDendif2] = ACTIONS(12706),
    [anon_sym_POUNDENDIF2] = ACTIONS(12706),
    [anon_sym_POUNDEndif2] = ACTIONS(12706),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12706),
    [sym_trigger_keyword] = ACTIONS(12706),
    [sym_var_keyword] = ACTIONS(12706),
    [sym_local_keyword] = ACTIONS(12706),
    [sym_internal_keyword] = ACTIONS(12706),
    [sym_protected_keyword] = ACTIONS(12706),
    [sym_event_keyword] = ACTIONS(12706),
    [sym_fields_keyword] = ACTIONS(12706),
    [sym_keys_keyword] = ACTIONS(12706),
    [sym_fieldgroups_keyword] = ACTIONS(12706),
    [sym_actions_keyword] = ACTIONS(12706),
    [sym_layout_keyword] = ACTIONS(12706),
    [sym_area_keyword] = ACTIONS(12706),
    [sym_group_keyword] = ACTIONS(12706),
    [sym_repeater_keyword] = ACTIONS(12706),
    [sym_cuegroup_keyword] = ACTIONS(12706),
    [sym_fixed_keyword] = ACTIONS(12706),
    [sym_grid_keyword] = ACTIONS(12706),
    [sym_part_keyword] = ACTIONS(12706),
    [sym_systempart_keyword] = ACTIONS(12706),
    [sym_usercontrol_keyword] = ACTIONS(12706),
    [sym_dataset_keyword] = ACTIONS(12706),
    [sym_elements_keyword] = ACTIONS(12706),
    [sym_dataitem_keyword] = ACTIONS(12706),
    [sym_column_keyword] = ACTIONS(12706),
    [sym_filter_keyword] = ACTIONS(12706),
    [sym_labels_keyword] = ACTIONS(12706),
    [sym_rendering_keyword] = ACTIONS(12706),
    [sym_requestpage_keyword] = ACTIONS(12706),
    [sym_schema_keyword] = ACTIONS(12706),
    [sym_views_keyword] = ACTIONS(12706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12706),
    [sym_preproc_open] = ACTIONS(12281),
    [sym_preproc_close] = ACTIONS(12706),
  },
  [STATE(5158)] = {
    [anon_sym_SEMI] = ACTIONS(12281),
    [aux_sym_where_condition_token1] = ACTIONS(12704),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12706),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12706),
    [anon_sym_LBRACK] = ACTIONS(12706),
    [aux_sym_basic_type_token6] = ACTIONS(12704),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12706),
    [aux_sym_addafter_modification_token1] = ACTIONS(12706),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12706),
    [aux_sym_modify_modification_token1] = ACTIONS(12706),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12706),
    [aux_sym_movelast_modification_token1] = ACTIONS(12706),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12706),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12706),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12706),
    [anon_sym_POUNDif] = ACTIONS(12281),
    [anon_sym_POUNDIF] = ACTIONS(12281),
    [anon_sym_POUNDIf] = ACTIONS(12281),
    [anon_sym_POUNDelif] = ACTIONS(12706),
    [anon_sym_POUNDELIF] = ACTIONS(12706),
    [anon_sym_POUNDElif] = ACTIONS(12706),
    [anon_sym_POUNDelse] = ACTIONS(12706),
    [anon_sym_POUNDELSE] = ACTIONS(12706),
    [anon_sym_POUNDElse] = ACTIONS(12706),
    [anon_sym_POUNDelse2] = ACTIONS(12706),
    [anon_sym_POUNDELSE2] = ACTIONS(12706),
    [anon_sym_POUNDElse2] = ACTIONS(12706),
    [anon_sym_POUNDendif] = ACTIONS(12706),
    [anon_sym_POUNDENDIF] = ACTIONS(12706),
    [anon_sym_POUNDEndif] = ACTIONS(12706),
    [anon_sym_POUNDendif2] = ACTIONS(12706),
    [anon_sym_POUNDENDIF2] = ACTIONS(12706),
    [anon_sym_POUNDEndif2] = ACTIONS(12706),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12706),
    [sym_trigger_keyword] = ACTIONS(12706),
    [sym_var_keyword] = ACTIONS(12706),
    [sym_local_keyword] = ACTIONS(12706),
    [sym_internal_keyword] = ACTIONS(12706),
    [sym_protected_keyword] = ACTIONS(12706),
    [sym_event_keyword] = ACTIONS(12706),
    [sym_fields_keyword] = ACTIONS(12706),
    [sym_keys_keyword] = ACTIONS(12706),
    [sym_fieldgroups_keyword] = ACTIONS(12706),
    [sym_actions_keyword] = ACTIONS(12706),
    [sym_layout_keyword] = ACTIONS(12706),
    [sym_area_keyword] = ACTIONS(12706),
    [sym_group_keyword] = ACTIONS(12706),
    [sym_repeater_keyword] = ACTIONS(12706),
    [sym_cuegroup_keyword] = ACTIONS(12706),
    [sym_fixed_keyword] = ACTIONS(12706),
    [sym_grid_keyword] = ACTIONS(12706),
    [sym_part_keyword] = ACTIONS(12706),
    [sym_systempart_keyword] = ACTIONS(12706),
    [sym_usercontrol_keyword] = ACTIONS(12706),
    [sym_dataset_keyword] = ACTIONS(12706),
    [sym_elements_keyword] = ACTIONS(12706),
    [sym_dataitem_keyword] = ACTIONS(12706),
    [sym_column_keyword] = ACTIONS(12706),
    [sym_filter_keyword] = ACTIONS(12706),
    [sym_labels_keyword] = ACTIONS(12706),
    [sym_rendering_keyword] = ACTIONS(12706),
    [sym_requestpage_keyword] = ACTIONS(12706),
    [sym_schema_keyword] = ACTIONS(12706),
    [sym_views_keyword] = ACTIONS(12706),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12706),
    [sym_preproc_open] = ACTIONS(12281),
    [sym_preproc_close] = ACTIONS(12706),
  },
  [STATE(5159)] = {
    [anon_sym_SEMI] = ACTIONS(12708),
    [aux_sym_where_condition_token1] = ACTIONS(12710),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12712),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12712),
    [anon_sym_LBRACK] = ACTIONS(12712),
    [aux_sym_basic_type_token6] = ACTIONS(12710),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12712),
    [aux_sym_addafter_modification_token1] = ACTIONS(12712),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12712),
    [aux_sym_modify_modification_token1] = ACTIONS(12712),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12712),
    [aux_sym_movelast_modification_token1] = ACTIONS(12712),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12712),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12712),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12712),
    [anon_sym_POUNDif] = ACTIONS(12712),
    [anon_sym_POUNDIF] = ACTIONS(12712),
    [anon_sym_POUNDIf] = ACTIONS(12712),
    [anon_sym_POUNDelif] = ACTIONS(12712),
    [anon_sym_POUNDELIF] = ACTIONS(12712),
    [anon_sym_POUNDElif] = ACTIONS(12712),
    [anon_sym_POUNDelse] = ACTIONS(12712),
    [anon_sym_POUNDELSE] = ACTIONS(12712),
    [anon_sym_POUNDElse] = ACTIONS(12712),
    [anon_sym_POUNDelse2] = ACTIONS(12712),
    [anon_sym_POUNDELSE2] = ACTIONS(12712),
    [anon_sym_POUNDElse2] = ACTIONS(12712),
    [anon_sym_POUNDendif] = ACTIONS(12712),
    [anon_sym_POUNDENDIF] = ACTIONS(12712),
    [anon_sym_POUNDEndif] = ACTIONS(12712),
    [anon_sym_POUNDendif2] = ACTIONS(12712),
    [anon_sym_POUNDENDIF2] = ACTIONS(12712),
    [anon_sym_POUNDEndif2] = ACTIONS(12712),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12712),
    [sym_trigger_keyword] = ACTIONS(12712),
    [sym_var_keyword] = ACTIONS(12712),
    [sym_local_keyword] = ACTIONS(12712),
    [sym_internal_keyword] = ACTIONS(12712),
    [sym_protected_keyword] = ACTIONS(12712),
    [sym_event_keyword] = ACTIONS(12712),
    [sym_fields_keyword] = ACTIONS(12712),
    [sym_keys_keyword] = ACTIONS(12712),
    [sym_fieldgroups_keyword] = ACTIONS(12712),
    [sym_actions_keyword] = ACTIONS(12712),
    [sym_layout_keyword] = ACTIONS(12712),
    [sym_area_keyword] = ACTIONS(12712),
    [sym_group_keyword] = ACTIONS(12712),
    [sym_repeater_keyword] = ACTIONS(12712),
    [sym_cuegroup_keyword] = ACTIONS(12712),
    [sym_fixed_keyword] = ACTIONS(12712),
    [sym_grid_keyword] = ACTIONS(12712),
    [sym_part_keyword] = ACTIONS(12712),
    [sym_systempart_keyword] = ACTIONS(12712),
    [sym_usercontrol_keyword] = ACTIONS(12712),
    [sym_dataset_keyword] = ACTIONS(12712),
    [sym_elements_keyword] = ACTIONS(12712),
    [sym_dataitem_keyword] = ACTIONS(12712),
    [sym_column_keyword] = ACTIONS(12712),
    [sym_filter_keyword] = ACTIONS(12712),
    [sym_labels_keyword] = ACTIONS(12712),
    [sym_rendering_keyword] = ACTIONS(12712),
    [sym_requestpage_keyword] = ACTIONS(12712),
    [sym_schema_keyword] = ACTIONS(12712),
    [sym_views_keyword] = ACTIONS(12712),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12712),
    [sym_preproc_open] = ACTIONS(12712),
    [sym_preproc_close] = ACTIONS(12712),
  },
  [STATE(5160)] = {
    [anon_sym_SEMI] = ACTIONS(8379),
    [anon_sym_COMMA] = ACTIONS(12714),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8379),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8379),
    [anon_sym_LBRACK] = ACTIONS(8379),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8379),
    [aux_sym_modify_modification_token1] = ACTIONS(8379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8379),
    [anon_sym_POUNDif] = ACTIONS(8379),
    [anon_sym_POUNDIF] = ACTIONS(8379),
    [anon_sym_POUNDIf] = ACTIONS(8379),
    [anon_sym_POUNDelif] = ACTIONS(8379),
    [anon_sym_POUNDELIF] = ACTIONS(8379),
    [anon_sym_POUNDElif] = ACTIONS(8379),
    [anon_sym_POUNDelse] = ACTIONS(8379),
    [anon_sym_POUNDELSE] = ACTIONS(8379),
    [anon_sym_POUNDElse] = ACTIONS(8379),
    [anon_sym_POUNDelse2] = ACTIONS(8379),
    [anon_sym_POUNDELSE2] = ACTIONS(8379),
    [anon_sym_POUNDElse2] = ACTIONS(8379),
    [anon_sym_POUNDendif] = ACTIONS(8379),
    [anon_sym_POUNDENDIF] = ACTIONS(8379),
    [anon_sym_POUNDEndif] = ACTIONS(8379),
    [anon_sym_POUNDendif2] = ACTIONS(8379),
    [anon_sym_POUNDENDIF2] = ACTIONS(8379),
    [anon_sym_POUNDEndif2] = ACTIONS(8379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8383),
    [sym_page_keyword] = ACTIONS(8379),
    [anon_sym_codeunit] = ACTIONS(8379),
    [anon_sym_CODEUNIT] = ACTIONS(8379),
    [anon_sym_Codeunit] = ACTIONS(8379),
    [anon_sym_CodeUnit] = ACTIONS(8379),
    [anon_sym_COdeunit] = ACTIONS(8379),
    [anon_sym_codeUnit] = ACTIONS(8379),
    [sym_report_keyword] = ACTIONS(8379),
    [sym_query_keyword] = ACTIONS(8379),
    [anon_sym_xmlport] = ACTIONS(8379),
    [anon_sym_XMLPORT] = ACTIONS(8379),
    [anon_sym_Xmlport] = ACTIONS(8379),
    [anon_sym_XMLport] = ACTIONS(8379),
    [anon_sym_XMLPort] = ACTIONS(8379),
    [anon_sym_XmlPort] = ACTIONS(8379),
    [sym_procedure_keyword] = ACTIONS(8379),
    [sym_trigger_keyword] = ACTIONS(8379),
    [sym_var_keyword] = ACTIONS(8379),
    [sym_local_keyword] = ACTIONS(8379),
    [sym_internal_keyword] = ACTIONS(8379),
    [sym_protected_keyword] = ACTIONS(8379),
    [sym_event_keyword] = ACTIONS(8379),
    [sym_fields_keyword] = ACTIONS(8379),
    [sym_keys_keyword] = ACTIONS(8379),
    [sym_fieldgroups_keyword] = ACTIONS(8379),
    [sym_actions_keyword] = ACTIONS(8379),
    [sym_layout_keyword] = ACTIONS(8379),
    [sym_dataset_keyword] = ACTIONS(8379),
    [sym_elements_keyword] = ACTIONS(8379),
    [sym_dataitem_keyword] = ACTIONS(8379),
    [sym_column_keyword] = ACTIONS(8379),
    [sym_filter_keyword] = ACTIONS(8379),
    [sym_labels_keyword] = ACTIONS(8379),
    [sym_rendering_keyword] = ACTIONS(8379),
    [sym_requestpage_keyword] = ACTIONS(8379),
    [sym_schema_keyword] = ACTIONS(8379),
    [sym_views_keyword] = ACTIONS(8379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8379),
    [sym_preproc_open] = ACTIONS(8379),
    [sym_preproc_close] = ACTIONS(8379),
  },
  [STATE(5161)] = {
    [anon_sym_SEMI] = ACTIONS(12716),
    [aux_sym_where_condition_token1] = ACTIONS(12718),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12716),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12716),
    [anon_sym_LBRACK] = ACTIONS(12716),
    [aux_sym_basic_type_token6] = ACTIONS(12718),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12716),
    [aux_sym_addafter_modification_token1] = ACTIONS(12716),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12716),
    [aux_sym_modify_modification_token1] = ACTIONS(12716),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12716),
    [aux_sym_movelast_modification_token1] = ACTIONS(12716),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12716),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12716),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12716),
    [anon_sym_POUNDif] = ACTIONS(12716),
    [anon_sym_POUNDIF] = ACTIONS(12716),
    [anon_sym_POUNDIf] = ACTIONS(12716),
    [anon_sym_POUNDelif] = ACTIONS(12716),
    [anon_sym_POUNDELIF] = ACTIONS(12716),
    [anon_sym_POUNDElif] = ACTIONS(12716),
    [anon_sym_POUNDelse] = ACTIONS(12716),
    [anon_sym_POUNDELSE] = ACTIONS(12716),
    [anon_sym_POUNDElse] = ACTIONS(12716),
    [anon_sym_POUNDelse2] = ACTIONS(12716),
    [anon_sym_POUNDELSE2] = ACTIONS(12716),
    [anon_sym_POUNDElse2] = ACTIONS(12716),
    [anon_sym_POUNDendif] = ACTIONS(12716),
    [anon_sym_POUNDENDIF] = ACTIONS(12716),
    [anon_sym_POUNDEndif] = ACTIONS(12716),
    [anon_sym_POUNDendif2] = ACTIONS(12716),
    [anon_sym_POUNDENDIF2] = ACTIONS(12716),
    [anon_sym_POUNDEndif2] = ACTIONS(12716),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12716),
    [sym_trigger_keyword] = ACTIONS(12716),
    [sym_var_keyword] = ACTIONS(12716),
    [sym_local_keyword] = ACTIONS(12716),
    [sym_internal_keyword] = ACTIONS(12716),
    [sym_protected_keyword] = ACTIONS(12716),
    [sym_event_keyword] = ACTIONS(12716),
    [sym_fields_keyword] = ACTIONS(12716),
    [sym_keys_keyword] = ACTIONS(12716),
    [sym_fieldgroups_keyword] = ACTIONS(12716),
    [sym_actions_keyword] = ACTIONS(12716),
    [sym_layout_keyword] = ACTIONS(12716),
    [sym_area_keyword] = ACTIONS(12716),
    [sym_group_keyword] = ACTIONS(12716),
    [sym_repeater_keyword] = ACTIONS(12716),
    [sym_cuegroup_keyword] = ACTIONS(12716),
    [sym_fixed_keyword] = ACTIONS(12716),
    [sym_grid_keyword] = ACTIONS(12716),
    [sym_part_keyword] = ACTIONS(12716),
    [sym_systempart_keyword] = ACTIONS(12716),
    [sym_usercontrol_keyword] = ACTIONS(12716),
    [sym_dataset_keyword] = ACTIONS(12716),
    [sym_elements_keyword] = ACTIONS(12716),
    [sym_dataitem_keyword] = ACTIONS(12716),
    [sym_column_keyword] = ACTIONS(12716),
    [sym_filter_keyword] = ACTIONS(12716),
    [sym_labels_keyword] = ACTIONS(12716),
    [sym_rendering_keyword] = ACTIONS(12716),
    [sym_requestpage_keyword] = ACTIONS(12716),
    [sym_schema_keyword] = ACTIONS(12716),
    [sym_views_keyword] = ACTIONS(12716),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12716),
    [sym_preproc_open] = ACTIONS(12716),
    [sym_preproc_close] = ACTIONS(12716),
  },
  [STATE(5162)] = {
    [anon_sym_SEMI] = ACTIONS(12720),
    [aux_sym_where_condition_token1] = ACTIONS(12722),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12720),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12720),
    [anon_sym_LBRACK] = ACTIONS(12720),
    [aux_sym_basic_type_token6] = ACTIONS(12722),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12720),
    [aux_sym_addafter_modification_token1] = ACTIONS(12720),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12720),
    [aux_sym_modify_modification_token1] = ACTIONS(12720),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12720),
    [aux_sym_movelast_modification_token1] = ACTIONS(12720),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12720),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12720),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12720),
    [anon_sym_POUNDif] = ACTIONS(12720),
    [anon_sym_POUNDIF] = ACTIONS(12720),
    [anon_sym_POUNDIf] = ACTIONS(12720),
    [anon_sym_POUNDelif] = ACTIONS(12720),
    [anon_sym_POUNDELIF] = ACTIONS(12720),
    [anon_sym_POUNDElif] = ACTIONS(12720),
    [anon_sym_POUNDelse] = ACTIONS(12720),
    [anon_sym_POUNDELSE] = ACTIONS(12720),
    [anon_sym_POUNDElse] = ACTIONS(12720),
    [anon_sym_POUNDelse2] = ACTIONS(12720),
    [anon_sym_POUNDELSE2] = ACTIONS(12720),
    [anon_sym_POUNDElse2] = ACTIONS(12720),
    [anon_sym_POUNDendif] = ACTIONS(12720),
    [anon_sym_POUNDENDIF] = ACTIONS(12720),
    [anon_sym_POUNDEndif] = ACTIONS(12720),
    [anon_sym_POUNDendif2] = ACTIONS(12720),
    [anon_sym_POUNDENDIF2] = ACTIONS(12720),
    [anon_sym_POUNDEndif2] = ACTIONS(12720),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12720),
    [sym_trigger_keyword] = ACTIONS(12720),
    [sym_var_keyword] = ACTIONS(12720),
    [sym_local_keyword] = ACTIONS(12720),
    [sym_internal_keyword] = ACTIONS(12720),
    [sym_protected_keyword] = ACTIONS(12720),
    [sym_event_keyword] = ACTIONS(12720),
    [sym_fields_keyword] = ACTIONS(12720),
    [sym_keys_keyword] = ACTIONS(12720),
    [sym_fieldgroups_keyword] = ACTIONS(12720),
    [sym_actions_keyword] = ACTIONS(12720),
    [sym_layout_keyword] = ACTIONS(12720),
    [sym_area_keyword] = ACTIONS(12720),
    [sym_group_keyword] = ACTIONS(12720),
    [sym_repeater_keyword] = ACTIONS(12720),
    [sym_cuegroup_keyword] = ACTIONS(12720),
    [sym_fixed_keyword] = ACTIONS(12720),
    [sym_grid_keyword] = ACTIONS(12720),
    [sym_part_keyword] = ACTIONS(12720),
    [sym_systempart_keyword] = ACTIONS(12720),
    [sym_usercontrol_keyword] = ACTIONS(12720),
    [sym_dataset_keyword] = ACTIONS(12720),
    [sym_elements_keyword] = ACTIONS(12720),
    [sym_dataitem_keyword] = ACTIONS(12720),
    [sym_column_keyword] = ACTIONS(12720),
    [sym_filter_keyword] = ACTIONS(12720),
    [sym_labels_keyword] = ACTIONS(12720),
    [sym_rendering_keyword] = ACTIONS(12720),
    [sym_requestpage_keyword] = ACTIONS(12720),
    [sym_schema_keyword] = ACTIONS(12720),
    [sym_views_keyword] = ACTIONS(12720),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12720),
    [sym_preproc_open] = ACTIONS(12720),
    [sym_preproc_close] = ACTIONS(12720),
  },
  [STATE(5163)] = {
    [anon_sym_SEMI] = ACTIONS(12724),
    [aux_sym_where_condition_token1] = ACTIONS(12726),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12724),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12724),
    [anon_sym_LBRACK] = ACTIONS(12724),
    [aux_sym_basic_type_token6] = ACTIONS(12726),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12724),
    [aux_sym_addafter_modification_token1] = ACTIONS(12724),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12724),
    [aux_sym_modify_modification_token1] = ACTIONS(12724),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12724),
    [aux_sym_movelast_modification_token1] = ACTIONS(12724),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12724),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12724),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12724),
    [anon_sym_POUNDif] = ACTIONS(12724),
    [anon_sym_POUNDIF] = ACTIONS(12724),
    [anon_sym_POUNDIf] = ACTIONS(12724),
    [anon_sym_POUNDelif] = ACTIONS(12724),
    [anon_sym_POUNDELIF] = ACTIONS(12724),
    [anon_sym_POUNDElif] = ACTIONS(12724),
    [anon_sym_POUNDelse] = ACTIONS(12724),
    [anon_sym_POUNDELSE] = ACTIONS(12724),
    [anon_sym_POUNDElse] = ACTIONS(12724),
    [anon_sym_POUNDelse2] = ACTIONS(12724),
    [anon_sym_POUNDELSE2] = ACTIONS(12724),
    [anon_sym_POUNDElse2] = ACTIONS(12724),
    [anon_sym_POUNDendif] = ACTIONS(12724),
    [anon_sym_POUNDENDIF] = ACTIONS(12724),
    [anon_sym_POUNDEndif] = ACTIONS(12724),
    [anon_sym_POUNDendif2] = ACTIONS(12724),
    [anon_sym_POUNDENDIF2] = ACTIONS(12724),
    [anon_sym_POUNDEndif2] = ACTIONS(12724),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12724),
    [sym_trigger_keyword] = ACTIONS(12724),
    [sym_var_keyword] = ACTIONS(12724),
    [sym_local_keyword] = ACTIONS(12724),
    [sym_internal_keyword] = ACTIONS(12724),
    [sym_protected_keyword] = ACTIONS(12724),
    [sym_event_keyword] = ACTIONS(12724),
    [sym_fields_keyword] = ACTIONS(12724),
    [sym_keys_keyword] = ACTIONS(12724),
    [sym_fieldgroups_keyword] = ACTIONS(12724),
    [sym_actions_keyword] = ACTIONS(12724),
    [sym_layout_keyword] = ACTIONS(12724),
    [sym_area_keyword] = ACTIONS(12724),
    [sym_group_keyword] = ACTIONS(12724),
    [sym_repeater_keyword] = ACTIONS(12724),
    [sym_cuegroup_keyword] = ACTIONS(12724),
    [sym_fixed_keyword] = ACTIONS(12724),
    [sym_grid_keyword] = ACTIONS(12724),
    [sym_part_keyword] = ACTIONS(12724),
    [sym_systempart_keyword] = ACTIONS(12724),
    [sym_usercontrol_keyword] = ACTIONS(12724),
    [sym_dataset_keyword] = ACTIONS(12724),
    [sym_elements_keyword] = ACTIONS(12724),
    [sym_dataitem_keyword] = ACTIONS(12724),
    [sym_column_keyword] = ACTIONS(12724),
    [sym_filter_keyword] = ACTIONS(12724),
    [sym_labels_keyword] = ACTIONS(12724),
    [sym_rendering_keyword] = ACTIONS(12724),
    [sym_requestpage_keyword] = ACTIONS(12724),
    [sym_schema_keyword] = ACTIONS(12724),
    [sym_views_keyword] = ACTIONS(12724),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12724),
    [sym_preproc_open] = ACTIONS(12724),
    [sym_preproc_close] = ACTIONS(12724),
  },
  [STATE(5164)] = {
    [anon_sym_SEMI] = ACTIONS(12728),
    [aux_sym_where_condition_token1] = ACTIONS(12730),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12728),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12728),
    [anon_sym_LBRACK] = ACTIONS(12728),
    [aux_sym_basic_type_token6] = ACTIONS(12730),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12728),
    [aux_sym_addafter_modification_token1] = ACTIONS(12728),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12728),
    [aux_sym_modify_modification_token1] = ACTIONS(12728),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12728),
    [aux_sym_movelast_modification_token1] = ACTIONS(12728),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12728),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12728),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12728),
    [anon_sym_POUNDif] = ACTIONS(12728),
    [anon_sym_POUNDIF] = ACTIONS(12728),
    [anon_sym_POUNDIf] = ACTIONS(12728),
    [anon_sym_POUNDelif] = ACTIONS(12728),
    [anon_sym_POUNDELIF] = ACTIONS(12728),
    [anon_sym_POUNDElif] = ACTIONS(12728),
    [anon_sym_POUNDelse] = ACTIONS(12728),
    [anon_sym_POUNDELSE] = ACTIONS(12728),
    [anon_sym_POUNDElse] = ACTIONS(12728),
    [anon_sym_POUNDelse2] = ACTIONS(12728),
    [anon_sym_POUNDELSE2] = ACTIONS(12728),
    [anon_sym_POUNDElse2] = ACTIONS(12728),
    [anon_sym_POUNDendif] = ACTIONS(12728),
    [anon_sym_POUNDENDIF] = ACTIONS(12728),
    [anon_sym_POUNDEndif] = ACTIONS(12728),
    [anon_sym_POUNDendif2] = ACTIONS(12728),
    [anon_sym_POUNDENDIF2] = ACTIONS(12728),
    [anon_sym_POUNDEndif2] = ACTIONS(12728),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12728),
    [sym_trigger_keyword] = ACTIONS(12728),
    [sym_var_keyword] = ACTIONS(12728),
    [sym_local_keyword] = ACTIONS(12728),
    [sym_internal_keyword] = ACTIONS(12728),
    [sym_protected_keyword] = ACTIONS(12728),
    [sym_event_keyword] = ACTIONS(12728),
    [sym_fields_keyword] = ACTIONS(12728),
    [sym_keys_keyword] = ACTIONS(12728),
    [sym_fieldgroups_keyword] = ACTIONS(12728),
    [sym_actions_keyword] = ACTIONS(12728),
    [sym_layout_keyword] = ACTIONS(12728),
    [sym_area_keyword] = ACTIONS(12728),
    [sym_group_keyword] = ACTIONS(12728),
    [sym_repeater_keyword] = ACTIONS(12728),
    [sym_cuegroup_keyword] = ACTIONS(12728),
    [sym_fixed_keyword] = ACTIONS(12728),
    [sym_grid_keyword] = ACTIONS(12728),
    [sym_part_keyword] = ACTIONS(12728),
    [sym_systempart_keyword] = ACTIONS(12728),
    [sym_usercontrol_keyword] = ACTIONS(12728),
    [sym_dataset_keyword] = ACTIONS(12728),
    [sym_elements_keyword] = ACTIONS(12728),
    [sym_dataitem_keyword] = ACTIONS(12728),
    [sym_column_keyword] = ACTIONS(12728),
    [sym_filter_keyword] = ACTIONS(12728),
    [sym_labels_keyword] = ACTIONS(12728),
    [sym_rendering_keyword] = ACTIONS(12728),
    [sym_requestpage_keyword] = ACTIONS(12728),
    [sym_schema_keyword] = ACTIONS(12728),
    [sym_views_keyword] = ACTIONS(12728),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12728),
    [sym_preproc_open] = ACTIONS(12728),
    [sym_preproc_close] = ACTIONS(12728),
  },
  [STATE(5165)] = {
    [anon_sym_SEMI] = ACTIONS(12732),
    [aux_sym_where_condition_token1] = ACTIONS(12734),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12732),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12732),
    [anon_sym_LBRACK] = ACTIONS(12732),
    [aux_sym_basic_type_token6] = ACTIONS(12734),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12732),
    [aux_sym_addafter_modification_token1] = ACTIONS(12732),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12732),
    [aux_sym_modify_modification_token1] = ACTIONS(12732),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12732),
    [aux_sym_movelast_modification_token1] = ACTIONS(12732),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12732),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12732),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12732),
    [anon_sym_POUNDif] = ACTIONS(12732),
    [anon_sym_POUNDIF] = ACTIONS(12732),
    [anon_sym_POUNDIf] = ACTIONS(12732),
    [anon_sym_POUNDelif] = ACTIONS(12732),
    [anon_sym_POUNDELIF] = ACTIONS(12732),
    [anon_sym_POUNDElif] = ACTIONS(12732),
    [anon_sym_POUNDelse] = ACTIONS(12732),
    [anon_sym_POUNDELSE] = ACTIONS(12732),
    [anon_sym_POUNDElse] = ACTIONS(12732),
    [anon_sym_POUNDelse2] = ACTIONS(12732),
    [anon_sym_POUNDELSE2] = ACTIONS(12732),
    [anon_sym_POUNDElse2] = ACTIONS(12732),
    [anon_sym_POUNDendif] = ACTIONS(12732),
    [anon_sym_POUNDENDIF] = ACTIONS(12732),
    [anon_sym_POUNDEndif] = ACTIONS(12732),
    [anon_sym_POUNDendif2] = ACTIONS(12732),
    [anon_sym_POUNDENDIF2] = ACTIONS(12732),
    [anon_sym_POUNDEndif2] = ACTIONS(12732),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12732),
    [sym_trigger_keyword] = ACTIONS(12732),
    [sym_var_keyword] = ACTIONS(12732),
    [sym_local_keyword] = ACTIONS(12732),
    [sym_internal_keyword] = ACTIONS(12732),
    [sym_protected_keyword] = ACTIONS(12732),
    [sym_event_keyword] = ACTIONS(12732),
    [sym_fields_keyword] = ACTIONS(12732),
    [sym_keys_keyword] = ACTIONS(12732),
    [sym_fieldgroups_keyword] = ACTIONS(12732),
    [sym_actions_keyword] = ACTIONS(12732),
    [sym_layout_keyword] = ACTIONS(12732),
    [sym_area_keyword] = ACTIONS(12732),
    [sym_group_keyword] = ACTIONS(12732),
    [sym_repeater_keyword] = ACTIONS(12732),
    [sym_cuegroup_keyword] = ACTIONS(12732),
    [sym_fixed_keyword] = ACTIONS(12732),
    [sym_grid_keyword] = ACTIONS(12732),
    [sym_part_keyword] = ACTIONS(12732),
    [sym_systempart_keyword] = ACTIONS(12732),
    [sym_usercontrol_keyword] = ACTIONS(12732),
    [sym_dataset_keyword] = ACTIONS(12732),
    [sym_elements_keyword] = ACTIONS(12732),
    [sym_dataitem_keyword] = ACTIONS(12732),
    [sym_column_keyword] = ACTIONS(12732),
    [sym_filter_keyword] = ACTIONS(12732),
    [sym_labels_keyword] = ACTIONS(12732),
    [sym_rendering_keyword] = ACTIONS(12732),
    [sym_requestpage_keyword] = ACTIONS(12732),
    [sym_schema_keyword] = ACTIONS(12732),
    [sym_views_keyword] = ACTIONS(12732),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12732),
    [sym_preproc_open] = ACTIONS(12732),
    [sym_preproc_close] = ACTIONS(12732),
  },
  [STATE(5166)] = {
    [anon_sym_SEMI] = ACTIONS(12736),
    [aux_sym_where_condition_token1] = ACTIONS(12738),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12736),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12736),
    [anon_sym_LBRACK] = ACTIONS(12736),
    [aux_sym_basic_type_token6] = ACTIONS(12738),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12736),
    [aux_sym_addafter_modification_token1] = ACTIONS(12736),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12736),
    [aux_sym_modify_modification_token1] = ACTIONS(12736),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12736),
    [aux_sym_movelast_modification_token1] = ACTIONS(12736),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12736),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12736),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12736),
    [anon_sym_POUNDif] = ACTIONS(12736),
    [anon_sym_POUNDIF] = ACTIONS(12736),
    [anon_sym_POUNDIf] = ACTIONS(12736),
    [anon_sym_POUNDelif] = ACTIONS(12736),
    [anon_sym_POUNDELIF] = ACTIONS(12736),
    [anon_sym_POUNDElif] = ACTIONS(12736),
    [anon_sym_POUNDelse] = ACTIONS(12736),
    [anon_sym_POUNDELSE] = ACTIONS(12736),
    [anon_sym_POUNDElse] = ACTIONS(12736),
    [anon_sym_POUNDelse2] = ACTIONS(12736),
    [anon_sym_POUNDELSE2] = ACTIONS(12736),
    [anon_sym_POUNDElse2] = ACTIONS(12736),
    [anon_sym_POUNDendif] = ACTIONS(12736),
    [anon_sym_POUNDENDIF] = ACTIONS(12736),
    [anon_sym_POUNDEndif] = ACTIONS(12736),
    [anon_sym_POUNDendif2] = ACTIONS(12736),
    [anon_sym_POUNDENDIF2] = ACTIONS(12736),
    [anon_sym_POUNDEndif2] = ACTIONS(12736),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12736),
    [sym_trigger_keyword] = ACTIONS(12736),
    [sym_var_keyword] = ACTIONS(12736),
    [sym_local_keyword] = ACTIONS(12736),
    [sym_internal_keyword] = ACTIONS(12736),
    [sym_protected_keyword] = ACTIONS(12736),
    [sym_event_keyword] = ACTIONS(12736),
    [sym_fields_keyword] = ACTIONS(12736),
    [sym_keys_keyword] = ACTIONS(12736),
    [sym_fieldgroups_keyword] = ACTIONS(12736),
    [sym_actions_keyword] = ACTIONS(12736),
    [sym_layout_keyword] = ACTIONS(12736),
    [sym_area_keyword] = ACTIONS(12736),
    [sym_group_keyword] = ACTIONS(12736),
    [sym_repeater_keyword] = ACTIONS(12736),
    [sym_cuegroup_keyword] = ACTIONS(12736),
    [sym_fixed_keyword] = ACTIONS(12736),
    [sym_grid_keyword] = ACTIONS(12736),
    [sym_part_keyword] = ACTIONS(12736),
    [sym_systempart_keyword] = ACTIONS(12736),
    [sym_usercontrol_keyword] = ACTIONS(12736),
    [sym_dataset_keyword] = ACTIONS(12736),
    [sym_elements_keyword] = ACTIONS(12736),
    [sym_dataitem_keyword] = ACTIONS(12736),
    [sym_column_keyword] = ACTIONS(12736),
    [sym_filter_keyword] = ACTIONS(12736),
    [sym_labels_keyword] = ACTIONS(12736),
    [sym_rendering_keyword] = ACTIONS(12736),
    [sym_requestpage_keyword] = ACTIONS(12736),
    [sym_schema_keyword] = ACTIONS(12736),
    [sym_views_keyword] = ACTIONS(12736),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12736),
    [sym_preproc_open] = ACTIONS(12736),
    [sym_preproc_close] = ACTIONS(12736),
  },
  [STATE(5167)] = {
    [anon_sym_SEMI] = ACTIONS(12740),
    [aux_sym_where_condition_token1] = ACTIONS(12742),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12740),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12740),
    [anon_sym_LBRACK] = ACTIONS(12740),
    [aux_sym_basic_type_token6] = ACTIONS(12742),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12740),
    [aux_sym_addafter_modification_token1] = ACTIONS(12740),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12740),
    [aux_sym_modify_modification_token1] = ACTIONS(12740),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12740),
    [aux_sym_movelast_modification_token1] = ACTIONS(12740),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12740),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12740),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12740),
    [anon_sym_POUNDif] = ACTIONS(12740),
    [anon_sym_POUNDIF] = ACTIONS(12740),
    [anon_sym_POUNDIf] = ACTIONS(12740),
    [anon_sym_POUNDelif] = ACTIONS(12740),
    [anon_sym_POUNDELIF] = ACTIONS(12740),
    [anon_sym_POUNDElif] = ACTIONS(12740),
    [anon_sym_POUNDelse] = ACTIONS(12740),
    [anon_sym_POUNDELSE] = ACTIONS(12740),
    [anon_sym_POUNDElse] = ACTIONS(12740),
    [anon_sym_POUNDelse2] = ACTIONS(12740),
    [anon_sym_POUNDELSE2] = ACTIONS(12740),
    [anon_sym_POUNDElse2] = ACTIONS(12740),
    [anon_sym_POUNDendif] = ACTIONS(12740),
    [anon_sym_POUNDENDIF] = ACTIONS(12740),
    [anon_sym_POUNDEndif] = ACTIONS(12740),
    [anon_sym_POUNDendif2] = ACTIONS(12740),
    [anon_sym_POUNDENDIF2] = ACTIONS(12740),
    [anon_sym_POUNDEndif2] = ACTIONS(12740),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12740),
    [sym_trigger_keyword] = ACTIONS(12740),
    [sym_var_keyword] = ACTIONS(12740),
    [sym_local_keyword] = ACTIONS(12740),
    [sym_internal_keyword] = ACTIONS(12740),
    [sym_protected_keyword] = ACTIONS(12740),
    [sym_event_keyword] = ACTIONS(12740),
    [sym_fields_keyword] = ACTIONS(12740),
    [sym_keys_keyword] = ACTIONS(12740),
    [sym_fieldgroups_keyword] = ACTIONS(12740),
    [sym_actions_keyword] = ACTIONS(12740),
    [sym_layout_keyword] = ACTIONS(12740),
    [sym_area_keyword] = ACTIONS(12740),
    [sym_group_keyword] = ACTIONS(12740),
    [sym_repeater_keyword] = ACTIONS(12740),
    [sym_cuegroup_keyword] = ACTIONS(12740),
    [sym_fixed_keyword] = ACTIONS(12740),
    [sym_grid_keyword] = ACTIONS(12740),
    [sym_part_keyword] = ACTIONS(12740),
    [sym_systempart_keyword] = ACTIONS(12740),
    [sym_usercontrol_keyword] = ACTIONS(12740),
    [sym_dataset_keyword] = ACTIONS(12740),
    [sym_elements_keyword] = ACTIONS(12740),
    [sym_dataitem_keyword] = ACTIONS(12740),
    [sym_column_keyword] = ACTIONS(12740),
    [sym_filter_keyword] = ACTIONS(12740),
    [sym_labels_keyword] = ACTIONS(12740),
    [sym_rendering_keyword] = ACTIONS(12740),
    [sym_requestpage_keyword] = ACTIONS(12740),
    [sym_schema_keyword] = ACTIONS(12740),
    [sym_views_keyword] = ACTIONS(12740),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12740),
    [sym_preproc_open] = ACTIONS(12740),
    [sym_preproc_close] = ACTIONS(12740),
  },
  [STATE(5168)] = {
    [anon_sym_SEMI] = ACTIONS(12744),
    [aux_sym_where_condition_token1] = ACTIONS(12746),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12744),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12744),
    [anon_sym_LBRACK] = ACTIONS(12744),
    [aux_sym_basic_type_token6] = ACTIONS(12746),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12744),
    [aux_sym_addafter_modification_token1] = ACTIONS(12744),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12744),
    [aux_sym_modify_modification_token1] = ACTIONS(12744),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12744),
    [aux_sym_movelast_modification_token1] = ACTIONS(12744),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12744),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12744),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12744),
    [anon_sym_POUNDif] = ACTIONS(12744),
    [anon_sym_POUNDIF] = ACTIONS(12744),
    [anon_sym_POUNDIf] = ACTIONS(12744),
    [anon_sym_POUNDelif] = ACTIONS(12744),
    [anon_sym_POUNDELIF] = ACTIONS(12744),
    [anon_sym_POUNDElif] = ACTIONS(12744),
    [anon_sym_POUNDelse] = ACTIONS(12744),
    [anon_sym_POUNDELSE] = ACTIONS(12744),
    [anon_sym_POUNDElse] = ACTIONS(12744),
    [anon_sym_POUNDelse2] = ACTIONS(12744),
    [anon_sym_POUNDELSE2] = ACTIONS(12744),
    [anon_sym_POUNDElse2] = ACTIONS(12744),
    [anon_sym_POUNDendif] = ACTIONS(12744),
    [anon_sym_POUNDENDIF] = ACTIONS(12744),
    [anon_sym_POUNDEndif] = ACTIONS(12744),
    [anon_sym_POUNDendif2] = ACTIONS(12744),
    [anon_sym_POUNDENDIF2] = ACTIONS(12744),
    [anon_sym_POUNDEndif2] = ACTIONS(12744),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12744),
    [sym_trigger_keyword] = ACTIONS(12744),
    [sym_var_keyword] = ACTIONS(12744),
    [sym_local_keyword] = ACTIONS(12744),
    [sym_internal_keyword] = ACTIONS(12744),
    [sym_protected_keyword] = ACTIONS(12744),
    [sym_event_keyword] = ACTIONS(12744),
    [sym_fields_keyword] = ACTIONS(12744),
    [sym_keys_keyword] = ACTIONS(12744),
    [sym_fieldgroups_keyword] = ACTIONS(12744),
    [sym_actions_keyword] = ACTIONS(12744),
    [sym_layout_keyword] = ACTIONS(12744),
    [sym_area_keyword] = ACTIONS(12744),
    [sym_group_keyword] = ACTIONS(12744),
    [sym_repeater_keyword] = ACTIONS(12744),
    [sym_cuegroup_keyword] = ACTIONS(12744),
    [sym_fixed_keyword] = ACTIONS(12744),
    [sym_grid_keyword] = ACTIONS(12744),
    [sym_part_keyword] = ACTIONS(12744),
    [sym_systempart_keyword] = ACTIONS(12744),
    [sym_usercontrol_keyword] = ACTIONS(12744),
    [sym_dataset_keyword] = ACTIONS(12744),
    [sym_elements_keyword] = ACTIONS(12744),
    [sym_dataitem_keyword] = ACTIONS(12744),
    [sym_column_keyword] = ACTIONS(12744),
    [sym_filter_keyword] = ACTIONS(12744),
    [sym_labels_keyword] = ACTIONS(12744),
    [sym_rendering_keyword] = ACTIONS(12744),
    [sym_requestpage_keyword] = ACTIONS(12744),
    [sym_schema_keyword] = ACTIONS(12744),
    [sym_views_keyword] = ACTIONS(12744),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12744),
    [sym_preproc_open] = ACTIONS(12744),
    [sym_preproc_close] = ACTIONS(12744),
  },
  [STATE(5169)] = {
    [anon_sym_SEMI] = ACTIONS(12744),
    [aux_sym_where_condition_token1] = ACTIONS(12746),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12744),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12744),
    [anon_sym_LBRACK] = ACTIONS(12744),
    [aux_sym_basic_type_token6] = ACTIONS(12746),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12744),
    [aux_sym_addafter_modification_token1] = ACTIONS(12744),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12744),
    [aux_sym_modify_modification_token1] = ACTIONS(12744),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12744),
    [aux_sym_movelast_modification_token1] = ACTIONS(12744),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12744),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12744),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12744),
    [anon_sym_POUNDif] = ACTIONS(12744),
    [anon_sym_POUNDIF] = ACTIONS(12744),
    [anon_sym_POUNDIf] = ACTIONS(12744),
    [anon_sym_POUNDelif] = ACTIONS(12744),
    [anon_sym_POUNDELIF] = ACTIONS(12744),
    [anon_sym_POUNDElif] = ACTIONS(12744),
    [anon_sym_POUNDelse] = ACTIONS(12744),
    [anon_sym_POUNDELSE] = ACTIONS(12744),
    [anon_sym_POUNDElse] = ACTIONS(12744),
    [anon_sym_POUNDelse2] = ACTIONS(12744),
    [anon_sym_POUNDELSE2] = ACTIONS(12744),
    [anon_sym_POUNDElse2] = ACTIONS(12744),
    [anon_sym_POUNDendif] = ACTIONS(12744),
    [anon_sym_POUNDENDIF] = ACTIONS(12744),
    [anon_sym_POUNDEndif] = ACTIONS(12744),
    [anon_sym_POUNDendif2] = ACTIONS(12744),
    [anon_sym_POUNDENDIF2] = ACTIONS(12744),
    [anon_sym_POUNDEndif2] = ACTIONS(12744),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12744),
    [sym_trigger_keyword] = ACTIONS(12744),
    [sym_var_keyword] = ACTIONS(12744),
    [sym_local_keyword] = ACTIONS(12744),
    [sym_internal_keyword] = ACTIONS(12744),
    [sym_protected_keyword] = ACTIONS(12744),
    [sym_event_keyword] = ACTIONS(12744),
    [sym_fields_keyword] = ACTIONS(12744),
    [sym_keys_keyword] = ACTIONS(12744),
    [sym_fieldgroups_keyword] = ACTIONS(12744),
    [sym_actions_keyword] = ACTIONS(12744),
    [sym_layout_keyword] = ACTIONS(12744),
    [sym_area_keyword] = ACTIONS(12744),
    [sym_group_keyword] = ACTIONS(12744),
    [sym_repeater_keyword] = ACTIONS(12744),
    [sym_cuegroup_keyword] = ACTIONS(12744),
    [sym_fixed_keyword] = ACTIONS(12744),
    [sym_grid_keyword] = ACTIONS(12744),
    [sym_part_keyword] = ACTIONS(12744),
    [sym_systempart_keyword] = ACTIONS(12744),
    [sym_usercontrol_keyword] = ACTIONS(12744),
    [sym_dataset_keyword] = ACTIONS(12744),
    [sym_elements_keyword] = ACTIONS(12744),
    [sym_dataitem_keyword] = ACTIONS(12744),
    [sym_column_keyword] = ACTIONS(12744),
    [sym_filter_keyword] = ACTIONS(12744),
    [sym_labels_keyword] = ACTIONS(12744),
    [sym_rendering_keyword] = ACTIONS(12744),
    [sym_requestpage_keyword] = ACTIONS(12744),
    [sym_schema_keyword] = ACTIONS(12744),
    [sym_views_keyword] = ACTIONS(12744),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12744),
    [sym_preproc_open] = ACTIONS(12744),
    [sym_preproc_close] = ACTIONS(12744),
  },
  [STATE(5170)] = {
    [anon_sym_SEMI] = ACTIONS(12748),
    [aux_sym_where_condition_token1] = ACTIONS(12750),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12748),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12748),
    [anon_sym_LBRACK] = ACTIONS(12748),
    [aux_sym_basic_type_token6] = ACTIONS(12750),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12748),
    [aux_sym_addafter_modification_token1] = ACTIONS(12748),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12748),
    [aux_sym_modify_modification_token1] = ACTIONS(12748),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12748),
    [aux_sym_movelast_modification_token1] = ACTIONS(12748),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12748),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12748),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12748),
    [anon_sym_POUNDif] = ACTIONS(12748),
    [anon_sym_POUNDIF] = ACTIONS(12748),
    [anon_sym_POUNDIf] = ACTIONS(12748),
    [anon_sym_POUNDelif] = ACTIONS(12748),
    [anon_sym_POUNDELIF] = ACTIONS(12748),
    [anon_sym_POUNDElif] = ACTIONS(12748),
    [anon_sym_POUNDelse] = ACTIONS(12748),
    [anon_sym_POUNDELSE] = ACTIONS(12748),
    [anon_sym_POUNDElse] = ACTIONS(12748),
    [anon_sym_POUNDelse2] = ACTIONS(12748),
    [anon_sym_POUNDELSE2] = ACTIONS(12748),
    [anon_sym_POUNDElse2] = ACTIONS(12748),
    [anon_sym_POUNDendif] = ACTIONS(12748),
    [anon_sym_POUNDENDIF] = ACTIONS(12748),
    [anon_sym_POUNDEndif] = ACTIONS(12748),
    [anon_sym_POUNDendif2] = ACTIONS(12748),
    [anon_sym_POUNDENDIF2] = ACTIONS(12748),
    [anon_sym_POUNDEndif2] = ACTIONS(12748),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12748),
    [sym_trigger_keyword] = ACTIONS(12748),
    [sym_var_keyword] = ACTIONS(12748),
    [sym_local_keyword] = ACTIONS(12748),
    [sym_internal_keyword] = ACTIONS(12748),
    [sym_protected_keyword] = ACTIONS(12748),
    [sym_event_keyword] = ACTIONS(12748),
    [sym_fields_keyword] = ACTIONS(12748),
    [sym_keys_keyword] = ACTIONS(12748),
    [sym_fieldgroups_keyword] = ACTIONS(12748),
    [sym_actions_keyword] = ACTIONS(12748),
    [sym_layout_keyword] = ACTIONS(12748),
    [sym_area_keyword] = ACTIONS(12748),
    [sym_group_keyword] = ACTIONS(12748),
    [sym_repeater_keyword] = ACTIONS(12748),
    [sym_cuegroup_keyword] = ACTIONS(12748),
    [sym_fixed_keyword] = ACTIONS(12748),
    [sym_grid_keyword] = ACTIONS(12748),
    [sym_part_keyword] = ACTIONS(12748),
    [sym_systempart_keyword] = ACTIONS(12748),
    [sym_usercontrol_keyword] = ACTIONS(12748),
    [sym_dataset_keyword] = ACTIONS(12748),
    [sym_elements_keyword] = ACTIONS(12748),
    [sym_dataitem_keyword] = ACTIONS(12748),
    [sym_column_keyword] = ACTIONS(12748),
    [sym_filter_keyword] = ACTIONS(12748),
    [sym_labels_keyword] = ACTIONS(12748),
    [sym_rendering_keyword] = ACTIONS(12748),
    [sym_requestpage_keyword] = ACTIONS(12748),
    [sym_schema_keyword] = ACTIONS(12748),
    [sym_views_keyword] = ACTIONS(12748),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12748),
    [sym_preproc_open] = ACTIONS(12748),
    [sym_preproc_close] = ACTIONS(12748),
  },
  [STATE(5171)] = {
    [anon_sym_SEMI] = ACTIONS(12752),
    [aux_sym_where_condition_token1] = ACTIONS(12754),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12752),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12752),
    [anon_sym_LBRACK] = ACTIONS(12752),
    [aux_sym_basic_type_token6] = ACTIONS(12754),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12752),
    [aux_sym_addafter_modification_token1] = ACTIONS(12752),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12752),
    [aux_sym_modify_modification_token1] = ACTIONS(12752),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12752),
    [aux_sym_movelast_modification_token1] = ACTIONS(12752),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12752),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12752),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12752),
    [anon_sym_POUNDif] = ACTIONS(12752),
    [anon_sym_POUNDIF] = ACTIONS(12752),
    [anon_sym_POUNDIf] = ACTIONS(12752),
    [anon_sym_POUNDelif] = ACTIONS(12752),
    [anon_sym_POUNDELIF] = ACTIONS(12752),
    [anon_sym_POUNDElif] = ACTIONS(12752),
    [anon_sym_POUNDelse] = ACTIONS(12752),
    [anon_sym_POUNDELSE] = ACTIONS(12752),
    [anon_sym_POUNDElse] = ACTIONS(12752),
    [anon_sym_POUNDelse2] = ACTIONS(12752),
    [anon_sym_POUNDELSE2] = ACTIONS(12752),
    [anon_sym_POUNDElse2] = ACTIONS(12752),
    [anon_sym_POUNDendif] = ACTIONS(12752),
    [anon_sym_POUNDENDIF] = ACTIONS(12752),
    [anon_sym_POUNDEndif] = ACTIONS(12752),
    [anon_sym_POUNDendif2] = ACTIONS(12752),
    [anon_sym_POUNDENDIF2] = ACTIONS(12752),
    [anon_sym_POUNDEndif2] = ACTIONS(12752),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12752),
    [sym_trigger_keyword] = ACTIONS(12752),
    [sym_var_keyword] = ACTIONS(12752),
    [sym_local_keyword] = ACTIONS(12752),
    [sym_internal_keyword] = ACTIONS(12752),
    [sym_protected_keyword] = ACTIONS(12752),
    [sym_event_keyword] = ACTIONS(12752),
    [sym_fields_keyword] = ACTIONS(12752),
    [sym_keys_keyword] = ACTIONS(12752),
    [sym_fieldgroups_keyword] = ACTIONS(12752),
    [sym_actions_keyword] = ACTIONS(12752),
    [sym_layout_keyword] = ACTIONS(12752),
    [sym_area_keyword] = ACTIONS(12752),
    [sym_group_keyword] = ACTIONS(12752),
    [sym_repeater_keyword] = ACTIONS(12752),
    [sym_cuegroup_keyword] = ACTIONS(12752),
    [sym_fixed_keyword] = ACTIONS(12752),
    [sym_grid_keyword] = ACTIONS(12752),
    [sym_part_keyword] = ACTIONS(12752),
    [sym_systempart_keyword] = ACTIONS(12752),
    [sym_usercontrol_keyword] = ACTIONS(12752),
    [sym_dataset_keyword] = ACTIONS(12752),
    [sym_elements_keyword] = ACTIONS(12752),
    [sym_dataitem_keyword] = ACTIONS(12752),
    [sym_column_keyword] = ACTIONS(12752),
    [sym_filter_keyword] = ACTIONS(12752),
    [sym_labels_keyword] = ACTIONS(12752),
    [sym_rendering_keyword] = ACTIONS(12752),
    [sym_requestpage_keyword] = ACTIONS(12752),
    [sym_schema_keyword] = ACTIONS(12752),
    [sym_views_keyword] = ACTIONS(12752),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12752),
    [sym_preproc_open] = ACTIONS(12752),
    [sym_preproc_close] = ACTIONS(12752),
  },
  [STATE(5172)] = {
    [anon_sym_SEMI] = ACTIONS(12756),
    [aux_sym_where_condition_token1] = ACTIONS(12758),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12756),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12756),
    [anon_sym_LBRACK] = ACTIONS(12756),
    [aux_sym_basic_type_token6] = ACTIONS(12758),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12756),
    [aux_sym_addafter_modification_token1] = ACTIONS(12756),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12756),
    [aux_sym_modify_modification_token1] = ACTIONS(12756),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12756),
    [aux_sym_movelast_modification_token1] = ACTIONS(12756),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12756),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12756),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12756),
    [anon_sym_POUNDif] = ACTIONS(12756),
    [anon_sym_POUNDIF] = ACTIONS(12756),
    [anon_sym_POUNDIf] = ACTIONS(12756),
    [anon_sym_POUNDelif] = ACTIONS(12756),
    [anon_sym_POUNDELIF] = ACTIONS(12756),
    [anon_sym_POUNDElif] = ACTIONS(12756),
    [anon_sym_POUNDelse] = ACTIONS(12756),
    [anon_sym_POUNDELSE] = ACTIONS(12756),
    [anon_sym_POUNDElse] = ACTIONS(12756),
    [anon_sym_POUNDelse2] = ACTIONS(12756),
    [anon_sym_POUNDELSE2] = ACTIONS(12756),
    [anon_sym_POUNDElse2] = ACTIONS(12756),
    [anon_sym_POUNDendif] = ACTIONS(12756),
    [anon_sym_POUNDENDIF] = ACTIONS(12756),
    [anon_sym_POUNDEndif] = ACTIONS(12756),
    [anon_sym_POUNDendif2] = ACTIONS(12756),
    [anon_sym_POUNDENDIF2] = ACTIONS(12756),
    [anon_sym_POUNDEndif2] = ACTIONS(12756),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12756),
    [sym_trigger_keyword] = ACTIONS(12756),
    [sym_var_keyword] = ACTIONS(12756),
    [sym_local_keyword] = ACTIONS(12756),
    [sym_internal_keyword] = ACTIONS(12756),
    [sym_protected_keyword] = ACTIONS(12756),
    [sym_event_keyword] = ACTIONS(12756),
    [sym_fields_keyword] = ACTIONS(12756),
    [sym_keys_keyword] = ACTIONS(12756),
    [sym_fieldgroups_keyword] = ACTIONS(12756),
    [sym_actions_keyword] = ACTIONS(12756),
    [sym_layout_keyword] = ACTIONS(12756),
    [sym_area_keyword] = ACTIONS(12756),
    [sym_group_keyword] = ACTIONS(12756),
    [sym_repeater_keyword] = ACTIONS(12756),
    [sym_cuegroup_keyword] = ACTIONS(12756),
    [sym_fixed_keyword] = ACTIONS(12756),
    [sym_grid_keyword] = ACTIONS(12756),
    [sym_part_keyword] = ACTIONS(12756),
    [sym_systempart_keyword] = ACTIONS(12756),
    [sym_usercontrol_keyword] = ACTIONS(12756),
    [sym_dataset_keyword] = ACTIONS(12756),
    [sym_elements_keyword] = ACTIONS(12756),
    [sym_dataitem_keyword] = ACTIONS(12756),
    [sym_column_keyword] = ACTIONS(12756),
    [sym_filter_keyword] = ACTIONS(12756),
    [sym_labels_keyword] = ACTIONS(12756),
    [sym_rendering_keyword] = ACTIONS(12756),
    [sym_requestpage_keyword] = ACTIONS(12756),
    [sym_schema_keyword] = ACTIONS(12756),
    [sym_views_keyword] = ACTIONS(12756),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12756),
    [sym_preproc_open] = ACTIONS(12756),
    [sym_preproc_close] = ACTIONS(12756),
  },
  [STATE(5173)] = {
    [anon_sym_SEMI] = ACTIONS(12760),
    [aux_sym_where_condition_token1] = ACTIONS(12762),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12760),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12760),
    [anon_sym_LBRACK] = ACTIONS(12760),
    [aux_sym_basic_type_token6] = ACTIONS(12762),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12760),
    [aux_sym_addafter_modification_token1] = ACTIONS(12760),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12760),
    [aux_sym_modify_modification_token1] = ACTIONS(12760),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12760),
    [aux_sym_movelast_modification_token1] = ACTIONS(12760),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12760),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12760),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12760),
    [anon_sym_POUNDif] = ACTIONS(12760),
    [anon_sym_POUNDIF] = ACTIONS(12760),
    [anon_sym_POUNDIf] = ACTIONS(12760),
    [anon_sym_POUNDelif] = ACTIONS(12760),
    [anon_sym_POUNDELIF] = ACTIONS(12760),
    [anon_sym_POUNDElif] = ACTIONS(12760),
    [anon_sym_POUNDelse] = ACTIONS(12760),
    [anon_sym_POUNDELSE] = ACTIONS(12760),
    [anon_sym_POUNDElse] = ACTIONS(12760),
    [anon_sym_POUNDelse2] = ACTIONS(12760),
    [anon_sym_POUNDELSE2] = ACTIONS(12760),
    [anon_sym_POUNDElse2] = ACTIONS(12760),
    [anon_sym_POUNDendif] = ACTIONS(12760),
    [anon_sym_POUNDENDIF] = ACTIONS(12760),
    [anon_sym_POUNDEndif] = ACTIONS(12760),
    [anon_sym_POUNDendif2] = ACTIONS(12760),
    [anon_sym_POUNDENDIF2] = ACTIONS(12760),
    [anon_sym_POUNDEndif2] = ACTIONS(12760),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12760),
    [sym_trigger_keyword] = ACTIONS(12760),
    [sym_var_keyword] = ACTIONS(12760),
    [sym_local_keyword] = ACTIONS(12760),
    [sym_internal_keyword] = ACTIONS(12760),
    [sym_protected_keyword] = ACTIONS(12760),
    [sym_event_keyword] = ACTIONS(12760),
    [sym_fields_keyword] = ACTIONS(12760),
    [sym_keys_keyword] = ACTIONS(12760),
    [sym_fieldgroups_keyword] = ACTIONS(12760),
    [sym_actions_keyword] = ACTIONS(12760),
    [sym_layout_keyword] = ACTIONS(12760),
    [sym_area_keyword] = ACTIONS(12760),
    [sym_group_keyword] = ACTIONS(12760),
    [sym_repeater_keyword] = ACTIONS(12760),
    [sym_cuegroup_keyword] = ACTIONS(12760),
    [sym_fixed_keyword] = ACTIONS(12760),
    [sym_grid_keyword] = ACTIONS(12760),
    [sym_part_keyword] = ACTIONS(12760),
    [sym_systempart_keyword] = ACTIONS(12760),
    [sym_usercontrol_keyword] = ACTIONS(12760),
    [sym_dataset_keyword] = ACTIONS(12760),
    [sym_elements_keyword] = ACTIONS(12760),
    [sym_dataitem_keyword] = ACTIONS(12760),
    [sym_column_keyword] = ACTIONS(12760),
    [sym_filter_keyword] = ACTIONS(12760),
    [sym_labels_keyword] = ACTIONS(12760),
    [sym_rendering_keyword] = ACTIONS(12760),
    [sym_requestpage_keyword] = ACTIONS(12760),
    [sym_schema_keyword] = ACTIONS(12760),
    [sym_views_keyword] = ACTIONS(12760),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12760),
    [sym_preproc_open] = ACTIONS(12760),
    [sym_preproc_close] = ACTIONS(12760),
  },
  [STATE(5174)] = {
    [anon_sym_SEMI] = ACTIONS(12764),
    [aux_sym_where_condition_token1] = ACTIONS(12766),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12764),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12764),
    [anon_sym_LBRACK] = ACTIONS(12764),
    [aux_sym_basic_type_token6] = ACTIONS(12766),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12764),
    [aux_sym_addafter_modification_token1] = ACTIONS(12764),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12764),
    [aux_sym_modify_modification_token1] = ACTIONS(12764),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12764),
    [aux_sym_movelast_modification_token1] = ACTIONS(12764),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12764),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12764),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12764),
    [anon_sym_POUNDif] = ACTIONS(12764),
    [anon_sym_POUNDIF] = ACTIONS(12764),
    [anon_sym_POUNDIf] = ACTIONS(12764),
    [anon_sym_POUNDelif] = ACTIONS(12764),
    [anon_sym_POUNDELIF] = ACTIONS(12764),
    [anon_sym_POUNDElif] = ACTIONS(12764),
    [anon_sym_POUNDelse] = ACTIONS(12764),
    [anon_sym_POUNDELSE] = ACTIONS(12764),
    [anon_sym_POUNDElse] = ACTIONS(12764),
    [anon_sym_POUNDelse2] = ACTIONS(12764),
    [anon_sym_POUNDELSE2] = ACTIONS(12764),
    [anon_sym_POUNDElse2] = ACTIONS(12764),
    [anon_sym_POUNDendif] = ACTIONS(12764),
    [anon_sym_POUNDENDIF] = ACTIONS(12764),
    [anon_sym_POUNDEndif] = ACTIONS(12764),
    [anon_sym_POUNDendif2] = ACTIONS(12764),
    [anon_sym_POUNDENDIF2] = ACTIONS(12764),
    [anon_sym_POUNDEndif2] = ACTIONS(12764),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12764),
    [sym_trigger_keyword] = ACTIONS(12764),
    [sym_var_keyword] = ACTIONS(12764),
    [sym_local_keyword] = ACTIONS(12764),
    [sym_internal_keyword] = ACTIONS(12764),
    [sym_protected_keyword] = ACTIONS(12764),
    [sym_event_keyword] = ACTIONS(12764),
    [sym_fields_keyword] = ACTIONS(12764),
    [sym_keys_keyword] = ACTIONS(12764),
    [sym_fieldgroups_keyword] = ACTIONS(12764),
    [sym_actions_keyword] = ACTIONS(12764),
    [sym_layout_keyword] = ACTIONS(12764),
    [sym_area_keyword] = ACTIONS(12764),
    [sym_group_keyword] = ACTIONS(12764),
    [sym_repeater_keyword] = ACTIONS(12764),
    [sym_cuegroup_keyword] = ACTIONS(12764),
    [sym_fixed_keyword] = ACTIONS(12764),
    [sym_grid_keyword] = ACTIONS(12764),
    [sym_part_keyword] = ACTIONS(12764),
    [sym_systempart_keyword] = ACTIONS(12764),
    [sym_usercontrol_keyword] = ACTIONS(12764),
    [sym_dataset_keyword] = ACTIONS(12764),
    [sym_elements_keyword] = ACTIONS(12764),
    [sym_dataitem_keyword] = ACTIONS(12764),
    [sym_column_keyword] = ACTIONS(12764),
    [sym_filter_keyword] = ACTIONS(12764),
    [sym_labels_keyword] = ACTIONS(12764),
    [sym_rendering_keyword] = ACTIONS(12764),
    [sym_requestpage_keyword] = ACTIONS(12764),
    [sym_schema_keyword] = ACTIONS(12764),
    [sym_views_keyword] = ACTIONS(12764),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12764),
    [sym_preproc_open] = ACTIONS(12764),
    [sym_preproc_close] = ACTIONS(12764),
  },
  [STATE(5175)] = {
    [anon_sym_SEMI] = ACTIONS(12768),
    [aux_sym_where_condition_token1] = ACTIONS(12770),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12768),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12768),
    [anon_sym_LBRACK] = ACTIONS(12768),
    [aux_sym_basic_type_token6] = ACTIONS(12770),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12768),
    [aux_sym_addafter_modification_token1] = ACTIONS(12768),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12768),
    [aux_sym_modify_modification_token1] = ACTIONS(12768),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12768),
    [aux_sym_movelast_modification_token1] = ACTIONS(12768),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12768),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12768),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12768),
    [anon_sym_POUNDif] = ACTIONS(12768),
    [anon_sym_POUNDIF] = ACTIONS(12768),
    [anon_sym_POUNDIf] = ACTIONS(12768),
    [anon_sym_POUNDelif] = ACTIONS(12768),
    [anon_sym_POUNDELIF] = ACTIONS(12768),
    [anon_sym_POUNDElif] = ACTIONS(12768),
    [anon_sym_POUNDelse] = ACTIONS(12768),
    [anon_sym_POUNDELSE] = ACTIONS(12768),
    [anon_sym_POUNDElse] = ACTIONS(12768),
    [anon_sym_POUNDelse2] = ACTIONS(12768),
    [anon_sym_POUNDELSE2] = ACTIONS(12768),
    [anon_sym_POUNDElse2] = ACTIONS(12768),
    [anon_sym_POUNDendif] = ACTIONS(12768),
    [anon_sym_POUNDENDIF] = ACTIONS(12768),
    [anon_sym_POUNDEndif] = ACTIONS(12768),
    [anon_sym_POUNDendif2] = ACTIONS(12768),
    [anon_sym_POUNDENDIF2] = ACTIONS(12768),
    [anon_sym_POUNDEndif2] = ACTIONS(12768),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12768),
    [sym_trigger_keyword] = ACTIONS(12768),
    [sym_var_keyword] = ACTIONS(12768),
    [sym_local_keyword] = ACTIONS(12768),
    [sym_internal_keyword] = ACTIONS(12768),
    [sym_protected_keyword] = ACTIONS(12768),
    [sym_event_keyword] = ACTIONS(12768),
    [sym_fields_keyword] = ACTIONS(12768),
    [sym_keys_keyword] = ACTIONS(12768),
    [sym_fieldgroups_keyword] = ACTIONS(12768),
    [sym_actions_keyword] = ACTIONS(12768),
    [sym_layout_keyword] = ACTIONS(12768),
    [sym_area_keyword] = ACTIONS(12768),
    [sym_group_keyword] = ACTIONS(12768),
    [sym_repeater_keyword] = ACTIONS(12768),
    [sym_cuegroup_keyword] = ACTIONS(12768),
    [sym_fixed_keyword] = ACTIONS(12768),
    [sym_grid_keyword] = ACTIONS(12768),
    [sym_part_keyword] = ACTIONS(12768),
    [sym_systempart_keyword] = ACTIONS(12768),
    [sym_usercontrol_keyword] = ACTIONS(12768),
    [sym_dataset_keyword] = ACTIONS(12768),
    [sym_elements_keyword] = ACTIONS(12768),
    [sym_dataitem_keyword] = ACTIONS(12768),
    [sym_column_keyword] = ACTIONS(12768),
    [sym_filter_keyword] = ACTIONS(12768),
    [sym_labels_keyword] = ACTIONS(12768),
    [sym_rendering_keyword] = ACTIONS(12768),
    [sym_requestpage_keyword] = ACTIONS(12768),
    [sym_schema_keyword] = ACTIONS(12768),
    [sym_views_keyword] = ACTIONS(12768),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12768),
    [sym_preproc_open] = ACTIONS(12768),
    [sym_preproc_close] = ACTIONS(12768),
  },
  [STATE(5176)] = {
    [anon_sym_SEMI] = ACTIONS(12772),
    [aux_sym_where_condition_token1] = ACTIONS(12774),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12772),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12772),
    [anon_sym_LBRACK] = ACTIONS(12772),
    [aux_sym_basic_type_token6] = ACTIONS(12774),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12772),
    [aux_sym_addafter_modification_token1] = ACTIONS(12772),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12772),
    [aux_sym_modify_modification_token1] = ACTIONS(12772),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12772),
    [aux_sym_movelast_modification_token1] = ACTIONS(12772),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12772),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12772),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12772),
    [anon_sym_POUNDif] = ACTIONS(12772),
    [anon_sym_POUNDIF] = ACTIONS(12772),
    [anon_sym_POUNDIf] = ACTIONS(12772),
    [anon_sym_POUNDelif] = ACTIONS(12772),
    [anon_sym_POUNDELIF] = ACTIONS(12772),
    [anon_sym_POUNDElif] = ACTIONS(12772),
    [anon_sym_POUNDelse] = ACTIONS(12772),
    [anon_sym_POUNDELSE] = ACTIONS(12772),
    [anon_sym_POUNDElse] = ACTIONS(12772),
    [anon_sym_POUNDelse2] = ACTIONS(12772),
    [anon_sym_POUNDELSE2] = ACTIONS(12772),
    [anon_sym_POUNDElse2] = ACTIONS(12772),
    [anon_sym_POUNDendif] = ACTIONS(12772),
    [anon_sym_POUNDENDIF] = ACTIONS(12772),
    [anon_sym_POUNDEndif] = ACTIONS(12772),
    [anon_sym_POUNDendif2] = ACTIONS(12772),
    [anon_sym_POUNDENDIF2] = ACTIONS(12772),
    [anon_sym_POUNDEndif2] = ACTIONS(12772),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12772),
    [sym_trigger_keyword] = ACTIONS(12772),
    [sym_var_keyword] = ACTIONS(12772),
    [sym_local_keyword] = ACTIONS(12772),
    [sym_internal_keyword] = ACTIONS(12772),
    [sym_protected_keyword] = ACTIONS(12772),
    [sym_event_keyword] = ACTIONS(12772),
    [sym_fields_keyword] = ACTIONS(12772),
    [sym_keys_keyword] = ACTIONS(12772),
    [sym_fieldgroups_keyword] = ACTIONS(12772),
    [sym_actions_keyword] = ACTIONS(12772),
    [sym_layout_keyword] = ACTIONS(12772),
    [sym_area_keyword] = ACTIONS(12772),
    [sym_group_keyword] = ACTIONS(12772),
    [sym_repeater_keyword] = ACTIONS(12772),
    [sym_cuegroup_keyword] = ACTIONS(12772),
    [sym_fixed_keyword] = ACTIONS(12772),
    [sym_grid_keyword] = ACTIONS(12772),
    [sym_part_keyword] = ACTIONS(12772),
    [sym_systempart_keyword] = ACTIONS(12772),
    [sym_usercontrol_keyword] = ACTIONS(12772),
    [sym_dataset_keyword] = ACTIONS(12772),
    [sym_elements_keyword] = ACTIONS(12772),
    [sym_dataitem_keyword] = ACTIONS(12772),
    [sym_column_keyword] = ACTIONS(12772),
    [sym_filter_keyword] = ACTIONS(12772),
    [sym_labels_keyword] = ACTIONS(12772),
    [sym_rendering_keyword] = ACTIONS(12772),
    [sym_requestpage_keyword] = ACTIONS(12772),
    [sym_schema_keyword] = ACTIONS(12772),
    [sym_views_keyword] = ACTIONS(12772),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12772),
    [sym_preproc_open] = ACTIONS(12772),
    [sym_preproc_close] = ACTIONS(12772),
  },
  [STATE(5177)] = {
    [anon_sym_SEMI] = ACTIONS(12772),
    [aux_sym_where_condition_token1] = ACTIONS(12774),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12772),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12772),
    [anon_sym_LBRACK] = ACTIONS(12772),
    [aux_sym_basic_type_token6] = ACTIONS(12774),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12772),
    [aux_sym_addafter_modification_token1] = ACTIONS(12772),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12772),
    [aux_sym_modify_modification_token1] = ACTIONS(12772),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12772),
    [aux_sym_movelast_modification_token1] = ACTIONS(12772),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12772),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12772),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12772),
    [anon_sym_POUNDif] = ACTIONS(12772),
    [anon_sym_POUNDIF] = ACTIONS(12772),
    [anon_sym_POUNDIf] = ACTIONS(12772),
    [anon_sym_POUNDelif] = ACTIONS(12772),
    [anon_sym_POUNDELIF] = ACTIONS(12772),
    [anon_sym_POUNDElif] = ACTIONS(12772),
    [anon_sym_POUNDelse] = ACTIONS(12772),
    [anon_sym_POUNDELSE] = ACTIONS(12772),
    [anon_sym_POUNDElse] = ACTIONS(12772),
    [anon_sym_POUNDelse2] = ACTIONS(12772),
    [anon_sym_POUNDELSE2] = ACTIONS(12772),
    [anon_sym_POUNDElse2] = ACTIONS(12772),
    [anon_sym_POUNDendif] = ACTIONS(12772),
    [anon_sym_POUNDENDIF] = ACTIONS(12772),
    [anon_sym_POUNDEndif] = ACTIONS(12772),
    [anon_sym_POUNDendif2] = ACTIONS(12772),
    [anon_sym_POUNDENDIF2] = ACTIONS(12772),
    [anon_sym_POUNDEndif2] = ACTIONS(12772),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12772),
    [sym_trigger_keyword] = ACTIONS(12772),
    [sym_var_keyword] = ACTIONS(12772),
    [sym_local_keyword] = ACTIONS(12772),
    [sym_internal_keyword] = ACTIONS(12772),
    [sym_protected_keyword] = ACTIONS(12772),
    [sym_event_keyword] = ACTIONS(12772),
    [sym_fields_keyword] = ACTIONS(12772),
    [sym_keys_keyword] = ACTIONS(12772),
    [sym_fieldgroups_keyword] = ACTIONS(12772),
    [sym_actions_keyword] = ACTIONS(12772),
    [sym_layout_keyword] = ACTIONS(12772),
    [sym_area_keyword] = ACTIONS(12772),
    [sym_group_keyword] = ACTIONS(12772),
    [sym_repeater_keyword] = ACTIONS(12772),
    [sym_cuegroup_keyword] = ACTIONS(12772),
    [sym_fixed_keyword] = ACTIONS(12772),
    [sym_grid_keyword] = ACTIONS(12772),
    [sym_part_keyword] = ACTIONS(12772),
    [sym_systempart_keyword] = ACTIONS(12772),
    [sym_usercontrol_keyword] = ACTIONS(12772),
    [sym_dataset_keyword] = ACTIONS(12772),
    [sym_elements_keyword] = ACTIONS(12772),
    [sym_dataitem_keyword] = ACTIONS(12772),
    [sym_column_keyword] = ACTIONS(12772),
    [sym_filter_keyword] = ACTIONS(12772),
    [sym_labels_keyword] = ACTIONS(12772),
    [sym_rendering_keyword] = ACTIONS(12772),
    [sym_requestpage_keyword] = ACTIONS(12772),
    [sym_schema_keyword] = ACTIONS(12772),
    [sym_views_keyword] = ACTIONS(12772),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12772),
    [sym_preproc_open] = ACTIONS(12772),
    [sym_preproc_close] = ACTIONS(12772),
  },
  [STATE(5178)] = {
    [sym__body_element] = STATE(5212),
    [sym_empty_statement] = STATE(5212),
    [sym_property] = STATE(5212),
    [sym_permissions_property] = STATE(5212),
    [sym_table_relation_property] = STATE(5212),
    [sym_fields_section] = STATE(5212),
    [sym_keys_section] = STATE(5212),
    [sym_fieldgroups_section] = STATE(5212),
    [sym_enum_value_declaration] = STATE(5212),
    [sym_labels_section] = STATE(5212),
    [sym_layout_section] = STATE(5212),
    [sym_modify_modification] = STATE(5212),
    [sym_actions_section] = STATE(5212),
    [sym_views_section] = STATE(5212),
    [sym_dataset_section] = STATE(5212),
    [sym_report_dataitem] = STATE(5212),
    [sym__report_body_element] = STATE(5212),
    [sym_preproc_conditional_report] = STATE(5212),
    [sym_report_column] = STATE(5212),
    [sym_requestpage_section] = STATE(5212),
    [sym_rendering_section] = STATE(5212),
    [sym_elements_section] = STATE(5212),
    [sym_schema_section] = STATE(5212),
    [sym_assembly_declaration] = STATE(5212),
    [sym_event_declaration] = STATE(5212),
    [sym_procedure] = STATE(5212),
    [sym_preproc_split_procedure] = STATE(5212),
    [sym_preproc_split_procedure_preamble] = STATE(5212),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5212),
    [sym_var_section] = STATE(5212),
    [sym_attribute_item] = STATE(5212),
    [sym_preproc_conditional] = STATE(5212),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5212),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12776),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5179)] = {
    [anon_sym_SEMI] = ACTIONS(12778),
    [aux_sym_where_condition_token1] = ACTIONS(12780),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12778),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12778),
    [anon_sym_LBRACK] = ACTIONS(12778),
    [aux_sym_basic_type_token6] = ACTIONS(12780),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12778),
    [aux_sym_addafter_modification_token1] = ACTIONS(12778),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12778),
    [aux_sym_modify_modification_token1] = ACTIONS(12778),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12778),
    [aux_sym_movelast_modification_token1] = ACTIONS(12778),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12778),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12778),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12778),
    [anon_sym_POUNDif] = ACTIONS(12778),
    [anon_sym_POUNDIF] = ACTIONS(12778),
    [anon_sym_POUNDIf] = ACTIONS(12778),
    [anon_sym_POUNDelif] = ACTIONS(12778),
    [anon_sym_POUNDELIF] = ACTIONS(12778),
    [anon_sym_POUNDElif] = ACTIONS(12778),
    [anon_sym_POUNDelse] = ACTIONS(12778),
    [anon_sym_POUNDELSE] = ACTIONS(12778),
    [anon_sym_POUNDElse] = ACTIONS(12778),
    [anon_sym_POUNDelse2] = ACTIONS(12778),
    [anon_sym_POUNDELSE2] = ACTIONS(12778),
    [anon_sym_POUNDElse2] = ACTIONS(12778),
    [anon_sym_POUNDendif] = ACTIONS(12778),
    [anon_sym_POUNDENDIF] = ACTIONS(12778),
    [anon_sym_POUNDEndif] = ACTIONS(12778),
    [anon_sym_POUNDendif2] = ACTIONS(12778),
    [anon_sym_POUNDENDIF2] = ACTIONS(12778),
    [anon_sym_POUNDEndif2] = ACTIONS(12778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12778),
    [sym_trigger_keyword] = ACTIONS(12778),
    [sym_var_keyword] = ACTIONS(12778),
    [sym_local_keyword] = ACTIONS(12778),
    [sym_internal_keyword] = ACTIONS(12778),
    [sym_protected_keyword] = ACTIONS(12778),
    [sym_event_keyword] = ACTIONS(12778),
    [sym_fields_keyword] = ACTIONS(12778),
    [sym_keys_keyword] = ACTIONS(12778),
    [sym_fieldgroups_keyword] = ACTIONS(12778),
    [sym_actions_keyword] = ACTIONS(12778),
    [sym_layout_keyword] = ACTIONS(12778),
    [sym_area_keyword] = ACTIONS(12778),
    [sym_group_keyword] = ACTIONS(12778),
    [sym_repeater_keyword] = ACTIONS(12778),
    [sym_cuegroup_keyword] = ACTIONS(12778),
    [sym_fixed_keyword] = ACTIONS(12778),
    [sym_grid_keyword] = ACTIONS(12778),
    [sym_part_keyword] = ACTIONS(12778),
    [sym_systempart_keyword] = ACTIONS(12778),
    [sym_usercontrol_keyword] = ACTIONS(12778),
    [sym_dataset_keyword] = ACTIONS(12778),
    [sym_elements_keyword] = ACTIONS(12778),
    [sym_dataitem_keyword] = ACTIONS(12778),
    [sym_column_keyword] = ACTIONS(12778),
    [sym_filter_keyword] = ACTIONS(12778),
    [sym_labels_keyword] = ACTIONS(12778),
    [sym_rendering_keyword] = ACTIONS(12778),
    [sym_requestpage_keyword] = ACTIONS(12778),
    [sym_schema_keyword] = ACTIONS(12778),
    [sym_views_keyword] = ACTIONS(12778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12778),
    [sym_preproc_open] = ACTIONS(12778),
    [sym_preproc_close] = ACTIONS(12778),
  },
  [STATE(5180)] = {
    [anon_sym_SEMI] = ACTIONS(12778),
    [aux_sym_where_condition_token1] = ACTIONS(12780),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12778),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12778),
    [anon_sym_LBRACK] = ACTIONS(12778),
    [aux_sym_basic_type_token6] = ACTIONS(12780),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12778),
    [aux_sym_addafter_modification_token1] = ACTIONS(12778),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12778),
    [aux_sym_modify_modification_token1] = ACTIONS(12778),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12778),
    [aux_sym_movelast_modification_token1] = ACTIONS(12778),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12778),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12778),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12778),
    [anon_sym_POUNDif] = ACTIONS(12778),
    [anon_sym_POUNDIF] = ACTIONS(12778),
    [anon_sym_POUNDIf] = ACTIONS(12778),
    [anon_sym_POUNDelif] = ACTIONS(12778),
    [anon_sym_POUNDELIF] = ACTIONS(12778),
    [anon_sym_POUNDElif] = ACTIONS(12778),
    [anon_sym_POUNDelse] = ACTIONS(12778),
    [anon_sym_POUNDELSE] = ACTIONS(12778),
    [anon_sym_POUNDElse] = ACTIONS(12778),
    [anon_sym_POUNDelse2] = ACTIONS(12778),
    [anon_sym_POUNDELSE2] = ACTIONS(12778),
    [anon_sym_POUNDElse2] = ACTIONS(12778),
    [anon_sym_POUNDendif] = ACTIONS(12778),
    [anon_sym_POUNDENDIF] = ACTIONS(12778),
    [anon_sym_POUNDEndif] = ACTIONS(12778),
    [anon_sym_POUNDendif2] = ACTIONS(12778),
    [anon_sym_POUNDENDIF2] = ACTIONS(12778),
    [anon_sym_POUNDEndif2] = ACTIONS(12778),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12778),
    [sym_trigger_keyword] = ACTIONS(12778),
    [sym_var_keyword] = ACTIONS(12778),
    [sym_local_keyword] = ACTIONS(12778),
    [sym_internal_keyword] = ACTIONS(12778),
    [sym_protected_keyword] = ACTIONS(12778),
    [sym_event_keyword] = ACTIONS(12778),
    [sym_fields_keyword] = ACTIONS(12778),
    [sym_keys_keyword] = ACTIONS(12778),
    [sym_fieldgroups_keyword] = ACTIONS(12778),
    [sym_actions_keyword] = ACTIONS(12778),
    [sym_layout_keyword] = ACTIONS(12778),
    [sym_area_keyword] = ACTIONS(12778),
    [sym_group_keyword] = ACTIONS(12778),
    [sym_repeater_keyword] = ACTIONS(12778),
    [sym_cuegroup_keyword] = ACTIONS(12778),
    [sym_fixed_keyword] = ACTIONS(12778),
    [sym_grid_keyword] = ACTIONS(12778),
    [sym_part_keyword] = ACTIONS(12778),
    [sym_systempart_keyword] = ACTIONS(12778),
    [sym_usercontrol_keyword] = ACTIONS(12778),
    [sym_dataset_keyword] = ACTIONS(12778),
    [sym_elements_keyword] = ACTIONS(12778),
    [sym_dataitem_keyword] = ACTIONS(12778),
    [sym_column_keyword] = ACTIONS(12778),
    [sym_filter_keyword] = ACTIONS(12778),
    [sym_labels_keyword] = ACTIONS(12778),
    [sym_rendering_keyword] = ACTIONS(12778),
    [sym_requestpage_keyword] = ACTIONS(12778),
    [sym_schema_keyword] = ACTIONS(12778),
    [sym_views_keyword] = ACTIONS(12778),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12778),
    [sym_preproc_open] = ACTIONS(12778),
    [sym_preproc_close] = ACTIONS(12778),
  },
  [STATE(5181)] = {
    [anon_sym_SEMI] = ACTIONS(12782),
    [aux_sym_where_condition_token1] = ACTIONS(12784),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12782),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12782),
    [anon_sym_LBRACK] = ACTIONS(12782),
    [aux_sym_basic_type_token6] = ACTIONS(12784),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12782),
    [aux_sym_addafter_modification_token1] = ACTIONS(12782),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12782),
    [aux_sym_modify_modification_token1] = ACTIONS(12782),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12782),
    [aux_sym_movelast_modification_token1] = ACTIONS(12782),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12782),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12782),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12782),
    [anon_sym_POUNDif] = ACTIONS(12782),
    [anon_sym_POUNDIF] = ACTIONS(12782),
    [anon_sym_POUNDIf] = ACTIONS(12782),
    [anon_sym_POUNDelif] = ACTIONS(12782),
    [anon_sym_POUNDELIF] = ACTIONS(12782),
    [anon_sym_POUNDElif] = ACTIONS(12782),
    [anon_sym_POUNDelse] = ACTIONS(12782),
    [anon_sym_POUNDELSE] = ACTIONS(12782),
    [anon_sym_POUNDElse] = ACTIONS(12782),
    [anon_sym_POUNDelse2] = ACTIONS(12782),
    [anon_sym_POUNDELSE2] = ACTIONS(12782),
    [anon_sym_POUNDElse2] = ACTIONS(12782),
    [anon_sym_POUNDendif] = ACTIONS(12782),
    [anon_sym_POUNDENDIF] = ACTIONS(12782),
    [anon_sym_POUNDEndif] = ACTIONS(12782),
    [anon_sym_POUNDendif2] = ACTIONS(12782),
    [anon_sym_POUNDENDIF2] = ACTIONS(12782),
    [anon_sym_POUNDEndif2] = ACTIONS(12782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12782),
    [sym_trigger_keyword] = ACTIONS(12782),
    [sym_var_keyword] = ACTIONS(12782),
    [sym_local_keyword] = ACTIONS(12782),
    [sym_internal_keyword] = ACTIONS(12782),
    [sym_protected_keyword] = ACTIONS(12782),
    [sym_event_keyword] = ACTIONS(12782),
    [sym_fields_keyword] = ACTIONS(12782),
    [sym_keys_keyword] = ACTIONS(12782),
    [sym_fieldgroups_keyword] = ACTIONS(12782),
    [sym_actions_keyword] = ACTIONS(12782),
    [sym_layout_keyword] = ACTIONS(12782),
    [sym_area_keyword] = ACTIONS(12782),
    [sym_group_keyword] = ACTIONS(12782),
    [sym_repeater_keyword] = ACTIONS(12782),
    [sym_cuegroup_keyword] = ACTIONS(12782),
    [sym_fixed_keyword] = ACTIONS(12782),
    [sym_grid_keyword] = ACTIONS(12782),
    [sym_part_keyword] = ACTIONS(12782),
    [sym_systempart_keyword] = ACTIONS(12782),
    [sym_usercontrol_keyword] = ACTIONS(12782),
    [sym_dataset_keyword] = ACTIONS(12782),
    [sym_elements_keyword] = ACTIONS(12782),
    [sym_dataitem_keyword] = ACTIONS(12782),
    [sym_column_keyword] = ACTIONS(12782),
    [sym_filter_keyword] = ACTIONS(12782),
    [sym_labels_keyword] = ACTIONS(12782),
    [sym_rendering_keyword] = ACTIONS(12782),
    [sym_requestpage_keyword] = ACTIONS(12782),
    [sym_schema_keyword] = ACTIONS(12782),
    [sym_views_keyword] = ACTIONS(12782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12782),
    [sym_preproc_open] = ACTIONS(12782),
    [sym_preproc_close] = ACTIONS(12782),
  },
  [STATE(5182)] = {
    [anon_sym_SEMI] = ACTIONS(12782),
    [aux_sym_where_condition_token1] = ACTIONS(12784),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12782),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12782),
    [anon_sym_LBRACK] = ACTIONS(12782),
    [aux_sym_basic_type_token6] = ACTIONS(12784),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12782),
    [aux_sym_addafter_modification_token1] = ACTIONS(12782),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12782),
    [aux_sym_modify_modification_token1] = ACTIONS(12782),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12782),
    [aux_sym_movelast_modification_token1] = ACTIONS(12782),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12782),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12782),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12782),
    [anon_sym_POUNDif] = ACTIONS(12782),
    [anon_sym_POUNDIF] = ACTIONS(12782),
    [anon_sym_POUNDIf] = ACTIONS(12782),
    [anon_sym_POUNDelif] = ACTIONS(12782),
    [anon_sym_POUNDELIF] = ACTIONS(12782),
    [anon_sym_POUNDElif] = ACTIONS(12782),
    [anon_sym_POUNDelse] = ACTIONS(12782),
    [anon_sym_POUNDELSE] = ACTIONS(12782),
    [anon_sym_POUNDElse] = ACTIONS(12782),
    [anon_sym_POUNDelse2] = ACTIONS(12782),
    [anon_sym_POUNDELSE2] = ACTIONS(12782),
    [anon_sym_POUNDElse2] = ACTIONS(12782),
    [anon_sym_POUNDendif] = ACTIONS(12782),
    [anon_sym_POUNDENDIF] = ACTIONS(12782),
    [anon_sym_POUNDEndif] = ACTIONS(12782),
    [anon_sym_POUNDendif2] = ACTIONS(12782),
    [anon_sym_POUNDENDIF2] = ACTIONS(12782),
    [anon_sym_POUNDEndif2] = ACTIONS(12782),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12782),
    [sym_trigger_keyword] = ACTIONS(12782),
    [sym_var_keyword] = ACTIONS(12782),
    [sym_local_keyword] = ACTIONS(12782),
    [sym_internal_keyword] = ACTIONS(12782),
    [sym_protected_keyword] = ACTIONS(12782),
    [sym_event_keyword] = ACTIONS(12782),
    [sym_fields_keyword] = ACTIONS(12782),
    [sym_keys_keyword] = ACTIONS(12782),
    [sym_fieldgroups_keyword] = ACTIONS(12782),
    [sym_actions_keyword] = ACTIONS(12782),
    [sym_layout_keyword] = ACTIONS(12782),
    [sym_area_keyword] = ACTIONS(12782),
    [sym_group_keyword] = ACTIONS(12782),
    [sym_repeater_keyword] = ACTIONS(12782),
    [sym_cuegroup_keyword] = ACTIONS(12782),
    [sym_fixed_keyword] = ACTIONS(12782),
    [sym_grid_keyword] = ACTIONS(12782),
    [sym_part_keyword] = ACTIONS(12782),
    [sym_systempart_keyword] = ACTIONS(12782),
    [sym_usercontrol_keyword] = ACTIONS(12782),
    [sym_dataset_keyword] = ACTIONS(12782),
    [sym_elements_keyword] = ACTIONS(12782),
    [sym_dataitem_keyword] = ACTIONS(12782),
    [sym_column_keyword] = ACTIONS(12782),
    [sym_filter_keyword] = ACTIONS(12782),
    [sym_labels_keyword] = ACTIONS(12782),
    [sym_rendering_keyword] = ACTIONS(12782),
    [sym_requestpage_keyword] = ACTIONS(12782),
    [sym_schema_keyword] = ACTIONS(12782),
    [sym_views_keyword] = ACTIONS(12782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12782),
    [sym_preproc_open] = ACTIONS(12782),
    [sym_preproc_close] = ACTIONS(12782),
  },
  [STATE(5183)] = {
    [anon_sym_SEMI] = ACTIONS(12786),
    [aux_sym_where_condition_token1] = ACTIONS(12788),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12786),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12786),
    [anon_sym_LBRACK] = ACTIONS(12786),
    [aux_sym_basic_type_token6] = ACTIONS(12788),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12786),
    [aux_sym_addafter_modification_token1] = ACTIONS(12786),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12786),
    [aux_sym_modify_modification_token1] = ACTIONS(12786),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12786),
    [aux_sym_movelast_modification_token1] = ACTIONS(12786),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12786),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12786),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12786),
    [anon_sym_POUNDif] = ACTIONS(12786),
    [anon_sym_POUNDIF] = ACTIONS(12786),
    [anon_sym_POUNDIf] = ACTIONS(12786),
    [anon_sym_POUNDelif] = ACTIONS(12786),
    [anon_sym_POUNDELIF] = ACTIONS(12786),
    [anon_sym_POUNDElif] = ACTIONS(12786),
    [anon_sym_POUNDelse] = ACTIONS(12786),
    [anon_sym_POUNDELSE] = ACTIONS(12786),
    [anon_sym_POUNDElse] = ACTIONS(12786),
    [anon_sym_POUNDelse2] = ACTIONS(12786),
    [anon_sym_POUNDELSE2] = ACTIONS(12786),
    [anon_sym_POUNDElse2] = ACTIONS(12786),
    [anon_sym_POUNDendif] = ACTIONS(12786),
    [anon_sym_POUNDENDIF] = ACTIONS(12786),
    [anon_sym_POUNDEndif] = ACTIONS(12786),
    [anon_sym_POUNDendif2] = ACTIONS(12786),
    [anon_sym_POUNDENDIF2] = ACTIONS(12786),
    [anon_sym_POUNDEndif2] = ACTIONS(12786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12786),
    [sym_trigger_keyword] = ACTIONS(12786),
    [sym_var_keyword] = ACTIONS(12786),
    [sym_local_keyword] = ACTIONS(12786),
    [sym_internal_keyword] = ACTIONS(12786),
    [sym_protected_keyword] = ACTIONS(12786),
    [sym_event_keyword] = ACTIONS(12786),
    [sym_fields_keyword] = ACTIONS(12786),
    [sym_keys_keyword] = ACTIONS(12786),
    [sym_fieldgroups_keyword] = ACTIONS(12786),
    [sym_actions_keyword] = ACTIONS(12786),
    [sym_layout_keyword] = ACTIONS(12786),
    [sym_area_keyword] = ACTIONS(12786),
    [sym_group_keyword] = ACTIONS(12786),
    [sym_repeater_keyword] = ACTIONS(12786),
    [sym_cuegroup_keyword] = ACTIONS(12786),
    [sym_fixed_keyword] = ACTIONS(12786),
    [sym_grid_keyword] = ACTIONS(12786),
    [sym_part_keyword] = ACTIONS(12786),
    [sym_systempart_keyword] = ACTIONS(12786),
    [sym_usercontrol_keyword] = ACTIONS(12786),
    [sym_dataset_keyword] = ACTIONS(12786),
    [sym_elements_keyword] = ACTIONS(12786),
    [sym_dataitem_keyword] = ACTIONS(12786),
    [sym_column_keyword] = ACTIONS(12786),
    [sym_filter_keyword] = ACTIONS(12786),
    [sym_labels_keyword] = ACTIONS(12786),
    [sym_rendering_keyword] = ACTIONS(12786),
    [sym_requestpage_keyword] = ACTIONS(12786),
    [sym_schema_keyword] = ACTIONS(12786),
    [sym_views_keyword] = ACTIONS(12786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12786),
    [sym_preproc_open] = ACTIONS(12786),
    [sym_preproc_close] = ACTIONS(12786),
  },
  [STATE(5184)] = {
    [anon_sym_SEMI] = ACTIONS(12786),
    [aux_sym_where_condition_token1] = ACTIONS(12788),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12786),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12786),
    [anon_sym_LBRACK] = ACTIONS(12786),
    [aux_sym_basic_type_token6] = ACTIONS(12788),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12786),
    [aux_sym_addafter_modification_token1] = ACTIONS(12786),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12786),
    [aux_sym_modify_modification_token1] = ACTIONS(12786),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12786),
    [aux_sym_movelast_modification_token1] = ACTIONS(12786),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12786),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12786),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12786),
    [anon_sym_POUNDif] = ACTIONS(12786),
    [anon_sym_POUNDIF] = ACTIONS(12786),
    [anon_sym_POUNDIf] = ACTIONS(12786),
    [anon_sym_POUNDelif] = ACTIONS(12786),
    [anon_sym_POUNDELIF] = ACTIONS(12786),
    [anon_sym_POUNDElif] = ACTIONS(12786),
    [anon_sym_POUNDelse] = ACTIONS(12786),
    [anon_sym_POUNDELSE] = ACTIONS(12786),
    [anon_sym_POUNDElse] = ACTIONS(12786),
    [anon_sym_POUNDelse2] = ACTIONS(12786),
    [anon_sym_POUNDELSE2] = ACTIONS(12786),
    [anon_sym_POUNDElse2] = ACTIONS(12786),
    [anon_sym_POUNDendif] = ACTIONS(12786),
    [anon_sym_POUNDENDIF] = ACTIONS(12786),
    [anon_sym_POUNDEndif] = ACTIONS(12786),
    [anon_sym_POUNDendif2] = ACTIONS(12786),
    [anon_sym_POUNDENDIF2] = ACTIONS(12786),
    [anon_sym_POUNDEndif2] = ACTIONS(12786),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12786),
    [sym_trigger_keyword] = ACTIONS(12786),
    [sym_var_keyword] = ACTIONS(12786),
    [sym_local_keyword] = ACTIONS(12786),
    [sym_internal_keyword] = ACTIONS(12786),
    [sym_protected_keyword] = ACTIONS(12786),
    [sym_event_keyword] = ACTIONS(12786),
    [sym_fields_keyword] = ACTIONS(12786),
    [sym_keys_keyword] = ACTIONS(12786),
    [sym_fieldgroups_keyword] = ACTIONS(12786),
    [sym_actions_keyword] = ACTIONS(12786),
    [sym_layout_keyword] = ACTIONS(12786),
    [sym_area_keyword] = ACTIONS(12786),
    [sym_group_keyword] = ACTIONS(12786),
    [sym_repeater_keyword] = ACTIONS(12786),
    [sym_cuegroup_keyword] = ACTIONS(12786),
    [sym_fixed_keyword] = ACTIONS(12786),
    [sym_grid_keyword] = ACTIONS(12786),
    [sym_part_keyword] = ACTIONS(12786),
    [sym_systempart_keyword] = ACTIONS(12786),
    [sym_usercontrol_keyword] = ACTIONS(12786),
    [sym_dataset_keyword] = ACTIONS(12786),
    [sym_elements_keyword] = ACTIONS(12786),
    [sym_dataitem_keyword] = ACTIONS(12786),
    [sym_column_keyword] = ACTIONS(12786),
    [sym_filter_keyword] = ACTIONS(12786),
    [sym_labels_keyword] = ACTIONS(12786),
    [sym_rendering_keyword] = ACTIONS(12786),
    [sym_requestpage_keyword] = ACTIONS(12786),
    [sym_schema_keyword] = ACTIONS(12786),
    [sym_views_keyword] = ACTIONS(12786),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12786),
    [sym_preproc_open] = ACTIONS(12786),
    [sym_preproc_close] = ACTIONS(12786),
  },
  [STATE(5185)] = {
    [anon_sym_SEMI] = ACTIONS(12790),
    [aux_sym_where_condition_token1] = ACTIONS(12792),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12794),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12794),
    [anon_sym_LBRACK] = ACTIONS(12794),
    [aux_sym_basic_type_token6] = ACTIONS(12792),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12794),
    [aux_sym_addafter_modification_token1] = ACTIONS(12794),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12794),
    [aux_sym_modify_modification_token1] = ACTIONS(12794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12794),
    [aux_sym_movelast_modification_token1] = ACTIONS(12794),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12794),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12794),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12794),
    [anon_sym_POUNDif] = ACTIONS(12794),
    [anon_sym_POUNDIF] = ACTIONS(12794),
    [anon_sym_POUNDIf] = ACTIONS(12794),
    [anon_sym_POUNDelif] = ACTIONS(12794),
    [anon_sym_POUNDELIF] = ACTIONS(12794),
    [anon_sym_POUNDElif] = ACTIONS(12794),
    [anon_sym_POUNDelse] = ACTIONS(12794),
    [anon_sym_POUNDELSE] = ACTIONS(12794),
    [anon_sym_POUNDElse] = ACTIONS(12794),
    [anon_sym_POUNDelse2] = ACTIONS(12794),
    [anon_sym_POUNDELSE2] = ACTIONS(12794),
    [anon_sym_POUNDElse2] = ACTIONS(12794),
    [anon_sym_POUNDendif] = ACTIONS(12794),
    [anon_sym_POUNDENDIF] = ACTIONS(12794),
    [anon_sym_POUNDEndif] = ACTIONS(12794),
    [anon_sym_POUNDendif2] = ACTIONS(12794),
    [anon_sym_POUNDENDIF2] = ACTIONS(12794),
    [anon_sym_POUNDEndif2] = ACTIONS(12794),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12794),
    [sym_trigger_keyword] = ACTIONS(12794),
    [sym_var_keyword] = ACTIONS(12794),
    [sym_local_keyword] = ACTIONS(12794),
    [sym_internal_keyword] = ACTIONS(12794),
    [sym_protected_keyword] = ACTIONS(12794),
    [sym_event_keyword] = ACTIONS(12794),
    [sym_fields_keyword] = ACTIONS(12794),
    [sym_keys_keyword] = ACTIONS(12794),
    [sym_fieldgroups_keyword] = ACTIONS(12794),
    [sym_actions_keyword] = ACTIONS(12794),
    [sym_layout_keyword] = ACTIONS(12794),
    [sym_area_keyword] = ACTIONS(12794),
    [sym_group_keyword] = ACTIONS(12794),
    [sym_repeater_keyword] = ACTIONS(12794),
    [sym_cuegroup_keyword] = ACTIONS(12794),
    [sym_fixed_keyword] = ACTIONS(12794),
    [sym_grid_keyword] = ACTIONS(12794),
    [sym_part_keyword] = ACTIONS(12794),
    [sym_systempart_keyword] = ACTIONS(12794),
    [sym_usercontrol_keyword] = ACTIONS(12794),
    [sym_dataset_keyword] = ACTIONS(12794),
    [sym_elements_keyword] = ACTIONS(12794),
    [sym_dataitem_keyword] = ACTIONS(12794),
    [sym_column_keyword] = ACTIONS(12794),
    [sym_filter_keyword] = ACTIONS(12794),
    [sym_labels_keyword] = ACTIONS(12794),
    [sym_rendering_keyword] = ACTIONS(12794),
    [sym_requestpage_keyword] = ACTIONS(12794),
    [sym_schema_keyword] = ACTIONS(12794),
    [sym_views_keyword] = ACTIONS(12794),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12794),
    [sym_preproc_open] = ACTIONS(12794),
    [sym_preproc_close] = ACTIONS(12794),
  },
  [STATE(5186)] = {
    [anon_sym_SEMI] = ACTIONS(12796),
    [aux_sym_where_condition_token1] = ACTIONS(12792),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12794),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12794),
    [anon_sym_LBRACK] = ACTIONS(12794),
    [aux_sym_basic_type_token6] = ACTIONS(12792),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12794),
    [aux_sym_addafter_modification_token1] = ACTIONS(12794),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12794),
    [aux_sym_modify_modification_token1] = ACTIONS(12794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12794),
    [aux_sym_movelast_modification_token1] = ACTIONS(12794),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12794),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12794),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12794),
    [anon_sym_POUNDif] = ACTIONS(12794),
    [anon_sym_POUNDIF] = ACTIONS(12794),
    [anon_sym_POUNDIf] = ACTIONS(12794),
    [anon_sym_POUNDelif] = ACTIONS(12794),
    [anon_sym_POUNDELIF] = ACTIONS(12794),
    [anon_sym_POUNDElif] = ACTIONS(12794),
    [anon_sym_POUNDelse] = ACTIONS(12794),
    [anon_sym_POUNDELSE] = ACTIONS(12794),
    [anon_sym_POUNDElse] = ACTIONS(12794),
    [anon_sym_POUNDelse2] = ACTIONS(12794),
    [anon_sym_POUNDELSE2] = ACTIONS(12794),
    [anon_sym_POUNDElse2] = ACTIONS(12794),
    [anon_sym_POUNDendif] = ACTIONS(12794),
    [anon_sym_POUNDENDIF] = ACTIONS(12794),
    [anon_sym_POUNDEndif] = ACTIONS(12794),
    [anon_sym_POUNDendif2] = ACTIONS(12794),
    [anon_sym_POUNDENDIF2] = ACTIONS(12794),
    [anon_sym_POUNDEndif2] = ACTIONS(12794),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12794),
    [sym_trigger_keyword] = ACTIONS(12794),
    [sym_var_keyword] = ACTIONS(12794),
    [sym_local_keyword] = ACTIONS(12794),
    [sym_internal_keyword] = ACTIONS(12794),
    [sym_protected_keyword] = ACTIONS(12794),
    [sym_event_keyword] = ACTIONS(12794),
    [sym_fields_keyword] = ACTIONS(12794),
    [sym_keys_keyword] = ACTIONS(12794),
    [sym_fieldgroups_keyword] = ACTIONS(12794),
    [sym_actions_keyword] = ACTIONS(12794),
    [sym_layout_keyword] = ACTIONS(12794),
    [sym_area_keyword] = ACTIONS(12794),
    [sym_group_keyword] = ACTIONS(12794),
    [sym_repeater_keyword] = ACTIONS(12794),
    [sym_cuegroup_keyword] = ACTIONS(12794),
    [sym_fixed_keyword] = ACTIONS(12794),
    [sym_grid_keyword] = ACTIONS(12794),
    [sym_part_keyword] = ACTIONS(12794),
    [sym_systempart_keyword] = ACTIONS(12794),
    [sym_usercontrol_keyword] = ACTIONS(12794),
    [sym_dataset_keyword] = ACTIONS(12794),
    [sym_elements_keyword] = ACTIONS(12794),
    [sym_dataitem_keyword] = ACTIONS(12794),
    [sym_column_keyword] = ACTIONS(12794),
    [sym_filter_keyword] = ACTIONS(12794),
    [sym_labels_keyword] = ACTIONS(12794),
    [sym_rendering_keyword] = ACTIONS(12794),
    [sym_requestpage_keyword] = ACTIONS(12794),
    [sym_schema_keyword] = ACTIONS(12794),
    [sym_views_keyword] = ACTIONS(12794),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12794),
    [sym_preproc_open] = ACTIONS(12794),
    [sym_preproc_close] = ACTIONS(12794),
  },
  [STATE(5187)] = {
    [anon_sym_SEMI] = ACTIONS(12798),
    [aux_sym_where_condition_token1] = ACTIONS(12800),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12798),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12798),
    [anon_sym_LBRACK] = ACTIONS(12798),
    [aux_sym_basic_type_token6] = ACTIONS(12800),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12798),
    [aux_sym_addafter_modification_token1] = ACTIONS(12798),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12798),
    [aux_sym_modify_modification_token1] = ACTIONS(12798),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12798),
    [aux_sym_movelast_modification_token1] = ACTIONS(12798),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12798),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12798),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12798),
    [anon_sym_POUNDif] = ACTIONS(12798),
    [anon_sym_POUNDIF] = ACTIONS(12798),
    [anon_sym_POUNDIf] = ACTIONS(12798),
    [anon_sym_POUNDelif] = ACTIONS(12798),
    [anon_sym_POUNDELIF] = ACTIONS(12798),
    [anon_sym_POUNDElif] = ACTIONS(12798),
    [anon_sym_POUNDelse] = ACTIONS(12798),
    [anon_sym_POUNDELSE] = ACTIONS(12798),
    [anon_sym_POUNDElse] = ACTIONS(12798),
    [anon_sym_POUNDelse2] = ACTIONS(12798),
    [anon_sym_POUNDELSE2] = ACTIONS(12798),
    [anon_sym_POUNDElse2] = ACTIONS(12798),
    [anon_sym_POUNDendif] = ACTIONS(12798),
    [anon_sym_POUNDENDIF] = ACTIONS(12798),
    [anon_sym_POUNDEndif] = ACTIONS(12798),
    [anon_sym_POUNDendif2] = ACTIONS(12798),
    [anon_sym_POUNDENDIF2] = ACTIONS(12798),
    [anon_sym_POUNDEndif2] = ACTIONS(12798),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12798),
    [sym_trigger_keyword] = ACTIONS(12798),
    [sym_var_keyword] = ACTIONS(12798),
    [sym_local_keyword] = ACTIONS(12798),
    [sym_internal_keyword] = ACTIONS(12798),
    [sym_protected_keyword] = ACTIONS(12798),
    [sym_event_keyword] = ACTIONS(12798),
    [sym_fields_keyword] = ACTIONS(12798),
    [sym_keys_keyword] = ACTIONS(12798),
    [sym_fieldgroups_keyword] = ACTIONS(12798),
    [sym_actions_keyword] = ACTIONS(12798),
    [sym_layout_keyword] = ACTIONS(12798),
    [sym_area_keyword] = ACTIONS(12798),
    [sym_group_keyword] = ACTIONS(12798),
    [sym_repeater_keyword] = ACTIONS(12798),
    [sym_cuegroup_keyword] = ACTIONS(12798),
    [sym_fixed_keyword] = ACTIONS(12798),
    [sym_grid_keyword] = ACTIONS(12798),
    [sym_part_keyword] = ACTIONS(12798),
    [sym_systempart_keyword] = ACTIONS(12798),
    [sym_usercontrol_keyword] = ACTIONS(12798),
    [sym_dataset_keyword] = ACTIONS(12798),
    [sym_elements_keyword] = ACTIONS(12798),
    [sym_dataitem_keyword] = ACTIONS(12798),
    [sym_column_keyword] = ACTIONS(12798),
    [sym_filter_keyword] = ACTIONS(12798),
    [sym_labels_keyword] = ACTIONS(12798),
    [sym_rendering_keyword] = ACTIONS(12798),
    [sym_requestpage_keyword] = ACTIONS(12798),
    [sym_schema_keyword] = ACTIONS(12798),
    [sym_views_keyword] = ACTIONS(12798),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12798),
    [sym_preproc_open] = ACTIONS(12798),
    [sym_preproc_close] = ACTIONS(12798),
  },
  [STATE(5188)] = {
    [anon_sym_SEMI] = ACTIONS(12802),
    [aux_sym_where_condition_token1] = ACTIONS(12804),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12802),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12802),
    [anon_sym_LBRACK] = ACTIONS(12806),
    [aux_sym_basic_type_token6] = ACTIONS(12804),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12802),
    [aux_sym_addafter_modification_token1] = ACTIONS(12802),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12802),
    [aux_sym_modify_modification_token1] = ACTIONS(12802),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12802),
    [aux_sym_movelast_modification_token1] = ACTIONS(12802),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12802),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12802),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12802),
    [anon_sym_POUNDif] = ACTIONS(12802),
    [anon_sym_POUNDIF] = ACTIONS(12802),
    [anon_sym_POUNDIf] = ACTIONS(12802),
    [anon_sym_POUNDelif] = ACTIONS(12802),
    [anon_sym_POUNDELIF] = ACTIONS(12802),
    [anon_sym_POUNDElif] = ACTIONS(12802),
    [anon_sym_POUNDelse] = ACTIONS(12802),
    [anon_sym_POUNDELSE] = ACTIONS(12802),
    [anon_sym_POUNDElse] = ACTIONS(12802),
    [anon_sym_POUNDelse2] = ACTIONS(12802),
    [anon_sym_POUNDELSE2] = ACTIONS(12802),
    [anon_sym_POUNDElse2] = ACTIONS(12802),
    [anon_sym_POUNDendif] = ACTIONS(12802),
    [anon_sym_POUNDENDIF] = ACTIONS(12802),
    [anon_sym_POUNDEndif] = ACTIONS(12802),
    [anon_sym_POUNDendif2] = ACTIONS(12802),
    [anon_sym_POUNDENDIF2] = ACTIONS(12802),
    [anon_sym_POUNDEndif2] = ACTIONS(12802),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12806),
    [sym_trigger_keyword] = ACTIONS(12802),
    [sym_var_keyword] = ACTIONS(12802),
    [sym_local_keyword] = ACTIONS(12806),
    [sym_internal_keyword] = ACTIONS(12806),
    [sym_protected_keyword] = ACTIONS(12806),
    [sym_event_keyword] = ACTIONS(12802),
    [sym_fields_keyword] = ACTIONS(12802),
    [sym_keys_keyword] = ACTIONS(12802),
    [sym_fieldgroups_keyword] = ACTIONS(12802),
    [sym_actions_keyword] = ACTIONS(12802),
    [sym_layout_keyword] = ACTIONS(12802),
    [sym_area_keyword] = ACTIONS(12802),
    [sym_group_keyword] = ACTIONS(12802),
    [sym_repeater_keyword] = ACTIONS(12802),
    [sym_cuegroup_keyword] = ACTIONS(12802),
    [sym_fixed_keyword] = ACTIONS(12802),
    [sym_grid_keyword] = ACTIONS(12802),
    [sym_part_keyword] = ACTIONS(12802),
    [sym_systempart_keyword] = ACTIONS(12802),
    [sym_usercontrol_keyword] = ACTIONS(12802),
    [sym_dataset_keyword] = ACTIONS(12802),
    [sym_elements_keyword] = ACTIONS(12802),
    [sym_dataitem_keyword] = ACTIONS(12802),
    [sym_column_keyword] = ACTIONS(12802),
    [sym_filter_keyword] = ACTIONS(12802),
    [sym_labels_keyword] = ACTIONS(12802),
    [sym_rendering_keyword] = ACTIONS(12802),
    [sym_requestpage_keyword] = ACTIONS(12802),
    [sym_schema_keyword] = ACTIONS(12802),
    [sym_views_keyword] = ACTIONS(12802),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12802),
    [sym_preproc_open] = ACTIONS(12802),
    [sym_preproc_close] = ACTIONS(12802),
  },
  [STATE(5189)] = {
    [anon_sym_SEMI] = ACTIONS(12809),
    [aux_sym_where_condition_token1] = ACTIONS(12811),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12809),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12809),
    [anon_sym_LBRACK] = ACTIONS(12809),
    [aux_sym_basic_type_token6] = ACTIONS(12811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12809),
    [aux_sym_addafter_modification_token1] = ACTIONS(12809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12809),
    [aux_sym_modify_modification_token1] = ACTIONS(12809),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12809),
    [aux_sym_movelast_modification_token1] = ACTIONS(12809),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12809),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12809),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12809),
    [anon_sym_POUNDif] = ACTIONS(12809),
    [anon_sym_POUNDIF] = ACTIONS(12809),
    [anon_sym_POUNDIf] = ACTIONS(12809),
    [anon_sym_POUNDelif] = ACTIONS(12809),
    [anon_sym_POUNDELIF] = ACTIONS(12809),
    [anon_sym_POUNDElif] = ACTIONS(12809),
    [anon_sym_POUNDelse] = ACTIONS(12809),
    [anon_sym_POUNDELSE] = ACTIONS(12809),
    [anon_sym_POUNDElse] = ACTIONS(12809),
    [anon_sym_POUNDelse2] = ACTIONS(12809),
    [anon_sym_POUNDELSE2] = ACTIONS(12809),
    [anon_sym_POUNDElse2] = ACTIONS(12809),
    [anon_sym_POUNDendif] = ACTIONS(12809),
    [anon_sym_POUNDENDIF] = ACTIONS(12809),
    [anon_sym_POUNDEndif] = ACTIONS(12809),
    [anon_sym_POUNDendif2] = ACTIONS(12809),
    [anon_sym_POUNDENDIF2] = ACTIONS(12809),
    [anon_sym_POUNDEndif2] = ACTIONS(12809),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12809),
    [sym_trigger_keyword] = ACTIONS(12809),
    [sym_var_keyword] = ACTIONS(12809),
    [sym_local_keyword] = ACTIONS(12809),
    [sym_internal_keyword] = ACTIONS(12809),
    [sym_protected_keyword] = ACTIONS(12809),
    [sym_event_keyword] = ACTIONS(12809),
    [sym_fields_keyword] = ACTIONS(12809),
    [sym_keys_keyword] = ACTIONS(12809),
    [sym_fieldgroups_keyword] = ACTIONS(12809),
    [sym_actions_keyword] = ACTIONS(12809),
    [sym_layout_keyword] = ACTIONS(12809),
    [sym_area_keyword] = ACTIONS(12809),
    [sym_group_keyword] = ACTIONS(12809),
    [sym_repeater_keyword] = ACTIONS(12809),
    [sym_cuegroup_keyword] = ACTIONS(12809),
    [sym_fixed_keyword] = ACTIONS(12809),
    [sym_grid_keyword] = ACTIONS(12809),
    [sym_part_keyword] = ACTIONS(12809),
    [sym_systempart_keyword] = ACTIONS(12809),
    [sym_usercontrol_keyword] = ACTIONS(12809),
    [sym_dataset_keyword] = ACTIONS(12809),
    [sym_elements_keyword] = ACTIONS(12809),
    [sym_dataitem_keyword] = ACTIONS(12809),
    [sym_column_keyword] = ACTIONS(12809),
    [sym_filter_keyword] = ACTIONS(12809),
    [sym_labels_keyword] = ACTIONS(12809),
    [sym_rendering_keyword] = ACTIONS(12809),
    [sym_requestpage_keyword] = ACTIONS(12809),
    [sym_schema_keyword] = ACTIONS(12809),
    [sym_views_keyword] = ACTIONS(12809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12809),
    [sym_preproc_open] = ACTIONS(12809),
    [sym_preproc_close] = ACTIONS(12809),
  },
  [STATE(5190)] = {
    [anon_sym_SEMI] = ACTIONS(12809),
    [aux_sym_where_condition_token1] = ACTIONS(12811),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12809),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12809),
    [anon_sym_LBRACK] = ACTIONS(12809),
    [aux_sym_basic_type_token6] = ACTIONS(12811),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12809),
    [aux_sym_addafter_modification_token1] = ACTIONS(12809),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12809),
    [aux_sym_modify_modification_token1] = ACTIONS(12809),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12809),
    [aux_sym_movelast_modification_token1] = ACTIONS(12809),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12809),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12809),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12809),
    [anon_sym_POUNDif] = ACTIONS(12809),
    [anon_sym_POUNDIF] = ACTIONS(12809),
    [anon_sym_POUNDIf] = ACTIONS(12809),
    [anon_sym_POUNDelif] = ACTIONS(12809),
    [anon_sym_POUNDELIF] = ACTIONS(12809),
    [anon_sym_POUNDElif] = ACTIONS(12809),
    [anon_sym_POUNDelse] = ACTIONS(12809),
    [anon_sym_POUNDELSE] = ACTIONS(12809),
    [anon_sym_POUNDElse] = ACTIONS(12809),
    [anon_sym_POUNDelse2] = ACTIONS(12809),
    [anon_sym_POUNDELSE2] = ACTIONS(12809),
    [anon_sym_POUNDElse2] = ACTIONS(12809),
    [anon_sym_POUNDendif] = ACTIONS(12809),
    [anon_sym_POUNDENDIF] = ACTIONS(12809),
    [anon_sym_POUNDEndif] = ACTIONS(12809),
    [anon_sym_POUNDendif2] = ACTIONS(12809),
    [anon_sym_POUNDENDIF2] = ACTIONS(12809),
    [anon_sym_POUNDEndif2] = ACTIONS(12809),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12809),
    [sym_trigger_keyword] = ACTIONS(12809),
    [sym_var_keyword] = ACTIONS(12809),
    [sym_local_keyword] = ACTIONS(12809),
    [sym_internal_keyword] = ACTIONS(12809),
    [sym_protected_keyword] = ACTIONS(12809),
    [sym_event_keyword] = ACTIONS(12809),
    [sym_fields_keyword] = ACTIONS(12809),
    [sym_keys_keyword] = ACTIONS(12809),
    [sym_fieldgroups_keyword] = ACTIONS(12809),
    [sym_actions_keyword] = ACTIONS(12809),
    [sym_layout_keyword] = ACTIONS(12809),
    [sym_area_keyword] = ACTIONS(12809),
    [sym_group_keyword] = ACTIONS(12809),
    [sym_repeater_keyword] = ACTIONS(12809),
    [sym_cuegroup_keyword] = ACTIONS(12809),
    [sym_fixed_keyword] = ACTIONS(12809),
    [sym_grid_keyword] = ACTIONS(12809),
    [sym_part_keyword] = ACTIONS(12809),
    [sym_systempart_keyword] = ACTIONS(12809),
    [sym_usercontrol_keyword] = ACTIONS(12809),
    [sym_dataset_keyword] = ACTIONS(12809),
    [sym_elements_keyword] = ACTIONS(12809),
    [sym_dataitem_keyword] = ACTIONS(12809),
    [sym_column_keyword] = ACTIONS(12809),
    [sym_filter_keyword] = ACTIONS(12809),
    [sym_labels_keyword] = ACTIONS(12809),
    [sym_rendering_keyword] = ACTIONS(12809),
    [sym_requestpage_keyword] = ACTIONS(12809),
    [sym_schema_keyword] = ACTIONS(12809),
    [sym_views_keyword] = ACTIONS(12809),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12809),
    [sym_preproc_open] = ACTIONS(12809),
    [sym_preproc_close] = ACTIONS(12809),
  },
  [STATE(5191)] = {
    [anon_sym_SEMI] = ACTIONS(12813),
    [aux_sym_where_condition_token1] = ACTIONS(12815),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12813),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12813),
    [anon_sym_LBRACK] = ACTIONS(12813),
    [aux_sym_basic_type_token6] = ACTIONS(12815),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12813),
    [aux_sym_addafter_modification_token1] = ACTIONS(12813),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12813),
    [aux_sym_modify_modification_token1] = ACTIONS(12813),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12813),
    [aux_sym_movelast_modification_token1] = ACTIONS(12813),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12813),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12813),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12813),
    [anon_sym_POUNDif] = ACTIONS(12813),
    [anon_sym_POUNDIF] = ACTIONS(12813),
    [anon_sym_POUNDIf] = ACTIONS(12813),
    [anon_sym_POUNDelif] = ACTIONS(12813),
    [anon_sym_POUNDELIF] = ACTIONS(12813),
    [anon_sym_POUNDElif] = ACTIONS(12813),
    [anon_sym_POUNDelse] = ACTIONS(12813),
    [anon_sym_POUNDELSE] = ACTIONS(12813),
    [anon_sym_POUNDElse] = ACTIONS(12813),
    [anon_sym_POUNDelse2] = ACTIONS(12813),
    [anon_sym_POUNDELSE2] = ACTIONS(12813),
    [anon_sym_POUNDElse2] = ACTIONS(12813),
    [anon_sym_POUNDendif] = ACTIONS(12813),
    [anon_sym_POUNDENDIF] = ACTIONS(12813),
    [anon_sym_POUNDEndif] = ACTIONS(12813),
    [anon_sym_POUNDendif2] = ACTIONS(12813),
    [anon_sym_POUNDENDIF2] = ACTIONS(12813),
    [anon_sym_POUNDEndif2] = ACTIONS(12813),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12813),
    [sym_trigger_keyword] = ACTIONS(12813),
    [sym_var_keyword] = ACTIONS(12813),
    [sym_local_keyword] = ACTIONS(12813),
    [sym_internal_keyword] = ACTIONS(12813),
    [sym_protected_keyword] = ACTIONS(12813),
    [sym_event_keyword] = ACTIONS(12813),
    [sym_fields_keyword] = ACTIONS(12813),
    [sym_keys_keyword] = ACTIONS(12813),
    [sym_fieldgroups_keyword] = ACTIONS(12813),
    [sym_actions_keyword] = ACTIONS(12813),
    [sym_layout_keyword] = ACTIONS(12813),
    [sym_area_keyword] = ACTIONS(12813),
    [sym_group_keyword] = ACTIONS(12813),
    [sym_repeater_keyword] = ACTIONS(12813),
    [sym_cuegroup_keyword] = ACTIONS(12813),
    [sym_fixed_keyword] = ACTIONS(12813),
    [sym_grid_keyword] = ACTIONS(12813),
    [sym_part_keyword] = ACTIONS(12813),
    [sym_systempart_keyword] = ACTIONS(12813),
    [sym_usercontrol_keyword] = ACTIONS(12813),
    [sym_dataset_keyword] = ACTIONS(12813),
    [sym_elements_keyword] = ACTIONS(12813),
    [sym_dataitem_keyword] = ACTIONS(12813),
    [sym_column_keyword] = ACTIONS(12813),
    [sym_filter_keyword] = ACTIONS(12813),
    [sym_labels_keyword] = ACTIONS(12813),
    [sym_rendering_keyword] = ACTIONS(12813),
    [sym_requestpage_keyword] = ACTIONS(12813),
    [sym_schema_keyword] = ACTIONS(12813),
    [sym_views_keyword] = ACTIONS(12813),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12813),
    [sym_preproc_open] = ACTIONS(12813),
    [sym_preproc_close] = ACTIONS(12813),
  },
  [STATE(5192)] = {
    [anon_sym_SEMI] = ACTIONS(12817),
    [aux_sym_where_condition_token1] = ACTIONS(12819),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12817),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12817),
    [anon_sym_LBRACK] = ACTIONS(12817),
    [aux_sym_basic_type_token6] = ACTIONS(12819),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12817),
    [aux_sym_addafter_modification_token1] = ACTIONS(12817),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12817),
    [aux_sym_modify_modification_token1] = ACTIONS(12817),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12817),
    [aux_sym_movelast_modification_token1] = ACTIONS(12817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12817),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12817),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12817),
    [anon_sym_POUNDif] = ACTIONS(12817),
    [anon_sym_POUNDIF] = ACTIONS(12817),
    [anon_sym_POUNDIf] = ACTIONS(12817),
    [anon_sym_POUNDelif] = ACTIONS(12817),
    [anon_sym_POUNDELIF] = ACTIONS(12817),
    [anon_sym_POUNDElif] = ACTIONS(12817),
    [anon_sym_POUNDelse] = ACTIONS(12817),
    [anon_sym_POUNDELSE] = ACTIONS(12817),
    [anon_sym_POUNDElse] = ACTIONS(12817),
    [anon_sym_POUNDelse2] = ACTIONS(12817),
    [anon_sym_POUNDELSE2] = ACTIONS(12817),
    [anon_sym_POUNDElse2] = ACTIONS(12817),
    [anon_sym_POUNDendif] = ACTIONS(12817),
    [anon_sym_POUNDENDIF] = ACTIONS(12817),
    [anon_sym_POUNDEndif] = ACTIONS(12817),
    [anon_sym_POUNDendif2] = ACTIONS(12817),
    [anon_sym_POUNDENDIF2] = ACTIONS(12817),
    [anon_sym_POUNDEndif2] = ACTIONS(12817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12817),
    [sym_trigger_keyword] = ACTIONS(12817),
    [sym_var_keyword] = ACTIONS(12817),
    [sym_local_keyword] = ACTIONS(12817),
    [sym_internal_keyword] = ACTIONS(12817),
    [sym_protected_keyword] = ACTIONS(12817),
    [sym_event_keyword] = ACTIONS(12817),
    [sym_fields_keyword] = ACTIONS(12817),
    [sym_keys_keyword] = ACTIONS(12817),
    [sym_fieldgroups_keyword] = ACTIONS(12817),
    [sym_actions_keyword] = ACTIONS(12817),
    [sym_layout_keyword] = ACTIONS(12817),
    [sym_area_keyword] = ACTIONS(12817),
    [sym_group_keyword] = ACTIONS(12817),
    [sym_repeater_keyword] = ACTIONS(12817),
    [sym_cuegroup_keyword] = ACTIONS(12817),
    [sym_fixed_keyword] = ACTIONS(12817),
    [sym_grid_keyword] = ACTIONS(12817),
    [sym_part_keyword] = ACTIONS(12817),
    [sym_systempart_keyword] = ACTIONS(12817),
    [sym_usercontrol_keyword] = ACTIONS(12817),
    [sym_dataset_keyword] = ACTIONS(12817),
    [sym_elements_keyword] = ACTIONS(12817),
    [sym_dataitem_keyword] = ACTIONS(12817),
    [sym_column_keyword] = ACTIONS(12817),
    [sym_filter_keyword] = ACTIONS(12817),
    [sym_labels_keyword] = ACTIONS(12817),
    [sym_rendering_keyword] = ACTIONS(12817),
    [sym_requestpage_keyword] = ACTIONS(12817),
    [sym_schema_keyword] = ACTIONS(12817),
    [sym_views_keyword] = ACTIONS(12817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12817),
    [sym_preproc_open] = ACTIONS(12817),
    [sym_preproc_close] = ACTIONS(12817),
  },
  [STATE(5193)] = {
    [anon_sym_SEMI] = ACTIONS(12817),
    [aux_sym_where_condition_token1] = ACTIONS(12819),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12817),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12817),
    [anon_sym_LBRACK] = ACTIONS(12817),
    [aux_sym_basic_type_token6] = ACTIONS(12819),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12817),
    [aux_sym_addafter_modification_token1] = ACTIONS(12817),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12817),
    [aux_sym_modify_modification_token1] = ACTIONS(12817),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12817),
    [aux_sym_movelast_modification_token1] = ACTIONS(12817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12817),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12817),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12817),
    [anon_sym_POUNDif] = ACTIONS(12817),
    [anon_sym_POUNDIF] = ACTIONS(12817),
    [anon_sym_POUNDIf] = ACTIONS(12817),
    [anon_sym_POUNDelif] = ACTIONS(12817),
    [anon_sym_POUNDELIF] = ACTIONS(12817),
    [anon_sym_POUNDElif] = ACTIONS(12817),
    [anon_sym_POUNDelse] = ACTIONS(12817),
    [anon_sym_POUNDELSE] = ACTIONS(12817),
    [anon_sym_POUNDElse] = ACTIONS(12817),
    [anon_sym_POUNDelse2] = ACTIONS(12817),
    [anon_sym_POUNDELSE2] = ACTIONS(12817),
    [anon_sym_POUNDElse2] = ACTIONS(12817),
    [anon_sym_POUNDendif] = ACTIONS(12817),
    [anon_sym_POUNDENDIF] = ACTIONS(12817),
    [anon_sym_POUNDEndif] = ACTIONS(12817),
    [anon_sym_POUNDendif2] = ACTIONS(12817),
    [anon_sym_POUNDENDIF2] = ACTIONS(12817),
    [anon_sym_POUNDEndif2] = ACTIONS(12817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12817),
    [sym_trigger_keyword] = ACTIONS(12817),
    [sym_var_keyword] = ACTIONS(12817),
    [sym_local_keyword] = ACTIONS(12817),
    [sym_internal_keyword] = ACTIONS(12817),
    [sym_protected_keyword] = ACTIONS(12817),
    [sym_event_keyword] = ACTIONS(12817),
    [sym_fields_keyword] = ACTIONS(12817),
    [sym_keys_keyword] = ACTIONS(12817),
    [sym_fieldgroups_keyword] = ACTIONS(12817),
    [sym_actions_keyword] = ACTIONS(12817),
    [sym_layout_keyword] = ACTIONS(12817),
    [sym_area_keyword] = ACTIONS(12817),
    [sym_group_keyword] = ACTIONS(12817),
    [sym_repeater_keyword] = ACTIONS(12817),
    [sym_cuegroup_keyword] = ACTIONS(12817),
    [sym_fixed_keyword] = ACTIONS(12817),
    [sym_grid_keyword] = ACTIONS(12817),
    [sym_part_keyword] = ACTIONS(12817),
    [sym_systempart_keyword] = ACTIONS(12817),
    [sym_usercontrol_keyword] = ACTIONS(12817),
    [sym_dataset_keyword] = ACTIONS(12817),
    [sym_elements_keyword] = ACTIONS(12817),
    [sym_dataitem_keyword] = ACTIONS(12817),
    [sym_column_keyword] = ACTIONS(12817),
    [sym_filter_keyword] = ACTIONS(12817),
    [sym_labels_keyword] = ACTIONS(12817),
    [sym_rendering_keyword] = ACTIONS(12817),
    [sym_requestpage_keyword] = ACTIONS(12817),
    [sym_schema_keyword] = ACTIONS(12817),
    [sym_views_keyword] = ACTIONS(12817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12817),
    [sym_preproc_open] = ACTIONS(12817),
    [sym_preproc_close] = ACTIONS(12817),
  },
  [STATE(5194)] = {
    [anon_sym_SEMI] = ACTIONS(12817),
    [aux_sym_where_condition_token1] = ACTIONS(12819),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12817),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12817),
    [anon_sym_LBRACK] = ACTIONS(12817),
    [aux_sym_basic_type_token6] = ACTIONS(12819),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12817),
    [aux_sym_addafter_modification_token1] = ACTIONS(12817),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12817),
    [aux_sym_modify_modification_token1] = ACTIONS(12817),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12817),
    [aux_sym_movelast_modification_token1] = ACTIONS(12817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12817),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12817),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12817),
    [anon_sym_POUNDif] = ACTIONS(12817),
    [anon_sym_POUNDIF] = ACTIONS(12817),
    [anon_sym_POUNDIf] = ACTIONS(12817),
    [anon_sym_POUNDelif] = ACTIONS(12817),
    [anon_sym_POUNDELIF] = ACTIONS(12817),
    [anon_sym_POUNDElif] = ACTIONS(12817),
    [anon_sym_POUNDelse] = ACTIONS(12817),
    [anon_sym_POUNDELSE] = ACTIONS(12817),
    [anon_sym_POUNDElse] = ACTIONS(12817),
    [anon_sym_POUNDelse2] = ACTIONS(12817),
    [anon_sym_POUNDELSE2] = ACTIONS(12817),
    [anon_sym_POUNDElse2] = ACTIONS(12817),
    [anon_sym_POUNDendif] = ACTIONS(12817),
    [anon_sym_POUNDENDIF] = ACTIONS(12817),
    [anon_sym_POUNDEndif] = ACTIONS(12817),
    [anon_sym_POUNDendif2] = ACTIONS(12817),
    [anon_sym_POUNDENDIF2] = ACTIONS(12817),
    [anon_sym_POUNDEndif2] = ACTIONS(12817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12817),
    [sym_trigger_keyword] = ACTIONS(12817),
    [sym_var_keyword] = ACTIONS(12817),
    [sym_local_keyword] = ACTIONS(12817),
    [sym_internal_keyword] = ACTIONS(12817),
    [sym_protected_keyword] = ACTIONS(12817),
    [sym_event_keyword] = ACTIONS(12817),
    [sym_fields_keyword] = ACTIONS(12817),
    [sym_keys_keyword] = ACTIONS(12817),
    [sym_fieldgroups_keyword] = ACTIONS(12817),
    [sym_actions_keyword] = ACTIONS(12817),
    [sym_layout_keyword] = ACTIONS(12817),
    [sym_area_keyword] = ACTIONS(12817),
    [sym_group_keyword] = ACTIONS(12817),
    [sym_repeater_keyword] = ACTIONS(12817),
    [sym_cuegroup_keyword] = ACTIONS(12817),
    [sym_fixed_keyword] = ACTIONS(12817),
    [sym_grid_keyword] = ACTIONS(12817),
    [sym_part_keyword] = ACTIONS(12817),
    [sym_systempart_keyword] = ACTIONS(12817),
    [sym_usercontrol_keyword] = ACTIONS(12817),
    [sym_dataset_keyword] = ACTIONS(12817),
    [sym_elements_keyword] = ACTIONS(12817),
    [sym_dataitem_keyword] = ACTIONS(12817),
    [sym_column_keyword] = ACTIONS(12817),
    [sym_filter_keyword] = ACTIONS(12817),
    [sym_labels_keyword] = ACTIONS(12817),
    [sym_rendering_keyword] = ACTIONS(12817),
    [sym_requestpage_keyword] = ACTIONS(12817),
    [sym_schema_keyword] = ACTIONS(12817),
    [sym_views_keyword] = ACTIONS(12817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12817),
    [sym_preproc_open] = ACTIONS(12817),
    [sym_preproc_close] = ACTIONS(12817),
  },
  [STATE(5195)] = {
    [anon_sym_SEMI] = ACTIONS(12817),
    [aux_sym_where_condition_token1] = ACTIONS(12819),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12817),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12817),
    [anon_sym_LBRACK] = ACTIONS(12817),
    [aux_sym_basic_type_token6] = ACTIONS(12819),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12817),
    [aux_sym_addafter_modification_token1] = ACTIONS(12817),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12817),
    [aux_sym_modify_modification_token1] = ACTIONS(12817),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12817),
    [aux_sym_movelast_modification_token1] = ACTIONS(12817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12817),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12817),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12817),
    [anon_sym_POUNDif] = ACTIONS(12817),
    [anon_sym_POUNDIF] = ACTIONS(12817),
    [anon_sym_POUNDIf] = ACTIONS(12817),
    [anon_sym_POUNDelif] = ACTIONS(12817),
    [anon_sym_POUNDELIF] = ACTIONS(12817),
    [anon_sym_POUNDElif] = ACTIONS(12817),
    [anon_sym_POUNDelse] = ACTIONS(12817),
    [anon_sym_POUNDELSE] = ACTIONS(12817),
    [anon_sym_POUNDElse] = ACTIONS(12817),
    [anon_sym_POUNDelse2] = ACTIONS(12817),
    [anon_sym_POUNDELSE2] = ACTIONS(12817),
    [anon_sym_POUNDElse2] = ACTIONS(12817),
    [anon_sym_POUNDendif] = ACTIONS(12817),
    [anon_sym_POUNDENDIF] = ACTIONS(12817),
    [anon_sym_POUNDEndif] = ACTIONS(12817),
    [anon_sym_POUNDendif2] = ACTIONS(12817),
    [anon_sym_POUNDENDIF2] = ACTIONS(12817),
    [anon_sym_POUNDEndif2] = ACTIONS(12817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12817),
    [sym_trigger_keyword] = ACTIONS(12817),
    [sym_var_keyword] = ACTIONS(12817),
    [sym_local_keyword] = ACTIONS(12817),
    [sym_internal_keyword] = ACTIONS(12817),
    [sym_protected_keyword] = ACTIONS(12817),
    [sym_event_keyword] = ACTIONS(12817),
    [sym_fields_keyword] = ACTIONS(12817),
    [sym_keys_keyword] = ACTIONS(12817),
    [sym_fieldgroups_keyword] = ACTIONS(12817),
    [sym_actions_keyword] = ACTIONS(12817),
    [sym_layout_keyword] = ACTIONS(12817),
    [sym_area_keyword] = ACTIONS(12817),
    [sym_group_keyword] = ACTIONS(12817),
    [sym_repeater_keyword] = ACTIONS(12817),
    [sym_cuegroup_keyword] = ACTIONS(12817),
    [sym_fixed_keyword] = ACTIONS(12817),
    [sym_grid_keyword] = ACTIONS(12817),
    [sym_part_keyword] = ACTIONS(12817),
    [sym_systempart_keyword] = ACTIONS(12817),
    [sym_usercontrol_keyword] = ACTIONS(12817),
    [sym_dataset_keyword] = ACTIONS(12817),
    [sym_elements_keyword] = ACTIONS(12817),
    [sym_dataitem_keyword] = ACTIONS(12817),
    [sym_column_keyword] = ACTIONS(12817),
    [sym_filter_keyword] = ACTIONS(12817),
    [sym_labels_keyword] = ACTIONS(12817),
    [sym_rendering_keyword] = ACTIONS(12817),
    [sym_requestpage_keyword] = ACTIONS(12817),
    [sym_schema_keyword] = ACTIONS(12817),
    [sym_views_keyword] = ACTIONS(12817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12817),
    [sym_preproc_open] = ACTIONS(12817),
    [sym_preproc_close] = ACTIONS(12817),
  },
  [STATE(5196)] = {
    [anon_sym_SEMI] = ACTIONS(12817),
    [aux_sym_where_condition_token1] = ACTIONS(12819),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12817),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12817),
    [anon_sym_LBRACK] = ACTIONS(12817),
    [aux_sym_basic_type_token6] = ACTIONS(12819),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12817),
    [aux_sym_addafter_modification_token1] = ACTIONS(12817),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12817),
    [aux_sym_modify_modification_token1] = ACTIONS(12817),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12817),
    [aux_sym_movelast_modification_token1] = ACTIONS(12817),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12817),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12817),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12817),
    [anon_sym_POUNDif] = ACTIONS(12817),
    [anon_sym_POUNDIF] = ACTIONS(12817),
    [anon_sym_POUNDIf] = ACTIONS(12817),
    [anon_sym_POUNDelif] = ACTIONS(12817),
    [anon_sym_POUNDELIF] = ACTIONS(12817),
    [anon_sym_POUNDElif] = ACTIONS(12817),
    [anon_sym_POUNDelse] = ACTIONS(12817),
    [anon_sym_POUNDELSE] = ACTIONS(12817),
    [anon_sym_POUNDElse] = ACTIONS(12817),
    [anon_sym_POUNDelse2] = ACTIONS(12817),
    [anon_sym_POUNDELSE2] = ACTIONS(12817),
    [anon_sym_POUNDElse2] = ACTIONS(12817),
    [anon_sym_POUNDendif] = ACTIONS(12817),
    [anon_sym_POUNDENDIF] = ACTIONS(12817),
    [anon_sym_POUNDEndif] = ACTIONS(12817),
    [anon_sym_POUNDendif2] = ACTIONS(12817),
    [anon_sym_POUNDENDIF2] = ACTIONS(12817),
    [anon_sym_POUNDEndif2] = ACTIONS(12817),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12817),
    [sym_trigger_keyword] = ACTIONS(12817),
    [sym_var_keyword] = ACTIONS(12817),
    [sym_local_keyword] = ACTIONS(12817),
    [sym_internal_keyword] = ACTIONS(12817),
    [sym_protected_keyword] = ACTIONS(12817),
    [sym_event_keyword] = ACTIONS(12817),
    [sym_fields_keyword] = ACTIONS(12817),
    [sym_keys_keyword] = ACTIONS(12817),
    [sym_fieldgroups_keyword] = ACTIONS(12817),
    [sym_actions_keyword] = ACTIONS(12817),
    [sym_layout_keyword] = ACTIONS(12817),
    [sym_area_keyword] = ACTIONS(12817),
    [sym_group_keyword] = ACTIONS(12817),
    [sym_repeater_keyword] = ACTIONS(12817),
    [sym_cuegroup_keyword] = ACTIONS(12817),
    [sym_fixed_keyword] = ACTIONS(12817),
    [sym_grid_keyword] = ACTIONS(12817),
    [sym_part_keyword] = ACTIONS(12817),
    [sym_systempart_keyword] = ACTIONS(12817),
    [sym_usercontrol_keyword] = ACTIONS(12817),
    [sym_dataset_keyword] = ACTIONS(12817),
    [sym_elements_keyword] = ACTIONS(12817),
    [sym_dataitem_keyword] = ACTIONS(12817),
    [sym_column_keyword] = ACTIONS(12817),
    [sym_filter_keyword] = ACTIONS(12817),
    [sym_labels_keyword] = ACTIONS(12817),
    [sym_rendering_keyword] = ACTIONS(12817),
    [sym_requestpage_keyword] = ACTIONS(12817),
    [sym_schema_keyword] = ACTIONS(12817),
    [sym_views_keyword] = ACTIONS(12817),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12817),
    [sym_preproc_open] = ACTIONS(12817),
    [sym_preproc_close] = ACTIONS(12817),
  },
  [STATE(5197)] = {
    [anon_sym_SEMI] = ACTIONS(12821),
    [aux_sym_where_condition_token1] = ACTIONS(12823),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12821),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12821),
    [anon_sym_LBRACK] = ACTIONS(12821),
    [aux_sym_basic_type_token6] = ACTIONS(12823),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12821),
    [aux_sym_addafter_modification_token1] = ACTIONS(12821),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12821),
    [aux_sym_modify_modification_token1] = ACTIONS(12821),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12821),
    [aux_sym_movelast_modification_token1] = ACTIONS(12821),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12821),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12821),
    [anon_sym_POUNDif] = ACTIONS(12821),
    [anon_sym_POUNDIF] = ACTIONS(12821),
    [anon_sym_POUNDIf] = ACTIONS(12821),
    [anon_sym_POUNDelif] = ACTIONS(12821),
    [anon_sym_POUNDELIF] = ACTIONS(12821),
    [anon_sym_POUNDElif] = ACTIONS(12821),
    [anon_sym_POUNDelse] = ACTIONS(12821),
    [anon_sym_POUNDELSE] = ACTIONS(12821),
    [anon_sym_POUNDElse] = ACTIONS(12821),
    [anon_sym_POUNDelse2] = ACTIONS(12821),
    [anon_sym_POUNDELSE2] = ACTIONS(12821),
    [anon_sym_POUNDElse2] = ACTIONS(12821),
    [anon_sym_POUNDendif] = ACTIONS(12821),
    [anon_sym_POUNDENDIF] = ACTIONS(12821),
    [anon_sym_POUNDEndif] = ACTIONS(12821),
    [anon_sym_POUNDendif2] = ACTIONS(12821),
    [anon_sym_POUNDENDIF2] = ACTIONS(12821),
    [anon_sym_POUNDEndif2] = ACTIONS(12821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12821),
    [sym_trigger_keyword] = ACTIONS(12821),
    [sym_var_keyword] = ACTIONS(12821),
    [sym_local_keyword] = ACTIONS(12821),
    [sym_internal_keyword] = ACTIONS(12821),
    [sym_protected_keyword] = ACTIONS(12821),
    [sym_event_keyword] = ACTIONS(12821),
    [sym_fields_keyword] = ACTIONS(12821),
    [sym_keys_keyword] = ACTIONS(12821),
    [sym_fieldgroups_keyword] = ACTIONS(12821),
    [sym_actions_keyword] = ACTIONS(12821),
    [sym_layout_keyword] = ACTIONS(12821),
    [sym_area_keyword] = ACTIONS(12821),
    [sym_group_keyword] = ACTIONS(12821),
    [sym_repeater_keyword] = ACTIONS(12821),
    [sym_cuegroup_keyword] = ACTIONS(12821),
    [sym_fixed_keyword] = ACTIONS(12821),
    [sym_grid_keyword] = ACTIONS(12821),
    [sym_part_keyword] = ACTIONS(12821),
    [sym_systempart_keyword] = ACTIONS(12821),
    [sym_usercontrol_keyword] = ACTIONS(12821),
    [sym_dataset_keyword] = ACTIONS(12821),
    [sym_elements_keyword] = ACTIONS(12821),
    [sym_dataitem_keyword] = ACTIONS(12821),
    [sym_column_keyword] = ACTIONS(12821),
    [sym_filter_keyword] = ACTIONS(12821),
    [sym_labels_keyword] = ACTIONS(12821),
    [sym_rendering_keyword] = ACTIONS(12821),
    [sym_requestpage_keyword] = ACTIONS(12821),
    [sym_schema_keyword] = ACTIONS(12821),
    [sym_views_keyword] = ACTIONS(12821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12821),
    [sym_preproc_open] = ACTIONS(12821),
    [sym_preproc_close] = ACTIONS(12821),
  },
  [STATE(5198)] = {
    [anon_sym_SEMI] = ACTIONS(12821),
    [aux_sym_where_condition_token1] = ACTIONS(12823),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12821),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12821),
    [anon_sym_LBRACK] = ACTIONS(12821),
    [aux_sym_basic_type_token6] = ACTIONS(12823),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12821),
    [aux_sym_addafter_modification_token1] = ACTIONS(12821),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12821),
    [aux_sym_modify_modification_token1] = ACTIONS(12821),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12821),
    [aux_sym_movelast_modification_token1] = ACTIONS(12821),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12821),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12821),
    [anon_sym_POUNDif] = ACTIONS(12821),
    [anon_sym_POUNDIF] = ACTIONS(12821),
    [anon_sym_POUNDIf] = ACTIONS(12821),
    [anon_sym_POUNDelif] = ACTIONS(12821),
    [anon_sym_POUNDELIF] = ACTIONS(12821),
    [anon_sym_POUNDElif] = ACTIONS(12821),
    [anon_sym_POUNDelse] = ACTIONS(12821),
    [anon_sym_POUNDELSE] = ACTIONS(12821),
    [anon_sym_POUNDElse] = ACTIONS(12821),
    [anon_sym_POUNDelse2] = ACTIONS(12821),
    [anon_sym_POUNDELSE2] = ACTIONS(12821),
    [anon_sym_POUNDElse2] = ACTIONS(12821),
    [anon_sym_POUNDendif] = ACTIONS(12821),
    [anon_sym_POUNDENDIF] = ACTIONS(12821),
    [anon_sym_POUNDEndif] = ACTIONS(12821),
    [anon_sym_POUNDendif2] = ACTIONS(12821),
    [anon_sym_POUNDENDIF2] = ACTIONS(12821),
    [anon_sym_POUNDEndif2] = ACTIONS(12821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12821),
    [sym_trigger_keyword] = ACTIONS(12821),
    [sym_var_keyword] = ACTIONS(12821),
    [sym_local_keyword] = ACTIONS(12821),
    [sym_internal_keyword] = ACTIONS(12821),
    [sym_protected_keyword] = ACTIONS(12821),
    [sym_event_keyword] = ACTIONS(12821),
    [sym_fields_keyword] = ACTIONS(12821),
    [sym_keys_keyword] = ACTIONS(12821),
    [sym_fieldgroups_keyword] = ACTIONS(12821),
    [sym_actions_keyword] = ACTIONS(12821),
    [sym_layout_keyword] = ACTIONS(12821),
    [sym_area_keyword] = ACTIONS(12821),
    [sym_group_keyword] = ACTIONS(12821),
    [sym_repeater_keyword] = ACTIONS(12821),
    [sym_cuegroup_keyword] = ACTIONS(12821),
    [sym_fixed_keyword] = ACTIONS(12821),
    [sym_grid_keyword] = ACTIONS(12821),
    [sym_part_keyword] = ACTIONS(12821),
    [sym_systempart_keyword] = ACTIONS(12821),
    [sym_usercontrol_keyword] = ACTIONS(12821),
    [sym_dataset_keyword] = ACTIONS(12821),
    [sym_elements_keyword] = ACTIONS(12821),
    [sym_dataitem_keyword] = ACTIONS(12821),
    [sym_column_keyword] = ACTIONS(12821),
    [sym_filter_keyword] = ACTIONS(12821),
    [sym_labels_keyword] = ACTIONS(12821),
    [sym_rendering_keyword] = ACTIONS(12821),
    [sym_requestpage_keyword] = ACTIONS(12821),
    [sym_schema_keyword] = ACTIONS(12821),
    [sym_views_keyword] = ACTIONS(12821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12821),
    [sym_preproc_open] = ACTIONS(12821),
    [sym_preproc_close] = ACTIONS(12821),
  },
  [STATE(5199)] = {
    [anon_sym_SEMI] = ACTIONS(12821),
    [aux_sym_where_condition_token1] = ACTIONS(12823),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12821),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12821),
    [anon_sym_LBRACK] = ACTIONS(12821),
    [aux_sym_basic_type_token6] = ACTIONS(12823),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12821),
    [aux_sym_addafter_modification_token1] = ACTIONS(12821),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12821),
    [aux_sym_modify_modification_token1] = ACTIONS(12821),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12821),
    [aux_sym_movelast_modification_token1] = ACTIONS(12821),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12821),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12821),
    [anon_sym_POUNDif] = ACTIONS(12821),
    [anon_sym_POUNDIF] = ACTIONS(12821),
    [anon_sym_POUNDIf] = ACTIONS(12821),
    [anon_sym_POUNDelif] = ACTIONS(12821),
    [anon_sym_POUNDELIF] = ACTIONS(12821),
    [anon_sym_POUNDElif] = ACTIONS(12821),
    [anon_sym_POUNDelse] = ACTIONS(12821),
    [anon_sym_POUNDELSE] = ACTIONS(12821),
    [anon_sym_POUNDElse] = ACTIONS(12821),
    [anon_sym_POUNDelse2] = ACTIONS(12821),
    [anon_sym_POUNDELSE2] = ACTIONS(12821),
    [anon_sym_POUNDElse2] = ACTIONS(12821),
    [anon_sym_POUNDendif] = ACTIONS(12821),
    [anon_sym_POUNDENDIF] = ACTIONS(12821),
    [anon_sym_POUNDEndif] = ACTIONS(12821),
    [anon_sym_POUNDendif2] = ACTIONS(12821),
    [anon_sym_POUNDENDIF2] = ACTIONS(12821),
    [anon_sym_POUNDEndif2] = ACTIONS(12821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12821),
    [sym_trigger_keyword] = ACTIONS(12821),
    [sym_var_keyword] = ACTIONS(12821),
    [sym_local_keyword] = ACTIONS(12821),
    [sym_internal_keyword] = ACTIONS(12821),
    [sym_protected_keyword] = ACTIONS(12821),
    [sym_event_keyword] = ACTIONS(12821),
    [sym_fields_keyword] = ACTIONS(12821),
    [sym_keys_keyword] = ACTIONS(12821),
    [sym_fieldgroups_keyword] = ACTIONS(12821),
    [sym_actions_keyword] = ACTIONS(12821),
    [sym_layout_keyword] = ACTIONS(12821),
    [sym_area_keyword] = ACTIONS(12821),
    [sym_group_keyword] = ACTIONS(12821),
    [sym_repeater_keyword] = ACTIONS(12821),
    [sym_cuegroup_keyword] = ACTIONS(12821),
    [sym_fixed_keyword] = ACTIONS(12821),
    [sym_grid_keyword] = ACTIONS(12821),
    [sym_part_keyword] = ACTIONS(12821),
    [sym_systempart_keyword] = ACTIONS(12821),
    [sym_usercontrol_keyword] = ACTIONS(12821),
    [sym_dataset_keyword] = ACTIONS(12821),
    [sym_elements_keyword] = ACTIONS(12821),
    [sym_dataitem_keyword] = ACTIONS(12821),
    [sym_column_keyword] = ACTIONS(12821),
    [sym_filter_keyword] = ACTIONS(12821),
    [sym_labels_keyword] = ACTIONS(12821),
    [sym_rendering_keyword] = ACTIONS(12821),
    [sym_requestpage_keyword] = ACTIONS(12821),
    [sym_schema_keyword] = ACTIONS(12821),
    [sym_views_keyword] = ACTIONS(12821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12821),
    [sym_preproc_open] = ACTIONS(12821),
    [sym_preproc_close] = ACTIONS(12821),
  },
  [STATE(5200)] = {
    [anon_sym_SEMI] = ACTIONS(12821),
    [aux_sym_where_condition_token1] = ACTIONS(12823),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12821),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12821),
    [anon_sym_LBRACK] = ACTIONS(12821),
    [aux_sym_basic_type_token6] = ACTIONS(12823),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12821),
    [aux_sym_addafter_modification_token1] = ACTIONS(12821),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12821),
    [aux_sym_modify_modification_token1] = ACTIONS(12821),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12821),
    [aux_sym_movelast_modification_token1] = ACTIONS(12821),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12821),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12821),
    [anon_sym_POUNDif] = ACTIONS(12821),
    [anon_sym_POUNDIF] = ACTIONS(12821),
    [anon_sym_POUNDIf] = ACTIONS(12821),
    [anon_sym_POUNDelif] = ACTIONS(12821),
    [anon_sym_POUNDELIF] = ACTIONS(12821),
    [anon_sym_POUNDElif] = ACTIONS(12821),
    [anon_sym_POUNDelse] = ACTIONS(12821),
    [anon_sym_POUNDELSE] = ACTIONS(12821),
    [anon_sym_POUNDElse] = ACTIONS(12821),
    [anon_sym_POUNDelse2] = ACTIONS(12821),
    [anon_sym_POUNDELSE2] = ACTIONS(12821),
    [anon_sym_POUNDElse2] = ACTIONS(12821),
    [anon_sym_POUNDendif] = ACTIONS(12821),
    [anon_sym_POUNDENDIF] = ACTIONS(12821),
    [anon_sym_POUNDEndif] = ACTIONS(12821),
    [anon_sym_POUNDendif2] = ACTIONS(12821),
    [anon_sym_POUNDENDIF2] = ACTIONS(12821),
    [anon_sym_POUNDEndif2] = ACTIONS(12821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12821),
    [sym_trigger_keyword] = ACTIONS(12821),
    [sym_var_keyword] = ACTIONS(12821),
    [sym_local_keyword] = ACTIONS(12821),
    [sym_internal_keyword] = ACTIONS(12821),
    [sym_protected_keyword] = ACTIONS(12821),
    [sym_event_keyword] = ACTIONS(12821),
    [sym_fields_keyword] = ACTIONS(12821),
    [sym_keys_keyword] = ACTIONS(12821),
    [sym_fieldgroups_keyword] = ACTIONS(12821),
    [sym_actions_keyword] = ACTIONS(12821),
    [sym_layout_keyword] = ACTIONS(12821),
    [sym_area_keyword] = ACTIONS(12821),
    [sym_group_keyword] = ACTIONS(12821),
    [sym_repeater_keyword] = ACTIONS(12821),
    [sym_cuegroup_keyword] = ACTIONS(12821),
    [sym_fixed_keyword] = ACTIONS(12821),
    [sym_grid_keyword] = ACTIONS(12821),
    [sym_part_keyword] = ACTIONS(12821),
    [sym_systempart_keyword] = ACTIONS(12821),
    [sym_usercontrol_keyword] = ACTIONS(12821),
    [sym_dataset_keyword] = ACTIONS(12821),
    [sym_elements_keyword] = ACTIONS(12821),
    [sym_dataitem_keyword] = ACTIONS(12821),
    [sym_column_keyword] = ACTIONS(12821),
    [sym_filter_keyword] = ACTIONS(12821),
    [sym_labels_keyword] = ACTIONS(12821),
    [sym_rendering_keyword] = ACTIONS(12821),
    [sym_requestpage_keyword] = ACTIONS(12821),
    [sym_schema_keyword] = ACTIONS(12821),
    [sym_views_keyword] = ACTIONS(12821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12821),
    [sym_preproc_open] = ACTIONS(12821),
    [sym_preproc_close] = ACTIONS(12821),
  },
  [STATE(5201)] = {
    [anon_sym_SEMI] = ACTIONS(12821),
    [aux_sym_where_condition_token1] = ACTIONS(12823),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12821),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12821),
    [anon_sym_LBRACK] = ACTIONS(12821),
    [aux_sym_basic_type_token6] = ACTIONS(12823),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12821),
    [aux_sym_addafter_modification_token1] = ACTIONS(12821),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12821),
    [aux_sym_modify_modification_token1] = ACTIONS(12821),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12821),
    [aux_sym_movelast_modification_token1] = ACTIONS(12821),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12821),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12821),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12821),
    [anon_sym_POUNDif] = ACTIONS(12821),
    [anon_sym_POUNDIF] = ACTIONS(12821),
    [anon_sym_POUNDIf] = ACTIONS(12821),
    [anon_sym_POUNDelif] = ACTIONS(12821),
    [anon_sym_POUNDELIF] = ACTIONS(12821),
    [anon_sym_POUNDElif] = ACTIONS(12821),
    [anon_sym_POUNDelse] = ACTIONS(12821),
    [anon_sym_POUNDELSE] = ACTIONS(12821),
    [anon_sym_POUNDElse] = ACTIONS(12821),
    [anon_sym_POUNDelse2] = ACTIONS(12821),
    [anon_sym_POUNDELSE2] = ACTIONS(12821),
    [anon_sym_POUNDElse2] = ACTIONS(12821),
    [anon_sym_POUNDendif] = ACTIONS(12821),
    [anon_sym_POUNDENDIF] = ACTIONS(12821),
    [anon_sym_POUNDEndif] = ACTIONS(12821),
    [anon_sym_POUNDendif2] = ACTIONS(12821),
    [anon_sym_POUNDENDIF2] = ACTIONS(12821),
    [anon_sym_POUNDEndif2] = ACTIONS(12821),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12821),
    [sym_trigger_keyword] = ACTIONS(12821),
    [sym_var_keyword] = ACTIONS(12821),
    [sym_local_keyword] = ACTIONS(12821),
    [sym_internal_keyword] = ACTIONS(12821),
    [sym_protected_keyword] = ACTIONS(12821),
    [sym_event_keyword] = ACTIONS(12821),
    [sym_fields_keyword] = ACTIONS(12821),
    [sym_keys_keyword] = ACTIONS(12821),
    [sym_fieldgroups_keyword] = ACTIONS(12821),
    [sym_actions_keyword] = ACTIONS(12821),
    [sym_layout_keyword] = ACTIONS(12821),
    [sym_area_keyword] = ACTIONS(12821),
    [sym_group_keyword] = ACTIONS(12821),
    [sym_repeater_keyword] = ACTIONS(12821),
    [sym_cuegroup_keyword] = ACTIONS(12821),
    [sym_fixed_keyword] = ACTIONS(12821),
    [sym_grid_keyword] = ACTIONS(12821),
    [sym_part_keyword] = ACTIONS(12821),
    [sym_systempart_keyword] = ACTIONS(12821),
    [sym_usercontrol_keyword] = ACTIONS(12821),
    [sym_dataset_keyword] = ACTIONS(12821),
    [sym_elements_keyword] = ACTIONS(12821),
    [sym_dataitem_keyword] = ACTIONS(12821),
    [sym_column_keyword] = ACTIONS(12821),
    [sym_filter_keyword] = ACTIONS(12821),
    [sym_labels_keyword] = ACTIONS(12821),
    [sym_rendering_keyword] = ACTIONS(12821),
    [sym_requestpage_keyword] = ACTIONS(12821),
    [sym_schema_keyword] = ACTIONS(12821),
    [sym_views_keyword] = ACTIONS(12821),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12821),
    [sym_preproc_open] = ACTIONS(12821),
    [sym_preproc_close] = ACTIONS(12821),
  },
  [STATE(5202)] = {
    [anon_sym_SEMI] = ACTIONS(12825),
    [aux_sym_where_condition_token1] = ACTIONS(12827),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12825),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12825),
    [anon_sym_LBRACK] = ACTIONS(12825),
    [aux_sym_basic_type_token6] = ACTIONS(12827),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12825),
    [aux_sym_addafter_modification_token1] = ACTIONS(12825),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12825),
    [aux_sym_modify_modification_token1] = ACTIONS(12825),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12825),
    [aux_sym_movelast_modification_token1] = ACTIONS(12825),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12825),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12825),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12825),
    [anon_sym_POUNDif] = ACTIONS(12825),
    [anon_sym_POUNDIF] = ACTIONS(12825),
    [anon_sym_POUNDIf] = ACTIONS(12825),
    [anon_sym_POUNDelif] = ACTIONS(12825),
    [anon_sym_POUNDELIF] = ACTIONS(12825),
    [anon_sym_POUNDElif] = ACTIONS(12825),
    [anon_sym_POUNDelse] = ACTIONS(12825),
    [anon_sym_POUNDELSE] = ACTIONS(12825),
    [anon_sym_POUNDElse] = ACTIONS(12825),
    [anon_sym_POUNDelse2] = ACTIONS(12825),
    [anon_sym_POUNDELSE2] = ACTIONS(12825),
    [anon_sym_POUNDElse2] = ACTIONS(12825),
    [anon_sym_POUNDendif] = ACTIONS(12825),
    [anon_sym_POUNDENDIF] = ACTIONS(12825),
    [anon_sym_POUNDEndif] = ACTIONS(12825),
    [anon_sym_POUNDendif2] = ACTIONS(12825),
    [anon_sym_POUNDENDIF2] = ACTIONS(12825),
    [anon_sym_POUNDEndif2] = ACTIONS(12825),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12825),
    [sym_trigger_keyword] = ACTIONS(12825),
    [sym_var_keyword] = ACTIONS(12825),
    [sym_local_keyword] = ACTIONS(12825),
    [sym_internal_keyword] = ACTIONS(12825),
    [sym_protected_keyword] = ACTIONS(12825),
    [sym_event_keyword] = ACTIONS(12825),
    [sym_fields_keyword] = ACTIONS(12825),
    [sym_keys_keyword] = ACTIONS(12825),
    [sym_fieldgroups_keyword] = ACTIONS(12825),
    [sym_actions_keyword] = ACTIONS(12825),
    [sym_layout_keyword] = ACTIONS(12825),
    [sym_area_keyword] = ACTIONS(12825),
    [sym_group_keyword] = ACTIONS(12825),
    [sym_repeater_keyword] = ACTIONS(12825),
    [sym_cuegroup_keyword] = ACTIONS(12825),
    [sym_fixed_keyword] = ACTIONS(12825),
    [sym_grid_keyword] = ACTIONS(12825),
    [sym_part_keyword] = ACTIONS(12825),
    [sym_systempart_keyword] = ACTIONS(12825),
    [sym_usercontrol_keyword] = ACTIONS(12825),
    [sym_dataset_keyword] = ACTIONS(12825),
    [sym_elements_keyword] = ACTIONS(12825),
    [sym_dataitem_keyword] = ACTIONS(12825),
    [sym_column_keyword] = ACTIONS(12825),
    [sym_filter_keyword] = ACTIONS(12825),
    [sym_labels_keyword] = ACTIONS(12825),
    [sym_rendering_keyword] = ACTIONS(12825),
    [sym_requestpage_keyword] = ACTIONS(12825),
    [sym_schema_keyword] = ACTIONS(12825),
    [sym_views_keyword] = ACTIONS(12825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12825),
    [sym_preproc_open] = ACTIONS(12825),
    [sym_preproc_close] = ACTIONS(12825),
  },
  [STATE(5203)] = {
    [anon_sym_SEMI] = ACTIONS(12825),
    [aux_sym_where_condition_token1] = ACTIONS(12827),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12825),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12825),
    [anon_sym_LBRACK] = ACTIONS(12825),
    [aux_sym_basic_type_token6] = ACTIONS(12827),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12825),
    [aux_sym_addafter_modification_token1] = ACTIONS(12825),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12825),
    [aux_sym_modify_modification_token1] = ACTIONS(12825),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12825),
    [aux_sym_movelast_modification_token1] = ACTIONS(12825),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12825),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12825),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12825),
    [anon_sym_POUNDif] = ACTIONS(12825),
    [anon_sym_POUNDIF] = ACTIONS(12825),
    [anon_sym_POUNDIf] = ACTIONS(12825),
    [anon_sym_POUNDelif] = ACTIONS(12825),
    [anon_sym_POUNDELIF] = ACTIONS(12825),
    [anon_sym_POUNDElif] = ACTIONS(12825),
    [anon_sym_POUNDelse] = ACTIONS(12825),
    [anon_sym_POUNDELSE] = ACTIONS(12825),
    [anon_sym_POUNDElse] = ACTIONS(12825),
    [anon_sym_POUNDelse2] = ACTIONS(12825),
    [anon_sym_POUNDELSE2] = ACTIONS(12825),
    [anon_sym_POUNDElse2] = ACTIONS(12825),
    [anon_sym_POUNDendif] = ACTIONS(12825),
    [anon_sym_POUNDENDIF] = ACTIONS(12825),
    [anon_sym_POUNDEndif] = ACTIONS(12825),
    [anon_sym_POUNDendif2] = ACTIONS(12825),
    [anon_sym_POUNDENDIF2] = ACTIONS(12825),
    [anon_sym_POUNDEndif2] = ACTIONS(12825),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12825),
    [sym_trigger_keyword] = ACTIONS(12825),
    [sym_var_keyword] = ACTIONS(12825),
    [sym_local_keyword] = ACTIONS(12825),
    [sym_internal_keyword] = ACTIONS(12825),
    [sym_protected_keyword] = ACTIONS(12825),
    [sym_event_keyword] = ACTIONS(12825),
    [sym_fields_keyword] = ACTIONS(12825),
    [sym_keys_keyword] = ACTIONS(12825),
    [sym_fieldgroups_keyword] = ACTIONS(12825),
    [sym_actions_keyword] = ACTIONS(12825),
    [sym_layout_keyword] = ACTIONS(12825),
    [sym_area_keyword] = ACTIONS(12825),
    [sym_group_keyword] = ACTIONS(12825),
    [sym_repeater_keyword] = ACTIONS(12825),
    [sym_cuegroup_keyword] = ACTIONS(12825),
    [sym_fixed_keyword] = ACTIONS(12825),
    [sym_grid_keyword] = ACTIONS(12825),
    [sym_part_keyword] = ACTIONS(12825),
    [sym_systempart_keyword] = ACTIONS(12825),
    [sym_usercontrol_keyword] = ACTIONS(12825),
    [sym_dataset_keyword] = ACTIONS(12825),
    [sym_elements_keyword] = ACTIONS(12825),
    [sym_dataitem_keyword] = ACTIONS(12825),
    [sym_column_keyword] = ACTIONS(12825),
    [sym_filter_keyword] = ACTIONS(12825),
    [sym_labels_keyword] = ACTIONS(12825),
    [sym_rendering_keyword] = ACTIONS(12825),
    [sym_requestpage_keyword] = ACTIONS(12825),
    [sym_schema_keyword] = ACTIONS(12825),
    [sym_views_keyword] = ACTIONS(12825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12825),
    [sym_preproc_open] = ACTIONS(12825),
    [sym_preproc_close] = ACTIONS(12825),
  },
  [STATE(5204)] = {
    [anon_sym_SEMI] = ACTIONS(12825),
    [aux_sym_where_condition_token1] = ACTIONS(12827),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12825),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12825),
    [anon_sym_LBRACK] = ACTIONS(12825),
    [aux_sym_basic_type_token6] = ACTIONS(12827),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12825),
    [aux_sym_addafter_modification_token1] = ACTIONS(12825),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12825),
    [aux_sym_modify_modification_token1] = ACTIONS(12825),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12825),
    [aux_sym_movelast_modification_token1] = ACTIONS(12825),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12825),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12825),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12825),
    [anon_sym_POUNDif] = ACTIONS(12825),
    [anon_sym_POUNDIF] = ACTIONS(12825),
    [anon_sym_POUNDIf] = ACTIONS(12825),
    [anon_sym_POUNDelif] = ACTIONS(12825),
    [anon_sym_POUNDELIF] = ACTIONS(12825),
    [anon_sym_POUNDElif] = ACTIONS(12825),
    [anon_sym_POUNDelse] = ACTIONS(12825),
    [anon_sym_POUNDELSE] = ACTIONS(12825),
    [anon_sym_POUNDElse] = ACTIONS(12825),
    [anon_sym_POUNDelse2] = ACTIONS(12825),
    [anon_sym_POUNDELSE2] = ACTIONS(12825),
    [anon_sym_POUNDElse2] = ACTIONS(12825),
    [anon_sym_POUNDendif] = ACTIONS(12825),
    [anon_sym_POUNDENDIF] = ACTIONS(12825),
    [anon_sym_POUNDEndif] = ACTIONS(12825),
    [anon_sym_POUNDendif2] = ACTIONS(12825),
    [anon_sym_POUNDENDIF2] = ACTIONS(12825),
    [anon_sym_POUNDEndif2] = ACTIONS(12825),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12825),
    [sym_trigger_keyword] = ACTIONS(12825),
    [sym_var_keyword] = ACTIONS(12825),
    [sym_local_keyword] = ACTIONS(12825),
    [sym_internal_keyword] = ACTIONS(12825),
    [sym_protected_keyword] = ACTIONS(12825),
    [sym_event_keyword] = ACTIONS(12825),
    [sym_fields_keyword] = ACTIONS(12825),
    [sym_keys_keyword] = ACTIONS(12825),
    [sym_fieldgroups_keyword] = ACTIONS(12825),
    [sym_actions_keyword] = ACTIONS(12825),
    [sym_layout_keyword] = ACTIONS(12825),
    [sym_area_keyword] = ACTIONS(12825),
    [sym_group_keyword] = ACTIONS(12825),
    [sym_repeater_keyword] = ACTIONS(12825),
    [sym_cuegroup_keyword] = ACTIONS(12825),
    [sym_fixed_keyword] = ACTIONS(12825),
    [sym_grid_keyword] = ACTIONS(12825),
    [sym_part_keyword] = ACTIONS(12825),
    [sym_systempart_keyword] = ACTIONS(12825),
    [sym_usercontrol_keyword] = ACTIONS(12825),
    [sym_dataset_keyword] = ACTIONS(12825),
    [sym_elements_keyword] = ACTIONS(12825),
    [sym_dataitem_keyword] = ACTIONS(12825),
    [sym_column_keyword] = ACTIONS(12825),
    [sym_filter_keyword] = ACTIONS(12825),
    [sym_labels_keyword] = ACTIONS(12825),
    [sym_rendering_keyword] = ACTIONS(12825),
    [sym_requestpage_keyword] = ACTIONS(12825),
    [sym_schema_keyword] = ACTIONS(12825),
    [sym_views_keyword] = ACTIONS(12825),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12825),
    [sym_preproc_open] = ACTIONS(12825),
    [sym_preproc_close] = ACTIONS(12825),
  },
  [STATE(5205)] = {
    [anon_sym_SEMI] = ACTIONS(12829),
    [aux_sym_where_condition_token1] = ACTIONS(12831),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12829),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12829),
    [anon_sym_LBRACK] = ACTIONS(12829),
    [aux_sym_basic_type_token6] = ACTIONS(12831),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12829),
    [aux_sym_addafter_modification_token1] = ACTIONS(12829),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12829),
    [aux_sym_modify_modification_token1] = ACTIONS(12829),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12829),
    [aux_sym_movelast_modification_token1] = ACTIONS(12829),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12829),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12829),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12829),
    [anon_sym_POUNDif] = ACTIONS(12829),
    [anon_sym_POUNDIF] = ACTIONS(12829),
    [anon_sym_POUNDIf] = ACTIONS(12829),
    [anon_sym_POUNDelif] = ACTIONS(12829),
    [anon_sym_POUNDELIF] = ACTIONS(12829),
    [anon_sym_POUNDElif] = ACTIONS(12829),
    [anon_sym_POUNDelse] = ACTIONS(12829),
    [anon_sym_POUNDELSE] = ACTIONS(12829),
    [anon_sym_POUNDElse] = ACTIONS(12829),
    [anon_sym_POUNDelse2] = ACTIONS(12829),
    [anon_sym_POUNDELSE2] = ACTIONS(12829),
    [anon_sym_POUNDElse2] = ACTIONS(12829),
    [anon_sym_POUNDendif] = ACTIONS(12829),
    [anon_sym_POUNDENDIF] = ACTIONS(12829),
    [anon_sym_POUNDEndif] = ACTIONS(12829),
    [anon_sym_POUNDendif2] = ACTIONS(12829),
    [anon_sym_POUNDENDIF2] = ACTIONS(12829),
    [anon_sym_POUNDEndif2] = ACTIONS(12829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12829),
    [sym_trigger_keyword] = ACTIONS(12829),
    [sym_var_keyword] = ACTIONS(12829),
    [sym_local_keyword] = ACTIONS(12829),
    [sym_internal_keyword] = ACTIONS(12829),
    [sym_protected_keyword] = ACTIONS(12829),
    [sym_event_keyword] = ACTIONS(12829),
    [sym_fields_keyword] = ACTIONS(12829),
    [sym_keys_keyword] = ACTIONS(12829),
    [sym_fieldgroups_keyword] = ACTIONS(12829),
    [sym_actions_keyword] = ACTIONS(12829),
    [sym_layout_keyword] = ACTIONS(12829),
    [sym_area_keyword] = ACTIONS(12829),
    [sym_group_keyword] = ACTIONS(12829),
    [sym_repeater_keyword] = ACTIONS(12829),
    [sym_cuegroup_keyword] = ACTIONS(12829),
    [sym_fixed_keyword] = ACTIONS(12829),
    [sym_grid_keyword] = ACTIONS(12829),
    [sym_part_keyword] = ACTIONS(12829),
    [sym_systempart_keyword] = ACTIONS(12829),
    [sym_usercontrol_keyword] = ACTIONS(12829),
    [sym_dataset_keyword] = ACTIONS(12829),
    [sym_elements_keyword] = ACTIONS(12829),
    [sym_dataitem_keyword] = ACTIONS(12829),
    [sym_column_keyword] = ACTIONS(12829),
    [sym_filter_keyword] = ACTIONS(12829),
    [sym_labels_keyword] = ACTIONS(12829),
    [sym_rendering_keyword] = ACTIONS(12829),
    [sym_requestpage_keyword] = ACTIONS(12829),
    [sym_schema_keyword] = ACTIONS(12829),
    [sym_views_keyword] = ACTIONS(12829),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12829),
    [sym_preproc_open] = ACTIONS(12829),
    [sym_preproc_close] = ACTIONS(12829),
  },
  [STATE(5206)] = {
    [anon_sym_SEMI] = ACTIONS(12829),
    [aux_sym_where_condition_token1] = ACTIONS(12831),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12829),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12829),
    [anon_sym_LBRACK] = ACTIONS(12829),
    [aux_sym_basic_type_token6] = ACTIONS(12831),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12829),
    [aux_sym_addafter_modification_token1] = ACTIONS(12829),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12829),
    [aux_sym_modify_modification_token1] = ACTIONS(12829),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12829),
    [aux_sym_movelast_modification_token1] = ACTIONS(12829),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12829),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12829),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12829),
    [anon_sym_POUNDif] = ACTIONS(12829),
    [anon_sym_POUNDIF] = ACTIONS(12829),
    [anon_sym_POUNDIf] = ACTIONS(12829),
    [anon_sym_POUNDelif] = ACTIONS(12829),
    [anon_sym_POUNDELIF] = ACTIONS(12829),
    [anon_sym_POUNDElif] = ACTIONS(12829),
    [anon_sym_POUNDelse] = ACTIONS(12829),
    [anon_sym_POUNDELSE] = ACTIONS(12829),
    [anon_sym_POUNDElse] = ACTIONS(12829),
    [anon_sym_POUNDelse2] = ACTIONS(12829),
    [anon_sym_POUNDELSE2] = ACTIONS(12829),
    [anon_sym_POUNDElse2] = ACTIONS(12829),
    [anon_sym_POUNDendif] = ACTIONS(12829),
    [anon_sym_POUNDENDIF] = ACTIONS(12829),
    [anon_sym_POUNDEndif] = ACTIONS(12829),
    [anon_sym_POUNDendif2] = ACTIONS(12829),
    [anon_sym_POUNDENDIF2] = ACTIONS(12829),
    [anon_sym_POUNDEndif2] = ACTIONS(12829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12829),
    [sym_trigger_keyword] = ACTIONS(12829),
    [sym_var_keyword] = ACTIONS(12829),
    [sym_local_keyword] = ACTIONS(12829),
    [sym_internal_keyword] = ACTIONS(12829),
    [sym_protected_keyword] = ACTIONS(12829),
    [sym_event_keyword] = ACTIONS(12829),
    [sym_fields_keyword] = ACTIONS(12829),
    [sym_keys_keyword] = ACTIONS(12829),
    [sym_fieldgroups_keyword] = ACTIONS(12829),
    [sym_actions_keyword] = ACTIONS(12829),
    [sym_layout_keyword] = ACTIONS(12829),
    [sym_area_keyword] = ACTIONS(12829),
    [sym_group_keyword] = ACTIONS(12829),
    [sym_repeater_keyword] = ACTIONS(12829),
    [sym_cuegroup_keyword] = ACTIONS(12829),
    [sym_fixed_keyword] = ACTIONS(12829),
    [sym_grid_keyword] = ACTIONS(12829),
    [sym_part_keyword] = ACTIONS(12829),
    [sym_systempart_keyword] = ACTIONS(12829),
    [sym_usercontrol_keyword] = ACTIONS(12829),
    [sym_dataset_keyword] = ACTIONS(12829),
    [sym_elements_keyword] = ACTIONS(12829),
    [sym_dataitem_keyword] = ACTIONS(12829),
    [sym_column_keyword] = ACTIONS(12829),
    [sym_filter_keyword] = ACTIONS(12829),
    [sym_labels_keyword] = ACTIONS(12829),
    [sym_rendering_keyword] = ACTIONS(12829),
    [sym_requestpage_keyword] = ACTIONS(12829),
    [sym_schema_keyword] = ACTIONS(12829),
    [sym_views_keyword] = ACTIONS(12829),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12829),
    [sym_preproc_open] = ACTIONS(12829),
    [sym_preproc_close] = ACTIONS(12829),
  },
  [STATE(5207)] = {
    [anon_sym_SEMI] = ACTIONS(12829),
    [aux_sym_where_condition_token1] = ACTIONS(12831),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12829),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12829),
    [anon_sym_LBRACK] = ACTIONS(12829),
    [aux_sym_basic_type_token6] = ACTIONS(12831),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12829),
    [aux_sym_addafter_modification_token1] = ACTIONS(12829),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12829),
    [aux_sym_modify_modification_token1] = ACTIONS(12829),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12829),
    [aux_sym_movelast_modification_token1] = ACTIONS(12829),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12829),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12829),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12829),
    [anon_sym_POUNDif] = ACTIONS(12829),
    [anon_sym_POUNDIF] = ACTIONS(12829),
    [anon_sym_POUNDIf] = ACTIONS(12829),
    [anon_sym_POUNDelif] = ACTIONS(12829),
    [anon_sym_POUNDELIF] = ACTIONS(12829),
    [anon_sym_POUNDElif] = ACTIONS(12829),
    [anon_sym_POUNDelse] = ACTIONS(12829),
    [anon_sym_POUNDELSE] = ACTIONS(12829),
    [anon_sym_POUNDElse] = ACTIONS(12829),
    [anon_sym_POUNDelse2] = ACTIONS(12829),
    [anon_sym_POUNDELSE2] = ACTIONS(12829),
    [anon_sym_POUNDElse2] = ACTIONS(12829),
    [anon_sym_POUNDendif] = ACTIONS(12829),
    [anon_sym_POUNDENDIF] = ACTIONS(12829),
    [anon_sym_POUNDEndif] = ACTIONS(12829),
    [anon_sym_POUNDendif2] = ACTIONS(12829),
    [anon_sym_POUNDENDIF2] = ACTIONS(12829),
    [anon_sym_POUNDEndif2] = ACTIONS(12829),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12829),
    [sym_trigger_keyword] = ACTIONS(12829),
    [sym_var_keyword] = ACTIONS(12829),
    [sym_local_keyword] = ACTIONS(12829),
    [sym_internal_keyword] = ACTIONS(12829),
    [sym_protected_keyword] = ACTIONS(12829),
    [sym_event_keyword] = ACTIONS(12829),
    [sym_fields_keyword] = ACTIONS(12829),
    [sym_keys_keyword] = ACTIONS(12829),
    [sym_fieldgroups_keyword] = ACTIONS(12829),
    [sym_actions_keyword] = ACTIONS(12829),
    [sym_layout_keyword] = ACTIONS(12829),
    [sym_area_keyword] = ACTIONS(12829),
    [sym_group_keyword] = ACTIONS(12829),
    [sym_repeater_keyword] = ACTIONS(12829),
    [sym_cuegroup_keyword] = ACTIONS(12829),
    [sym_fixed_keyword] = ACTIONS(12829),
    [sym_grid_keyword] = ACTIONS(12829),
    [sym_part_keyword] = ACTIONS(12829),
    [sym_systempart_keyword] = ACTIONS(12829),
    [sym_usercontrol_keyword] = ACTIONS(12829),
    [sym_dataset_keyword] = ACTIONS(12829),
    [sym_elements_keyword] = ACTIONS(12829),
    [sym_dataitem_keyword] = ACTIONS(12829),
    [sym_column_keyword] = ACTIONS(12829),
    [sym_filter_keyword] = ACTIONS(12829),
    [sym_labels_keyword] = ACTIONS(12829),
    [sym_rendering_keyword] = ACTIONS(12829),
    [sym_requestpage_keyword] = ACTIONS(12829),
    [sym_schema_keyword] = ACTIONS(12829),
    [sym_views_keyword] = ACTIONS(12829),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12829),
    [sym_preproc_open] = ACTIONS(12829),
    [sym_preproc_close] = ACTIONS(12829),
  },
  [STATE(5208)] = {
    [anon_sym_SEMI] = ACTIONS(12662),
    [aux_sym_where_condition_token1] = ACTIONS(12664),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12662),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12662),
    [anon_sym_LBRACK] = ACTIONS(12662),
    [aux_sym_basic_type_token6] = ACTIONS(12664),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12662),
    [aux_sym_addafter_modification_token1] = ACTIONS(12662),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12662),
    [aux_sym_modify_modification_token1] = ACTIONS(12662),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12662),
    [aux_sym_movelast_modification_token1] = ACTIONS(12662),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12662),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12662),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12662),
    [anon_sym_POUNDif] = ACTIONS(12662),
    [anon_sym_POUNDIF] = ACTIONS(12662),
    [anon_sym_POUNDIf] = ACTIONS(12662),
    [anon_sym_POUNDelif] = ACTIONS(12662),
    [anon_sym_POUNDELIF] = ACTIONS(12662),
    [anon_sym_POUNDElif] = ACTIONS(12662),
    [anon_sym_POUNDelse] = ACTIONS(12662),
    [anon_sym_POUNDELSE] = ACTIONS(12662),
    [anon_sym_POUNDElse] = ACTIONS(12662),
    [anon_sym_POUNDelse2] = ACTIONS(12662),
    [anon_sym_POUNDELSE2] = ACTIONS(12662),
    [anon_sym_POUNDElse2] = ACTIONS(12662),
    [anon_sym_POUNDendif] = ACTIONS(12662),
    [anon_sym_POUNDENDIF] = ACTIONS(12662),
    [anon_sym_POUNDEndif] = ACTIONS(12662),
    [anon_sym_POUNDendif2] = ACTIONS(12662),
    [anon_sym_POUNDENDIF2] = ACTIONS(12662),
    [anon_sym_POUNDEndif2] = ACTIONS(12662),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12662),
    [sym_trigger_keyword] = ACTIONS(12662),
    [sym_var_keyword] = ACTIONS(12662),
    [sym_local_keyword] = ACTIONS(12662),
    [sym_internal_keyword] = ACTIONS(12662),
    [sym_protected_keyword] = ACTIONS(12662),
    [sym_event_keyword] = ACTIONS(12662),
    [sym_fields_keyword] = ACTIONS(12662),
    [sym_keys_keyword] = ACTIONS(12662),
    [sym_fieldgroups_keyword] = ACTIONS(12662),
    [sym_actions_keyword] = ACTIONS(12662),
    [sym_layout_keyword] = ACTIONS(12662),
    [sym_area_keyword] = ACTIONS(12662),
    [sym_group_keyword] = ACTIONS(12662),
    [sym_repeater_keyword] = ACTIONS(12662),
    [sym_cuegroup_keyword] = ACTIONS(12662),
    [sym_fixed_keyword] = ACTIONS(12662),
    [sym_grid_keyword] = ACTIONS(12662),
    [sym_part_keyword] = ACTIONS(12662),
    [sym_systempart_keyword] = ACTIONS(12662),
    [sym_usercontrol_keyword] = ACTIONS(12662),
    [sym_dataset_keyword] = ACTIONS(12662),
    [sym_elements_keyword] = ACTIONS(12662),
    [sym_dataitem_keyword] = ACTIONS(12662),
    [sym_column_keyword] = ACTIONS(12662),
    [sym_filter_keyword] = ACTIONS(12662),
    [sym_labels_keyword] = ACTIONS(12662),
    [sym_rendering_keyword] = ACTIONS(12662),
    [sym_requestpage_keyword] = ACTIONS(12662),
    [sym_schema_keyword] = ACTIONS(12662),
    [sym_views_keyword] = ACTIONS(12662),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12662),
    [sym_preproc_open] = ACTIONS(12662),
    [sym_preproc_close] = ACTIONS(12662),
  },
  [STATE(5209)] = {
    [anon_sym_SEMI] = ACTIONS(12662),
    [aux_sym_where_condition_token1] = ACTIONS(12664),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12662),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12662),
    [anon_sym_LBRACK] = ACTIONS(12662),
    [aux_sym_basic_type_token6] = ACTIONS(12664),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12662),
    [aux_sym_addafter_modification_token1] = ACTIONS(12662),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12662),
    [aux_sym_modify_modification_token1] = ACTIONS(12662),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12662),
    [aux_sym_movelast_modification_token1] = ACTIONS(12662),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12662),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12662),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12662),
    [anon_sym_POUNDif] = ACTIONS(12662),
    [anon_sym_POUNDIF] = ACTIONS(12662),
    [anon_sym_POUNDIf] = ACTIONS(12662),
    [anon_sym_POUNDelif] = ACTIONS(12662),
    [anon_sym_POUNDELIF] = ACTIONS(12662),
    [anon_sym_POUNDElif] = ACTIONS(12662),
    [anon_sym_POUNDelse] = ACTIONS(12662),
    [anon_sym_POUNDELSE] = ACTIONS(12662),
    [anon_sym_POUNDElse] = ACTIONS(12662),
    [anon_sym_POUNDelse2] = ACTIONS(12662),
    [anon_sym_POUNDELSE2] = ACTIONS(12662),
    [anon_sym_POUNDElse2] = ACTIONS(12662),
    [anon_sym_POUNDendif] = ACTIONS(12662),
    [anon_sym_POUNDENDIF] = ACTIONS(12662),
    [anon_sym_POUNDEndif] = ACTIONS(12662),
    [anon_sym_POUNDendif2] = ACTIONS(12662),
    [anon_sym_POUNDENDIF2] = ACTIONS(12662),
    [anon_sym_POUNDEndif2] = ACTIONS(12662),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12662),
    [sym_trigger_keyword] = ACTIONS(12662),
    [sym_var_keyword] = ACTIONS(12662),
    [sym_local_keyword] = ACTIONS(12662),
    [sym_internal_keyword] = ACTIONS(12662),
    [sym_protected_keyword] = ACTIONS(12662),
    [sym_event_keyword] = ACTIONS(12662),
    [sym_fields_keyword] = ACTIONS(12662),
    [sym_keys_keyword] = ACTIONS(12662),
    [sym_fieldgroups_keyword] = ACTIONS(12662),
    [sym_actions_keyword] = ACTIONS(12662),
    [sym_layout_keyword] = ACTIONS(12662),
    [sym_area_keyword] = ACTIONS(12662),
    [sym_group_keyword] = ACTIONS(12662),
    [sym_repeater_keyword] = ACTIONS(12662),
    [sym_cuegroup_keyword] = ACTIONS(12662),
    [sym_fixed_keyword] = ACTIONS(12662),
    [sym_grid_keyword] = ACTIONS(12662),
    [sym_part_keyword] = ACTIONS(12662),
    [sym_systempart_keyword] = ACTIONS(12662),
    [sym_usercontrol_keyword] = ACTIONS(12662),
    [sym_dataset_keyword] = ACTIONS(12662),
    [sym_elements_keyword] = ACTIONS(12662),
    [sym_dataitem_keyword] = ACTIONS(12662),
    [sym_column_keyword] = ACTIONS(12662),
    [sym_filter_keyword] = ACTIONS(12662),
    [sym_labels_keyword] = ACTIONS(12662),
    [sym_rendering_keyword] = ACTIONS(12662),
    [sym_requestpage_keyword] = ACTIONS(12662),
    [sym_schema_keyword] = ACTIONS(12662),
    [sym_views_keyword] = ACTIONS(12662),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12662),
    [sym_preproc_open] = ACTIONS(12662),
    [sym_preproc_close] = ACTIONS(12662),
  },
  [STATE(5210)] = {
    [anon_sym_SEMI] = ACTIONS(12662),
    [aux_sym_where_condition_token1] = ACTIONS(12664),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12662),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12662),
    [anon_sym_LBRACK] = ACTIONS(12662),
    [aux_sym_basic_type_token6] = ACTIONS(12664),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12662),
    [aux_sym_addafter_modification_token1] = ACTIONS(12662),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12662),
    [aux_sym_modify_modification_token1] = ACTIONS(12662),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12662),
    [aux_sym_movelast_modification_token1] = ACTIONS(12662),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12662),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12662),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12662),
    [anon_sym_POUNDif] = ACTIONS(12662),
    [anon_sym_POUNDIF] = ACTIONS(12662),
    [anon_sym_POUNDIf] = ACTIONS(12662),
    [anon_sym_POUNDelif] = ACTIONS(12662),
    [anon_sym_POUNDELIF] = ACTIONS(12662),
    [anon_sym_POUNDElif] = ACTIONS(12662),
    [anon_sym_POUNDelse] = ACTIONS(12662),
    [anon_sym_POUNDELSE] = ACTIONS(12662),
    [anon_sym_POUNDElse] = ACTIONS(12662),
    [anon_sym_POUNDelse2] = ACTIONS(12662),
    [anon_sym_POUNDELSE2] = ACTIONS(12662),
    [anon_sym_POUNDElse2] = ACTIONS(12662),
    [anon_sym_POUNDendif] = ACTIONS(12662),
    [anon_sym_POUNDENDIF] = ACTIONS(12662),
    [anon_sym_POUNDEndif] = ACTIONS(12662),
    [anon_sym_POUNDendif2] = ACTIONS(12662),
    [anon_sym_POUNDENDIF2] = ACTIONS(12662),
    [anon_sym_POUNDEndif2] = ACTIONS(12662),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12662),
    [sym_trigger_keyword] = ACTIONS(12662),
    [sym_var_keyword] = ACTIONS(12662),
    [sym_local_keyword] = ACTIONS(12662),
    [sym_internal_keyword] = ACTIONS(12662),
    [sym_protected_keyword] = ACTIONS(12662),
    [sym_event_keyword] = ACTIONS(12662),
    [sym_fields_keyword] = ACTIONS(12662),
    [sym_keys_keyword] = ACTIONS(12662),
    [sym_fieldgroups_keyword] = ACTIONS(12662),
    [sym_actions_keyword] = ACTIONS(12662),
    [sym_layout_keyword] = ACTIONS(12662),
    [sym_area_keyword] = ACTIONS(12662),
    [sym_group_keyword] = ACTIONS(12662),
    [sym_repeater_keyword] = ACTIONS(12662),
    [sym_cuegroup_keyword] = ACTIONS(12662),
    [sym_fixed_keyword] = ACTIONS(12662),
    [sym_grid_keyword] = ACTIONS(12662),
    [sym_part_keyword] = ACTIONS(12662),
    [sym_systempart_keyword] = ACTIONS(12662),
    [sym_usercontrol_keyword] = ACTIONS(12662),
    [sym_dataset_keyword] = ACTIONS(12662),
    [sym_elements_keyword] = ACTIONS(12662),
    [sym_dataitem_keyword] = ACTIONS(12662),
    [sym_column_keyword] = ACTIONS(12662),
    [sym_filter_keyword] = ACTIONS(12662),
    [sym_labels_keyword] = ACTIONS(12662),
    [sym_rendering_keyword] = ACTIONS(12662),
    [sym_requestpage_keyword] = ACTIONS(12662),
    [sym_schema_keyword] = ACTIONS(12662),
    [sym_views_keyword] = ACTIONS(12662),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12662),
    [sym_preproc_open] = ACTIONS(12662),
    [sym_preproc_close] = ACTIONS(12662),
  },
  [STATE(5211)] = {
    [anon_sym_SEMI] = ACTIONS(12833),
    [aux_sym_where_condition_token1] = ACTIONS(12835),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12833),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12833),
    [anon_sym_LBRACK] = ACTIONS(12833),
    [aux_sym_basic_type_token6] = ACTIONS(12835),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12833),
    [aux_sym_addafter_modification_token1] = ACTIONS(12833),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12833),
    [aux_sym_modify_modification_token1] = ACTIONS(12833),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12833),
    [aux_sym_movelast_modification_token1] = ACTIONS(12833),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12833),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12833),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12833),
    [anon_sym_POUNDif] = ACTIONS(12833),
    [anon_sym_POUNDIF] = ACTIONS(12833),
    [anon_sym_POUNDIf] = ACTIONS(12833),
    [anon_sym_POUNDelif] = ACTIONS(12833),
    [anon_sym_POUNDELIF] = ACTIONS(12833),
    [anon_sym_POUNDElif] = ACTIONS(12833),
    [anon_sym_POUNDelse] = ACTIONS(12833),
    [anon_sym_POUNDELSE] = ACTIONS(12833),
    [anon_sym_POUNDElse] = ACTIONS(12833),
    [anon_sym_POUNDelse2] = ACTIONS(12833),
    [anon_sym_POUNDELSE2] = ACTIONS(12833),
    [anon_sym_POUNDElse2] = ACTIONS(12833),
    [anon_sym_POUNDendif] = ACTIONS(12833),
    [anon_sym_POUNDENDIF] = ACTIONS(12833),
    [anon_sym_POUNDEndif] = ACTIONS(12833),
    [anon_sym_POUNDendif2] = ACTIONS(12833),
    [anon_sym_POUNDENDIF2] = ACTIONS(12833),
    [anon_sym_POUNDEndif2] = ACTIONS(12833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12833),
    [sym_trigger_keyword] = ACTIONS(12833),
    [sym_var_keyword] = ACTIONS(12833),
    [sym_local_keyword] = ACTIONS(12833),
    [sym_internal_keyword] = ACTIONS(12833),
    [sym_protected_keyword] = ACTIONS(12833),
    [sym_event_keyword] = ACTIONS(12833),
    [sym_fields_keyword] = ACTIONS(12833),
    [sym_keys_keyword] = ACTIONS(12833),
    [sym_fieldgroups_keyword] = ACTIONS(12833),
    [sym_actions_keyword] = ACTIONS(12833),
    [sym_layout_keyword] = ACTIONS(12833),
    [sym_area_keyword] = ACTIONS(12833),
    [sym_group_keyword] = ACTIONS(12833),
    [sym_repeater_keyword] = ACTIONS(12833),
    [sym_cuegroup_keyword] = ACTIONS(12833),
    [sym_fixed_keyword] = ACTIONS(12833),
    [sym_grid_keyword] = ACTIONS(12833),
    [sym_part_keyword] = ACTIONS(12833),
    [sym_systempart_keyword] = ACTIONS(12833),
    [sym_usercontrol_keyword] = ACTIONS(12833),
    [sym_dataset_keyword] = ACTIONS(12833),
    [sym_elements_keyword] = ACTIONS(12833),
    [sym_dataitem_keyword] = ACTIONS(12833),
    [sym_column_keyword] = ACTIONS(12833),
    [sym_filter_keyword] = ACTIONS(12833),
    [sym_labels_keyword] = ACTIONS(12833),
    [sym_rendering_keyword] = ACTIONS(12833),
    [sym_requestpage_keyword] = ACTIONS(12833),
    [sym_schema_keyword] = ACTIONS(12833),
    [sym_views_keyword] = ACTIONS(12833),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12833),
    [sym_preproc_open] = ACTIONS(12833),
    [sym_preproc_close] = ACTIONS(12833),
  },
  [STATE(5212)] = {
    [sym__body_element] = STATE(5097),
    [sym_empty_statement] = STATE(5097),
    [sym_property] = STATE(5097),
    [sym_permissions_property] = STATE(5097),
    [sym_table_relation_property] = STATE(5097),
    [sym_fields_section] = STATE(5097),
    [sym_keys_section] = STATE(5097),
    [sym_fieldgroups_section] = STATE(5097),
    [sym_enum_value_declaration] = STATE(5097),
    [sym_labels_section] = STATE(5097),
    [sym_layout_section] = STATE(5097),
    [sym_modify_modification] = STATE(5097),
    [sym_actions_section] = STATE(5097),
    [sym_views_section] = STATE(5097),
    [sym_dataset_section] = STATE(5097),
    [sym_report_dataitem] = STATE(5097),
    [sym__report_body_element] = STATE(5097),
    [sym_preproc_conditional_report] = STATE(5097),
    [sym_report_column] = STATE(5097),
    [sym_requestpage_section] = STATE(5097),
    [sym_rendering_section] = STATE(5097),
    [sym_elements_section] = STATE(5097),
    [sym_schema_section] = STATE(5097),
    [sym_assembly_declaration] = STATE(5097),
    [sym_event_declaration] = STATE(5097),
    [sym_procedure] = STATE(5097),
    [sym_preproc_split_procedure] = STATE(5097),
    [sym_preproc_split_procedure_preamble] = STATE(5097),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5097),
    [sym_var_section] = STATE(5097),
    [sym_attribute_item] = STATE(5097),
    [sym_preproc_conditional] = STATE(5097),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5097),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(12837),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5213)] = {
    [anon_sym_SEMI] = ACTIONS(12839),
    [aux_sym_where_condition_token1] = ACTIONS(12841),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12839),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12839),
    [anon_sym_LBRACK] = ACTIONS(12839),
    [aux_sym_basic_type_token6] = ACTIONS(12841),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12839),
    [aux_sym_addafter_modification_token1] = ACTIONS(12839),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12839),
    [aux_sym_modify_modification_token1] = ACTIONS(12839),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12839),
    [aux_sym_movelast_modification_token1] = ACTIONS(12839),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12839),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12839),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12839),
    [anon_sym_POUNDif] = ACTIONS(12839),
    [anon_sym_POUNDIF] = ACTIONS(12839),
    [anon_sym_POUNDIf] = ACTIONS(12839),
    [anon_sym_POUNDelif] = ACTIONS(12839),
    [anon_sym_POUNDELIF] = ACTIONS(12839),
    [anon_sym_POUNDElif] = ACTIONS(12839),
    [anon_sym_POUNDelse] = ACTIONS(12839),
    [anon_sym_POUNDELSE] = ACTIONS(12839),
    [anon_sym_POUNDElse] = ACTIONS(12839),
    [anon_sym_POUNDelse2] = ACTIONS(12839),
    [anon_sym_POUNDELSE2] = ACTIONS(12839),
    [anon_sym_POUNDElse2] = ACTIONS(12839),
    [anon_sym_POUNDendif] = ACTIONS(12839),
    [anon_sym_POUNDENDIF] = ACTIONS(12839),
    [anon_sym_POUNDEndif] = ACTIONS(12839),
    [anon_sym_POUNDendif2] = ACTIONS(12839),
    [anon_sym_POUNDENDIF2] = ACTIONS(12839),
    [anon_sym_POUNDEndif2] = ACTIONS(12839),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12839),
    [sym_trigger_keyword] = ACTIONS(12839),
    [sym_var_keyword] = ACTIONS(12839),
    [sym_local_keyword] = ACTIONS(12839),
    [sym_internal_keyword] = ACTIONS(12839),
    [sym_protected_keyword] = ACTIONS(12839),
    [sym_event_keyword] = ACTIONS(12839),
    [sym_fields_keyword] = ACTIONS(12839),
    [sym_keys_keyword] = ACTIONS(12839),
    [sym_fieldgroups_keyword] = ACTIONS(12839),
    [sym_actions_keyword] = ACTIONS(12839),
    [sym_layout_keyword] = ACTIONS(12839),
    [sym_area_keyword] = ACTIONS(12839),
    [sym_group_keyword] = ACTIONS(12839),
    [sym_repeater_keyword] = ACTIONS(12839),
    [sym_cuegroup_keyword] = ACTIONS(12839),
    [sym_fixed_keyword] = ACTIONS(12839),
    [sym_grid_keyword] = ACTIONS(12839),
    [sym_part_keyword] = ACTIONS(12839),
    [sym_systempart_keyword] = ACTIONS(12839),
    [sym_usercontrol_keyword] = ACTIONS(12839),
    [sym_dataset_keyword] = ACTIONS(12839),
    [sym_elements_keyword] = ACTIONS(12839),
    [sym_dataitem_keyword] = ACTIONS(12839),
    [sym_column_keyword] = ACTIONS(12839),
    [sym_filter_keyword] = ACTIONS(12839),
    [sym_labels_keyword] = ACTIONS(12839),
    [sym_rendering_keyword] = ACTIONS(12839),
    [sym_requestpage_keyword] = ACTIONS(12839),
    [sym_schema_keyword] = ACTIONS(12839),
    [sym_views_keyword] = ACTIONS(12839),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12839),
    [sym_preproc_open] = ACTIONS(12839),
    [sym_preproc_close] = ACTIONS(12839),
  },
  [STATE(5214)] = {
    [anon_sym_SEMI] = ACTIONS(8903),
    [aux_sym_where_condition_token1] = ACTIONS(8901),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8903),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8903),
    [anon_sym_LBRACK] = ACTIONS(8903),
    [aux_sym_basic_type_token6] = ACTIONS(8901),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8903),
    [aux_sym_addafter_modification_token1] = ACTIONS(8903),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8903),
    [aux_sym_modify_modification_token1] = ACTIONS(8903),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8903),
    [aux_sym_movelast_modification_token1] = ACTIONS(8903),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8903),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8903),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8903),
    [anon_sym_POUNDif] = ACTIONS(8903),
    [anon_sym_POUNDIF] = ACTIONS(8903),
    [anon_sym_POUNDIf] = ACTIONS(8903),
    [anon_sym_POUNDelif] = ACTIONS(8903),
    [anon_sym_POUNDELIF] = ACTIONS(8903),
    [anon_sym_POUNDElif] = ACTIONS(8903),
    [anon_sym_POUNDelse] = ACTIONS(8903),
    [anon_sym_POUNDELSE] = ACTIONS(8903),
    [anon_sym_POUNDElse] = ACTIONS(8903),
    [anon_sym_POUNDelse2] = ACTIONS(8903),
    [anon_sym_POUNDELSE2] = ACTIONS(8903),
    [anon_sym_POUNDElse2] = ACTIONS(8903),
    [anon_sym_POUNDendif] = ACTIONS(8903),
    [anon_sym_POUNDENDIF] = ACTIONS(8903),
    [anon_sym_POUNDEndif] = ACTIONS(8903),
    [anon_sym_POUNDendif2] = ACTIONS(8903),
    [anon_sym_POUNDENDIF2] = ACTIONS(8903),
    [anon_sym_POUNDEndif2] = ACTIONS(8903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8903),
    [sym_trigger_keyword] = ACTIONS(8903),
    [sym_var_keyword] = ACTIONS(8903),
    [sym_local_keyword] = ACTIONS(8903),
    [sym_internal_keyword] = ACTIONS(8903),
    [sym_protected_keyword] = ACTIONS(8903),
    [sym_event_keyword] = ACTIONS(8903),
    [sym_fields_keyword] = ACTIONS(8903),
    [sym_keys_keyword] = ACTIONS(8903),
    [sym_fieldgroups_keyword] = ACTIONS(8903),
    [sym_actions_keyword] = ACTIONS(8903),
    [sym_layout_keyword] = ACTIONS(8903),
    [sym_area_keyword] = ACTIONS(8903),
    [sym_group_keyword] = ACTIONS(8903),
    [sym_repeater_keyword] = ACTIONS(8903),
    [sym_cuegroup_keyword] = ACTIONS(8903),
    [sym_fixed_keyword] = ACTIONS(8903),
    [sym_grid_keyword] = ACTIONS(8903),
    [sym_part_keyword] = ACTIONS(8903),
    [sym_systempart_keyword] = ACTIONS(8903),
    [sym_usercontrol_keyword] = ACTIONS(8903),
    [sym_dataset_keyword] = ACTIONS(8903),
    [sym_elements_keyword] = ACTIONS(8903),
    [sym_dataitem_keyword] = ACTIONS(8903),
    [sym_column_keyword] = ACTIONS(8903),
    [sym_filter_keyword] = ACTIONS(8903),
    [sym_labels_keyword] = ACTIONS(8903),
    [sym_rendering_keyword] = ACTIONS(8903),
    [sym_requestpage_keyword] = ACTIONS(8903),
    [sym_schema_keyword] = ACTIONS(8903),
    [sym_views_keyword] = ACTIONS(8903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8903),
    [sym_preproc_open] = ACTIONS(8903),
    [sym_preproc_close] = ACTIONS(8903),
  },
  [STATE(5215)] = {
    [anon_sym_SEMI] = ACTIONS(12843),
    [aux_sym_where_condition_token1] = ACTIONS(12845),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12843),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12843),
    [anon_sym_LBRACK] = ACTIONS(12843),
    [aux_sym_basic_type_token6] = ACTIONS(12845),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12843),
    [aux_sym_addafter_modification_token1] = ACTIONS(12843),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12843),
    [aux_sym_modify_modification_token1] = ACTIONS(12843),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12843),
    [aux_sym_movelast_modification_token1] = ACTIONS(12843),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12843),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12843),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12843),
    [anon_sym_POUNDif] = ACTIONS(12843),
    [anon_sym_POUNDIF] = ACTIONS(12843),
    [anon_sym_POUNDIf] = ACTIONS(12843),
    [anon_sym_POUNDelif] = ACTIONS(12843),
    [anon_sym_POUNDELIF] = ACTIONS(12843),
    [anon_sym_POUNDElif] = ACTIONS(12843),
    [anon_sym_POUNDelse] = ACTIONS(12843),
    [anon_sym_POUNDELSE] = ACTIONS(12843),
    [anon_sym_POUNDElse] = ACTIONS(12843),
    [anon_sym_POUNDelse2] = ACTIONS(12843),
    [anon_sym_POUNDELSE2] = ACTIONS(12843),
    [anon_sym_POUNDElse2] = ACTIONS(12843),
    [anon_sym_POUNDendif] = ACTIONS(12843),
    [anon_sym_POUNDENDIF] = ACTIONS(12843),
    [anon_sym_POUNDEndif] = ACTIONS(12843),
    [anon_sym_POUNDendif2] = ACTIONS(12843),
    [anon_sym_POUNDENDIF2] = ACTIONS(12843),
    [anon_sym_POUNDEndif2] = ACTIONS(12843),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12843),
    [sym_trigger_keyword] = ACTIONS(12843),
    [sym_var_keyword] = ACTIONS(12843),
    [sym_local_keyword] = ACTIONS(12843),
    [sym_internal_keyword] = ACTIONS(12843),
    [sym_protected_keyword] = ACTIONS(12843),
    [sym_event_keyword] = ACTIONS(12843),
    [sym_fields_keyword] = ACTIONS(12843),
    [sym_keys_keyword] = ACTIONS(12843),
    [sym_fieldgroups_keyword] = ACTIONS(12843),
    [sym_actions_keyword] = ACTIONS(12843),
    [sym_layout_keyword] = ACTIONS(12843),
    [sym_area_keyword] = ACTIONS(12843),
    [sym_group_keyword] = ACTIONS(12843),
    [sym_repeater_keyword] = ACTIONS(12843),
    [sym_cuegroup_keyword] = ACTIONS(12843),
    [sym_fixed_keyword] = ACTIONS(12843),
    [sym_grid_keyword] = ACTIONS(12843),
    [sym_part_keyword] = ACTIONS(12843),
    [sym_systempart_keyword] = ACTIONS(12843),
    [sym_usercontrol_keyword] = ACTIONS(12843),
    [sym_dataset_keyword] = ACTIONS(12843),
    [sym_elements_keyword] = ACTIONS(12843),
    [sym_dataitem_keyword] = ACTIONS(12843),
    [sym_column_keyword] = ACTIONS(12843),
    [sym_filter_keyword] = ACTIONS(12843),
    [sym_labels_keyword] = ACTIONS(12843),
    [sym_rendering_keyword] = ACTIONS(12843),
    [sym_requestpage_keyword] = ACTIONS(12843),
    [sym_schema_keyword] = ACTIONS(12843),
    [sym_views_keyword] = ACTIONS(12843),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12843),
    [sym_preproc_open] = ACTIONS(12843),
    [sym_preproc_close] = ACTIONS(12843),
  },
  [STATE(5216)] = {
    [anon_sym_SEMI] = ACTIONS(12847),
    [aux_sym_where_condition_token1] = ACTIONS(12849),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12847),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12847),
    [anon_sym_LBRACK] = ACTIONS(12847),
    [aux_sym_basic_type_token6] = ACTIONS(12849),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12847),
    [aux_sym_addafter_modification_token1] = ACTIONS(12847),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12847),
    [aux_sym_modify_modification_token1] = ACTIONS(12847),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12847),
    [aux_sym_movelast_modification_token1] = ACTIONS(12847),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12847),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12847),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12847),
    [anon_sym_POUNDif] = ACTIONS(12847),
    [anon_sym_POUNDIF] = ACTIONS(12847),
    [anon_sym_POUNDIf] = ACTIONS(12847),
    [anon_sym_POUNDelif] = ACTIONS(12847),
    [anon_sym_POUNDELIF] = ACTIONS(12847),
    [anon_sym_POUNDElif] = ACTIONS(12847),
    [anon_sym_POUNDelse] = ACTIONS(12847),
    [anon_sym_POUNDELSE] = ACTIONS(12847),
    [anon_sym_POUNDElse] = ACTIONS(12847),
    [anon_sym_POUNDelse2] = ACTIONS(12847),
    [anon_sym_POUNDELSE2] = ACTIONS(12847),
    [anon_sym_POUNDElse2] = ACTIONS(12847),
    [anon_sym_POUNDendif] = ACTIONS(12847),
    [anon_sym_POUNDENDIF] = ACTIONS(12847),
    [anon_sym_POUNDEndif] = ACTIONS(12847),
    [anon_sym_POUNDendif2] = ACTIONS(12847),
    [anon_sym_POUNDENDIF2] = ACTIONS(12847),
    [anon_sym_POUNDEndif2] = ACTIONS(12847),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12847),
    [sym_trigger_keyword] = ACTIONS(12847),
    [sym_var_keyword] = ACTIONS(12847),
    [sym_local_keyword] = ACTIONS(12847),
    [sym_internal_keyword] = ACTIONS(12847),
    [sym_protected_keyword] = ACTIONS(12847),
    [sym_event_keyword] = ACTIONS(12847),
    [sym_fields_keyword] = ACTIONS(12847),
    [sym_keys_keyword] = ACTIONS(12847),
    [sym_fieldgroups_keyword] = ACTIONS(12847),
    [sym_actions_keyword] = ACTIONS(12847),
    [sym_layout_keyword] = ACTIONS(12847),
    [sym_area_keyword] = ACTIONS(12847),
    [sym_group_keyword] = ACTIONS(12847),
    [sym_repeater_keyword] = ACTIONS(12847),
    [sym_cuegroup_keyword] = ACTIONS(12847),
    [sym_fixed_keyword] = ACTIONS(12847),
    [sym_grid_keyword] = ACTIONS(12847),
    [sym_part_keyword] = ACTIONS(12847),
    [sym_systempart_keyword] = ACTIONS(12847),
    [sym_usercontrol_keyword] = ACTIONS(12847),
    [sym_dataset_keyword] = ACTIONS(12847),
    [sym_elements_keyword] = ACTIONS(12847),
    [sym_dataitem_keyword] = ACTIONS(12847),
    [sym_column_keyword] = ACTIONS(12847),
    [sym_filter_keyword] = ACTIONS(12847),
    [sym_labels_keyword] = ACTIONS(12847),
    [sym_rendering_keyword] = ACTIONS(12847),
    [sym_requestpage_keyword] = ACTIONS(12847),
    [sym_schema_keyword] = ACTIONS(12847),
    [sym_views_keyword] = ACTIONS(12847),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12847),
    [sym_preproc_open] = ACTIONS(12847),
    [sym_preproc_close] = ACTIONS(12847),
  },
  [STATE(5217)] = {
    [anon_sym_SEMI] = ACTIONS(12851),
    [aux_sym_where_condition_token1] = ACTIONS(12853),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12855),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12855),
    [anon_sym_LBRACK] = ACTIONS(12855),
    [aux_sym_basic_type_token6] = ACTIONS(12853),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12855),
    [aux_sym_addafter_modification_token1] = ACTIONS(12855),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12855),
    [aux_sym_modify_modification_token1] = ACTIONS(12855),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12855),
    [aux_sym_movelast_modification_token1] = ACTIONS(12855),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12855),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12855),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12855),
    [anon_sym_POUNDif] = ACTIONS(12855),
    [anon_sym_POUNDIF] = ACTIONS(12855),
    [anon_sym_POUNDIf] = ACTIONS(12855),
    [anon_sym_POUNDelif] = ACTIONS(12855),
    [anon_sym_POUNDELIF] = ACTIONS(12855),
    [anon_sym_POUNDElif] = ACTIONS(12855),
    [anon_sym_POUNDelse] = ACTIONS(12855),
    [anon_sym_POUNDELSE] = ACTIONS(12855),
    [anon_sym_POUNDElse] = ACTIONS(12855),
    [anon_sym_POUNDelse2] = ACTIONS(12855),
    [anon_sym_POUNDELSE2] = ACTIONS(12855),
    [anon_sym_POUNDElse2] = ACTIONS(12855),
    [anon_sym_POUNDendif] = ACTIONS(12855),
    [anon_sym_POUNDENDIF] = ACTIONS(12855),
    [anon_sym_POUNDEndif] = ACTIONS(12855),
    [anon_sym_POUNDendif2] = ACTIONS(12855),
    [anon_sym_POUNDENDIF2] = ACTIONS(12855),
    [anon_sym_POUNDEndif2] = ACTIONS(12855),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12855),
    [sym_trigger_keyword] = ACTIONS(12855),
    [sym_var_keyword] = ACTIONS(12855),
    [sym_local_keyword] = ACTIONS(12855),
    [sym_internal_keyword] = ACTIONS(12855),
    [sym_protected_keyword] = ACTIONS(12855),
    [sym_event_keyword] = ACTIONS(12855),
    [sym_fields_keyword] = ACTIONS(12855),
    [sym_keys_keyword] = ACTIONS(12855),
    [sym_fieldgroups_keyword] = ACTIONS(12855),
    [sym_actions_keyword] = ACTIONS(12855),
    [sym_layout_keyword] = ACTIONS(12855),
    [sym_area_keyword] = ACTIONS(12855),
    [sym_group_keyword] = ACTIONS(12855),
    [sym_repeater_keyword] = ACTIONS(12855),
    [sym_cuegroup_keyword] = ACTIONS(12855),
    [sym_fixed_keyword] = ACTIONS(12855),
    [sym_grid_keyword] = ACTIONS(12855),
    [sym_part_keyword] = ACTIONS(12855),
    [sym_systempart_keyword] = ACTIONS(12855),
    [sym_usercontrol_keyword] = ACTIONS(12855),
    [sym_dataset_keyword] = ACTIONS(12855),
    [sym_elements_keyword] = ACTIONS(12855),
    [sym_dataitem_keyword] = ACTIONS(12855),
    [sym_column_keyword] = ACTIONS(12855),
    [sym_filter_keyword] = ACTIONS(12855),
    [sym_labels_keyword] = ACTIONS(12855),
    [sym_rendering_keyword] = ACTIONS(12855),
    [sym_requestpage_keyword] = ACTIONS(12855),
    [sym_schema_keyword] = ACTIONS(12855),
    [sym_views_keyword] = ACTIONS(12855),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12855),
    [sym_preproc_open] = ACTIONS(12855),
    [sym_preproc_close] = ACTIONS(12855),
  },
  [STATE(5218)] = {
    [anon_sym_SEMI] = ACTIONS(12857),
    [aux_sym_where_condition_token1] = ACTIONS(12859),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12857),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12857),
    [anon_sym_LBRACK] = ACTIONS(12857),
    [aux_sym_basic_type_token6] = ACTIONS(12859),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12857),
    [aux_sym_addafter_modification_token1] = ACTIONS(12857),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12857),
    [aux_sym_modify_modification_token1] = ACTIONS(12857),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12857),
    [aux_sym_movelast_modification_token1] = ACTIONS(12857),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12857),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12857),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12857),
    [anon_sym_POUNDif] = ACTIONS(12857),
    [anon_sym_POUNDIF] = ACTIONS(12857),
    [anon_sym_POUNDIf] = ACTIONS(12857),
    [anon_sym_POUNDelif] = ACTIONS(12857),
    [anon_sym_POUNDELIF] = ACTIONS(12857),
    [anon_sym_POUNDElif] = ACTIONS(12857),
    [anon_sym_POUNDelse] = ACTIONS(12857),
    [anon_sym_POUNDELSE] = ACTIONS(12857),
    [anon_sym_POUNDElse] = ACTIONS(12857),
    [anon_sym_POUNDelse2] = ACTIONS(12857),
    [anon_sym_POUNDELSE2] = ACTIONS(12857),
    [anon_sym_POUNDElse2] = ACTIONS(12857),
    [anon_sym_POUNDendif] = ACTIONS(12857),
    [anon_sym_POUNDENDIF] = ACTIONS(12857),
    [anon_sym_POUNDEndif] = ACTIONS(12857),
    [anon_sym_POUNDendif2] = ACTIONS(12857),
    [anon_sym_POUNDENDIF2] = ACTIONS(12857),
    [anon_sym_POUNDEndif2] = ACTIONS(12857),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12857),
    [sym_trigger_keyword] = ACTIONS(12857),
    [sym_var_keyword] = ACTIONS(12857),
    [sym_local_keyword] = ACTIONS(12857),
    [sym_internal_keyword] = ACTIONS(12857),
    [sym_protected_keyword] = ACTIONS(12857),
    [sym_event_keyword] = ACTIONS(12857),
    [sym_fields_keyword] = ACTIONS(12857),
    [sym_keys_keyword] = ACTIONS(12857),
    [sym_fieldgroups_keyword] = ACTIONS(12857),
    [sym_actions_keyword] = ACTIONS(12857),
    [sym_layout_keyword] = ACTIONS(12857),
    [sym_area_keyword] = ACTIONS(12857),
    [sym_group_keyword] = ACTIONS(12857),
    [sym_repeater_keyword] = ACTIONS(12857),
    [sym_cuegroup_keyword] = ACTIONS(12857),
    [sym_fixed_keyword] = ACTIONS(12857),
    [sym_grid_keyword] = ACTIONS(12857),
    [sym_part_keyword] = ACTIONS(12857),
    [sym_systempart_keyword] = ACTIONS(12857),
    [sym_usercontrol_keyword] = ACTIONS(12857),
    [sym_dataset_keyword] = ACTIONS(12857),
    [sym_elements_keyword] = ACTIONS(12857),
    [sym_dataitem_keyword] = ACTIONS(12857),
    [sym_column_keyword] = ACTIONS(12857),
    [sym_filter_keyword] = ACTIONS(12857),
    [sym_labels_keyword] = ACTIONS(12857),
    [sym_rendering_keyword] = ACTIONS(12857),
    [sym_requestpage_keyword] = ACTIONS(12857),
    [sym_schema_keyword] = ACTIONS(12857),
    [sym_views_keyword] = ACTIONS(12857),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12857),
    [sym_preproc_open] = ACTIONS(12857),
    [sym_preproc_close] = ACTIONS(12857),
  },
  [STATE(5219)] = {
    [anon_sym_SEMI] = ACTIONS(12861),
    [aux_sym_where_condition_token1] = ACTIONS(12863),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12861),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12861),
    [anon_sym_LBRACK] = ACTIONS(12861),
    [aux_sym_basic_type_token6] = ACTIONS(12863),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12861),
    [aux_sym_addafter_modification_token1] = ACTIONS(12861),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12861),
    [aux_sym_modify_modification_token1] = ACTIONS(12861),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12861),
    [aux_sym_movelast_modification_token1] = ACTIONS(12861),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12861),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12861),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12861),
    [anon_sym_POUNDif] = ACTIONS(12861),
    [anon_sym_POUNDIF] = ACTIONS(12861),
    [anon_sym_POUNDIf] = ACTIONS(12861),
    [anon_sym_POUNDelif] = ACTIONS(12861),
    [anon_sym_POUNDELIF] = ACTIONS(12861),
    [anon_sym_POUNDElif] = ACTIONS(12861),
    [anon_sym_POUNDelse] = ACTIONS(12861),
    [anon_sym_POUNDELSE] = ACTIONS(12861),
    [anon_sym_POUNDElse] = ACTIONS(12861),
    [anon_sym_POUNDelse2] = ACTIONS(12861),
    [anon_sym_POUNDELSE2] = ACTIONS(12861),
    [anon_sym_POUNDElse2] = ACTIONS(12861),
    [anon_sym_POUNDendif] = ACTIONS(12861),
    [anon_sym_POUNDENDIF] = ACTIONS(12861),
    [anon_sym_POUNDEndif] = ACTIONS(12861),
    [anon_sym_POUNDendif2] = ACTIONS(12861),
    [anon_sym_POUNDENDIF2] = ACTIONS(12861),
    [anon_sym_POUNDEndif2] = ACTIONS(12861),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12861),
    [sym_trigger_keyword] = ACTIONS(12861),
    [sym_var_keyword] = ACTIONS(12861),
    [sym_local_keyword] = ACTIONS(12861),
    [sym_internal_keyword] = ACTIONS(12861),
    [sym_protected_keyword] = ACTIONS(12861),
    [sym_event_keyword] = ACTIONS(12861),
    [sym_fields_keyword] = ACTIONS(12861),
    [sym_keys_keyword] = ACTIONS(12861),
    [sym_fieldgroups_keyword] = ACTIONS(12861),
    [sym_actions_keyword] = ACTIONS(12861),
    [sym_layout_keyword] = ACTIONS(12861),
    [sym_area_keyword] = ACTIONS(12861),
    [sym_group_keyword] = ACTIONS(12861),
    [sym_repeater_keyword] = ACTIONS(12861),
    [sym_cuegroup_keyword] = ACTIONS(12861),
    [sym_fixed_keyword] = ACTIONS(12861),
    [sym_grid_keyword] = ACTIONS(12861),
    [sym_part_keyword] = ACTIONS(12861),
    [sym_systempart_keyword] = ACTIONS(12861),
    [sym_usercontrol_keyword] = ACTIONS(12861),
    [sym_dataset_keyword] = ACTIONS(12861),
    [sym_elements_keyword] = ACTIONS(12861),
    [sym_dataitem_keyword] = ACTIONS(12861),
    [sym_column_keyword] = ACTIONS(12861),
    [sym_filter_keyword] = ACTIONS(12861),
    [sym_labels_keyword] = ACTIONS(12861),
    [sym_rendering_keyword] = ACTIONS(12861),
    [sym_requestpage_keyword] = ACTIONS(12861),
    [sym_schema_keyword] = ACTIONS(12861),
    [sym_views_keyword] = ACTIONS(12861),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12861),
    [sym_preproc_open] = ACTIONS(12861),
    [sym_preproc_close] = ACTIONS(12861),
  },
  [STATE(5220)] = {
    [anon_sym_SEMI] = ACTIONS(12833),
    [aux_sym_where_condition_token1] = ACTIONS(12835),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12833),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12833),
    [anon_sym_LBRACK] = ACTIONS(12833),
    [aux_sym_basic_type_token6] = ACTIONS(12835),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12833),
    [aux_sym_addafter_modification_token1] = ACTIONS(12833),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12833),
    [aux_sym_modify_modification_token1] = ACTIONS(12833),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12833),
    [aux_sym_movelast_modification_token1] = ACTIONS(12833),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12833),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12833),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12833),
    [anon_sym_POUNDif] = ACTIONS(12833),
    [anon_sym_POUNDIF] = ACTIONS(12833),
    [anon_sym_POUNDIf] = ACTIONS(12833),
    [anon_sym_POUNDelif] = ACTIONS(12833),
    [anon_sym_POUNDELIF] = ACTIONS(12833),
    [anon_sym_POUNDElif] = ACTIONS(12833),
    [anon_sym_POUNDelse] = ACTIONS(12833),
    [anon_sym_POUNDELSE] = ACTIONS(12833),
    [anon_sym_POUNDElse] = ACTIONS(12833),
    [anon_sym_POUNDelse2] = ACTIONS(12833),
    [anon_sym_POUNDELSE2] = ACTIONS(12833),
    [anon_sym_POUNDElse2] = ACTIONS(12833),
    [anon_sym_POUNDendif] = ACTIONS(12833),
    [anon_sym_POUNDENDIF] = ACTIONS(12833),
    [anon_sym_POUNDEndif] = ACTIONS(12833),
    [anon_sym_POUNDendif2] = ACTIONS(12833),
    [anon_sym_POUNDENDIF2] = ACTIONS(12833),
    [anon_sym_POUNDEndif2] = ACTIONS(12833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12833),
    [sym_trigger_keyword] = ACTIONS(12833),
    [sym_var_keyword] = ACTIONS(12833),
    [sym_local_keyword] = ACTIONS(12833),
    [sym_internal_keyword] = ACTIONS(12833),
    [sym_protected_keyword] = ACTIONS(12833),
    [sym_event_keyword] = ACTIONS(12833),
    [sym_fields_keyword] = ACTIONS(12833),
    [sym_keys_keyword] = ACTIONS(12833),
    [sym_fieldgroups_keyword] = ACTIONS(12833),
    [sym_actions_keyword] = ACTIONS(12833),
    [sym_layout_keyword] = ACTIONS(12833),
    [sym_area_keyword] = ACTIONS(12833),
    [sym_group_keyword] = ACTIONS(12833),
    [sym_repeater_keyword] = ACTIONS(12833),
    [sym_cuegroup_keyword] = ACTIONS(12833),
    [sym_fixed_keyword] = ACTIONS(12833),
    [sym_grid_keyword] = ACTIONS(12833),
    [sym_part_keyword] = ACTIONS(12833),
    [sym_systempart_keyword] = ACTIONS(12833),
    [sym_usercontrol_keyword] = ACTIONS(12833),
    [sym_dataset_keyword] = ACTIONS(12833),
    [sym_elements_keyword] = ACTIONS(12833),
    [sym_dataitem_keyword] = ACTIONS(12833),
    [sym_column_keyword] = ACTIONS(12833),
    [sym_filter_keyword] = ACTIONS(12833),
    [sym_labels_keyword] = ACTIONS(12833),
    [sym_rendering_keyword] = ACTIONS(12833),
    [sym_requestpage_keyword] = ACTIONS(12833),
    [sym_schema_keyword] = ACTIONS(12833),
    [sym_views_keyword] = ACTIONS(12833),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12833),
    [sym_preproc_open] = ACTIONS(12833),
    [sym_preproc_close] = ACTIONS(12833),
  },
  [STATE(5221)] = {
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8907),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8907),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8907),
    [aux_sym_addafter_modification_token1] = ACTIONS(8907),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8907),
    [aux_sym_modify_modification_token1] = ACTIONS(8907),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8907),
    [aux_sym_movelast_modification_token1] = ACTIONS(8907),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8907),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8907),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8907),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8907),
    [sym_trigger_keyword] = ACTIONS(8907),
    [sym_var_keyword] = ACTIONS(8907),
    [sym_local_keyword] = ACTIONS(8907),
    [sym_internal_keyword] = ACTIONS(8907),
    [sym_protected_keyword] = ACTIONS(8907),
    [sym_event_keyword] = ACTIONS(8907),
    [sym_fields_keyword] = ACTIONS(8907),
    [sym_keys_keyword] = ACTIONS(8907),
    [sym_fieldgroups_keyword] = ACTIONS(8907),
    [sym_actions_keyword] = ACTIONS(8907),
    [sym_layout_keyword] = ACTIONS(8907),
    [sym_area_keyword] = ACTIONS(8907),
    [sym_group_keyword] = ACTIONS(8907),
    [sym_repeater_keyword] = ACTIONS(8907),
    [sym_cuegroup_keyword] = ACTIONS(8907),
    [sym_fixed_keyword] = ACTIONS(8907),
    [sym_grid_keyword] = ACTIONS(8907),
    [sym_part_keyword] = ACTIONS(8907),
    [sym_systempart_keyword] = ACTIONS(8907),
    [sym_usercontrol_keyword] = ACTIONS(8907),
    [sym_dataset_keyword] = ACTIONS(8907),
    [sym_elements_keyword] = ACTIONS(8907),
    [sym_dataitem_keyword] = ACTIONS(8907),
    [sym_column_keyword] = ACTIONS(8907),
    [sym_filter_keyword] = ACTIONS(8907),
    [sym_labels_keyword] = ACTIONS(8907),
    [sym_rendering_keyword] = ACTIONS(8907),
    [sym_requestpage_keyword] = ACTIONS(8907),
    [sym_schema_keyword] = ACTIONS(8907),
    [sym_views_keyword] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
  },
  [STATE(5222)] = {
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8907),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8907),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8907),
    [aux_sym_addafter_modification_token1] = ACTIONS(8907),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8907),
    [aux_sym_modify_modification_token1] = ACTIONS(8907),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8907),
    [aux_sym_movelast_modification_token1] = ACTIONS(8907),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8907),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8907),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8907),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8907),
    [sym_trigger_keyword] = ACTIONS(8907),
    [sym_var_keyword] = ACTIONS(8907),
    [sym_local_keyword] = ACTIONS(8907),
    [sym_internal_keyword] = ACTIONS(8907),
    [sym_protected_keyword] = ACTIONS(8907),
    [sym_event_keyword] = ACTIONS(8907),
    [sym_fields_keyword] = ACTIONS(8907),
    [sym_keys_keyword] = ACTIONS(8907),
    [sym_fieldgroups_keyword] = ACTIONS(8907),
    [sym_actions_keyword] = ACTIONS(8907),
    [sym_layout_keyword] = ACTIONS(8907),
    [sym_area_keyword] = ACTIONS(8907),
    [sym_group_keyword] = ACTIONS(8907),
    [sym_repeater_keyword] = ACTIONS(8907),
    [sym_cuegroup_keyword] = ACTIONS(8907),
    [sym_fixed_keyword] = ACTIONS(8907),
    [sym_grid_keyword] = ACTIONS(8907),
    [sym_part_keyword] = ACTIONS(8907),
    [sym_systempart_keyword] = ACTIONS(8907),
    [sym_usercontrol_keyword] = ACTIONS(8907),
    [sym_dataset_keyword] = ACTIONS(8907),
    [sym_elements_keyword] = ACTIONS(8907),
    [sym_dataitem_keyword] = ACTIONS(8907),
    [sym_column_keyword] = ACTIONS(8907),
    [sym_filter_keyword] = ACTIONS(8907),
    [sym_labels_keyword] = ACTIONS(8907),
    [sym_rendering_keyword] = ACTIONS(8907),
    [sym_requestpage_keyword] = ACTIONS(8907),
    [sym_schema_keyword] = ACTIONS(8907),
    [sym_views_keyword] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
  },
  [STATE(5223)] = {
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8907),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8907),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8907),
    [aux_sym_addafter_modification_token1] = ACTIONS(8907),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8907),
    [aux_sym_modify_modification_token1] = ACTIONS(8907),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8907),
    [aux_sym_movelast_modification_token1] = ACTIONS(8907),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8907),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8907),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8907),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8907),
    [sym_trigger_keyword] = ACTIONS(8907),
    [sym_var_keyword] = ACTIONS(8907),
    [sym_local_keyword] = ACTIONS(8907),
    [sym_internal_keyword] = ACTIONS(8907),
    [sym_protected_keyword] = ACTIONS(8907),
    [sym_event_keyword] = ACTIONS(8907),
    [sym_fields_keyword] = ACTIONS(8907),
    [sym_keys_keyword] = ACTIONS(8907),
    [sym_fieldgroups_keyword] = ACTIONS(8907),
    [sym_actions_keyword] = ACTIONS(8907),
    [sym_layout_keyword] = ACTIONS(8907),
    [sym_area_keyword] = ACTIONS(8907),
    [sym_group_keyword] = ACTIONS(8907),
    [sym_repeater_keyword] = ACTIONS(8907),
    [sym_cuegroup_keyword] = ACTIONS(8907),
    [sym_fixed_keyword] = ACTIONS(8907),
    [sym_grid_keyword] = ACTIONS(8907),
    [sym_part_keyword] = ACTIONS(8907),
    [sym_systempart_keyword] = ACTIONS(8907),
    [sym_usercontrol_keyword] = ACTIONS(8907),
    [sym_dataset_keyword] = ACTIONS(8907),
    [sym_elements_keyword] = ACTIONS(8907),
    [sym_dataitem_keyword] = ACTIONS(8907),
    [sym_column_keyword] = ACTIONS(8907),
    [sym_filter_keyword] = ACTIONS(8907),
    [sym_labels_keyword] = ACTIONS(8907),
    [sym_rendering_keyword] = ACTIONS(8907),
    [sym_requestpage_keyword] = ACTIONS(8907),
    [sym_schema_keyword] = ACTIONS(8907),
    [sym_views_keyword] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
  },
  [STATE(5224)] = {
    [anon_sym_SEMI] = ACTIONS(8911),
    [aux_sym_where_condition_token1] = ACTIONS(8909),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8911),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8911),
    [anon_sym_LBRACK] = ACTIONS(8911),
    [aux_sym_basic_type_token6] = ACTIONS(8909),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8911),
    [aux_sym_addafter_modification_token1] = ACTIONS(8911),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8911),
    [aux_sym_modify_modification_token1] = ACTIONS(8911),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8911),
    [aux_sym_movelast_modification_token1] = ACTIONS(8911),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8911),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8911),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8911),
    [anon_sym_POUNDif] = ACTIONS(8911),
    [anon_sym_POUNDIF] = ACTIONS(8911),
    [anon_sym_POUNDIf] = ACTIONS(8911),
    [anon_sym_POUNDelif] = ACTIONS(8911),
    [anon_sym_POUNDELIF] = ACTIONS(8911),
    [anon_sym_POUNDElif] = ACTIONS(8911),
    [anon_sym_POUNDelse] = ACTIONS(8911),
    [anon_sym_POUNDELSE] = ACTIONS(8911),
    [anon_sym_POUNDElse] = ACTIONS(8911),
    [anon_sym_POUNDelse2] = ACTIONS(8911),
    [anon_sym_POUNDELSE2] = ACTIONS(8911),
    [anon_sym_POUNDElse2] = ACTIONS(8911),
    [anon_sym_POUNDendif] = ACTIONS(8911),
    [anon_sym_POUNDENDIF] = ACTIONS(8911),
    [anon_sym_POUNDEndif] = ACTIONS(8911),
    [anon_sym_POUNDendif2] = ACTIONS(8911),
    [anon_sym_POUNDENDIF2] = ACTIONS(8911),
    [anon_sym_POUNDEndif2] = ACTIONS(8911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8911),
    [sym_trigger_keyword] = ACTIONS(8911),
    [sym_var_keyword] = ACTIONS(8911),
    [sym_local_keyword] = ACTIONS(8911),
    [sym_internal_keyword] = ACTIONS(8911),
    [sym_protected_keyword] = ACTIONS(8911),
    [sym_event_keyword] = ACTIONS(8911),
    [sym_fields_keyword] = ACTIONS(8911),
    [sym_keys_keyword] = ACTIONS(8911),
    [sym_fieldgroups_keyword] = ACTIONS(8911),
    [sym_actions_keyword] = ACTIONS(8911),
    [sym_layout_keyword] = ACTIONS(8911),
    [sym_area_keyword] = ACTIONS(8911),
    [sym_group_keyword] = ACTIONS(8911),
    [sym_repeater_keyword] = ACTIONS(8911),
    [sym_cuegroup_keyword] = ACTIONS(8911),
    [sym_fixed_keyword] = ACTIONS(8911),
    [sym_grid_keyword] = ACTIONS(8911),
    [sym_part_keyword] = ACTIONS(8911),
    [sym_systempart_keyword] = ACTIONS(8911),
    [sym_usercontrol_keyword] = ACTIONS(8911),
    [sym_dataset_keyword] = ACTIONS(8911),
    [sym_elements_keyword] = ACTIONS(8911),
    [sym_dataitem_keyword] = ACTIONS(8911),
    [sym_column_keyword] = ACTIONS(8911),
    [sym_filter_keyword] = ACTIONS(8911),
    [sym_labels_keyword] = ACTIONS(8911),
    [sym_rendering_keyword] = ACTIONS(8911),
    [sym_requestpage_keyword] = ACTIONS(8911),
    [sym_schema_keyword] = ACTIONS(8911),
    [sym_views_keyword] = ACTIONS(8911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8911),
    [sym_preproc_open] = ACTIONS(8911),
    [sym_preproc_close] = ACTIONS(8911),
  },
  [STATE(5225)] = {
    [anon_sym_SEMI] = ACTIONS(12865),
    [aux_sym_where_condition_token1] = ACTIONS(12867),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12865),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12865),
    [anon_sym_LBRACK] = ACTIONS(12865),
    [aux_sym_basic_type_token6] = ACTIONS(12867),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12865),
    [aux_sym_addafter_modification_token1] = ACTIONS(12865),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12865),
    [aux_sym_modify_modification_token1] = ACTIONS(12865),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12865),
    [aux_sym_movelast_modification_token1] = ACTIONS(12865),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12865),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12865),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12865),
    [anon_sym_POUNDif] = ACTIONS(12865),
    [anon_sym_POUNDIF] = ACTIONS(12865),
    [anon_sym_POUNDIf] = ACTIONS(12865),
    [anon_sym_POUNDelif] = ACTIONS(12865),
    [anon_sym_POUNDELIF] = ACTIONS(12865),
    [anon_sym_POUNDElif] = ACTIONS(12865),
    [anon_sym_POUNDelse] = ACTIONS(12865),
    [anon_sym_POUNDELSE] = ACTIONS(12865),
    [anon_sym_POUNDElse] = ACTIONS(12865),
    [anon_sym_POUNDelse2] = ACTIONS(12865),
    [anon_sym_POUNDELSE2] = ACTIONS(12865),
    [anon_sym_POUNDElse2] = ACTIONS(12865),
    [anon_sym_POUNDendif] = ACTIONS(12865),
    [anon_sym_POUNDENDIF] = ACTIONS(12865),
    [anon_sym_POUNDEndif] = ACTIONS(12865),
    [anon_sym_POUNDendif2] = ACTIONS(12865),
    [anon_sym_POUNDENDIF2] = ACTIONS(12865),
    [anon_sym_POUNDEndif2] = ACTIONS(12865),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12865),
    [sym_trigger_keyword] = ACTIONS(12865),
    [sym_var_keyword] = ACTIONS(12865),
    [sym_local_keyword] = ACTIONS(12865),
    [sym_internal_keyword] = ACTIONS(12865),
    [sym_protected_keyword] = ACTIONS(12865),
    [sym_event_keyword] = ACTIONS(12865),
    [sym_fields_keyword] = ACTIONS(12865),
    [sym_keys_keyword] = ACTIONS(12865),
    [sym_fieldgroups_keyword] = ACTIONS(12865),
    [sym_actions_keyword] = ACTIONS(12865),
    [sym_layout_keyword] = ACTIONS(12865),
    [sym_area_keyword] = ACTIONS(12865),
    [sym_group_keyword] = ACTIONS(12865),
    [sym_repeater_keyword] = ACTIONS(12865),
    [sym_cuegroup_keyword] = ACTIONS(12865),
    [sym_fixed_keyword] = ACTIONS(12865),
    [sym_grid_keyword] = ACTIONS(12865),
    [sym_part_keyword] = ACTIONS(12865),
    [sym_systempart_keyword] = ACTIONS(12865),
    [sym_usercontrol_keyword] = ACTIONS(12865),
    [sym_dataset_keyword] = ACTIONS(12865),
    [sym_elements_keyword] = ACTIONS(12865),
    [sym_dataitem_keyword] = ACTIONS(12865),
    [sym_column_keyword] = ACTIONS(12865),
    [sym_filter_keyword] = ACTIONS(12865),
    [sym_labels_keyword] = ACTIONS(12865),
    [sym_rendering_keyword] = ACTIONS(12865),
    [sym_requestpage_keyword] = ACTIONS(12865),
    [sym_schema_keyword] = ACTIONS(12865),
    [sym_views_keyword] = ACTIONS(12865),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12865),
    [sym_preproc_open] = ACTIONS(12865),
    [sym_preproc_close] = ACTIONS(12865),
  },
  [STATE(5226)] = {
    [anon_sym_SEMI] = ACTIONS(8333),
    [anon_sym_COMMA] = ACTIONS(8333),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8333),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8333),
    [anon_sym_LBRACK] = ACTIONS(8333),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8333),
    [aux_sym_modify_modification_token1] = ACTIONS(8333),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8333),
    [anon_sym_POUNDif] = ACTIONS(8333),
    [anon_sym_POUNDIF] = ACTIONS(8333),
    [anon_sym_POUNDIf] = ACTIONS(8333),
    [anon_sym_POUNDelif] = ACTIONS(8333),
    [anon_sym_POUNDELIF] = ACTIONS(8333),
    [anon_sym_POUNDElif] = ACTIONS(8333),
    [anon_sym_POUNDelse] = ACTIONS(8333),
    [anon_sym_POUNDELSE] = ACTIONS(8333),
    [anon_sym_POUNDElse] = ACTIONS(8333),
    [anon_sym_POUNDelse2] = ACTIONS(8333),
    [anon_sym_POUNDELSE2] = ACTIONS(8333),
    [anon_sym_POUNDElse2] = ACTIONS(8333),
    [anon_sym_POUNDendif] = ACTIONS(8333),
    [anon_sym_POUNDENDIF] = ACTIONS(8333),
    [anon_sym_POUNDEndif] = ACTIONS(8333),
    [anon_sym_POUNDendif2] = ACTIONS(8333),
    [anon_sym_POUNDENDIF2] = ACTIONS(8333),
    [anon_sym_POUNDEndif2] = ACTIONS(8333),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8335),
    [sym_page_keyword] = ACTIONS(8333),
    [anon_sym_codeunit] = ACTIONS(8333),
    [anon_sym_CODEUNIT] = ACTIONS(8333),
    [anon_sym_Codeunit] = ACTIONS(8333),
    [anon_sym_CodeUnit] = ACTIONS(8333),
    [anon_sym_COdeunit] = ACTIONS(8333),
    [anon_sym_codeUnit] = ACTIONS(8333),
    [sym_report_keyword] = ACTIONS(8333),
    [sym_query_keyword] = ACTIONS(8333),
    [anon_sym_xmlport] = ACTIONS(8333),
    [anon_sym_XMLPORT] = ACTIONS(8333),
    [anon_sym_Xmlport] = ACTIONS(8333),
    [anon_sym_XMLport] = ACTIONS(8333),
    [anon_sym_XMLPort] = ACTIONS(8333),
    [anon_sym_XmlPort] = ACTIONS(8333),
    [sym_procedure_keyword] = ACTIONS(8333),
    [sym_trigger_keyword] = ACTIONS(8333),
    [sym_var_keyword] = ACTIONS(8333),
    [sym_local_keyword] = ACTIONS(8333),
    [sym_internal_keyword] = ACTIONS(8333),
    [sym_protected_keyword] = ACTIONS(8333),
    [sym_event_keyword] = ACTIONS(8333),
    [sym_fields_keyword] = ACTIONS(8333),
    [sym_keys_keyword] = ACTIONS(8333),
    [sym_fieldgroups_keyword] = ACTIONS(8333),
    [sym_actions_keyword] = ACTIONS(8333),
    [sym_layout_keyword] = ACTIONS(8333),
    [sym_dataset_keyword] = ACTIONS(8333),
    [sym_elements_keyword] = ACTIONS(8333),
    [sym_dataitem_keyword] = ACTIONS(8333),
    [sym_column_keyword] = ACTIONS(8333),
    [sym_filter_keyword] = ACTIONS(8333),
    [sym_labels_keyword] = ACTIONS(8333),
    [sym_rendering_keyword] = ACTIONS(8333),
    [sym_requestpage_keyword] = ACTIONS(8333),
    [sym_schema_keyword] = ACTIONS(8333),
    [sym_views_keyword] = ACTIONS(8333),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8333),
    [sym_preproc_open] = ACTIONS(8333),
    [sym_preproc_close] = ACTIONS(8333),
  },
  [STATE(5227)] = {
    [anon_sym_SEMI] = ACTIONS(12869),
    [aux_sym_where_condition_token1] = ACTIONS(12871),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12869),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12869),
    [anon_sym_LBRACK] = ACTIONS(12869),
    [aux_sym_basic_type_token6] = ACTIONS(12871),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12869),
    [aux_sym_addafter_modification_token1] = ACTIONS(12869),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12869),
    [aux_sym_modify_modification_token1] = ACTIONS(12869),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12869),
    [aux_sym_movelast_modification_token1] = ACTIONS(12869),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12869),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12869),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12869),
    [anon_sym_POUNDif] = ACTIONS(12869),
    [anon_sym_POUNDIF] = ACTIONS(12869),
    [anon_sym_POUNDIf] = ACTIONS(12869),
    [anon_sym_POUNDelif] = ACTIONS(12869),
    [anon_sym_POUNDELIF] = ACTIONS(12869),
    [anon_sym_POUNDElif] = ACTIONS(12869),
    [anon_sym_POUNDelse] = ACTIONS(12869),
    [anon_sym_POUNDELSE] = ACTIONS(12869),
    [anon_sym_POUNDElse] = ACTIONS(12869),
    [anon_sym_POUNDelse2] = ACTIONS(12869),
    [anon_sym_POUNDELSE2] = ACTIONS(12869),
    [anon_sym_POUNDElse2] = ACTIONS(12869),
    [anon_sym_POUNDendif] = ACTIONS(12869),
    [anon_sym_POUNDENDIF] = ACTIONS(12869),
    [anon_sym_POUNDEndif] = ACTIONS(12869),
    [anon_sym_POUNDendif2] = ACTIONS(12869),
    [anon_sym_POUNDENDIF2] = ACTIONS(12869),
    [anon_sym_POUNDEndif2] = ACTIONS(12869),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12869),
    [sym_trigger_keyword] = ACTIONS(12869),
    [sym_var_keyword] = ACTIONS(12869),
    [sym_local_keyword] = ACTIONS(12869),
    [sym_internal_keyword] = ACTIONS(12869),
    [sym_protected_keyword] = ACTIONS(12869),
    [sym_event_keyword] = ACTIONS(12869),
    [sym_fields_keyword] = ACTIONS(12869),
    [sym_keys_keyword] = ACTIONS(12869),
    [sym_fieldgroups_keyword] = ACTIONS(12869),
    [sym_actions_keyword] = ACTIONS(12869),
    [sym_layout_keyword] = ACTIONS(12869),
    [sym_area_keyword] = ACTIONS(12869),
    [sym_group_keyword] = ACTIONS(12869),
    [sym_repeater_keyword] = ACTIONS(12869),
    [sym_cuegroup_keyword] = ACTIONS(12869),
    [sym_fixed_keyword] = ACTIONS(12869),
    [sym_grid_keyword] = ACTIONS(12869),
    [sym_part_keyword] = ACTIONS(12869),
    [sym_systempart_keyword] = ACTIONS(12869),
    [sym_usercontrol_keyword] = ACTIONS(12869),
    [sym_dataset_keyword] = ACTIONS(12869),
    [sym_elements_keyword] = ACTIONS(12869),
    [sym_dataitem_keyword] = ACTIONS(12869),
    [sym_column_keyword] = ACTIONS(12869),
    [sym_filter_keyword] = ACTIONS(12869),
    [sym_labels_keyword] = ACTIONS(12869),
    [sym_rendering_keyword] = ACTIONS(12869),
    [sym_requestpage_keyword] = ACTIONS(12869),
    [sym_schema_keyword] = ACTIONS(12869),
    [sym_views_keyword] = ACTIONS(12869),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12869),
    [sym_preproc_open] = ACTIONS(12869),
    [sym_preproc_close] = ACTIONS(12869),
  },
  [STATE(5228)] = {
    [anon_sym_SEMI] = ACTIONS(12873),
    [aux_sym_where_condition_token1] = ACTIONS(12875),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12873),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12873),
    [anon_sym_LBRACK] = ACTIONS(12873),
    [aux_sym_basic_type_token6] = ACTIONS(12875),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12873),
    [aux_sym_addafter_modification_token1] = ACTIONS(12873),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12873),
    [aux_sym_modify_modification_token1] = ACTIONS(12873),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12873),
    [aux_sym_movelast_modification_token1] = ACTIONS(12873),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12873),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12873),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12873),
    [anon_sym_POUNDif] = ACTIONS(12873),
    [anon_sym_POUNDIF] = ACTIONS(12873),
    [anon_sym_POUNDIf] = ACTIONS(12873),
    [anon_sym_POUNDelif] = ACTIONS(12873),
    [anon_sym_POUNDELIF] = ACTIONS(12873),
    [anon_sym_POUNDElif] = ACTIONS(12873),
    [anon_sym_POUNDelse] = ACTIONS(12873),
    [anon_sym_POUNDELSE] = ACTIONS(12873),
    [anon_sym_POUNDElse] = ACTIONS(12873),
    [anon_sym_POUNDelse2] = ACTIONS(12873),
    [anon_sym_POUNDELSE2] = ACTIONS(12873),
    [anon_sym_POUNDElse2] = ACTIONS(12873),
    [anon_sym_POUNDendif] = ACTIONS(12873),
    [anon_sym_POUNDENDIF] = ACTIONS(12873),
    [anon_sym_POUNDEndif] = ACTIONS(12873),
    [anon_sym_POUNDendif2] = ACTIONS(12873),
    [anon_sym_POUNDENDIF2] = ACTIONS(12873),
    [anon_sym_POUNDEndif2] = ACTIONS(12873),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12873),
    [sym_trigger_keyword] = ACTIONS(12873),
    [sym_var_keyword] = ACTIONS(12873),
    [sym_local_keyword] = ACTIONS(12873),
    [sym_internal_keyword] = ACTIONS(12873),
    [sym_protected_keyword] = ACTIONS(12873),
    [sym_event_keyword] = ACTIONS(12873),
    [sym_fields_keyword] = ACTIONS(12873),
    [sym_keys_keyword] = ACTIONS(12873),
    [sym_fieldgroups_keyword] = ACTIONS(12873),
    [sym_actions_keyword] = ACTIONS(12873),
    [sym_layout_keyword] = ACTIONS(12873),
    [sym_area_keyword] = ACTIONS(12873),
    [sym_group_keyword] = ACTIONS(12873),
    [sym_repeater_keyword] = ACTIONS(12873),
    [sym_cuegroup_keyword] = ACTIONS(12873),
    [sym_fixed_keyword] = ACTIONS(12873),
    [sym_grid_keyword] = ACTIONS(12873),
    [sym_part_keyword] = ACTIONS(12873),
    [sym_systempart_keyword] = ACTIONS(12873),
    [sym_usercontrol_keyword] = ACTIONS(12873),
    [sym_dataset_keyword] = ACTIONS(12873),
    [sym_elements_keyword] = ACTIONS(12873),
    [sym_dataitem_keyword] = ACTIONS(12873),
    [sym_column_keyword] = ACTIONS(12873),
    [sym_filter_keyword] = ACTIONS(12873),
    [sym_labels_keyword] = ACTIONS(12873),
    [sym_rendering_keyword] = ACTIONS(12873),
    [sym_requestpage_keyword] = ACTIONS(12873),
    [sym_schema_keyword] = ACTIONS(12873),
    [sym_views_keyword] = ACTIONS(12873),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12873),
    [sym_preproc_open] = ACTIONS(12873),
    [sym_preproc_close] = ACTIONS(12873),
  },
  [STATE(5229)] = {
    [anon_sym_SEMI] = ACTIONS(12833),
    [aux_sym_where_condition_token1] = ACTIONS(12835),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12833),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12833),
    [anon_sym_LBRACK] = ACTIONS(12833),
    [aux_sym_basic_type_token6] = ACTIONS(12835),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12833),
    [aux_sym_addafter_modification_token1] = ACTIONS(12833),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12833),
    [aux_sym_modify_modification_token1] = ACTIONS(12833),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12833),
    [aux_sym_movelast_modification_token1] = ACTIONS(12833),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12833),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12833),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12833),
    [anon_sym_POUNDif] = ACTIONS(12833),
    [anon_sym_POUNDIF] = ACTIONS(12833),
    [anon_sym_POUNDIf] = ACTIONS(12833),
    [anon_sym_POUNDelif] = ACTIONS(12833),
    [anon_sym_POUNDELIF] = ACTIONS(12833),
    [anon_sym_POUNDElif] = ACTIONS(12833),
    [anon_sym_POUNDelse] = ACTIONS(12833),
    [anon_sym_POUNDELSE] = ACTIONS(12833),
    [anon_sym_POUNDElse] = ACTIONS(12833),
    [anon_sym_POUNDelse2] = ACTIONS(12833),
    [anon_sym_POUNDELSE2] = ACTIONS(12833),
    [anon_sym_POUNDElse2] = ACTIONS(12833),
    [anon_sym_POUNDendif] = ACTIONS(12833),
    [anon_sym_POUNDENDIF] = ACTIONS(12833),
    [anon_sym_POUNDEndif] = ACTIONS(12833),
    [anon_sym_POUNDendif2] = ACTIONS(12833),
    [anon_sym_POUNDENDIF2] = ACTIONS(12833),
    [anon_sym_POUNDEndif2] = ACTIONS(12833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12833),
    [sym_trigger_keyword] = ACTIONS(12833),
    [sym_var_keyword] = ACTIONS(12833),
    [sym_local_keyword] = ACTIONS(12833),
    [sym_internal_keyword] = ACTIONS(12833),
    [sym_protected_keyword] = ACTIONS(12833),
    [sym_event_keyword] = ACTIONS(12833),
    [sym_fields_keyword] = ACTIONS(12833),
    [sym_keys_keyword] = ACTIONS(12833),
    [sym_fieldgroups_keyword] = ACTIONS(12833),
    [sym_actions_keyword] = ACTIONS(12833),
    [sym_layout_keyword] = ACTIONS(12833),
    [sym_area_keyword] = ACTIONS(12833),
    [sym_group_keyword] = ACTIONS(12833),
    [sym_repeater_keyword] = ACTIONS(12833),
    [sym_cuegroup_keyword] = ACTIONS(12833),
    [sym_fixed_keyword] = ACTIONS(12833),
    [sym_grid_keyword] = ACTIONS(12833),
    [sym_part_keyword] = ACTIONS(12833),
    [sym_systempart_keyword] = ACTIONS(12833),
    [sym_usercontrol_keyword] = ACTIONS(12833),
    [sym_dataset_keyword] = ACTIONS(12833),
    [sym_elements_keyword] = ACTIONS(12833),
    [sym_dataitem_keyword] = ACTIONS(12833),
    [sym_column_keyword] = ACTIONS(12833),
    [sym_filter_keyword] = ACTIONS(12833),
    [sym_labels_keyword] = ACTIONS(12833),
    [sym_rendering_keyword] = ACTIONS(12833),
    [sym_requestpage_keyword] = ACTIONS(12833),
    [sym_schema_keyword] = ACTIONS(12833),
    [sym_views_keyword] = ACTIONS(12833),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12833),
    [sym_preproc_open] = ACTIONS(12833),
    [sym_preproc_close] = ACTIONS(12833),
  },
  [STATE(5230)] = {
    [anon_sym_SEMI] = ACTIONS(12877),
    [aux_sym_where_condition_token1] = ACTIONS(12879),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12877),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12877),
    [anon_sym_LBRACK] = ACTIONS(12877),
    [aux_sym_basic_type_token6] = ACTIONS(12879),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12877),
    [aux_sym_addafter_modification_token1] = ACTIONS(12877),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12877),
    [aux_sym_modify_modification_token1] = ACTIONS(12877),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12877),
    [aux_sym_movelast_modification_token1] = ACTIONS(12877),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12877),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12877),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12877),
    [anon_sym_POUNDif] = ACTIONS(12877),
    [anon_sym_POUNDIF] = ACTIONS(12877),
    [anon_sym_POUNDIf] = ACTIONS(12877),
    [anon_sym_POUNDelif] = ACTIONS(12877),
    [anon_sym_POUNDELIF] = ACTIONS(12877),
    [anon_sym_POUNDElif] = ACTIONS(12877),
    [anon_sym_POUNDelse] = ACTIONS(12877),
    [anon_sym_POUNDELSE] = ACTIONS(12877),
    [anon_sym_POUNDElse] = ACTIONS(12877),
    [anon_sym_POUNDelse2] = ACTIONS(12877),
    [anon_sym_POUNDELSE2] = ACTIONS(12877),
    [anon_sym_POUNDElse2] = ACTIONS(12877),
    [anon_sym_POUNDendif] = ACTIONS(12877),
    [anon_sym_POUNDENDIF] = ACTIONS(12877),
    [anon_sym_POUNDEndif] = ACTIONS(12877),
    [anon_sym_POUNDendif2] = ACTIONS(12877),
    [anon_sym_POUNDENDIF2] = ACTIONS(12877),
    [anon_sym_POUNDEndif2] = ACTIONS(12877),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12877),
    [sym_trigger_keyword] = ACTIONS(12877),
    [sym_var_keyword] = ACTIONS(12877),
    [sym_local_keyword] = ACTIONS(12877),
    [sym_internal_keyword] = ACTIONS(12877),
    [sym_protected_keyword] = ACTIONS(12877),
    [sym_event_keyword] = ACTIONS(12877),
    [sym_fields_keyword] = ACTIONS(12877),
    [sym_keys_keyword] = ACTIONS(12877),
    [sym_fieldgroups_keyword] = ACTIONS(12877),
    [sym_actions_keyword] = ACTIONS(12877),
    [sym_layout_keyword] = ACTIONS(12877),
    [sym_area_keyword] = ACTIONS(12877),
    [sym_group_keyword] = ACTIONS(12877),
    [sym_repeater_keyword] = ACTIONS(12877),
    [sym_cuegroup_keyword] = ACTIONS(12877),
    [sym_fixed_keyword] = ACTIONS(12877),
    [sym_grid_keyword] = ACTIONS(12877),
    [sym_part_keyword] = ACTIONS(12877),
    [sym_systempart_keyword] = ACTIONS(12877),
    [sym_usercontrol_keyword] = ACTIONS(12877),
    [sym_dataset_keyword] = ACTIONS(12877),
    [sym_elements_keyword] = ACTIONS(12877),
    [sym_dataitem_keyword] = ACTIONS(12877),
    [sym_column_keyword] = ACTIONS(12877),
    [sym_filter_keyword] = ACTIONS(12877),
    [sym_labels_keyword] = ACTIONS(12877),
    [sym_rendering_keyword] = ACTIONS(12877),
    [sym_requestpage_keyword] = ACTIONS(12877),
    [sym_schema_keyword] = ACTIONS(12877),
    [sym_views_keyword] = ACTIONS(12877),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12877),
    [sym_preproc_open] = ACTIONS(12877),
    [sym_preproc_close] = ACTIONS(12877),
  },
  [STATE(5231)] = {
    [anon_sym_SEMI] = ACTIONS(12881),
    [aux_sym_where_condition_token1] = ACTIONS(12883),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12881),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12881),
    [anon_sym_LBRACK] = ACTIONS(12881),
    [aux_sym_basic_type_token6] = ACTIONS(12883),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12881),
    [aux_sym_addafter_modification_token1] = ACTIONS(12881),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12881),
    [aux_sym_modify_modification_token1] = ACTIONS(12881),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12881),
    [aux_sym_movelast_modification_token1] = ACTIONS(12881),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12881),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12881),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12881),
    [anon_sym_POUNDif] = ACTIONS(12881),
    [anon_sym_POUNDIF] = ACTIONS(12881),
    [anon_sym_POUNDIf] = ACTIONS(12881),
    [anon_sym_POUNDelif] = ACTIONS(12881),
    [anon_sym_POUNDELIF] = ACTIONS(12881),
    [anon_sym_POUNDElif] = ACTIONS(12881),
    [anon_sym_POUNDelse] = ACTIONS(12881),
    [anon_sym_POUNDELSE] = ACTIONS(12881),
    [anon_sym_POUNDElse] = ACTIONS(12881),
    [anon_sym_POUNDelse2] = ACTIONS(12881),
    [anon_sym_POUNDELSE2] = ACTIONS(12881),
    [anon_sym_POUNDElse2] = ACTIONS(12881),
    [anon_sym_POUNDendif] = ACTIONS(12881),
    [anon_sym_POUNDENDIF] = ACTIONS(12881),
    [anon_sym_POUNDEndif] = ACTIONS(12881),
    [anon_sym_POUNDendif2] = ACTIONS(12881),
    [anon_sym_POUNDENDIF2] = ACTIONS(12881),
    [anon_sym_POUNDEndif2] = ACTIONS(12881),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12881),
    [sym_trigger_keyword] = ACTIONS(12881),
    [sym_var_keyword] = ACTIONS(12881),
    [sym_local_keyword] = ACTIONS(12881),
    [sym_internal_keyword] = ACTIONS(12881),
    [sym_protected_keyword] = ACTIONS(12881),
    [sym_event_keyword] = ACTIONS(12881),
    [sym_fields_keyword] = ACTIONS(12881),
    [sym_keys_keyword] = ACTIONS(12881),
    [sym_fieldgroups_keyword] = ACTIONS(12881),
    [sym_actions_keyword] = ACTIONS(12881),
    [sym_layout_keyword] = ACTIONS(12881),
    [sym_area_keyword] = ACTIONS(12881),
    [sym_group_keyword] = ACTIONS(12881),
    [sym_repeater_keyword] = ACTIONS(12881),
    [sym_cuegroup_keyword] = ACTIONS(12881),
    [sym_fixed_keyword] = ACTIONS(12881),
    [sym_grid_keyword] = ACTIONS(12881),
    [sym_part_keyword] = ACTIONS(12881),
    [sym_systempart_keyword] = ACTIONS(12881),
    [sym_usercontrol_keyword] = ACTIONS(12881),
    [sym_dataset_keyword] = ACTIONS(12881),
    [sym_elements_keyword] = ACTIONS(12881),
    [sym_dataitem_keyword] = ACTIONS(12881),
    [sym_column_keyword] = ACTIONS(12881),
    [sym_filter_keyword] = ACTIONS(12881),
    [sym_labels_keyword] = ACTIONS(12881),
    [sym_rendering_keyword] = ACTIONS(12881),
    [sym_requestpage_keyword] = ACTIONS(12881),
    [sym_schema_keyword] = ACTIONS(12881),
    [sym_views_keyword] = ACTIONS(12881),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12881),
    [sym_preproc_open] = ACTIONS(12881),
    [sym_preproc_close] = ACTIONS(12881),
  },
  [STATE(5232)] = {
    [anon_sym_SEMI] = ACTIONS(12885),
    [aux_sym_where_condition_token1] = ACTIONS(12887),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12885),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12885),
    [anon_sym_LBRACK] = ACTIONS(12885),
    [aux_sym_basic_type_token6] = ACTIONS(12887),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12885),
    [aux_sym_addafter_modification_token1] = ACTIONS(12885),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12885),
    [aux_sym_modify_modification_token1] = ACTIONS(12885),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12885),
    [aux_sym_movelast_modification_token1] = ACTIONS(12885),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12885),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12885),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12885),
    [anon_sym_POUNDif] = ACTIONS(12885),
    [anon_sym_POUNDIF] = ACTIONS(12885),
    [anon_sym_POUNDIf] = ACTIONS(12885),
    [anon_sym_POUNDelif] = ACTIONS(12885),
    [anon_sym_POUNDELIF] = ACTIONS(12885),
    [anon_sym_POUNDElif] = ACTIONS(12885),
    [anon_sym_POUNDelse] = ACTIONS(12885),
    [anon_sym_POUNDELSE] = ACTIONS(12885),
    [anon_sym_POUNDElse] = ACTIONS(12885),
    [anon_sym_POUNDelse2] = ACTIONS(12885),
    [anon_sym_POUNDELSE2] = ACTIONS(12885),
    [anon_sym_POUNDElse2] = ACTIONS(12885),
    [anon_sym_POUNDendif] = ACTIONS(12885),
    [anon_sym_POUNDENDIF] = ACTIONS(12885),
    [anon_sym_POUNDEndif] = ACTIONS(12885),
    [anon_sym_POUNDendif2] = ACTIONS(12885),
    [anon_sym_POUNDENDIF2] = ACTIONS(12885),
    [anon_sym_POUNDEndif2] = ACTIONS(12885),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12885),
    [sym_trigger_keyword] = ACTIONS(12885),
    [sym_var_keyword] = ACTIONS(12885),
    [sym_local_keyword] = ACTIONS(12885),
    [sym_internal_keyword] = ACTIONS(12885),
    [sym_protected_keyword] = ACTIONS(12885),
    [sym_event_keyword] = ACTIONS(12885),
    [sym_fields_keyword] = ACTIONS(12885),
    [sym_keys_keyword] = ACTIONS(12885),
    [sym_fieldgroups_keyword] = ACTIONS(12885),
    [sym_actions_keyword] = ACTIONS(12885),
    [sym_layout_keyword] = ACTIONS(12885),
    [sym_area_keyword] = ACTIONS(12885),
    [sym_group_keyword] = ACTIONS(12885),
    [sym_repeater_keyword] = ACTIONS(12885),
    [sym_cuegroup_keyword] = ACTIONS(12885),
    [sym_fixed_keyword] = ACTIONS(12885),
    [sym_grid_keyword] = ACTIONS(12885),
    [sym_part_keyword] = ACTIONS(12885),
    [sym_systempart_keyword] = ACTIONS(12885),
    [sym_usercontrol_keyword] = ACTIONS(12885),
    [sym_dataset_keyword] = ACTIONS(12885),
    [sym_elements_keyword] = ACTIONS(12885),
    [sym_dataitem_keyword] = ACTIONS(12885),
    [sym_column_keyword] = ACTIONS(12885),
    [sym_filter_keyword] = ACTIONS(12885),
    [sym_labels_keyword] = ACTIONS(12885),
    [sym_rendering_keyword] = ACTIONS(12885),
    [sym_requestpage_keyword] = ACTIONS(12885),
    [sym_schema_keyword] = ACTIONS(12885),
    [sym_views_keyword] = ACTIONS(12885),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12885),
    [sym_preproc_open] = ACTIONS(12885),
    [sym_preproc_close] = ACTIONS(12885),
  },
  [STATE(5233)] = {
    [anon_sym_SEMI] = ACTIONS(9000),
    [aux_sym_where_condition_token1] = ACTIONS(8998),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9000),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9000),
    [anon_sym_LBRACK] = ACTIONS(9000),
    [aux_sym_basic_type_token6] = ACTIONS(8998),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9000),
    [aux_sym_addafter_modification_token1] = ACTIONS(9000),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9000),
    [aux_sym_modify_modification_token1] = ACTIONS(9000),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9000),
    [aux_sym_movelast_modification_token1] = ACTIONS(9000),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9000),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9000),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9000),
    [anon_sym_POUNDif] = ACTIONS(9000),
    [anon_sym_POUNDIF] = ACTIONS(9000),
    [anon_sym_POUNDIf] = ACTIONS(9000),
    [anon_sym_POUNDelif] = ACTIONS(9000),
    [anon_sym_POUNDELIF] = ACTIONS(9000),
    [anon_sym_POUNDElif] = ACTIONS(9000),
    [anon_sym_POUNDelse] = ACTIONS(9000),
    [anon_sym_POUNDELSE] = ACTIONS(9000),
    [anon_sym_POUNDElse] = ACTIONS(9000),
    [anon_sym_POUNDelse2] = ACTIONS(9000),
    [anon_sym_POUNDELSE2] = ACTIONS(9000),
    [anon_sym_POUNDElse2] = ACTIONS(9000),
    [anon_sym_POUNDendif] = ACTIONS(9000),
    [anon_sym_POUNDENDIF] = ACTIONS(9000),
    [anon_sym_POUNDEndif] = ACTIONS(9000),
    [anon_sym_POUNDendif2] = ACTIONS(9000),
    [anon_sym_POUNDENDIF2] = ACTIONS(9000),
    [anon_sym_POUNDEndif2] = ACTIONS(9000),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9000),
    [sym_trigger_keyword] = ACTIONS(9000),
    [sym_var_keyword] = ACTIONS(9000),
    [sym_local_keyword] = ACTIONS(9000),
    [sym_internal_keyword] = ACTIONS(9000),
    [sym_protected_keyword] = ACTIONS(9000),
    [sym_event_keyword] = ACTIONS(9000),
    [sym_fields_keyword] = ACTIONS(9000),
    [sym_keys_keyword] = ACTIONS(9000),
    [sym_fieldgroups_keyword] = ACTIONS(9000),
    [sym_actions_keyword] = ACTIONS(9000),
    [sym_layout_keyword] = ACTIONS(9000),
    [sym_area_keyword] = ACTIONS(9000),
    [sym_group_keyword] = ACTIONS(9000),
    [sym_repeater_keyword] = ACTIONS(9000),
    [sym_cuegroup_keyword] = ACTIONS(9000),
    [sym_fixed_keyword] = ACTIONS(9000),
    [sym_grid_keyword] = ACTIONS(9000),
    [sym_part_keyword] = ACTIONS(9000),
    [sym_systempart_keyword] = ACTIONS(9000),
    [sym_usercontrol_keyword] = ACTIONS(9000),
    [sym_dataset_keyword] = ACTIONS(9000),
    [sym_elements_keyword] = ACTIONS(9000),
    [sym_dataitem_keyword] = ACTIONS(9000),
    [sym_column_keyword] = ACTIONS(9000),
    [sym_filter_keyword] = ACTIONS(9000),
    [sym_labels_keyword] = ACTIONS(9000),
    [sym_rendering_keyword] = ACTIONS(9000),
    [sym_requestpage_keyword] = ACTIONS(9000),
    [sym_schema_keyword] = ACTIONS(9000),
    [sym_views_keyword] = ACTIONS(9000),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9000),
    [sym_preproc_open] = ACTIONS(9000),
    [sym_preproc_close] = ACTIONS(9000),
  },
  [STATE(5234)] = {
    [anon_sym_SEMI] = ACTIONS(9004),
    [aux_sym_where_condition_token1] = ACTIONS(9002),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9004),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9004),
    [anon_sym_LBRACK] = ACTIONS(9004),
    [aux_sym_basic_type_token6] = ACTIONS(9002),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9004),
    [aux_sym_addafter_modification_token1] = ACTIONS(9004),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9004),
    [aux_sym_modify_modification_token1] = ACTIONS(9004),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9004),
    [aux_sym_movelast_modification_token1] = ACTIONS(9004),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9004),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9004),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9004),
    [anon_sym_POUNDif] = ACTIONS(9004),
    [anon_sym_POUNDIF] = ACTIONS(9004),
    [anon_sym_POUNDIf] = ACTIONS(9004),
    [anon_sym_POUNDelif] = ACTIONS(9004),
    [anon_sym_POUNDELIF] = ACTIONS(9004),
    [anon_sym_POUNDElif] = ACTIONS(9004),
    [anon_sym_POUNDelse] = ACTIONS(9004),
    [anon_sym_POUNDELSE] = ACTIONS(9004),
    [anon_sym_POUNDElse] = ACTIONS(9004),
    [anon_sym_POUNDelse2] = ACTIONS(9004),
    [anon_sym_POUNDELSE2] = ACTIONS(9004),
    [anon_sym_POUNDElse2] = ACTIONS(9004),
    [anon_sym_POUNDendif] = ACTIONS(9004),
    [anon_sym_POUNDENDIF] = ACTIONS(9004),
    [anon_sym_POUNDEndif] = ACTIONS(9004),
    [anon_sym_POUNDendif2] = ACTIONS(9004),
    [anon_sym_POUNDENDIF2] = ACTIONS(9004),
    [anon_sym_POUNDEndif2] = ACTIONS(9004),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9004),
    [sym_trigger_keyword] = ACTIONS(9004),
    [sym_var_keyword] = ACTIONS(9004),
    [sym_local_keyword] = ACTIONS(9004),
    [sym_internal_keyword] = ACTIONS(9004),
    [sym_protected_keyword] = ACTIONS(9004),
    [sym_event_keyword] = ACTIONS(9004),
    [sym_fields_keyword] = ACTIONS(9004),
    [sym_keys_keyword] = ACTIONS(9004),
    [sym_fieldgroups_keyword] = ACTIONS(9004),
    [sym_actions_keyword] = ACTIONS(9004),
    [sym_layout_keyword] = ACTIONS(9004),
    [sym_area_keyword] = ACTIONS(9004),
    [sym_group_keyword] = ACTIONS(9004),
    [sym_repeater_keyword] = ACTIONS(9004),
    [sym_cuegroup_keyword] = ACTIONS(9004),
    [sym_fixed_keyword] = ACTIONS(9004),
    [sym_grid_keyword] = ACTIONS(9004),
    [sym_part_keyword] = ACTIONS(9004),
    [sym_systempart_keyword] = ACTIONS(9004),
    [sym_usercontrol_keyword] = ACTIONS(9004),
    [sym_dataset_keyword] = ACTIONS(9004),
    [sym_elements_keyword] = ACTIONS(9004),
    [sym_dataitem_keyword] = ACTIONS(9004),
    [sym_column_keyword] = ACTIONS(9004),
    [sym_filter_keyword] = ACTIONS(9004),
    [sym_labels_keyword] = ACTIONS(9004),
    [sym_rendering_keyword] = ACTIONS(9004),
    [sym_requestpage_keyword] = ACTIONS(9004),
    [sym_schema_keyword] = ACTIONS(9004),
    [sym_views_keyword] = ACTIONS(9004),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9004),
    [sym_preproc_open] = ACTIONS(9004),
    [sym_preproc_close] = ACTIONS(9004),
  },
  [STATE(5235)] = {
    [anon_sym_SEMI] = ACTIONS(9004),
    [aux_sym_where_condition_token1] = ACTIONS(9002),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9004),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9004),
    [anon_sym_LBRACK] = ACTIONS(9004),
    [aux_sym_basic_type_token6] = ACTIONS(9002),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9004),
    [aux_sym_addafter_modification_token1] = ACTIONS(9004),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9004),
    [aux_sym_modify_modification_token1] = ACTIONS(9004),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9004),
    [aux_sym_movelast_modification_token1] = ACTIONS(9004),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9004),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9004),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9004),
    [anon_sym_POUNDif] = ACTIONS(9004),
    [anon_sym_POUNDIF] = ACTIONS(9004),
    [anon_sym_POUNDIf] = ACTIONS(9004),
    [anon_sym_POUNDelif] = ACTIONS(9004),
    [anon_sym_POUNDELIF] = ACTIONS(9004),
    [anon_sym_POUNDElif] = ACTIONS(9004),
    [anon_sym_POUNDelse] = ACTIONS(9004),
    [anon_sym_POUNDELSE] = ACTIONS(9004),
    [anon_sym_POUNDElse] = ACTIONS(9004),
    [anon_sym_POUNDelse2] = ACTIONS(9004),
    [anon_sym_POUNDELSE2] = ACTIONS(9004),
    [anon_sym_POUNDElse2] = ACTIONS(9004),
    [anon_sym_POUNDendif] = ACTIONS(9004),
    [anon_sym_POUNDENDIF] = ACTIONS(9004),
    [anon_sym_POUNDEndif] = ACTIONS(9004),
    [anon_sym_POUNDendif2] = ACTIONS(9004),
    [anon_sym_POUNDENDIF2] = ACTIONS(9004),
    [anon_sym_POUNDEndif2] = ACTIONS(9004),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9004),
    [sym_trigger_keyword] = ACTIONS(9004),
    [sym_var_keyword] = ACTIONS(9004),
    [sym_local_keyword] = ACTIONS(9004),
    [sym_internal_keyword] = ACTIONS(9004),
    [sym_protected_keyword] = ACTIONS(9004),
    [sym_event_keyword] = ACTIONS(9004),
    [sym_fields_keyword] = ACTIONS(9004),
    [sym_keys_keyword] = ACTIONS(9004),
    [sym_fieldgroups_keyword] = ACTIONS(9004),
    [sym_actions_keyword] = ACTIONS(9004),
    [sym_layout_keyword] = ACTIONS(9004),
    [sym_area_keyword] = ACTIONS(9004),
    [sym_group_keyword] = ACTIONS(9004),
    [sym_repeater_keyword] = ACTIONS(9004),
    [sym_cuegroup_keyword] = ACTIONS(9004),
    [sym_fixed_keyword] = ACTIONS(9004),
    [sym_grid_keyword] = ACTIONS(9004),
    [sym_part_keyword] = ACTIONS(9004),
    [sym_systempart_keyword] = ACTIONS(9004),
    [sym_usercontrol_keyword] = ACTIONS(9004),
    [sym_dataset_keyword] = ACTIONS(9004),
    [sym_elements_keyword] = ACTIONS(9004),
    [sym_dataitem_keyword] = ACTIONS(9004),
    [sym_column_keyword] = ACTIONS(9004),
    [sym_filter_keyword] = ACTIONS(9004),
    [sym_labels_keyword] = ACTIONS(9004),
    [sym_rendering_keyword] = ACTIONS(9004),
    [sym_requestpage_keyword] = ACTIONS(9004),
    [sym_schema_keyword] = ACTIONS(9004),
    [sym_views_keyword] = ACTIONS(9004),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9004),
    [sym_preproc_open] = ACTIONS(9004),
    [sym_preproc_close] = ACTIONS(9004),
  },
  [STATE(5236)] = {
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9008),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9008),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9008),
    [aux_sym_addafter_modification_token1] = ACTIONS(9008),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9008),
    [aux_sym_modify_modification_token1] = ACTIONS(9008),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9008),
    [aux_sym_movelast_modification_token1] = ACTIONS(9008),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9008),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9008),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9008),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9008),
    [sym_trigger_keyword] = ACTIONS(9008),
    [sym_var_keyword] = ACTIONS(9008),
    [sym_local_keyword] = ACTIONS(9008),
    [sym_internal_keyword] = ACTIONS(9008),
    [sym_protected_keyword] = ACTIONS(9008),
    [sym_event_keyword] = ACTIONS(9008),
    [sym_fields_keyword] = ACTIONS(9008),
    [sym_keys_keyword] = ACTIONS(9008),
    [sym_fieldgroups_keyword] = ACTIONS(9008),
    [sym_actions_keyword] = ACTIONS(9008),
    [sym_layout_keyword] = ACTIONS(9008),
    [sym_area_keyword] = ACTIONS(9008),
    [sym_group_keyword] = ACTIONS(9008),
    [sym_repeater_keyword] = ACTIONS(9008),
    [sym_cuegroup_keyword] = ACTIONS(9008),
    [sym_fixed_keyword] = ACTIONS(9008),
    [sym_grid_keyword] = ACTIONS(9008),
    [sym_part_keyword] = ACTIONS(9008),
    [sym_systempart_keyword] = ACTIONS(9008),
    [sym_usercontrol_keyword] = ACTIONS(9008),
    [sym_dataset_keyword] = ACTIONS(9008),
    [sym_elements_keyword] = ACTIONS(9008),
    [sym_dataitem_keyword] = ACTIONS(9008),
    [sym_column_keyword] = ACTIONS(9008),
    [sym_filter_keyword] = ACTIONS(9008),
    [sym_labels_keyword] = ACTIONS(9008),
    [sym_rendering_keyword] = ACTIONS(9008),
    [sym_requestpage_keyword] = ACTIONS(9008),
    [sym_schema_keyword] = ACTIONS(9008),
    [sym_views_keyword] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
  },
  [STATE(5237)] = {
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9008),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9008),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9008),
    [aux_sym_addafter_modification_token1] = ACTIONS(9008),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9008),
    [aux_sym_modify_modification_token1] = ACTIONS(9008),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9008),
    [aux_sym_movelast_modification_token1] = ACTIONS(9008),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9008),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9008),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9008),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9008),
    [sym_trigger_keyword] = ACTIONS(9008),
    [sym_var_keyword] = ACTIONS(9008),
    [sym_local_keyword] = ACTIONS(9008),
    [sym_internal_keyword] = ACTIONS(9008),
    [sym_protected_keyword] = ACTIONS(9008),
    [sym_event_keyword] = ACTIONS(9008),
    [sym_fields_keyword] = ACTIONS(9008),
    [sym_keys_keyword] = ACTIONS(9008),
    [sym_fieldgroups_keyword] = ACTIONS(9008),
    [sym_actions_keyword] = ACTIONS(9008),
    [sym_layout_keyword] = ACTIONS(9008),
    [sym_area_keyword] = ACTIONS(9008),
    [sym_group_keyword] = ACTIONS(9008),
    [sym_repeater_keyword] = ACTIONS(9008),
    [sym_cuegroup_keyword] = ACTIONS(9008),
    [sym_fixed_keyword] = ACTIONS(9008),
    [sym_grid_keyword] = ACTIONS(9008),
    [sym_part_keyword] = ACTIONS(9008),
    [sym_systempart_keyword] = ACTIONS(9008),
    [sym_usercontrol_keyword] = ACTIONS(9008),
    [sym_dataset_keyword] = ACTIONS(9008),
    [sym_elements_keyword] = ACTIONS(9008),
    [sym_dataitem_keyword] = ACTIONS(9008),
    [sym_column_keyword] = ACTIONS(9008),
    [sym_filter_keyword] = ACTIONS(9008),
    [sym_labels_keyword] = ACTIONS(9008),
    [sym_rendering_keyword] = ACTIONS(9008),
    [sym_requestpage_keyword] = ACTIONS(9008),
    [sym_schema_keyword] = ACTIONS(9008),
    [sym_views_keyword] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
  },
  [STATE(5238)] = {
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9008),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9008),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9008),
    [aux_sym_addafter_modification_token1] = ACTIONS(9008),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9008),
    [aux_sym_modify_modification_token1] = ACTIONS(9008),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9008),
    [aux_sym_movelast_modification_token1] = ACTIONS(9008),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9008),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9008),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9008),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9008),
    [sym_trigger_keyword] = ACTIONS(9008),
    [sym_var_keyword] = ACTIONS(9008),
    [sym_local_keyword] = ACTIONS(9008),
    [sym_internal_keyword] = ACTIONS(9008),
    [sym_protected_keyword] = ACTIONS(9008),
    [sym_event_keyword] = ACTIONS(9008),
    [sym_fields_keyword] = ACTIONS(9008),
    [sym_keys_keyword] = ACTIONS(9008),
    [sym_fieldgroups_keyword] = ACTIONS(9008),
    [sym_actions_keyword] = ACTIONS(9008),
    [sym_layout_keyword] = ACTIONS(9008),
    [sym_area_keyword] = ACTIONS(9008),
    [sym_group_keyword] = ACTIONS(9008),
    [sym_repeater_keyword] = ACTIONS(9008),
    [sym_cuegroup_keyword] = ACTIONS(9008),
    [sym_fixed_keyword] = ACTIONS(9008),
    [sym_grid_keyword] = ACTIONS(9008),
    [sym_part_keyword] = ACTIONS(9008),
    [sym_systempart_keyword] = ACTIONS(9008),
    [sym_usercontrol_keyword] = ACTIONS(9008),
    [sym_dataset_keyword] = ACTIONS(9008),
    [sym_elements_keyword] = ACTIONS(9008),
    [sym_dataitem_keyword] = ACTIONS(9008),
    [sym_column_keyword] = ACTIONS(9008),
    [sym_filter_keyword] = ACTIONS(9008),
    [sym_labels_keyword] = ACTIONS(9008),
    [sym_rendering_keyword] = ACTIONS(9008),
    [sym_requestpage_keyword] = ACTIONS(9008),
    [sym_schema_keyword] = ACTIONS(9008),
    [sym_views_keyword] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
  },
  [STATE(5239)] = {
    [anon_sym_SEMI] = ACTIONS(12889),
    [aux_sym_where_condition_token1] = ACTIONS(12891),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12889),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12889),
    [anon_sym_LBRACK] = ACTIONS(12889),
    [aux_sym_basic_type_token6] = ACTIONS(12891),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12889),
    [aux_sym_addafter_modification_token1] = ACTIONS(12889),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12889),
    [aux_sym_modify_modification_token1] = ACTIONS(12889),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12889),
    [aux_sym_movelast_modification_token1] = ACTIONS(12889),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12889),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12889),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12889),
    [anon_sym_POUNDif] = ACTIONS(12889),
    [anon_sym_POUNDIF] = ACTIONS(12889),
    [anon_sym_POUNDIf] = ACTIONS(12889),
    [anon_sym_POUNDelif] = ACTIONS(12889),
    [anon_sym_POUNDELIF] = ACTIONS(12889),
    [anon_sym_POUNDElif] = ACTIONS(12889),
    [anon_sym_POUNDelse] = ACTIONS(12889),
    [anon_sym_POUNDELSE] = ACTIONS(12889),
    [anon_sym_POUNDElse] = ACTIONS(12889),
    [anon_sym_POUNDelse2] = ACTIONS(12889),
    [anon_sym_POUNDELSE2] = ACTIONS(12889),
    [anon_sym_POUNDElse2] = ACTIONS(12889),
    [anon_sym_POUNDendif] = ACTIONS(12889),
    [anon_sym_POUNDENDIF] = ACTIONS(12889),
    [anon_sym_POUNDEndif] = ACTIONS(12889),
    [anon_sym_POUNDendif2] = ACTIONS(12889),
    [anon_sym_POUNDENDIF2] = ACTIONS(12889),
    [anon_sym_POUNDEndif2] = ACTIONS(12889),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12889),
    [sym_trigger_keyword] = ACTIONS(12889),
    [sym_var_keyword] = ACTIONS(12889),
    [sym_local_keyword] = ACTIONS(12889),
    [sym_internal_keyword] = ACTIONS(12889),
    [sym_protected_keyword] = ACTIONS(12889),
    [sym_event_keyword] = ACTIONS(12889),
    [sym_fields_keyword] = ACTIONS(12889),
    [sym_keys_keyword] = ACTIONS(12889),
    [sym_fieldgroups_keyword] = ACTIONS(12889),
    [sym_actions_keyword] = ACTIONS(12889),
    [sym_layout_keyword] = ACTIONS(12889),
    [sym_area_keyword] = ACTIONS(12889),
    [sym_group_keyword] = ACTIONS(12889),
    [sym_repeater_keyword] = ACTIONS(12889),
    [sym_cuegroup_keyword] = ACTIONS(12889),
    [sym_fixed_keyword] = ACTIONS(12889),
    [sym_grid_keyword] = ACTIONS(12889),
    [sym_part_keyword] = ACTIONS(12889),
    [sym_systempart_keyword] = ACTIONS(12889),
    [sym_usercontrol_keyword] = ACTIONS(12889),
    [sym_dataset_keyword] = ACTIONS(12889),
    [sym_elements_keyword] = ACTIONS(12889),
    [sym_dataitem_keyword] = ACTIONS(12889),
    [sym_column_keyword] = ACTIONS(12889),
    [sym_filter_keyword] = ACTIONS(12889),
    [sym_labels_keyword] = ACTIONS(12889),
    [sym_rendering_keyword] = ACTIONS(12889),
    [sym_requestpage_keyword] = ACTIONS(12889),
    [sym_schema_keyword] = ACTIONS(12889),
    [sym_views_keyword] = ACTIONS(12889),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12889),
    [sym_preproc_open] = ACTIONS(12889),
    [sym_preproc_close] = ACTIONS(12889),
  },
  [STATE(5240)] = {
    [anon_sym_SEMI] = ACTIONS(12893),
    [aux_sym_where_condition_token1] = ACTIONS(12895),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12893),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12893),
    [anon_sym_LBRACK] = ACTIONS(12893),
    [aux_sym_basic_type_token6] = ACTIONS(12895),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12893),
    [aux_sym_addafter_modification_token1] = ACTIONS(12893),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12893),
    [aux_sym_modify_modification_token1] = ACTIONS(12893),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12893),
    [aux_sym_movelast_modification_token1] = ACTIONS(12893),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12893),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12893),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12893),
    [anon_sym_POUNDif] = ACTIONS(12893),
    [anon_sym_POUNDIF] = ACTIONS(12893),
    [anon_sym_POUNDIf] = ACTIONS(12893),
    [anon_sym_POUNDelif] = ACTIONS(12893),
    [anon_sym_POUNDELIF] = ACTIONS(12893),
    [anon_sym_POUNDElif] = ACTIONS(12893),
    [anon_sym_POUNDelse] = ACTIONS(12893),
    [anon_sym_POUNDELSE] = ACTIONS(12893),
    [anon_sym_POUNDElse] = ACTIONS(12893),
    [anon_sym_POUNDelse2] = ACTIONS(12893),
    [anon_sym_POUNDELSE2] = ACTIONS(12893),
    [anon_sym_POUNDElse2] = ACTIONS(12893),
    [anon_sym_POUNDendif] = ACTIONS(12893),
    [anon_sym_POUNDENDIF] = ACTIONS(12893),
    [anon_sym_POUNDEndif] = ACTIONS(12893),
    [anon_sym_POUNDendif2] = ACTIONS(12893),
    [anon_sym_POUNDENDIF2] = ACTIONS(12893),
    [anon_sym_POUNDEndif2] = ACTIONS(12893),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12893),
    [sym_trigger_keyword] = ACTIONS(12893),
    [sym_var_keyword] = ACTIONS(12893),
    [sym_local_keyword] = ACTIONS(12893),
    [sym_internal_keyword] = ACTIONS(12893),
    [sym_protected_keyword] = ACTIONS(12893),
    [sym_event_keyword] = ACTIONS(12893),
    [sym_fields_keyword] = ACTIONS(12893),
    [sym_keys_keyword] = ACTIONS(12893),
    [sym_fieldgroups_keyword] = ACTIONS(12893),
    [sym_actions_keyword] = ACTIONS(12893),
    [sym_layout_keyword] = ACTIONS(12893),
    [sym_area_keyword] = ACTIONS(12893),
    [sym_group_keyword] = ACTIONS(12893),
    [sym_repeater_keyword] = ACTIONS(12893),
    [sym_cuegroup_keyword] = ACTIONS(12893),
    [sym_fixed_keyword] = ACTIONS(12893),
    [sym_grid_keyword] = ACTIONS(12893),
    [sym_part_keyword] = ACTIONS(12893),
    [sym_systempart_keyword] = ACTIONS(12893),
    [sym_usercontrol_keyword] = ACTIONS(12893),
    [sym_dataset_keyword] = ACTIONS(12893),
    [sym_elements_keyword] = ACTIONS(12893),
    [sym_dataitem_keyword] = ACTIONS(12893),
    [sym_column_keyword] = ACTIONS(12893),
    [sym_filter_keyword] = ACTIONS(12893),
    [sym_labels_keyword] = ACTIONS(12893),
    [sym_rendering_keyword] = ACTIONS(12893),
    [sym_requestpage_keyword] = ACTIONS(12893),
    [sym_schema_keyword] = ACTIONS(12893),
    [sym_views_keyword] = ACTIONS(12893),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12893),
    [sym_preproc_open] = ACTIONS(12893),
    [sym_preproc_close] = ACTIONS(12893),
  },
  [STATE(5241)] = {
    [anon_sym_SEMI] = ACTIONS(12897),
    [aux_sym_where_condition_token1] = ACTIONS(12899),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12897),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12897),
    [anon_sym_LBRACK] = ACTIONS(12897),
    [aux_sym_basic_type_token6] = ACTIONS(12899),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12897),
    [aux_sym_addafter_modification_token1] = ACTIONS(12897),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12897),
    [aux_sym_modify_modification_token1] = ACTIONS(12897),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12897),
    [aux_sym_movelast_modification_token1] = ACTIONS(12897),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12897),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12897),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12897),
    [anon_sym_POUNDif] = ACTIONS(12897),
    [anon_sym_POUNDIF] = ACTIONS(12897),
    [anon_sym_POUNDIf] = ACTIONS(12897),
    [anon_sym_POUNDelif] = ACTIONS(12897),
    [anon_sym_POUNDELIF] = ACTIONS(12897),
    [anon_sym_POUNDElif] = ACTIONS(12897),
    [anon_sym_POUNDelse] = ACTIONS(12897),
    [anon_sym_POUNDELSE] = ACTIONS(12897),
    [anon_sym_POUNDElse] = ACTIONS(12897),
    [anon_sym_POUNDelse2] = ACTIONS(12897),
    [anon_sym_POUNDELSE2] = ACTIONS(12897),
    [anon_sym_POUNDElse2] = ACTIONS(12897),
    [anon_sym_POUNDendif] = ACTIONS(12897),
    [anon_sym_POUNDENDIF] = ACTIONS(12897),
    [anon_sym_POUNDEndif] = ACTIONS(12897),
    [anon_sym_POUNDendif2] = ACTIONS(12897),
    [anon_sym_POUNDENDIF2] = ACTIONS(12897),
    [anon_sym_POUNDEndif2] = ACTIONS(12897),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12897),
    [sym_trigger_keyword] = ACTIONS(12897),
    [sym_var_keyword] = ACTIONS(12897),
    [sym_local_keyword] = ACTIONS(12897),
    [sym_internal_keyword] = ACTIONS(12897),
    [sym_protected_keyword] = ACTIONS(12897),
    [sym_event_keyword] = ACTIONS(12897),
    [sym_fields_keyword] = ACTIONS(12897),
    [sym_keys_keyword] = ACTIONS(12897),
    [sym_fieldgroups_keyword] = ACTIONS(12897),
    [sym_actions_keyword] = ACTIONS(12897),
    [sym_layout_keyword] = ACTIONS(12897),
    [sym_area_keyword] = ACTIONS(12897),
    [sym_group_keyword] = ACTIONS(12897),
    [sym_repeater_keyword] = ACTIONS(12897),
    [sym_cuegroup_keyword] = ACTIONS(12897),
    [sym_fixed_keyword] = ACTIONS(12897),
    [sym_grid_keyword] = ACTIONS(12897),
    [sym_part_keyword] = ACTIONS(12897),
    [sym_systempart_keyword] = ACTIONS(12897),
    [sym_usercontrol_keyword] = ACTIONS(12897),
    [sym_dataset_keyword] = ACTIONS(12897),
    [sym_elements_keyword] = ACTIONS(12897),
    [sym_dataitem_keyword] = ACTIONS(12897),
    [sym_column_keyword] = ACTIONS(12897),
    [sym_filter_keyword] = ACTIONS(12897),
    [sym_labels_keyword] = ACTIONS(12897),
    [sym_rendering_keyword] = ACTIONS(12897),
    [sym_requestpage_keyword] = ACTIONS(12897),
    [sym_schema_keyword] = ACTIONS(12897),
    [sym_views_keyword] = ACTIONS(12897),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12897),
    [sym_preproc_open] = ACTIONS(12897),
    [sym_preproc_close] = ACTIONS(12897),
  },
  [STATE(5242)] = {
    [anon_sym_SEMI] = ACTIONS(12901),
    [aux_sym_where_condition_token1] = ACTIONS(12903),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12901),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12901),
    [anon_sym_LBRACK] = ACTIONS(12901),
    [aux_sym_basic_type_token6] = ACTIONS(12903),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12901),
    [aux_sym_addafter_modification_token1] = ACTIONS(12901),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12901),
    [aux_sym_modify_modification_token1] = ACTIONS(12901),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12901),
    [aux_sym_movelast_modification_token1] = ACTIONS(12901),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12901),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12901),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12901),
    [anon_sym_POUNDif] = ACTIONS(12901),
    [anon_sym_POUNDIF] = ACTIONS(12901),
    [anon_sym_POUNDIf] = ACTIONS(12901),
    [anon_sym_POUNDelif] = ACTIONS(12901),
    [anon_sym_POUNDELIF] = ACTIONS(12901),
    [anon_sym_POUNDElif] = ACTIONS(12901),
    [anon_sym_POUNDelse] = ACTIONS(12901),
    [anon_sym_POUNDELSE] = ACTIONS(12901),
    [anon_sym_POUNDElse] = ACTIONS(12901),
    [anon_sym_POUNDelse2] = ACTIONS(12901),
    [anon_sym_POUNDELSE2] = ACTIONS(12901),
    [anon_sym_POUNDElse2] = ACTIONS(12901),
    [anon_sym_POUNDendif] = ACTIONS(12901),
    [anon_sym_POUNDENDIF] = ACTIONS(12901),
    [anon_sym_POUNDEndif] = ACTIONS(12901),
    [anon_sym_POUNDendif2] = ACTIONS(12901),
    [anon_sym_POUNDENDIF2] = ACTIONS(12901),
    [anon_sym_POUNDEndif2] = ACTIONS(12901),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12901),
    [sym_trigger_keyword] = ACTIONS(12901),
    [sym_var_keyword] = ACTIONS(12901),
    [sym_local_keyword] = ACTIONS(12901),
    [sym_internal_keyword] = ACTIONS(12901),
    [sym_protected_keyword] = ACTIONS(12901),
    [sym_event_keyword] = ACTIONS(12901),
    [sym_fields_keyword] = ACTIONS(12901),
    [sym_keys_keyword] = ACTIONS(12901),
    [sym_fieldgroups_keyword] = ACTIONS(12901),
    [sym_actions_keyword] = ACTIONS(12901),
    [sym_layout_keyword] = ACTIONS(12901),
    [sym_area_keyword] = ACTIONS(12901),
    [sym_group_keyword] = ACTIONS(12901),
    [sym_repeater_keyword] = ACTIONS(12901),
    [sym_cuegroup_keyword] = ACTIONS(12901),
    [sym_fixed_keyword] = ACTIONS(12901),
    [sym_grid_keyword] = ACTIONS(12901),
    [sym_part_keyword] = ACTIONS(12901),
    [sym_systempart_keyword] = ACTIONS(12901),
    [sym_usercontrol_keyword] = ACTIONS(12901),
    [sym_dataset_keyword] = ACTIONS(12901),
    [sym_elements_keyword] = ACTIONS(12901),
    [sym_dataitem_keyword] = ACTIONS(12901),
    [sym_column_keyword] = ACTIONS(12901),
    [sym_filter_keyword] = ACTIONS(12901),
    [sym_labels_keyword] = ACTIONS(12901),
    [sym_rendering_keyword] = ACTIONS(12901),
    [sym_requestpage_keyword] = ACTIONS(12901),
    [sym_schema_keyword] = ACTIONS(12901),
    [sym_views_keyword] = ACTIONS(12901),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12901),
    [sym_preproc_open] = ACTIONS(12901),
    [sym_preproc_close] = ACTIONS(12901),
  },
  [STATE(5243)] = {
    [anon_sym_SEMI] = ACTIONS(12905),
    [aux_sym_where_condition_token1] = ACTIONS(12907),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12905),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12905),
    [anon_sym_LBRACK] = ACTIONS(12905),
    [aux_sym_basic_type_token6] = ACTIONS(12907),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12905),
    [aux_sym_addafter_modification_token1] = ACTIONS(12905),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12905),
    [aux_sym_modify_modification_token1] = ACTIONS(12905),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12905),
    [aux_sym_movelast_modification_token1] = ACTIONS(12905),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12905),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12905),
    [anon_sym_POUNDif] = ACTIONS(12905),
    [anon_sym_POUNDIF] = ACTIONS(12905),
    [anon_sym_POUNDIf] = ACTIONS(12905),
    [anon_sym_POUNDelif] = ACTIONS(12905),
    [anon_sym_POUNDELIF] = ACTIONS(12905),
    [anon_sym_POUNDElif] = ACTIONS(12905),
    [anon_sym_POUNDelse] = ACTIONS(12905),
    [anon_sym_POUNDELSE] = ACTIONS(12905),
    [anon_sym_POUNDElse] = ACTIONS(12905),
    [anon_sym_POUNDelse2] = ACTIONS(12905),
    [anon_sym_POUNDELSE2] = ACTIONS(12905),
    [anon_sym_POUNDElse2] = ACTIONS(12905),
    [anon_sym_POUNDendif] = ACTIONS(12905),
    [anon_sym_POUNDENDIF] = ACTIONS(12905),
    [anon_sym_POUNDEndif] = ACTIONS(12905),
    [anon_sym_POUNDendif2] = ACTIONS(12905),
    [anon_sym_POUNDENDIF2] = ACTIONS(12905),
    [anon_sym_POUNDEndif2] = ACTIONS(12905),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12905),
    [sym_trigger_keyword] = ACTIONS(12905),
    [sym_var_keyword] = ACTIONS(12905),
    [sym_local_keyword] = ACTIONS(12905),
    [sym_internal_keyword] = ACTIONS(12905),
    [sym_protected_keyword] = ACTIONS(12905),
    [sym_event_keyword] = ACTIONS(12905),
    [sym_fields_keyword] = ACTIONS(12905),
    [sym_keys_keyword] = ACTIONS(12905),
    [sym_fieldgroups_keyword] = ACTIONS(12905),
    [sym_actions_keyword] = ACTIONS(12905),
    [sym_layout_keyword] = ACTIONS(12905),
    [sym_area_keyword] = ACTIONS(12905),
    [sym_group_keyword] = ACTIONS(12905),
    [sym_repeater_keyword] = ACTIONS(12905),
    [sym_cuegroup_keyword] = ACTIONS(12905),
    [sym_fixed_keyword] = ACTIONS(12905),
    [sym_grid_keyword] = ACTIONS(12905),
    [sym_part_keyword] = ACTIONS(12905),
    [sym_systempart_keyword] = ACTIONS(12905),
    [sym_usercontrol_keyword] = ACTIONS(12905),
    [sym_dataset_keyword] = ACTIONS(12905),
    [sym_elements_keyword] = ACTIONS(12905),
    [sym_dataitem_keyword] = ACTIONS(12905),
    [sym_column_keyword] = ACTIONS(12905),
    [sym_filter_keyword] = ACTIONS(12905),
    [sym_labels_keyword] = ACTIONS(12905),
    [sym_rendering_keyword] = ACTIONS(12905),
    [sym_requestpage_keyword] = ACTIONS(12905),
    [sym_schema_keyword] = ACTIONS(12905),
    [sym_views_keyword] = ACTIONS(12905),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12905),
    [sym_preproc_open] = ACTIONS(12905),
    [sym_preproc_close] = ACTIONS(12905),
  },
  [STATE(5244)] = {
    [anon_sym_SEMI] = ACTIONS(12909),
    [aux_sym_where_condition_token1] = ACTIONS(12911),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12909),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12909),
    [anon_sym_LBRACK] = ACTIONS(12909),
    [aux_sym_basic_type_token6] = ACTIONS(12911),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12909),
    [aux_sym_addafter_modification_token1] = ACTIONS(12909),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12909),
    [aux_sym_modify_modification_token1] = ACTIONS(12909),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12909),
    [aux_sym_movelast_modification_token1] = ACTIONS(12909),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12909),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12909),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12909),
    [anon_sym_POUNDif] = ACTIONS(12909),
    [anon_sym_POUNDIF] = ACTIONS(12909),
    [anon_sym_POUNDIf] = ACTIONS(12909),
    [anon_sym_POUNDelif] = ACTIONS(12909),
    [anon_sym_POUNDELIF] = ACTIONS(12909),
    [anon_sym_POUNDElif] = ACTIONS(12909),
    [anon_sym_POUNDelse] = ACTIONS(12909),
    [anon_sym_POUNDELSE] = ACTIONS(12909),
    [anon_sym_POUNDElse] = ACTIONS(12909),
    [anon_sym_POUNDelse2] = ACTIONS(12909),
    [anon_sym_POUNDELSE2] = ACTIONS(12909),
    [anon_sym_POUNDElse2] = ACTIONS(12909),
    [anon_sym_POUNDendif] = ACTIONS(12909),
    [anon_sym_POUNDENDIF] = ACTIONS(12909),
    [anon_sym_POUNDEndif] = ACTIONS(12909),
    [anon_sym_POUNDendif2] = ACTIONS(12909),
    [anon_sym_POUNDENDIF2] = ACTIONS(12909),
    [anon_sym_POUNDEndif2] = ACTIONS(12909),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12909),
    [sym_trigger_keyword] = ACTIONS(12909),
    [sym_var_keyword] = ACTIONS(12909),
    [sym_local_keyword] = ACTIONS(12909),
    [sym_internal_keyword] = ACTIONS(12909),
    [sym_protected_keyword] = ACTIONS(12909),
    [sym_event_keyword] = ACTIONS(12909),
    [sym_fields_keyword] = ACTIONS(12909),
    [sym_keys_keyword] = ACTIONS(12909),
    [sym_fieldgroups_keyword] = ACTIONS(12909),
    [sym_actions_keyword] = ACTIONS(12909),
    [sym_layout_keyword] = ACTIONS(12909),
    [sym_area_keyword] = ACTIONS(12909),
    [sym_group_keyword] = ACTIONS(12909),
    [sym_repeater_keyword] = ACTIONS(12909),
    [sym_cuegroup_keyword] = ACTIONS(12909),
    [sym_fixed_keyword] = ACTIONS(12909),
    [sym_grid_keyword] = ACTIONS(12909),
    [sym_part_keyword] = ACTIONS(12909),
    [sym_systempart_keyword] = ACTIONS(12909),
    [sym_usercontrol_keyword] = ACTIONS(12909),
    [sym_dataset_keyword] = ACTIONS(12909),
    [sym_elements_keyword] = ACTIONS(12909),
    [sym_dataitem_keyword] = ACTIONS(12909),
    [sym_column_keyword] = ACTIONS(12909),
    [sym_filter_keyword] = ACTIONS(12909),
    [sym_labels_keyword] = ACTIONS(12909),
    [sym_rendering_keyword] = ACTIONS(12909),
    [sym_requestpage_keyword] = ACTIONS(12909),
    [sym_schema_keyword] = ACTIONS(12909),
    [sym_views_keyword] = ACTIONS(12909),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12909),
    [sym_preproc_open] = ACTIONS(12909),
    [sym_preproc_close] = ACTIONS(12909),
  },
  [STATE(5245)] = {
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9046),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9046),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9046),
    [aux_sym_addafter_modification_token1] = ACTIONS(9046),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9046),
    [aux_sym_modify_modification_token1] = ACTIONS(9046),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9046),
    [aux_sym_movelast_modification_token1] = ACTIONS(9046),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9046),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9046),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9046),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9046),
    [sym_trigger_keyword] = ACTIONS(9046),
    [sym_var_keyword] = ACTIONS(9046),
    [sym_local_keyword] = ACTIONS(9046),
    [sym_internal_keyword] = ACTIONS(9046),
    [sym_protected_keyword] = ACTIONS(9046),
    [sym_event_keyword] = ACTIONS(9046),
    [sym_fields_keyword] = ACTIONS(9046),
    [sym_keys_keyword] = ACTIONS(9046),
    [sym_fieldgroups_keyword] = ACTIONS(9046),
    [sym_actions_keyword] = ACTIONS(9046),
    [sym_layout_keyword] = ACTIONS(9046),
    [sym_area_keyword] = ACTIONS(9046),
    [sym_group_keyword] = ACTIONS(9046),
    [sym_repeater_keyword] = ACTIONS(9046),
    [sym_cuegroup_keyword] = ACTIONS(9046),
    [sym_fixed_keyword] = ACTIONS(9046),
    [sym_grid_keyword] = ACTIONS(9046),
    [sym_part_keyword] = ACTIONS(9046),
    [sym_systempart_keyword] = ACTIONS(9046),
    [sym_usercontrol_keyword] = ACTIONS(9046),
    [sym_dataset_keyword] = ACTIONS(9046),
    [sym_elements_keyword] = ACTIONS(9046),
    [sym_dataitem_keyword] = ACTIONS(9046),
    [sym_column_keyword] = ACTIONS(9046),
    [sym_filter_keyword] = ACTIONS(9046),
    [sym_labels_keyword] = ACTIONS(9046),
    [sym_rendering_keyword] = ACTIONS(9046),
    [sym_requestpage_keyword] = ACTIONS(9046),
    [sym_schema_keyword] = ACTIONS(9046),
    [sym_views_keyword] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
  },
  [STATE(5246)] = {
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9046),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9046),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9046),
    [aux_sym_addafter_modification_token1] = ACTIONS(9046),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9046),
    [aux_sym_modify_modification_token1] = ACTIONS(9046),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9046),
    [aux_sym_movelast_modification_token1] = ACTIONS(9046),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9046),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9046),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9046),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9046),
    [sym_trigger_keyword] = ACTIONS(9046),
    [sym_var_keyword] = ACTIONS(9046),
    [sym_local_keyword] = ACTIONS(9046),
    [sym_internal_keyword] = ACTIONS(9046),
    [sym_protected_keyword] = ACTIONS(9046),
    [sym_event_keyword] = ACTIONS(9046),
    [sym_fields_keyword] = ACTIONS(9046),
    [sym_keys_keyword] = ACTIONS(9046),
    [sym_fieldgroups_keyword] = ACTIONS(9046),
    [sym_actions_keyword] = ACTIONS(9046),
    [sym_layout_keyword] = ACTIONS(9046),
    [sym_area_keyword] = ACTIONS(9046),
    [sym_group_keyword] = ACTIONS(9046),
    [sym_repeater_keyword] = ACTIONS(9046),
    [sym_cuegroup_keyword] = ACTIONS(9046),
    [sym_fixed_keyword] = ACTIONS(9046),
    [sym_grid_keyword] = ACTIONS(9046),
    [sym_part_keyword] = ACTIONS(9046),
    [sym_systempart_keyword] = ACTIONS(9046),
    [sym_usercontrol_keyword] = ACTIONS(9046),
    [sym_dataset_keyword] = ACTIONS(9046),
    [sym_elements_keyword] = ACTIONS(9046),
    [sym_dataitem_keyword] = ACTIONS(9046),
    [sym_column_keyword] = ACTIONS(9046),
    [sym_filter_keyword] = ACTIONS(9046),
    [sym_labels_keyword] = ACTIONS(9046),
    [sym_rendering_keyword] = ACTIONS(9046),
    [sym_requestpage_keyword] = ACTIONS(9046),
    [sym_schema_keyword] = ACTIONS(9046),
    [sym_views_keyword] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
  },
  [STATE(5247)] = {
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9046),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9046),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9046),
    [aux_sym_addafter_modification_token1] = ACTIONS(9046),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9046),
    [aux_sym_modify_modification_token1] = ACTIONS(9046),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9046),
    [aux_sym_movelast_modification_token1] = ACTIONS(9046),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9046),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9046),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9046),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9046),
    [sym_trigger_keyword] = ACTIONS(9046),
    [sym_var_keyword] = ACTIONS(9046),
    [sym_local_keyword] = ACTIONS(9046),
    [sym_internal_keyword] = ACTIONS(9046),
    [sym_protected_keyword] = ACTIONS(9046),
    [sym_event_keyword] = ACTIONS(9046),
    [sym_fields_keyword] = ACTIONS(9046),
    [sym_keys_keyword] = ACTIONS(9046),
    [sym_fieldgroups_keyword] = ACTIONS(9046),
    [sym_actions_keyword] = ACTIONS(9046),
    [sym_layout_keyword] = ACTIONS(9046),
    [sym_area_keyword] = ACTIONS(9046),
    [sym_group_keyword] = ACTIONS(9046),
    [sym_repeater_keyword] = ACTIONS(9046),
    [sym_cuegroup_keyword] = ACTIONS(9046),
    [sym_fixed_keyword] = ACTIONS(9046),
    [sym_grid_keyword] = ACTIONS(9046),
    [sym_part_keyword] = ACTIONS(9046),
    [sym_systempart_keyword] = ACTIONS(9046),
    [sym_usercontrol_keyword] = ACTIONS(9046),
    [sym_dataset_keyword] = ACTIONS(9046),
    [sym_elements_keyword] = ACTIONS(9046),
    [sym_dataitem_keyword] = ACTIONS(9046),
    [sym_column_keyword] = ACTIONS(9046),
    [sym_filter_keyword] = ACTIONS(9046),
    [sym_labels_keyword] = ACTIONS(9046),
    [sym_rendering_keyword] = ACTIONS(9046),
    [sym_requestpage_keyword] = ACTIONS(9046),
    [sym_schema_keyword] = ACTIONS(9046),
    [sym_views_keyword] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
  },
  [STATE(5248)] = {
    [anon_sym_SEMI] = ACTIONS(9050),
    [aux_sym_where_condition_token1] = ACTIONS(9048),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9050),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9050),
    [anon_sym_LBRACK] = ACTIONS(9050),
    [aux_sym_basic_type_token6] = ACTIONS(9048),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9050),
    [aux_sym_addafter_modification_token1] = ACTIONS(9050),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9050),
    [aux_sym_modify_modification_token1] = ACTIONS(9050),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9050),
    [aux_sym_movelast_modification_token1] = ACTIONS(9050),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9050),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9050),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9050),
    [anon_sym_POUNDif] = ACTIONS(9050),
    [anon_sym_POUNDIF] = ACTIONS(9050),
    [anon_sym_POUNDIf] = ACTIONS(9050),
    [anon_sym_POUNDelif] = ACTIONS(9050),
    [anon_sym_POUNDELIF] = ACTIONS(9050),
    [anon_sym_POUNDElif] = ACTIONS(9050),
    [anon_sym_POUNDelse] = ACTIONS(9050),
    [anon_sym_POUNDELSE] = ACTIONS(9050),
    [anon_sym_POUNDElse] = ACTIONS(9050),
    [anon_sym_POUNDelse2] = ACTIONS(9050),
    [anon_sym_POUNDELSE2] = ACTIONS(9050),
    [anon_sym_POUNDElse2] = ACTIONS(9050),
    [anon_sym_POUNDendif] = ACTIONS(9050),
    [anon_sym_POUNDENDIF] = ACTIONS(9050),
    [anon_sym_POUNDEndif] = ACTIONS(9050),
    [anon_sym_POUNDendif2] = ACTIONS(9050),
    [anon_sym_POUNDENDIF2] = ACTIONS(9050),
    [anon_sym_POUNDEndif2] = ACTIONS(9050),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9050),
    [sym_trigger_keyword] = ACTIONS(9050),
    [sym_var_keyword] = ACTIONS(9050),
    [sym_local_keyword] = ACTIONS(9050),
    [sym_internal_keyword] = ACTIONS(9050),
    [sym_protected_keyword] = ACTIONS(9050),
    [sym_event_keyword] = ACTIONS(9050),
    [sym_fields_keyword] = ACTIONS(9050),
    [sym_keys_keyword] = ACTIONS(9050),
    [sym_fieldgroups_keyword] = ACTIONS(9050),
    [sym_actions_keyword] = ACTIONS(9050),
    [sym_layout_keyword] = ACTIONS(9050),
    [sym_area_keyword] = ACTIONS(9050),
    [sym_group_keyword] = ACTIONS(9050),
    [sym_repeater_keyword] = ACTIONS(9050),
    [sym_cuegroup_keyword] = ACTIONS(9050),
    [sym_fixed_keyword] = ACTIONS(9050),
    [sym_grid_keyword] = ACTIONS(9050),
    [sym_part_keyword] = ACTIONS(9050),
    [sym_systempart_keyword] = ACTIONS(9050),
    [sym_usercontrol_keyword] = ACTIONS(9050),
    [sym_dataset_keyword] = ACTIONS(9050),
    [sym_elements_keyword] = ACTIONS(9050),
    [sym_dataitem_keyword] = ACTIONS(9050),
    [sym_column_keyword] = ACTIONS(9050),
    [sym_filter_keyword] = ACTIONS(9050),
    [sym_labels_keyword] = ACTIONS(9050),
    [sym_rendering_keyword] = ACTIONS(9050),
    [sym_requestpage_keyword] = ACTIONS(9050),
    [sym_schema_keyword] = ACTIONS(9050),
    [sym_views_keyword] = ACTIONS(9050),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9050),
    [sym_preproc_open] = ACTIONS(9050),
    [sym_preproc_close] = ACTIONS(9050),
  },
  [STATE(5249)] = {
    [anon_sym_SEMI] = ACTIONS(9054),
    [aux_sym_where_condition_token1] = ACTIONS(9052),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9054),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9054),
    [anon_sym_LBRACK] = ACTIONS(9054),
    [aux_sym_basic_type_token6] = ACTIONS(9052),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9054),
    [aux_sym_addafter_modification_token1] = ACTIONS(9054),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9054),
    [aux_sym_modify_modification_token1] = ACTIONS(9054),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9054),
    [aux_sym_movelast_modification_token1] = ACTIONS(9054),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9054),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9054),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9054),
    [anon_sym_POUNDif] = ACTIONS(9054),
    [anon_sym_POUNDIF] = ACTIONS(9054),
    [anon_sym_POUNDIf] = ACTIONS(9054),
    [anon_sym_POUNDelif] = ACTIONS(9054),
    [anon_sym_POUNDELIF] = ACTIONS(9054),
    [anon_sym_POUNDElif] = ACTIONS(9054),
    [anon_sym_POUNDelse] = ACTIONS(9054),
    [anon_sym_POUNDELSE] = ACTIONS(9054),
    [anon_sym_POUNDElse] = ACTIONS(9054),
    [anon_sym_POUNDelse2] = ACTIONS(9054),
    [anon_sym_POUNDELSE2] = ACTIONS(9054),
    [anon_sym_POUNDElse2] = ACTIONS(9054),
    [anon_sym_POUNDendif] = ACTIONS(9054),
    [anon_sym_POUNDENDIF] = ACTIONS(9054),
    [anon_sym_POUNDEndif] = ACTIONS(9054),
    [anon_sym_POUNDendif2] = ACTIONS(9054),
    [anon_sym_POUNDENDIF2] = ACTIONS(9054),
    [anon_sym_POUNDEndif2] = ACTIONS(9054),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9054),
    [sym_trigger_keyword] = ACTIONS(9054),
    [sym_var_keyword] = ACTIONS(9054),
    [sym_local_keyword] = ACTIONS(9054),
    [sym_internal_keyword] = ACTIONS(9054),
    [sym_protected_keyword] = ACTIONS(9054),
    [sym_event_keyword] = ACTIONS(9054),
    [sym_fields_keyword] = ACTIONS(9054),
    [sym_keys_keyword] = ACTIONS(9054),
    [sym_fieldgroups_keyword] = ACTIONS(9054),
    [sym_actions_keyword] = ACTIONS(9054),
    [sym_layout_keyword] = ACTIONS(9054),
    [sym_area_keyword] = ACTIONS(9054),
    [sym_group_keyword] = ACTIONS(9054),
    [sym_repeater_keyword] = ACTIONS(9054),
    [sym_cuegroup_keyword] = ACTIONS(9054),
    [sym_fixed_keyword] = ACTIONS(9054),
    [sym_grid_keyword] = ACTIONS(9054),
    [sym_part_keyword] = ACTIONS(9054),
    [sym_systempart_keyword] = ACTIONS(9054),
    [sym_usercontrol_keyword] = ACTIONS(9054),
    [sym_dataset_keyword] = ACTIONS(9054),
    [sym_elements_keyword] = ACTIONS(9054),
    [sym_dataitem_keyword] = ACTIONS(9054),
    [sym_column_keyword] = ACTIONS(9054),
    [sym_filter_keyword] = ACTIONS(9054),
    [sym_labels_keyword] = ACTIONS(9054),
    [sym_rendering_keyword] = ACTIONS(9054),
    [sym_requestpage_keyword] = ACTIONS(9054),
    [sym_schema_keyword] = ACTIONS(9054),
    [sym_views_keyword] = ACTIONS(9054),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9054),
    [sym_preproc_open] = ACTIONS(9054),
    [sym_preproc_close] = ACTIONS(9054),
  },
  [STATE(5250)] = {
    [anon_sym_SEMI] = ACTIONS(9054),
    [aux_sym_where_condition_token1] = ACTIONS(9052),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9054),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9054),
    [anon_sym_LBRACK] = ACTIONS(9054),
    [aux_sym_basic_type_token6] = ACTIONS(9052),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9054),
    [aux_sym_addafter_modification_token1] = ACTIONS(9054),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9054),
    [aux_sym_modify_modification_token1] = ACTIONS(9054),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9054),
    [aux_sym_movelast_modification_token1] = ACTIONS(9054),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9054),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9054),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9054),
    [anon_sym_POUNDif] = ACTIONS(9054),
    [anon_sym_POUNDIF] = ACTIONS(9054),
    [anon_sym_POUNDIf] = ACTIONS(9054),
    [anon_sym_POUNDelif] = ACTIONS(9054),
    [anon_sym_POUNDELIF] = ACTIONS(9054),
    [anon_sym_POUNDElif] = ACTIONS(9054),
    [anon_sym_POUNDelse] = ACTIONS(9054),
    [anon_sym_POUNDELSE] = ACTIONS(9054),
    [anon_sym_POUNDElse] = ACTIONS(9054),
    [anon_sym_POUNDelse2] = ACTIONS(9054),
    [anon_sym_POUNDELSE2] = ACTIONS(9054),
    [anon_sym_POUNDElse2] = ACTIONS(9054),
    [anon_sym_POUNDendif] = ACTIONS(9054),
    [anon_sym_POUNDENDIF] = ACTIONS(9054),
    [anon_sym_POUNDEndif] = ACTIONS(9054),
    [anon_sym_POUNDendif2] = ACTIONS(9054),
    [anon_sym_POUNDENDIF2] = ACTIONS(9054),
    [anon_sym_POUNDEndif2] = ACTIONS(9054),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9054),
    [sym_trigger_keyword] = ACTIONS(9054),
    [sym_var_keyword] = ACTIONS(9054),
    [sym_local_keyword] = ACTIONS(9054),
    [sym_internal_keyword] = ACTIONS(9054),
    [sym_protected_keyword] = ACTIONS(9054),
    [sym_event_keyword] = ACTIONS(9054),
    [sym_fields_keyword] = ACTIONS(9054),
    [sym_keys_keyword] = ACTIONS(9054),
    [sym_fieldgroups_keyword] = ACTIONS(9054),
    [sym_actions_keyword] = ACTIONS(9054),
    [sym_layout_keyword] = ACTIONS(9054),
    [sym_area_keyword] = ACTIONS(9054),
    [sym_group_keyword] = ACTIONS(9054),
    [sym_repeater_keyword] = ACTIONS(9054),
    [sym_cuegroup_keyword] = ACTIONS(9054),
    [sym_fixed_keyword] = ACTIONS(9054),
    [sym_grid_keyword] = ACTIONS(9054),
    [sym_part_keyword] = ACTIONS(9054),
    [sym_systempart_keyword] = ACTIONS(9054),
    [sym_usercontrol_keyword] = ACTIONS(9054),
    [sym_dataset_keyword] = ACTIONS(9054),
    [sym_elements_keyword] = ACTIONS(9054),
    [sym_dataitem_keyword] = ACTIONS(9054),
    [sym_column_keyword] = ACTIONS(9054),
    [sym_filter_keyword] = ACTIONS(9054),
    [sym_labels_keyword] = ACTIONS(9054),
    [sym_rendering_keyword] = ACTIONS(9054),
    [sym_requestpage_keyword] = ACTIONS(9054),
    [sym_schema_keyword] = ACTIONS(9054),
    [sym_views_keyword] = ACTIONS(9054),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9054),
    [sym_preproc_open] = ACTIONS(9054),
    [sym_preproc_close] = ACTIONS(9054),
  },
  [STATE(5251)] = {
    [anon_sym_SEMI] = ACTIONS(12913),
    [aux_sym_where_condition_token1] = ACTIONS(12915),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12913),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12913),
    [anon_sym_LBRACK] = ACTIONS(12913),
    [aux_sym_basic_type_token6] = ACTIONS(12915),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12913),
    [aux_sym_addafter_modification_token1] = ACTIONS(12913),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12913),
    [aux_sym_modify_modification_token1] = ACTIONS(12913),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12913),
    [aux_sym_movelast_modification_token1] = ACTIONS(12913),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12913),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12913),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12913),
    [anon_sym_POUNDif] = ACTIONS(12913),
    [anon_sym_POUNDIF] = ACTIONS(12913),
    [anon_sym_POUNDIf] = ACTIONS(12913),
    [anon_sym_POUNDelif] = ACTIONS(12913),
    [anon_sym_POUNDELIF] = ACTIONS(12913),
    [anon_sym_POUNDElif] = ACTIONS(12913),
    [anon_sym_POUNDelse] = ACTIONS(12913),
    [anon_sym_POUNDELSE] = ACTIONS(12913),
    [anon_sym_POUNDElse] = ACTIONS(12913),
    [anon_sym_POUNDelse2] = ACTIONS(12913),
    [anon_sym_POUNDELSE2] = ACTIONS(12913),
    [anon_sym_POUNDElse2] = ACTIONS(12913),
    [anon_sym_POUNDendif] = ACTIONS(12913),
    [anon_sym_POUNDENDIF] = ACTIONS(12913),
    [anon_sym_POUNDEndif] = ACTIONS(12913),
    [anon_sym_POUNDendif2] = ACTIONS(12913),
    [anon_sym_POUNDENDIF2] = ACTIONS(12913),
    [anon_sym_POUNDEndif2] = ACTIONS(12913),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12913),
    [sym_trigger_keyword] = ACTIONS(12913),
    [sym_var_keyword] = ACTIONS(12913),
    [sym_local_keyword] = ACTIONS(12913),
    [sym_internal_keyword] = ACTIONS(12913),
    [sym_protected_keyword] = ACTIONS(12913),
    [sym_event_keyword] = ACTIONS(12913),
    [sym_fields_keyword] = ACTIONS(12913),
    [sym_keys_keyword] = ACTIONS(12913),
    [sym_fieldgroups_keyword] = ACTIONS(12913),
    [sym_actions_keyword] = ACTIONS(12913),
    [sym_layout_keyword] = ACTIONS(12913),
    [sym_area_keyword] = ACTIONS(12913),
    [sym_group_keyword] = ACTIONS(12913),
    [sym_repeater_keyword] = ACTIONS(12913),
    [sym_cuegroup_keyword] = ACTIONS(12913),
    [sym_fixed_keyword] = ACTIONS(12913),
    [sym_grid_keyword] = ACTIONS(12913),
    [sym_part_keyword] = ACTIONS(12913),
    [sym_systempart_keyword] = ACTIONS(12913),
    [sym_usercontrol_keyword] = ACTIONS(12913),
    [sym_dataset_keyword] = ACTIONS(12913),
    [sym_elements_keyword] = ACTIONS(12913),
    [sym_dataitem_keyword] = ACTIONS(12913),
    [sym_column_keyword] = ACTIONS(12913),
    [sym_filter_keyword] = ACTIONS(12913),
    [sym_labels_keyword] = ACTIONS(12913),
    [sym_rendering_keyword] = ACTIONS(12913),
    [sym_requestpage_keyword] = ACTIONS(12913),
    [sym_schema_keyword] = ACTIONS(12913),
    [sym_views_keyword] = ACTIONS(12913),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12913),
    [sym_preproc_open] = ACTIONS(12913),
    [sym_preproc_close] = ACTIONS(12913),
  },
  [STATE(5252)] = {
    [anon_sym_SEMI] = ACTIONS(12917),
    [aux_sym_where_condition_token1] = ACTIONS(12919),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12917),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12917),
    [anon_sym_LBRACK] = ACTIONS(12917),
    [aux_sym_basic_type_token6] = ACTIONS(12919),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12917),
    [aux_sym_addafter_modification_token1] = ACTIONS(12917),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12917),
    [aux_sym_modify_modification_token1] = ACTIONS(12917),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12917),
    [aux_sym_movelast_modification_token1] = ACTIONS(12917),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12917),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12917),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12917),
    [anon_sym_POUNDif] = ACTIONS(12917),
    [anon_sym_POUNDIF] = ACTIONS(12917),
    [anon_sym_POUNDIf] = ACTIONS(12917),
    [anon_sym_POUNDelif] = ACTIONS(12917),
    [anon_sym_POUNDELIF] = ACTIONS(12917),
    [anon_sym_POUNDElif] = ACTIONS(12917),
    [anon_sym_POUNDelse] = ACTIONS(12917),
    [anon_sym_POUNDELSE] = ACTIONS(12917),
    [anon_sym_POUNDElse] = ACTIONS(12917),
    [anon_sym_POUNDelse2] = ACTIONS(12917),
    [anon_sym_POUNDELSE2] = ACTIONS(12917),
    [anon_sym_POUNDElse2] = ACTIONS(12917),
    [anon_sym_POUNDendif] = ACTIONS(12917),
    [anon_sym_POUNDENDIF] = ACTIONS(12917),
    [anon_sym_POUNDEndif] = ACTIONS(12917),
    [anon_sym_POUNDendif2] = ACTIONS(12917),
    [anon_sym_POUNDENDIF2] = ACTIONS(12917),
    [anon_sym_POUNDEndif2] = ACTIONS(12917),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12917),
    [sym_trigger_keyword] = ACTIONS(12917),
    [sym_var_keyword] = ACTIONS(12917),
    [sym_local_keyword] = ACTIONS(12917),
    [sym_internal_keyword] = ACTIONS(12917),
    [sym_protected_keyword] = ACTIONS(12917),
    [sym_event_keyword] = ACTIONS(12917),
    [sym_fields_keyword] = ACTIONS(12917),
    [sym_keys_keyword] = ACTIONS(12917),
    [sym_fieldgroups_keyword] = ACTIONS(12917),
    [sym_actions_keyword] = ACTIONS(12917),
    [sym_layout_keyword] = ACTIONS(12917),
    [sym_area_keyword] = ACTIONS(12917),
    [sym_group_keyword] = ACTIONS(12917),
    [sym_repeater_keyword] = ACTIONS(12917),
    [sym_cuegroup_keyword] = ACTIONS(12917),
    [sym_fixed_keyword] = ACTIONS(12917),
    [sym_grid_keyword] = ACTIONS(12917),
    [sym_part_keyword] = ACTIONS(12917),
    [sym_systempart_keyword] = ACTIONS(12917),
    [sym_usercontrol_keyword] = ACTIONS(12917),
    [sym_dataset_keyword] = ACTIONS(12917),
    [sym_elements_keyword] = ACTIONS(12917),
    [sym_dataitem_keyword] = ACTIONS(12917),
    [sym_column_keyword] = ACTIONS(12917),
    [sym_filter_keyword] = ACTIONS(12917),
    [sym_labels_keyword] = ACTIONS(12917),
    [sym_rendering_keyword] = ACTIONS(12917),
    [sym_requestpage_keyword] = ACTIONS(12917),
    [sym_schema_keyword] = ACTIONS(12917),
    [sym_views_keyword] = ACTIONS(12917),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12917),
    [sym_preproc_open] = ACTIONS(12917),
    [sym_preproc_close] = ACTIONS(12917),
  },
  [STATE(5253)] = {
    [anon_sym_SEMI] = ACTIONS(12921),
    [aux_sym_where_condition_token1] = ACTIONS(12923),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12921),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12921),
    [anon_sym_LBRACK] = ACTIONS(12921),
    [aux_sym_basic_type_token6] = ACTIONS(12923),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12921),
    [aux_sym_addafter_modification_token1] = ACTIONS(12921),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12921),
    [aux_sym_modify_modification_token1] = ACTIONS(12921),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12921),
    [aux_sym_movelast_modification_token1] = ACTIONS(12921),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12921),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12921),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12921),
    [anon_sym_POUNDif] = ACTIONS(12921),
    [anon_sym_POUNDIF] = ACTIONS(12921),
    [anon_sym_POUNDIf] = ACTIONS(12921),
    [anon_sym_POUNDelif] = ACTIONS(12921),
    [anon_sym_POUNDELIF] = ACTIONS(12921),
    [anon_sym_POUNDElif] = ACTIONS(12921),
    [anon_sym_POUNDelse] = ACTIONS(12921),
    [anon_sym_POUNDELSE] = ACTIONS(12921),
    [anon_sym_POUNDElse] = ACTIONS(12921),
    [anon_sym_POUNDelse2] = ACTIONS(12921),
    [anon_sym_POUNDELSE2] = ACTIONS(12921),
    [anon_sym_POUNDElse2] = ACTIONS(12921),
    [anon_sym_POUNDendif] = ACTIONS(12921),
    [anon_sym_POUNDENDIF] = ACTIONS(12921),
    [anon_sym_POUNDEndif] = ACTIONS(12921),
    [anon_sym_POUNDendif2] = ACTIONS(12921),
    [anon_sym_POUNDENDIF2] = ACTIONS(12921),
    [anon_sym_POUNDEndif2] = ACTIONS(12921),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12921),
    [sym_trigger_keyword] = ACTIONS(12921),
    [sym_var_keyword] = ACTIONS(12921),
    [sym_local_keyword] = ACTIONS(12921),
    [sym_internal_keyword] = ACTIONS(12921),
    [sym_protected_keyword] = ACTIONS(12921),
    [sym_event_keyword] = ACTIONS(12921),
    [sym_fields_keyword] = ACTIONS(12921),
    [sym_keys_keyword] = ACTIONS(12921),
    [sym_fieldgroups_keyword] = ACTIONS(12921),
    [sym_actions_keyword] = ACTIONS(12921),
    [sym_layout_keyword] = ACTIONS(12921),
    [sym_area_keyword] = ACTIONS(12921),
    [sym_group_keyword] = ACTIONS(12921),
    [sym_repeater_keyword] = ACTIONS(12921),
    [sym_cuegroup_keyword] = ACTIONS(12921),
    [sym_fixed_keyword] = ACTIONS(12921),
    [sym_grid_keyword] = ACTIONS(12921),
    [sym_part_keyword] = ACTIONS(12921),
    [sym_systempart_keyword] = ACTIONS(12921),
    [sym_usercontrol_keyword] = ACTIONS(12921),
    [sym_dataset_keyword] = ACTIONS(12921),
    [sym_elements_keyword] = ACTIONS(12921),
    [sym_dataitem_keyword] = ACTIONS(12921),
    [sym_column_keyword] = ACTIONS(12921),
    [sym_filter_keyword] = ACTIONS(12921),
    [sym_labels_keyword] = ACTIONS(12921),
    [sym_rendering_keyword] = ACTIONS(12921),
    [sym_requestpage_keyword] = ACTIONS(12921),
    [sym_schema_keyword] = ACTIONS(12921),
    [sym_views_keyword] = ACTIONS(12921),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12921),
    [sym_preproc_open] = ACTIONS(12921),
    [sym_preproc_close] = ACTIONS(12921),
  },
  [STATE(5254)] = {
    [anon_sym_SEMI] = ACTIONS(12925),
    [aux_sym_where_condition_token1] = ACTIONS(12927),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12925),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12925),
    [anon_sym_LBRACK] = ACTIONS(12925),
    [aux_sym_basic_type_token6] = ACTIONS(12927),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12925),
    [aux_sym_addafter_modification_token1] = ACTIONS(12925),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12925),
    [aux_sym_modify_modification_token1] = ACTIONS(12925),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12925),
    [aux_sym_movelast_modification_token1] = ACTIONS(12925),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12925),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12925),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12925),
    [anon_sym_POUNDif] = ACTIONS(12925),
    [anon_sym_POUNDIF] = ACTIONS(12925),
    [anon_sym_POUNDIf] = ACTIONS(12925),
    [anon_sym_POUNDelif] = ACTIONS(12925),
    [anon_sym_POUNDELIF] = ACTIONS(12925),
    [anon_sym_POUNDElif] = ACTIONS(12925),
    [anon_sym_POUNDelse] = ACTIONS(12925),
    [anon_sym_POUNDELSE] = ACTIONS(12925),
    [anon_sym_POUNDElse] = ACTIONS(12925),
    [anon_sym_POUNDelse2] = ACTIONS(12925),
    [anon_sym_POUNDELSE2] = ACTIONS(12925),
    [anon_sym_POUNDElse2] = ACTIONS(12925),
    [anon_sym_POUNDendif] = ACTIONS(12925),
    [anon_sym_POUNDENDIF] = ACTIONS(12925),
    [anon_sym_POUNDEndif] = ACTIONS(12925),
    [anon_sym_POUNDendif2] = ACTIONS(12925),
    [anon_sym_POUNDENDIF2] = ACTIONS(12925),
    [anon_sym_POUNDEndif2] = ACTIONS(12925),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12925),
    [sym_trigger_keyword] = ACTIONS(12925),
    [sym_var_keyword] = ACTIONS(12925),
    [sym_local_keyword] = ACTIONS(12925),
    [sym_internal_keyword] = ACTIONS(12925),
    [sym_protected_keyword] = ACTIONS(12925),
    [sym_event_keyword] = ACTIONS(12925),
    [sym_fields_keyword] = ACTIONS(12925),
    [sym_keys_keyword] = ACTIONS(12925),
    [sym_fieldgroups_keyword] = ACTIONS(12925),
    [sym_actions_keyword] = ACTIONS(12925),
    [sym_layout_keyword] = ACTIONS(12925),
    [sym_area_keyword] = ACTIONS(12925),
    [sym_group_keyword] = ACTIONS(12925),
    [sym_repeater_keyword] = ACTIONS(12925),
    [sym_cuegroup_keyword] = ACTIONS(12925),
    [sym_fixed_keyword] = ACTIONS(12925),
    [sym_grid_keyword] = ACTIONS(12925),
    [sym_part_keyword] = ACTIONS(12925),
    [sym_systempart_keyword] = ACTIONS(12925),
    [sym_usercontrol_keyword] = ACTIONS(12925),
    [sym_dataset_keyword] = ACTIONS(12925),
    [sym_elements_keyword] = ACTIONS(12925),
    [sym_dataitem_keyword] = ACTIONS(12925),
    [sym_column_keyword] = ACTIONS(12925),
    [sym_filter_keyword] = ACTIONS(12925),
    [sym_labels_keyword] = ACTIONS(12925),
    [sym_rendering_keyword] = ACTIONS(12925),
    [sym_requestpage_keyword] = ACTIONS(12925),
    [sym_schema_keyword] = ACTIONS(12925),
    [sym_views_keyword] = ACTIONS(12925),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12925),
    [sym_preproc_open] = ACTIONS(12925),
    [sym_preproc_close] = ACTIONS(12925),
  },
  [STATE(5255)] = {
    [anon_sym_SEMI] = ACTIONS(12929),
    [aux_sym_where_condition_token1] = ACTIONS(12931),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12929),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12929),
    [anon_sym_LBRACK] = ACTIONS(12929),
    [aux_sym_basic_type_token6] = ACTIONS(12931),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12929),
    [aux_sym_addafter_modification_token1] = ACTIONS(12929),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12929),
    [aux_sym_modify_modification_token1] = ACTIONS(12929),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12929),
    [aux_sym_movelast_modification_token1] = ACTIONS(12929),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12929),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12929),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12929),
    [anon_sym_POUNDif] = ACTIONS(12929),
    [anon_sym_POUNDIF] = ACTIONS(12929),
    [anon_sym_POUNDIf] = ACTIONS(12929),
    [anon_sym_POUNDelif] = ACTIONS(12929),
    [anon_sym_POUNDELIF] = ACTIONS(12929),
    [anon_sym_POUNDElif] = ACTIONS(12929),
    [anon_sym_POUNDelse] = ACTIONS(12929),
    [anon_sym_POUNDELSE] = ACTIONS(12929),
    [anon_sym_POUNDElse] = ACTIONS(12929),
    [anon_sym_POUNDelse2] = ACTIONS(12929),
    [anon_sym_POUNDELSE2] = ACTIONS(12929),
    [anon_sym_POUNDElse2] = ACTIONS(12929),
    [anon_sym_POUNDendif] = ACTIONS(12929),
    [anon_sym_POUNDENDIF] = ACTIONS(12929),
    [anon_sym_POUNDEndif] = ACTIONS(12929),
    [anon_sym_POUNDendif2] = ACTIONS(12929),
    [anon_sym_POUNDENDIF2] = ACTIONS(12929),
    [anon_sym_POUNDEndif2] = ACTIONS(12929),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12929),
    [sym_trigger_keyword] = ACTIONS(12929),
    [sym_var_keyword] = ACTIONS(12929),
    [sym_local_keyword] = ACTIONS(12929),
    [sym_internal_keyword] = ACTIONS(12929),
    [sym_protected_keyword] = ACTIONS(12929),
    [sym_event_keyword] = ACTIONS(12929),
    [sym_fields_keyword] = ACTIONS(12929),
    [sym_keys_keyword] = ACTIONS(12929),
    [sym_fieldgroups_keyword] = ACTIONS(12929),
    [sym_actions_keyword] = ACTIONS(12929),
    [sym_layout_keyword] = ACTIONS(12929),
    [sym_area_keyword] = ACTIONS(12929),
    [sym_group_keyword] = ACTIONS(12929),
    [sym_repeater_keyword] = ACTIONS(12929),
    [sym_cuegroup_keyword] = ACTIONS(12929),
    [sym_fixed_keyword] = ACTIONS(12929),
    [sym_grid_keyword] = ACTIONS(12929),
    [sym_part_keyword] = ACTIONS(12929),
    [sym_systempart_keyword] = ACTIONS(12929),
    [sym_usercontrol_keyword] = ACTIONS(12929),
    [sym_dataset_keyword] = ACTIONS(12929),
    [sym_elements_keyword] = ACTIONS(12929),
    [sym_dataitem_keyword] = ACTIONS(12929),
    [sym_column_keyword] = ACTIONS(12929),
    [sym_filter_keyword] = ACTIONS(12929),
    [sym_labels_keyword] = ACTIONS(12929),
    [sym_rendering_keyword] = ACTIONS(12929),
    [sym_requestpage_keyword] = ACTIONS(12929),
    [sym_schema_keyword] = ACTIONS(12929),
    [sym_views_keyword] = ACTIONS(12929),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12929),
    [sym_preproc_open] = ACTIONS(12929),
    [sym_preproc_close] = ACTIONS(12929),
  },
  [STATE(5256)] = {
    [anon_sym_SEMI] = ACTIONS(9066),
    [aux_sym_where_condition_token1] = ACTIONS(9064),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9066),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9066),
    [anon_sym_LBRACK] = ACTIONS(9066),
    [aux_sym_basic_type_token6] = ACTIONS(9064),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9066),
    [aux_sym_addafter_modification_token1] = ACTIONS(9066),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9066),
    [aux_sym_modify_modification_token1] = ACTIONS(9066),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9066),
    [aux_sym_movelast_modification_token1] = ACTIONS(9066),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9066),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9066),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9066),
    [anon_sym_POUNDif] = ACTIONS(9066),
    [anon_sym_POUNDIF] = ACTIONS(9066),
    [anon_sym_POUNDIf] = ACTIONS(9066),
    [anon_sym_POUNDelif] = ACTIONS(9066),
    [anon_sym_POUNDELIF] = ACTIONS(9066),
    [anon_sym_POUNDElif] = ACTIONS(9066),
    [anon_sym_POUNDelse] = ACTIONS(9066),
    [anon_sym_POUNDELSE] = ACTIONS(9066),
    [anon_sym_POUNDElse] = ACTIONS(9066),
    [anon_sym_POUNDelse2] = ACTIONS(9066),
    [anon_sym_POUNDELSE2] = ACTIONS(9066),
    [anon_sym_POUNDElse2] = ACTIONS(9066),
    [anon_sym_POUNDendif] = ACTIONS(9066),
    [anon_sym_POUNDENDIF] = ACTIONS(9066),
    [anon_sym_POUNDEndif] = ACTIONS(9066),
    [anon_sym_POUNDendif2] = ACTIONS(9066),
    [anon_sym_POUNDENDIF2] = ACTIONS(9066),
    [anon_sym_POUNDEndif2] = ACTIONS(9066),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9066),
    [sym_trigger_keyword] = ACTIONS(9066),
    [sym_var_keyword] = ACTIONS(9066),
    [sym_local_keyword] = ACTIONS(9066),
    [sym_internal_keyword] = ACTIONS(9066),
    [sym_protected_keyword] = ACTIONS(9066),
    [sym_event_keyword] = ACTIONS(9066),
    [sym_fields_keyword] = ACTIONS(9066),
    [sym_keys_keyword] = ACTIONS(9066),
    [sym_fieldgroups_keyword] = ACTIONS(9066),
    [sym_actions_keyword] = ACTIONS(9066),
    [sym_layout_keyword] = ACTIONS(9066),
    [sym_area_keyword] = ACTIONS(9066),
    [sym_group_keyword] = ACTIONS(9066),
    [sym_repeater_keyword] = ACTIONS(9066),
    [sym_cuegroup_keyword] = ACTIONS(9066),
    [sym_fixed_keyword] = ACTIONS(9066),
    [sym_grid_keyword] = ACTIONS(9066),
    [sym_part_keyword] = ACTIONS(9066),
    [sym_systempart_keyword] = ACTIONS(9066),
    [sym_usercontrol_keyword] = ACTIONS(9066),
    [sym_dataset_keyword] = ACTIONS(9066),
    [sym_elements_keyword] = ACTIONS(9066),
    [sym_dataitem_keyword] = ACTIONS(9066),
    [sym_column_keyword] = ACTIONS(9066),
    [sym_filter_keyword] = ACTIONS(9066),
    [sym_labels_keyword] = ACTIONS(9066),
    [sym_rendering_keyword] = ACTIONS(9066),
    [sym_requestpage_keyword] = ACTIONS(9066),
    [sym_schema_keyword] = ACTIONS(9066),
    [sym_views_keyword] = ACTIONS(9066),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9066),
    [sym_preproc_open] = ACTIONS(9066),
    [sym_preproc_close] = ACTIONS(9066),
  },
  [STATE(5257)] = {
    [anon_sym_SEMI] = ACTIONS(9066),
    [aux_sym_where_condition_token1] = ACTIONS(9064),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9066),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9066),
    [anon_sym_LBRACK] = ACTIONS(9066),
    [aux_sym_basic_type_token6] = ACTIONS(9064),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9066),
    [aux_sym_addafter_modification_token1] = ACTIONS(9066),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9066),
    [aux_sym_modify_modification_token1] = ACTIONS(9066),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9066),
    [aux_sym_movelast_modification_token1] = ACTIONS(9066),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9066),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9066),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9066),
    [anon_sym_POUNDif] = ACTIONS(9066),
    [anon_sym_POUNDIF] = ACTIONS(9066),
    [anon_sym_POUNDIf] = ACTIONS(9066),
    [anon_sym_POUNDelif] = ACTIONS(9066),
    [anon_sym_POUNDELIF] = ACTIONS(9066),
    [anon_sym_POUNDElif] = ACTIONS(9066),
    [anon_sym_POUNDelse] = ACTIONS(9066),
    [anon_sym_POUNDELSE] = ACTIONS(9066),
    [anon_sym_POUNDElse] = ACTIONS(9066),
    [anon_sym_POUNDelse2] = ACTIONS(9066),
    [anon_sym_POUNDELSE2] = ACTIONS(9066),
    [anon_sym_POUNDElse2] = ACTIONS(9066),
    [anon_sym_POUNDendif] = ACTIONS(9066),
    [anon_sym_POUNDENDIF] = ACTIONS(9066),
    [anon_sym_POUNDEndif] = ACTIONS(9066),
    [anon_sym_POUNDendif2] = ACTIONS(9066),
    [anon_sym_POUNDENDIF2] = ACTIONS(9066),
    [anon_sym_POUNDEndif2] = ACTIONS(9066),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9066),
    [sym_trigger_keyword] = ACTIONS(9066),
    [sym_var_keyword] = ACTIONS(9066),
    [sym_local_keyword] = ACTIONS(9066),
    [sym_internal_keyword] = ACTIONS(9066),
    [sym_protected_keyword] = ACTIONS(9066),
    [sym_event_keyword] = ACTIONS(9066),
    [sym_fields_keyword] = ACTIONS(9066),
    [sym_keys_keyword] = ACTIONS(9066),
    [sym_fieldgroups_keyword] = ACTIONS(9066),
    [sym_actions_keyword] = ACTIONS(9066),
    [sym_layout_keyword] = ACTIONS(9066),
    [sym_area_keyword] = ACTIONS(9066),
    [sym_group_keyword] = ACTIONS(9066),
    [sym_repeater_keyword] = ACTIONS(9066),
    [sym_cuegroup_keyword] = ACTIONS(9066),
    [sym_fixed_keyword] = ACTIONS(9066),
    [sym_grid_keyword] = ACTIONS(9066),
    [sym_part_keyword] = ACTIONS(9066),
    [sym_systempart_keyword] = ACTIONS(9066),
    [sym_usercontrol_keyword] = ACTIONS(9066),
    [sym_dataset_keyword] = ACTIONS(9066),
    [sym_elements_keyword] = ACTIONS(9066),
    [sym_dataitem_keyword] = ACTIONS(9066),
    [sym_column_keyword] = ACTIONS(9066),
    [sym_filter_keyword] = ACTIONS(9066),
    [sym_labels_keyword] = ACTIONS(9066),
    [sym_rendering_keyword] = ACTIONS(9066),
    [sym_requestpage_keyword] = ACTIONS(9066),
    [sym_schema_keyword] = ACTIONS(9066),
    [sym_views_keyword] = ACTIONS(9066),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9066),
    [sym_preproc_open] = ACTIONS(9066),
    [sym_preproc_close] = ACTIONS(9066),
  },
  [STATE(5258)] = {
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9070),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9070),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9070),
    [aux_sym_addafter_modification_token1] = ACTIONS(9070),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9070),
    [aux_sym_modify_modification_token1] = ACTIONS(9070),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9070),
    [aux_sym_movelast_modification_token1] = ACTIONS(9070),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9070),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9070),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9070),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9070),
    [sym_trigger_keyword] = ACTIONS(9070),
    [sym_var_keyword] = ACTIONS(9070),
    [sym_local_keyword] = ACTIONS(9070),
    [sym_internal_keyword] = ACTIONS(9070),
    [sym_protected_keyword] = ACTIONS(9070),
    [sym_event_keyword] = ACTIONS(9070),
    [sym_fields_keyword] = ACTIONS(9070),
    [sym_keys_keyword] = ACTIONS(9070),
    [sym_fieldgroups_keyword] = ACTIONS(9070),
    [sym_actions_keyword] = ACTIONS(9070),
    [sym_layout_keyword] = ACTIONS(9070),
    [sym_area_keyword] = ACTIONS(9070),
    [sym_group_keyword] = ACTIONS(9070),
    [sym_repeater_keyword] = ACTIONS(9070),
    [sym_cuegroup_keyword] = ACTIONS(9070),
    [sym_fixed_keyword] = ACTIONS(9070),
    [sym_grid_keyword] = ACTIONS(9070),
    [sym_part_keyword] = ACTIONS(9070),
    [sym_systempart_keyword] = ACTIONS(9070),
    [sym_usercontrol_keyword] = ACTIONS(9070),
    [sym_dataset_keyword] = ACTIONS(9070),
    [sym_elements_keyword] = ACTIONS(9070),
    [sym_dataitem_keyword] = ACTIONS(9070),
    [sym_column_keyword] = ACTIONS(9070),
    [sym_filter_keyword] = ACTIONS(9070),
    [sym_labels_keyword] = ACTIONS(9070),
    [sym_rendering_keyword] = ACTIONS(9070),
    [sym_requestpage_keyword] = ACTIONS(9070),
    [sym_schema_keyword] = ACTIONS(9070),
    [sym_views_keyword] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
  },
  [STATE(5259)] = {
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9070),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9070),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9070),
    [aux_sym_addafter_modification_token1] = ACTIONS(9070),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9070),
    [aux_sym_modify_modification_token1] = ACTIONS(9070),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9070),
    [aux_sym_movelast_modification_token1] = ACTIONS(9070),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9070),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9070),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9070),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9070),
    [sym_trigger_keyword] = ACTIONS(9070),
    [sym_var_keyword] = ACTIONS(9070),
    [sym_local_keyword] = ACTIONS(9070),
    [sym_internal_keyword] = ACTIONS(9070),
    [sym_protected_keyword] = ACTIONS(9070),
    [sym_event_keyword] = ACTIONS(9070),
    [sym_fields_keyword] = ACTIONS(9070),
    [sym_keys_keyword] = ACTIONS(9070),
    [sym_fieldgroups_keyword] = ACTIONS(9070),
    [sym_actions_keyword] = ACTIONS(9070),
    [sym_layout_keyword] = ACTIONS(9070),
    [sym_area_keyword] = ACTIONS(9070),
    [sym_group_keyword] = ACTIONS(9070),
    [sym_repeater_keyword] = ACTIONS(9070),
    [sym_cuegroup_keyword] = ACTIONS(9070),
    [sym_fixed_keyword] = ACTIONS(9070),
    [sym_grid_keyword] = ACTIONS(9070),
    [sym_part_keyword] = ACTIONS(9070),
    [sym_systempart_keyword] = ACTIONS(9070),
    [sym_usercontrol_keyword] = ACTIONS(9070),
    [sym_dataset_keyword] = ACTIONS(9070),
    [sym_elements_keyword] = ACTIONS(9070),
    [sym_dataitem_keyword] = ACTIONS(9070),
    [sym_column_keyword] = ACTIONS(9070),
    [sym_filter_keyword] = ACTIONS(9070),
    [sym_labels_keyword] = ACTIONS(9070),
    [sym_rendering_keyword] = ACTIONS(9070),
    [sym_requestpage_keyword] = ACTIONS(9070),
    [sym_schema_keyword] = ACTIONS(9070),
    [sym_views_keyword] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
  },
  [STATE(5260)] = {
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9070),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9070),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9070),
    [aux_sym_addafter_modification_token1] = ACTIONS(9070),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9070),
    [aux_sym_modify_modification_token1] = ACTIONS(9070),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9070),
    [aux_sym_movelast_modification_token1] = ACTIONS(9070),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9070),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9070),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9070),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(9070),
    [sym_trigger_keyword] = ACTIONS(9070),
    [sym_var_keyword] = ACTIONS(9070),
    [sym_local_keyword] = ACTIONS(9070),
    [sym_internal_keyword] = ACTIONS(9070),
    [sym_protected_keyword] = ACTIONS(9070),
    [sym_event_keyword] = ACTIONS(9070),
    [sym_fields_keyword] = ACTIONS(9070),
    [sym_keys_keyword] = ACTIONS(9070),
    [sym_fieldgroups_keyword] = ACTIONS(9070),
    [sym_actions_keyword] = ACTIONS(9070),
    [sym_layout_keyword] = ACTIONS(9070),
    [sym_area_keyword] = ACTIONS(9070),
    [sym_group_keyword] = ACTIONS(9070),
    [sym_repeater_keyword] = ACTIONS(9070),
    [sym_cuegroup_keyword] = ACTIONS(9070),
    [sym_fixed_keyword] = ACTIONS(9070),
    [sym_grid_keyword] = ACTIONS(9070),
    [sym_part_keyword] = ACTIONS(9070),
    [sym_systempart_keyword] = ACTIONS(9070),
    [sym_usercontrol_keyword] = ACTIONS(9070),
    [sym_dataset_keyword] = ACTIONS(9070),
    [sym_elements_keyword] = ACTIONS(9070),
    [sym_dataitem_keyword] = ACTIONS(9070),
    [sym_column_keyword] = ACTIONS(9070),
    [sym_filter_keyword] = ACTIONS(9070),
    [sym_labels_keyword] = ACTIONS(9070),
    [sym_rendering_keyword] = ACTIONS(9070),
    [sym_requestpage_keyword] = ACTIONS(9070),
    [sym_schema_keyword] = ACTIONS(9070),
    [sym_views_keyword] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
  },
  [STATE(5261)] = {
    [anon_sym_SEMI] = ACTIONS(12933),
    [aux_sym_where_condition_token1] = ACTIONS(12935),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12933),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12933),
    [anon_sym_LBRACK] = ACTIONS(12933),
    [aux_sym_basic_type_token6] = ACTIONS(12935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12933),
    [aux_sym_addafter_modification_token1] = ACTIONS(12933),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12933),
    [aux_sym_modify_modification_token1] = ACTIONS(12933),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12933),
    [aux_sym_movelast_modification_token1] = ACTIONS(12933),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12933),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12933),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12933),
    [anon_sym_POUNDif] = ACTIONS(12933),
    [anon_sym_POUNDIF] = ACTIONS(12933),
    [anon_sym_POUNDIf] = ACTIONS(12933),
    [anon_sym_POUNDelif] = ACTIONS(12933),
    [anon_sym_POUNDELIF] = ACTIONS(12933),
    [anon_sym_POUNDElif] = ACTIONS(12933),
    [anon_sym_POUNDelse] = ACTIONS(12933),
    [anon_sym_POUNDELSE] = ACTIONS(12933),
    [anon_sym_POUNDElse] = ACTIONS(12933),
    [anon_sym_POUNDelse2] = ACTIONS(12933),
    [anon_sym_POUNDELSE2] = ACTIONS(12933),
    [anon_sym_POUNDElse2] = ACTIONS(12933),
    [anon_sym_POUNDendif] = ACTIONS(12933),
    [anon_sym_POUNDENDIF] = ACTIONS(12933),
    [anon_sym_POUNDEndif] = ACTIONS(12933),
    [anon_sym_POUNDendif2] = ACTIONS(12933),
    [anon_sym_POUNDENDIF2] = ACTIONS(12933),
    [anon_sym_POUNDEndif2] = ACTIONS(12933),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12933),
    [sym_trigger_keyword] = ACTIONS(12933),
    [sym_var_keyword] = ACTIONS(12933),
    [sym_local_keyword] = ACTIONS(12933),
    [sym_internal_keyword] = ACTIONS(12933),
    [sym_protected_keyword] = ACTIONS(12933),
    [sym_event_keyword] = ACTIONS(12933),
    [sym_fields_keyword] = ACTIONS(12933),
    [sym_keys_keyword] = ACTIONS(12933),
    [sym_fieldgroups_keyword] = ACTIONS(12933),
    [sym_actions_keyword] = ACTIONS(12933),
    [sym_layout_keyword] = ACTIONS(12933),
    [sym_area_keyword] = ACTIONS(12933),
    [sym_group_keyword] = ACTIONS(12933),
    [sym_repeater_keyword] = ACTIONS(12933),
    [sym_cuegroup_keyword] = ACTIONS(12933),
    [sym_fixed_keyword] = ACTIONS(12933),
    [sym_grid_keyword] = ACTIONS(12933),
    [sym_part_keyword] = ACTIONS(12933),
    [sym_systempart_keyword] = ACTIONS(12933),
    [sym_usercontrol_keyword] = ACTIONS(12933),
    [sym_dataset_keyword] = ACTIONS(12933),
    [sym_elements_keyword] = ACTIONS(12933),
    [sym_dataitem_keyword] = ACTIONS(12933),
    [sym_column_keyword] = ACTIONS(12933),
    [sym_filter_keyword] = ACTIONS(12933),
    [sym_labels_keyword] = ACTIONS(12933),
    [sym_rendering_keyword] = ACTIONS(12933),
    [sym_requestpage_keyword] = ACTIONS(12933),
    [sym_schema_keyword] = ACTIONS(12933),
    [sym_views_keyword] = ACTIONS(12933),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12933),
    [sym_preproc_open] = ACTIONS(12933),
    [sym_preproc_close] = ACTIONS(12933),
  },
  [STATE(5262)] = {
    [anon_sym_SEMI] = ACTIONS(12937),
    [aux_sym_where_condition_token1] = ACTIONS(12939),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12937),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12937),
    [anon_sym_LBRACK] = ACTIONS(12937),
    [aux_sym_basic_type_token6] = ACTIONS(12939),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12937),
    [aux_sym_addafter_modification_token1] = ACTIONS(12937),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12937),
    [aux_sym_modify_modification_token1] = ACTIONS(12937),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12937),
    [aux_sym_movelast_modification_token1] = ACTIONS(12937),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12937),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12937),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12937),
    [anon_sym_POUNDif] = ACTIONS(12937),
    [anon_sym_POUNDIF] = ACTIONS(12937),
    [anon_sym_POUNDIf] = ACTIONS(12937),
    [anon_sym_POUNDelif] = ACTIONS(12937),
    [anon_sym_POUNDELIF] = ACTIONS(12937),
    [anon_sym_POUNDElif] = ACTIONS(12937),
    [anon_sym_POUNDelse] = ACTIONS(12937),
    [anon_sym_POUNDELSE] = ACTIONS(12937),
    [anon_sym_POUNDElse] = ACTIONS(12937),
    [anon_sym_POUNDelse2] = ACTIONS(12937),
    [anon_sym_POUNDELSE2] = ACTIONS(12937),
    [anon_sym_POUNDElse2] = ACTIONS(12937),
    [anon_sym_POUNDendif] = ACTIONS(12937),
    [anon_sym_POUNDENDIF] = ACTIONS(12937),
    [anon_sym_POUNDEndif] = ACTIONS(12937),
    [anon_sym_POUNDendif2] = ACTIONS(12937),
    [anon_sym_POUNDENDIF2] = ACTIONS(12937),
    [anon_sym_POUNDEndif2] = ACTIONS(12937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12937),
    [sym_trigger_keyword] = ACTIONS(12937),
    [sym_var_keyword] = ACTIONS(12937),
    [sym_local_keyword] = ACTIONS(12937),
    [sym_internal_keyword] = ACTIONS(12937),
    [sym_protected_keyword] = ACTIONS(12937),
    [sym_event_keyword] = ACTIONS(12937),
    [sym_fields_keyword] = ACTIONS(12937),
    [sym_keys_keyword] = ACTIONS(12937),
    [sym_fieldgroups_keyword] = ACTIONS(12937),
    [sym_actions_keyword] = ACTIONS(12937),
    [sym_layout_keyword] = ACTIONS(12937),
    [sym_area_keyword] = ACTIONS(12937),
    [sym_group_keyword] = ACTIONS(12937),
    [sym_repeater_keyword] = ACTIONS(12937),
    [sym_cuegroup_keyword] = ACTIONS(12937),
    [sym_fixed_keyword] = ACTIONS(12937),
    [sym_grid_keyword] = ACTIONS(12937),
    [sym_part_keyword] = ACTIONS(12937),
    [sym_systempart_keyword] = ACTIONS(12937),
    [sym_usercontrol_keyword] = ACTIONS(12937),
    [sym_dataset_keyword] = ACTIONS(12937),
    [sym_elements_keyword] = ACTIONS(12937),
    [sym_dataitem_keyword] = ACTIONS(12937),
    [sym_column_keyword] = ACTIONS(12937),
    [sym_filter_keyword] = ACTIONS(12937),
    [sym_labels_keyword] = ACTIONS(12937),
    [sym_rendering_keyword] = ACTIONS(12937),
    [sym_requestpage_keyword] = ACTIONS(12937),
    [sym_schema_keyword] = ACTIONS(12937),
    [sym_views_keyword] = ACTIONS(12937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12937),
    [sym_preproc_open] = ACTIONS(12937),
    [sym_preproc_close] = ACTIONS(12937),
  },
  [STATE(5263)] = {
    [anon_sym_SEMI] = ACTIONS(8891),
    [aux_sym_where_condition_token1] = ACTIONS(8889),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8891),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8891),
    [anon_sym_LBRACK] = ACTIONS(8891),
    [aux_sym_basic_type_token6] = ACTIONS(8889),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8891),
    [aux_sym_addafter_modification_token1] = ACTIONS(8891),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8891),
    [aux_sym_modify_modification_token1] = ACTIONS(8891),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8891),
    [aux_sym_movelast_modification_token1] = ACTIONS(8891),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8891),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8891),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8891),
    [anon_sym_POUNDif] = ACTIONS(8891),
    [anon_sym_POUNDIF] = ACTIONS(8891),
    [anon_sym_POUNDIf] = ACTIONS(8891),
    [anon_sym_POUNDelif] = ACTIONS(8891),
    [anon_sym_POUNDELIF] = ACTIONS(8891),
    [anon_sym_POUNDElif] = ACTIONS(8891),
    [anon_sym_POUNDelse] = ACTIONS(8891),
    [anon_sym_POUNDELSE] = ACTIONS(8891),
    [anon_sym_POUNDElse] = ACTIONS(8891),
    [anon_sym_POUNDelse2] = ACTIONS(8891),
    [anon_sym_POUNDELSE2] = ACTIONS(8891),
    [anon_sym_POUNDElse2] = ACTIONS(8891),
    [anon_sym_POUNDendif] = ACTIONS(8891),
    [anon_sym_POUNDENDIF] = ACTIONS(8891),
    [anon_sym_POUNDEndif] = ACTIONS(8891),
    [anon_sym_POUNDendif2] = ACTIONS(8891),
    [anon_sym_POUNDENDIF2] = ACTIONS(8891),
    [anon_sym_POUNDEndif2] = ACTIONS(8891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8891),
    [sym_trigger_keyword] = ACTIONS(8891),
    [sym_var_keyword] = ACTIONS(8891),
    [sym_local_keyword] = ACTIONS(8891),
    [sym_internal_keyword] = ACTIONS(8891),
    [sym_protected_keyword] = ACTIONS(8891),
    [sym_event_keyword] = ACTIONS(8891),
    [sym_fields_keyword] = ACTIONS(8891),
    [sym_keys_keyword] = ACTIONS(8891),
    [sym_fieldgroups_keyword] = ACTIONS(8891),
    [sym_actions_keyword] = ACTIONS(8891),
    [sym_layout_keyword] = ACTIONS(8891),
    [sym_area_keyword] = ACTIONS(8891),
    [sym_group_keyword] = ACTIONS(8891),
    [sym_repeater_keyword] = ACTIONS(8891),
    [sym_cuegroup_keyword] = ACTIONS(8891),
    [sym_fixed_keyword] = ACTIONS(8891),
    [sym_grid_keyword] = ACTIONS(8891),
    [sym_part_keyword] = ACTIONS(8891),
    [sym_systempart_keyword] = ACTIONS(8891),
    [sym_usercontrol_keyword] = ACTIONS(8891),
    [sym_dataset_keyword] = ACTIONS(8891),
    [sym_elements_keyword] = ACTIONS(8891),
    [sym_dataitem_keyword] = ACTIONS(8891),
    [sym_column_keyword] = ACTIONS(8891),
    [sym_filter_keyword] = ACTIONS(8891),
    [sym_labels_keyword] = ACTIONS(8891),
    [sym_rendering_keyword] = ACTIONS(8891),
    [sym_requestpage_keyword] = ACTIONS(8891),
    [sym_schema_keyword] = ACTIONS(8891),
    [sym_views_keyword] = ACTIONS(8891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8891),
    [sym_preproc_open] = ACTIONS(8891),
    [sym_preproc_close] = ACTIONS(8891),
  },
  [STATE(5264)] = {
    [anon_sym_SEMI] = ACTIONS(8891),
    [aux_sym_where_condition_token1] = ACTIONS(8889),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8891),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8891),
    [anon_sym_LBRACK] = ACTIONS(8891),
    [aux_sym_basic_type_token6] = ACTIONS(8889),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8891),
    [aux_sym_addafter_modification_token1] = ACTIONS(8891),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8891),
    [aux_sym_modify_modification_token1] = ACTIONS(8891),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8891),
    [aux_sym_movelast_modification_token1] = ACTIONS(8891),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8891),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8891),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8891),
    [anon_sym_POUNDif] = ACTIONS(8891),
    [anon_sym_POUNDIF] = ACTIONS(8891),
    [anon_sym_POUNDIf] = ACTIONS(8891),
    [anon_sym_POUNDelif] = ACTIONS(8891),
    [anon_sym_POUNDELIF] = ACTIONS(8891),
    [anon_sym_POUNDElif] = ACTIONS(8891),
    [anon_sym_POUNDelse] = ACTIONS(8891),
    [anon_sym_POUNDELSE] = ACTIONS(8891),
    [anon_sym_POUNDElse] = ACTIONS(8891),
    [anon_sym_POUNDelse2] = ACTIONS(8891),
    [anon_sym_POUNDELSE2] = ACTIONS(8891),
    [anon_sym_POUNDElse2] = ACTIONS(8891),
    [anon_sym_POUNDendif] = ACTIONS(8891),
    [anon_sym_POUNDENDIF] = ACTIONS(8891),
    [anon_sym_POUNDEndif] = ACTIONS(8891),
    [anon_sym_POUNDendif2] = ACTIONS(8891),
    [anon_sym_POUNDENDIF2] = ACTIONS(8891),
    [anon_sym_POUNDEndif2] = ACTIONS(8891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(8891),
    [sym_trigger_keyword] = ACTIONS(8891),
    [sym_var_keyword] = ACTIONS(8891),
    [sym_local_keyword] = ACTIONS(8891),
    [sym_internal_keyword] = ACTIONS(8891),
    [sym_protected_keyword] = ACTIONS(8891),
    [sym_event_keyword] = ACTIONS(8891),
    [sym_fields_keyword] = ACTIONS(8891),
    [sym_keys_keyword] = ACTIONS(8891),
    [sym_fieldgroups_keyword] = ACTIONS(8891),
    [sym_actions_keyword] = ACTIONS(8891),
    [sym_layout_keyword] = ACTIONS(8891),
    [sym_area_keyword] = ACTIONS(8891),
    [sym_group_keyword] = ACTIONS(8891),
    [sym_repeater_keyword] = ACTIONS(8891),
    [sym_cuegroup_keyword] = ACTIONS(8891),
    [sym_fixed_keyword] = ACTIONS(8891),
    [sym_grid_keyword] = ACTIONS(8891),
    [sym_part_keyword] = ACTIONS(8891),
    [sym_systempart_keyword] = ACTIONS(8891),
    [sym_usercontrol_keyword] = ACTIONS(8891),
    [sym_dataset_keyword] = ACTIONS(8891),
    [sym_elements_keyword] = ACTIONS(8891),
    [sym_dataitem_keyword] = ACTIONS(8891),
    [sym_column_keyword] = ACTIONS(8891),
    [sym_filter_keyword] = ACTIONS(8891),
    [sym_labels_keyword] = ACTIONS(8891),
    [sym_rendering_keyword] = ACTIONS(8891),
    [sym_requestpage_keyword] = ACTIONS(8891),
    [sym_schema_keyword] = ACTIONS(8891),
    [sym_views_keyword] = ACTIONS(8891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8891),
    [sym_preproc_open] = ACTIONS(8891),
    [sym_preproc_close] = ACTIONS(8891),
  },
  [STATE(5265)] = {
    [anon_sym_SEMI] = ACTIONS(12941),
    [aux_sym_where_condition_token1] = ACTIONS(12943),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12941),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12941),
    [anon_sym_LBRACK] = ACTIONS(12941),
    [aux_sym_basic_type_token6] = ACTIONS(12943),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12941),
    [aux_sym_addafter_modification_token1] = ACTIONS(12941),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12941),
    [aux_sym_modify_modification_token1] = ACTIONS(12941),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12941),
    [aux_sym_movelast_modification_token1] = ACTIONS(12941),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12941),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12941),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12941),
    [anon_sym_POUNDif] = ACTIONS(12941),
    [anon_sym_POUNDIF] = ACTIONS(12941),
    [anon_sym_POUNDIf] = ACTIONS(12941),
    [anon_sym_POUNDelif] = ACTIONS(12941),
    [anon_sym_POUNDELIF] = ACTIONS(12941),
    [anon_sym_POUNDElif] = ACTIONS(12941),
    [anon_sym_POUNDelse] = ACTIONS(12941),
    [anon_sym_POUNDELSE] = ACTIONS(12941),
    [anon_sym_POUNDElse] = ACTIONS(12941),
    [anon_sym_POUNDelse2] = ACTIONS(12941),
    [anon_sym_POUNDELSE2] = ACTIONS(12941),
    [anon_sym_POUNDElse2] = ACTIONS(12941),
    [anon_sym_POUNDendif] = ACTIONS(12941),
    [anon_sym_POUNDENDIF] = ACTIONS(12941),
    [anon_sym_POUNDEndif] = ACTIONS(12941),
    [anon_sym_POUNDendif2] = ACTIONS(12941),
    [anon_sym_POUNDENDIF2] = ACTIONS(12941),
    [anon_sym_POUNDEndif2] = ACTIONS(12941),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12941),
    [sym_trigger_keyword] = ACTIONS(12941),
    [sym_var_keyword] = ACTIONS(12941),
    [sym_local_keyword] = ACTIONS(12941),
    [sym_internal_keyword] = ACTIONS(12941),
    [sym_protected_keyword] = ACTIONS(12941),
    [sym_event_keyword] = ACTIONS(12941),
    [sym_fields_keyword] = ACTIONS(12941),
    [sym_keys_keyword] = ACTIONS(12941),
    [sym_fieldgroups_keyword] = ACTIONS(12941),
    [sym_actions_keyword] = ACTIONS(12941),
    [sym_layout_keyword] = ACTIONS(12941),
    [sym_area_keyword] = ACTIONS(12941),
    [sym_group_keyword] = ACTIONS(12941),
    [sym_repeater_keyword] = ACTIONS(12941),
    [sym_cuegroup_keyword] = ACTIONS(12941),
    [sym_fixed_keyword] = ACTIONS(12941),
    [sym_grid_keyword] = ACTIONS(12941),
    [sym_part_keyword] = ACTIONS(12941),
    [sym_systempart_keyword] = ACTIONS(12941),
    [sym_usercontrol_keyword] = ACTIONS(12941),
    [sym_dataset_keyword] = ACTIONS(12941),
    [sym_elements_keyword] = ACTIONS(12941),
    [sym_dataitem_keyword] = ACTIONS(12941),
    [sym_column_keyword] = ACTIONS(12941),
    [sym_filter_keyword] = ACTIONS(12941),
    [sym_labels_keyword] = ACTIONS(12941),
    [sym_rendering_keyword] = ACTIONS(12941),
    [sym_requestpage_keyword] = ACTIONS(12941),
    [sym_schema_keyword] = ACTIONS(12941),
    [sym_views_keyword] = ACTIONS(12941),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12941),
    [sym_preproc_open] = ACTIONS(12941),
    [sym_preproc_close] = ACTIONS(12941),
  },
  [STATE(5266)] = {
    [anon_sym_SEMI] = ACTIONS(12945),
    [aux_sym_where_condition_token1] = ACTIONS(12947),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12945),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12945),
    [anon_sym_LBRACK] = ACTIONS(12945),
    [aux_sym_basic_type_token6] = ACTIONS(12947),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12945),
    [aux_sym_addafter_modification_token1] = ACTIONS(12945),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12945),
    [aux_sym_modify_modification_token1] = ACTIONS(12945),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12945),
    [aux_sym_movelast_modification_token1] = ACTIONS(12945),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12945),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12945),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12945),
    [anon_sym_POUNDif] = ACTIONS(12945),
    [anon_sym_POUNDIF] = ACTIONS(12945),
    [anon_sym_POUNDIf] = ACTIONS(12945),
    [anon_sym_POUNDelif] = ACTIONS(12945),
    [anon_sym_POUNDELIF] = ACTIONS(12945),
    [anon_sym_POUNDElif] = ACTIONS(12945),
    [anon_sym_POUNDelse] = ACTIONS(12945),
    [anon_sym_POUNDELSE] = ACTIONS(12945),
    [anon_sym_POUNDElse] = ACTIONS(12945),
    [anon_sym_POUNDelse2] = ACTIONS(12945),
    [anon_sym_POUNDELSE2] = ACTIONS(12945),
    [anon_sym_POUNDElse2] = ACTIONS(12945),
    [anon_sym_POUNDendif] = ACTIONS(12945),
    [anon_sym_POUNDENDIF] = ACTIONS(12945),
    [anon_sym_POUNDEndif] = ACTIONS(12945),
    [anon_sym_POUNDendif2] = ACTIONS(12945),
    [anon_sym_POUNDENDIF2] = ACTIONS(12945),
    [anon_sym_POUNDEndif2] = ACTIONS(12945),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12945),
    [sym_trigger_keyword] = ACTIONS(12945),
    [sym_var_keyword] = ACTIONS(12945),
    [sym_local_keyword] = ACTIONS(12945),
    [sym_internal_keyword] = ACTIONS(12945),
    [sym_protected_keyword] = ACTIONS(12945),
    [sym_event_keyword] = ACTIONS(12945),
    [sym_fields_keyword] = ACTIONS(12945),
    [sym_keys_keyword] = ACTIONS(12945),
    [sym_fieldgroups_keyword] = ACTIONS(12945),
    [sym_actions_keyword] = ACTIONS(12945),
    [sym_layout_keyword] = ACTIONS(12945),
    [sym_area_keyword] = ACTIONS(12945),
    [sym_group_keyword] = ACTIONS(12945),
    [sym_repeater_keyword] = ACTIONS(12945),
    [sym_cuegroup_keyword] = ACTIONS(12945),
    [sym_fixed_keyword] = ACTIONS(12945),
    [sym_grid_keyword] = ACTIONS(12945),
    [sym_part_keyword] = ACTIONS(12945),
    [sym_systempart_keyword] = ACTIONS(12945),
    [sym_usercontrol_keyword] = ACTIONS(12945),
    [sym_dataset_keyword] = ACTIONS(12945),
    [sym_elements_keyword] = ACTIONS(12945),
    [sym_dataitem_keyword] = ACTIONS(12945),
    [sym_column_keyword] = ACTIONS(12945),
    [sym_filter_keyword] = ACTIONS(12945),
    [sym_labels_keyword] = ACTIONS(12945),
    [sym_rendering_keyword] = ACTIONS(12945),
    [sym_requestpage_keyword] = ACTIONS(12945),
    [sym_schema_keyword] = ACTIONS(12945),
    [sym_views_keyword] = ACTIONS(12945),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12945),
    [sym_preproc_open] = ACTIONS(12945),
    [sym_preproc_close] = ACTIONS(12945),
  },
  [STATE(5267)] = {
    [anon_sym_SEMI] = ACTIONS(12949),
    [aux_sym_where_condition_token1] = ACTIONS(12951),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12949),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12949),
    [anon_sym_LBRACK] = ACTIONS(12949),
    [aux_sym_basic_type_token6] = ACTIONS(12951),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12949),
    [aux_sym_addafter_modification_token1] = ACTIONS(12949),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12949),
    [aux_sym_modify_modification_token1] = ACTIONS(12949),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12949),
    [aux_sym_movelast_modification_token1] = ACTIONS(12949),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12949),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12949),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12949),
    [anon_sym_POUNDif] = ACTIONS(12949),
    [anon_sym_POUNDIF] = ACTIONS(12949),
    [anon_sym_POUNDIf] = ACTIONS(12949),
    [anon_sym_POUNDelif] = ACTIONS(12949),
    [anon_sym_POUNDELIF] = ACTIONS(12949),
    [anon_sym_POUNDElif] = ACTIONS(12949),
    [anon_sym_POUNDelse] = ACTIONS(12949),
    [anon_sym_POUNDELSE] = ACTIONS(12949),
    [anon_sym_POUNDElse] = ACTIONS(12949),
    [anon_sym_POUNDelse2] = ACTIONS(12949),
    [anon_sym_POUNDELSE2] = ACTIONS(12949),
    [anon_sym_POUNDElse2] = ACTIONS(12949),
    [anon_sym_POUNDendif] = ACTIONS(12949),
    [anon_sym_POUNDENDIF] = ACTIONS(12949),
    [anon_sym_POUNDEndif] = ACTIONS(12949),
    [anon_sym_POUNDendif2] = ACTIONS(12949),
    [anon_sym_POUNDENDIF2] = ACTIONS(12949),
    [anon_sym_POUNDEndif2] = ACTIONS(12949),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12949),
    [sym_trigger_keyword] = ACTIONS(12949),
    [sym_var_keyword] = ACTIONS(12949),
    [sym_local_keyword] = ACTIONS(12949),
    [sym_internal_keyword] = ACTIONS(12949),
    [sym_protected_keyword] = ACTIONS(12949),
    [sym_event_keyword] = ACTIONS(12949),
    [sym_fields_keyword] = ACTIONS(12949),
    [sym_keys_keyword] = ACTIONS(12949),
    [sym_fieldgroups_keyword] = ACTIONS(12949),
    [sym_actions_keyword] = ACTIONS(12949),
    [sym_layout_keyword] = ACTIONS(12949),
    [sym_area_keyword] = ACTIONS(12949),
    [sym_group_keyword] = ACTIONS(12949),
    [sym_repeater_keyword] = ACTIONS(12949),
    [sym_cuegroup_keyword] = ACTIONS(12949),
    [sym_fixed_keyword] = ACTIONS(12949),
    [sym_grid_keyword] = ACTIONS(12949),
    [sym_part_keyword] = ACTIONS(12949),
    [sym_systempart_keyword] = ACTIONS(12949),
    [sym_usercontrol_keyword] = ACTIONS(12949),
    [sym_dataset_keyword] = ACTIONS(12949),
    [sym_elements_keyword] = ACTIONS(12949),
    [sym_dataitem_keyword] = ACTIONS(12949),
    [sym_column_keyword] = ACTIONS(12949),
    [sym_filter_keyword] = ACTIONS(12949),
    [sym_labels_keyword] = ACTIONS(12949),
    [sym_rendering_keyword] = ACTIONS(12949),
    [sym_requestpage_keyword] = ACTIONS(12949),
    [sym_schema_keyword] = ACTIONS(12949),
    [sym_views_keyword] = ACTIONS(12949),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12949),
    [sym_preproc_open] = ACTIONS(12949),
    [sym_preproc_close] = ACTIONS(12949),
  },
  [STATE(5268)] = {
    [anon_sym_SEMI] = ACTIONS(12953),
    [aux_sym_where_condition_token1] = ACTIONS(12951),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12949),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12949),
    [anon_sym_LBRACK] = ACTIONS(12949),
    [aux_sym_basic_type_token6] = ACTIONS(12951),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12949),
    [aux_sym_addafter_modification_token1] = ACTIONS(12949),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12949),
    [aux_sym_modify_modification_token1] = ACTIONS(12949),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12949),
    [aux_sym_movelast_modification_token1] = ACTIONS(12949),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12949),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12949),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12949),
    [anon_sym_POUNDif] = ACTIONS(12949),
    [anon_sym_POUNDIF] = ACTIONS(12949),
    [anon_sym_POUNDIf] = ACTIONS(12949),
    [anon_sym_POUNDelif] = ACTIONS(12949),
    [anon_sym_POUNDELIF] = ACTIONS(12949),
    [anon_sym_POUNDElif] = ACTIONS(12949),
    [anon_sym_POUNDelse] = ACTIONS(12949),
    [anon_sym_POUNDELSE] = ACTIONS(12949),
    [anon_sym_POUNDElse] = ACTIONS(12949),
    [anon_sym_POUNDelse2] = ACTIONS(12949),
    [anon_sym_POUNDELSE2] = ACTIONS(12949),
    [anon_sym_POUNDElse2] = ACTIONS(12949),
    [anon_sym_POUNDendif] = ACTIONS(12949),
    [anon_sym_POUNDENDIF] = ACTIONS(12949),
    [anon_sym_POUNDEndif] = ACTIONS(12949),
    [anon_sym_POUNDendif2] = ACTIONS(12949),
    [anon_sym_POUNDENDIF2] = ACTIONS(12949),
    [anon_sym_POUNDEndif2] = ACTIONS(12949),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12949),
    [sym_trigger_keyword] = ACTIONS(12949),
    [sym_var_keyword] = ACTIONS(12949),
    [sym_local_keyword] = ACTIONS(12949),
    [sym_internal_keyword] = ACTIONS(12949),
    [sym_protected_keyword] = ACTIONS(12949),
    [sym_event_keyword] = ACTIONS(12949),
    [sym_fields_keyword] = ACTIONS(12949),
    [sym_keys_keyword] = ACTIONS(12949),
    [sym_fieldgroups_keyword] = ACTIONS(12949),
    [sym_actions_keyword] = ACTIONS(12949),
    [sym_layout_keyword] = ACTIONS(12949),
    [sym_area_keyword] = ACTIONS(12949),
    [sym_group_keyword] = ACTIONS(12949),
    [sym_repeater_keyword] = ACTIONS(12949),
    [sym_cuegroup_keyword] = ACTIONS(12949),
    [sym_fixed_keyword] = ACTIONS(12949),
    [sym_grid_keyword] = ACTIONS(12949),
    [sym_part_keyword] = ACTIONS(12949),
    [sym_systempart_keyword] = ACTIONS(12949),
    [sym_usercontrol_keyword] = ACTIONS(12949),
    [sym_dataset_keyword] = ACTIONS(12949),
    [sym_elements_keyword] = ACTIONS(12949),
    [sym_dataitem_keyword] = ACTIONS(12949),
    [sym_column_keyword] = ACTIONS(12949),
    [sym_filter_keyword] = ACTIONS(12949),
    [sym_labels_keyword] = ACTIONS(12949),
    [sym_rendering_keyword] = ACTIONS(12949),
    [sym_requestpage_keyword] = ACTIONS(12949),
    [sym_schema_keyword] = ACTIONS(12949),
    [sym_views_keyword] = ACTIONS(12949),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12949),
    [sym_preproc_open] = ACTIONS(12949),
    [sym_preproc_close] = ACTIONS(12949),
  },
  [STATE(5269)] = {
    [anon_sym_SEMI] = ACTIONS(12833),
    [aux_sym_where_condition_token1] = ACTIONS(12835),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12833),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12833),
    [anon_sym_LBRACK] = ACTIONS(12833),
    [aux_sym_basic_type_token6] = ACTIONS(12835),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12833),
    [aux_sym_addafter_modification_token1] = ACTIONS(12833),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12833),
    [aux_sym_modify_modification_token1] = ACTIONS(12833),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12833),
    [aux_sym_movelast_modification_token1] = ACTIONS(12833),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12833),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12833),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12833),
    [anon_sym_POUNDif] = ACTIONS(12833),
    [anon_sym_POUNDIF] = ACTIONS(12833),
    [anon_sym_POUNDIf] = ACTIONS(12833),
    [anon_sym_POUNDelif] = ACTIONS(12833),
    [anon_sym_POUNDELIF] = ACTIONS(12833),
    [anon_sym_POUNDElif] = ACTIONS(12833),
    [anon_sym_POUNDelse] = ACTIONS(12833),
    [anon_sym_POUNDELSE] = ACTIONS(12833),
    [anon_sym_POUNDElse] = ACTIONS(12833),
    [anon_sym_POUNDelse2] = ACTIONS(12833),
    [anon_sym_POUNDELSE2] = ACTIONS(12833),
    [anon_sym_POUNDElse2] = ACTIONS(12833),
    [anon_sym_POUNDendif] = ACTIONS(12833),
    [anon_sym_POUNDENDIF] = ACTIONS(12833),
    [anon_sym_POUNDEndif] = ACTIONS(12833),
    [anon_sym_POUNDendif2] = ACTIONS(12833),
    [anon_sym_POUNDENDIF2] = ACTIONS(12833),
    [anon_sym_POUNDEndif2] = ACTIONS(12833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12833),
    [sym_trigger_keyword] = ACTIONS(12833),
    [sym_var_keyword] = ACTIONS(12833),
    [sym_local_keyword] = ACTIONS(12833),
    [sym_internal_keyword] = ACTIONS(12833),
    [sym_protected_keyword] = ACTIONS(12833),
    [sym_event_keyword] = ACTIONS(12833),
    [sym_fields_keyword] = ACTIONS(12833),
    [sym_keys_keyword] = ACTIONS(12833),
    [sym_fieldgroups_keyword] = ACTIONS(12833),
    [sym_actions_keyword] = ACTIONS(12833),
    [sym_layout_keyword] = ACTIONS(12833),
    [sym_area_keyword] = ACTIONS(12833),
    [sym_group_keyword] = ACTIONS(12833),
    [sym_repeater_keyword] = ACTIONS(12833),
    [sym_cuegroup_keyword] = ACTIONS(12833),
    [sym_fixed_keyword] = ACTIONS(12833),
    [sym_grid_keyword] = ACTIONS(12833),
    [sym_part_keyword] = ACTIONS(12833),
    [sym_systempart_keyword] = ACTIONS(12833),
    [sym_usercontrol_keyword] = ACTIONS(12833),
    [sym_dataset_keyword] = ACTIONS(12833),
    [sym_elements_keyword] = ACTIONS(12833),
    [sym_dataitem_keyword] = ACTIONS(12833),
    [sym_column_keyword] = ACTIONS(12833),
    [sym_filter_keyword] = ACTIONS(12833),
    [sym_labels_keyword] = ACTIONS(12833),
    [sym_rendering_keyword] = ACTIONS(12833),
    [sym_requestpage_keyword] = ACTIONS(12833),
    [sym_schema_keyword] = ACTIONS(12833),
    [sym_views_keyword] = ACTIONS(12833),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12833),
    [sym_preproc_open] = ACTIONS(12833),
    [sym_preproc_close] = ACTIONS(12833),
  },
  [STATE(5270)] = {
    [anon_sym_SEMI] = ACTIONS(12955),
    [aux_sym_where_condition_token1] = ACTIONS(12957),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12955),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12955),
    [anon_sym_LBRACK] = ACTIONS(12955),
    [aux_sym_basic_type_token6] = ACTIONS(12957),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12955),
    [aux_sym_addafter_modification_token1] = ACTIONS(12955),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12955),
    [aux_sym_modify_modification_token1] = ACTIONS(12955),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12955),
    [aux_sym_movelast_modification_token1] = ACTIONS(12955),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12955),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12955),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12955),
    [anon_sym_POUNDif] = ACTIONS(12955),
    [anon_sym_POUNDIF] = ACTIONS(12955),
    [anon_sym_POUNDIf] = ACTIONS(12955),
    [anon_sym_POUNDelif] = ACTIONS(12955),
    [anon_sym_POUNDELIF] = ACTIONS(12955),
    [anon_sym_POUNDElif] = ACTIONS(12955),
    [anon_sym_POUNDelse] = ACTIONS(12955),
    [anon_sym_POUNDELSE] = ACTIONS(12955),
    [anon_sym_POUNDElse] = ACTIONS(12955),
    [anon_sym_POUNDelse2] = ACTIONS(12955),
    [anon_sym_POUNDELSE2] = ACTIONS(12955),
    [anon_sym_POUNDElse2] = ACTIONS(12955),
    [anon_sym_POUNDendif] = ACTIONS(12955),
    [anon_sym_POUNDENDIF] = ACTIONS(12955),
    [anon_sym_POUNDEndif] = ACTIONS(12955),
    [anon_sym_POUNDendif2] = ACTIONS(12955),
    [anon_sym_POUNDENDIF2] = ACTIONS(12955),
    [anon_sym_POUNDEndif2] = ACTIONS(12955),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12955),
    [sym_trigger_keyword] = ACTIONS(12955),
    [sym_var_keyword] = ACTIONS(12955),
    [sym_local_keyword] = ACTIONS(12955),
    [sym_internal_keyword] = ACTIONS(12955),
    [sym_protected_keyword] = ACTIONS(12955),
    [sym_event_keyword] = ACTIONS(12955),
    [sym_fields_keyword] = ACTIONS(12955),
    [sym_keys_keyword] = ACTIONS(12955),
    [sym_fieldgroups_keyword] = ACTIONS(12955),
    [sym_actions_keyword] = ACTIONS(12955),
    [sym_layout_keyword] = ACTIONS(12955),
    [sym_area_keyword] = ACTIONS(12955),
    [sym_group_keyword] = ACTIONS(12955),
    [sym_repeater_keyword] = ACTIONS(12955),
    [sym_cuegroup_keyword] = ACTIONS(12955),
    [sym_fixed_keyword] = ACTIONS(12955),
    [sym_grid_keyword] = ACTIONS(12955),
    [sym_part_keyword] = ACTIONS(12955),
    [sym_systempart_keyword] = ACTIONS(12955),
    [sym_usercontrol_keyword] = ACTIONS(12955),
    [sym_dataset_keyword] = ACTIONS(12955),
    [sym_elements_keyword] = ACTIONS(12955),
    [sym_dataitem_keyword] = ACTIONS(12955),
    [sym_column_keyword] = ACTIONS(12955),
    [sym_filter_keyword] = ACTIONS(12955),
    [sym_labels_keyword] = ACTIONS(12955),
    [sym_rendering_keyword] = ACTIONS(12955),
    [sym_requestpage_keyword] = ACTIONS(12955),
    [sym_schema_keyword] = ACTIONS(12955),
    [sym_views_keyword] = ACTIONS(12955),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12955),
    [sym_preproc_open] = ACTIONS(12955),
    [sym_preproc_close] = ACTIONS(12955),
  },
  [STATE(5271)] = {
    [anon_sym_SEMI] = ACTIONS(12959),
    [aux_sym_where_condition_token1] = ACTIONS(12961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12959),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12959),
    [anon_sym_LBRACK] = ACTIONS(12959),
    [aux_sym_basic_type_token6] = ACTIONS(12961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12959),
    [aux_sym_addafter_modification_token1] = ACTIONS(12959),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12959),
    [aux_sym_modify_modification_token1] = ACTIONS(12959),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12959),
    [aux_sym_movelast_modification_token1] = ACTIONS(12959),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12959),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12959),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12959),
    [anon_sym_POUNDif] = ACTIONS(12959),
    [anon_sym_POUNDIF] = ACTIONS(12959),
    [anon_sym_POUNDIf] = ACTIONS(12959),
    [anon_sym_POUNDelif] = ACTIONS(12959),
    [anon_sym_POUNDELIF] = ACTIONS(12959),
    [anon_sym_POUNDElif] = ACTIONS(12959),
    [anon_sym_POUNDelse] = ACTIONS(12959),
    [anon_sym_POUNDELSE] = ACTIONS(12959),
    [anon_sym_POUNDElse] = ACTIONS(12959),
    [anon_sym_POUNDelse2] = ACTIONS(12959),
    [anon_sym_POUNDELSE2] = ACTIONS(12959),
    [anon_sym_POUNDElse2] = ACTIONS(12959),
    [anon_sym_POUNDendif] = ACTIONS(12959),
    [anon_sym_POUNDENDIF] = ACTIONS(12959),
    [anon_sym_POUNDEndif] = ACTIONS(12959),
    [anon_sym_POUNDendif2] = ACTIONS(12959),
    [anon_sym_POUNDENDIF2] = ACTIONS(12959),
    [anon_sym_POUNDEndif2] = ACTIONS(12959),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12959),
    [sym_trigger_keyword] = ACTIONS(12959),
    [sym_var_keyword] = ACTIONS(12959),
    [sym_local_keyword] = ACTIONS(12959),
    [sym_internal_keyword] = ACTIONS(12959),
    [sym_protected_keyword] = ACTIONS(12959),
    [sym_event_keyword] = ACTIONS(12959),
    [sym_fields_keyword] = ACTIONS(12959),
    [sym_keys_keyword] = ACTIONS(12959),
    [sym_fieldgroups_keyword] = ACTIONS(12959),
    [sym_actions_keyword] = ACTIONS(12959),
    [sym_layout_keyword] = ACTIONS(12959),
    [sym_area_keyword] = ACTIONS(12959),
    [sym_group_keyword] = ACTIONS(12959),
    [sym_repeater_keyword] = ACTIONS(12959),
    [sym_cuegroup_keyword] = ACTIONS(12959),
    [sym_fixed_keyword] = ACTIONS(12959),
    [sym_grid_keyword] = ACTIONS(12959),
    [sym_part_keyword] = ACTIONS(12959),
    [sym_systempart_keyword] = ACTIONS(12959),
    [sym_usercontrol_keyword] = ACTIONS(12959),
    [sym_dataset_keyword] = ACTIONS(12959),
    [sym_elements_keyword] = ACTIONS(12959),
    [sym_dataitem_keyword] = ACTIONS(12959),
    [sym_column_keyword] = ACTIONS(12959),
    [sym_filter_keyword] = ACTIONS(12959),
    [sym_labels_keyword] = ACTIONS(12959),
    [sym_rendering_keyword] = ACTIONS(12959),
    [sym_requestpage_keyword] = ACTIONS(12959),
    [sym_schema_keyword] = ACTIONS(12959),
    [sym_views_keyword] = ACTIONS(12959),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12959),
    [sym_preproc_open] = ACTIONS(12959),
    [sym_preproc_close] = ACTIONS(12959),
  },
  [STATE(5272)] = {
    [anon_sym_SEMI] = ACTIONS(12963),
    [aux_sym_where_condition_token1] = ACTIONS(12965),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12963),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12963),
    [anon_sym_LBRACK] = ACTIONS(12963),
    [aux_sym_basic_type_token6] = ACTIONS(12965),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12963),
    [aux_sym_addafter_modification_token1] = ACTIONS(12963),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12963),
    [aux_sym_modify_modification_token1] = ACTIONS(12963),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12963),
    [aux_sym_movelast_modification_token1] = ACTIONS(12963),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12963),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12963),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12963),
    [anon_sym_POUNDif] = ACTIONS(12963),
    [anon_sym_POUNDIF] = ACTIONS(12963),
    [anon_sym_POUNDIf] = ACTIONS(12963),
    [anon_sym_POUNDelif] = ACTIONS(12963),
    [anon_sym_POUNDELIF] = ACTIONS(12963),
    [anon_sym_POUNDElif] = ACTIONS(12963),
    [anon_sym_POUNDelse] = ACTIONS(12963),
    [anon_sym_POUNDELSE] = ACTIONS(12963),
    [anon_sym_POUNDElse] = ACTIONS(12963),
    [anon_sym_POUNDelse2] = ACTIONS(12963),
    [anon_sym_POUNDELSE2] = ACTIONS(12963),
    [anon_sym_POUNDElse2] = ACTIONS(12963),
    [anon_sym_POUNDendif] = ACTIONS(12963),
    [anon_sym_POUNDENDIF] = ACTIONS(12963),
    [anon_sym_POUNDEndif] = ACTIONS(12963),
    [anon_sym_POUNDendif2] = ACTIONS(12963),
    [anon_sym_POUNDENDIF2] = ACTIONS(12963),
    [anon_sym_POUNDEndif2] = ACTIONS(12963),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12963),
    [sym_trigger_keyword] = ACTIONS(12963),
    [sym_var_keyword] = ACTIONS(12963),
    [sym_local_keyword] = ACTIONS(12963),
    [sym_internal_keyword] = ACTIONS(12963),
    [sym_protected_keyword] = ACTIONS(12963),
    [sym_event_keyword] = ACTIONS(12963),
    [sym_fields_keyword] = ACTIONS(12963),
    [sym_keys_keyword] = ACTIONS(12963),
    [sym_fieldgroups_keyword] = ACTIONS(12963),
    [sym_actions_keyword] = ACTIONS(12963),
    [sym_layout_keyword] = ACTIONS(12963),
    [sym_area_keyword] = ACTIONS(12963),
    [sym_group_keyword] = ACTIONS(12963),
    [sym_repeater_keyword] = ACTIONS(12963),
    [sym_cuegroup_keyword] = ACTIONS(12963),
    [sym_fixed_keyword] = ACTIONS(12963),
    [sym_grid_keyword] = ACTIONS(12963),
    [sym_part_keyword] = ACTIONS(12963),
    [sym_systempart_keyword] = ACTIONS(12963),
    [sym_usercontrol_keyword] = ACTIONS(12963),
    [sym_dataset_keyword] = ACTIONS(12963),
    [sym_elements_keyword] = ACTIONS(12963),
    [sym_dataitem_keyword] = ACTIONS(12963),
    [sym_column_keyword] = ACTIONS(12963),
    [sym_filter_keyword] = ACTIONS(12963),
    [sym_labels_keyword] = ACTIONS(12963),
    [sym_rendering_keyword] = ACTIONS(12963),
    [sym_requestpage_keyword] = ACTIONS(12963),
    [sym_schema_keyword] = ACTIONS(12963),
    [sym_views_keyword] = ACTIONS(12963),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12963),
    [sym_preproc_open] = ACTIONS(12963),
    [sym_preproc_close] = ACTIONS(12963),
  },
  [STATE(5273)] = {
    [anon_sym_SEMI] = ACTIONS(12967),
    [aux_sym_where_condition_token1] = ACTIONS(12969),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12967),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12967),
    [anon_sym_LBRACK] = ACTIONS(12967),
    [aux_sym_basic_type_token6] = ACTIONS(12969),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12967),
    [aux_sym_addafter_modification_token1] = ACTIONS(12967),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12967),
    [aux_sym_modify_modification_token1] = ACTIONS(12967),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12967),
    [aux_sym_movelast_modification_token1] = ACTIONS(12967),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12967),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12967),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12967),
    [anon_sym_POUNDif] = ACTIONS(12967),
    [anon_sym_POUNDIF] = ACTIONS(12967),
    [anon_sym_POUNDIf] = ACTIONS(12967),
    [anon_sym_POUNDelif] = ACTIONS(12967),
    [anon_sym_POUNDELIF] = ACTIONS(12967),
    [anon_sym_POUNDElif] = ACTIONS(12967),
    [anon_sym_POUNDelse] = ACTIONS(12967),
    [anon_sym_POUNDELSE] = ACTIONS(12967),
    [anon_sym_POUNDElse] = ACTIONS(12967),
    [anon_sym_POUNDelse2] = ACTIONS(12967),
    [anon_sym_POUNDELSE2] = ACTIONS(12967),
    [anon_sym_POUNDElse2] = ACTIONS(12967),
    [anon_sym_POUNDendif] = ACTIONS(12967),
    [anon_sym_POUNDENDIF] = ACTIONS(12967),
    [anon_sym_POUNDEndif] = ACTIONS(12967),
    [anon_sym_POUNDendif2] = ACTIONS(12967),
    [anon_sym_POUNDENDIF2] = ACTIONS(12967),
    [anon_sym_POUNDEndif2] = ACTIONS(12967),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12967),
    [sym_trigger_keyword] = ACTIONS(12967),
    [sym_var_keyword] = ACTIONS(12967),
    [sym_local_keyword] = ACTIONS(12967),
    [sym_internal_keyword] = ACTIONS(12967),
    [sym_protected_keyword] = ACTIONS(12967),
    [sym_event_keyword] = ACTIONS(12967),
    [sym_fields_keyword] = ACTIONS(12967),
    [sym_keys_keyword] = ACTIONS(12967),
    [sym_fieldgroups_keyword] = ACTIONS(12967),
    [sym_actions_keyword] = ACTIONS(12967),
    [sym_layout_keyword] = ACTIONS(12967),
    [sym_area_keyword] = ACTIONS(12967),
    [sym_group_keyword] = ACTIONS(12967),
    [sym_repeater_keyword] = ACTIONS(12967),
    [sym_cuegroup_keyword] = ACTIONS(12967),
    [sym_fixed_keyword] = ACTIONS(12967),
    [sym_grid_keyword] = ACTIONS(12967),
    [sym_part_keyword] = ACTIONS(12967),
    [sym_systempart_keyword] = ACTIONS(12967),
    [sym_usercontrol_keyword] = ACTIONS(12967),
    [sym_dataset_keyword] = ACTIONS(12967),
    [sym_elements_keyword] = ACTIONS(12967),
    [sym_dataitem_keyword] = ACTIONS(12967),
    [sym_column_keyword] = ACTIONS(12967),
    [sym_filter_keyword] = ACTIONS(12967),
    [sym_labels_keyword] = ACTIONS(12967),
    [sym_rendering_keyword] = ACTIONS(12967),
    [sym_requestpage_keyword] = ACTIONS(12967),
    [sym_schema_keyword] = ACTIONS(12967),
    [sym_views_keyword] = ACTIONS(12967),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12967),
    [sym_preproc_open] = ACTIONS(12967),
    [sym_preproc_close] = ACTIONS(12967),
  },
  [STATE(5274)] = {
    [anon_sym_SEMI] = ACTIONS(12971),
    [aux_sym_where_condition_token1] = ACTIONS(12973),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12971),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12971),
    [anon_sym_LBRACK] = ACTIONS(12971),
    [aux_sym_basic_type_token6] = ACTIONS(12973),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12971),
    [aux_sym_addafter_modification_token1] = ACTIONS(12971),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12971),
    [aux_sym_modify_modification_token1] = ACTIONS(12971),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12971),
    [aux_sym_movelast_modification_token1] = ACTIONS(12971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12971),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12971),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12971),
    [anon_sym_POUNDif] = ACTIONS(12971),
    [anon_sym_POUNDIF] = ACTIONS(12971),
    [anon_sym_POUNDIf] = ACTIONS(12971),
    [anon_sym_POUNDelif] = ACTIONS(12971),
    [anon_sym_POUNDELIF] = ACTIONS(12971),
    [anon_sym_POUNDElif] = ACTIONS(12971),
    [anon_sym_POUNDelse] = ACTIONS(12971),
    [anon_sym_POUNDELSE] = ACTIONS(12971),
    [anon_sym_POUNDElse] = ACTIONS(12971),
    [anon_sym_POUNDelse2] = ACTIONS(12971),
    [anon_sym_POUNDELSE2] = ACTIONS(12971),
    [anon_sym_POUNDElse2] = ACTIONS(12971),
    [anon_sym_POUNDendif] = ACTIONS(12971),
    [anon_sym_POUNDENDIF] = ACTIONS(12971),
    [anon_sym_POUNDEndif] = ACTIONS(12971),
    [anon_sym_POUNDendif2] = ACTIONS(12971),
    [anon_sym_POUNDENDIF2] = ACTIONS(12971),
    [anon_sym_POUNDEndif2] = ACTIONS(12971),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12971),
    [sym_trigger_keyword] = ACTIONS(12971),
    [sym_var_keyword] = ACTIONS(12971),
    [sym_local_keyword] = ACTIONS(12971),
    [sym_internal_keyword] = ACTIONS(12971),
    [sym_protected_keyword] = ACTIONS(12971),
    [sym_event_keyword] = ACTIONS(12971),
    [sym_fields_keyword] = ACTIONS(12971),
    [sym_keys_keyword] = ACTIONS(12971),
    [sym_fieldgroups_keyword] = ACTIONS(12971),
    [sym_actions_keyword] = ACTIONS(12971),
    [sym_layout_keyword] = ACTIONS(12971),
    [sym_area_keyword] = ACTIONS(12971),
    [sym_group_keyword] = ACTIONS(12971),
    [sym_repeater_keyword] = ACTIONS(12971),
    [sym_cuegroup_keyword] = ACTIONS(12971),
    [sym_fixed_keyword] = ACTIONS(12971),
    [sym_grid_keyword] = ACTIONS(12971),
    [sym_part_keyword] = ACTIONS(12971),
    [sym_systempart_keyword] = ACTIONS(12971),
    [sym_usercontrol_keyword] = ACTIONS(12971),
    [sym_dataset_keyword] = ACTIONS(12971),
    [sym_elements_keyword] = ACTIONS(12971),
    [sym_dataitem_keyword] = ACTIONS(12971),
    [sym_column_keyword] = ACTIONS(12971),
    [sym_filter_keyword] = ACTIONS(12971),
    [sym_labels_keyword] = ACTIONS(12971),
    [sym_rendering_keyword] = ACTIONS(12971),
    [sym_requestpage_keyword] = ACTIONS(12971),
    [sym_schema_keyword] = ACTIONS(12971),
    [sym_views_keyword] = ACTIONS(12971),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12971),
    [sym_preproc_open] = ACTIONS(12971),
    [sym_preproc_close] = ACTIONS(12971),
  },
  [STATE(5275)] = {
    [anon_sym_SEMI] = ACTIONS(12971),
    [aux_sym_where_condition_token1] = ACTIONS(12973),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12971),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12971),
    [anon_sym_LBRACK] = ACTIONS(12971),
    [aux_sym_basic_type_token6] = ACTIONS(12973),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12971),
    [aux_sym_addafter_modification_token1] = ACTIONS(12971),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12971),
    [aux_sym_modify_modification_token1] = ACTIONS(12971),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12971),
    [aux_sym_movelast_modification_token1] = ACTIONS(12971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12971),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12971),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12971),
    [anon_sym_POUNDif] = ACTIONS(12971),
    [anon_sym_POUNDIF] = ACTIONS(12971),
    [anon_sym_POUNDIf] = ACTIONS(12971),
    [anon_sym_POUNDelif] = ACTIONS(12971),
    [anon_sym_POUNDELIF] = ACTIONS(12971),
    [anon_sym_POUNDElif] = ACTIONS(12971),
    [anon_sym_POUNDelse] = ACTIONS(12971),
    [anon_sym_POUNDELSE] = ACTIONS(12971),
    [anon_sym_POUNDElse] = ACTIONS(12971),
    [anon_sym_POUNDelse2] = ACTIONS(12971),
    [anon_sym_POUNDELSE2] = ACTIONS(12971),
    [anon_sym_POUNDElse2] = ACTIONS(12971),
    [anon_sym_POUNDendif] = ACTIONS(12971),
    [anon_sym_POUNDENDIF] = ACTIONS(12971),
    [anon_sym_POUNDEndif] = ACTIONS(12971),
    [anon_sym_POUNDendif2] = ACTIONS(12971),
    [anon_sym_POUNDENDIF2] = ACTIONS(12971),
    [anon_sym_POUNDEndif2] = ACTIONS(12971),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12971),
    [sym_trigger_keyword] = ACTIONS(12971),
    [sym_var_keyword] = ACTIONS(12971),
    [sym_local_keyword] = ACTIONS(12971),
    [sym_internal_keyword] = ACTIONS(12971),
    [sym_protected_keyword] = ACTIONS(12971),
    [sym_event_keyword] = ACTIONS(12971),
    [sym_fields_keyword] = ACTIONS(12971),
    [sym_keys_keyword] = ACTIONS(12971),
    [sym_fieldgroups_keyword] = ACTIONS(12971),
    [sym_actions_keyword] = ACTIONS(12971),
    [sym_layout_keyword] = ACTIONS(12971),
    [sym_area_keyword] = ACTIONS(12971),
    [sym_group_keyword] = ACTIONS(12971),
    [sym_repeater_keyword] = ACTIONS(12971),
    [sym_cuegroup_keyword] = ACTIONS(12971),
    [sym_fixed_keyword] = ACTIONS(12971),
    [sym_grid_keyword] = ACTIONS(12971),
    [sym_part_keyword] = ACTIONS(12971),
    [sym_systempart_keyword] = ACTIONS(12971),
    [sym_usercontrol_keyword] = ACTIONS(12971),
    [sym_dataset_keyword] = ACTIONS(12971),
    [sym_elements_keyword] = ACTIONS(12971),
    [sym_dataitem_keyword] = ACTIONS(12971),
    [sym_column_keyword] = ACTIONS(12971),
    [sym_filter_keyword] = ACTIONS(12971),
    [sym_labels_keyword] = ACTIONS(12971),
    [sym_rendering_keyword] = ACTIONS(12971),
    [sym_requestpage_keyword] = ACTIONS(12971),
    [sym_schema_keyword] = ACTIONS(12971),
    [sym_views_keyword] = ACTIONS(12971),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12971),
    [sym_preproc_open] = ACTIONS(12971),
    [sym_preproc_close] = ACTIONS(12971),
  },
  [STATE(5276)] = {
    [anon_sym_SEMI] = ACTIONS(12971),
    [aux_sym_where_condition_token1] = ACTIONS(12973),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12971),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12971),
    [anon_sym_LBRACK] = ACTIONS(12971),
    [aux_sym_basic_type_token6] = ACTIONS(12973),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12971),
    [aux_sym_addafter_modification_token1] = ACTIONS(12971),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12971),
    [aux_sym_modify_modification_token1] = ACTIONS(12971),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12971),
    [aux_sym_movelast_modification_token1] = ACTIONS(12971),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12971),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12971),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12971),
    [anon_sym_POUNDif] = ACTIONS(12971),
    [anon_sym_POUNDIF] = ACTIONS(12971),
    [anon_sym_POUNDIf] = ACTIONS(12971),
    [anon_sym_POUNDelif] = ACTIONS(12971),
    [anon_sym_POUNDELIF] = ACTIONS(12971),
    [anon_sym_POUNDElif] = ACTIONS(12971),
    [anon_sym_POUNDelse] = ACTIONS(12971),
    [anon_sym_POUNDELSE] = ACTIONS(12971),
    [anon_sym_POUNDElse] = ACTIONS(12971),
    [anon_sym_POUNDelse2] = ACTIONS(12971),
    [anon_sym_POUNDELSE2] = ACTIONS(12971),
    [anon_sym_POUNDElse2] = ACTIONS(12971),
    [anon_sym_POUNDendif] = ACTIONS(12971),
    [anon_sym_POUNDENDIF] = ACTIONS(12971),
    [anon_sym_POUNDEndif] = ACTIONS(12971),
    [anon_sym_POUNDendif2] = ACTIONS(12971),
    [anon_sym_POUNDENDIF2] = ACTIONS(12971),
    [anon_sym_POUNDEndif2] = ACTIONS(12971),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12971),
    [sym_trigger_keyword] = ACTIONS(12971),
    [sym_var_keyword] = ACTIONS(12971),
    [sym_local_keyword] = ACTIONS(12971),
    [sym_internal_keyword] = ACTIONS(12971),
    [sym_protected_keyword] = ACTIONS(12971),
    [sym_event_keyword] = ACTIONS(12971),
    [sym_fields_keyword] = ACTIONS(12971),
    [sym_keys_keyword] = ACTIONS(12971),
    [sym_fieldgroups_keyword] = ACTIONS(12971),
    [sym_actions_keyword] = ACTIONS(12971),
    [sym_layout_keyword] = ACTIONS(12971),
    [sym_area_keyword] = ACTIONS(12971),
    [sym_group_keyword] = ACTIONS(12971),
    [sym_repeater_keyword] = ACTIONS(12971),
    [sym_cuegroup_keyword] = ACTIONS(12971),
    [sym_fixed_keyword] = ACTIONS(12971),
    [sym_grid_keyword] = ACTIONS(12971),
    [sym_part_keyword] = ACTIONS(12971),
    [sym_systempart_keyword] = ACTIONS(12971),
    [sym_usercontrol_keyword] = ACTIONS(12971),
    [sym_dataset_keyword] = ACTIONS(12971),
    [sym_elements_keyword] = ACTIONS(12971),
    [sym_dataitem_keyword] = ACTIONS(12971),
    [sym_column_keyword] = ACTIONS(12971),
    [sym_filter_keyword] = ACTIONS(12971),
    [sym_labels_keyword] = ACTIONS(12971),
    [sym_rendering_keyword] = ACTIONS(12971),
    [sym_requestpage_keyword] = ACTIONS(12971),
    [sym_schema_keyword] = ACTIONS(12971),
    [sym_views_keyword] = ACTIONS(12971),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12971),
    [sym_preproc_open] = ACTIONS(12971),
    [sym_preproc_close] = ACTIONS(12971),
  },
  [STATE(5277)] = {
    [anon_sym_SEMI] = ACTIONS(12975),
    [aux_sym_where_condition_token1] = ACTIONS(12977),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12975),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12975),
    [anon_sym_LBRACK] = ACTIONS(12975),
    [aux_sym_basic_type_token6] = ACTIONS(12977),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12975),
    [aux_sym_addafter_modification_token1] = ACTIONS(12975),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12975),
    [aux_sym_modify_modification_token1] = ACTIONS(12975),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12975),
    [aux_sym_movelast_modification_token1] = ACTIONS(12975),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12975),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12975),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12975),
    [anon_sym_POUNDif] = ACTIONS(12975),
    [anon_sym_POUNDIF] = ACTIONS(12975),
    [anon_sym_POUNDIf] = ACTIONS(12975),
    [anon_sym_POUNDelif] = ACTIONS(12975),
    [anon_sym_POUNDELIF] = ACTIONS(12975),
    [anon_sym_POUNDElif] = ACTIONS(12975),
    [anon_sym_POUNDelse] = ACTIONS(12975),
    [anon_sym_POUNDELSE] = ACTIONS(12975),
    [anon_sym_POUNDElse] = ACTIONS(12975),
    [anon_sym_POUNDelse2] = ACTIONS(12975),
    [anon_sym_POUNDELSE2] = ACTIONS(12975),
    [anon_sym_POUNDElse2] = ACTIONS(12975),
    [anon_sym_POUNDendif] = ACTIONS(12975),
    [anon_sym_POUNDENDIF] = ACTIONS(12975),
    [anon_sym_POUNDEndif] = ACTIONS(12975),
    [anon_sym_POUNDendif2] = ACTIONS(12975),
    [anon_sym_POUNDENDIF2] = ACTIONS(12975),
    [anon_sym_POUNDEndif2] = ACTIONS(12975),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12975),
    [sym_trigger_keyword] = ACTIONS(12975),
    [sym_var_keyword] = ACTIONS(12975),
    [sym_local_keyword] = ACTIONS(12975),
    [sym_internal_keyword] = ACTIONS(12975),
    [sym_protected_keyword] = ACTIONS(12975),
    [sym_event_keyword] = ACTIONS(12975),
    [sym_fields_keyword] = ACTIONS(12975),
    [sym_keys_keyword] = ACTIONS(12975),
    [sym_fieldgroups_keyword] = ACTIONS(12975),
    [sym_actions_keyword] = ACTIONS(12975),
    [sym_layout_keyword] = ACTIONS(12975),
    [sym_area_keyword] = ACTIONS(12975),
    [sym_group_keyword] = ACTIONS(12975),
    [sym_repeater_keyword] = ACTIONS(12975),
    [sym_cuegroup_keyword] = ACTIONS(12975),
    [sym_fixed_keyword] = ACTIONS(12975),
    [sym_grid_keyword] = ACTIONS(12975),
    [sym_part_keyword] = ACTIONS(12975),
    [sym_systempart_keyword] = ACTIONS(12975),
    [sym_usercontrol_keyword] = ACTIONS(12975),
    [sym_dataset_keyword] = ACTIONS(12975),
    [sym_elements_keyword] = ACTIONS(12975),
    [sym_dataitem_keyword] = ACTIONS(12975),
    [sym_column_keyword] = ACTIONS(12975),
    [sym_filter_keyword] = ACTIONS(12975),
    [sym_labels_keyword] = ACTIONS(12975),
    [sym_rendering_keyword] = ACTIONS(12975),
    [sym_requestpage_keyword] = ACTIONS(12975),
    [sym_schema_keyword] = ACTIONS(12975),
    [sym_views_keyword] = ACTIONS(12975),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12975),
    [sym_preproc_open] = ACTIONS(12975),
    [sym_preproc_close] = ACTIONS(12975),
  },
  [STATE(5278)] = {
    [anon_sym_SEMI] = ACTIONS(12979),
    [aux_sym_where_condition_token1] = ACTIONS(12981),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12979),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12979),
    [anon_sym_LBRACK] = ACTIONS(12979),
    [aux_sym_basic_type_token6] = ACTIONS(12981),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12979),
    [aux_sym_addafter_modification_token1] = ACTIONS(12979),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12979),
    [aux_sym_modify_modification_token1] = ACTIONS(12979),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12979),
    [aux_sym_movelast_modification_token1] = ACTIONS(12979),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12979),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12979),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12979),
    [anon_sym_POUNDif] = ACTIONS(12979),
    [anon_sym_POUNDIF] = ACTIONS(12979),
    [anon_sym_POUNDIf] = ACTIONS(12979),
    [anon_sym_POUNDelif] = ACTIONS(12979),
    [anon_sym_POUNDELIF] = ACTIONS(12979),
    [anon_sym_POUNDElif] = ACTIONS(12979),
    [anon_sym_POUNDelse] = ACTIONS(12979),
    [anon_sym_POUNDELSE] = ACTIONS(12979),
    [anon_sym_POUNDElse] = ACTIONS(12979),
    [anon_sym_POUNDelse2] = ACTIONS(12979),
    [anon_sym_POUNDELSE2] = ACTIONS(12979),
    [anon_sym_POUNDElse2] = ACTIONS(12979),
    [anon_sym_POUNDendif] = ACTIONS(12979),
    [anon_sym_POUNDENDIF] = ACTIONS(12979),
    [anon_sym_POUNDEndif] = ACTIONS(12979),
    [anon_sym_POUNDendif2] = ACTIONS(12979),
    [anon_sym_POUNDENDIF2] = ACTIONS(12979),
    [anon_sym_POUNDEndif2] = ACTIONS(12979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12979),
    [sym_trigger_keyword] = ACTIONS(12979),
    [sym_var_keyword] = ACTIONS(12979),
    [sym_local_keyword] = ACTIONS(12979),
    [sym_internal_keyword] = ACTIONS(12979),
    [sym_protected_keyword] = ACTIONS(12979),
    [sym_event_keyword] = ACTIONS(12979),
    [sym_fields_keyword] = ACTIONS(12979),
    [sym_keys_keyword] = ACTIONS(12979),
    [sym_fieldgroups_keyword] = ACTIONS(12979),
    [sym_actions_keyword] = ACTIONS(12979),
    [sym_layout_keyword] = ACTIONS(12979),
    [sym_area_keyword] = ACTIONS(12979),
    [sym_group_keyword] = ACTIONS(12979),
    [sym_repeater_keyword] = ACTIONS(12979),
    [sym_cuegroup_keyword] = ACTIONS(12979),
    [sym_fixed_keyword] = ACTIONS(12979),
    [sym_grid_keyword] = ACTIONS(12979),
    [sym_part_keyword] = ACTIONS(12979),
    [sym_systempart_keyword] = ACTIONS(12979),
    [sym_usercontrol_keyword] = ACTIONS(12979),
    [sym_dataset_keyword] = ACTIONS(12979),
    [sym_elements_keyword] = ACTIONS(12979),
    [sym_dataitem_keyword] = ACTIONS(12979),
    [sym_column_keyword] = ACTIONS(12979),
    [sym_filter_keyword] = ACTIONS(12979),
    [sym_labels_keyword] = ACTIONS(12979),
    [sym_rendering_keyword] = ACTIONS(12979),
    [sym_requestpage_keyword] = ACTIONS(12979),
    [sym_schema_keyword] = ACTIONS(12979),
    [sym_views_keyword] = ACTIONS(12979),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12979),
    [sym_preproc_open] = ACTIONS(12979),
    [sym_preproc_close] = ACTIONS(12979),
  },
  [STATE(5279)] = {
    [anon_sym_SEMI] = ACTIONS(12983),
    [aux_sym_where_condition_token1] = ACTIONS(12985),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12983),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12983),
    [anon_sym_LBRACK] = ACTIONS(12983),
    [aux_sym_basic_type_token6] = ACTIONS(12985),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12983),
    [aux_sym_addafter_modification_token1] = ACTIONS(12983),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12983),
    [aux_sym_modify_modification_token1] = ACTIONS(12983),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12983),
    [aux_sym_movelast_modification_token1] = ACTIONS(12983),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12983),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12983),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12983),
    [anon_sym_POUNDif] = ACTIONS(12983),
    [anon_sym_POUNDIF] = ACTIONS(12983),
    [anon_sym_POUNDIf] = ACTIONS(12983),
    [anon_sym_POUNDelif] = ACTIONS(12983),
    [anon_sym_POUNDELIF] = ACTIONS(12983),
    [anon_sym_POUNDElif] = ACTIONS(12983),
    [anon_sym_POUNDelse] = ACTIONS(12983),
    [anon_sym_POUNDELSE] = ACTIONS(12983),
    [anon_sym_POUNDElse] = ACTIONS(12983),
    [anon_sym_POUNDelse2] = ACTIONS(12983),
    [anon_sym_POUNDELSE2] = ACTIONS(12983),
    [anon_sym_POUNDElse2] = ACTIONS(12983),
    [anon_sym_POUNDendif] = ACTIONS(12983),
    [anon_sym_POUNDENDIF] = ACTIONS(12983),
    [anon_sym_POUNDEndif] = ACTIONS(12983),
    [anon_sym_POUNDendif2] = ACTIONS(12983),
    [anon_sym_POUNDENDIF2] = ACTIONS(12983),
    [anon_sym_POUNDEndif2] = ACTIONS(12983),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12983),
    [sym_trigger_keyword] = ACTIONS(12983),
    [sym_var_keyword] = ACTIONS(12983),
    [sym_local_keyword] = ACTIONS(12983),
    [sym_internal_keyword] = ACTIONS(12983),
    [sym_protected_keyword] = ACTIONS(12983),
    [sym_event_keyword] = ACTIONS(12983),
    [sym_fields_keyword] = ACTIONS(12983),
    [sym_keys_keyword] = ACTIONS(12983),
    [sym_fieldgroups_keyword] = ACTIONS(12983),
    [sym_actions_keyword] = ACTIONS(12983),
    [sym_layout_keyword] = ACTIONS(12983),
    [sym_area_keyword] = ACTIONS(12983),
    [sym_group_keyword] = ACTIONS(12983),
    [sym_repeater_keyword] = ACTIONS(12983),
    [sym_cuegroup_keyword] = ACTIONS(12983),
    [sym_fixed_keyword] = ACTIONS(12983),
    [sym_grid_keyword] = ACTIONS(12983),
    [sym_part_keyword] = ACTIONS(12983),
    [sym_systempart_keyword] = ACTIONS(12983),
    [sym_usercontrol_keyword] = ACTIONS(12983),
    [sym_dataset_keyword] = ACTIONS(12983),
    [sym_elements_keyword] = ACTIONS(12983),
    [sym_dataitem_keyword] = ACTIONS(12983),
    [sym_column_keyword] = ACTIONS(12983),
    [sym_filter_keyword] = ACTIONS(12983),
    [sym_labels_keyword] = ACTIONS(12983),
    [sym_rendering_keyword] = ACTIONS(12983),
    [sym_requestpage_keyword] = ACTIONS(12983),
    [sym_schema_keyword] = ACTIONS(12983),
    [sym_views_keyword] = ACTIONS(12983),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12983),
    [sym_preproc_open] = ACTIONS(12983),
    [sym_preproc_close] = ACTIONS(12983),
  },
  [STATE(5280)] = {
    [anon_sym_SEMI] = ACTIONS(12979),
    [aux_sym_where_condition_token1] = ACTIONS(12981),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12979),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12979),
    [anon_sym_LBRACK] = ACTIONS(12979),
    [aux_sym_basic_type_token6] = ACTIONS(12981),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12979),
    [aux_sym_addafter_modification_token1] = ACTIONS(12979),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12979),
    [aux_sym_modify_modification_token1] = ACTIONS(12979),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12979),
    [aux_sym_movelast_modification_token1] = ACTIONS(12979),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12979),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12979),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12979),
    [anon_sym_POUNDif] = ACTIONS(12979),
    [anon_sym_POUNDIF] = ACTIONS(12979),
    [anon_sym_POUNDIf] = ACTIONS(12979),
    [anon_sym_POUNDelif] = ACTIONS(12979),
    [anon_sym_POUNDELIF] = ACTIONS(12979),
    [anon_sym_POUNDElif] = ACTIONS(12979),
    [anon_sym_POUNDelse] = ACTIONS(12979),
    [anon_sym_POUNDELSE] = ACTIONS(12979),
    [anon_sym_POUNDElse] = ACTIONS(12979),
    [anon_sym_POUNDelse2] = ACTIONS(12979),
    [anon_sym_POUNDELSE2] = ACTIONS(12979),
    [anon_sym_POUNDElse2] = ACTIONS(12979),
    [anon_sym_POUNDendif] = ACTIONS(12979),
    [anon_sym_POUNDENDIF] = ACTIONS(12979),
    [anon_sym_POUNDEndif] = ACTIONS(12979),
    [anon_sym_POUNDendif2] = ACTIONS(12979),
    [anon_sym_POUNDENDIF2] = ACTIONS(12979),
    [anon_sym_POUNDEndif2] = ACTIONS(12979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12979),
    [sym_trigger_keyword] = ACTIONS(12979),
    [sym_var_keyword] = ACTIONS(12979),
    [sym_local_keyword] = ACTIONS(12979),
    [sym_internal_keyword] = ACTIONS(12979),
    [sym_protected_keyword] = ACTIONS(12979),
    [sym_event_keyword] = ACTIONS(12979),
    [sym_fields_keyword] = ACTIONS(12979),
    [sym_keys_keyword] = ACTIONS(12979),
    [sym_fieldgroups_keyword] = ACTIONS(12979),
    [sym_actions_keyword] = ACTIONS(12979),
    [sym_layout_keyword] = ACTIONS(12979),
    [sym_area_keyword] = ACTIONS(12979),
    [sym_group_keyword] = ACTIONS(12979),
    [sym_repeater_keyword] = ACTIONS(12979),
    [sym_cuegroup_keyword] = ACTIONS(12979),
    [sym_fixed_keyword] = ACTIONS(12979),
    [sym_grid_keyword] = ACTIONS(12979),
    [sym_part_keyword] = ACTIONS(12979),
    [sym_systempart_keyword] = ACTIONS(12979),
    [sym_usercontrol_keyword] = ACTIONS(12979),
    [sym_dataset_keyword] = ACTIONS(12979),
    [sym_elements_keyword] = ACTIONS(12979),
    [sym_dataitem_keyword] = ACTIONS(12979),
    [sym_column_keyword] = ACTIONS(12979),
    [sym_filter_keyword] = ACTIONS(12979),
    [sym_labels_keyword] = ACTIONS(12979),
    [sym_rendering_keyword] = ACTIONS(12979),
    [sym_requestpage_keyword] = ACTIONS(12979),
    [sym_schema_keyword] = ACTIONS(12979),
    [sym_views_keyword] = ACTIONS(12979),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12979),
    [sym_preproc_open] = ACTIONS(12979),
    [sym_preproc_close] = ACTIONS(12979),
  },
  [STATE(5281)] = {
    [anon_sym_SEMI] = ACTIONS(12979),
    [aux_sym_where_condition_token1] = ACTIONS(12981),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12979),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12979),
    [anon_sym_LBRACK] = ACTIONS(12979),
    [aux_sym_basic_type_token6] = ACTIONS(12981),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12979),
    [aux_sym_addafter_modification_token1] = ACTIONS(12979),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12979),
    [aux_sym_modify_modification_token1] = ACTIONS(12979),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12979),
    [aux_sym_movelast_modification_token1] = ACTIONS(12979),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12979),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12979),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12979),
    [anon_sym_POUNDif] = ACTIONS(12979),
    [anon_sym_POUNDIF] = ACTIONS(12979),
    [anon_sym_POUNDIf] = ACTIONS(12979),
    [anon_sym_POUNDelif] = ACTIONS(12979),
    [anon_sym_POUNDELIF] = ACTIONS(12979),
    [anon_sym_POUNDElif] = ACTIONS(12979),
    [anon_sym_POUNDelse] = ACTIONS(12979),
    [anon_sym_POUNDELSE] = ACTIONS(12979),
    [anon_sym_POUNDElse] = ACTIONS(12979),
    [anon_sym_POUNDelse2] = ACTIONS(12979),
    [anon_sym_POUNDELSE2] = ACTIONS(12979),
    [anon_sym_POUNDElse2] = ACTIONS(12979),
    [anon_sym_POUNDendif] = ACTIONS(12979),
    [anon_sym_POUNDENDIF] = ACTIONS(12979),
    [anon_sym_POUNDEndif] = ACTIONS(12979),
    [anon_sym_POUNDendif2] = ACTIONS(12979),
    [anon_sym_POUNDENDIF2] = ACTIONS(12979),
    [anon_sym_POUNDEndif2] = ACTIONS(12979),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12979),
    [sym_trigger_keyword] = ACTIONS(12979),
    [sym_var_keyword] = ACTIONS(12979),
    [sym_local_keyword] = ACTIONS(12979),
    [sym_internal_keyword] = ACTIONS(12979),
    [sym_protected_keyword] = ACTIONS(12979),
    [sym_event_keyword] = ACTIONS(12979),
    [sym_fields_keyword] = ACTIONS(12979),
    [sym_keys_keyword] = ACTIONS(12979),
    [sym_fieldgroups_keyword] = ACTIONS(12979),
    [sym_actions_keyword] = ACTIONS(12979),
    [sym_layout_keyword] = ACTIONS(12979),
    [sym_area_keyword] = ACTIONS(12979),
    [sym_group_keyword] = ACTIONS(12979),
    [sym_repeater_keyword] = ACTIONS(12979),
    [sym_cuegroup_keyword] = ACTIONS(12979),
    [sym_fixed_keyword] = ACTIONS(12979),
    [sym_grid_keyword] = ACTIONS(12979),
    [sym_part_keyword] = ACTIONS(12979),
    [sym_systempart_keyword] = ACTIONS(12979),
    [sym_usercontrol_keyword] = ACTIONS(12979),
    [sym_dataset_keyword] = ACTIONS(12979),
    [sym_elements_keyword] = ACTIONS(12979),
    [sym_dataitem_keyword] = ACTIONS(12979),
    [sym_column_keyword] = ACTIONS(12979),
    [sym_filter_keyword] = ACTIONS(12979),
    [sym_labels_keyword] = ACTIONS(12979),
    [sym_rendering_keyword] = ACTIONS(12979),
    [sym_requestpage_keyword] = ACTIONS(12979),
    [sym_schema_keyword] = ACTIONS(12979),
    [sym_views_keyword] = ACTIONS(12979),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12979),
    [sym_preproc_open] = ACTIONS(12979),
    [sym_preproc_close] = ACTIONS(12979),
  },
  [STATE(5282)] = {
    [anon_sym_SEMI] = ACTIONS(12983),
    [aux_sym_where_condition_token1] = ACTIONS(12985),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12983),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12983),
    [anon_sym_LBRACK] = ACTIONS(12983),
    [aux_sym_basic_type_token6] = ACTIONS(12985),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12983),
    [aux_sym_addafter_modification_token1] = ACTIONS(12983),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12983),
    [aux_sym_modify_modification_token1] = ACTIONS(12983),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12983),
    [aux_sym_movelast_modification_token1] = ACTIONS(12983),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12983),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12983),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12983),
    [anon_sym_POUNDif] = ACTIONS(12983),
    [anon_sym_POUNDIF] = ACTIONS(12983),
    [anon_sym_POUNDIf] = ACTIONS(12983),
    [anon_sym_POUNDelif] = ACTIONS(12983),
    [anon_sym_POUNDELIF] = ACTIONS(12983),
    [anon_sym_POUNDElif] = ACTIONS(12983),
    [anon_sym_POUNDelse] = ACTIONS(12983),
    [anon_sym_POUNDELSE] = ACTIONS(12983),
    [anon_sym_POUNDElse] = ACTIONS(12983),
    [anon_sym_POUNDelse2] = ACTIONS(12983),
    [anon_sym_POUNDELSE2] = ACTIONS(12983),
    [anon_sym_POUNDElse2] = ACTIONS(12983),
    [anon_sym_POUNDendif] = ACTIONS(12983),
    [anon_sym_POUNDENDIF] = ACTIONS(12983),
    [anon_sym_POUNDEndif] = ACTIONS(12983),
    [anon_sym_POUNDendif2] = ACTIONS(12983),
    [anon_sym_POUNDENDIF2] = ACTIONS(12983),
    [anon_sym_POUNDEndif2] = ACTIONS(12983),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12983),
    [sym_trigger_keyword] = ACTIONS(12983),
    [sym_var_keyword] = ACTIONS(12983),
    [sym_local_keyword] = ACTIONS(12983),
    [sym_internal_keyword] = ACTIONS(12983),
    [sym_protected_keyword] = ACTIONS(12983),
    [sym_event_keyword] = ACTIONS(12983),
    [sym_fields_keyword] = ACTIONS(12983),
    [sym_keys_keyword] = ACTIONS(12983),
    [sym_fieldgroups_keyword] = ACTIONS(12983),
    [sym_actions_keyword] = ACTIONS(12983),
    [sym_layout_keyword] = ACTIONS(12983),
    [sym_area_keyword] = ACTIONS(12983),
    [sym_group_keyword] = ACTIONS(12983),
    [sym_repeater_keyword] = ACTIONS(12983),
    [sym_cuegroup_keyword] = ACTIONS(12983),
    [sym_fixed_keyword] = ACTIONS(12983),
    [sym_grid_keyword] = ACTIONS(12983),
    [sym_part_keyword] = ACTIONS(12983),
    [sym_systempart_keyword] = ACTIONS(12983),
    [sym_usercontrol_keyword] = ACTIONS(12983),
    [sym_dataset_keyword] = ACTIONS(12983),
    [sym_elements_keyword] = ACTIONS(12983),
    [sym_dataitem_keyword] = ACTIONS(12983),
    [sym_column_keyword] = ACTIONS(12983),
    [sym_filter_keyword] = ACTIONS(12983),
    [sym_labels_keyword] = ACTIONS(12983),
    [sym_rendering_keyword] = ACTIONS(12983),
    [sym_requestpage_keyword] = ACTIONS(12983),
    [sym_schema_keyword] = ACTIONS(12983),
    [sym_views_keyword] = ACTIONS(12983),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12983),
    [sym_preproc_open] = ACTIONS(12983),
    [sym_preproc_close] = ACTIONS(12983),
  },
  [STATE(5283)] = {
    [anon_sym_SEMI] = ACTIONS(12987),
    [aux_sym_where_condition_token1] = ACTIONS(12989),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12987),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12987),
    [anon_sym_LBRACK] = ACTIONS(12987),
    [aux_sym_basic_type_token6] = ACTIONS(12989),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12987),
    [aux_sym_addafter_modification_token1] = ACTIONS(12987),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12987),
    [aux_sym_modify_modification_token1] = ACTIONS(12987),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12987),
    [aux_sym_movelast_modification_token1] = ACTIONS(12987),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12987),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12987),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12987),
    [anon_sym_POUNDif] = ACTIONS(12987),
    [anon_sym_POUNDIF] = ACTIONS(12987),
    [anon_sym_POUNDIf] = ACTIONS(12987),
    [anon_sym_POUNDelif] = ACTIONS(12987),
    [anon_sym_POUNDELIF] = ACTIONS(12987),
    [anon_sym_POUNDElif] = ACTIONS(12987),
    [anon_sym_POUNDelse] = ACTIONS(12987),
    [anon_sym_POUNDELSE] = ACTIONS(12987),
    [anon_sym_POUNDElse] = ACTIONS(12987),
    [anon_sym_POUNDelse2] = ACTIONS(12987),
    [anon_sym_POUNDELSE2] = ACTIONS(12987),
    [anon_sym_POUNDElse2] = ACTIONS(12987),
    [anon_sym_POUNDendif] = ACTIONS(12987),
    [anon_sym_POUNDENDIF] = ACTIONS(12987),
    [anon_sym_POUNDEndif] = ACTIONS(12987),
    [anon_sym_POUNDendif2] = ACTIONS(12987),
    [anon_sym_POUNDENDIF2] = ACTIONS(12987),
    [anon_sym_POUNDEndif2] = ACTIONS(12987),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12987),
    [sym_trigger_keyword] = ACTIONS(12987),
    [sym_var_keyword] = ACTIONS(12987),
    [sym_local_keyword] = ACTIONS(12987),
    [sym_internal_keyword] = ACTIONS(12987),
    [sym_protected_keyword] = ACTIONS(12987),
    [sym_event_keyword] = ACTIONS(12987),
    [sym_fields_keyword] = ACTIONS(12987),
    [sym_keys_keyword] = ACTIONS(12987),
    [sym_fieldgroups_keyword] = ACTIONS(12987),
    [sym_actions_keyword] = ACTIONS(12987),
    [sym_layout_keyword] = ACTIONS(12987),
    [sym_area_keyword] = ACTIONS(12987),
    [sym_group_keyword] = ACTIONS(12987),
    [sym_repeater_keyword] = ACTIONS(12987),
    [sym_cuegroup_keyword] = ACTIONS(12987),
    [sym_fixed_keyword] = ACTIONS(12987),
    [sym_grid_keyword] = ACTIONS(12987),
    [sym_part_keyword] = ACTIONS(12987),
    [sym_systempart_keyword] = ACTIONS(12987),
    [sym_usercontrol_keyword] = ACTIONS(12987),
    [sym_dataset_keyword] = ACTIONS(12987),
    [sym_elements_keyword] = ACTIONS(12987),
    [sym_dataitem_keyword] = ACTIONS(12987),
    [sym_column_keyword] = ACTIONS(12987),
    [sym_filter_keyword] = ACTIONS(12987),
    [sym_labels_keyword] = ACTIONS(12987),
    [sym_rendering_keyword] = ACTIONS(12987),
    [sym_requestpage_keyword] = ACTIONS(12987),
    [sym_schema_keyword] = ACTIONS(12987),
    [sym_views_keyword] = ACTIONS(12987),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12987),
    [sym_preproc_open] = ACTIONS(12987),
    [sym_preproc_close] = ACTIONS(12987),
  },
  [STATE(5284)] = {
    [anon_sym_SEMI] = ACTIONS(12987),
    [aux_sym_where_condition_token1] = ACTIONS(12989),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12987),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12987),
    [anon_sym_LBRACK] = ACTIONS(12987),
    [aux_sym_basic_type_token6] = ACTIONS(12989),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12987),
    [aux_sym_addafter_modification_token1] = ACTIONS(12987),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12987),
    [aux_sym_modify_modification_token1] = ACTIONS(12987),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12987),
    [aux_sym_movelast_modification_token1] = ACTIONS(12987),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12987),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12987),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12987),
    [anon_sym_POUNDif] = ACTIONS(12987),
    [anon_sym_POUNDIF] = ACTIONS(12987),
    [anon_sym_POUNDIf] = ACTIONS(12987),
    [anon_sym_POUNDelif] = ACTIONS(12987),
    [anon_sym_POUNDELIF] = ACTIONS(12987),
    [anon_sym_POUNDElif] = ACTIONS(12987),
    [anon_sym_POUNDelse] = ACTIONS(12987),
    [anon_sym_POUNDELSE] = ACTIONS(12987),
    [anon_sym_POUNDElse] = ACTIONS(12987),
    [anon_sym_POUNDelse2] = ACTIONS(12987),
    [anon_sym_POUNDELSE2] = ACTIONS(12987),
    [anon_sym_POUNDElse2] = ACTIONS(12987),
    [anon_sym_POUNDendif] = ACTIONS(12987),
    [anon_sym_POUNDENDIF] = ACTIONS(12987),
    [anon_sym_POUNDEndif] = ACTIONS(12987),
    [anon_sym_POUNDendif2] = ACTIONS(12987),
    [anon_sym_POUNDENDIF2] = ACTIONS(12987),
    [anon_sym_POUNDEndif2] = ACTIONS(12987),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12987),
    [sym_trigger_keyword] = ACTIONS(12987),
    [sym_var_keyword] = ACTIONS(12987),
    [sym_local_keyword] = ACTIONS(12987),
    [sym_internal_keyword] = ACTIONS(12987),
    [sym_protected_keyword] = ACTIONS(12987),
    [sym_event_keyword] = ACTIONS(12987),
    [sym_fields_keyword] = ACTIONS(12987),
    [sym_keys_keyword] = ACTIONS(12987),
    [sym_fieldgroups_keyword] = ACTIONS(12987),
    [sym_actions_keyword] = ACTIONS(12987),
    [sym_layout_keyword] = ACTIONS(12987),
    [sym_area_keyword] = ACTIONS(12987),
    [sym_group_keyword] = ACTIONS(12987),
    [sym_repeater_keyword] = ACTIONS(12987),
    [sym_cuegroup_keyword] = ACTIONS(12987),
    [sym_fixed_keyword] = ACTIONS(12987),
    [sym_grid_keyword] = ACTIONS(12987),
    [sym_part_keyword] = ACTIONS(12987),
    [sym_systempart_keyword] = ACTIONS(12987),
    [sym_usercontrol_keyword] = ACTIONS(12987),
    [sym_dataset_keyword] = ACTIONS(12987),
    [sym_elements_keyword] = ACTIONS(12987),
    [sym_dataitem_keyword] = ACTIONS(12987),
    [sym_column_keyword] = ACTIONS(12987),
    [sym_filter_keyword] = ACTIONS(12987),
    [sym_labels_keyword] = ACTIONS(12987),
    [sym_rendering_keyword] = ACTIONS(12987),
    [sym_requestpage_keyword] = ACTIONS(12987),
    [sym_schema_keyword] = ACTIONS(12987),
    [sym_views_keyword] = ACTIONS(12987),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12987),
    [sym_preproc_open] = ACTIONS(12987),
    [sym_preproc_close] = ACTIONS(12987),
  },
  [STATE(5285)] = {
    [anon_sym_SEMI] = ACTIONS(12833),
    [aux_sym_where_condition_token1] = ACTIONS(12835),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12833),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12833),
    [anon_sym_LBRACK] = ACTIONS(12833),
    [aux_sym_basic_type_token6] = ACTIONS(12835),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12833),
    [aux_sym_addafter_modification_token1] = ACTIONS(12833),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12833),
    [aux_sym_modify_modification_token1] = ACTIONS(12833),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12833),
    [aux_sym_movelast_modification_token1] = ACTIONS(12833),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12833),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12833),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12833),
    [anon_sym_POUNDif] = ACTIONS(12833),
    [anon_sym_POUNDIF] = ACTIONS(12833),
    [anon_sym_POUNDIf] = ACTIONS(12833),
    [anon_sym_POUNDelif] = ACTIONS(12833),
    [anon_sym_POUNDELIF] = ACTIONS(12833),
    [anon_sym_POUNDElif] = ACTIONS(12833),
    [anon_sym_POUNDelse] = ACTIONS(12833),
    [anon_sym_POUNDELSE] = ACTIONS(12833),
    [anon_sym_POUNDElse] = ACTIONS(12833),
    [anon_sym_POUNDelse2] = ACTIONS(12833),
    [anon_sym_POUNDELSE2] = ACTIONS(12833),
    [anon_sym_POUNDElse2] = ACTIONS(12833),
    [anon_sym_POUNDendif] = ACTIONS(12833),
    [anon_sym_POUNDENDIF] = ACTIONS(12833),
    [anon_sym_POUNDEndif] = ACTIONS(12833),
    [anon_sym_POUNDendif2] = ACTIONS(12833),
    [anon_sym_POUNDENDIF2] = ACTIONS(12833),
    [anon_sym_POUNDEndif2] = ACTIONS(12833),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12833),
    [sym_trigger_keyword] = ACTIONS(12833),
    [sym_var_keyword] = ACTIONS(12833),
    [sym_local_keyword] = ACTIONS(12833),
    [sym_internal_keyword] = ACTIONS(12833),
    [sym_protected_keyword] = ACTIONS(12833),
    [sym_event_keyword] = ACTIONS(12833),
    [sym_fields_keyword] = ACTIONS(12833),
    [sym_keys_keyword] = ACTIONS(12833),
    [sym_fieldgroups_keyword] = ACTIONS(12833),
    [sym_actions_keyword] = ACTIONS(12833),
    [sym_layout_keyword] = ACTIONS(12833),
    [sym_area_keyword] = ACTIONS(12833),
    [sym_group_keyword] = ACTIONS(12833),
    [sym_repeater_keyword] = ACTIONS(12833),
    [sym_cuegroup_keyword] = ACTIONS(12833),
    [sym_fixed_keyword] = ACTIONS(12833),
    [sym_grid_keyword] = ACTIONS(12833),
    [sym_part_keyword] = ACTIONS(12833),
    [sym_systempart_keyword] = ACTIONS(12833),
    [sym_usercontrol_keyword] = ACTIONS(12833),
    [sym_dataset_keyword] = ACTIONS(12833),
    [sym_elements_keyword] = ACTIONS(12833),
    [sym_dataitem_keyword] = ACTIONS(12833),
    [sym_column_keyword] = ACTIONS(12833),
    [sym_filter_keyword] = ACTIONS(12833),
    [sym_labels_keyword] = ACTIONS(12833),
    [sym_rendering_keyword] = ACTIONS(12833),
    [sym_requestpage_keyword] = ACTIONS(12833),
    [sym_schema_keyword] = ACTIONS(12833),
    [sym_views_keyword] = ACTIONS(12833),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12833),
    [sym_preproc_open] = ACTIONS(12833),
    [sym_preproc_close] = ACTIONS(12833),
  },
  [STATE(5286)] = {
    [anon_sym_SEMI] = ACTIONS(12991),
    [aux_sym_where_condition_token1] = ACTIONS(12993),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12991),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12991),
    [anon_sym_LBRACK] = ACTIONS(12991),
    [aux_sym_basic_type_token6] = ACTIONS(12993),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12991),
    [aux_sym_addafter_modification_token1] = ACTIONS(12991),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12991),
    [aux_sym_modify_modification_token1] = ACTIONS(12991),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12991),
    [aux_sym_movelast_modification_token1] = ACTIONS(12991),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12991),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12991),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12991),
    [anon_sym_POUNDif] = ACTIONS(12991),
    [anon_sym_POUNDIF] = ACTIONS(12991),
    [anon_sym_POUNDIf] = ACTIONS(12991),
    [anon_sym_POUNDelif] = ACTIONS(12991),
    [anon_sym_POUNDELIF] = ACTIONS(12991),
    [anon_sym_POUNDElif] = ACTIONS(12991),
    [anon_sym_POUNDelse] = ACTIONS(12991),
    [anon_sym_POUNDELSE] = ACTIONS(12991),
    [anon_sym_POUNDElse] = ACTIONS(12991),
    [anon_sym_POUNDelse2] = ACTIONS(12991),
    [anon_sym_POUNDELSE2] = ACTIONS(12991),
    [anon_sym_POUNDElse2] = ACTIONS(12991),
    [anon_sym_POUNDendif] = ACTIONS(12991),
    [anon_sym_POUNDENDIF] = ACTIONS(12991),
    [anon_sym_POUNDEndif] = ACTIONS(12991),
    [anon_sym_POUNDendif2] = ACTIONS(12991),
    [anon_sym_POUNDENDIF2] = ACTIONS(12991),
    [anon_sym_POUNDEndif2] = ACTIONS(12991),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12991),
    [sym_trigger_keyword] = ACTIONS(12991),
    [sym_var_keyword] = ACTIONS(12991),
    [sym_local_keyword] = ACTIONS(12991),
    [sym_internal_keyword] = ACTIONS(12991),
    [sym_protected_keyword] = ACTIONS(12991),
    [sym_event_keyword] = ACTIONS(12991),
    [sym_fields_keyword] = ACTIONS(12991),
    [sym_keys_keyword] = ACTIONS(12991),
    [sym_fieldgroups_keyword] = ACTIONS(12991),
    [sym_actions_keyword] = ACTIONS(12991),
    [sym_layout_keyword] = ACTIONS(12991),
    [sym_area_keyword] = ACTIONS(12991),
    [sym_group_keyword] = ACTIONS(12991),
    [sym_repeater_keyword] = ACTIONS(12991),
    [sym_cuegroup_keyword] = ACTIONS(12991),
    [sym_fixed_keyword] = ACTIONS(12991),
    [sym_grid_keyword] = ACTIONS(12991),
    [sym_part_keyword] = ACTIONS(12991),
    [sym_systempart_keyword] = ACTIONS(12991),
    [sym_usercontrol_keyword] = ACTIONS(12991),
    [sym_dataset_keyword] = ACTIONS(12991),
    [sym_elements_keyword] = ACTIONS(12991),
    [sym_dataitem_keyword] = ACTIONS(12991),
    [sym_column_keyword] = ACTIONS(12991),
    [sym_filter_keyword] = ACTIONS(12991),
    [sym_labels_keyword] = ACTIONS(12991),
    [sym_rendering_keyword] = ACTIONS(12991),
    [sym_requestpage_keyword] = ACTIONS(12991),
    [sym_schema_keyword] = ACTIONS(12991),
    [sym_views_keyword] = ACTIONS(12991),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12991),
    [sym_preproc_open] = ACTIONS(12991),
    [sym_preproc_close] = ACTIONS(12991),
  },
  [STATE(5287)] = {
    [anon_sym_SEMI] = ACTIONS(12995),
    [aux_sym_where_condition_token1] = ACTIONS(12997),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12995),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12995),
    [anon_sym_LBRACK] = ACTIONS(12995),
    [aux_sym_basic_type_token6] = ACTIONS(12997),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12995),
    [aux_sym_addafter_modification_token1] = ACTIONS(12995),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12995),
    [aux_sym_modify_modification_token1] = ACTIONS(12995),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12995),
    [aux_sym_movelast_modification_token1] = ACTIONS(12995),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12995),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12995),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12995),
    [anon_sym_POUNDif] = ACTIONS(12995),
    [anon_sym_POUNDIF] = ACTIONS(12995),
    [anon_sym_POUNDIf] = ACTIONS(12995),
    [anon_sym_POUNDelif] = ACTIONS(12995),
    [anon_sym_POUNDELIF] = ACTIONS(12995),
    [anon_sym_POUNDElif] = ACTIONS(12995),
    [anon_sym_POUNDelse] = ACTIONS(12995),
    [anon_sym_POUNDELSE] = ACTIONS(12995),
    [anon_sym_POUNDElse] = ACTIONS(12995),
    [anon_sym_POUNDelse2] = ACTIONS(12995),
    [anon_sym_POUNDELSE2] = ACTIONS(12995),
    [anon_sym_POUNDElse2] = ACTIONS(12995),
    [anon_sym_POUNDendif] = ACTIONS(12995),
    [anon_sym_POUNDENDIF] = ACTIONS(12995),
    [anon_sym_POUNDEndif] = ACTIONS(12995),
    [anon_sym_POUNDendif2] = ACTIONS(12995),
    [anon_sym_POUNDENDIF2] = ACTIONS(12995),
    [anon_sym_POUNDEndif2] = ACTIONS(12995),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12995),
    [sym_trigger_keyword] = ACTIONS(12995),
    [sym_var_keyword] = ACTIONS(12995),
    [sym_local_keyword] = ACTIONS(12995),
    [sym_internal_keyword] = ACTIONS(12995),
    [sym_protected_keyword] = ACTIONS(12995),
    [sym_event_keyword] = ACTIONS(12995),
    [sym_fields_keyword] = ACTIONS(12995),
    [sym_keys_keyword] = ACTIONS(12995),
    [sym_fieldgroups_keyword] = ACTIONS(12995),
    [sym_actions_keyword] = ACTIONS(12995),
    [sym_layout_keyword] = ACTIONS(12995),
    [sym_area_keyword] = ACTIONS(12995),
    [sym_group_keyword] = ACTIONS(12995),
    [sym_repeater_keyword] = ACTIONS(12995),
    [sym_cuegroup_keyword] = ACTIONS(12995),
    [sym_fixed_keyword] = ACTIONS(12995),
    [sym_grid_keyword] = ACTIONS(12995),
    [sym_part_keyword] = ACTIONS(12995),
    [sym_systempart_keyword] = ACTIONS(12995),
    [sym_usercontrol_keyword] = ACTIONS(12995),
    [sym_dataset_keyword] = ACTIONS(12995),
    [sym_elements_keyword] = ACTIONS(12995),
    [sym_dataitem_keyword] = ACTIONS(12995),
    [sym_column_keyword] = ACTIONS(12995),
    [sym_filter_keyword] = ACTIONS(12995),
    [sym_labels_keyword] = ACTIONS(12995),
    [sym_rendering_keyword] = ACTIONS(12995),
    [sym_requestpage_keyword] = ACTIONS(12995),
    [sym_schema_keyword] = ACTIONS(12995),
    [sym_views_keyword] = ACTIONS(12995),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12995),
    [sym_preproc_open] = ACTIONS(12995),
    [sym_preproc_close] = ACTIONS(12995),
  },
  [STATE(5288)] = {
    [anon_sym_SEMI] = ACTIONS(12991),
    [aux_sym_where_condition_token1] = ACTIONS(12993),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12991),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12991),
    [anon_sym_LBRACK] = ACTIONS(12991),
    [aux_sym_basic_type_token6] = ACTIONS(12993),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12991),
    [aux_sym_addafter_modification_token1] = ACTIONS(12991),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12991),
    [aux_sym_modify_modification_token1] = ACTIONS(12991),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12991),
    [aux_sym_movelast_modification_token1] = ACTIONS(12991),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12991),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12991),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12991),
    [anon_sym_POUNDif] = ACTIONS(12991),
    [anon_sym_POUNDIF] = ACTIONS(12991),
    [anon_sym_POUNDIf] = ACTIONS(12991),
    [anon_sym_POUNDelif] = ACTIONS(12991),
    [anon_sym_POUNDELIF] = ACTIONS(12991),
    [anon_sym_POUNDElif] = ACTIONS(12991),
    [anon_sym_POUNDelse] = ACTIONS(12991),
    [anon_sym_POUNDELSE] = ACTIONS(12991),
    [anon_sym_POUNDElse] = ACTIONS(12991),
    [anon_sym_POUNDelse2] = ACTIONS(12991),
    [anon_sym_POUNDELSE2] = ACTIONS(12991),
    [anon_sym_POUNDElse2] = ACTIONS(12991),
    [anon_sym_POUNDendif] = ACTIONS(12991),
    [anon_sym_POUNDENDIF] = ACTIONS(12991),
    [anon_sym_POUNDEndif] = ACTIONS(12991),
    [anon_sym_POUNDendif2] = ACTIONS(12991),
    [anon_sym_POUNDENDIF2] = ACTIONS(12991),
    [anon_sym_POUNDEndif2] = ACTIONS(12991),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12991),
    [sym_trigger_keyword] = ACTIONS(12991),
    [sym_var_keyword] = ACTIONS(12991),
    [sym_local_keyword] = ACTIONS(12991),
    [sym_internal_keyword] = ACTIONS(12991),
    [sym_protected_keyword] = ACTIONS(12991),
    [sym_event_keyword] = ACTIONS(12991),
    [sym_fields_keyword] = ACTIONS(12991),
    [sym_keys_keyword] = ACTIONS(12991),
    [sym_fieldgroups_keyword] = ACTIONS(12991),
    [sym_actions_keyword] = ACTIONS(12991),
    [sym_layout_keyword] = ACTIONS(12991),
    [sym_area_keyword] = ACTIONS(12991),
    [sym_group_keyword] = ACTIONS(12991),
    [sym_repeater_keyword] = ACTIONS(12991),
    [sym_cuegroup_keyword] = ACTIONS(12991),
    [sym_fixed_keyword] = ACTIONS(12991),
    [sym_grid_keyword] = ACTIONS(12991),
    [sym_part_keyword] = ACTIONS(12991),
    [sym_systempart_keyword] = ACTIONS(12991),
    [sym_usercontrol_keyword] = ACTIONS(12991),
    [sym_dataset_keyword] = ACTIONS(12991),
    [sym_elements_keyword] = ACTIONS(12991),
    [sym_dataitem_keyword] = ACTIONS(12991),
    [sym_column_keyword] = ACTIONS(12991),
    [sym_filter_keyword] = ACTIONS(12991),
    [sym_labels_keyword] = ACTIONS(12991),
    [sym_rendering_keyword] = ACTIONS(12991),
    [sym_requestpage_keyword] = ACTIONS(12991),
    [sym_schema_keyword] = ACTIONS(12991),
    [sym_views_keyword] = ACTIONS(12991),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12991),
    [sym_preproc_open] = ACTIONS(12991),
    [sym_preproc_close] = ACTIONS(12991),
  },
  [STATE(5289)] = {
    [anon_sym_SEMI] = ACTIONS(12991),
    [aux_sym_where_condition_token1] = ACTIONS(12993),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12991),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12991),
    [anon_sym_LBRACK] = ACTIONS(12991),
    [aux_sym_basic_type_token6] = ACTIONS(12993),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12991),
    [aux_sym_addafter_modification_token1] = ACTIONS(12991),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12991),
    [aux_sym_modify_modification_token1] = ACTIONS(12991),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12991),
    [aux_sym_movelast_modification_token1] = ACTIONS(12991),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12991),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12991),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12991),
    [anon_sym_POUNDif] = ACTIONS(12991),
    [anon_sym_POUNDIF] = ACTIONS(12991),
    [anon_sym_POUNDIf] = ACTIONS(12991),
    [anon_sym_POUNDelif] = ACTIONS(12991),
    [anon_sym_POUNDELIF] = ACTIONS(12991),
    [anon_sym_POUNDElif] = ACTIONS(12991),
    [anon_sym_POUNDelse] = ACTIONS(12991),
    [anon_sym_POUNDELSE] = ACTIONS(12991),
    [anon_sym_POUNDElse] = ACTIONS(12991),
    [anon_sym_POUNDelse2] = ACTIONS(12991),
    [anon_sym_POUNDELSE2] = ACTIONS(12991),
    [anon_sym_POUNDElse2] = ACTIONS(12991),
    [anon_sym_POUNDendif] = ACTIONS(12991),
    [anon_sym_POUNDENDIF] = ACTIONS(12991),
    [anon_sym_POUNDEndif] = ACTIONS(12991),
    [anon_sym_POUNDendif2] = ACTIONS(12991),
    [anon_sym_POUNDENDIF2] = ACTIONS(12991),
    [anon_sym_POUNDEndif2] = ACTIONS(12991),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12991),
    [sym_trigger_keyword] = ACTIONS(12991),
    [sym_var_keyword] = ACTIONS(12991),
    [sym_local_keyword] = ACTIONS(12991),
    [sym_internal_keyword] = ACTIONS(12991),
    [sym_protected_keyword] = ACTIONS(12991),
    [sym_event_keyword] = ACTIONS(12991),
    [sym_fields_keyword] = ACTIONS(12991),
    [sym_keys_keyword] = ACTIONS(12991),
    [sym_fieldgroups_keyword] = ACTIONS(12991),
    [sym_actions_keyword] = ACTIONS(12991),
    [sym_layout_keyword] = ACTIONS(12991),
    [sym_area_keyword] = ACTIONS(12991),
    [sym_group_keyword] = ACTIONS(12991),
    [sym_repeater_keyword] = ACTIONS(12991),
    [sym_cuegroup_keyword] = ACTIONS(12991),
    [sym_fixed_keyword] = ACTIONS(12991),
    [sym_grid_keyword] = ACTIONS(12991),
    [sym_part_keyword] = ACTIONS(12991),
    [sym_systempart_keyword] = ACTIONS(12991),
    [sym_usercontrol_keyword] = ACTIONS(12991),
    [sym_dataset_keyword] = ACTIONS(12991),
    [sym_elements_keyword] = ACTIONS(12991),
    [sym_dataitem_keyword] = ACTIONS(12991),
    [sym_column_keyword] = ACTIONS(12991),
    [sym_filter_keyword] = ACTIONS(12991),
    [sym_labels_keyword] = ACTIONS(12991),
    [sym_rendering_keyword] = ACTIONS(12991),
    [sym_requestpage_keyword] = ACTIONS(12991),
    [sym_schema_keyword] = ACTIONS(12991),
    [sym_views_keyword] = ACTIONS(12991),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12991),
    [sym_preproc_open] = ACTIONS(12991),
    [sym_preproc_close] = ACTIONS(12991),
  },
  [STATE(5290)] = {
    [anon_sym_SEMI] = ACTIONS(12991),
    [aux_sym_where_condition_token1] = ACTIONS(12993),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12991),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12991),
    [anon_sym_LBRACK] = ACTIONS(12991),
    [aux_sym_basic_type_token6] = ACTIONS(12993),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12991),
    [aux_sym_addafter_modification_token1] = ACTIONS(12991),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12991),
    [aux_sym_modify_modification_token1] = ACTIONS(12991),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12991),
    [aux_sym_movelast_modification_token1] = ACTIONS(12991),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12991),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12991),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12991),
    [anon_sym_POUNDif] = ACTIONS(12991),
    [anon_sym_POUNDIF] = ACTIONS(12991),
    [anon_sym_POUNDIf] = ACTIONS(12991),
    [anon_sym_POUNDelif] = ACTIONS(12991),
    [anon_sym_POUNDELIF] = ACTIONS(12991),
    [anon_sym_POUNDElif] = ACTIONS(12991),
    [anon_sym_POUNDelse] = ACTIONS(12991),
    [anon_sym_POUNDELSE] = ACTIONS(12991),
    [anon_sym_POUNDElse] = ACTIONS(12991),
    [anon_sym_POUNDelse2] = ACTIONS(12991),
    [anon_sym_POUNDELSE2] = ACTIONS(12991),
    [anon_sym_POUNDElse2] = ACTIONS(12991),
    [anon_sym_POUNDendif] = ACTIONS(12991),
    [anon_sym_POUNDENDIF] = ACTIONS(12991),
    [anon_sym_POUNDEndif] = ACTIONS(12991),
    [anon_sym_POUNDendif2] = ACTIONS(12991),
    [anon_sym_POUNDENDIF2] = ACTIONS(12991),
    [anon_sym_POUNDEndif2] = ACTIONS(12991),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12991),
    [sym_trigger_keyword] = ACTIONS(12991),
    [sym_var_keyword] = ACTIONS(12991),
    [sym_local_keyword] = ACTIONS(12991),
    [sym_internal_keyword] = ACTIONS(12991),
    [sym_protected_keyword] = ACTIONS(12991),
    [sym_event_keyword] = ACTIONS(12991),
    [sym_fields_keyword] = ACTIONS(12991),
    [sym_keys_keyword] = ACTIONS(12991),
    [sym_fieldgroups_keyword] = ACTIONS(12991),
    [sym_actions_keyword] = ACTIONS(12991),
    [sym_layout_keyword] = ACTIONS(12991),
    [sym_area_keyword] = ACTIONS(12991),
    [sym_group_keyword] = ACTIONS(12991),
    [sym_repeater_keyword] = ACTIONS(12991),
    [sym_cuegroup_keyword] = ACTIONS(12991),
    [sym_fixed_keyword] = ACTIONS(12991),
    [sym_grid_keyword] = ACTIONS(12991),
    [sym_part_keyword] = ACTIONS(12991),
    [sym_systempart_keyword] = ACTIONS(12991),
    [sym_usercontrol_keyword] = ACTIONS(12991),
    [sym_dataset_keyword] = ACTIONS(12991),
    [sym_elements_keyword] = ACTIONS(12991),
    [sym_dataitem_keyword] = ACTIONS(12991),
    [sym_column_keyword] = ACTIONS(12991),
    [sym_filter_keyword] = ACTIONS(12991),
    [sym_labels_keyword] = ACTIONS(12991),
    [sym_rendering_keyword] = ACTIONS(12991),
    [sym_requestpage_keyword] = ACTIONS(12991),
    [sym_schema_keyword] = ACTIONS(12991),
    [sym_views_keyword] = ACTIONS(12991),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12991),
    [sym_preproc_open] = ACTIONS(12991),
    [sym_preproc_close] = ACTIONS(12991),
  },
  [STATE(5291)] = {
    [anon_sym_SEMI] = ACTIONS(12991),
    [aux_sym_where_condition_token1] = ACTIONS(12993),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12991),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12991),
    [anon_sym_LBRACK] = ACTIONS(12991),
    [aux_sym_basic_type_token6] = ACTIONS(12993),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12991),
    [aux_sym_addafter_modification_token1] = ACTIONS(12991),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12991),
    [aux_sym_modify_modification_token1] = ACTIONS(12991),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12991),
    [aux_sym_movelast_modification_token1] = ACTIONS(12991),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12991),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12991),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12991),
    [anon_sym_POUNDif] = ACTIONS(12991),
    [anon_sym_POUNDIF] = ACTIONS(12991),
    [anon_sym_POUNDIf] = ACTIONS(12991),
    [anon_sym_POUNDelif] = ACTIONS(12991),
    [anon_sym_POUNDELIF] = ACTIONS(12991),
    [anon_sym_POUNDElif] = ACTIONS(12991),
    [anon_sym_POUNDelse] = ACTIONS(12991),
    [anon_sym_POUNDELSE] = ACTIONS(12991),
    [anon_sym_POUNDElse] = ACTIONS(12991),
    [anon_sym_POUNDelse2] = ACTIONS(12991),
    [anon_sym_POUNDELSE2] = ACTIONS(12991),
    [anon_sym_POUNDElse2] = ACTIONS(12991),
    [anon_sym_POUNDendif] = ACTIONS(12991),
    [anon_sym_POUNDENDIF] = ACTIONS(12991),
    [anon_sym_POUNDEndif] = ACTIONS(12991),
    [anon_sym_POUNDendif2] = ACTIONS(12991),
    [anon_sym_POUNDENDIF2] = ACTIONS(12991),
    [anon_sym_POUNDEndif2] = ACTIONS(12991),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12991),
    [sym_trigger_keyword] = ACTIONS(12991),
    [sym_var_keyword] = ACTIONS(12991),
    [sym_local_keyword] = ACTIONS(12991),
    [sym_internal_keyword] = ACTIONS(12991),
    [sym_protected_keyword] = ACTIONS(12991),
    [sym_event_keyword] = ACTIONS(12991),
    [sym_fields_keyword] = ACTIONS(12991),
    [sym_keys_keyword] = ACTIONS(12991),
    [sym_fieldgroups_keyword] = ACTIONS(12991),
    [sym_actions_keyword] = ACTIONS(12991),
    [sym_layout_keyword] = ACTIONS(12991),
    [sym_area_keyword] = ACTIONS(12991),
    [sym_group_keyword] = ACTIONS(12991),
    [sym_repeater_keyword] = ACTIONS(12991),
    [sym_cuegroup_keyword] = ACTIONS(12991),
    [sym_fixed_keyword] = ACTIONS(12991),
    [sym_grid_keyword] = ACTIONS(12991),
    [sym_part_keyword] = ACTIONS(12991),
    [sym_systempart_keyword] = ACTIONS(12991),
    [sym_usercontrol_keyword] = ACTIONS(12991),
    [sym_dataset_keyword] = ACTIONS(12991),
    [sym_elements_keyword] = ACTIONS(12991),
    [sym_dataitem_keyword] = ACTIONS(12991),
    [sym_column_keyword] = ACTIONS(12991),
    [sym_filter_keyword] = ACTIONS(12991),
    [sym_labels_keyword] = ACTIONS(12991),
    [sym_rendering_keyword] = ACTIONS(12991),
    [sym_requestpage_keyword] = ACTIONS(12991),
    [sym_schema_keyword] = ACTIONS(12991),
    [sym_views_keyword] = ACTIONS(12991),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12991),
    [sym_preproc_open] = ACTIONS(12991),
    [sym_preproc_close] = ACTIONS(12991),
  },
  [STATE(5292)] = {
    [anon_sym_SEMI] = ACTIONS(12999),
    [aux_sym_where_condition_token1] = ACTIONS(13001),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12999),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12999),
    [anon_sym_LBRACK] = ACTIONS(12999),
    [aux_sym_basic_type_token6] = ACTIONS(13001),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12999),
    [aux_sym_addafter_modification_token1] = ACTIONS(12999),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12999),
    [aux_sym_modify_modification_token1] = ACTIONS(12999),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12999),
    [aux_sym_movelast_modification_token1] = ACTIONS(12999),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12999),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12999),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12999),
    [anon_sym_POUNDif] = ACTIONS(12999),
    [anon_sym_POUNDIF] = ACTIONS(12999),
    [anon_sym_POUNDIf] = ACTIONS(12999),
    [anon_sym_POUNDelif] = ACTIONS(12999),
    [anon_sym_POUNDELIF] = ACTIONS(12999),
    [anon_sym_POUNDElif] = ACTIONS(12999),
    [anon_sym_POUNDelse] = ACTIONS(12999),
    [anon_sym_POUNDELSE] = ACTIONS(12999),
    [anon_sym_POUNDElse] = ACTIONS(12999),
    [anon_sym_POUNDelse2] = ACTIONS(12999),
    [anon_sym_POUNDELSE2] = ACTIONS(12999),
    [anon_sym_POUNDElse2] = ACTIONS(12999),
    [anon_sym_POUNDendif] = ACTIONS(12999),
    [anon_sym_POUNDENDIF] = ACTIONS(12999),
    [anon_sym_POUNDEndif] = ACTIONS(12999),
    [anon_sym_POUNDendif2] = ACTIONS(12999),
    [anon_sym_POUNDENDIF2] = ACTIONS(12999),
    [anon_sym_POUNDEndif2] = ACTIONS(12999),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12999),
    [sym_trigger_keyword] = ACTIONS(12999),
    [sym_var_keyword] = ACTIONS(12999),
    [sym_local_keyword] = ACTIONS(12999),
    [sym_internal_keyword] = ACTIONS(12999),
    [sym_protected_keyword] = ACTIONS(12999),
    [sym_event_keyword] = ACTIONS(12999),
    [sym_fields_keyword] = ACTIONS(12999),
    [sym_keys_keyword] = ACTIONS(12999),
    [sym_fieldgroups_keyword] = ACTIONS(12999),
    [sym_actions_keyword] = ACTIONS(12999),
    [sym_layout_keyword] = ACTIONS(12999),
    [sym_area_keyword] = ACTIONS(12999),
    [sym_group_keyword] = ACTIONS(12999),
    [sym_repeater_keyword] = ACTIONS(12999),
    [sym_cuegroup_keyword] = ACTIONS(12999),
    [sym_fixed_keyword] = ACTIONS(12999),
    [sym_grid_keyword] = ACTIONS(12999),
    [sym_part_keyword] = ACTIONS(12999),
    [sym_systempart_keyword] = ACTIONS(12999),
    [sym_usercontrol_keyword] = ACTIONS(12999),
    [sym_dataset_keyword] = ACTIONS(12999),
    [sym_elements_keyword] = ACTIONS(12999),
    [sym_dataitem_keyword] = ACTIONS(12999),
    [sym_column_keyword] = ACTIONS(12999),
    [sym_filter_keyword] = ACTIONS(12999),
    [sym_labels_keyword] = ACTIONS(12999),
    [sym_rendering_keyword] = ACTIONS(12999),
    [sym_requestpage_keyword] = ACTIONS(12999),
    [sym_schema_keyword] = ACTIONS(12999),
    [sym_views_keyword] = ACTIONS(12999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12999),
    [sym_preproc_open] = ACTIONS(12999),
    [sym_preproc_close] = ACTIONS(12999),
  },
  [STATE(5293)] = {
    [anon_sym_SEMI] = ACTIONS(12999),
    [aux_sym_where_condition_token1] = ACTIONS(13001),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12999),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12999),
    [anon_sym_LBRACK] = ACTIONS(12999),
    [aux_sym_basic_type_token6] = ACTIONS(13001),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12999),
    [aux_sym_addafter_modification_token1] = ACTIONS(12999),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12999),
    [aux_sym_modify_modification_token1] = ACTIONS(12999),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12999),
    [aux_sym_movelast_modification_token1] = ACTIONS(12999),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12999),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12999),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12999),
    [anon_sym_POUNDif] = ACTIONS(12999),
    [anon_sym_POUNDIF] = ACTIONS(12999),
    [anon_sym_POUNDIf] = ACTIONS(12999),
    [anon_sym_POUNDelif] = ACTIONS(12999),
    [anon_sym_POUNDELIF] = ACTIONS(12999),
    [anon_sym_POUNDElif] = ACTIONS(12999),
    [anon_sym_POUNDelse] = ACTIONS(12999),
    [anon_sym_POUNDELSE] = ACTIONS(12999),
    [anon_sym_POUNDElse] = ACTIONS(12999),
    [anon_sym_POUNDelse2] = ACTIONS(12999),
    [anon_sym_POUNDELSE2] = ACTIONS(12999),
    [anon_sym_POUNDElse2] = ACTIONS(12999),
    [anon_sym_POUNDendif] = ACTIONS(12999),
    [anon_sym_POUNDENDIF] = ACTIONS(12999),
    [anon_sym_POUNDEndif] = ACTIONS(12999),
    [anon_sym_POUNDendif2] = ACTIONS(12999),
    [anon_sym_POUNDENDIF2] = ACTIONS(12999),
    [anon_sym_POUNDEndif2] = ACTIONS(12999),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12999),
    [sym_trigger_keyword] = ACTIONS(12999),
    [sym_var_keyword] = ACTIONS(12999),
    [sym_local_keyword] = ACTIONS(12999),
    [sym_internal_keyword] = ACTIONS(12999),
    [sym_protected_keyword] = ACTIONS(12999),
    [sym_event_keyword] = ACTIONS(12999),
    [sym_fields_keyword] = ACTIONS(12999),
    [sym_keys_keyword] = ACTIONS(12999),
    [sym_fieldgroups_keyword] = ACTIONS(12999),
    [sym_actions_keyword] = ACTIONS(12999),
    [sym_layout_keyword] = ACTIONS(12999),
    [sym_area_keyword] = ACTIONS(12999),
    [sym_group_keyword] = ACTIONS(12999),
    [sym_repeater_keyword] = ACTIONS(12999),
    [sym_cuegroup_keyword] = ACTIONS(12999),
    [sym_fixed_keyword] = ACTIONS(12999),
    [sym_grid_keyword] = ACTIONS(12999),
    [sym_part_keyword] = ACTIONS(12999),
    [sym_systempart_keyword] = ACTIONS(12999),
    [sym_usercontrol_keyword] = ACTIONS(12999),
    [sym_dataset_keyword] = ACTIONS(12999),
    [sym_elements_keyword] = ACTIONS(12999),
    [sym_dataitem_keyword] = ACTIONS(12999),
    [sym_column_keyword] = ACTIONS(12999),
    [sym_filter_keyword] = ACTIONS(12999),
    [sym_labels_keyword] = ACTIONS(12999),
    [sym_rendering_keyword] = ACTIONS(12999),
    [sym_requestpage_keyword] = ACTIONS(12999),
    [sym_schema_keyword] = ACTIONS(12999),
    [sym_views_keyword] = ACTIONS(12999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12999),
    [sym_preproc_open] = ACTIONS(12999),
    [sym_preproc_close] = ACTIONS(12999),
  },
  [STATE(5294)] = {
    [anon_sym_SEMI] = ACTIONS(12999),
    [aux_sym_where_condition_token1] = ACTIONS(13001),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12999),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12999),
    [anon_sym_LBRACK] = ACTIONS(12999),
    [aux_sym_basic_type_token6] = ACTIONS(13001),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12999),
    [aux_sym_addafter_modification_token1] = ACTIONS(12999),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12999),
    [aux_sym_modify_modification_token1] = ACTIONS(12999),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12999),
    [aux_sym_movelast_modification_token1] = ACTIONS(12999),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12999),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12999),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12999),
    [anon_sym_POUNDif] = ACTIONS(12999),
    [anon_sym_POUNDIF] = ACTIONS(12999),
    [anon_sym_POUNDIf] = ACTIONS(12999),
    [anon_sym_POUNDelif] = ACTIONS(12999),
    [anon_sym_POUNDELIF] = ACTIONS(12999),
    [anon_sym_POUNDElif] = ACTIONS(12999),
    [anon_sym_POUNDelse] = ACTIONS(12999),
    [anon_sym_POUNDELSE] = ACTIONS(12999),
    [anon_sym_POUNDElse] = ACTIONS(12999),
    [anon_sym_POUNDelse2] = ACTIONS(12999),
    [anon_sym_POUNDELSE2] = ACTIONS(12999),
    [anon_sym_POUNDElse2] = ACTIONS(12999),
    [anon_sym_POUNDendif] = ACTIONS(12999),
    [anon_sym_POUNDENDIF] = ACTIONS(12999),
    [anon_sym_POUNDEndif] = ACTIONS(12999),
    [anon_sym_POUNDendif2] = ACTIONS(12999),
    [anon_sym_POUNDENDIF2] = ACTIONS(12999),
    [anon_sym_POUNDEndif2] = ACTIONS(12999),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12999),
    [sym_trigger_keyword] = ACTIONS(12999),
    [sym_var_keyword] = ACTIONS(12999),
    [sym_local_keyword] = ACTIONS(12999),
    [sym_internal_keyword] = ACTIONS(12999),
    [sym_protected_keyword] = ACTIONS(12999),
    [sym_event_keyword] = ACTIONS(12999),
    [sym_fields_keyword] = ACTIONS(12999),
    [sym_keys_keyword] = ACTIONS(12999),
    [sym_fieldgroups_keyword] = ACTIONS(12999),
    [sym_actions_keyword] = ACTIONS(12999),
    [sym_layout_keyword] = ACTIONS(12999),
    [sym_area_keyword] = ACTIONS(12999),
    [sym_group_keyword] = ACTIONS(12999),
    [sym_repeater_keyword] = ACTIONS(12999),
    [sym_cuegroup_keyword] = ACTIONS(12999),
    [sym_fixed_keyword] = ACTIONS(12999),
    [sym_grid_keyword] = ACTIONS(12999),
    [sym_part_keyword] = ACTIONS(12999),
    [sym_systempart_keyword] = ACTIONS(12999),
    [sym_usercontrol_keyword] = ACTIONS(12999),
    [sym_dataset_keyword] = ACTIONS(12999),
    [sym_elements_keyword] = ACTIONS(12999),
    [sym_dataitem_keyword] = ACTIONS(12999),
    [sym_column_keyword] = ACTIONS(12999),
    [sym_filter_keyword] = ACTIONS(12999),
    [sym_labels_keyword] = ACTIONS(12999),
    [sym_rendering_keyword] = ACTIONS(12999),
    [sym_requestpage_keyword] = ACTIONS(12999),
    [sym_schema_keyword] = ACTIONS(12999),
    [sym_views_keyword] = ACTIONS(12999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12999),
    [sym_preproc_open] = ACTIONS(12999),
    [sym_preproc_close] = ACTIONS(12999),
  },
  [STATE(5295)] = {
    [anon_sym_SEMI] = ACTIONS(12999),
    [aux_sym_where_condition_token1] = ACTIONS(13001),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12999),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12999),
    [anon_sym_LBRACK] = ACTIONS(12999),
    [aux_sym_basic_type_token6] = ACTIONS(13001),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12999),
    [aux_sym_addafter_modification_token1] = ACTIONS(12999),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12999),
    [aux_sym_modify_modification_token1] = ACTIONS(12999),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12999),
    [aux_sym_movelast_modification_token1] = ACTIONS(12999),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12999),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12999),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12999),
    [anon_sym_POUNDif] = ACTIONS(12999),
    [anon_sym_POUNDIF] = ACTIONS(12999),
    [anon_sym_POUNDIf] = ACTIONS(12999),
    [anon_sym_POUNDelif] = ACTIONS(12999),
    [anon_sym_POUNDELIF] = ACTIONS(12999),
    [anon_sym_POUNDElif] = ACTIONS(12999),
    [anon_sym_POUNDelse] = ACTIONS(12999),
    [anon_sym_POUNDELSE] = ACTIONS(12999),
    [anon_sym_POUNDElse] = ACTIONS(12999),
    [anon_sym_POUNDelse2] = ACTIONS(12999),
    [anon_sym_POUNDELSE2] = ACTIONS(12999),
    [anon_sym_POUNDElse2] = ACTIONS(12999),
    [anon_sym_POUNDendif] = ACTIONS(12999),
    [anon_sym_POUNDENDIF] = ACTIONS(12999),
    [anon_sym_POUNDEndif] = ACTIONS(12999),
    [anon_sym_POUNDendif2] = ACTIONS(12999),
    [anon_sym_POUNDENDIF2] = ACTIONS(12999),
    [anon_sym_POUNDEndif2] = ACTIONS(12999),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12999),
    [sym_trigger_keyword] = ACTIONS(12999),
    [sym_var_keyword] = ACTIONS(12999),
    [sym_local_keyword] = ACTIONS(12999),
    [sym_internal_keyword] = ACTIONS(12999),
    [sym_protected_keyword] = ACTIONS(12999),
    [sym_event_keyword] = ACTIONS(12999),
    [sym_fields_keyword] = ACTIONS(12999),
    [sym_keys_keyword] = ACTIONS(12999),
    [sym_fieldgroups_keyword] = ACTIONS(12999),
    [sym_actions_keyword] = ACTIONS(12999),
    [sym_layout_keyword] = ACTIONS(12999),
    [sym_area_keyword] = ACTIONS(12999),
    [sym_group_keyword] = ACTIONS(12999),
    [sym_repeater_keyword] = ACTIONS(12999),
    [sym_cuegroup_keyword] = ACTIONS(12999),
    [sym_fixed_keyword] = ACTIONS(12999),
    [sym_grid_keyword] = ACTIONS(12999),
    [sym_part_keyword] = ACTIONS(12999),
    [sym_systempart_keyword] = ACTIONS(12999),
    [sym_usercontrol_keyword] = ACTIONS(12999),
    [sym_dataset_keyword] = ACTIONS(12999),
    [sym_elements_keyword] = ACTIONS(12999),
    [sym_dataitem_keyword] = ACTIONS(12999),
    [sym_column_keyword] = ACTIONS(12999),
    [sym_filter_keyword] = ACTIONS(12999),
    [sym_labels_keyword] = ACTIONS(12999),
    [sym_rendering_keyword] = ACTIONS(12999),
    [sym_requestpage_keyword] = ACTIONS(12999),
    [sym_schema_keyword] = ACTIONS(12999),
    [sym_views_keyword] = ACTIONS(12999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12999),
    [sym_preproc_open] = ACTIONS(12999),
    [sym_preproc_close] = ACTIONS(12999),
  },
  [STATE(5296)] = {
    [anon_sym_SEMI] = ACTIONS(12999),
    [aux_sym_where_condition_token1] = ACTIONS(13001),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12999),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12999),
    [anon_sym_LBRACK] = ACTIONS(12999),
    [aux_sym_basic_type_token6] = ACTIONS(13001),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12999),
    [aux_sym_addafter_modification_token1] = ACTIONS(12999),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12999),
    [aux_sym_modify_modification_token1] = ACTIONS(12999),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12999),
    [aux_sym_movelast_modification_token1] = ACTIONS(12999),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12999),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12999),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12999),
    [anon_sym_POUNDif] = ACTIONS(12999),
    [anon_sym_POUNDIF] = ACTIONS(12999),
    [anon_sym_POUNDIf] = ACTIONS(12999),
    [anon_sym_POUNDelif] = ACTIONS(12999),
    [anon_sym_POUNDELIF] = ACTIONS(12999),
    [anon_sym_POUNDElif] = ACTIONS(12999),
    [anon_sym_POUNDelse] = ACTIONS(12999),
    [anon_sym_POUNDELSE] = ACTIONS(12999),
    [anon_sym_POUNDElse] = ACTIONS(12999),
    [anon_sym_POUNDelse2] = ACTIONS(12999),
    [anon_sym_POUNDELSE2] = ACTIONS(12999),
    [anon_sym_POUNDElse2] = ACTIONS(12999),
    [anon_sym_POUNDendif] = ACTIONS(12999),
    [anon_sym_POUNDENDIF] = ACTIONS(12999),
    [anon_sym_POUNDEndif] = ACTIONS(12999),
    [anon_sym_POUNDendif2] = ACTIONS(12999),
    [anon_sym_POUNDENDIF2] = ACTIONS(12999),
    [anon_sym_POUNDEndif2] = ACTIONS(12999),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12999),
    [sym_trigger_keyword] = ACTIONS(12999),
    [sym_var_keyword] = ACTIONS(12999),
    [sym_local_keyword] = ACTIONS(12999),
    [sym_internal_keyword] = ACTIONS(12999),
    [sym_protected_keyword] = ACTIONS(12999),
    [sym_event_keyword] = ACTIONS(12999),
    [sym_fields_keyword] = ACTIONS(12999),
    [sym_keys_keyword] = ACTIONS(12999),
    [sym_fieldgroups_keyword] = ACTIONS(12999),
    [sym_actions_keyword] = ACTIONS(12999),
    [sym_layout_keyword] = ACTIONS(12999),
    [sym_area_keyword] = ACTIONS(12999),
    [sym_group_keyword] = ACTIONS(12999),
    [sym_repeater_keyword] = ACTIONS(12999),
    [sym_cuegroup_keyword] = ACTIONS(12999),
    [sym_fixed_keyword] = ACTIONS(12999),
    [sym_grid_keyword] = ACTIONS(12999),
    [sym_part_keyword] = ACTIONS(12999),
    [sym_systempart_keyword] = ACTIONS(12999),
    [sym_usercontrol_keyword] = ACTIONS(12999),
    [sym_dataset_keyword] = ACTIONS(12999),
    [sym_elements_keyword] = ACTIONS(12999),
    [sym_dataitem_keyword] = ACTIONS(12999),
    [sym_column_keyword] = ACTIONS(12999),
    [sym_filter_keyword] = ACTIONS(12999),
    [sym_labels_keyword] = ACTIONS(12999),
    [sym_rendering_keyword] = ACTIONS(12999),
    [sym_requestpage_keyword] = ACTIONS(12999),
    [sym_schema_keyword] = ACTIONS(12999),
    [sym_views_keyword] = ACTIONS(12999),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12999),
    [sym_preproc_open] = ACTIONS(12999),
    [sym_preproc_close] = ACTIONS(12999),
  },
  [STATE(5297)] = {
    [anon_sym_SEMI] = ACTIONS(13003),
    [aux_sym_where_condition_token1] = ACTIONS(13005),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13003),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13003),
    [anon_sym_LBRACK] = ACTIONS(13003),
    [aux_sym_basic_type_token6] = ACTIONS(13005),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13003),
    [aux_sym_addafter_modification_token1] = ACTIONS(13003),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13003),
    [aux_sym_modify_modification_token1] = ACTIONS(13003),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13003),
    [aux_sym_movelast_modification_token1] = ACTIONS(13003),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13003),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13003),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13003),
    [anon_sym_POUNDif] = ACTIONS(13003),
    [anon_sym_POUNDIF] = ACTIONS(13003),
    [anon_sym_POUNDIf] = ACTIONS(13003),
    [anon_sym_POUNDelif] = ACTIONS(13003),
    [anon_sym_POUNDELIF] = ACTIONS(13003),
    [anon_sym_POUNDElif] = ACTIONS(13003),
    [anon_sym_POUNDelse] = ACTIONS(13003),
    [anon_sym_POUNDELSE] = ACTIONS(13003),
    [anon_sym_POUNDElse] = ACTIONS(13003),
    [anon_sym_POUNDelse2] = ACTIONS(13003),
    [anon_sym_POUNDELSE2] = ACTIONS(13003),
    [anon_sym_POUNDElse2] = ACTIONS(13003),
    [anon_sym_POUNDendif] = ACTIONS(13003),
    [anon_sym_POUNDENDIF] = ACTIONS(13003),
    [anon_sym_POUNDEndif] = ACTIONS(13003),
    [anon_sym_POUNDendif2] = ACTIONS(13003),
    [anon_sym_POUNDENDIF2] = ACTIONS(13003),
    [anon_sym_POUNDEndif2] = ACTIONS(13003),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13003),
    [sym_trigger_keyword] = ACTIONS(13003),
    [sym_var_keyword] = ACTIONS(13003),
    [sym_local_keyword] = ACTIONS(13003),
    [sym_internal_keyword] = ACTIONS(13003),
    [sym_protected_keyword] = ACTIONS(13003),
    [sym_event_keyword] = ACTIONS(13003),
    [sym_fields_keyword] = ACTIONS(13003),
    [sym_keys_keyword] = ACTIONS(13003),
    [sym_fieldgroups_keyword] = ACTIONS(13003),
    [sym_actions_keyword] = ACTIONS(13003),
    [sym_layout_keyword] = ACTIONS(13003),
    [sym_area_keyword] = ACTIONS(13003),
    [sym_group_keyword] = ACTIONS(13003),
    [sym_repeater_keyword] = ACTIONS(13003),
    [sym_cuegroup_keyword] = ACTIONS(13003),
    [sym_fixed_keyword] = ACTIONS(13003),
    [sym_grid_keyword] = ACTIONS(13003),
    [sym_part_keyword] = ACTIONS(13003),
    [sym_systempart_keyword] = ACTIONS(13003),
    [sym_usercontrol_keyword] = ACTIONS(13003),
    [sym_dataset_keyword] = ACTIONS(13003),
    [sym_elements_keyword] = ACTIONS(13003),
    [sym_dataitem_keyword] = ACTIONS(13003),
    [sym_column_keyword] = ACTIONS(13003),
    [sym_filter_keyword] = ACTIONS(13003),
    [sym_labels_keyword] = ACTIONS(13003),
    [sym_rendering_keyword] = ACTIONS(13003),
    [sym_requestpage_keyword] = ACTIONS(13003),
    [sym_schema_keyword] = ACTIONS(13003),
    [sym_views_keyword] = ACTIONS(13003),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13003),
    [sym_preproc_open] = ACTIONS(13003),
    [sym_preproc_close] = ACTIONS(13003),
  },
  [STATE(5298)] = {
    [anon_sym_SEMI] = ACTIONS(13007),
    [aux_sym_where_condition_token1] = ACTIONS(13009),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13007),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13007),
    [anon_sym_LBRACK] = ACTIONS(13007),
    [aux_sym_basic_type_token6] = ACTIONS(13009),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13007),
    [aux_sym_addafter_modification_token1] = ACTIONS(13007),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13007),
    [aux_sym_modify_modification_token1] = ACTIONS(13007),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13007),
    [aux_sym_movelast_modification_token1] = ACTIONS(13007),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13007),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13007),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13007),
    [anon_sym_POUNDif] = ACTIONS(13007),
    [anon_sym_POUNDIF] = ACTIONS(13007),
    [anon_sym_POUNDIf] = ACTIONS(13007),
    [anon_sym_POUNDelif] = ACTIONS(13007),
    [anon_sym_POUNDELIF] = ACTIONS(13007),
    [anon_sym_POUNDElif] = ACTIONS(13007),
    [anon_sym_POUNDelse] = ACTIONS(13007),
    [anon_sym_POUNDELSE] = ACTIONS(13007),
    [anon_sym_POUNDElse] = ACTIONS(13007),
    [anon_sym_POUNDelse2] = ACTIONS(13007),
    [anon_sym_POUNDELSE2] = ACTIONS(13007),
    [anon_sym_POUNDElse2] = ACTIONS(13007),
    [anon_sym_POUNDendif] = ACTIONS(13007),
    [anon_sym_POUNDENDIF] = ACTIONS(13007),
    [anon_sym_POUNDEndif] = ACTIONS(13007),
    [anon_sym_POUNDendif2] = ACTIONS(13007),
    [anon_sym_POUNDENDIF2] = ACTIONS(13007),
    [anon_sym_POUNDEndif2] = ACTIONS(13007),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13007),
    [sym_trigger_keyword] = ACTIONS(13007),
    [sym_var_keyword] = ACTIONS(13007),
    [sym_local_keyword] = ACTIONS(13007),
    [sym_internal_keyword] = ACTIONS(13007),
    [sym_protected_keyword] = ACTIONS(13007),
    [sym_event_keyword] = ACTIONS(13007),
    [sym_fields_keyword] = ACTIONS(13007),
    [sym_keys_keyword] = ACTIONS(13007),
    [sym_fieldgroups_keyword] = ACTIONS(13007),
    [sym_actions_keyword] = ACTIONS(13007),
    [sym_layout_keyword] = ACTIONS(13007),
    [sym_area_keyword] = ACTIONS(13007),
    [sym_group_keyword] = ACTIONS(13007),
    [sym_repeater_keyword] = ACTIONS(13007),
    [sym_cuegroup_keyword] = ACTIONS(13007),
    [sym_fixed_keyword] = ACTIONS(13007),
    [sym_grid_keyword] = ACTIONS(13007),
    [sym_part_keyword] = ACTIONS(13007),
    [sym_systempart_keyword] = ACTIONS(13007),
    [sym_usercontrol_keyword] = ACTIONS(13007),
    [sym_dataset_keyword] = ACTIONS(13007),
    [sym_elements_keyword] = ACTIONS(13007),
    [sym_dataitem_keyword] = ACTIONS(13007),
    [sym_column_keyword] = ACTIONS(13007),
    [sym_filter_keyword] = ACTIONS(13007),
    [sym_labels_keyword] = ACTIONS(13007),
    [sym_rendering_keyword] = ACTIONS(13007),
    [sym_requestpage_keyword] = ACTIONS(13007),
    [sym_schema_keyword] = ACTIONS(13007),
    [sym_views_keyword] = ACTIONS(13007),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13007),
    [sym_preproc_open] = ACTIONS(13007),
    [sym_preproc_close] = ACTIONS(13007),
  },
  [STATE(5299)] = {
    [anon_sym_SEMI] = ACTIONS(12235),
    [aux_sym_where_condition_token1] = ACTIONS(12237),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12235),
    [anon_sym_LBRACK] = ACTIONS(12235),
    [aux_sym_basic_type_token6] = ACTIONS(12237),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12235),
    [aux_sym_addafter_modification_token1] = ACTIONS(12235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12235),
    [aux_sym_modify_modification_token1] = ACTIONS(12235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12235),
    [aux_sym_movelast_modification_token1] = ACTIONS(12235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12235),
    [anon_sym_POUNDif] = ACTIONS(12235),
    [anon_sym_POUNDIF] = ACTIONS(12235),
    [anon_sym_POUNDIf] = ACTIONS(12235),
    [anon_sym_POUNDelif] = ACTIONS(12235),
    [anon_sym_POUNDELIF] = ACTIONS(12235),
    [anon_sym_POUNDElif] = ACTIONS(12235),
    [anon_sym_POUNDelse] = ACTIONS(12235),
    [anon_sym_POUNDELSE] = ACTIONS(12235),
    [anon_sym_POUNDElse] = ACTIONS(12235),
    [anon_sym_POUNDelse2] = ACTIONS(12235),
    [anon_sym_POUNDELSE2] = ACTIONS(12235),
    [anon_sym_POUNDElse2] = ACTIONS(12235),
    [anon_sym_POUNDendif] = ACTIONS(12235),
    [anon_sym_POUNDENDIF] = ACTIONS(12235),
    [anon_sym_POUNDEndif] = ACTIONS(12235),
    [anon_sym_POUNDendif2] = ACTIONS(12235),
    [anon_sym_POUNDENDIF2] = ACTIONS(12235),
    [anon_sym_POUNDEndif2] = ACTIONS(12235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12235),
    [sym_trigger_keyword] = ACTIONS(12235),
    [sym_var_keyword] = ACTIONS(12235),
    [sym_local_keyword] = ACTIONS(12235),
    [sym_internal_keyword] = ACTIONS(12235),
    [sym_protected_keyword] = ACTIONS(12235),
    [sym_event_keyword] = ACTIONS(12235),
    [sym_fields_keyword] = ACTIONS(12235),
    [sym_keys_keyword] = ACTIONS(12235),
    [sym_fieldgroups_keyword] = ACTIONS(12235),
    [sym_actions_keyword] = ACTIONS(12235),
    [sym_layout_keyword] = ACTIONS(12235),
    [sym_area_keyword] = ACTIONS(12235),
    [sym_group_keyword] = ACTIONS(12235),
    [sym_repeater_keyword] = ACTIONS(12235),
    [sym_cuegroup_keyword] = ACTIONS(12235),
    [sym_fixed_keyword] = ACTIONS(12235),
    [sym_grid_keyword] = ACTIONS(12235),
    [sym_part_keyword] = ACTIONS(12235),
    [sym_systempart_keyword] = ACTIONS(12235),
    [sym_usercontrol_keyword] = ACTIONS(12235),
    [sym_dataset_keyword] = ACTIONS(12235),
    [sym_elements_keyword] = ACTIONS(12235),
    [sym_dataitem_keyword] = ACTIONS(12235),
    [sym_column_keyword] = ACTIONS(12235),
    [sym_filter_keyword] = ACTIONS(12235),
    [sym_labels_keyword] = ACTIONS(12235),
    [sym_rendering_keyword] = ACTIONS(12235),
    [sym_requestpage_keyword] = ACTIONS(12235),
    [sym_schema_keyword] = ACTIONS(12235),
    [sym_views_keyword] = ACTIONS(12235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12235),
    [sym_preproc_open] = ACTIONS(12235),
    [sym_preproc_close] = ACTIONS(12235),
  },
  [STATE(5300)] = {
    [sym__body_element] = STATE(5302),
    [sym_empty_statement] = STATE(5302),
    [sym_property] = STATE(5302),
    [sym_permissions_property] = STATE(5302),
    [sym_table_relation_property] = STATE(5302),
    [sym_fields_section] = STATE(5302),
    [sym_keys_section] = STATE(5302),
    [sym_fieldgroups_section] = STATE(5302),
    [sym_enum_value_declaration] = STATE(5302),
    [sym_labels_section] = STATE(5302),
    [sym_layout_section] = STATE(5302),
    [sym_modify_modification] = STATE(5302),
    [sym_actions_section] = STATE(5302),
    [sym_views_section] = STATE(5302),
    [sym_dataset_section] = STATE(5302),
    [sym_report_dataitem] = STATE(5302),
    [sym__report_body_element] = STATE(5302),
    [sym_preproc_conditional_report] = STATE(5302),
    [sym_report_column] = STATE(5302),
    [sym_requestpage_section] = STATE(5302),
    [sym_rendering_section] = STATE(5302),
    [sym_elements_section] = STATE(5302),
    [sym_schema_section] = STATE(5302),
    [sym_assembly_declaration] = STATE(5302),
    [sym_event_declaration] = STATE(5302),
    [sym_procedure] = STATE(5302),
    [sym_preproc_split_procedure] = STATE(5302),
    [sym_preproc_split_procedure_preamble] = STATE(5302),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5302),
    [sym_var_section] = STATE(5302),
    [sym_attribute_item] = STATE(5302),
    [sym_preproc_conditional] = STATE(5302),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5302),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13011),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5301)] = {
    [anon_sym_SEMI] = ACTIONS(12235),
    [aux_sym_where_condition_token1] = ACTIONS(12237),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(12235),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(12235),
    [anon_sym_LBRACK] = ACTIONS(12235),
    [aux_sym_basic_type_token6] = ACTIONS(12237),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12235),
    [aux_sym_addafter_modification_token1] = ACTIONS(12235),
    [aux_sym_addbefore_modification_token1] = ACTIONS(12235),
    [aux_sym_modify_modification_token1] = ACTIONS(12235),
    [aux_sym_movefirst_modification_token1] = ACTIONS(12235),
    [aux_sym_movelast_modification_token1] = ACTIONS(12235),
    [aux_sym_moveafter_modification_token1] = ACTIONS(12235),
    [aux_sym_movebefore_modification_token1] = ACTIONS(12235),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12235),
    [anon_sym_POUNDif] = ACTIONS(12235),
    [anon_sym_POUNDIF] = ACTIONS(12235),
    [anon_sym_POUNDIf] = ACTIONS(12235),
    [anon_sym_POUNDelif] = ACTIONS(12235),
    [anon_sym_POUNDELIF] = ACTIONS(12235),
    [anon_sym_POUNDElif] = ACTIONS(12235),
    [anon_sym_POUNDelse] = ACTIONS(12235),
    [anon_sym_POUNDELSE] = ACTIONS(12235),
    [anon_sym_POUNDElse] = ACTIONS(12235),
    [anon_sym_POUNDelse2] = ACTIONS(12235),
    [anon_sym_POUNDELSE2] = ACTIONS(12235),
    [anon_sym_POUNDElse2] = ACTIONS(12235),
    [anon_sym_POUNDendif] = ACTIONS(12235),
    [anon_sym_POUNDENDIF] = ACTIONS(12235),
    [anon_sym_POUNDEndif] = ACTIONS(12235),
    [anon_sym_POUNDendif2] = ACTIONS(12235),
    [anon_sym_POUNDENDIF2] = ACTIONS(12235),
    [anon_sym_POUNDEndif2] = ACTIONS(12235),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12235),
    [sym_trigger_keyword] = ACTIONS(12235),
    [sym_var_keyword] = ACTIONS(12235),
    [sym_local_keyword] = ACTIONS(12235),
    [sym_internal_keyword] = ACTIONS(12235),
    [sym_protected_keyword] = ACTIONS(12235),
    [sym_event_keyword] = ACTIONS(12235),
    [sym_fields_keyword] = ACTIONS(12235),
    [sym_keys_keyword] = ACTIONS(12235),
    [sym_fieldgroups_keyword] = ACTIONS(12235),
    [sym_actions_keyword] = ACTIONS(12235),
    [sym_layout_keyword] = ACTIONS(12235),
    [sym_area_keyword] = ACTIONS(12235),
    [sym_group_keyword] = ACTIONS(12235),
    [sym_repeater_keyword] = ACTIONS(12235),
    [sym_cuegroup_keyword] = ACTIONS(12235),
    [sym_fixed_keyword] = ACTIONS(12235),
    [sym_grid_keyword] = ACTIONS(12235),
    [sym_part_keyword] = ACTIONS(12235),
    [sym_systempart_keyword] = ACTIONS(12235),
    [sym_usercontrol_keyword] = ACTIONS(12235),
    [sym_dataset_keyword] = ACTIONS(12235),
    [sym_elements_keyword] = ACTIONS(12235),
    [sym_dataitem_keyword] = ACTIONS(12235),
    [sym_column_keyword] = ACTIONS(12235),
    [sym_filter_keyword] = ACTIONS(12235),
    [sym_labels_keyword] = ACTIONS(12235),
    [sym_rendering_keyword] = ACTIONS(12235),
    [sym_requestpage_keyword] = ACTIONS(12235),
    [sym_schema_keyword] = ACTIONS(12235),
    [sym_views_keyword] = ACTIONS(12235),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12235),
    [sym_preproc_open] = ACTIONS(12235),
    [sym_preproc_close] = ACTIONS(12235),
  },
  [STATE(5302)] = {
    [sym__body_element] = STATE(5097),
    [sym_empty_statement] = STATE(5097),
    [sym_property] = STATE(5097),
    [sym_permissions_property] = STATE(5097),
    [sym_table_relation_property] = STATE(5097),
    [sym_fields_section] = STATE(5097),
    [sym_keys_section] = STATE(5097),
    [sym_fieldgroups_section] = STATE(5097),
    [sym_enum_value_declaration] = STATE(5097),
    [sym_labels_section] = STATE(5097),
    [sym_layout_section] = STATE(5097),
    [sym_modify_modification] = STATE(5097),
    [sym_actions_section] = STATE(5097),
    [sym_views_section] = STATE(5097),
    [sym_dataset_section] = STATE(5097),
    [sym_report_dataitem] = STATE(5097),
    [sym__report_body_element] = STATE(5097),
    [sym_preproc_conditional_report] = STATE(5097),
    [sym_report_column] = STATE(5097),
    [sym_requestpage_section] = STATE(5097),
    [sym_rendering_section] = STATE(5097),
    [sym_elements_section] = STATE(5097),
    [sym_schema_section] = STATE(5097),
    [sym_assembly_declaration] = STATE(5097),
    [sym_event_declaration] = STATE(5097),
    [sym_procedure] = STATE(5097),
    [sym_preproc_split_procedure] = STATE(5097),
    [sym_preproc_split_procedure_preamble] = STATE(5097),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5097),
    [sym_var_section] = STATE(5097),
    [sym_attribute_item] = STATE(5097),
    [sym_preproc_conditional] = STATE(5097),
    [sym_preproc_if] = STATE(3546),
    [aux_sym_report_dataitem_repeat1] = STATE(5097),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13013),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5303)] = {
    [anon_sym_SEMI] = ACTIONS(13015),
    [aux_sym_where_condition_token1] = ACTIONS(13017),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13015),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13015),
    [anon_sym_LBRACK] = ACTIONS(13015),
    [aux_sym_basic_type_token6] = ACTIONS(13017),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13015),
    [aux_sym_addafter_modification_token1] = ACTIONS(13015),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13015),
    [aux_sym_modify_modification_token1] = ACTIONS(13015),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13015),
    [aux_sym_movelast_modification_token1] = ACTIONS(13015),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13015),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13015),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13015),
    [anon_sym_POUNDif] = ACTIONS(13015),
    [anon_sym_POUNDIF] = ACTIONS(13015),
    [anon_sym_POUNDIf] = ACTIONS(13015),
    [anon_sym_POUNDelif] = ACTIONS(13015),
    [anon_sym_POUNDELIF] = ACTIONS(13015),
    [anon_sym_POUNDElif] = ACTIONS(13015),
    [anon_sym_POUNDelse] = ACTIONS(13015),
    [anon_sym_POUNDELSE] = ACTIONS(13015),
    [anon_sym_POUNDElse] = ACTIONS(13015),
    [anon_sym_POUNDelse2] = ACTIONS(13015),
    [anon_sym_POUNDELSE2] = ACTIONS(13015),
    [anon_sym_POUNDElse2] = ACTIONS(13015),
    [anon_sym_POUNDendif] = ACTIONS(13015),
    [anon_sym_POUNDENDIF] = ACTIONS(13015),
    [anon_sym_POUNDEndif] = ACTIONS(13015),
    [anon_sym_POUNDendif2] = ACTIONS(13015),
    [anon_sym_POUNDENDIF2] = ACTIONS(13015),
    [anon_sym_POUNDEndif2] = ACTIONS(13015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13015),
    [sym_trigger_keyword] = ACTIONS(13015),
    [sym_var_keyword] = ACTIONS(13015),
    [sym_local_keyword] = ACTIONS(13015),
    [sym_internal_keyword] = ACTIONS(13015),
    [sym_protected_keyword] = ACTIONS(13015),
    [sym_event_keyword] = ACTIONS(13015),
    [sym_fields_keyword] = ACTIONS(13015),
    [sym_keys_keyword] = ACTIONS(13015),
    [sym_fieldgroups_keyword] = ACTIONS(13015),
    [sym_actions_keyword] = ACTIONS(13015),
    [sym_layout_keyword] = ACTIONS(13015),
    [sym_area_keyword] = ACTIONS(13015),
    [sym_group_keyword] = ACTIONS(13015),
    [sym_repeater_keyword] = ACTIONS(13015),
    [sym_cuegroup_keyword] = ACTIONS(13015),
    [sym_fixed_keyword] = ACTIONS(13015),
    [sym_grid_keyword] = ACTIONS(13015),
    [sym_part_keyword] = ACTIONS(13015),
    [sym_systempart_keyword] = ACTIONS(13015),
    [sym_usercontrol_keyword] = ACTIONS(13015),
    [sym_dataset_keyword] = ACTIONS(13015),
    [sym_elements_keyword] = ACTIONS(13015),
    [sym_dataitem_keyword] = ACTIONS(13015),
    [sym_column_keyword] = ACTIONS(13015),
    [sym_filter_keyword] = ACTIONS(13015),
    [sym_labels_keyword] = ACTIONS(13015),
    [sym_rendering_keyword] = ACTIONS(13015),
    [sym_requestpage_keyword] = ACTIONS(13015),
    [sym_schema_keyword] = ACTIONS(13015),
    [sym_views_keyword] = ACTIONS(13015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13015),
    [sym_preproc_open] = ACTIONS(13015),
    [sym_preproc_close] = ACTIONS(13015),
  },
  [STATE(5304)] = {
    [anon_sym_SEMI] = ACTIONS(13015),
    [aux_sym_where_condition_token1] = ACTIONS(13017),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13015),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13015),
    [anon_sym_LBRACK] = ACTIONS(13015),
    [aux_sym_basic_type_token6] = ACTIONS(13017),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13015),
    [aux_sym_addafter_modification_token1] = ACTIONS(13015),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13015),
    [aux_sym_modify_modification_token1] = ACTIONS(13015),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13015),
    [aux_sym_movelast_modification_token1] = ACTIONS(13015),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13015),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13015),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13015),
    [anon_sym_POUNDif] = ACTIONS(13015),
    [anon_sym_POUNDIF] = ACTIONS(13015),
    [anon_sym_POUNDIf] = ACTIONS(13015),
    [anon_sym_POUNDelif] = ACTIONS(13015),
    [anon_sym_POUNDELIF] = ACTIONS(13015),
    [anon_sym_POUNDElif] = ACTIONS(13015),
    [anon_sym_POUNDelse] = ACTIONS(13015),
    [anon_sym_POUNDELSE] = ACTIONS(13015),
    [anon_sym_POUNDElse] = ACTIONS(13015),
    [anon_sym_POUNDelse2] = ACTIONS(13015),
    [anon_sym_POUNDELSE2] = ACTIONS(13015),
    [anon_sym_POUNDElse2] = ACTIONS(13015),
    [anon_sym_POUNDendif] = ACTIONS(13015),
    [anon_sym_POUNDENDIF] = ACTIONS(13015),
    [anon_sym_POUNDEndif] = ACTIONS(13015),
    [anon_sym_POUNDendif2] = ACTIONS(13015),
    [anon_sym_POUNDENDIF2] = ACTIONS(13015),
    [anon_sym_POUNDEndif2] = ACTIONS(13015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13015),
    [sym_trigger_keyword] = ACTIONS(13015),
    [sym_var_keyword] = ACTIONS(13015),
    [sym_local_keyword] = ACTIONS(13015),
    [sym_internal_keyword] = ACTIONS(13015),
    [sym_protected_keyword] = ACTIONS(13015),
    [sym_event_keyword] = ACTIONS(13015),
    [sym_fields_keyword] = ACTIONS(13015),
    [sym_keys_keyword] = ACTIONS(13015),
    [sym_fieldgroups_keyword] = ACTIONS(13015),
    [sym_actions_keyword] = ACTIONS(13015),
    [sym_layout_keyword] = ACTIONS(13015),
    [sym_area_keyword] = ACTIONS(13015),
    [sym_group_keyword] = ACTIONS(13015),
    [sym_repeater_keyword] = ACTIONS(13015),
    [sym_cuegroup_keyword] = ACTIONS(13015),
    [sym_fixed_keyword] = ACTIONS(13015),
    [sym_grid_keyword] = ACTIONS(13015),
    [sym_part_keyword] = ACTIONS(13015),
    [sym_systempart_keyword] = ACTIONS(13015),
    [sym_usercontrol_keyword] = ACTIONS(13015),
    [sym_dataset_keyword] = ACTIONS(13015),
    [sym_elements_keyword] = ACTIONS(13015),
    [sym_dataitem_keyword] = ACTIONS(13015),
    [sym_column_keyword] = ACTIONS(13015),
    [sym_filter_keyword] = ACTIONS(13015),
    [sym_labels_keyword] = ACTIONS(13015),
    [sym_rendering_keyword] = ACTIONS(13015),
    [sym_requestpage_keyword] = ACTIONS(13015),
    [sym_schema_keyword] = ACTIONS(13015),
    [sym_views_keyword] = ACTIONS(13015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13015),
    [sym_preproc_open] = ACTIONS(13015),
    [sym_preproc_close] = ACTIONS(13015),
  },
  [STATE(5305)] = {
    [anon_sym_SEMI] = ACTIONS(13015),
    [aux_sym_where_condition_token1] = ACTIONS(13017),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13015),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13015),
    [anon_sym_LBRACK] = ACTIONS(13015),
    [aux_sym_basic_type_token6] = ACTIONS(13017),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13015),
    [aux_sym_addafter_modification_token1] = ACTIONS(13015),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13015),
    [aux_sym_modify_modification_token1] = ACTIONS(13015),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13015),
    [aux_sym_movelast_modification_token1] = ACTIONS(13015),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13015),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13015),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13015),
    [anon_sym_POUNDif] = ACTIONS(13015),
    [anon_sym_POUNDIF] = ACTIONS(13015),
    [anon_sym_POUNDIf] = ACTIONS(13015),
    [anon_sym_POUNDelif] = ACTIONS(13015),
    [anon_sym_POUNDELIF] = ACTIONS(13015),
    [anon_sym_POUNDElif] = ACTIONS(13015),
    [anon_sym_POUNDelse] = ACTIONS(13015),
    [anon_sym_POUNDELSE] = ACTIONS(13015),
    [anon_sym_POUNDElse] = ACTIONS(13015),
    [anon_sym_POUNDelse2] = ACTIONS(13015),
    [anon_sym_POUNDELSE2] = ACTIONS(13015),
    [anon_sym_POUNDElse2] = ACTIONS(13015),
    [anon_sym_POUNDendif] = ACTIONS(13015),
    [anon_sym_POUNDENDIF] = ACTIONS(13015),
    [anon_sym_POUNDEndif] = ACTIONS(13015),
    [anon_sym_POUNDendif2] = ACTIONS(13015),
    [anon_sym_POUNDENDIF2] = ACTIONS(13015),
    [anon_sym_POUNDEndif2] = ACTIONS(13015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13015),
    [sym_trigger_keyword] = ACTIONS(13015),
    [sym_var_keyword] = ACTIONS(13015),
    [sym_local_keyword] = ACTIONS(13015),
    [sym_internal_keyword] = ACTIONS(13015),
    [sym_protected_keyword] = ACTIONS(13015),
    [sym_event_keyword] = ACTIONS(13015),
    [sym_fields_keyword] = ACTIONS(13015),
    [sym_keys_keyword] = ACTIONS(13015),
    [sym_fieldgroups_keyword] = ACTIONS(13015),
    [sym_actions_keyword] = ACTIONS(13015),
    [sym_layout_keyword] = ACTIONS(13015),
    [sym_area_keyword] = ACTIONS(13015),
    [sym_group_keyword] = ACTIONS(13015),
    [sym_repeater_keyword] = ACTIONS(13015),
    [sym_cuegroup_keyword] = ACTIONS(13015),
    [sym_fixed_keyword] = ACTIONS(13015),
    [sym_grid_keyword] = ACTIONS(13015),
    [sym_part_keyword] = ACTIONS(13015),
    [sym_systempart_keyword] = ACTIONS(13015),
    [sym_usercontrol_keyword] = ACTIONS(13015),
    [sym_dataset_keyword] = ACTIONS(13015),
    [sym_elements_keyword] = ACTIONS(13015),
    [sym_dataitem_keyword] = ACTIONS(13015),
    [sym_column_keyword] = ACTIONS(13015),
    [sym_filter_keyword] = ACTIONS(13015),
    [sym_labels_keyword] = ACTIONS(13015),
    [sym_rendering_keyword] = ACTIONS(13015),
    [sym_requestpage_keyword] = ACTIONS(13015),
    [sym_schema_keyword] = ACTIONS(13015),
    [sym_views_keyword] = ACTIONS(13015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13015),
    [sym_preproc_open] = ACTIONS(13015),
    [sym_preproc_close] = ACTIONS(13015),
  },
  [STATE(5306)] = {
    [anon_sym_SEMI] = ACTIONS(13015),
    [aux_sym_where_condition_token1] = ACTIONS(13017),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13015),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13015),
    [anon_sym_LBRACK] = ACTIONS(13015),
    [aux_sym_basic_type_token6] = ACTIONS(13017),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13015),
    [aux_sym_addafter_modification_token1] = ACTIONS(13015),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13015),
    [aux_sym_modify_modification_token1] = ACTIONS(13015),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13015),
    [aux_sym_movelast_modification_token1] = ACTIONS(13015),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13015),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13015),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13015),
    [anon_sym_POUNDif] = ACTIONS(13015),
    [anon_sym_POUNDIF] = ACTIONS(13015),
    [anon_sym_POUNDIf] = ACTIONS(13015),
    [anon_sym_POUNDelif] = ACTIONS(13015),
    [anon_sym_POUNDELIF] = ACTIONS(13015),
    [anon_sym_POUNDElif] = ACTIONS(13015),
    [anon_sym_POUNDelse] = ACTIONS(13015),
    [anon_sym_POUNDELSE] = ACTIONS(13015),
    [anon_sym_POUNDElse] = ACTIONS(13015),
    [anon_sym_POUNDelse2] = ACTIONS(13015),
    [anon_sym_POUNDELSE2] = ACTIONS(13015),
    [anon_sym_POUNDElse2] = ACTIONS(13015),
    [anon_sym_POUNDendif] = ACTIONS(13015),
    [anon_sym_POUNDENDIF] = ACTIONS(13015),
    [anon_sym_POUNDEndif] = ACTIONS(13015),
    [anon_sym_POUNDendif2] = ACTIONS(13015),
    [anon_sym_POUNDENDIF2] = ACTIONS(13015),
    [anon_sym_POUNDEndif2] = ACTIONS(13015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13015),
    [sym_trigger_keyword] = ACTIONS(13015),
    [sym_var_keyword] = ACTIONS(13015),
    [sym_local_keyword] = ACTIONS(13015),
    [sym_internal_keyword] = ACTIONS(13015),
    [sym_protected_keyword] = ACTIONS(13015),
    [sym_event_keyword] = ACTIONS(13015),
    [sym_fields_keyword] = ACTIONS(13015),
    [sym_keys_keyword] = ACTIONS(13015),
    [sym_fieldgroups_keyword] = ACTIONS(13015),
    [sym_actions_keyword] = ACTIONS(13015),
    [sym_layout_keyword] = ACTIONS(13015),
    [sym_area_keyword] = ACTIONS(13015),
    [sym_group_keyword] = ACTIONS(13015),
    [sym_repeater_keyword] = ACTIONS(13015),
    [sym_cuegroup_keyword] = ACTIONS(13015),
    [sym_fixed_keyword] = ACTIONS(13015),
    [sym_grid_keyword] = ACTIONS(13015),
    [sym_part_keyword] = ACTIONS(13015),
    [sym_systempart_keyword] = ACTIONS(13015),
    [sym_usercontrol_keyword] = ACTIONS(13015),
    [sym_dataset_keyword] = ACTIONS(13015),
    [sym_elements_keyword] = ACTIONS(13015),
    [sym_dataitem_keyword] = ACTIONS(13015),
    [sym_column_keyword] = ACTIONS(13015),
    [sym_filter_keyword] = ACTIONS(13015),
    [sym_labels_keyword] = ACTIONS(13015),
    [sym_rendering_keyword] = ACTIONS(13015),
    [sym_requestpage_keyword] = ACTIONS(13015),
    [sym_schema_keyword] = ACTIONS(13015),
    [sym_views_keyword] = ACTIONS(13015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13015),
    [sym_preproc_open] = ACTIONS(13015),
    [sym_preproc_close] = ACTIONS(13015),
  },
  [STATE(5307)] = {
    [anon_sym_SEMI] = ACTIONS(13015),
    [aux_sym_where_condition_token1] = ACTIONS(13017),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13015),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13015),
    [anon_sym_LBRACK] = ACTIONS(13015),
    [aux_sym_basic_type_token6] = ACTIONS(13017),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13015),
    [aux_sym_addafter_modification_token1] = ACTIONS(13015),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13015),
    [aux_sym_modify_modification_token1] = ACTIONS(13015),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13015),
    [aux_sym_movelast_modification_token1] = ACTIONS(13015),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13015),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13015),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13015),
    [anon_sym_POUNDif] = ACTIONS(13015),
    [anon_sym_POUNDIF] = ACTIONS(13015),
    [anon_sym_POUNDIf] = ACTIONS(13015),
    [anon_sym_POUNDelif] = ACTIONS(13015),
    [anon_sym_POUNDELIF] = ACTIONS(13015),
    [anon_sym_POUNDElif] = ACTIONS(13015),
    [anon_sym_POUNDelse] = ACTIONS(13015),
    [anon_sym_POUNDELSE] = ACTIONS(13015),
    [anon_sym_POUNDElse] = ACTIONS(13015),
    [anon_sym_POUNDelse2] = ACTIONS(13015),
    [anon_sym_POUNDELSE2] = ACTIONS(13015),
    [anon_sym_POUNDElse2] = ACTIONS(13015),
    [anon_sym_POUNDendif] = ACTIONS(13015),
    [anon_sym_POUNDENDIF] = ACTIONS(13015),
    [anon_sym_POUNDEndif] = ACTIONS(13015),
    [anon_sym_POUNDendif2] = ACTIONS(13015),
    [anon_sym_POUNDENDIF2] = ACTIONS(13015),
    [anon_sym_POUNDEndif2] = ACTIONS(13015),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13015),
    [sym_trigger_keyword] = ACTIONS(13015),
    [sym_var_keyword] = ACTIONS(13015),
    [sym_local_keyword] = ACTIONS(13015),
    [sym_internal_keyword] = ACTIONS(13015),
    [sym_protected_keyword] = ACTIONS(13015),
    [sym_event_keyword] = ACTIONS(13015),
    [sym_fields_keyword] = ACTIONS(13015),
    [sym_keys_keyword] = ACTIONS(13015),
    [sym_fieldgroups_keyword] = ACTIONS(13015),
    [sym_actions_keyword] = ACTIONS(13015),
    [sym_layout_keyword] = ACTIONS(13015),
    [sym_area_keyword] = ACTIONS(13015),
    [sym_group_keyword] = ACTIONS(13015),
    [sym_repeater_keyword] = ACTIONS(13015),
    [sym_cuegroup_keyword] = ACTIONS(13015),
    [sym_fixed_keyword] = ACTIONS(13015),
    [sym_grid_keyword] = ACTIONS(13015),
    [sym_part_keyword] = ACTIONS(13015),
    [sym_systempart_keyword] = ACTIONS(13015),
    [sym_usercontrol_keyword] = ACTIONS(13015),
    [sym_dataset_keyword] = ACTIONS(13015),
    [sym_elements_keyword] = ACTIONS(13015),
    [sym_dataitem_keyword] = ACTIONS(13015),
    [sym_column_keyword] = ACTIONS(13015),
    [sym_filter_keyword] = ACTIONS(13015),
    [sym_labels_keyword] = ACTIONS(13015),
    [sym_rendering_keyword] = ACTIONS(13015),
    [sym_requestpage_keyword] = ACTIONS(13015),
    [sym_schema_keyword] = ACTIONS(13015),
    [sym_views_keyword] = ACTIONS(13015),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13015),
    [sym_preproc_open] = ACTIONS(13015),
    [sym_preproc_close] = ACTIONS(13015),
  },
  [STATE(5308)] = {
    [anon_sym_SEMI] = ACTIONS(13019),
    [aux_sym_where_condition_token1] = ACTIONS(13021),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13019),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13019),
    [anon_sym_LBRACK] = ACTIONS(13019),
    [aux_sym_basic_type_token6] = ACTIONS(13021),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13019),
    [aux_sym_addafter_modification_token1] = ACTIONS(13019),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13019),
    [aux_sym_modify_modification_token1] = ACTIONS(13019),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13019),
    [aux_sym_movelast_modification_token1] = ACTIONS(13019),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13019),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13019),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13019),
    [anon_sym_POUNDif] = ACTIONS(13019),
    [anon_sym_POUNDIF] = ACTIONS(13019),
    [anon_sym_POUNDIf] = ACTIONS(13019),
    [anon_sym_POUNDelif] = ACTIONS(13019),
    [anon_sym_POUNDELIF] = ACTIONS(13019),
    [anon_sym_POUNDElif] = ACTIONS(13019),
    [anon_sym_POUNDelse] = ACTIONS(13019),
    [anon_sym_POUNDELSE] = ACTIONS(13019),
    [anon_sym_POUNDElse] = ACTIONS(13019),
    [anon_sym_POUNDelse2] = ACTIONS(13019),
    [anon_sym_POUNDELSE2] = ACTIONS(13019),
    [anon_sym_POUNDElse2] = ACTIONS(13019),
    [anon_sym_POUNDendif] = ACTIONS(13019),
    [anon_sym_POUNDENDIF] = ACTIONS(13019),
    [anon_sym_POUNDEndif] = ACTIONS(13019),
    [anon_sym_POUNDendif2] = ACTIONS(13019),
    [anon_sym_POUNDENDIF2] = ACTIONS(13019),
    [anon_sym_POUNDEndif2] = ACTIONS(13019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13019),
    [sym_trigger_keyword] = ACTIONS(13019),
    [sym_var_keyword] = ACTIONS(13019),
    [sym_local_keyword] = ACTIONS(13019),
    [sym_internal_keyword] = ACTIONS(13019),
    [sym_protected_keyword] = ACTIONS(13019),
    [sym_event_keyword] = ACTIONS(13019),
    [sym_fields_keyword] = ACTIONS(13019),
    [sym_keys_keyword] = ACTIONS(13019),
    [sym_fieldgroups_keyword] = ACTIONS(13019),
    [sym_actions_keyword] = ACTIONS(13019),
    [sym_layout_keyword] = ACTIONS(13019),
    [sym_area_keyword] = ACTIONS(13019),
    [sym_group_keyword] = ACTIONS(13019),
    [sym_repeater_keyword] = ACTIONS(13019),
    [sym_cuegroup_keyword] = ACTIONS(13019),
    [sym_fixed_keyword] = ACTIONS(13019),
    [sym_grid_keyword] = ACTIONS(13019),
    [sym_part_keyword] = ACTIONS(13019),
    [sym_systempart_keyword] = ACTIONS(13019),
    [sym_usercontrol_keyword] = ACTIONS(13019),
    [sym_dataset_keyword] = ACTIONS(13019),
    [sym_elements_keyword] = ACTIONS(13019),
    [sym_dataitem_keyword] = ACTIONS(13019),
    [sym_column_keyword] = ACTIONS(13019),
    [sym_filter_keyword] = ACTIONS(13019),
    [sym_labels_keyword] = ACTIONS(13019),
    [sym_rendering_keyword] = ACTIONS(13019),
    [sym_requestpage_keyword] = ACTIONS(13019),
    [sym_schema_keyword] = ACTIONS(13019),
    [sym_views_keyword] = ACTIONS(13019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13019),
    [sym_preproc_open] = ACTIONS(13019),
    [sym_preproc_close] = ACTIONS(13019),
  },
  [STATE(5309)] = {
    [anon_sym_SEMI] = ACTIONS(13019),
    [aux_sym_where_condition_token1] = ACTIONS(13021),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13019),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13019),
    [anon_sym_LBRACK] = ACTIONS(13019),
    [aux_sym_basic_type_token6] = ACTIONS(13021),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13019),
    [aux_sym_addafter_modification_token1] = ACTIONS(13019),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13019),
    [aux_sym_modify_modification_token1] = ACTIONS(13019),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13019),
    [aux_sym_movelast_modification_token1] = ACTIONS(13019),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13019),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13019),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13019),
    [anon_sym_POUNDif] = ACTIONS(13019),
    [anon_sym_POUNDIF] = ACTIONS(13019),
    [anon_sym_POUNDIf] = ACTIONS(13019),
    [anon_sym_POUNDelif] = ACTIONS(13019),
    [anon_sym_POUNDELIF] = ACTIONS(13019),
    [anon_sym_POUNDElif] = ACTIONS(13019),
    [anon_sym_POUNDelse] = ACTIONS(13019),
    [anon_sym_POUNDELSE] = ACTIONS(13019),
    [anon_sym_POUNDElse] = ACTIONS(13019),
    [anon_sym_POUNDelse2] = ACTIONS(13019),
    [anon_sym_POUNDELSE2] = ACTIONS(13019),
    [anon_sym_POUNDElse2] = ACTIONS(13019),
    [anon_sym_POUNDendif] = ACTIONS(13019),
    [anon_sym_POUNDENDIF] = ACTIONS(13019),
    [anon_sym_POUNDEndif] = ACTIONS(13019),
    [anon_sym_POUNDendif2] = ACTIONS(13019),
    [anon_sym_POUNDENDIF2] = ACTIONS(13019),
    [anon_sym_POUNDEndif2] = ACTIONS(13019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13019),
    [sym_trigger_keyword] = ACTIONS(13019),
    [sym_var_keyword] = ACTIONS(13019),
    [sym_local_keyword] = ACTIONS(13019),
    [sym_internal_keyword] = ACTIONS(13019),
    [sym_protected_keyword] = ACTIONS(13019),
    [sym_event_keyword] = ACTIONS(13019),
    [sym_fields_keyword] = ACTIONS(13019),
    [sym_keys_keyword] = ACTIONS(13019),
    [sym_fieldgroups_keyword] = ACTIONS(13019),
    [sym_actions_keyword] = ACTIONS(13019),
    [sym_layout_keyword] = ACTIONS(13019),
    [sym_area_keyword] = ACTIONS(13019),
    [sym_group_keyword] = ACTIONS(13019),
    [sym_repeater_keyword] = ACTIONS(13019),
    [sym_cuegroup_keyword] = ACTIONS(13019),
    [sym_fixed_keyword] = ACTIONS(13019),
    [sym_grid_keyword] = ACTIONS(13019),
    [sym_part_keyword] = ACTIONS(13019),
    [sym_systempart_keyword] = ACTIONS(13019),
    [sym_usercontrol_keyword] = ACTIONS(13019),
    [sym_dataset_keyword] = ACTIONS(13019),
    [sym_elements_keyword] = ACTIONS(13019),
    [sym_dataitem_keyword] = ACTIONS(13019),
    [sym_column_keyword] = ACTIONS(13019),
    [sym_filter_keyword] = ACTIONS(13019),
    [sym_labels_keyword] = ACTIONS(13019),
    [sym_rendering_keyword] = ACTIONS(13019),
    [sym_requestpage_keyword] = ACTIONS(13019),
    [sym_schema_keyword] = ACTIONS(13019),
    [sym_views_keyword] = ACTIONS(13019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13019),
    [sym_preproc_open] = ACTIONS(13019),
    [sym_preproc_close] = ACTIONS(13019),
  },
  [STATE(5310)] = {
    [anon_sym_SEMI] = ACTIONS(13019),
    [aux_sym_where_condition_token1] = ACTIONS(13021),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13019),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13019),
    [anon_sym_LBRACK] = ACTIONS(13019),
    [aux_sym_basic_type_token6] = ACTIONS(13021),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13019),
    [aux_sym_addafter_modification_token1] = ACTIONS(13019),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13019),
    [aux_sym_modify_modification_token1] = ACTIONS(13019),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13019),
    [aux_sym_movelast_modification_token1] = ACTIONS(13019),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13019),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13019),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13019),
    [anon_sym_POUNDif] = ACTIONS(13019),
    [anon_sym_POUNDIF] = ACTIONS(13019),
    [anon_sym_POUNDIf] = ACTIONS(13019),
    [anon_sym_POUNDelif] = ACTIONS(13019),
    [anon_sym_POUNDELIF] = ACTIONS(13019),
    [anon_sym_POUNDElif] = ACTIONS(13019),
    [anon_sym_POUNDelse] = ACTIONS(13019),
    [anon_sym_POUNDELSE] = ACTIONS(13019),
    [anon_sym_POUNDElse] = ACTIONS(13019),
    [anon_sym_POUNDelse2] = ACTIONS(13019),
    [anon_sym_POUNDELSE2] = ACTIONS(13019),
    [anon_sym_POUNDElse2] = ACTIONS(13019),
    [anon_sym_POUNDendif] = ACTIONS(13019),
    [anon_sym_POUNDENDIF] = ACTIONS(13019),
    [anon_sym_POUNDEndif] = ACTIONS(13019),
    [anon_sym_POUNDendif2] = ACTIONS(13019),
    [anon_sym_POUNDENDIF2] = ACTIONS(13019),
    [anon_sym_POUNDEndif2] = ACTIONS(13019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13019),
    [sym_trigger_keyword] = ACTIONS(13019),
    [sym_var_keyword] = ACTIONS(13019),
    [sym_local_keyword] = ACTIONS(13019),
    [sym_internal_keyword] = ACTIONS(13019),
    [sym_protected_keyword] = ACTIONS(13019),
    [sym_event_keyword] = ACTIONS(13019),
    [sym_fields_keyword] = ACTIONS(13019),
    [sym_keys_keyword] = ACTIONS(13019),
    [sym_fieldgroups_keyword] = ACTIONS(13019),
    [sym_actions_keyword] = ACTIONS(13019),
    [sym_layout_keyword] = ACTIONS(13019),
    [sym_area_keyword] = ACTIONS(13019),
    [sym_group_keyword] = ACTIONS(13019),
    [sym_repeater_keyword] = ACTIONS(13019),
    [sym_cuegroup_keyword] = ACTIONS(13019),
    [sym_fixed_keyword] = ACTIONS(13019),
    [sym_grid_keyword] = ACTIONS(13019),
    [sym_part_keyword] = ACTIONS(13019),
    [sym_systempart_keyword] = ACTIONS(13019),
    [sym_usercontrol_keyword] = ACTIONS(13019),
    [sym_dataset_keyword] = ACTIONS(13019),
    [sym_elements_keyword] = ACTIONS(13019),
    [sym_dataitem_keyword] = ACTIONS(13019),
    [sym_column_keyword] = ACTIONS(13019),
    [sym_filter_keyword] = ACTIONS(13019),
    [sym_labels_keyword] = ACTIONS(13019),
    [sym_rendering_keyword] = ACTIONS(13019),
    [sym_requestpage_keyword] = ACTIONS(13019),
    [sym_schema_keyword] = ACTIONS(13019),
    [sym_views_keyword] = ACTIONS(13019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13019),
    [sym_preproc_open] = ACTIONS(13019),
    [sym_preproc_close] = ACTIONS(13019),
  },
  [STATE(5311)] = {
    [anon_sym_SEMI] = ACTIONS(13019),
    [aux_sym_where_condition_token1] = ACTIONS(13021),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13019),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13019),
    [anon_sym_LBRACK] = ACTIONS(13019),
    [aux_sym_basic_type_token6] = ACTIONS(13021),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13019),
    [aux_sym_addafter_modification_token1] = ACTIONS(13019),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13019),
    [aux_sym_modify_modification_token1] = ACTIONS(13019),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13019),
    [aux_sym_movelast_modification_token1] = ACTIONS(13019),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13019),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13019),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13019),
    [anon_sym_POUNDif] = ACTIONS(13019),
    [anon_sym_POUNDIF] = ACTIONS(13019),
    [anon_sym_POUNDIf] = ACTIONS(13019),
    [anon_sym_POUNDelif] = ACTIONS(13019),
    [anon_sym_POUNDELIF] = ACTIONS(13019),
    [anon_sym_POUNDElif] = ACTIONS(13019),
    [anon_sym_POUNDelse] = ACTIONS(13019),
    [anon_sym_POUNDELSE] = ACTIONS(13019),
    [anon_sym_POUNDElse] = ACTIONS(13019),
    [anon_sym_POUNDelse2] = ACTIONS(13019),
    [anon_sym_POUNDELSE2] = ACTIONS(13019),
    [anon_sym_POUNDElse2] = ACTIONS(13019),
    [anon_sym_POUNDendif] = ACTIONS(13019),
    [anon_sym_POUNDENDIF] = ACTIONS(13019),
    [anon_sym_POUNDEndif] = ACTIONS(13019),
    [anon_sym_POUNDendif2] = ACTIONS(13019),
    [anon_sym_POUNDENDIF2] = ACTIONS(13019),
    [anon_sym_POUNDEndif2] = ACTIONS(13019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13019),
    [sym_trigger_keyword] = ACTIONS(13019),
    [sym_var_keyword] = ACTIONS(13019),
    [sym_local_keyword] = ACTIONS(13019),
    [sym_internal_keyword] = ACTIONS(13019),
    [sym_protected_keyword] = ACTIONS(13019),
    [sym_event_keyword] = ACTIONS(13019),
    [sym_fields_keyword] = ACTIONS(13019),
    [sym_keys_keyword] = ACTIONS(13019),
    [sym_fieldgroups_keyword] = ACTIONS(13019),
    [sym_actions_keyword] = ACTIONS(13019),
    [sym_layout_keyword] = ACTIONS(13019),
    [sym_area_keyword] = ACTIONS(13019),
    [sym_group_keyword] = ACTIONS(13019),
    [sym_repeater_keyword] = ACTIONS(13019),
    [sym_cuegroup_keyword] = ACTIONS(13019),
    [sym_fixed_keyword] = ACTIONS(13019),
    [sym_grid_keyword] = ACTIONS(13019),
    [sym_part_keyword] = ACTIONS(13019),
    [sym_systempart_keyword] = ACTIONS(13019),
    [sym_usercontrol_keyword] = ACTIONS(13019),
    [sym_dataset_keyword] = ACTIONS(13019),
    [sym_elements_keyword] = ACTIONS(13019),
    [sym_dataitem_keyword] = ACTIONS(13019),
    [sym_column_keyword] = ACTIONS(13019),
    [sym_filter_keyword] = ACTIONS(13019),
    [sym_labels_keyword] = ACTIONS(13019),
    [sym_rendering_keyword] = ACTIONS(13019),
    [sym_requestpage_keyword] = ACTIONS(13019),
    [sym_schema_keyword] = ACTIONS(13019),
    [sym_views_keyword] = ACTIONS(13019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13019),
    [sym_preproc_open] = ACTIONS(13019),
    [sym_preproc_close] = ACTIONS(13019),
  },
  [STATE(5312)] = {
    [anon_sym_SEMI] = ACTIONS(13019),
    [aux_sym_where_condition_token1] = ACTIONS(13021),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13019),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13019),
    [anon_sym_LBRACK] = ACTIONS(13019),
    [aux_sym_basic_type_token6] = ACTIONS(13021),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13019),
    [aux_sym_addafter_modification_token1] = ACTIONS(13019),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13019),
    [aux_sym_modify_modification_token1] = ACTIONS(13019),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13019),
    [aux_sym_movelast_modification_token1] = ACTIONS(13019),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13019),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13019),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13019),
    [anon_sym_POUNDif] = ACTIONS(13019),
    [anon_sym_POUNDIF] = ACTIONS(13019),
    [anon_sym_POUNDIf] = ACTIONS(13019),
    [anon_sym_POUNDelif] = ACTIONS(13019),
    [anon_sym_POUNDELIF] = ACTIONS(13019),
    [anon_sym_POUNDElif] = ACTIONS(13019),
    [anon_sym_POUNDelse] = ACTIONS(13019),
    [anon_sym_POUNDELSE] = ACTIONS(13019),
    [anon_sym_POUNDElse] = ACTIONS(13019),
    [anon_sym_POUNDelse2] = ACTIONS(13019),
    [anon_sym_POUNDELSE2] = ACTIONS(13019),
    [anon_sym_POUNDElse2] = ACTIONS(13019),
    [anon_sym_POUNDendif] = ACTIONS(13019),
    [anon_sym_POUNDENDIF] = ACTIONS(13019),
    [anon_sym_POUNDEndif] = ACTIONS(13019),
    [anon_sym_POUNDendif2] = ACTIONS(13019),
    [anon_sym_POUNDENDIF2] = ACTIONS(13019),
    [anon_sym_POUNDEndif2] = ACTIONS(13019),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13019),
    [sym_trigger_keyword] = ACTIONS(13019),
    [sym_var_keyword] = ACTIONS(13019),
    [sym_local_keyword] = ACTIONS(13019),
    [sym_internal_keyword] = ACTIONS(13019),
    [sym_protected_keyword] = ACTIONS(13019),
    [sym_event_keyword] = ACTIONS(13019),
    [sym_fields_keyword] = ACTIONS(13019),
    [sym_keys_keyword] = ACTIONS(13019),
    [sym_fieldgroups_keyword] = ACTIONS(13019),
    [sym_actions_keyword] = ACTIONS(13019),
    [sym_layout_keyword] = ACTIONS(13019),
    [sym_area_keyword] = ACTIONS(13019),
    [sym_group_keyword] = ACTIONS(13019),
    [sym_repeater_keyword] = ACTIONS(13019),
    [sym_cuegroup_keyword] = ACTIONS(13019),
    [sym_fixed_keyword] = ACTIONS(13019),
    [sym_grid_keyword] = ACTIONS(13019),
    [sym_part_keyword] = ACTIONS(13019),
    [sym_systempart_keyword] = ACTIONS(13019),
    [sym_usercontrol_keyword] = ACTIONS(13019),
    [sym_dataset_keyword] = ACTIONS(13019),
    [sym_elements_keyword] = ACTIONS(13019),
    [sym_dataitem_keyword] = ACTIONS(13019),
    [sym_column_keyword] = ACTIONS(13019),
    [sym_filter_keyword] = ACTIONS(13019),
    [sym_labels_keyword] = ACTIONS(13019),
    [sym_rendering_keyword] = ACTIONS(13019),
    [sym_requestpage_keyword] = ACTIONS(13019),
    [sym_schema_keyword] = ACTIONS(13019),
    [sym_views_keyword] = ACTIONS(13019),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13019),
    [sym_preproc_open] = ACTIONS(13019),
    [sym_preproc_close] = ACTIONS(13019),
  },
  [STATE(5313)] = {
    [anon_sym_SEMI] = ACTIONS(13023),
    [aux_sym_where_condition_token1] = ACTIONS(13025),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13023),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13023),
    [anon_sym_LBRACK] = ACTIONS(13023),
    [aux_sym_basic_type_token6] = ACTIONS(13025),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13023),
    [aux_sym_addafter_modification_token1] = ACTIONS(13023),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13023),
    [aux_sym_modify_modification_token1] = ACTIONS(13023),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13023),
    [aux_sym_movelast_modification_token1] = ACTIONS(13023),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13023),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13023),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13023),
    [anon_sym_POUNDif] = ACTIONS(13023),
    [anon_sym_POUNDIF] = ACTIONS(13023),
    [anon_sym_POUNDIf] = ACTIONS(13023),
    [anon_sym_POUNDelif] = ACTIONS(13023),
    [anon_sym_POUNDELIF] = ACTIONS(13023),
    [anon_sym_POUNDElif] = ACTIONS(13023),
    [anon_sym_POUNDelse] = ACTIONS(13023),
    [anon_sym_POUNDELSE] = ACTIONS(13023),
    [anon_sym_POUNDElse] = ACTIONS(13023),
    [anon_sym_POUNDelse2] = ACTIONS(13023),
    [anon_sym_POUNDELSE2] = ACTIONS(13023),
    [anon_sym_POUNDElse2] = ACTIONS(13023),
    [anon_sym_POUNDendif] = ACTIONS(13023),
    [anon_sym_POUNDENDIF] = ACTIONS(13023),
    [anon_sym_POUNDEndif] = ACTIONS(13023),
    [anon_sym_POUNDendif2] = ACTIONS(13023),
    [anon_sym_POUNDENDIF2] = ACTIONS(13023),
    [anon_sym_POUNDEndif2] = ACTIONS(13023),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13023),
    [sym_trigger_keyword] = ACTIONS(13023),
    [sym_var_keyword] = ACTIONS(13023),
    [sym_local_keyword] = ACTIONS(13023),
    [sym_internal_keyword] = ACTIONS(13023),
    [sym_protected_keyword] = ACTIONS(13023),
    [sym_event_keyword] = ACTIONS(13023),
    [sym_fields_keyword] = ACTIONS(13023),
    [sym_keys_keyword] = ACTIONS(13023),
    [sym_fieldgroups_keyword] = ACTIONS(13023),
    [sym_actions_keyword] = ACTIONS(13023),
    [sym_layout_keyword] = ACTIONS(13023),
    [sym_area_keyword] = ACTIONS(13023),
    [sym_group_keyword] = ACTIONS(13023),
    [sym_repeater_keyword] = ACTIONS(13023),
    [sym_cuegroup_keyword] = ACTIONS(13023),
    [sym_fixed_keyword] = ACTIONS(13023),
    [sym_grid_keyword] = ACTIONS(13023),
    [sym_part_keyword] = ACTIONS(13023),
    [sym_systempart_keyword] = ACTIONS(13023),
    [sym_usercontrol_keyword] = ACTIONS(13023),
    [sym_dataset_keyword] = ACTIONS(13023),
    [sym_elements_keyword] = ACTIONS(13023),
    [sym_dataitem_keyword] = ACTIONS(13023),
    [sym_column_keyword] = ACTIONS(13023),
    [sym_filter_keyword] = ACTIONS(13023),
    [sym_labels_keyword] = ACTIONS(13023),
    [sym_rendering_keyword] = ACTIONS(13023),
    [sym_requestpage_keyword] = ACTIONS(13023),
    [sym_schema_keyword] = ACTIONS(13023),
    [sym_views_keyword] = ACTIONS(13023),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13023),
    [sym_preproc_open] = ACTIONS(13023),
    [sym_preproc_close] = ACTIONS(13023),
  },
  [STATE(5314)] = {
    [anon_sym_SEMI] = ACTIONS(8442),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8442),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8442),
    [anon_sym_LBRACK] = ACTIONS(8442),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8442),
    [aux_sym_modify_modification_token1] = ACTIONS(8442),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8442),
    [anon_sym_POUNDif] = ACTIONS(8442),
    [anon_sym_POUNDIF] = ACTIONS(8442),
    [anon_sym_POUNDIf] = ACTIONS(8442),
    [anon_sym_POUNDelif] = ACTIONS(8442),
    [anon_sym_POUNDELIF] = ACTIONS(8442),
    [anon_sym_POUNDElif] = ACTIONS(8442),
    [anon_sym_POUNDelse] = ACTIONS(8442),
    [anon_sym_POUNDELSE] = ACTIONS(8442),
    [anon_sym_POUNDElse] = ACTIONS(8442),
    [anon_sym_POUNDelse2] = ACTIONS(8442),
    [anon_sym_POUNDELSE2] = ACTIONS(8442),
    [anon_sym_POUNDElse2] = ACTIONS(8442),
    [anon_sym_POUNDendif] = ACTIONS(8442),
    [anon_sym_POUNDENDIF] = ACTIONS(8442),
    [anon_sym_POUNDEndif] = ACTIONS(8442),
    [anon_sym_POUNDendif2] = ACTIONS(8442),
    [anon_sym_POUNDENDIF2] = ACTIONS(8442),
    [anon_sym_POUNDEndif2] = ACTIONS(8442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8444),
    [sym_page_keyword] = ACTIONS(8442),
    [anon_sym_codeunit] = ACTIONS(8442),
    [anon_sym_CODEUNIT] = ACTIONS(8442),
    [anon_sym_Codeunit] = ACTIONS(8442),
    [anon_sym_CodeUnit] = ACTIONS(8442),
    [anon_sym_COdeunit] = ACTIONS(8442),
    [anon_sym_codeUnit] = ACTIONS(8442),
    [sym_report_keyword] = ACTIONS(8442),
    [sym_query_keyword] = ACTIONS(8442),
    [anon_sym_xmlport] = ACTIONS(8442),
    [anon_sym_XMLPORT] = ACTIONS(8442),
    [anon_sym_Xmlport] = ACTIONS(8442),
    [anon_sym_XMLport] = ACTIONS(8442),
    [anon_sym_XMLPort] = ACTIONS(8442),
    [anon_sym_XmlPort] = ACTIONS(8442),
    [sym_procedure_keyword] = ACTIONS(8442),
    [sym_trigger_keyword] = ACTIONS(8442),
    [sym_var_keyword] = ACTIONS(8442),
    [sym_local_keyword] = ACTIONS(8442),
    [sym_internal_keyword] = ACTIONS(8442),
    [sym_protected_keyword] = ACTIONS(8442),
    [sym_event_keyword] = ACTIONS(8442),
    [sym_fields_keyword] = ACTIONS(8442),
    [sym_keys_keyword] = ACTIONS(8442),
    [sym_fieldgroups_keyword] = ACTIONS(8442),
    [sym_actions_keyword] = ACTIONS(8442),
    [sym_layout_keyword] = ACTIONS(8442),
    [sym_dataset_keyword] = ACTIONS(8442),
    [sym_elements_keyword] = ACTIONS(8442),
    [sym_dataitem_keyword] = ACTIONS(8442),
    [sym_column_keyword] = ACTIONS(8442),
    [sym_filter_keyword] = ACTIONS(8442),
    [sym_labels_keyword] = ACTIONS(8442),
    [sym_rendering_keyword] = ACTIONS(8442),
    [sym_requestpage_keyword] = ACTIONS(8442),
    [sym_schema_keyword] = ACTIONS(8442),
    [sym_views_keyword] = ACTIONS(8442),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8442),
    [sym_preproc_open] = ACTIONS(8442),
    [sym_preproc_close] = ACTIONS(8442),
  },
  [STATE(5315)] = {
    [anon_sym_SEMI] = ACTIONS(8430),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8430),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8430),
    [anon_sym_LBRACK] = ACTIONS(8430),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8430),
    [aux_sym_modify_modification_token1] = ACTIONS(8430),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8430),
    [anon_sym_POUNDif] = ACTIONS(8430),
    [anon_sym_POUNDIF] = ACTIONS(8430),
    [anon_sym_POUNDIf] = ACTIONS(8430),
    [anon_sym_POUNDelif] = ACTIONS(8430),
    [anon_sym_POUNDELIF] = ACTIONS(8430),
    [anon_sym_POUNDElif] = ACTIONS(8430),
    [anon_sym_POUNDelse] = ACTIONS(8430),
    [anon_sym_POUNDELSE] = ACTIONS(8430),
    [anon_sym_POUNDElse] = ACTIONS(8430),
    [anon_sym_POUNDelse2] = ACTIONS(8430),
    [anon_sym_POUNDELSE2] = ACTIONS(8430),
    [anon_sym_POUNDElse2] = ACTIONS(8430),
    [anon_sym_POUNDendif] = ACTIONS(8430),
    [anon_sym_POUNDENDIF] = ACTIONS(8430),
    [anon_sym_POUNDEndif] = ACTIONS(8430),
    [anon_sym_POUNDendif2] = ACTIONS(8430),
    [anon_sym_POUNDENDIF2] = ACTIONS(8430),
    [anon_sym_POUNDEndif2] = ACTIONS(8430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8432),
    [sym_page_keyword] = ACTIONS(8430),
    [anon_sym_codeunit] = ACTIONS(8430),
    [anon_sym_CODEUNIT] = ACTIONS(8430),
    [anon_sym_Codeunit] = ACTIONS(8430),
    [anon_sym_CodeUnit] = ACTIONS(8430),
    [anon_sym_COdeunit] = ACTIONS(8430),
    [anon_sym_codeUnit] = ACTIONS(8430),
    [sym_report_keyword] = ACTIONS(8430),
    [sym_query_keyword] = ACTIONS(8430),
    [anon_sym_xmlport] = ACTIONS(8430),
    [anon_sym_XMLPORT] = ACTIONS(8430),
    [anon_sym_Xmlport] = ACTIONS(8430),
    [anon_sym_XMLport] = ACTIONS(8430),
    [anon_sym_XMLPort] = ACTIONS(8430),
    [anon_sym_XmlPort] = ACTIONS(8430),
    [sym_procedure_keyword] = ACTIONS(8430),
    [sym_trigger_keyword] = ACTIONS(8430),
    [sym_var_keyword] = ACTIONS(8430),
    [sym_local_keyword] = ACTIONS(8430),
    [sym_internal_keyword] = ACTIONS(8430),
    [sym_protected_keyword] = ACTIONS(8430),
    [sym_event_keyword] = ACTIONS(8430),
    [sym_fields_keyword] = ACTIONS(8430),
    [sym_keys_keyword] = ACTIONS(8430),
    [sym_fieldgroups_keyword] = ACTIONS(8430),
    [sym_actions_keyword] = ACTIONS(8430),
    [sym_layout_keyword] = ACTIONS(8430),
    [sym_dataset_keyword] = ACTIONS(8430),
    [sym_elements_keyword] = ACTIONS(8430),
    [sym_dataitem_keyword] = ACTIONS(8430),
    [sym_column_keyword] = ACTIONS(8430),
    [sym_filter_keyword] = ACTIONS(8430),
    [sym_labels_keyword] = ACTIONS(8430),
    [sym_rendering_keyword] = ACTIONS(8430),
    [sym_requestpage_keyword] = ACTIONS(8430),
    [sym_schema_keyword] = ACTIONS(8430),
    [sym_views_keyword] = ACTIONS(8430),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8430),
    [sym_preproc_open] = ACTIONS(8430),
    [sym_preproc_close] = ACTIONS(8430),
  },
  [STATE(5316)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [anon_sym_RBRACE] = ACTIONS(13027),
    [aux_sym_where_condition_token1] = ACTIONS(13029),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13032),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13035),
    [aux_sym_basic_type_token6] = ACTIONS(13038),
    [aux_sym_addafter_modification_token1] = ACTIONS(13041),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13044),
    [aux_sym_modify_modification_token1] = ACTIONS(13047),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13050),
    [aux_sym_movelast_modification_token1] = ACTIONS(13053),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13056),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13059),
    [anon_sym_POUNDif] = ACTIONS(13062),
    [anon_sym_POUNDIF] = ACTIONS(13062),
    [anon_sym_POUNDIf] = ACTIONS(13062),
    [anon_sym_POUNDelif] = ACTIONS(13027),
    [anon_sym_POUNDELIF] = ACTIONS(13027),
    [anon_sym_POUNDElif] = ACTIONS(13027),
    [anon_sym_POUNDelse] = ACTIONS(13027),
    [anon_sym_POUNDELSE] = ACTIONS(13027),
    [anon_sym_POUNDElse] = ACTIONS(13027),
    [anon_sym_POUNDelse2] = ACTIONS(13027),
    [anon_sym_POUNDELSE2] = ACTIONS(13027),
    [anon_sym_POUNDElse2] = ACTIONS(13027),
    [anon_sym_POUNDendif] = ACTIONS(13027),
    [anon_sym_POUNDENDIF] = ACTIONS(13027),
    [anon_sym_POUNDEndif] = ACTIONS(13027),
    [anon_sym_POUNDendif2] = ACTIONS(13027),
    [anon_sym_POUNDENDIF2] = ACTIONS(13027),
    [anon_sym_POUNDEndif2] = ACTIONS(13027),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(13065),
    [sym_group_keyword] = ACTIONS(13068),
    [sym_repeater_keyword] = ACTIONS(13071),
    [sym_cuegroup_keyword] = ACTIONS(13074),
    [sym_fixed_keyword] = ACTIONS(13077),
    [sym_grid_keyword] = ACTIONS(13080),
    [sym_part_keyword] = ACTIONS(13083),
    [sym_systempart_keyword] = ACTIONS(13086),
    [sym_usercontrol_keyword] = ACTIONS(13089),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(13062),
    [sym_preproc_close] = ACTIONS(13027),
  },
  [STATE(5317)] = {
    [anon_sym_SEMI] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7785),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7785),
    [anon_sym_POUNDIF] = ACTIONS(7785),
    [anon_sym_POUNDIf] = ACTIONS(7785),
    [anon_sym_POUNDelif] = ACTIONS(7785),
    [anon_sym_POUNDELIF] = ACTIONS(7785),
    [anon_sym_POUNDElif] = ACTIONS(7785),
    [anon_sym_POUNDelse] = ACTIONS(7785),
    [anon_sym_POUNDELSE] = ACTIONS(7785),
    [anon_sym_POUNDElse] = ACTIONS(7785),
    [anon_sym_POUNDelse2] = ACTIONS(7785),
    [anon_sym_POUNDELSE2] = ACTIONS(7785),
    [anon_sym_POUNDElse2] = ACTIONS(7785),
    [anon_sym_POUNDendif] = ACTIONS(7785),
    [anon_sym_POUNDENDIF] = ACTIONS(7785),
    [anon_sym_POUNDEndif] = ACTIONS(7785),
    [anon_sym_POUNDendif2] = ACTIONS(7785),
    [anon_sym_POUNDENDIF2] = ACTIONS(7785),
    [anon_sym_POUNDEndif2] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7787),
    [sym_page_keyword] = ACTIONS(7785),
    [anon_sym_codeunit] = ACTIONS(7785),
    [anon_sym_CODEUNIT] = ACTIONS(7785),
    [anon_sym_Codeunit] = ACTIONS(7785),
    [anon_sym_CodeUnit] = ACTIONS(7785),
    [anon_sym_COdeunit] = ACTIONS(7785),
    [anon_sym_codeUnit] = ACTIONS(7785),
    [sym_report_keyword] = ACTIONS(7785),
    [sym_query_keyword] = ACTIONS(7785),
    [anon_sym_xmlport] = ACTIONS(7785),
    [anon_sym_XMLPORT] = ACTIONS(7785),
    [anon_sym_Xmlport] = ACTIONS(7785),
    [anon_sym_XMLport] = ACTIONS(7785),
    [anon_sym_XMLPort] = ACTIONS(7785),
    [anon_sym_XmlPort] = ACTIONS(7785),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_dataitem_keyword] = ACTIONS(7785),
    [sym_column_keyword] = ACTIONS(7785),
    [sym_filter_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7785),
    [sym_preproc_close] = ACTIONS(7785),
  },
  [STATE(5318)] = {
    [anon_sym_SEMI] = ACTIONS(8434),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8434),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8434),
    [anon_sym_LBRACK] = ACTIONS(8434),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8434),
    [aux_sym_modify_modification_token1] = ACTIONS(8434),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8434),
    [anon_sym_POUNDif] = ACTIONS(8434),
    [anon_sym_POUNDIF] = ACTIONS(8434),
    [anon_sym_POUNDIf] = ACTIONS(8434),
    [anon_sym_POUNDelif] = ACTIONS(8434),
    [anon_sym_POUNDELIF] = ACTIONS(8434),
    [anon_sym_POUNDElif] = ACTIONS(8434),
    [anon_sym_POUNDelse] = ACTIONS(8434),
    [anon_sym_POUNDELSE] = ACTIONS(8434),
    [anon_sym_POUNDElse] = ACTIONS(8434),
    [anon_sym_POUNDelse2] = ACTIONS(8434),
    [anon_sym_POUNDELSE2] = ACTIONS(8434),
    [anon_sym_POUNDElse2] = ACTIONS(8434),
    [anon_sym_POUNDendif] = ACTIONS(8434),
    [anon_sym_POUNDENDIF] = ACTIONS(8434),
    [anon_sym_POUNDEndif] = ACTIONS(8434),
    [anon_sym_POUNDendif2] = ACTIONS(8434),
    [anon_sym_POUNDENDIF2] = ACTIONS(8434),
    [anon_sym_POUNDEndif2] = ACTIONS(8434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8436),
    [sym_page_keyword] = ACTIONS(8434),
    [anon_sym_codeunit] = ACTIONS(8434),
    [anon_sym_CODEUNIT] = ACTIONS(8434),
    [anon_sym_Codeunit] = ACTIONS(8434),
    [anon_sym_CodeUnit] = ACTIONS(8434),
    [anon_sym_COdeunit] = ACTIONS(8434),
    [anon_sym_codeUnit] = ACTIONS(8434),
    [sym_report_keyword] = ACTIONS(8434),
    [sym_query_keyword] = ACTIONS(8434),
    [anon_sym_xmlport] = ACTIONS(8434),
    [anon_sym_XMLPORT] = ACTIONS(8434),
    [anon_sym_Xmlport] = ACTIONS(8434),
    [anon_sym_XMLport] = ACTIONS(8434),
    [anon_sym_XMLPort] = ACTIONS(8434),
    [anon_sym_XmlPort] = ACTIONS(8434),
    [sym_procedure_keyword] = ACTIONS(8434),
    [sym_trigger_keyword] = ACTIONS(8434),
    [sym_var_keyword] = ACTIONS(8434),
    [sym_local_keyword] = ACTIONS(8434),
    [sym_internal_keyword] = ACTIONS(8434),
    [sym_protected_keyword] = ACTIONS(8434),
    [sym_event_keyword] = ACTIONS(8434),
    [sym_fields_keyword] = ACTIONS(8434),
    [sym_keys_keyword] = ACTIONS(8434),
    [sym_fieldgroups_keyword] = ACTIONS(8434),
    [sym_actions_keyword] = ACTIONS(8434),
    [sym_layout_keyword] = ACTIONS(8434),
    [sym_dataset_keyword] = ACTIONS(8434),
    [sym_elements_keyword] = ACTIONS(8434),
    [sym_dataitem_keyword] = ACTIONS(8434),
    [sym_column_keyword] = ACTIONS(8434),
    [sym_filter_keyword] = ACTIONS(8434),
    [sym_labels_keyword] = ACTIONS(8434),
    [sym_rendering_keyword] = ACTIONS(8434),
    [sym_requestpage_keyword] = ACTIONS(8434),
    [sym_schema_keyword] = ACTIONS(8434),
    [sym_views_keyword] = ACTIONS(8434),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8434),
    [sym_preproc_open] = ACTIONS(8434),
    [sym_preproc_close] = ACTIONS(8434),
  },
  [STATE(5319)] = {
    [anon_sym_SEMI] = ACTIONS(8438),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8438),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8438),
    [anon_sym_LBRACK] = ACTIONS(8438),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8438),
    [aux_sym_modify_modification_token1] = ACTIONS(8438),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8438),
    [anon_sym_POUNDif] = ACTIONS(8438),
    [anon_sym_POUNDIF] = ACTIONS(8438),
    [anon_sym_POUNDIf] = ACTIONS(8438),
    [anon_sym_POUNDelif] = ACTIONS(8438),
    [anon_sym_POUNDELIF] = ACTIONS(8438),
    [anon_sym_POUNDElif] = ACTIONS(8438),
    [anon_sym_POUNDelse] = ACTIONS(8438),
    [anon_sym_POUNDELSE] = ACTIONS(8438),
    [anon_sym_POUNDElse] = ACTIONS(8438),
    [anon_sym_POUNDelse2] = ACTIONS(8438),
    [anon_sym_POUNDELSE2] = ACTIONS(8438),
    [anon_sym_POUNDElse2] = ACTIONS(8438),
    [anon_sym_POUNDendif] = ACTIONS(8438),
    [anon_sym_POUNDENDIF] = ACTIONS(8438),
    [anon_sym_POUNDEndif] = ACTIONS(8438),
    [anon_sym_POUNDendif2] = ACTIONS(8438),
    [anon_sym_POUNDENDIF2] = ACTIONS(8438),
    [anon_sym_POUNDEndif2] = ACTIONS(8438),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8440),
    [sym_page_keyword] = ACTIONS(8438),
    [anon_sym_codeunit] = ACTIONS(8438),
    [anon_sym_CODEUNIT] = ACTIONS(8438),
    [anon_sym_Codeunit] = ACTIONS(8438),
    [anon_sym_CodeUnit] = ACTIONS(8438),
    [anon_sym_COdeunit] = ACTIONS(8438),
    [anon_sym_codeUnit] = ACTIONS(8438),
    [sym_report_keyword] = ACTIONS(8438),
    [sym_query_keyword] = ACTIONS(8438),
    [anon_sym_xmlport] = ACTIONS(8438),
    [anon_sym_XMLPORT] = ACTIONS(8438),
    [anon_sym_Xmlport] = ACTIONS(8438),
    [anon_sym_XMLport] = ACTIONS(8438),
    [anon_sym_XMLPort] = ACTIONS(8438),
    [anon_sym_XmlPort] = ACTIONS(8438),
    [sym_procedure_keyword] = ACTIONS(8438),
    [sym_trigger_keyword] = ACTIONS(8438),
    [sym_var_keyword] = ACTIONS(8438),
    [sym_local_keyword] = ACTIONS(8438),
    [sym_internal_keyword] = ACTIONS(8438),
    [sym_protected_keyword] = ACTIONS(8438),
    [sym_event_keyword] = ACTIONS(8438),
    [sym_fields_keyword] = ACTIONS(8438),
    [sym_keys_keyword] = ACTIONS(8438),
    [sym_fieldgroups_keyword] = ACTIONS(8438),
    [sym_actions_keyword] = ACTIONS(8438),
    [sym_layout_keyword] = ACTIONS(8438),
    [sym_dataset_keyword] = ACTIONS(8438),
    [sym_elements_keyword] = ACTIONS(8438),
    [sym_dataitem_keyword] = ACTIONS(8438),
    [sym_column_keyword] = ACTIONS(8438),
    [sym_filter_keyword] = ACTIONS(8438),
    [sym_labels_keyword] = ACTIONS(8438),
    [sym_rendering_keyword] = ACTIONS(8438),
    [sym_requestpage_keyword] = ACTIONS(8438),
    [sym_schema_keyword] = ACTIONS(8438),
    [sym_views_keyword] = ACTIONS(8438),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8438),
    [sym_preproc_open] = ACTIONS(8438),
    [sym_preproc_close] = ACTIONS(8438),
  },
  [STATE(5320)] = {
    [sym_preproc_conditional_permissions] = STATE(5320),
    [sym_tabledata_permission] = STATE(5496),
    [sym_preproc_if] = STATE(7977),
    [sym_codeunit_keyword] = STATE(11348),
    [sym_xmlport_keyword] = STATE(11348),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(5320),
    [anon_sym_SEMI] = ACTIONS(7785),
    [anon_sym_RBRACE] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token1] = ACTIONS(13092),
    [aux_sym_tabledata_permission_token2] = ACTIONS(13095),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7785),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7785),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_basic_type_token22] = ACTIONS(7787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_addafter_modification_token1] = ACTIONS(7785),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_separator_action_token1] = ACTIONS(7785),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7785),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7785),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7785),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7795),
    [anon_sym_POUNDIF] = ACTIONS(7795),
    [anon_sym_POUNDIf] = ACTIONS(7795),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(13095),
    [sym_page_keyword] = ACTIONS(13092),
    [anon_sym_codeunit] = ACTIONS(7798),
    [anon_sym_CODEUNIT] = ACTIONS(7798),
    [anon_sym_Codeunit] = ACTIONS(7798),
    [anon_sym_CodeUnit] = ACTIONS(7798),
    [anon_sym_COdeunit] = ACTIONS(7798),
    [anon_sym_codeUnit] = ACTIONS(7798),
    [sym_report_keyword] = ACTIONS(13092),
    [sym_query_keyword] = ACTIONS(13092),
    [anon_sym_xmlport] = ACTIONS(7801),
    [anon_sym_XMLPORT] = ACTIONS(7801),
    [anon_sym_Xmlport] = ACTIONS(7801),
    [anon_sym_XMLport] = ACTIONS(7801),
    [anon_sym_XMLPort] = ACTIONS(7801),
    [anon_sym_XmlPort] = ACTIONS(7801),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_area_keyword] = ACTIONS(7785),
    [sym_group_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7795),
  },
  [STATE(5321)] = {
    [sym_identifier] = ACTIONS(7757),
    [anon_sym_SEMI] = ACTIONS(7760),
    [anon_sym_RBRACE] = ACTIONS(7775),
    [aux_sym_where_condition_token1] = ACTIONS(7757),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7772),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7772),
    [anon_sym_LBRACK] = ACTIONS(7775),
    [aux_sym_basic_type_token22] = ACTIONS(7765),
    [aux_sym_basic_type_token53] = ACTIONS(7757),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7765),
    [aux_sym_addafter_modification_token1] = ACTIONS(7772),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7772),
    [aux_sym_modify_modification_token1] = ACTIONS(7772),
    [aux_sym_separator_action_token1] = ACTIONS(7765),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7772),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7772),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7772),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7772),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7765),
    [aux_sym_type_declaration_token1] = ACTIONS(7757),
    [anon_sym_POUNDif] = ACTIONS(7760),
    [anon_sym_POUNDIF] = ACTIONS(7760),
    [anon_sym_POUNDIf] = ACTIONS(7760),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7778),
    [sym_page_keyword] = ACTIONS(7770),
    [anon_sym_codeunit] = ACTIONS(7770),
    [anon_sym_CODEUNIT] = ACTIONS(7770),
    [anon_sym_Codeunit] = ACTIONS(7770),
    [anon_sym_CodeUnit] = ACTIONS(7770),
    [anon_sym_COdeunit] = ACTIONS(7770),
    [anon_sym_codeUnit] = ACTIONS(7770),
    [sym_report_keyword] = ACTIONS(7770),
    [sym_query_keyword] = ACTIONS(7770),
    [anon_sym_xmlport] = ACTIONS(7770),
    [anon_sym_XMLPORT] = ACTIONS(7770),
    [anon_sym_Xmlport] = ACTIONS(7770),
    [anon_sym_XMLport] = ACTIONS(7770),
    [anon_sym_XMLPort] = ACTIONS(7770),
    [anon_sym_XmlPort] = ACTIONS(7770),
    [sym_procedure_keyword] = ACTIONS(7772),
    [sym_trigger_keyword] = ACTIONS(7772),
    [sym_var_keyword] = ACTIONS(7772),
    [sym_local_keyword] = ACTIONS(7772),
    [sym_internal_keyword] = ACTIONS(7772),
    [sym_protected_keyword] = ACTIONS(7772),
    [sym_event_keyword] = ACTIONS(7772),
    [sym_fields_keyword] = ACTIONS(7772),
    [sym_keys_keyword] = ACTIONS(7772),
    [sym_key_keyword] = ACTIONS(7757),
    [sym_fieldgroups_keyword] = ACTIONS(7772),
    [sym_actions_keyword] = ACTIONS(7772),
    [sym_layout_keyword] = ACTIONS(7772),
    [sym_area_keyword] = ACTIONS(7772),
    [sym_group_keyword] = ACTIONS(7772),
    [sym_dataset_keyword] = ACTIONS(7765),
    [sym_elements_keyword] = ACTIONS(7772),
    [sym_labels_keyword] = ACTIONS(7772),
    [sym_rendering_keyword] = ACTIONS(7772),
    [sym_requestpage_keyword] = ACTIONS(7772),
    [sym_schema_keyword] = ACTIONS(7772),
    [sym_views_keyword] = ACTIONS(7772),
    [sym_quoted_identifier] = ACTIONS(7782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7775),
    [sym_preproc_open] = ACTIONS(7760),
  },
  [STATE(5322)] = {
    [anon_sym_SEMI] = ACTIONS(8446),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8446),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8446),
    [anon_sym_LBRACK] = ACTIONS(8446),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8446),
    [aux_sym_modify_modification_token1] = ACTIONS(8446),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8446),
    [anon_sym_POUNDif] = ACTIONS(8446),
    [anon_sym_POUNDIF] = ACTIONS(8446),
    [anon_sym_POUNDIf] = ACTIONS(8446),
    [anon_sym_POUNDelif] = ACTIONS(8446),
    [anon_sym_POUNDELIF] = ACTIONS(8446),
    [anon_sym_POUNDElif] = ACTIONS(8446),
    [anon_sym_POUNDelse] = ACTIONS(8446),
    [anon_sym_POUNDELSE] = ACTIONS(8446),
    [anon_sym_POUNDElse] = ACTIONS(8446),
    [anon_sym_POUNDelse2] = ACTIONS(8446),
    [anon_sym_POUNDELSE2] = ACTIONS(8446),
    [anon_sym_POUNDElse2] = ACTIONS(8446),
    [anon_sym_POUNDendif] = ACTIONS(8446),
    [anon_sym_POUNDENDIF] = ACTIONS(8446),
    [anon_sym_POUNDEndif] = ACTIONS(8446),
    [anon_sym_POUNDendif2] = ACTIONS(8446),
    [anon_sym_POUNDENDIF2] = ACTIONS(8446),
    [anon_sym_POUNDEndif2] = ACTIONS(8446),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8448),
    [sym_page_keyword] = ACTIONS(8446),
    [anon_sym_codeunit] = ACTIONS(8446),
    [anon_sym_CODEUNIT] = ACTIONS(8446),
    [anon_sym_Codeunit] = ACTIONS(8446),
    [anon_sym_CodeUnit] = ACTIONS(8446),
    [anon_sym_COdeunit] = ACTIONS(8446),
    [anon_sym_codeUnit] = ACTIONS(8446),
    [sym_report_keyword] = ACTIONS(8446),
    [sym_query_keyword] = ACTIONS(8446),
    [anon_sym_xmlport] = ACTIONS(8446),
    [anon_sym_XMLPORT] = ACTIONS(8446),
    [anon_sym_Xmlport] = ACTIONS(8446),
    [anon_sym_XMLport] = ACTIONS(8446),
    [anon_sym_XMLPort] = ACTIONS(8446),
    [anon_sym_XmlPort] = ACTIONS(8446),
    [sym_procedure_keyword] = ACTIONS(8446),
    [sym_trigger_keyword] = ACTIONS(8446),
    [sym_var_keyword] = ACTIONS(8446),
    [sym_local_keyword] = ACTIONS(8446),
    [sym_internal_keyword] = ACTIONS(8446),
    [sym_protected_keyword] = ACTIONS(8446),
    [sym_event_keyword] = ACTIONS(8446),
    [sym_fields_keyword] = ACTIONS(8446),
    [sym_keys_keyword] = ACTIONS(8446),
    [sym_fieldgroups_keyword] = ACTIONS(8446),
    [sym_actions_keyword] = ACTIONS(8446),
    [sym_layout_keyword] = ACTIONS(8446),
    [sym_dataset_keyword] = ACTIONS(8446),
    [sym_elements_keyword] = ACTIONS(8446),
    [sym_dataitem_keyword] = ACTIONS(8446),
    [sym_column_keyword] = ACTIONS(8446),
    [sym_filter_keyword] = ACTIONS(8446),
    [sym_labels_keyword] = ACTIONS(8446),
    [sym_rendering_keyword] = ACTIONS(8446),
    [sym_requestpage_keyword] = ACTIONS(8446),
    [sym_schema_keyword] = ACTIONS(8446),
    [sym_views_keyword] = ACTIONS(8446),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8446),
    [sym_preproc_open] = ACTIONS(8446),
    [sym_preproc_close] = ACTIONS(8446),
  },
  [STATE(5323)] = {
    [sym_identifier] = ACTIONS(7712),
    [anon_sym_SEMI] = ACTIONS(7715),
    [anon_sym_RBRACE] = ACTIONS(7730),
    [aux_sym_where_condition_token1] = ACTIONS(7712),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7727),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7727),
    [anon_sym_LBRACK] = ACTIONS(7730),
    [aux_sym_basic_type_token22] = ACTIONS(7720),
    [aux_sym_basic_type_token53] = ACTIONS(7712),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7720),
    [aux_sym_addafter_modification_token1] = ACTIONS(7727),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7727),
    [aux_sym_modify_modification_token1] = ACTIONS(7727),
    [aux_sym_separator_action_token1] = ACTIONS(7720),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7727),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7727),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7727),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7727),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7720),
    [aux_sym_type_declaration_token1] = ACTIONS(7712),
    [anon_sym_POUNDif] = ACTIONS(7715),
    [anon_sym_POUNDIF] = ACTIONS(7715),
    [anon_sym_POUNDIf] = ACTIONS(7715),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7733),
    [sym_page_keyword] = ACTIONS(7725),
    [anon_sym_codeunit] = ACTIONS(7725),
    [anon_sym_CODEUNIT] = ACTIONS(7725),
    [anon_sym_Codeunit] = ACTIONS(7725),
    [anon_sym_CodeUnit] = ACTIONS(7725),
    [anon_sym_COdeunit] = ACTIONS(7725),
    [anon_sym_codeUnit] = ACTIONS(7725),
    [sym_report_keyword] = ACTIONS(7725),
    [sym_query_keyword] = ACTIONS(7725),
    [anon_sym_xmlport] = ACTIONS(7725),
    [anon_sym_XMLPORT] = ACTIONS(7725),
    [anon_sym_Xmlport] = ACTIONS(7725),
    [anon_sym_XMLport] = ACTIONS(7725),
    [anon_sym_XMLPort] = ACTIONS(7725),
    [anon_sym_XmlPort] = ACTIONS(7725),
    [sym_procedure_keyword] = ACTIONS(7727),
    [sym_trigger_keyword] = ACTIONS(7727),
    [sym_var_keyword] = ACTIONS(7727),
    [sym_local_keyword] = ACTIONS(7727),
    [sym_internal_keyword] = ACTIONS(7727),
    [sym_protected_keyword] = ACTIONS(7727),
    [sym_event_keyword] = ACTIONS(7727),
    [sym_fields_keyword] = ACTIONS(7727),
    [sym_keys_keyword] = ACTIONS(7727),
    [sym_key_keyword] = ACTIONS(7712),
    [sym_fieldgroups_keyword] = ACTIONS(7727),
    [sym_actions_keyword] = ACTIONS(7727),
    [sym_layout_keyword] = ACTIONS(7727),
    [sym_area_keyword] = ACTIONS(7727),
    [sym_group_keyword] = ACTIONS(7727),
    [sym_dataset_keyword] = ACTIONS(7720),
    [sym_elements_keyword] = ACTIONS(7727),
    [sym_labels_keyword] = ACTIONS(7727),
    [sym_rendering_keyword] = ACTIONS(7727),
    [sym_requestpage_keyword] = ACTIONS(7727),
    [sym_schema_keyword] = ACTIONS(7727),
    [sym_views_keyword] = ACTIONS(7727),
    [sym_quoted_identifier] = ACTIONS(7737),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7730),
    [sym_preproc_open] = ACTIONS(7715),
  },
  [STATE(5324)] = {
    [anon_sym_SEMI] = ACTIONS(8426),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8426),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8426),
    [anon_sym_LBRACK] = ACTIONS(8426),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8426),
    [aux_sym_modify_modification_token1] = ACTIONS(8426),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8426),
    [anon_sym_POUNDif] = ACTIONS(8426),
    [anon_sym_POUNDIF] = ACTIONS(8426),
    [anon_sym_POUNDIf] = ACTIONS(8426),
    [anon_sym_POUNDelif] = ACTIONS(8426),
    [anon_sym_POUNDELIF] = ACTIONS(8426),
    [anon_sym_POUNDElif] = ACTIONS(8426),
    [anon_sym_POUNDelse] = ACTIONS(8426),
    [anon_sym_POUNDELSE] = ACTIONS(8426),
    [anon_sym_POUNDElse] = ACTIONS(8426),
    [anon_sym_POUNDelse2] = ACTIONS(8426),
    [anon_sym_POUNDELSE2] = ACTIONS(8426),
    [anon_sym_POUNDElse2] = ACTIONS(8426),
    [anon_sym_POUNDendif] = ACTIONS(8426),
    [anon_sym_POUNDENDIF] = ACTIONS(8426),
    [anon_sym_POUNDEndif] = ACTIONS(8426),
    [anon_sym_POUNDendif2] = ACTIONS(8426),
    [anon_sym_POUNDENDIF2] = ACTIONS(8426),
    [anon_sym_POUNDEndif2] = ACTIONS(8426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7770),
    [sym_page_keyword] = ACTIONS(8426),
    [anon_sym_codeunit] = ACTIONS(8426),
    [anon_sym_CODEUNIT] = ACTIONS(8426),
    [anon_sym_Codeunit] = ACTIONS(8426),
    [anon_sym_CodeUnit] = ACTIONS(8426),
    [anon_sym_COdeunit] = ACTIONS(8426),
    [anon_sym_codeUnit] = ACTIONS(8426),
    [sym_report_keyword] = ACTIONS(8426),
    [sym_query_keyword] = ACTIONS(8426),
    [anon_sym_xmlport] = ACTIONS(8426),
    [anon_sym_XMLPORT] = ACTIONS(8426),
    [anon_sym_Xmlport] = ACTIONS(8426),
    [anon_sym_XMLport] = ACTIONS(8426),
    [anon_sym_XMLPort] = ACTIONS(8426),
    [anon_sym_XmlPort] = ACTIONS(8426),
    [sym_procedure_keyword] = ACTIONS(8426),
    [sym_trigger_keyword] = ACTIONS(8426),
    [sym_var_keyword] = ACTIONS(8426),
    [sym_local_keyword] = ACTIONS(8426),
    [sym_internal_keyword] = ACTIONS(8426),
    [sym_protected_keyword] = ACTIONS(8426),
    [sym_event_keyword] = ACTIONS(8426),
    [sym_fields_keyword] = ACTIONS(8426),
    [sym_keys_keyword] = ACTIONS(8426),
    [sym_fieldgroups_keyword] = ACTIONS(8426),
    [sym_actions_keyword] = ACTIONS(8426),
    [sym_layout_keyword] = ACTIONS(8426),
    [sym_dataset_keyword] = ACTIONS(8426),
    [sym_elements_keyword] = ACTIONS(8426),
    [sym_dataitem_keyword] = ACTIONS(8426),
    [sym_column_keyword] = ACTIONS(8426),
    [sym_filter_keyword] = ACTIONS(8426),
    [sym_labels_keyword] = ACTIONS(8426),
    [sym_rendering_keyword] = ACTIONS(8426),
    [sym_requestpage_keyword] = ACTIONS(8426),
    [sym_schema_keyword] = ACTIONS(8426),
    [sym_views_keyword] = ACTIONS(8426),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8426),
    [sym_preproc_open] = ACTIONS(8426),
    [sym_preproc_close] = ACTIONS(8426),
  },
  [STATE(5325)] = {
    [sym_preproc_conditional_permissions] = STATE(5320),
    [sym_tabledata_permission] = STATE(5496),
    [sym_preproc_if] = STATE(7977),
    [sym_codeunit_keyword] = STATE(11348),
    [sym_xmlport_keyword] = STATE(11348),
    [aux_sym_tabledata_permission_list_repeat1] = STATE(5320),
    [anon_sym_SEMI] = ACTIONS(7846),
    [anon_sym_RBRACE] = ACTIONS(7846),
    [aux_sym_tabledata_permission_token1] = ACTIONS(13098),
    [aux_sym_tabledata_permission_token2] = ACTIONS(4101),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7846),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7846),
    [anon_sym_LBRACK] = ACTIONS(7846),
    [aux_sym_basic_type_token22] = ACTIONS(7848),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7846),
    [aux_sym_addafter_modification_token1] = ACTIONS(7846),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7846),
    [aux_sym_modify_modification_token1] = ACTIONS(7846),
    [aux_sym_separator_action_token1] = ACTIONS(7846),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7846),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7846),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7846),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7846),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7846),
    [anon_sym_POUNDif] = ACTIONS(7852),
    [anon_sym_POUNDIF] = ACTIONS(7852),
    [anon_sym_POUNDIf] = ACTIONS(7852),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(4101),
    [sym_page_keyword] = ACTIONS(13098),
    [anon_sym_codeunit] = ACTIONS(7855),
    [anon_sym_CODEUNIT] = ACTIONS(7855),
    [anon_sym_Codeunit] = ACTIONS(7855),
    [anon_sym_CodeUnit] = ACTIONS(7855),
    [anon_sym_COdeunit] = ACTIONS(7855),
    [anon_sym_codeUnit] = ACTIONS(7855),
    [sym_report_keyword] = ACTIONS(13098),
    [sym_query_keyword] = ACTIONS(13098),
    [anon_sym_xmlport] = ACTIONS(7857),
    [anon_sym_XMLPORT] = ACTIONS(7857),
    [anon_sym_Xmlport] = ACTIONS(7857),
    [anon_sym_XMLport] = ACTIONS(7857),
    [anon_sym_XMLPort] = ACTIONS(7857),
    [anon_sym_XmlPort] = ACTIONS(7857),
    [sym_procedure_keyword] = ACTIONS(7846),
    [sym_trigger_keyword] = ACTIONS(7846),
    [sym_var_keyword] = ACTIONS(7846),
    [sym_local_keyword] = ACTIONS(7846),
    [sym_internal_keyword] = ACTIONS(7846),
    [sym_protected_keyword] = ACTIONS(7846),
    [sym_event_keyword] = ACTIONS(7846),
    [sym_fields_keyword] = ACTIONS(7846),
    [sym_keys_keyword] = ACTIONS(7846),
    [sym_fieldgroups_keyword] = ACTIONS(7846),
    [sym_actions_keyword] = ACTIONS(7846),
    [sym_layout_keyword] = ACTIONS(7846),
    [sym_area_keyword] = ACTIONS(7846),
    [sym_group_keyword] = ACTIONS(7846),
    [sym_dataset_keyword] = ACTIONS(7846),
    [sym_elements_keyword] = ACTIONS(7846),
    [sym_labels_keyword] = ACTIONS(7846),
    [sym_rendering_keyword] = ACTIONS(7846),
    [sym_requestpage_keyword] = ACTIONS(7846),
    [sym_schema_keyword] = ACTIONS(7846),
    [sym_views_keyword] = ACTIONS(7846),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7846),
    [sym_preproc_open] = ACTIONS(7852),
  },
  [STATE(5326)] = {
    [aux_sym_option_member_list_repeat2] = STATE(5326),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(13100),
    [anon_sym_DASH] = ACTIONS(838),
    [aux_sym_boolean_token1] = ACTIONS(836),
    [aux_sym_boolean_token2] = ACTIONS(836),
    [aux_sym_where_condition_token1] = ACTIONS(836),
    [aux_sym_tabledata_permission_token2] = ACTIONS(836),
    [aux_sym_record_type_token1] = ACTIONS(836),
    [aux_sym_basic_type_token21] = ACTIONS(836),
    [aux_sym_basic_type_token22] = ACTIONS(836),
    [aux_sym_basic_type_token48] = ACTIONS(836),
    [aux_sym_basic_type_token53] = ACTIONS(836),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(836),
    [aux_sym_separator_action_token1] = ACTIONS(836),
    [aux_sym_assembly_declaration_token1] = ACTIONS(836),
    [aux_sym_type_declaration_token1] = ACTIONS(836),
    [anon_sym_POUNDelif] = ACTIONS(838),
    [anon_sym_POUNDELIF] = ACTIONS(838),
    [anon_sym_POUNDElif] = ACTIONS(838),
    [anon_sym_POUNDelse] = ACTIONS(838),
    [anon_sym_POUNDELSE] = ACTIONS(838),
    [anon_sym_POUNDElse] = ACTIONS(838),
    [anon_sym_POUNDelse2] = ACTIONS(838),
    [anon_sym_POUNDELSE2] = ACTIONS(838),
    [anon_sym_POUNDElse2] = ACTIONS(838),
    [anon_sym_POUNDendif] = ACTIONS(838),
    [anon_sym_POUNDENDIF] = ACTIONS(838),
    [anon_sym_POUNDEndif] = ACTIONS(838),
    [anon_sym_POUNDendif2] = ACTIONS(838),
    [anon_sym_POUNDENDIF2] = ACTIONS(838),
    [anon_sym_POUNDEndif2] = ACTIONS(838),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(836),
    [aux_sym_keyword_identifier_token2] = ACTIONS(836),
    [sym_table_keyword] = ACTIONS(836),
    [sym_page_keyword] = ACTIONS(836),
    [anon_sym_codeunit] = ACTIONS(836),
    [anon_sym_CODEUNIT] = ACTIONS(836),
    [anon_sym_Codeunit] = ACTIONS(836),
    [anon_sym_CodeUnit] = ACTIONS(836),
    [anon_sym_COdeunit] = ACTIONS(836),
    [anon_sym_codeUnit] = ACTIONS(836),
    [sym_report_keyword] = ACTIONS(836),
    [sym_query_keyword] = ACTIONS(836),
    [anon_sym_xmlport] = ACTIONS(836),
    [anon_sym_XMLPORT] = ACTIONS(836),
    [anon_sym_Xmlport] = ACTIONS(836),
    [anon_sym_XMLport] = ACTIONS(836),
    [anon_sym_XMLPort] = ACTIONS(836),
    [anon_sym_XmlPort] = ACTIONS(836),
    [anon_sym_enum] = ACTIONS(836),
    [anon_sym_ENUM] = ACTIONS(836),
    [anon_sym_Enum] = ACTIONS(836),
    [anon_sym_eNUM] = ACTIONS(836),
    [anon_sym_eNum] = ACTIONS(836),
    [anon_sym_ENum] = ACTIONS(836),
    [sym_local_keyword] = ACTIONS(836),
    [sym_internal_keyword] = ACTIONS(836),
    [sym_protected_keyword] = ACTIONS(836),
    [sym_key_keyword] = ACTIONS(836),
    [sym_dataset_keyword] = ACTIONS(836),
    [sym_quoted_identifier] = ACTIONS(838),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(838),
    [sym_integer] = ACTIONS(838),
    [sym_preproc_close] = ACTIONS(838),
  },
  [STATE(5327)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_RBRACE] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5279),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_addafter_modification_token1] = ACTIONS(5279),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5279),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5279),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5279),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_area_keyword] = ACTIONS(5279),
    [sym_group_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
  },
  [STATE(5328)] = {
    [anon_sym_SEMI] = ACTIONS(8428),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8428),
    [anon_sym_LBRACK] = ACTIONS(8428),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8428),
    [aux_sym_modify_modification_token1] = ACTIONS(8428),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8428),
    [anon_sym_POUNDif] = ACTIONS(8428),
    [anon_sym_POUNDIF] = ACTIONS(8428),
    [anon_sym_POUNDIf] = ACTIONS(8428),
    [anon_sym_POUNDelif] = ACTIONS(8428),
    [anon_sym_POUNDELIF] = ACTIONS(8428),
    [anon_sym_POUNDElif] = ACTIONS(8428),
    [anon_sym_POUNDelse] = ACTIONS(8428),
    [anon_sym_POUNDELSE] = ACTIONS(8428),
    [anon_sym_POUNDElse] = ACTIONS(8428),
    [anon_sym_POUNDelse2] = ACTIONS(8428),
    [anon_sym_POUNDELSE2] = ACTIONS(8428),
    [anon_sym_POUNDElse2] = ACTIONS(8428),
    [anon_sym_POUNDendif] = ACTIONS(8428),
    [anon_sym_POUNDENDIF] = ACTIONS(8428),
    [anon_sym_POUNDEndif] = ACTIONS(8428),
    [anon_sym_POUNDendif2] = ACTIONS(8428),
    [anon_sym_POUNDENDIF2] = ACTIONS(8428),
    [anon_sym_POUNDEndif2] = ACTIONS(8428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7725),
    [sym_page_keyword] = ACTIONS(8428),
    [anon_sym_codeunit] = ACTIONS(8428),
    [anon_sym_CODEUNIT] = ACTIONS(8428),
    [anon_sym_Codeunit] = ACTIONS(8428),
    [anon_sym_CodeUnit] = ACTIONS(8428),
    [anon_sym_COdeunit] = ACTIONS(8428),
    [anon_sym_codeUnit] = ACTIONS(8428),
    [sym_report_keyword] = ACTIONS(8428),
    [sym_query_keyword] = ACTIONS(8428),
    [anon_sym_xmlport] = ACTIONS(8428),
    [anon_sym_XMLPORT] = ACTIONS(8428),
    [anon_sym_Xmlport] = ACTIONS(8428),
    [anon_sym_XMLport] = ACTIONS(8428),
    [anon_sym_XMLPort] = ACTIONS(8428),
    [anon_sym_XmlPort] = ACTIONS(8428),
    [sym_procedure_keyword] = ACTIONS(8428),
    [sym_trigger_keyword] = ACTIONS(8428),
    [sym_var_keyword] = ACTIONS(8428),
    [sym_local_keyword] = ACTIONS(8428),
    [sym_internal_keyword] = ACTIONS(8428),
    [sym_protected_keyword] = ACTIONS(8428),
    [sym_event_keyword] = ACTIONS(8428),
    [sym_fields_keyword] = ACTIONS(8428),
    [sym_keys_keyword] = ACTIONS(8428),
    [sym_fieldgroups_keyword] = ACTIONS(8428),
    [sym_actions_keyword] = ACTIONS(8428),
    [sym_layout_keyword] = ACTIONS(8428),
    [sym_dataset_keyword] = ACTIONS(8428),
    [sym_elements_keyword] = ACTIONS(8428),
    [sym_dataitem_keyword] = ACTIONS(8428),
    [sym_column_keyword] = ACTIONS(8428),
    [sym_filter_keyword] = ACTIONS(8428),
    [sym_labels_keyword] = ACTIONS(8428),
    [sym_rendering_keyword] = ACTIONS(8428),
    [sym_requestpage_keyword] = ACTIONS(8428),
    [sym_schema_keyword] = ACTIONS(8428),
    [sym_views_keyword] = ACTIONS(8428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8428),
    [sym_preproc_open] = ACTIONS(8428),
    [sym_preproc_close] = ACTIONS(8428),
  },
  [STATE(5329)] = {
    [sym__body_element] = STATE(5337),
    [sym_empty_statement] = STATE(5337),
    [sym_property] = STATE(5337),
    [sym_permissions_property] = STATE(5337),
    [sym_table_relation_property] = STATE(5337),
    [sym_fields_section] = STATE(5337),
    [sym_keys_section] = STATE(5337),
    [sym_fieldgroups_section] = STATE(5337),
    [sym_enum_value_declaration] = STATE(5337),
    [sym_labels_section] = STATE(5337),
    [sym_layout_section] = STATE(5337),
    [sym_modify_modification] = STATE(5337),
    [sym_actions_section] = STATE(5337),
    [sym_views_section] = STATE(5337),
    [sym_dataset_section] = STATE(5337),
    [sym_report_dataitem] = STATE(5337),
    [sym_report_column] = STATE(5337),
    [sym_requestpage_section] = STATE(5337),
    [sym_rendering_section] = STATE(5337),
    [sym_elements_section] = STATE(5337),
    [sym_schema_section] = STATE(5337),
    [sym_assembly_declaration] = STATE(5337),
    [sym_event_declaration] = STATE(5337),
    [sym_procedure] = STATE(5337),
    [sym_preproc_split_procedure] = STATE(5337),
    [sym_preproc_split_procedure_preamble] = STATE(5337),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5337),
    [sym_var_section] = STATE(5337),
    [sym_attribute_item] = STATE(5337),
    [sym_preproc_conditional] = STATE(5337),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5337),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13103),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5330)] = {
    [sym_identifier] = ACTIONS(13105),
    [anon_sym_COMMA] = ACTIONS(13107),
    [anon_sym_DASH] = ACTIONS(11691),
    [aux_sym_boolean_token1] = ACTIONS(13105),
    [aux_sym_boolean_token2] = ACTIONS(13105),
    [sym_decimal] = ACTIONS(13105),
    [anon_sym_LPAREN] = ACTIONS(11691),
    [aux_sym_tabledata_permission_token2] = ACTIONS(13105),
    [anon_sym_LBRACK] = ACTIONS(11691),
    [aux_sym_record_type_token1] = ACTIONS(13105),
    [aux_sym_basic_type_token21] = ACTIONS(13105),
    [aux_sym_basic_type_token22] = ACTIONS(13105),
    [aux_sym_basic_type_token48] = ACTIONS(13105),
    [anon_sym_not] = ACTIONS(13105),
    [anon_sym_NOT] = ACTIONS(13105),
    [anon_sym_Not] = ACTIONS(13105),
    [anon_sym_POUNDelif] = ACTIONS(11691),
    [anon_sym_POUNDELIF] = ACTIONS(11691),
    [anon_sym_POUNDElif] = ACTIONS(11691),
    [anon_sym_POUNDelse] = ACTIONS(11691),
    [anon_sym_POUNDELSE] = ACTIONS(11691),
    [anon_sym_POUNDElse] = ACTIONS(11691),
    [anon_sym_POUNDelse2] = ACTIONS(11691),
    [anon_sym_POUNDELSE2] = ACTIONS(11691),
    [anon_sym_POUNDElse2] = ACTIONS(11691),
    [anon_sym_POUNDendif] = ACTIONS(11691),
    [anon_sym_POUNDENDIF] = ACTIONS(11691),
    [anon_sym_POUNDEndif] = ACTIONS(11691),
    [anon_sym_POUNDendif2] = ACTIONS(11691),
    [anon_sym_POUNDENDIF2] = ACTIONS(11691),
    [anon_sym_POUNDEndif2] = ACTIONS(11691),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(13105),
    [aux_sym_keyword_identifier_token2] = ACTIONS(13105),
    [anon_sym_PLUS] = ACTIONS(11691),
    [sym_datetime_literal] = ACTIONS(11691),
    [sym_date_literal] = ACTIONS(13105),
    [sym_time_literal] = ACTIONS(13105),
    [sym_biginteger_literal] = ACTIONS(11691),
    [sym_page_keyword] = ACTIONS(13105),
    [anon_sym_codeunit] = ACTIONS(13105),
    [anon_sym_CODEUNIT] = ACTIONS(13105),
    [anon_sym_Codeunit] = ACTIONS(13105),
    [anon_sym_CodeUnit] = ACTIONS(13105),
    [anon_sym_COdeunit] = ACTIONS(13105),
    [anon_sym_codeUnit] = ACTIONS(13105),
    [sym_report_keyword] = ACTIONS(13105),
    [sym_query_keyword] = ACTIONS(13105),
    [anon_sym_xmlport] = ACTIONS(13105),
    [anon_sym_XMLPORT] = ACTIONS(13105),
    [anon_sym_Xmlport] = ACTIONS(13105),
    [anon_sym_XMLport] = ACTIONS(13105),
    [anon_sym_XMLPort] = ACTIONS(13105),
    [anon_sym_XmlPort] = ACTIONS(13105),
    [anon_sym_enum] = ACTIONS(13105),
    [anon_sym_ENUM] = ACTIONS(13105),
    [anon_sym_Enum] = ACTIONS(13105),
    [anon_sym_eNUM] = ACTIONS(13105),
    [anon_sym_eNum] = ACTIONS(13105),
    [anon_sym_ENum] = ACTIONS(13105),
    [sym_quoted_identifier] = ACTIONS(11691),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(11691),
    [sym_verbatim_string] = ACTIONS(11691),
    [sym_integer] = ACTIONS(13105),
    [sym_continue_as_identifier] = ACTIONS(11691),
    [sym_preproc_close] = ACTIONS(11691),
  },
  [STATE(5331)] = {
    [anon_sym_SEMI] = ACTIONS(13109),
    [anon_sym_LBRACE] = ACTIONS(13111),
    [aux_sym_where_condition_token1] = ACTIONS(13113),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13109),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13109),
    [anon_sym_LBRACK] = ACTIONS(13109),
    [aux_sym_basic_type_token6] = ACTIONS(13113),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13109),
    [aux_sym_addafter_modification_token1] = ACTIONS(13109),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13109),
    [aux_sym_modify_modification_token1] = ACTIONS(13109),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13109),
    [aux_sym_movelast_modification_token1] = ACTIONS(13109),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13109),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13109),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13109),
    [anon_sym_POUNDif] = ACTIONS(13109),
    [anon_sym_POUNDIF] = ACTIONS(13109),
    [anon_sym_POUNDIf] = ACTIONS(13109),
    [anon_sym_POUNDelif] = ACTIONS(13109),
    [anon_sym_POUNDELIF] = ACTIONS(13109),
    [anon_sym_POUNDElif] = ACTIONS(13109),
    [anon_sym_POUNDelse] = ACTIONS(13109),
    [anon_sym_POUNDELSE] = ACTIONS(13109),
    [anon_sym_POUNDElse] = ACTIONS(13109),
    [anon_sym_POUNDelse2] = ACTIONS(13109),
    [anon_sym_POUNDELSE2] = ACTIONS(13109),
    [anon_sym_POUNDElse2] = ACTIONS(13109),
    [anon_sym_POUNDendif] = ACTIONS(13109),
    [anon_sym_POUNDENDIF] = ACTIONS(13109),
    [anon_sym_POUNDEndif] = ACTIONS(13109),
    [anon_sym_POUNDendif2] = ACTIONS(13109),
    [anon_sym_POUNDENDIF2] = ACTIONS(13109),
    [anon_sym_POUNDEndif2] = ACTIONS(13109),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13109),
    [sym_trigger_keyword] = ACTIONS(13109),
    [sym_var_keyword] = ACTIONS(13109),
    [sym_local_keyword] = ACTIONS(13109),
    [sym_internal_keyword] = ACTIONS(13109),
    [sym_protected_keyword] = ACTIONS(13109),
    [sym_event_keyword] = ACTIONS(13109),
    [sym_fields_keyword] = ACTIONS(13109),
    [sym_keys_keyword] = ACTIONS(13109),
    [sym_fieldgroups_keyword] = ACTIONS(13109),
    [sym_actions_keyword] = ACTIONS(13109),
    [sym_layout_keyword] = ACTIONS(13109),
    [sym_area_keyword] = ACTIONS(13109),
    [sym_group_keyword] = ACTIONS(13109),
    [sym_repeater_keyword] = ACTIONS(13109),
    [sym_cuegroup_keyword] = ACTIONS(13109),
    [sym_fixed_keyword] = ACTIONS(13109),
    [sym_grid_keyword] = ACTIONS(13109),
    [sym_part_keyword] = ACTIONS(13109),
    [sym_systempart_keyword] = ACTIONS(13109),
    [sym_usercontrol_keyword] = ACTIONS(13109),
    [sym_dataset_keyword] = ACTIONS(13109),
    [sym_elements_keyword] = ACTIONS(13109),
    [sym_labels_keyword] = ACTIONS(13109),
    [sym_rendering_keyword] = ACTIONS(13109),
    [sym_requestpage_keyword] = ACTIONS(13109),
    [sym_schema_keyword] = ACTIONS(13109),
    [sym_views_keyword] = ACTIONS(13109),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13109),
    [sym_preproc_open] = ACTIONS(13109),
    [sym_preproc_close] = ACTIONS(13109),
  },
  [STATE(5332)] = {
    [sym__body_element] = STATE(5336),
    [sym_empty_statement] = STATE(5336),
    [sym_property] = STATE(5336),
    [sym_permissions_property] = STATE(5336),
    [sym_table_relation_property] = STATE(5336),
    [sym_fields_section] = STATE(5336),
    [sym_keys_section] = STATE(5336),
    [sym_fieldgroups_section] = STATE(5336),
    [sym_enum_value_declaration] = STATE(5336),
    [sym_labels_section] = STATE(5336),
    [sym_layout_section] = STATE(5336),
    [sym_modify_modification] = STATE(5336),
    [sym_actions_section] = STATE(5336),
    [sym_views_section] = STATE(5336),
    [sym_dataset_section] = STATE(5336),
    [sym_report_dataitem] = STATE(5336),
    [sym_report_column] = STATE(5336),
    [sym_requestpage_section] = STATE(5336),
    [sym_rendering_section] = STATE(5336),
    [sym_elements_section] = STATE(5336),
    [sym_schema_section] = STATE(5336),
    [sym_assembly_declaration] = STATE(5336),
    [sym_event_declaration] = STATE(5336),
    [sym_procedure] = STATE(5336),
    [sym_preproc_split_procedure] = STATE(5336),
    [sym_preproc_split_procedure_preamble] = STATE(5336),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5336),
    [sym_var_section] = STATE(5336),
    [sym_attribute_item] = STATE(5336),
    [sym_preproc_conditional] = STATE(5336),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5336),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13115),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5333)] = {
    [sym__body_element] = STATE(5337),
    [sym_empty_statement] = STATE(5337),
    [sym_property] = STATE(5337),
    [sym_permissions_property] = STATE(5337),
    [sym_table_relation_property] = STATE(5337),
    [sym_fields_section] = STATE(5337),
    [sym_keys_section] = STATE(5337),
    [sym_fieldgroups_section] = STATE(5337),
    [sym_enum_value_declaration] = STATE(5337),
    [sym_labels_section] = STATE(5337),
    [sym_layout_section] = STATE(5337),
    [sym_modify_modification] = STATE(5337),
    [sym_actions_section] = STATE(5337),
    [sym_views_section] = STATE(5337),
    [sym_dataset_section] = STATE(5337),
    [sym_report_dataitem] = STATE(5337),
    [sym_report_column] = STATE(5337),
    [sym_requestpage_section] = STATE(5337),
    [sym_rendering_section] = STATE(5337),
    [sym_elements_section] = STATE(5337),
    [sym_schema_section] = STATE(5337),
    [sym_assembly_declaration] = STATE(5337),
    [sym_event_declaration] = STATE(5337),
    [sym_procedure] = STATE(5337),
    [sym_preproc_split_procedure] = STATE(5337),
    [sym_preproc_split_procedure_preamble] = STATE(5337),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5337),
    [sym_var_section] = STATE(5337),
    [sym_attribute_item] = STATE(5337),
    [sym_preproc_conditional] = STATE(5337),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5337),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13117),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5334)] = {
    [sym__body_element] = STATE(5337),
    [sym_empty_statement] = STATE(5337),
    [sym_property] = STATE(5337),
    [sym_permissions_property] = STATE(5337),
    [sym_table_relation_property] = STATE(5337),
    [sym_fields_section] = STATE(5337),
    [sym_keys_section] = STATE(5337),
    [sym_fieldgroups_section] = STATE(5337),
    [sym_enum_value_declaration] = STATE(5337),
    [sym_labels_section] = STATE(5337),
    [sym_layout_section] = STATE(5337),
    [sym_modify_modification] = STATE(5337),
    [sym_actions_section] = STATE(5337),
    [sym_views_section] = STATE(5337),
    [sym_dataset_section] = STATE(5337),
    [sym_report_dataitem] = STATE(5337),
    [sym_report_column] = STATE(5337),
    [sym_requestpage_section] = STATE(5337),
    [sym_rendering_section] = STATE(5337),
    [sym_elements_section] = STATE(5337),
    [sym_schema_section] = STATE(5337),
    [sym_assembly_declaration] = STATE(5337),
    [sym_event_declaration] = STATE(5337),
    [sym_procedure] = STATE(5337),
    [sym_preproc_split_procedure] = STATE(5337),
    [sym_preproc_split_procedure_preamble] = STATE(5337),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5337),
    [sym_var_section] = STATE(5337),
    [sym_attribute_item] = STATE(5337),
    [sym_preproc_conditional] = STATE(5337),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5337),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13119),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5335)] = {
    [anon_sym_SEMI] = ACTIONS(13121),
    [aux_sym_where_condition_token1] = ACTIONS(13123),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(13125),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13121),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13121),
    [anon_sym_LBRACK] = ACTIONS(13121),
    [aux_sym_basic_type_token6] = ACTIONS(13123),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13121),
    [aux_sym_addafter_modification_token1] = ACTIONS(13121),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13121),
    [aux_sym_modify_modification_token1] = ACTIONS(13121),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13121),
    [aux_sym_movelast_modification_token1] = ACTIONS(13121),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13121),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13121),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13121),
    [anon_sym_POUNDif] = ACTIONS(13121),
    [anon_sym_POUNDIF] = ACTIONS(13121),
    [anon_sym_POUNDIf] = ACTIONS(13121),
    [anon_sym_POUNDelif] = ACTIONS(13121),
    [anon_sym_POUNDELIF] = ACTIONS(13121),
    [anon_sym_POUNDElif] = ACTIONS(13121),
    [anon_sym_POUNDelse] = ACTIONS(13121),
    [anon_sym_POUNDELSE] = ACTIONS(13121),
    [anon_sym_POUNDElse] = ACTIONS(13121),
    [anon_sym_POUNDelse2] = ACTIONS(13121),
    [anon_sym_POUNDELSE2] = ACTIONS(13121),
    [anon_sym_POUNDElse2] = ACTIONS(13121),
    [anon_sym_POUNDendif] = ACTIONS(13121),
    [anon_sym_POUNDENDIF] = ACTIONS(13121),
    [anon_sym_POUNDEndif] = ACTIONS(13121),
    [anon_sym_POUNDendif2] = ACTIONS(13121),
    [anon_sym_POUNDENDIF2] = ACTIONS(13121),
    [anon_sym_POUNDEndif2] = ACTIONS(13121),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13121),
    [sym_trigger_keyword] = ACTIONS(13121),
    [sym_var_keyword] = ACTIONS(13121),
    [sym_local_keyword] = ACTIONS(13121),
    [sym_internal_keyword] = ACTIONS(13121),
    [sym_protected_keyword] = ACTIONS(13121),
    [sym_event_keyword] = ACTIONS(13121),
    [sym_fields_keyword] = ACTIONS(13121),
    [sym_keys_keyword] = ACTIONS(13121),
    [sym_fieldgroups_keyword] = ACTIONS(13121),
    [sym_actions_keyword] = ACTIONS(13121),
    [sym_layout_keyword] = ACTIONS(13121),
    [sym_area_keyword] = ACTIONS(13121),
    [sym_group_keyword] = ACTIONS(13121),
    [sym_repeater_keyword] = ACTIONS(13121),
    [sym_cuegroup_keyword] = ACTIONS(13121),
    [sym_fixed_keyword] = ACTIONS(13121),
    [sym_grid_keyword] = ACTIONS(13121),
    [sym_part_keyword] = ACTIONS(13121),
    [sym_systempart_keyword] = ACTIONS(13121),
    [sym_usercontrol_keyword] = ACTIONS(13121),
    [sym_dataset_keyword] = ACTIONS(13121),
    [sym_elements_keyword] = ACTIONS(13121),
    [sym_labels_keyword] = ACTIONS(13121),
    [sym_rendering_keyword] = ACTIONS(13121),
    [sym_requestpage_keyword] = ACTIONS(13121),
    [sym_schema_keyword] = ACTIONS(13121),
    [sym_views_keyword] = ACTIONS(13121),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13121),
    [sym_preproc_open] = ACTIONS(13121),
    [sym_preproc_close] = ACTIONS(13121),
  },
  [STATE(5336)] = {
    [sym__body_element] = STATE(5337),
    [sym_empty_statement] = STATE(5337),
    [sym_property] = STATE(5337),
    [sym_permissions_property] = STATE(5337),
    [sym_table_relation_property] = STATE(5337),
    [sym_fields_section] = STATE(5337),
    [sym_keys_section] = STATE(5337),
    [sym_fieldgroups_section] = STATE(5337),
    [sym_enum_value_declaration] = STATE(5337),
    [sym_labels_section] = STATE(5337),
    [sym_layout_section] = STATE(5337),
    [sym_modify_modification] = STATE(5337),
    [sym_actions_section] = STATE(5337),
    [sym_views_section] = STATE(5337),
    [sym_dataset_section] = STATE(5337),
    [sym_report_dataitem] = STATE(5337),
    [sym_report_column] = STATE(5337),
    [sym_requestpage_section] = STATE(5337),
    [sym_rendering_section] = STATE(5337),
    [sym_elements_section] = STATE(5337),
    [sym_schema_section] = STATE(5337),
    [sym_assembly_declaration] = STATE(5337),
    [sym_event_declaration] = STATE(5337),
    [sym_procedure] = STATE(5337),
    [sym_preproc_split_procedure] = STATE(5337),
    [sym_preproc_split_procedure_preamble] = STATE(5337),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5337),
    [sym_var_section] = STATE(5337),
    [sym_attribute_item] = STATE(5337),
    [sym_preproc_conditional] = STATE(5337),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5337),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13127),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5337)] = {
    [sym__body_element] = STATE(5337),
    [sym_empty_statement] = STATE(5337),
    [sym_property] = STATE(5337),
    [sym_permissions_property] = STATE(5337),
    [sym_table_relation_property] = STATE(5337),
    [sym_fields_section] = STATE(5337),
    [sym_keys_section] = STATE(5337),
    [sym_fieldgroups_section] = STATE(5337),
    [sym_enum_value_declaration] = STATE(5337),
    [sym_labels_section] = STATE(5337),
    [sym_layout_section] = STATE(5337),
    [sym_modify_modification] = STATE(5337),
    [sym_actions_section] = STATE(5337),
    [sym_views_section] = STATE(5337),
    [sym_dataset_section] = STATE(5337),
    [sym_report_dataitem] = STATE(5337),
    [sym_report_column] = STATE(5337),
    [sym_requestpage_section] = STATE(5337),
    [sym_rendering_section] = STATE(5337),
    [sym_elements_section] = STATE(5337),
    [sym_schema_section] = STATE(5337),
    [sym_assembly_declaration] = STATE(5337),
    [sym_event_declaration] = STATE(5337),
    [sym_procedure] = STATE(5337),
    [sym_preproc_split_procedure] = STATE(5337),
    [sym_preproc_split_procedure_preamble] = STATE(5337),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5337),
    [sym_var_section] = STATE(5337),
    [sym_attribute_item] = STATE(5337),
    [sym_preproc_conditional] = STATE(5337),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5337),
    [anon_sym_SEMI] = ACTIONS(13129),
    [anon_sym_RBRACE] = ACTIONS(13132),
    [anon_sym_LBRACK] = ACTIONS(13134),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13137),
    [aux_sym_modify_modification_token1] = ACTIONS(13140),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13143),
    [anon_sym_POUNDif] = ACTIONS(13146),
    [anon_sym_POUNDIF] = ACTIONS(13146),
    [anon_sym_POUNDIf] = ACTIONS(13146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13149),
    [sym_trigger_keyword] = ACTIONS(13152),
    [sym_var_keyword] = ACTIONS(13155),
    [sym_local_keyword] = ACTIONS(13158),
    [sym_internal_keyword] = ACTIONS(13161),
    [sym_protected_keyword] = ACTIONS(13158),
    [sym_event_keyword] = ACTIONS(13164),
    [sym_fields_keyword] = ACTIONS(13167),
    [sym_keys_keyword] = ACTIONS(13170),
    [sym_fieldgroups_keyword] = ACTIONS(13173),
    [sym_actions_keyword] = ACTIONS(13176),
    [sym_layout_keyword] = ACTIONS(13179),
    [sym_dataset_keyword] = ACTIONS(13182),
    [sym_elements_keyword] = ACTIONS(13185),
    [sym_dataitem_keyword] = ACTIONS(13188),
    [sym_column_keyword] = ACTIONS(13191),
    [sym_labels_keyword] = ACTIONS(13194),
    [sym_rendering_keyword] = ACTIONS(13197),
    [sym_requestpage_keyword] = ACTIONS(13200),
    [sym_schema_keyword] = ACTIONS(13203),
    [sym_views_keyword] = ACTIONS(13206),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13209),
    [sym_preproc_open] = ACTIONS(13146),
  },
  [STATE(5338)] = {
    [sym__body_element] = STATE(5349),
    [sym_empty_statement] = STATE(5349),
    [sym_property] = STATE(5349),
    [sym_permissions_property] = STATE(5349),
    [sym_table_relation_property] = STATE(5349),
    [sym_fields_section] = STATE(5349),
    [sym_keys_section] = STATE(5349),
    [sym_fieldgroups_section] = STATE(5349),
    [sym_enum_value_declaration] = STATE(5349),
    [sym_labels_section] = STATE(5349),
    [sym_layout_section] = STATE(5349),
    [sym_modify_modification] = STATE(5349),
    [sym_actions_section] = STATE(5349),
    [sym_views_section] = STATE(5349),
    [sym_dataset_section] = STATE(5349),
    [sym_report_dataitem] = STATE(5349),
    [sym_report_column] = STATE(5349),
    [sym_requestpage_section] = STATE(5349),
    [sym_rendering_section] = STATE(5349),
    [sym_elements_section] = STATE(5349),
    [sym_schema_section] = STATE(5349),
    [sym_assembly_declaration] = STATE(5349),
    [sym_event_declaration] = STATE(5349),
    [sym_procedure] = STATE(5349),
    [sym_preproc_split_procedure] = STATE(5349),
    [sym_preproc_split_procedure_preamble] = STATE(5349),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5349),
    [sym_var_section] = STATE(5349),
    [sym_attribute_item] = STATE(5349),
    [sym_preproc_conditional] = STATE(5349),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5349),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13212),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5339)] = {
    [sym__body_element] = STATE(5345),
    [sym_empty_statement] = STATE(5345),
    [sym_property] = STATE(5345),
    [sym_permissions_property] = STATE(5345),
    [sym_table_relation_property] = STATE(5345),
    [sym_fields_section] = STATE(5345),
    [sym_keys_section] = STATE(5345),
    [sym_fieldgroups_section] = STATE(5345),
    [sym_enum_value_declaration] = STATE(5345),
    [sym_labels_section] = STATE(5345),
    [sym_layout_section] = STATE(5345),
    [sym_modify_modification] = STATE(5345),
    [sym_actions_section] = STATE(5345),
    [sym_views_section] = STATE(5345),
    [sym_dataset_section] = STATE(5345),
    [sym_report_dataitem] = STATE(5345),
    [sym_report_column] = STATE(5345),
    [sym_requestpage_section] = STATE(5345),
    [sym_rendering_section] = STATE(5345),
    [sym_elements_section] = STATE(5345),
    [sym_schema_section] = STATE(5345),
    [sym_assembly_declaration] = STATE(5345),
    [sym_event_declaration] = STATE(5345),
    [sym_procedure] = STATE(5345),
    [sym_preproc_split_procedure] = STATE(5345),
    [sym_preproc_split_procedure_preamble] = STATE(5345),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5345),
    [sym_var_section] = STATE(5345),
    [sym_attribute_item] = STATE(5345),
    [sym_preproc_conditional] = STATE(5345),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5345),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13214),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5340)] = {
    [anon_sym_SEMI] = ACTIONS(13216),
    [anon_sym_LBRACE] = ACTIONS(13218),
    [aux_sym_where_condition_token1] = ACTIONS(13220),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13216),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13216),
    [anon_sym_LBRACK] = ACTIONS(13216),
    [aux_sym_basic_type_token6] = ACTIONS(13220),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13216),
    [aux_sym_addafter_modification_token1] = ACTIONS(13216),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13216),
    [aux_sym_modify_modification_token1] = ACTIONS(13216),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13216),
    [aux_sym_movelast_modification_token1] = ACTIONS(13216),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13216),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13216),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13216),
    [anon_sym_POUNDif] = ACTIONS(13216),
    [anon_sym_POUNDIF] = ACTIONS(13216),
    [anon_sym_POUNDIf] = ACTIONS(13216),
    [anon_sym_POUNDelif] = ACTIONS(13216),
    [anon_sym_POUNDELIF] = ACTIONS(13216),
    [anon_sym_POUNDElif] = ACTIONS(13216),
    [anon_sym_POUNDelse] = ACTIONS(13216),
    [anon_sym_POUNDELSE] = ACTIONS(13216),
    [anon_sym_POUNDElse] = ACTIONS(13216),
    [anon_sym_POUNDelse2] = ACTIONS(13216),
    [anon_sym_POUNDELSE2] = ACTIONS(13216),
    [anon_sym_POUNDElse2] = ACTIONS(13216),
    [anon_sym_POUNDendif] = ACTIONS(13216),
    [anon_sym_POUNDENDIF] = ACTIONS(13216),
    [anon_sym_POUNDEndif] = ACTIONS(13216),
    [anon_sym_POUNDendif2] = ACTIONS(13216),
    [anon_sym_POUNDENDIF2] = ACTIONS(13216),
    [anon_sym_POUNDEndif2] = ACTIONS(13216),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13216),
    [sym_trigger_keyword] = ACTIONS(13216),
    [sym_var_keyword] = ACTIONS(13216),
    [sym_local_keyword] = ACTIONS(13216),
    [sym_internal_keyword] = ACTIONS(13216),
    [sym_protected_keyword] = ACTIONS(13216),
    [sym_event_keyword] = ACTIONS(13216),
    [sym_fields_keyword] = ACTIONS(13216),
    [sym_keys_keyword] = ACTIONS(13216),
    [sym_fieldgroups_keyword] = ACTIONS(13216),
    [sym_actions_keyword] = ACTIONS(13216),
    [sym_layout_keyword] = ACTIONS(13216),
    [sym_area_keyword] = ACTIONS(13216),
    [sym_group_keyword] = ACTIONS(13216),
    [sym_repeater_keyword] = ACTIONS(13216),
    [sym_cuegroup_keyword] = ACTIONS(13216),
    [sym_fixed_keyword] = ACTIONS(13216),
    [sym_grid_keyword] = ACTIONS(13216),
    [sym_part_keyword] = ACTIONS(13216),
    [sym_systempart_keyword] = ACTIONS(13216),
    [sym_usercontrol_keyword] = ACTIONS(13216),
    [sym_dataset_keyword] = ACTIONS(13216),
    [sym_elements_keyword] = ACTIONS(13216),
    [sym_labels_keyword] = ACTIONS(13216),
    [sym_rendering_keyword] = ACTIONS(13216),
    [sym_requestpage_keyword] = ACTIONS(13216),
    [sym_schema_keyword] = ACTIONS(13216),
    [sym_views_keyword] = ACTIONS(13216),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13216),
    [sym_preproc_open] = ACTIONS(13216),
    [sym_preproc_close] = ACTIONS(13216),
  },
  [STATE(5341)] = {
    [sym__layout_element] = STATE(5343),
    [sym_area_section] = STATE(5343),
    [sym_group_section] = STATE(5343),
    [sym_repeater_section] = STATE(5343),
    [sym_cuegroup_section] = STATE(5343),
    [sym_fixed_section] = STATE(5343),
    [sym_grid_section] = STATE(5343),
    [sym_page_field] = STATE(5343),
    [sym_part_section] = STATE(5343),
    [sym_systempart_section] = STATE(5343),
    [sym_usercontrol_section] = STATE(5343),
    [sym_preproc_split_field] = STATE(5343),
    [sym_label_section] = STATE(5343),
    [sym_addfirst_modification] = STATE(5343),
    [sym_addlast_modification] = STATE(5343),
    [sym_addafter_modification] = STATE(5343),
    [sym_addbefore_modification] = STATE(5343),
    [sym_modify_modification] = STATE(5343),
    [sym_movefirst_modification] = STATE(5343),
    [sym_movelast_modification] = STATE(5343),
    [sym_moveafter_modification] = STATE(5343),
    [sym_movebefore_modification] = STATE(5343),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_conditional_layout] = STATE(5343),
    [aux_sym_layout_section_repeat1] = STATE(5343),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(13222),
    [anon_sym_POUNDELIF] = ACTIONS(13222),
    [anon_sym_POUNDElif] = ACTIONS(13222),
    [anon_sym_POUNDelse] = ACTIONS(13222),
    [anon_sym_POUNDELSE] = ACTIONS(13222),
    [anon_sym_POUNDElse] = ACTIONS(13222),
    [anon_sym_POUNDelse2] = ACTIONS(13222),
    [anon_sym_POUNDELSE2] = ACTIONS(13222),
    [anon_sym_POUNDElse2] = ACTIONS(13222),
    [anon_sym_POUNDendif] = ACTIONS(13222),
    [anon_sym_POUNDENDIF] = ACTIONS(13222),
    [anon_sym_POUNDEndif] = ACTIONS(13222),
    [anon_sym_POUNDendif2] = ACTIONS(13222),
    [anon_sym_POUNDENDIF2] = ACTIONS(13222),
    [anon_sym_POUNDEndif2] = ACTIONS(13222),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(13222),
  },
  [STATE(5342)] = {
    [sym__body_element] = STATE(5329),
    [sym_empty_statement] = STATE(5329),
    [sym_property] = STATE(5329),
    [sym_permissions_property] = STATE(5329),
    [sym_table_relation_property] = STATE(5329),
    [sym_fields_section] = STATE(5329),
    [sym_keys_section] = STATE(5329),
    [sym_fieldgroups_section] = STATE(5329),
    [sym_enum_value_declaration] = STATE(5329),
    [sym_labels_section] = STATE(5329),
    [sym_layout_section] = STATE(5329),
    [sym_modify_modification] = STATE(5329),
    [sym_actions_section] = STATE(5329),
    [sym_views_section] = STATE(5329),
    [sym_dataset_section] = STATE(5329),
    [sym_report_dataitem] = STATE(5329),
    [sym_report_column] = STATE(5329),
    [sym_requestpage_section] = STATE(5329),
    [sym_rendering_section] = STATE(5329),
    [sym_elements_section] = STATE(5329),
    [sym_schema_section] = STATE(5329),
    [sym_assembly_declaration] = STATE(5329),
    [sym_event_declaration] = STATE(5329),
    [sym_procedure] = STATE(5329),
    [sym_preproc_split_procedure] = STATE(5329),
    [sym_preproc_split_procedure_preamble] = STATE(5329),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5329),
    [sym_var_section] = STATE(5329),
    [sym_attribute_item] = STATE(5329),
    [sym_preproc_conditional] = STATE(5329),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5329),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13224),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5343)] = {
    [sym__layout_element] = STATE(5316),
    [sym_area_section] = STATE(5316),
    [sym_group_section] = STATE(5316),
    [sym_repeater_section] = STATE(5316),
    [sym_cuegroup_section] = STATE(5316),
    [sym_fixed_section] = STATE(5316),
    [sym_grid_section] = STATE(5316),
    [sym_page_field] = STATE(5316),
    [sym_part_section] = STATE(5316),
    [sym_systempart_section] = STATE(5316),
    [sym_usercontrol_section] = STATE(5316),
    [sym_preproc_split_field] = STATE(5316),
    [sym_label_section] = STATE(5316),
    [sym_addfirst_modification] = STATE(5316),
    [sym_addlast_modification] = STATE(5316),
    [sym_addafter_modification] = STATE(5316),
    [sym_addbefore_modification] = STATE(5316),
    [sym_modify_modification] = STATE(5316),
    [sym_movefirst_modification] = STATE(5316),
    [sym_movelast_modification] = STATE(5316),
    [sym_moveafter_modification] = STATE(5316),
    [sym_movebefore_modification] = STATE(5316),
    [sym_preproc_if] = STATE(4700),
    [sym_preproc_conditional_layout] = STATE(5316),
    [aux_sym_layout_section_repeat1] = STATE(5316),
    [aux_sym_where_condition_token1] = ACTIONS(10374),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(4439),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(4441),
    [aux_sym_basic_type_token6] = ACTIONS(9792),
    [aux_sym_addafter_modification_token1] = ACTIONS(4445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(4447),
    [aux_sym_modify_modification_token1] = ACTIONS(9794),
    [aux_sym_movefirst_modification_token1] = ACTIONS(4449),
    [aux_sym_movelast_modification_token1] = ACTIONS(4451),
    [aux_sym_moveafter_modification_token1] = ACTIONS(4453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(4455),
    [anon_sym_POUNDif] = ACTIONS(9796),
    [anon_sym_POUNDIF] = ACTIONS(9796),
    [anon_sym_POUNDIf] = ACTIONS(9796),
    [anon_sym_POUNDelif] = ACTIONS(13226),
    [anon_sym_POUNDELIF] = ACTIONS(13226),
    [anon_sym_POUNDElif] = ACTIONS(13226),
    [anon_sym_POUNDelse] = ACTIONS(13226),
    [anon_sym_POUNDELSE] = ACTIONS(13226),
    [anon_sym_POUNDElse] = ACTIONS(13226),
    [anon_sym_POUNDelse2] = ACTIONS(13226),
    [anon_sym_POUNDELSE2] = ACTIONS(13226),
    [anon_sym_POUNDElse2] = ACTIONS(13226),
    [anon_sym_POUNDendif] = ACTIONS(13226),
    [anon_sym_POUNDENDIF] = ACTIONS(13226),
    [anon_sym_POUNDEndif] = ACTIONS(13226),
    [anon_sym_POUNDendif2] = ACTIONS(13226),
    [anon_sym_POUNDENDIF2] = ACTIONS(13226),
    [anon_sym_POUNDEndif2] = ACTIONS(13226),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_area_keyword] = ACTIONS(4463),
    [sym_group_keyword] = ACTIONS(4465),
    [sym_repeater_keyword] = ACTIONS(4467),
    [sym_cuegroup_keyword] = ACTIONS(4469),
    [sym_fixed_keyword] = ACTIONS(4471),
    [sym_grid_keyword] = ACTIONS(4473),
    [sym_part_keyword] = ACTIONS(4475),
    [sym_systempart_keyword] = ACTIONS(4477),
    [sym_usercontrol_keyword] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_preproc_open] = ACTIONS(9796),
    [sym_preproc_close] = ACTIONS(13226),
  },
  [STATE(5344)] = {
    [sym__body_element] = STATE(5334),
    [sym_empty_statement] = STATE(5334),
    [sym_property] = STATE(5334),
    [sym_permissions_property] = STATE(5334),
    [sym_table_relation_property] = STATE(5334),
    [sym_fields_section] = STATE(5334),
    [sym_keys_section] = STATE(5334),
    [sym_fieldgroups_section] = STATE(5334),
    [sym_enum_value_declaration] = STATE(5334),
    [sym_labels_section] = STATE(5334),
    [sym_layout_section] = STATE(5334),
    [sym_modify_modification] = STATE(5334),
    [sym_actions_section] = STATE(5334),
    [sym_views_section] = STATE(5334),
    [sym_dataset_section] = STATE(5334),
    [sym_report_dataitem] = STATE(5334),
    [sym_report_column] = STATE(5334),
    [sym_requestpage_section] = STATE(5334),
    [sym_rendering_section] = STATE(5334),
    [sym_elements_section] = STATE(5334),
    [sym_schema_section] = STATE(5334),
    [sym_assembly_declaration] = STATE(5334),
    [sym_event_declaration] = STATE(5334),
    [sym_procedure] = STATE(5334),
    [sym_preproc_split_procedure] = STATE(5334),
    [sym_preproc_split_procedure_preamble] = STATE(5334),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5334),
    [sym_var_section] = STATE(5334),
    [sym_attribute_item] = STATE(5334),
    [sym_preproc_conditional] = STATE(5334),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5334),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13228),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5345)] = {
    [sym__body_element] = STATE(5337),
    [sym_empty_statement] = STATE(5337),
    [sym_property] = STATE(5337),
    [sym_permissions_property] = STATE(5337),
    [sym_table_relation_property] = STATE(5337),
    [sym_fields_section] = STATE(5337),
    [sym_keys_section] = STATE(5337),
    [sym_fieldgroups_section] = STATE(5337),
    [sym_enum_value_declaration] = STATE(5337),
    [sym_labels_section] = STATE(5337),
    [sym_layout_section] = STATE(5337),
    [sym_modify_modification] = STATE(5337),
    [sym_actions_section] = STATE(5337),
    [sym_views_section] = STATE(5337),
    [sym_dataset_section] = STATE(5337),
    [sym_report_dataitem] = STATE(5337),
    [sym_report_column] = STATE(5337),
    [sym_requestpage_section] = STATE(5337),
    [sym_rendering_section] = STATE(5337),
    [sym_elements_section] = STATE(5337),
    [sym_schema_section] = STATE(5337),
    [sym_assembly_declaration] = STATE(5337),
    [sym_event_declaration] = STATE(5337),
    [sym_procedure] = STATE(5337),
    [sym_preproc_split_procedure] = STATE(5337),
    [sym_preproc_split_procedure_preamble] = STATE(5337),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5337),
    [sym_var_section] = STATE(5337),
    [sym_attribute_item] = STATE(5337),
    [sym_preproc_conditional] = STATE(5337),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5337),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13230),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5346)] = {
    [sym_boolean] = STATE(12461),
    [sym_option_member_list] = STATE(12471),
    [sym_option_member] = STATE(12451),
    [sym_keyword_identifier] = STATE(12461),
    [sym_codeunit_keyword] = STATE(12463),
    [sym_xmlport_keyword] = STATE(12463),
    [sym_enum_keyword] = STATE(12463),
    [sym_keyword_as_identifier] = STATE(12461),
    [aux_sym_option_member_list_repeat2] = STATE(5358),
    [sym_identifier] = ACTIONS(13232),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(13234),
    [anon_sym_DASH] = ACTIONS(13236),
    [aux_sym_boolean_token1] = ACTIONS(13238),
    [aux_sym_boolean_token2] = ACTIONS(13238),
    [aux_sym_where_condition_token1] = ACTIONS(13240),
    [aux_sym_tabledata_permission_token2] = ACTIONS(13242),
    [aux_sym_record_type_token1] = ACTIONS(13242),
    [aux_sym_basic_type_token21] = ACTIONS(13242),
    [aux_sym_basic_type_token22] = ACTIONS(13244),
    [aux_sym_basic_type_token48] = ACTIONS(13242),
    [aux_sym_basic_type_token53] = ACTIONS(13240),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13240),
    [aux_sym_separator_action_token1] = ACTIONS(13240),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13240),
    [aux_sym_type_declaration_token1] = ACTIONS(13240),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(584),
    [anon_sym_POUNDif] = ACTIONS(582),
    [anon_sym_POUNDIF] = ACTIONS(582),
    [anon_sym_POUNDIf] = ACTIONS(582),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(13242),
    [aux_sym_keyword_identifier_token2] = ACTIONS(13242),
    [sym_table_keyword] = ACTIONS(13240),
    [sym_page_keyword] = ACTIONS(13242),
    [anon_sym_codeunit] = ACTIONS(13246),
    [anon_sym_CODEUNIT] = ACTIONS(13246),
    [anon_sym_Codeunit] = ACTIONS(13246),
    [anon_sym_CodeUnit] = ACTIONS(13246),
    [anon_sym_COdeunit] = ACTIONS(13246),
    [anon_sym_codeUnit] = ACTIONS(13246),
    [sym_report_keyword] = ACTIONS(13242),
    [sym_query_keyword] = ACTIONS(13242),
    [anon_sym_xmlport] = ACTIONS(13248),
    [anon_sym_XMLPORT] = ACTIONS(13248),
    [anon_sym_Xmlport] = ACTIONS(13248),
    [anon_sym_XMLport] = ACTIONS(13248),
    [anon_sym_XMLPort] = ACTIONS(13248),
    [anon_sym_XmlPort] = ACTIONS(13248),
    [anon_sym_enum] = ACTIONS(13250),
    [anon_sym_ENUM] = ACTIONS(13250),
    [anon_sym_Enum] = ACTIONS(13250),
    [anon_sym_eNUM] = ACTIONS(13250),
    [anon_sym_eNum] = ACTIONS(13250),
    [anon_sym_ENum] = ACTIONS(13250),
    [sym_var_keyword] = ACTIONS(584),
    [sym_local_keyword] = ACTIONS(13232),
    [sym_internal_keyword] = ACTIONS(13232),
    [sym_protected_keyword] = ACTIONS(13232),
    [sym_key_keyword] = ACTIONS(13240),
    [sym_dataset_keyword] = ACTIONS(13240),
    [sym_quoted_identifier] = ACTIONS(13252),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(13252),
    [sym_integer] = ACTIONS(13252),
    [sym_preproc_open] = ACTIONS(582),
    [sym_begin_keyword] = ACTIONS(582),
  },
  [STATE(5347)] = {
    [anon_sym_SEMI] = ACTIONS(13109),
    [anon_sym_LBRACE] = ACTIONS(13111),
    [aux_sym_where_condition_token1] = ACTIONS(13113),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13109),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13109),
    [anon_sym_LBRACK] = ACTIONS(13109),
    [aux_sym_basic_type_token6] = ACTIONS(13113),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13109),
    [aux_sym_addafter_modification_token1] = ACTIONS(13109),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13109),
    [aux_sym_modify_modification_token1] = ACTIONS(13109),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13109),
    [aux_sym_movelast_modification_token1] = ACTIONS(13109),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13109),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13109),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13109),
    [anon_sym_POUNDif] = ACTIONS(13109),
    [anon_sym_POUNDIF] = ACTIONS(13109),
    [anon_sym_POUNDIf] = ACTIONS(13109),
    [anon_sym_POUNDelif] = ACTIONS(13254),
    [anon_sym_POUNDELIF] = ACTIONS(13254),
    [anon_sym_POUNDElif] = ACTIONS(13254),
    [anon_sym_POUNDelse] = ACTIONS(13254),
    [anon_sym_POUNDELSE] = ACTIONS(13254),
    [anon_sym_POUNDElse] = ACTIONS(13254),
    [anon_sym_POUNDelse2] = ACTIONS(13254),
    [anon_sym_POUNDELSE2] = ACTIONS(13254),
    [anon_sym_POUNDElse2] = ACTIONS(13254),
    [anon_sym_POUNDendif] = ACTIONS(13254),
    [anon_sym_POUNDENDIF] = ACTIONS(13254),
    [anon_sym_POUNDEndif] = ACTIONS(13254),
    [anon_sym_POUNDendif2] = ACTIONS(13254),
    [anon_sym_POUNDENDIF2] = ACTIONS(13254),
    [anon_sym_POUNDEndif2] = ACTIONS(13254),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13109),
    [sym_trigger_keyword] = ACTIONS(13109),
    [sym_var_keyword] = ACTIONS(13109),
    [sym_local_keyword] = ACTIONS(13109),
    [sym_internal_keyword] = ACTIONS(13109),
    [sym_protected_keyword] = ACTIONS(13109),
    [sym_event_keyword] = ACTIONS(13109),
    [sym_fields_keyword] = ACTIONS(13109),
    [sym_keys_keyword] = ACTIONS(13109),
    [sym_fieldgroups_keyword] = ACTIONS(13109),
    [sym_actions_keyword] = ACTIONS(13109),
    [sym_layout_keyword] = ACTIONS(13109),
    [sym_area_keyword] = ACTIONS(13109),
    [sym_group_keyword] = ACTIONS(13109),
    [sym_repeater_keyword] = ACTIONS(13109),
    [sym_cuegroup_keyword] = ACTIONS(13109),
    [sym_fixed_keyword] = ACTIONS(13109),
    [sym_grid_keyword] = ACTIONS(13109),
    [sym_part_keyword] = ACTIONS(13109),
    [sym_systempart_keyword] = ACTIONS(13109),
    [sym_usercontrol_keyword] = ACTIONS(13109),
    [sym_dataset_keyword] = ACTIONS(13109),
    [sym_elements_keyword] = ACTIONS(13109),
    [sym_labels_keyword] = ACTIONS(13109),
    [sym_rendering_keyword] = ACTIONS(13109),
    [sym_requestpage_keyword] = ACTIONS(13109),
    [sym_schema_keyword] = ACTIONS(13109),
    [sym_views_keyword] = ACTIONS(13109),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13109),
    [sym_preproc_open] = ACTIONS(13109),
    [sym_preproc_close] = ACTIONS(13254),
  },
  [STATE(5348)] = {
    [anon_sym_SEMI] = ACTIONS(13257),
    [anon_sym_LBRACE] = ACTIONS(13259),
    [aux_sym_where_condition_token1] = ACTIONS(13261),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13257),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13257),
    [anon_sym_LBRACK] = ACTIONS(13257),
    [aux_sym_basic_type_token6] = ACTIONS(13261),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13257),
    [aux_sym_addafter_modification_token1] = ACTIONS(13257),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13257),
    [aux_sym_modify_modification_token1] = ACTIONS(13257),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13257),
    [aux_sym_movelast_modification_token1] = ACTIONS(13257),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13257),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13257),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13257),
    [anon_sym_POUNDif] = ACTIONS(13257),
    [anon_sym_POUNDIF] = ACTIONS(13257),
    [anon_sym_POUNDIf] = ACTIONS(13257),
    [anon_sym_POUNDelif] = ACTIONS(13257),
    [anon_sym_POUNDELIF] = ACTIONS(13257),
    [anon_sym_POUNDElif] = ACTIONS(13257),
    [anon_sym_POUNDelse] = ACTIONS(13257),
    [anon_sym_POUNDELSE] = ACTIONS(13257),
    [anon_sym_POUNDElse] = ACTIONS(13257),
    [anon_sym_POUNDelse2] = ACTIONS(13257),
    [anon_sym_POUNDELSE2] = ACTIONS(13257),
    [anon_sym_POUNDElse2] = ACTIONS(13257),
    [anon_sym_POUNDendif] = ACTIONS(13257),
    [anon_sym_POUNDENDIF] = ACTIONS(13257),
    [anon_sym_POUNDEndif] = ACTIONS(13257),
    [anon_sym_POUNDendif2] = ACTIONS(13257),
    [anon_sym_POUNDENDIF2] = ACTIONS(13257),
    [anon_sym_POUNDEndif2] = ACTIONS(13257),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13257),
    [sym_trigger_keyword] = ACTIONS(13257),
    [sym_var_keyword] = ACTIONS(13257),
    [sym_local_keyword] = ACTIONS(13257),
    [sym_internal_keyword] = ACTIONS(13257),
    [sym_protected_keyword] = ACTIONS(13257),
    [sym_event_keyword] = ACTIONS(13257),
    [sym_fields_keyword] = ACTIONS(13257),
    [sym_keys_keyword] = ACTIONS(13257),
    [sym_fieldgroups_keyword] = ACTIONS(13257),
    [sym_actions_keyword] = ACTIONS(13257),
    [sym_layout_keyword] = ACTIONS(13257),
    [sym_area_keyword] = ACTIONS(13257),
    [sym_group_keyword] = ACTIONS(13257),
    [sym_repeater_keyword] = ACTIONS(13257),
    [sym_cuegroup_keyword] = ACTIONS(13257),
    [sym_fixed_keyword] = ACTIONS(13257),
    [sym_grid_keyword] = ACTIONS(13257),
    [sym_part_keyword] = ACTIONS(13257),
    [sym_systempart_keyword] = ACTIONS(13257),
    [sym_usercontrol_keyword] = ACTIONS(13257),
    [sym_dataset_keyword] = ACTIONS(13257),
    [sym_elements_keyword] = ACTIONS(13257),
    [sym_labels_keyword] = ACTIONS(13257),
    [sym_rendering_keyword] = ACTIONS(13257),
    [sym_requestpage_keyword] = ACTIONS(13257),
    [sym_schema_keyword] = ACTIONS(13257),
    [sym_views_keyword] = ACTIONS(13257),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13257),
    [sym_preproc_open] = ACTIONS(13257),
    [sym_preproc_close] = ACTIONS(13257),
  },
  [STATE(5349)] = {
    [sym__body_element] = STATE(5337),
    [sym_empty_statement] = STATE(5337),
    [sym_property] = STATE(5337),
    [sym_permissions_property] = STATE(5337),
    [sym_table_relation_property] = STATE(5337),
    [sym_fields_section] = STATE(5337),
    [sym_keys_section] = STATE(5337),
    [sym_fieldgroups_section] = STATE(5337),
    [sym_enum_value_declaration] = STATE(5337),
    [sym_labels_section] = STATE(5337),
    [sym_layout_section] = STATE(5337),
    [sym_modify_modification] = STATE(5337),
    [sym_actions_section] = STATE(5337),
    [sym_views_section] = STATE(5337),
    [sym_dataset_section] = STATE(5337),
    [sym_report_dataitem] = STATE(5337),
    [sym_report_column] = STATE(5337),
    [sym_requestpage_section] = STATE(5337),
    [sym_rendering_section] = STATE(5337),
    [sym_elements_section] = STATE(5337),
    [sym_schema_section] = STATE(5337),
    [sym_assembly_declaration] = STATE(5337),
    [sym_event_declaration] = STATE(5337),
    [sym_procedure] = STATE(5337),
    [sym_preproc_split_procedure] = STATE(5337),
    [sym_preproc_split_procedure_preamble] = STATE(5337),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5337),
    [sym_var_section] = STATE(5337),
    [sym_attribute_item] = STATE(5337),
    [sym_preproc_conditional] = STATE(5337),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5337),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13263),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5350)] = {
    [sym__body_element] = STATE(5333),
    [sym_empty_statement] = STATE(5333),
    [sym_property] = STATE(5333),
    [sym_permissions_property] = STATE(5333),
    [sym_table_relation_property] = STATE(5333),
    [sym_fields_section] = STATE(5333),
    [sym_keys_section] = STATE(5333),
    [sym_fieldgroups_section] = STATE(5333),
    [sym_enum_value_declaration] = STATE(5333),
    [sym_labels_section] = STATE(5333),
    [sym_layout_section] = STATE(5333),
    [sym_modify_modification] = STATE(5333),
    [sym_actions_section] = STATE(5333),
    [sym_views_section] = STATE(5333),
    [sym_dataset_section] = STATE(5333),
    [sym_report_dataitem] = STATE(5333),
    [sym_report_column] = STATE(5333),
    [sym_requestpage_section] = STATE(5333),
    [sym_rendering_section] = STATE(5333),
    [sym_elements_section] = STATE(5333),
    [sym_schema_section] = STATE(5333),
    [sym_assembly_declaration] = STATE(5333),
    [sym_event_declaration] = STATE(5333),
    [sym_procedure] = STATE(5333),
    [sym_preproc_split_procedure] = STATE(5333),
    [sym_preproc_split_procedure_preamble] = STATE(5333),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5333),
    [sym_var_section] = STATE(5333),
    [sym_attribute_item] = STATE(5333),
    [sym_preproc_conditional] = STATE(5333),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_add_dataset_modification_repeat1] = STATE(5333),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13265),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_dataitem_keyword] = ACTIONS(12275),
    [sym_column_keyword] = ACTIONS(12277),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5351)] = {
    [anon_sym_SEMI] = ACTIONS(13267),
    [anon_sym_LBRACE] = ACTIONS(13269),
    [aux_sym_where_condition_token1] = ACTIONS(13271),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13267),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13267),
    [anon_sym_LBRACK] = ACTIONS(13267),
    [aux_sym_basic_type_token6] = ACTIONS(13271),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13267),
    [aux_sym_addafter_modification_token1] = ACTIONS(13267),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13267),
    [aux_sym_modify_modification_token1] = ACTIONS(13267),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13267),
    [aux_sym_movelast_modification_token1] = ACTIONS(13267),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13267),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13267),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13267),
    [anon_sym_POUNDif] = ACTIONS(13267),
    [anon_sym_POUNDIF] = ACTIONS(13267),
    [anon_sym_POUNDIf] = ACTIONS(13267),
    [anon_sym_POUNDelif] = ACTIONS(13267),
    [anon_sym_POUNDELIF] = ACTIONS(13267),
    [anon_sym_POUNDElif] = ACTIONS(13267),
    [anon_sym_POUNDelse] = ACTIONS(13267),
    [anon_sym_POUNDELSE] = ACTIONS(13267),
    [anon_sym_POUNDElse] = ACTIONS(13267),
    [anon_sym_POUNDelse2] = ACTIONS(13267),
    [anon_sym_POUNDELSE2] = ACTIONS(13267),
    [anon_sym_POUNDElse2] = ACTIONS(13267),
    [anon_sym_POUNDendif] = ACTIONS(13267),
    [anon_sym_POUNDENDIF] = ACTIONS(13267),
    [anon_sym_POUNDEndif] = ACTIONS(13267),
    [anon_sym_POUNDendif2] = ACTIONS(13267),
    [anon_sym_POUNDENDIF2] = ACTIONS(13267),
    [anon_sym_POUNDEndif2] = ACTIONS(13267),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13267),
    [sym_trigger_keyword] = ACTIONS(13267),
    [sym_var_keyword] = ACTIONS(13267),
    [sym_local_keyword] = ACTIONS(13267),
    [sym_internal_keyword] = ACTIONS(13267),
    [sym_protected_keyword] = ACTIONS(13267),
    [sym_event_keyword] = ACTIONS(13267),
    [sym_fields_keyword] = ACTIONS(13267),
    [sym_keys_keyword] = ACTIONS(13267),
    [sym_fieldgroups_keyword] = ACTIONS(13267),
    [sym_actions_keyword] = ACTIONS(13267),
    [sym_layout_keyword] = ACTIONS(13267),
    [sym_area_keyword] = ACTIONS(13267),
    [sym_group_keyword] = ACTIONS(13267),
    [sym_repeater_keyword] = ACTIONS(13267),
    [sym_cuegroup_keyword] = ACTIONS(13267),
    [sym_fixed_keyword] = ACTIONS(13267),
    [sym_grid_keyword] = ACTIONS(13267),
    [sym_part_keyword] = ACTIONS(13267),
    [sym_systempart_keyword] = ACTIONS(13267),
    [sym_usercontrol_keyword] = ACTIONS(13267),
    [sym_dataset_keyword] = ACTIONS(13267),
    [sym_elements_keyword] = ACTIONS(13267),
    [sym_labels_keyword] = ACTIONS(13267),
    [sym_rendering_keyword] = ACTIONS(13267),
    [sym_requestpage_keyword] = ACTIONS(13267),
    [sym_schema_keyword] = ACTIONS(13267),
    [sym_views_keyword] = ACTIONS(13267),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13267),
    [sym_preproc_open] = ACTIONS(13267),
    [sym_preproc_close] = ACTIONS(13267),
  },
  [STATE(5352)] = {
    [anon_sym_SEMI] = ACTIONS(13273),
    [anon_sym_LBRACE] = ACTIONS(13275),
    [aux_sym_where_condition_token1] = ACTIONS(13277),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13273),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13273),
    [anon_sym_LBRACK] = ACTIONS(13273),
    [aux_sym_basic_type_token6] = ACTIONS(13277),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13273),
    [aux_sym_addafter_modification_token1] = ACTIONS(13273),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13273),
    [aux_sym_modify_modification_token1] = ACTIONS(13273),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13273),
    [aux_sym_movelast_modification_token1] = ACTIONS(13273),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13273),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13273),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13273),
    [anon_sym_POUNDif] = ACTIONS(13273),
    [anon_sym_POUNDIF] = ACTIONS(13273),
    [anon_sym_POUNDIf] = ACTIONS(13273),
    [anon_sym_POUNDelif] = ACTIONS(13273),
    [anon_sym_POUNDELIF] = ACTIONS(13273),
    [anon_sym_POUNDElif] = ACTIONS(13273),
    [anon_sym_POUNDelse] = ACTIONS(13273),
    [anon_sym_POUNDELSE] = ACTIONS(13273),
    [anon_sym_POUNDElse] = ACTIONS(13273),
    [anon_sym_POUNDelse2] = ACTIONS(13273),
    [anon_sym_POUNDELSE2] = ACTIONS(13273),
    [anon_sym_POUNDElse2] = ACTIONS(13273),
    [anon_sym_POUNDendif] = ACTIONS(13273),
    [anon_sym_POUNDENDIF] = ACTIONS(13273),
    [anon_sym_POUNDEndif] = ACTIONS(13273),
    [anon_sym_POUNDendif2] = ACTIONS(13273),
    [anon_sym_POUNDENDIF2] = ACTIONS(13273),
    [anon_sym_POUNDEndif2] = ACTIONS(13273),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13273),
    [sym_trigger_keyword] = ACTIONS(13273),
    [sym_var_keyword] = ACTIONS(13273),
    [sym_local_keyword] = ACTIONS(13273),
    [sym_internal_keyword] = ACTIONS(13273),
    [sym_protected_keyword] = ACTIONS(13273),
    [sym_event_keyword] = ACTIONS(13273),
    [sym_fields_keyword] = ACTIONS(13273),
    [sym_keys_keyword] = ACTIONS(13273),
    [sym_fieldgroups_keyword] = ACTIONS(13273),
    [sym_actions_keyword] = ACTIONS(13273),
    [sym_layout_keyword] = ACTIONS(13273),
    [sym_area_keyword] = ACTIONS(13273),
    [sym_group_keyword] = ACTIONS(13273),
    [sym_repeater_keyword] = ACTIONS(13273),
    [sym_cuegroup_keyword] = ACTIONS(13273),
    [sym_fixed_keyword] = ACTIONS(13273),
    [sym_grid_keyword] = ACTIONS(13273),
    [sym_part_keyword] = ACTIONS(13273),
    [sym_systempart_keyword] = ACTIONS(13273),
    [sym_usercontrol_keyword] = ACTIONS(13273),
    [sym_dataset_keyword] = ACTIONS(13273),
    [sym_elements_keyword] = ACTIONS(13273),
    [sym_labels_keyword] = ACTIONS(13273),
    [sym_rendering_keyword] = ACTIONS(13273),
    [sym_requestpage_keyword] = ACTIONS(13273),
    [sym_schema_keyword] = ACTIONS(13273),
    [sym_views_keyword] = ACTIONS(13273),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13273),
    [sym_preproc_open] = ACTIONS(13273),
    [sym_preproc_close] = ACTIONS(13273),
  },
  [STATE(5353)] = {
    [anon_sym_SEMI] = ACTIONS(13279),
    [aux_sym_where_condition_token1] = ACTIONS(13281),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13279),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13279),
    [anon_sym_LBRACK] = ACTIONS(13279),
    [aux_sym_basic_type_token6] = ACTIONS(13281),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13279),
    [aux_sym_addafter_modification_token1] = ACTIONS(13279),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13279),
    [aux_sym_modify_modification_token1] = ACTIONS(13279),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13279),
    [aux_sym_movelast_modification_token1] = ACTIONS(13279),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13279),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13279),
    [anon_sym_POUNDif] = ACTIONS(13279),
    [anon_sym_POUNDIF] = ACTIONS(13279),
    [anon_sym_POUNDIf] = ACTIONS(13279),
    [anon_sym_POUNDelif] = ACTIONS(13279),
    [anon_sym_POUNDELIF] = ACTIONS(13279),
    [anon_sym_POUNDElif] = ACTIONS(13279),
    [anon_sym_POUNDelse] = ACTIONS(13279),
    [anon_sym_POUNDELSE] = ACTIONS(13279),
    [anon_sym_POUNDElse] = ACTIONS(13279),
    [anon_sym_POUNDelse2] = ACTIONS(13279),
    [anon_sym_POUNDELSE2] = ACTIONS(13279),
    [anon_sym_POUNDElse2] = ACTIONS(13279),
    [anon_sym_POUNDendif] = ACTIONS(13279),
    [anon_sym_POUNDENDIF] = ACTIONS(13279),
    [anon_sym_POUNDEndif] = ACTIONS(13279),
    [anon_sym_POUNDendif2] = ACTIONS(13279),
    [anon_sym_POUNDENDIF2] = ACTIONS(13279),
    [anon_sym_POUNDEndif2] = ACTIONS(13279),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13279),
    [sym_trigger_keyword] = ACTIONS(13279),
    [sym_var_keyword] = ACTIONS(13279),
    [sym_local_keyword] = ACTIONS(13279),
    [sym_internal_keyword] = ACTIONS(13279),
    [sym_protected_keyword] = ACTIONS(13279),
    [sym_event_keyword] = ACTIONS(13279),
    [sym_fields_keyword] = ACTIONS(13279),
    [sym_keys_keyword] = ACTIONS(13279),
    [sym_fieldgroups_keyword] = ACTIONS(13279),
    [sym_actions_keyword] = ACTIONS(13279),
    [sym_layout_keyword] = ACTIONS(13279),
    [sym_area_keyword] = ACTIONS(13279),
    [sym_group_keyword] = ACTIONS(13279),
    [sym_repeater_keyword] = ACTIONS(13279),
    [sym_cuegroup_keyword] = ACTIONS(13279),
    [sym_fixed_keyword] = ACTIONS(13279),
    [sym_grid_keyword] = ACTIONS(13279),
    [sym_part_keyword] = ACTIONS(13279),
    [sym_systempart_keyword] = ACTIONS(13279),
    [sym_usercontrol_keyword] = ACTIONS(13279),
    [sym_dataset_keyword] = ACTIONS(13279),
    [sym_elements_keyword] = ACTIONS(13279),
    [sym_labels_keyword] = ACTIONS(13279),
    [sym_rendering_keyword] = ACTIONS(13279),
    [sym_requestpage_keyword] = ACTIONS(13279),
    [sym_schema_keyword] = ACTIONS(13279),
    [sym_views_keyword] = ACTIONS(13279),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13279),
    [sym_preproc_open] = ACTIONS(13279),
    [sym_preproc_close] = ACTIONS(13279),
  },
  [STATE(5354)] = {
    [anon_sym_SEMI] = ACTIONS(12768),
    [aux_sym_where_condition_token1] = ACTIONS(13283),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13285),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13285),
    [anon_sym_LBRACK] = ACTIONS(12768),
    [aux_sym_basic_type_token6] = ACTIONS(13283),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12768),
    [aux_sym_addafter_modification_token1] = ACTIONS(13285),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13285),
    [aux_sym_modify_modification_token1] = ACTIONS(13287),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13285),
    [aux_sym_movelast_modification_token1] = ACTIONS(13285),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13285),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13285),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12768),
    [anon_sym_POUNDif] = ACTIONS(13287),
    [anon_sym_POUNDIF] = ACTIONS(13287),
    [anon_sym_POUNDIf] = ACTIONS(13287),
    [anon_sym_POUNDelif] = ACTIONS(13287),
    [anon_sym_POUNDELIF] = ACTIONS(13287),
    [anon_sym_POUNDElif] = ACTIONS(13287),
    [anon_sym_POUNDelse] = ACTIONS(13287),
    [anon_sym_POUNDELSE] = ACTIONS(13287),
    [anon_sym_POUNDElse] = ACTIONS(13287),
    [anon_sym_POUNDelse2] = ACTIONS(13287),
    [anon_sym_POUNDELSE2] = ACTIONS(13287),
    [anon_sym_POUNDElse2] = ACTIONS(13287),
    [anon_sym_POUNDendif] = ACTIONS(13287),
    [anon_sym_POUNDENDIF] = ACTIONS(13287),
    [anon_sym_POUNDEndif] = ACTIONS(13287),
    [anon_sym_POUNDendif2] = ACTIONS(13287),
    [anon_sym_POUNDENDIF2] = ACTIONS(13287),
    [anon_sym_POUNDEndif2] = ACTIONS(13287),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12768),
    [sym_trigger_keyword] = ACTIONS(12768),
    [sym_var_keyword] = ACTIONS(12768),
    [sym_local_keyword] = ACTIONS(12768),
    [sym_internal_keyword] = ACTIONS(12768),
    [sym_protected_keyword] = ACTIONS(12768),
    [sym_event_keyword] = ACTIONS(12768),
    [sym_fields_keyword] = ACTIONS(12768),
    [sym_keys_keyword] = ACTIONS(12768),
    [sym_fieldgroups_keyword] = ACTIONS(12768),
    [sym_actions_keyword] = ACTIONS(12768),
    [sym_layout_keyword] = ACTIONS(12768),
    [sym_area_keyword] = ACTIONS(13285),
    [sym_group_keyword] = ACTIONS(13285),
    [sym_repeater_keyword] = ACTIONS(13285),
    [sym_cuegroup_keyword] = ACTIONS(13285),
    [sym_fixed_keyword] = ACTIONS(13285),
    [sym_grid_keyword] = ACTIONS(13285),
    [sym_part_keyword] = ACTIONS(13285),
    [sym_systempart_keyword] = ACTIONS(13285),
    [sym_usercontrol_keyword] = ACTIONS(13285),
    [sym_dataset_keyword] = ACTIONS(12768),
    [sym_elements_keyword] = ACTIONS(12768),
    [sym_labels_keyword] = ACTIONS(12768),
    [sym_rendering_keyword] = ACTIONS(12768),
    [sym_requestpage_keyword] = ACTIONS(12768),
    [sym_schema_keyword] = ACTIONS(12768),
    [sym_views_keyword] = ACTIONS(12768),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12768),
    [sym_preproc_open] = ACTIONS(13287),
    [sym_preproc_close] = ACTIONS(13287),
  },
  [STATE(5355)] = {
    [anon_sym_SEMI] = ACTIONS(13290),
    [aux_sym_where_condition_token1] = ACTIONS(13292),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13290),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13290),
    [anon_sym_LBRACK] = ACTIONS(13290),
    [aux_sym_basic_type_token6] = ACTIONS(13292),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13290),
    [aux_sym_addafter_modification_token1] = ACTIONS(13290),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13290),
    [aux_sym_modify_modification_token1] = ACTIONS(13290),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13290),
    [aux_sym_movelast_modification_token1] = ACTIONS(13290),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13290),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13290),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13290),
    [anon_sym_POUNDif] = ACTIONS(13290),
    [anon_sym_POUNDIF] = ACTIONS(13290),
    [anon_sym_POUNDIf] = ACTIONS(13290),
    [anon_sym_POUNDelif] = ACTIONS(13290),
    [anon_sym_POUNDELIF] = ACTIONS(13290),
    [anon_sym_POUNDElif] = ACTIONS(13290),
    [anon_sym_POUNDelse] = ACTIONS(13290),
    [anon_sym_POUNDELSE] = ACTIONS(13290),
    [anon_sym_POUNDElse] = ACTIONS(13290),
    [anon_sym_POUNDelse2] = ACTIONS(13290),
    [anon_sym_POUNDELSE2] = ACTIONS(13290),
    [anon_sym_POUNDElse2] = ACTIONS(13290),
    [anon_sym_POUNDendif] = ACTIONS(13290),
    [anon_sym_POUNDENDIF] = ACTIONS(13290),
    [anon_sym_POUNDEndif] = ACTIONS(13290),
    [anon_sym_POUNDendif2] = ACTIONS(13290),
    [anon_sym_POUNDENDIF2] = ACTIONS(13290),
    [anon_sym_POUNDEndif2] = ACTIONS(13290),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13290),
    [sym_trigger_keyword] = ACTIONS(13290),
    [sym_var_keyword] = ACTIONS(13290),
    [sym_local_keyword] = ACTIONS(13290),
    [sym_internal_keyword] = ACTIONS(13290),
    [sym_protected_keyword] = ACTIONS(13290),
    [sym_event_keyword] = ACTIONS(13290),
    [sym_fields_keyword] = ACTIONS(13290),
    [sym_keys_keyword] = ACTIONS(13290),
    [sym_fieldgroups_keyword] = ACTIONS(13290),
    [sym_actions_keyword] = ACTIONS(13290),
    [sym_layout_keyword] = ACTIONS(13290),
    [sym_area_keyword] = ACTIONS(13290),
    [sym_group_keyword] = ACTIONS(13290),
    [sym_repeater_keyword] = ACTIONS(13290),
    [sym_cuegroup_keyword] = ACTIONS(13290),
    [sym_fixed_keyword] = ACTIONS(13290),
    [sym_grid_keyword] = ACTIONS(13290),
    [sym_part_keyword] = ACTIONS(13290),
    [sym_systempart_keyword] = ACTIONS(13290),
    [sym_usercontrol_keyword] = ACTIONS(13290),
    [sym_dataset_keyword] = ACTIONS(13290),
    [sym_elements_keyword] = ACTIONS(13290),
    [sym_labels_keyword] = ACTIONS(13290),
    [sym_rendering_keyword] = ACTIONS(13290),
    [sym_requestpage_keyword] = ACTIONS(13290),
    [sym_schema_keyword] = ACTIONS(13290),
    [sym_views_keyword] = ACTIONS(13290),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13290),
    [sym_preproc_open] = ACTIONS(13290),
    [sym_preproc_close] = ACTIONS(13290),
  },
  [STATE(5356)] = {
    [anon_sym_SEMI] = ACTIONS(13294),
    [aux_sym_where_condition_token1] = ACTIONS(13296),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13294),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13294),
    [anon_sym_LBRACK] = ACTIONS(13294),
    [aux_sym_basic_type_token6] = ACTIONS(13296),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13294),
    [aux_sym_addafter_modification_token1] = ACTIONS(13294),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13294),
    [aux_sym_modify_modification_token1] = ACTIONS(13294),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13294),
    [aux_sym_movelast_modification_token1] = ACTIONS(13294),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13294),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13294),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13294),
    [anon_sym_POUNDif] = ACTIONS(13294),
    [anon_sym_POUNDIF] = ACTIONS(13294),
    [anon_sym_POUNDIf] = ACTIONS(13294),
    [anon_sym_POUNDelif] = ACTIONS(13294),
    [anon_sym_POUNDELIF] = ACTIONS(13294),
    [anon_sym_POUNDElif] = ACTIONS(13294),
    [anon_sym_POUNDelse] = ACTIONS(13294),
    [anon_sym_POUNDELSE] = ACTIONS(13294),
    [anon_sym_POUNDElse] = ACTIONS(13294),
    [anon_sym_POUNDelse2] = ACTIONS(13294),
    [anon_sym_POUNDELSE2] = ACTIONS(13294),
    [anon_sym_POUNDElse2] = ACTIONS(13294),
    [anon_sym_POUNDendif] = ACTIONS(13294),
    [anon_sym_POUNDENDIF] = ACTIONS(13294),
    [anon_sym_POUNDEndif] = ACTIONS(13294),
    [anon_sym_POUNDendif2] = ACTIONS(13294),
    [anon_sym_POUNDENDIF2] = ACTIONS(13294),
    [anon_sym_POUNDEndif2] = ACTIONS(13294),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13294),
    [sym_trigger_keyword] = ACTIONS(13294),
    [sym_var_keyword] = ACTIONS(13294),
    [sym_local_keyword] = ACTIONS(13294),
    [sym_internal_keyword] = ACTIONS(13294),
    [sym_protected_keyword] = ACTIONS(13294),
    [sym_event_keyword] = ACTIONS(13294),
    [sym_fields_keyword] = ACTIONS(13294),
    [sym_keys_keyword] = ACTIONS(13294),
    [sym_fieldgroups_keyword] = ACTIONS(13294),
    [sym_actions_keyword] = ACTIONS(13294),
    [sym_layout_keyword] = ACTIONS(13294),
    [sym_area_keyword] = ACTIONS(13294),
    [sym_group_keyword] = ACTIONS(13294),
    [sym_repeater_keyword] = ACTIONS(13294),
    [sym_cuegroup_keyword] = ACTIONS(13294),
    [sym_fixed_keyword] = ACTIONS(13294),
    [sym_grid_keyword] = ACTIONS(13294),
    [sym_part_keyword] = ACTIONS(13294),
    [sym_systempart_keyword] = ACTIONS(13294),
    [sym_usercontrol_keyword] = ACTIONS(13294),
    [sym_dataset_keyword] = ACTIONS(13294),
    [sym_elements_keyword] = ACTIONS(13294),
    [sym_labels_keyword] = ACTIONS(13294),
    [sym_rendering_keyword] = ACTIONS(13294),
    [sym_requestpage_keyword] = ACTIONS(13294),
    [sym_schema_keyword] = ACTIONS(13294),
    [sym_views_keyword] = ACTIONS(13294),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13294),
    [sym_preproc_open] = ACTIONS(13294),
    [sym_preproc_close] = ACTIONS(13294),
  },
  [STATE(5357)] = {
    [anon_sym_SEMI] = ACTIONS(13298),
    [aux_sym_where_condition_token1] = ACTIONS(13300),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13298),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13298),
    [anon_sym_LBRACK] = ACTIONS(13298),
    [aux_sym_basic_type_token6] = ACTIONS(13300),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13298),
    [aux_sym_addafter_modification_token1] = ACTIONS(13298),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13298),
    [aux_sym_modify_modification_token1] = ACTIONS(13298),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13298),
    [aux_sym_movelast_modification_token1] = ACTIONS(13298),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13298),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13298),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13298),
    [anon_sym_POUNDif] = ACTIONS(13298),
    [anon_sym_POUNDIF] = ACTIONS(13298),
    [anon_sym_POUNDIf] = ACTIONS(13298),
    [anon_sym_POUNDelif] = ACTIONS(13298),
    [anon_sym_POUNDELIF] = ACTIONS(13298),
    [anon_sym_POUNDElif] = ACTIONS(13298),
    [anon_sym_POUNDelse] = ACTIONS(13298),
    [anon_sym_POUNDELSE] = ACTIONS(13298),
    [anon_sym_POUNDElse] = ACTIONS(13298),
    [anon_sym_POUNDelse2] = ACTIONS(13298),
    [anon_sym_POUNDELSE2] = ACTIONS(13298),
    [anon_sym_POUNDElse2] = ACTIONS(13298),
    [anon_sym_POUNDendif] = ACTIONS(13298),
    [anon_sym_POUNDENDIF] = ACTIONS(13298),
    [anon_sym_POUNDEndif] = ACTIONS(13298),
    [anon_sym_POUNDendif2] = ACTIONS(13298),
    [anon_sym_POUNDENDIF2] = ACTIONS(13298),
    [anon_sym_POUNDEndif2] = ACTIONS(13298),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13298),
    [sym_trigger_keyword] = ACTIONS(13298),
    [sym_var_keyword] = ACTIONS(13298),
    [sym_local_keyword] = ACTIONS(13298),
    [sym_internal_keyword] = ACTIONS(13298),
    [sym_protected_keyword] = ACTIONS(13298),
    [sym_event_keyword] = ACTIONS(13298),
    [sym_fields_keyword] = ACTIONS(13298),
    [sym_keys_keyword] = ACTIONS(13298),
    [sym_fieldgroups_keyword] = ACTIONS(13298),
    [sym_actions_keyword] = ACTIONS(13298),
    [sym_layout_keyword] = ACTIONS(13298),
    [sym_area_keyword] = ACTIONS(13298),
    [sym_group_keyword] = ACTIONS(13298),
    [sym_repeater_keyword] = ACTIONS(13298),
    [sym_cuegroup_keyword] = ACTIONS(13298),
    [sym_fixed_keyword] = ACTIONS(13298),
    [sym_grid_keyword] = ACTIONS(13298),
    [sym_part_keyword] = ACTIONS(13298),
    [sym_systempart_keyword] = ACTIONS(13298),
    [sym_usercontrol_keyword] = ACTIONS(13298),
    [sym_dataset_keyword] = ACTIONS(13298),
    [sym_elements_keyword] = ACTIONS(13298),
    [sym_labels_keyword] = ACTIONS(13298),
    [sym_rendering_keyword] = ACTIONS(13298),
    [sym_requestpage_keyword] = ACTIONS(13298),
    [sym_schema_keyword] = ACTIONS(13298),
    [sym_views_keyword] = ACTIONS(13298),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13298),
    [sym_preproc_open] = ACTIONS(13298),
    [sym_preproc_close] = ACTIONS(13298),
  },
  [STATE(5358)] = {
    [sym_boolean] = STATE(12461),
    [sym_option_member] = STATE(12443),
    [sym_keyword_identifier] = STATE(12461),
    [sym_codeunit_keyword] = STATE(12463),
    [sym_xmlport_keyword] = STATE(12463),
    [sym_enum_keyword] = STATE(12463),
    [sym_keyword_as_identifier] = STATE(12461),
    [aux_sym_option_member_list_repeat2] = STATE(6500),
    [sym_identifier] = ACTIONS(13232),
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(13302),
    [anon_sym_DASH] = ACTIONS(13236),
    [aux_sym_boolean_token1] = ACTIONS(13238),
    [aux_sym_boolean_token2] = ACTIONS(13238),
    [aux_sym_where_condition_token1] = ACTIONS(13240),
    [aux_sym_tabledata_permission_token2] = ACTIONS(13242),
    [aux_sym_record_type_token1] = ACTIONS(13242),
    [aux_sym_basic_type_token21] = ACTIONS(13242),
    [aux_sym_basic_type_token22] = ACTIONS(13244),
    [aux_sym_basic_type_token48] = ACTIONS(13242),
    [aux_sym_basic_type_token53] = ACTIONS(13240),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13240),
    [aux_sym_separator_action_token1] = ACTIONS(13240),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13240),
    [aux_sym_type_declaration_token1] = ACTIONS(13240),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(602),
    [anon_sym_POUNDif] = ACTIONS(600),
    [anon_sym_POUNDIF] = ACTIONS(600),
    [anon_sym_POUNDIf] = ACTIONS(600),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(13242),
    [aux_sym_keyword_identifier_token2] = ACTIONS(13242),
    [sym_table_keyword] = ACTIONS(13240),
    [sym_page_keyword] = ACTIONS(13242),
    [anon_sym_codeunit] = ACTIONS(13246),
    [anon_sym_CODEUNIT] = ACTIONS(13246),
    [anon_sym_Codeunit] = ACTIONS(13246),
    [anon_sym_CodeUnit] = ACTIONS(13246),
    [anon_sym_COdeunit] = ACTIONS(13246),
    [anon_sym_codeUnit] = ACTIONS(13246),
    [sym_report_keyword] = ACTIONS(13242),
    [sym_query_keyword] = ACTIONS(13242),
    [anon_sym_xmlport] = ACTIONS(13248),
    [anon_sym_XMLPORT] = ACTIONS(13248),
    [anon_sym_Xmlport] = ACTIONS(13248),
    [anon_sym_XMLport] = ACTIONS(13248),
    [anon_sym_XMLPort] = ACTIONS(13248),
    [anon_sym_XmlPort] = ACTIONS(13248),
    [anon_sym_enum] = ACTIONS(13250),
    [anon_sym_ENUM] = ACTIONS(13250),
    [anon_sym_Enum] = ACTIONS(13250),
    [anon_sym_eNUM] = ACTIONS(13250),
    [anon_sym_eNum] = ACTIONS(13250),
    [anon_sym_ENum] = ACTIONS(13250),
    [sym_var_keyword] = ACTIONS(602),
    [sym_local_keyword] = ACTIONS(13232),
    [sym_internal_keyword] = ACTIONS(13232),
    [sym_protected_keyword] = ACTIONS(13232),
    [sym_key_keyword] = ACTIONS(13240),
    [sym_dataset_keyword] = ACTIONS(13240),
    [sym_quoted_identifier] = ACTIONS(13252),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(13252),
    [sym_integer] = ACTIONS(13252),
    [sym_preproc_open] = ACTIONS(600),
    [sym_begin_keyword] = ACTIONS(600),
  },
  [STATE(5359)] = {
    [anon_sym_SEMI] = ACTIONS(13304),
    [aux_sym_where_condition_token1] = ACTIONS(13306),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13304),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13304),
    [anon_sym_LBRACK] = ACTIONS(13304),
    [aux_sym_basic_type_token6] = ACTIONS(13306),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13304),
    [aux_sym_addafter_modification_token1] = ACTIONS(13304),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13304),
    [aux_sym_modify_modification_token1] = ACTIONS(13304),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13304),
    [aux_sym_movelast_modification_token1] = ACTIONS(13304),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13304),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13304),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13304),
    [anon_sym_POUNDif] = ACTIONS(13304),
    [anon_sym_POUNDIF] = ACTIONS(13304),
    [anon_sym_POUNDIf] = ACTIONS(13304),
    [anon_sym_POUNDelif] = ACTIONS(13304),
    [anon_sym_POUNDELIF] = ACTIONS(13304),
    [anon_sym_POUNDElif] = ACTIONS(13304),
    [anon_sym_POUNDelse] = ACTIONS(13304),
    [anon_sym_POUNDELSE] = ACTIONS(13304),
    [anon_sym_POUNDElse] = ACTIONS(13304),
    [anon_sym_POUNDelse2] = ACTIONS(13304),
    [anon_sym_POUNDELSE2] = ACTIONS(13304),
    [anon_sym_POUNDElse2] = ACTIONS(13304),
    [anon_sym_POUNDendif] = ACTIONS(13304),
    [anon_sym_POUNDENDIF] = ACTIONS(13304),
    [anon_sym_POUNDEndif] = ACTIONS(13304),
    [anon_sym_POUNDendif2] = ACTIONS(13304),
    [anon_sym_POUNDENDIF2] = ACTIONS(13304),
    [anon_sym_POUNDEndif2] = ACTIONS(13304),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13304),
    [sym_trigger_keyword] = ACTIONS(13304),
    [sym_var_keyword] = ACTIONS(13304),
    [sym_local_keyword] = ACTIONS(13304),
    [sym_internal_keyword] = ACTIONS(13304),
    [sym_protected_keyword] = ACTIONS(13304),
    [sym_event_keyword] = ACTIONS(13304),
    [sym_fields_keyword] = ACTIONS(13304),
    [sym_keys_keyword] = ACTIONS(13304),
    [sym_fieldgroups_keyword] = ACTIONS(13304),
    [sym_actions_keyword] = ACTIONS(13304),
    [sym_layout_keyword] = ACTIONS(13304),
    [sym_area_keyword] = ACTIONS(13304),
    [sym_group_keyword] = ACTIONS(13304),
    [sym_repeater_keyword] = ACTIONS(13304),
    [sym_cuegroup_keyword] = ACTIONS(13304),
    [sym_fixed_keyword] = ACTIONS(13304),
    [sym_grid_keyword] = ACTIONS(13304),
    [sym_part_keyword] = ACTIONS(13304),
    [sym_systempart_keyword] = ACTIONS(13304),
    [sym_usercontrol_keyword] = ACTIONS(13304),
    [sym_dataset_keyword] = ACTIONS(13304),
    [sym_elements_keyword] = ACTIONS(13304),
    [sym_labels_keyword] = ACTIONS(13304),
    [sym_rendering_keyword] = ACTIONS(13304),
    [sym_requestpage_keyword] = ACTIONS(13304),
    [sym_schema_keyword] = ACTIONS(13304),
    [sym_views_keyword] = ACTIONS(13304),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13304),
    [sym_preproc_open] = ACTIONS(13304),
    [sym_preproc_close] = ACTIONS(13304),
  },
  [STATE(5360)] = {
    [anon_sym_SEMI] = ACTIONS(13308),
    [aux_sym_where_condition_token1] = ACTIONS(13310),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13308),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13308),
    [anon_sym_LBRACK] = ACTIONS(13308),
    [aux_sym_basic_type_token6] = ACTIONS(13310),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13308),
    [aux_sym_addafter_modification_token1] = ACTIONS(13308),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13308),
    [aux_sym_modify_modification_token1] = ACTIONS(13308),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13308),
    [aux_sym_movelast_modification_token1] = ACTIONS(13308),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13308),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13308),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13308),
    [anon_sym_POUNDif] = ACTIONS(13308),
    [anon_sym_POUNDIF] = ACTIONS(13308),
    [anon_sym_POUNDIf] = ACTIONS(13308),
    [anon_sym_POUNDelif] = ACTIONS(13308),
    [anon_sym_POUNDELIF] = ACTIONS(13308),
    [anon_sym_POUNDElif] = ACTIONS(13308),
    [anon_sym_POUNDelse] = ACTIONS(13308),
    [anon_sym_POUNDELSE] = ACTIONS(13308),
    [anon_sym_POUNDElse] = ACTIONS(13308),
    [anon_sym_POUNDelse2] = ACTIONS(13308),
    [anon_sym_POUNDELSE2] = ACTIONS(13308),
    [anon_sym_POUNDElse2] = ACTIONS(13308),
    [anon_sym_POUNDendif] = ACTIONS(13308),
    [anon_sym_POUNDENDIF] = ACTIONS(13308),
    [anon_sym_POUNDEndif] = ACTIONS(13308),
    [anon_sym_POUNDendif2] = ACTIONS(13308),
    [anon_sym_POUNDENDIF2] = ACTIONS(13308),
    [anon_sym_POUNDEndif2] = ACTIONS(13308),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13308),
    [sym_trigger_keyword] = ACTIONS(13308),
    [sym_var_keyword] = ACTIONS(13308),
    [sym_local_keyword] = ACTIONS(13308),
    [sym_internal_keyword] = ACTIONS(13308),
    [sym_protected_keyword] = ACTIONS(13308),
    [sym_event_keyword] = ACTIONS(13308),
    [sym_fields_keyword] = ACTIONS(13308),
    [sym_keys_keyword] = ACTIONS(13308),
    [sym_fieldgroups_keyword] = ACTIONS(13308),
    [sym_actions_keyword] = ACTIONS(13308),
    [sym_layout_keyword] = ACTIONS(13308),
    [sym_area_keyword] = ACTIONS(13308),
    [sym_group_keyword] = ACTIONS(13308),
    [sym_repeater_keyword] = ACTIONS(13308),
    [sym_cuegroup_keyword] = ACTIONS(13308),
    [sym_fixed_keyword] = ACTIONS(13308),
    [sym_grid_keyword] = ACTIONS(13308),
    [sym_part_keyword] = ACTIONS(13308),
    [sym_systempart_keyword] = ACTIONS(13308),
    [sym_usercontrol_keyword] = ACTIONS(13308),
    [sym_dataset_keyword] = ACTIONS(13308),
    [sym_elements_keyword] = ACTIONS(13308),
    [sym_labels_keyword] = ACTIONS(13308),
    [sym_rendering_keyword] = ACTIONS(13308),
    [sym_requestpage_keyword] = ACTIONS(13308),
    [sym_schema_keyword] = ACTIONS(13308),
    [sym_views_keyword] = ACTIONS(13308),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13308),
    [sym_preproc_open] = ACTIONS(13308),
    [sym_preproc_close] = ACTIONS(13308),
  },
  [STATE(5361)] = {
    [anon_sym_SEMI] = ACTIONS(13312),
    [aux_sym_where_condition_token1] = ACTIONS(13314),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13312),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13312),
    [anon_sym_LBRACK] = ACTIONS(13312),
    [aux_sym_basic_type_token6] = ACTIONS(13314),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13312),
    [aux_sym_addafter_modification_token1] = ACTIONS(13312),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13312),
    [aux_sym_modify_modification_token1] = ACTIONS(13312),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13312),
    [aux_sym_movelast_modification_token1] = ACTIONS(13312),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13312),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13312),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13312),
    [anon_sym_POUNDif] = ACTIONS(13312),
    [anon_sym_POUNDIF] = ACTIONS(13312),
    [anon_sym_POUNDIf] = ACTIONS(13312),
    [anon_sym_POUNDelif] = ACTIONS(13312),
    [anon_sym_POUNDELIF] = ACTIONS(13312),
    [anon_sym_POUNDElif] = ACTIONS(13312),
    [anon_sym_POUNDelse] = ACTIONS(13312),
    [anon_sym_POUNDELSE] = ACTIONS(13312),
    [anon_sym_POUNDElse] = ACTIONS(13312),
    [anon_sym_POUNDelse2] = ACTIONS(13312),
    [anon_sym_POUNDELSE2] = ACTIONS(13312),
    [anon_sym_POUNDElse2] = ACTIONS(13312),
    [anon_sym_POUNDendif] = ACTIONS(13312),
    [anon_sym_POUNDENDIF] = ACTIONS(13312),
    [anon_sym_POUNDEndif] = ACTIONS(13312),
    [anon_sym_POUNDendif2] = ACTIONS(13312),
    [anon_sym_POUNDENDIF2] = ACTIONS(13312),
    [anon_sym_POUNDEndif2] = ACTIONS(13312),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13312),
    [sym_trigger_keyword] = ACTIONS(13312),
    [sym_var_keyword] = ACTIONS(13312),
    [sym_local_keyword] = ACTIONS(13312),
    [sym_internal_keyword] = ACTIONS(13312),
    [sym_protected_keyword] = ACTIONS(13312),
    [sym_event_keyword] = ACTIONS(13312),
    [sym_fields_keyword] = ACTIONS(13312),
    [sym_keys_keyword] = ACTIONS(13312),
    [sym_fieldgroups_keyword] = ACTIONS(13312),
    [sym_actions_keyword] = ACTIONS(13312),
    [sym_layout_keyword] = ACTIONS(13312),
    [sym_area_keyword] = ACTIONS(13312),
    [sym_group_keyword] = ACTIONS(13312),
    [sym_repeater_keyword] = ACTIONS(13312),
    [sym_cuegroup_keyword] = ACTIONS(13312),
    [sym_fixed_keyword] = ACTIONS(13312),
    [sym_grid_keyword] = ACTIONS(13312),
    [sym_part_keyword] = ACTIONS(13312),
    [sym_systempart_keyword] = ACTIONS(13312),
    [sym_usercontrol_keyword] = ACTIONS(13312),
    [sym_dataset_keyword] = ACTIONS(13312),
    [sym_elements_keyword] = ACTIONS(13312),
    [sym_labels_keyword] = ACTIONS(13312),
    [sym_rendering_keyword] = ACTIONS(13312),
    [sym_requestpage_keyword] = ACTIONS(13312),
    [sym_schema_keyword] = ACTIONS(13312),
    [sym_views_keyword] = ACTIONS(13312),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13312),
    [sym_preproc_open] = ACTIONS(13312),
    [sym_preproc_close] = ACTIONS(13312),
  },
  [STATE(5362)] = {
    [anon_sym_SEMI] = ACTIONS(13316),
    [aux_sym_where_condition_token1] = ACTIONS(13318),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13316),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13316),
    [anon_sym_LBRACK] = ACTIONS(13316),
    [aux_sym_basic_type_token6] = ACTIONS(13318),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13316),
    [aux_sym_addafter_modification_token1] = ACTIONS(13316),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13316),
    [aux_sym_modify_modification_token1] = ACTIONS(13316),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13316),
    [aux_sym_movelast_modification_token1] = ACTIONS(13316),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13316),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13316),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13316),
    [anon_sym_POUNDif] = ACTIONS(13316),
    [anon_sym_POUNDIF] = ACTIONS(13316),
    [anon_sym_POUNDIf] = ACTIONS(13316),
    [anon_sym_POUNDelif] = ACTIONS(13316),
    [anon_sym_POUNDELIF] = ACTIONS(13316),
    [anon_sym_POUNDElif] = ACTIONS(13316),
    [anon_sym_POUNDelse] = ACTIONS(13316),
    [anon_sym_POUNDELSE] = ACTIONS(13316),
    [anon_sym_POUNDElse] = ACTIONS(13316),
    [anon_sym_POUNDelse2] = ACTIONS(13316),
    [anon_sym_POUNDELSE2] = ACTIONS(13316),
    [anon_sym_POUNDElse2] = ACTIONS(13316),
    [anon_sym_POUNDendif] = ACTIONS(13316),
    [anon_sym_POUNDENDIF] = ACTIONS(13316),
    [anon_sym_POUNDEndif] = ACTIONS(13316),
    [anon_sym_POUNDendif2] = ACTIONS(13316),
    [anon_sym_POUNDENDIF2] = ACTIONS(13316),
    [anon_sym_POUNDEndif2] = ACTIONS(13316),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13316),
    [sym_trigger_keyword] = ACTIONS(13316),
    [sym_var_keyword] = ACTIONS(13316),
    [sym_local_keyword] = ACTIONS(13316),
    [sym_internal_keyword] = ACTIONS(13316),
    [sym_protected_keyword] = ACTIONS(13316),
    [sym_event_keyword] = ACTIONS(13316),
    [sym_fields_keyword] = ACTIONS(13316),
    [sym_keys_keyword] = ACTIONS(13316),
    [sym_fieldgroups_keyword] = ACTIONS(13316),
    [sym_actions_keyword] = ACTIONS(13316),
    [sym_layout_keyword] = ACTIONS(13316),
    [sym_area_keyword] = ACTIONS(13316),
    [sym_group_keyword] = ACTIONS(13316),
    [sym_repeater_keyword] = ACTIONS(13316),
    [sym_cuegroup_keyword] = ACTIONS(13316),
    [sym_fixed_keyword] = ACTIONS(13316),
    [sym_grid_keyword] = ACTIONS(13316),
    [sym_part_keyword] = ACTIONS(13316),
    [sym_systempart_keyword] = ACTIONS(13316),
    [sym_usercontrol_keyword] = ACTIONS(13316),
    [sym_dataset_keyword] = ACTIONS(13316),
    [sym_elements_keyword] = ACTIONS(13316),
    [sym_labels_keyword] = ACTIONS(13316),
    [sym_rendering_keyword] = ACTIONS(13316),
    [sym_requestpage_keyword] = ACTIONS(13316),
    [sym_schema_keyword] = ACTIONS(13316),
    [sym_views_keyword] = ACTIONS(13316),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13316),
    [sym_preproc_open] = ACTIONS(13316),
    [sym_preproc_close] = ACTIONS(13316),
  },
  [STATE(5363)] = {
    [anon_sym_SEMI] = ACTIONS(13320),
    [aux_sym_where_condition_token1] = ACTIONS(13322),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13320),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13320),
    [anon_sym_LBRACK] = ACTIONS(13320),
    [aux_sym_basic_type_token6] = ACTIONS(13322),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13320),
    [aux_sym_addafter_modification_token1] = ACTIONS(13320),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13320),
    [aux_sym_modify_modification_token1] = ACTIONS(13320),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13320),
    [aux_sym_movelast_modification_token1] = ACTIONS(13320),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13320),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13320),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13320),
    [anon_sym_POUNDif] = ACTIONS(13320),
    [anon_sym_POUNDIF] = ACTIONS(13320),
    [anon_sym_POUNDIf] = ACTIONS(13320),
    [anon_sym_POUNDelif] = ACTIONS(13320),
    [anon_sym_POUNDELIF] = ACTIONS(13320),
    [anon_sym_POUNDElif] = ACTIONS(13320),
    [anon_sym_POUNDelse] = ACTIONS(13320),
    [anon_sym_POUNDELSE] = ACTIONS(13320),
    [anon_sym_POUNDElse] = ACTIONS(13320),
    [anon_sym_POUNDelse2] = ACTIONS(13320),
    [anon_sym_POUNDELSE2] = ACTIONS(13320),
    [anon_sym_POUNDElse2] = ACTIONS(13320),
    [anon_sym_POUNDendif] = ACTIONS(13320),
    [anon_sym_POUNDENDIF] = ACTIONS(13320),
    [anon_sym_POUNDEndif] = ACTIONS(13320),
    [anon_sym_POUNDendif2] = ACTIONS(13320),
    [anon_sym_POUNDENDIF2] = ACTIONS(13320),
    [anon_sym_POUNDEndif2] = ACTIONS(13320),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13320),
    [sym_trigger_keyword] = ACTIONS(13320),
    [sym_var_keyword] = ACTIONS(13320),
    [sym_local_keyword] = ACTIONS(13320),
    [sym_internal_keyword] = ACTIONS(13320),
    [sym_protected_keyword] = ACTIONS(13320),
    [sym_event_keyword] = ACTIONS(13320),
    [sym_fields_keyword] = ACTIONS(13320),
    [sym_keys_keyword] = ACTIONS(13320),
    [sym_fieldgroups_keyword] = ACTIONS(13320),
    [sym_actions_keyword] = ACTIONS(13320),
    [sym_layout_keyword] = ACTIONS(13320),
    [sym_area_keyword] = ACTIONS(13320),
    [sym_group_keyword] = ACTIONS(13320),
    [sym_repeater_keyword] = ACTIONS(13320),
    [sym_cuegroup_keyword] = ACTIONS(13320),
    [sym_fixed_keyword] = ACTIONS(13320),
    [sym_grid_keyword] = ACTIONS(13320),
    [sym_part_keyword] = ACTIONS(13320),
    [sym_systempart_keyword] = ACTIONS(13320),
    [sym_usercontrol_keyword] = ACTIONS(13320),
    [sym_dataset_keyword] = ACTIONS(13320),
    [sym_elements_keyword] = ACTIONS(13320),
    [sym_labels_keyword] = ACTIONS(13320),
    [sym_rendering_keyword] = ACTIONS(13320),
    [sym_requestpage_keyword] = ACTIONS(13320),
    [sym_schema_keyword] = ACTIONS(13320),
    [sym_views_keyword] = ACTIONS(13320),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13320),
    [sym_preproc_open] = ACTIONS(13320),
    [sym_preproc_close] = ACTIONS(13320),
  },
  [STATE(5364)] = {
    [anon_sym_SEMI] = ACTIONS(13324),
    [aux_sym_where_condition_token1] = ACTIONS(13326),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13324),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13324),
    [anon_sym_LBRACK] = ACTIONS(13324),
    [aux_sym_basic_type_token6] = ACTIONS(13326),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13324),
    [aux_sym_addafter_modification_token1] = ACTIONS(13324),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13324),
    [aux_sym_modify_modification_token1] = ACTIONS(13324),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13324),
    [aux_sym_movelast_modification_token1] = ACTIONS(13324),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13324),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13324),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13324),
    [anon_sym_POUNDif] = ACTIONS(13324),
    [anon_sym_POUNDIF] = ACTIONS(13324),
    [anon_sym_POUNDIf] = ACTIONS(13324),
    [anon_sym_POUNDelif] = ACTIONS(13324),
    [anon_sym_POUNDELIF] = ACTIONS(13324),
    [anon_sym_POUNDElif] = ACTIONS(13324),
    [anon_sym_POUNDelse] = ACTIONS(13324),
    [anon_sym_POUNDELSE] = ACTIONS(13324),
    [anon_sym_POUNDElse] = ACTIONS(13324),
    [anon_sym_POUNDelse2] = ACTIONS(13324),
    [anon_sym_POUNDELSE2] = ACTIONS(13324),
    [anon_sym_POUNDElse2] = ACTIONS(13324),
    [anon_sym_POUNDendif] = ACTIONS(13324),
    [anon_sym_POUNDENDIF] = ACTIONS(13324),
    [anon_sym_POUNDEndif] = ACTIONS(13324),
    [anon_sym_POUNDendif2] = ACTIONS(13324),
    [anon_sym_POUNDENDIF2] = ACTIONS(13324),
    [anon_sym_POUNDEndif2] = ACTIONS(13324),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13324),
    [sym_trigger_keyword] = ACTIONS(13324),
    [sym_var_keyword] = ACTIONS(13324),
    [sym_local_keyword] = ACTIONS(13324),
    [sym_internal_keyword] = ACTIONS(13324),
    [sym_protected_keyword] = ACTIONS(13324),
    [sym_event_keyword] = ACTIONS(13324),
    [sym_fields_keyword] = ACTIONS(13324),
    [sym_keys_keyword] = ACTIONS(13324),
    [sym_fieldgroups_keyword] = ACTIONS(13324),
    [sym_actions_keyword] = ACTIONS(13324),
    [sym_layout_keyword] = ACTIONS(13324),
    [sym_area_keyword] = ACTIONS(13324),
    [sym_group_keyword] = ACTIONS(13324),
    [sym_repeater_keyword] = ACTIONS(13324),
    [sym_cuegroup_keyword] = ACTIONS(13324),
    [sym_fixed_keyword] = ACTIONS(13324),
    [sym_grid_keyword] = ACTIONS(13324),
    [sym_part_keyword] = ACTIONS(13324),
    [sym_systempart_keyword] = ACTIONS(13324),
    [sym_usercontrol_keyword] = ACTIONS(13324),
    [sym_dataset_keyword] = ACTIONS(13324),
    [sym_elements_keyword] = ACTIONS(13324),
    [sym_labels_keyword] = ACTIONS(13324),
    [sym_rendering_keyword] = ACTIONS(13324),
    [sym_requestpage_keyword] = ACTIONS(13324),
    [sym_schema_keyword] = ACTIONS(13324),
    [sym_views_keyword] = ACTIONS(13324),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13324),
    [sym_preproc_open] = ACTIONS(13324),
    [sym_preproc_close] = ACTIONS(13324),
  },
  [STATE(5365)] = {
    [anon_sym_SEMI] = ACTIONS(13328),
    [aux_sym_where_condition_token1] = ACTIONS(13330),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13328),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13328),
    [anon_sym_LBRACK] = ACTIONS(13328),
    [aux_sym_basic_type_token6] = ACTIONS(13330),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13328),
    [aux_sym_addafter_modification_token1] = ACTIONS(13328),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13328),
    [aux_sym_modify_modification_token1] = ACTIONS(13328),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13328),
    [aux_sym_movelast_modification_token1] = ACTIONS(13328),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13328),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13328),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13328),
    [anon_sym_POUNDif] = ACTIONS(13328),
    [anon_sym_POUNDIF] = ACTIONS(13328),
    [anon_sym_POUNDIf] = ACTIONS(13328),
    [anon_sym_POUNDelif] = ACTIONS(13328),
    [anon_sym_POUNDELIF] = ACTIONS(13328),
    [anon_sym_POUNDElif] = ACTIONS(13328),
    [anon_sym_POUNDelse] = ACTIONS(13328),
    [anon_sym_POUNDELSE] = ACTIONS(13328),
    [anon_sym_POUNDElse] = ACTIONS(13328),
    [anon_sym_POUNDelse2] = ACTIONS(13328),
    [anon_sym_POUNDELSE2] = ACTIONS(13328),
    [anon_sym_POUNDElse2] = ACTIONS(13328),
    [anon_sym_POUNDendif] = ACTIONS(13328),
    [anon_sym_POUNDENDIF] = ACTIONS(13328),
    [anon_sym_POUNDEndif] = ACTIONS(13328),
    [anon_sym_POUNDendif2] = ACTIONS(13328),
    [anon_sym_POUNDENDIF2] = ACTIONS(13328),
    [anon_sym_POUNDEndif2] = ACTIONS(13328),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13328),
    [sym_trigger_keyword] = ACTIONS(13328),
    [sym_var_keyword] = ACTIONS(13328),
    [sym_local_keyword] = ACTIONS(13328),
    [sym_internal_keyword] = ACTIONS(13328),
    [sym_protected_keyword] = ACTIONS(13328),
    [sym_event_keyword] = ACTIONS(13328),
    [sym_fields_keyword] = ACTIONS(13328),
    [sym_keys_keyword] = ACTIONS(13328),
    [sym_fieldgroups_keyword] = ACTIONS(13328),
    [sym_actions_keyword] = ACTIONS(13328),
    [sym_layout_keyword] = ACTIONS(13328),
    [sym_area_keyword] = ACTIONS(13328),
    [sym_group_keyword] = ACTIONS(13328),
    [sym_repeater_keyword] = ACTIONS(13328),
    [sym_cuegroup_keyword] = ACTIONS(13328),
    [sym_fixed_keyword] = ACTIONS(13328),
    [sym_grid_keyword] = ACTIONS(13328),
    [sym_part_keyword] = ACTIONS(13328),
    [sym_systempart_keyword] = ACTIONS(13328),
    [sym_usercontrol_keyword] = ACTIONS(13328),
    [sym_dataset_keyword] = ACTIONS(13328),
    [sym_elements_keyword] = ACTIONS(13328),
    [sym_labels_keyword] = ACTIONS(13328),
    [sym_rendering_keyword] = ACTIONS(13328),
    [sym_requestpage_keyword] = ACTIONS(13328),
    [sym_schema_keyword] = ACTIONS(13328),
    [sym_views_keyword] = ACTIONS(13328),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13328),
    [sym_preproc_open] = ACTIONS(13328),
    [sym_preproc_close] = ACTIONS(13328),
  },
  [STATE(5366)] = {
    [anon_sym_SEMI] = ACTIONS(13332),
    [aux_sym_where_condition_token1] = ACTIONS(13334),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13332),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13332),
    [anon_sym_LBRACK] = ACTIONS(13332),
    [aux_sym_basic_type_token6] = ACTIONS(13334),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13332),
    [aux_sym_addafter_modification_token1] = ACTIONS(13332),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13332),
    [aux_sym_modify_modification_token1] = ACTIONS(13332),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13332),
    [aux_sym_movelast_modification_token1] = ACTIONS(13332),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13332),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13332),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13332),
    [anon_sym_POUNDif] = ACTIONS(13332),
    [anon_sym_POUNDIF] = ACTIONS(13332),
    [anon_sym_POUNDIf] = ACTIONS(13332),
    [anon_sym_POUNDelif] = ACTIONS(13332),
    [anon_sym_POUNDELIF] = ACTIONS(13332),
    [anon_sym_POUNDElif] = ACTIONS(13332),
    [anon_sym_POUNDelse] = ACTIONS(13332),
    [anon_sym_POUNDELSE] = ACTIONS(13332),
    [anon_sym_POUNDElse] = ACTIONS(13332),
    [anon_sym_POUNDelse2] = ACTIONS(13332),
    [anon_sym_POUNDELSE2] = ACTIONS(13332),
    [anon_sym_POUNDElse2] = ACTIONS(13332),
    [anon_sym_POUNDendif] = ACTIONS(13332),
    [anon_sym_POUNDENDIF] = ACTIONS(13332),
    [anon_sym_POUNDEndif] = ACTIONS(13332),
    [anon_sym_POUNDendif2] = ACTIONS(13332),
    [anon_sym_POUNDENDIF2] = ACTIONS(13332),
    [anon_sym_POUNDEndif2] = ACTIONS(13332),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13332),
    [sym_trigger_keyword] = ACTIONS(13332),
    [sym_var_keyword] = ACTIONS(13332),
    [sym_local_keyword] = ACTIONS(13332),
    [sym_internal_keyword] = ACTIONS(13332),
    [sym_protected_keyword] = ACTIONS(13332),
    [sym_event_keyword] = ACTIONS(13332),
    [sym_fields_keyword] = ACTIONS(13332),
    [sym_keys_keyword] = ACTIONS(13332),
    [sym_fieldgroups_keyword] = ACTIONS(13332),
    [sym_actions_keyword] = ACTIONS(13332),
    [sym_layout_keyword] = ACTIONS(13332),
    [sym_area_keyword] = ACTIONS(13332),
    [sym_group_keyword] = ACTIONS(13332),
    [sym_repeater_keyword] = ACTIONS(13332),
    [sym_cuegroup_keyword] = ACTIONS(13332),
    [sym_fixed_keyword] = ACTIONS(13332),
    [sym_grid_keyword] = ACTIONS(13332),
    [sym_part_keyword] = ACTIONS(13332),
    [sym_systempart_keyword] = ACTIONS(13332),
    [sym_usercontrol_keyword] = ACTIONS(13332),
    [sym_dataset_keyword] = ACTIONS(13332),
    [sym_elements_keyword] = ACTIONS(13332),
    [sym_labels_keyword] = ACTIONS(13332),
    [sym_rendering_keyword] = ACTIONS(13332),
    [sym_requestpage_keyword] = ACTIONS(13332),
    [sym_schema_keyword] = ACTIONS(13332),
    [sym_views_keyword] = ACTIONS(13332),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13332),
    [sym_preproc_open] = ACTIONS(13332),
    [sym_preproc_close] = ACTIONS(13332),
  },
  [STATE(5367)] = {
    [anon_sym_SEMI] = ACTIONS(13336),
    [aux_sym_where_condition_token1] = ACTIONS(13338),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13336),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13336),
    [anon_sym_LBRACK] = ACTIONS(13336),
    [aux_sym_basic_type_token6] = ACTIONS(13338),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13336),
    [aux_sym_addafter_modification_token1] = ACTIONS(13336),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13336),
    [aux_sym_modify_modification_token1] = ACTIONS(13336),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13336),
    [aux_sym_movelast_modification_token1] = ACTIONS(13336),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13336),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13336),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13336),
    [anon_sym_POUNDif] = ACTIONS(13336),
    [anon_sym_POUNDIF] = ACTIONS(13336),
    [anon_sym_POUNDIf] = ACTIONS(13336),
    [anon_sym_POUNDelif] = ACTIONS(13336),
    [anon_sym_POUNDELIF] = ACTIONS(13336),
    [anon_sym_POUNDElif] = ACTIONS(13336),
    [anon_sym_POUNDelse] = ACTIONS(13336),
    [anon_sym_POUNDELSE] = ACTIONS(13336),
    [anon_sym_POUNDElse] = ACTIONS(13336),
    [anon_sym_POUNDelse2] = ACTIONS(13336),
    [anon_sym_POUNDELSE2] = ACTIONS(13336),
    [anon_sym_POUNDElse2] = ACTIONS(13336),
    [anon_sym_POUNDendif] = ACTIONS(13336),
    [anon_sym_POUNDENDIF] = ACTIONS(13336),
    [anon_sym_POUNDEndif] = ACTIONS(13336),
    [anon_sym_POUNDendif2] = ACTIONS(13336),
    [anon_sym_POUNDENDIF2] = ACTIONS(13336),
    [anon_sym_POUNDEndif2] = ACTIONS(13336),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13336),
    [sym_trigger_keyword] = ACTIONS(13336),
    [sym_var_keyword] = ACTIONS(13336),
    [sym_local_keyword] = ACTIONS(13336),
    [sym_internal_keyword] = ACTIONS(13336),
    [sym_protected_keyword] = ACTIONS(13336),
    [sym_event_keyword] = ACTIONS(13336),
    [sym_fields_keyword] = ACTIONS(13336),
    [sym_keys_keyword] = ACTIONS(13336),
    [sym_fieldgroups_keyword] = ACTIONS(13336),
    [sym_actions_keyword] = ACTIONS(13336),
    [sym_layout_keyword] = ACTIONS(13336),
    [sym_area_keyword] = ACTIONS(13336),
    [sym_group_keyword] = ACTIONS(13336),
    [sym_repeater_keyword] = ACTIONS(13336),
    [sym_cuegroup_keyword] = ACTIONS(13336),
    [sym_fixed_keyword] = ACTIONS(13336),
    [sym_grid_keyword] = ACTIONS(13336),
    [sym_part_keyword] = ACTIONS(13336),
    [sym_systempart_keyword] = ACTIONS(13336),
    [sym_usercontrol_keyword] = ACTIONS(13336),
    [sym_dataset_keyword] = ACTIONS(13336),
    [sym_elements_keyword] = ACTIONS(13336),
    [sym_labels_keyword] = ACTIONS(13336),
    [sym_rendering_keyword] = ACTIONS(13336),
    [sym_requestpage_keyword] = ACTIONS(13336),
    [sym_schema_keyword] = ACTIONS(13336),
    [sym_views_keyword] = ACTIONS(13336),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13336),
    [sym_preproc_open] = ACTIONS(13336),
    [sym_preproc_close] = ACTIONS(13336),
  },
  [STATE(5368)] = {
    [anon_sym_SEMI] = ACTIONS(13340),
    [aux_sym_where_condition_token1] = ACTIONS(13342),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13340),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13340),
    [anon_sym_LBRACK] = ACTIONS(13340),
    [aux_sym_basic_type_token6] = ACTIONS(13342),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13340),
    [aux_sym_addafter_modification_token1] = ACTIONS(13340),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13340),
    [aux_sym_modify_modification_token1] = ACTIONS(13340),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13340),
    [aux_sym_movelast_modification_token1] = ACTIONS(13340),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13340),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13340),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13340),
    [anon_sym_POUNDif] = ACTIONS(13340),
    [anon_sym_POUNDIF] = ACTIONS(13340),
    [anon_sym_POUNDIf] = ACTIONS(13340),
    [anon_sym_POUNDelif] = ACTIONS(13340),
    [anon_sym_POUNDELIF] = ACTIONS(13340),
    [anon_sym_POUNDElif] = ACTIONS(13340),
    [anon_sym_POUNDelse] = ACTIONS(13340),
    [anon_sym_POUNDELSE] = ACTIONS(13340),
    [anon_sym_POUNDElse] = ACTIONS(13340),
    [anon_sym_POUNDelse2] = ACTIONS(13340),
    [anon_sym_POUNDELSE2] = ACTIONS(13340),
    [anon_sym_POUNDElse2] = ACTIONS(13340),
    [anon_sym_POUNDendif] = ACTIONS(13340),
    [anon_sym_POUNDENDIF] = ACTIONS(13340),
    [anon_sym_POUNDEndif] = ACTIONS(13340),
    [anon_sym_POUNDendif2] = ACTIONS(13340),
    [anon_sym_POUNDENDIF2] = ACTIONS(13340),
    [anon_sym_POUNDEndif2] = ACTIONS(13340),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13340),
    [sym_trigger_keyword] = ACTIONS(13340),
    [sym_var_keyword] = ACTIONS(13340),
    [sym_local_keyword] = ACTIONS(13340),
    [sym_internal_keyword] = ACTIONS(13340),
    [sym_protected_keyword] = ACTIONS(13340),
    [sym_event_keyword] = ACTIONS(13340),
    [sym_fields_keyword] = ACTIONS(13340),
    [sym_keys_keyword] = ACTIONS(13340),
    [sym_fieldgroups_keyword] = ACTIONS(13340),
    [sym_actions_keyword] = ACTIONS(13340),
    [sym_layout_keyword] = ACTIONS(13340),
    [sym_area_keyword] = ACTIONS(13340),
    [sym_group_keyword] = ACTIONS(13340),
    [sym_repeater_keyword] = ACTIONS(13340),
    [sym_cuegroup_keyword] = ACTIONS(13340),
    [sym_fixed_keyword] = ACTIONS(13340),
    [sym_grid_keyword] = ACTIONS(13340),
    [sym_part_keyword] = ACTIONS(13340),
    [sym_systempart_keyword] = ACTIONS(13340),
    [sym_usercontrol_keyword] = ACTIONS(13340),
    [sym_dataset_keyword] = ACTIONS(13340),
    [sym_elements_keyword] = ACTIONS(13340),
    [sym_labels_keyword] = ACTIONS(13340),
    [sym_rendering_keyword] = ACTIONS(13340),
    [sym_requestpage_keyword] = ACTIONS(13340),
    [sym_schema_keyword] = ACTIONS(13340),
    [sym_views_keyword] = ACTIONS(13340),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13340),
    [sym_preproc_open] = ACTIONS(13340),
    [sym_preproc_close] = ACTIONS(13340),
  },
  [STATE(5369)] = {
    [anon_sym_SEMI] = ACTIONS(13344),
    [aux_sym_where_condition_token1] = ACTIONS(13346),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13344),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13344),
    [anon_sym_LBRACK] = ACTIONS(13344),
    [aux_sym_basic_type_token6] = ACTIONS(13346),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13344),
    [aux_sym_addafter_modification_token1] = ACTIONS(13344),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13344),
    [aux_sym_modify_modification_token1] = ACTIONS(13344),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13344),
    [aux_sym_movelast_modification_token1] = ACTIONS(13344),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13344),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13344),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13344),
    [anon_sym_POUNDif] = ACTIONS(13344),
    [anon_sym_POUNDIF] = ACTIONS(13344),
    [anon_sym_POUNDIf] = ACTIONS(13344),
    [anon_sym_POUNDelif] = ACTIONS(13344),
    [anon_sym_POUNDELIF] = ACTIONS(13344),
    [anon_sym_POUNDElif] = ACTIONS(13344),
    [anon_sym_POUNDelse] = ACTIONS(13344),
    [anon_sym_POUNDELSE] = ACTIONS(13344),
    [anon_sym_POUNDElse] = ACTIONS(13344),
    [anon_sym_POUNDelse2] = ACTIONS(13344),
    [anon_sym_POUNDELSE2] = ACTIONS(13344),
    [anon_sym_POUNDElse2] = ACTIONS(13344),
    [anon_sym_POUNDendif] = ACTIONS(13344),
    [anon_sym_POUNDENDIF] = ACTIONS(13344),
    [anon_sym_POUNDEndif] = ACTIONS(13344),
    [anon_sym_POUNDendif2] = ACTIONS(13344),
    [anon_sym_POUNDENDIF2] = ACTIONS(13344),
    [anon_sym_POUNDEndif2] = ACTIONS(13344),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13344),
    [sym_trigger_keyword] = ACTIONS(13344),
    [sym_var_keyword] = ACTIONS(13344),
    [sym_local_keyword] = ACTIONS(13344),
    [sym_internal_keyword] = ACTIONS(13344),
    [sym_protected_keyword] = ACTIONS(13344),
    [sym_event_keyword] = ACTIONS(13344),
    [sym_fields_keyword] = ACTIONS(13344),
    [sym_keys_keyword] = ACTIONS(13344),
    [sym_fieldgroups_keyword] = ACTIONS(13344),
    [sym_actions_keyword] = ACTIONS(13344),
    [sym_layout_keyword] = ACTIONS(13344),
    [sym_area_keyword] = ACTIONS(13344),
    [sym_group_keyword] = ACTIONS(13344),
    [sym_repeater_keyword] = ACTIONS(13344),
    [sym_cuegroup_keyword] = ACTIONS(13344),
    [sym_fixed_keyword] = ACTIONS(13344),
    [sym_grid_keyword] = ACTIONS(13344),
    [sym_part_keyword] = ACTIONS(13344),
    [sym_systempart_keyword] = ACTIONS(13344),
    [sym_usercontrol_keyword] = ACTIONS(13344),
    [sym_dataset_keyword] = ACTIONS(13344),
    [sym_elements_keyword] = ACTIONS(13344),
    [sym_labels_keyword] = ACTIONS(13344),
    [sym_rendering_keyword] = ACTIONS(13344),
    [sym_requestpage_keyword] = ACTIONS(13344),
    [sym_schema_keyword] = ACTIONS(13344),
    [sym_views_keyword] = ACTIONS(13344),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13344),
    [sym_preproc_open] = ACTIONS(13344),
    [sym_preproc_close] = ACTIONS(13344),
  },
  [STATE(5370)] = {
    [anon_sym_SEMI] = ACTIONS(13348),
    [aux_sym_where_condition_token1] = ACTIONS(13350),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13348),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13348),
    [anon_sym_LBRACK] = ACTIONS(13348),
    [aux_sym_basic_type_token6] = ACTIONS(13350),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13348),
    [aux_sym_addafter_modification_token1] = ACTIONS(13348),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13348),
    [aux_sym_modify_modification_token1] = ACTIONS(13348),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13348),
    [aux_sym_movelast_modification_token1] = ACTIONS(13348),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13348),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13348),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13348),
    [anon_sym_POUNDif] = ACTIONS(13348),
    [anon_sym_POUNDIF] = ACTIONS(13348),
    [anon_sym_POUNDIf] = ACTIONS(13348),
    [anon_sym_POUNDelif] = ACTIONS(13348),
    [anon_sym_POUNDELIF] = ACTIONS(13348),
    [anon_sym_POUNDElif] = ACTIONS(13348),
    [anon_sym_POUNDelse] = ACTIONS(13348),
    [anon_sym_POUNDELSE] = ACTIONS(13348),
    [anon_sym_POUNDElse] = ACTIONS(13348),
    [anon_sym_POUNDelse2] = ACTIONS(13348),
    [anon_sym_POUNDELSE2] = ACTIONS(13348),
    [anon_sym_POUNDElse2] = ACTIONS(13348),
    [anon_sym_POUNDendif] = ACTIONS(13348),
    [anon_sym_POUNDENDIF] = ACTIONS(13348),
    [anon_sym_POUNDEndif] = ACTIONS(13348),
    [anon_sym_POUNDendif2] = ACTIONS(13348),
    [anon_sym_POUNDENDIF2] = ACTIONS(13348),
    [anon_sym_POUNDEndif2] = ACTIONS(13348),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13348),
    [sym_trigger_keyword] = ACTIONS(13348),
    [sym_var_keyword] = ACTIONS(13348),
    [sym_local_keyword] = ACTIONS(13348),
    [sym_internal_keyword] = ACTIONS(13348),
    [sym_protected_keyword] = ACTIONS(13348),
    [sym_event_keyword] = ACTIONS(13348),
    [sym_fields_keyword] = ACTIONS(13348),
    [sym_keys_keyword] = ACTIONS(13348),
    [sym_fieldgroups_keyword] = ACTIONS(13348),
    [sym_actions_keyword] = ACTIONS(13348),
    [sym_layout_keyword] = ACTIONS(13348),
    [sym_area_keyword] = ACTIONS(13348),
    [sym_group_keyword] = ACTIONS(13348),
    [sym_repeater_keyword] = ACTIONS(13348),
    [sym_cuegroup_keyword] = ACTIONS(13348),
    [sym_fixed_keyword] = ACTIONS(13348),
    [sym_grid_keyword] = ACTIONS(13348),
    [sym_part_keyword] = ACTIONS(13348),
    [sym_systempart_keyword] = ACTIONS(13348),
    [sym_usercontrol_keyword] = ACTIONS(13348),
    [sym_dataset_keyword] = ACTIONS(13348),
    [sym_elements_keyword] = ACTIONS(13348),
    [sym_labels_keyword] = ACTIONS(13348),
    [sym_rendering_keyword] = ACTIONS(13348),
    [sym_requestpage_keyword] = ACTIONS(13348),
    [sym_schema_keyword] = ACTIONS(13348),
    [sym_views_keyword] = ACTIONS(13348),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13348),
    [sym_preproc_open] = ACTIONS(13348),
    [sym_preproc_close] = ACTIONS(13348),
  },
  [STATE(5371)] = {
    [sym_identifier] = ACTIONS(13352),
    [anon_sym_DASH] = ACTIONS(12124),
    [aux_sym_boolean_token1] = ACTIONS(13352),
    [aux_sym_boolean_token2] = ACTIONS(13352),
    [sym_decimal] = ACTIONS(13352),
    [anon_sym_LPAREN] = ACTIONS(12124),
    [aux_sym_tabledata_permission_token2] = ACTIONS(13352),
    [anon_sym_LBRACK] = ACTIONS(12124),
    [aux_sym_record_type_token1] = ACTIONS(13352),
    [aux_sym_basic_type_token21] = ACTIONS(13352),
    [aux_sym_basic_type_token22] = ACTIONS(13352),
    [aux_sym_basic_type_token48] = ACTIONS(13352),
    [anon_sym_not] = ACTIONS(13352),
    [anon_sym_NOT] = ACTIONS(13352),
    [anon_sym_Not] = ACTIONS(13352),
    [anon_sym_POUNDelif] = ACTIONS(12124),
    [anon_sym_POUNDELIF] = ACTIONS(12124),
    [anon_sym_POUNDElif] = ACTIONS(12124),
    [anon_sym_POUNDelse] = ACTIONS(12124),
    [anon_sym_POUNDELSE] = ACTIONS(12124),
    [anon_sym_POUNDElse] = ACTIONS(12124),
    [anon_sym_POUNDelse2] = ACTIONS(12124),
    [anon_sym_POUNDELSE2] = ACTIONS(12124),
    [anon_sym_POUNDElse2] = ACTIONS(12124),
    [anon_sym_POUNDendif] = ACTIONS(12124),
    [anon_sym_POUNDENDIF] = ACTIONS(12124),
    [anon_sym_POUNDEndif] = ACTIONS(12124),
    [anon_sym_POUNDendif2] = ACTIONS(12124),
    [anon_sym_POUNDENDIF2] = ACTIONS(12124),
    [anon_sym_POUNDEndif2] = ACTIONS(12124),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(13352),
    [aux_sym_keyword_identifier_token2] = ACTIONS(13352),
    [anon_sym_PLUS] = ACTIONS(12124),
    [sym_datetime_literal] = ACTIONS(12124),
    [sym_date_literal] = ACTIONS(13352),
    [sym_time_literal] = ACTIONS(13352),
    [sym_biginteger_literal] = ACTIONS(12124),
    [sym_page_keyword] = ACTIONS(13352),
    [anon_sym_codeunit] = ACTIONS(13352),
    [anon_sym_CODEUNIT] = ACTIONS(13352),
    [anon_sym_Codeunit] = ACTIONS(13352),
    [anon_sym_CodeUnit] = ACTIONS(13352),
    [anon_sym_COdeunit] = ACTIONS(13352),
    [anon_sym_codeUnit] = ACTIONS(13352),
    [sym_report_keyword] = ACTIONS(13352),
    [sym_query_keyword] = ACTIONS(13352),
    [anon_sym_xmlport] = ACTIONS(13352),
    [anon_sym_XMLPORT] = ACTIONS(13352),
    [anon_sym_Xmlport] = ACTIONS(13352),
    [anon_sym_XMLport] = ACTIONS(13352),
    [anon_sym_XMLPort] = ACTIONS(13352),
    [anon_sym_XmlPort] = ACTIONS(13352),
    [anon_sym_enum] = ACTIONS(13352),
    [anon_sym_ENUM] = ACTIONS(13352),
    [anon_sym_Enum] = ACTIONS(13352),
    [anon_sym_eNUM] = ACTIONS(13352),
    [anon_sym_eNum] = ACTIONS(13352),
    [anon_sym_ENum] = ACTIONS(13352),
    [sym_quoted_identifier] = ACTIONS(12124),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(12124),
    [sym_verbatim_string] = ACTIONS(12124),
    [sym_integer] = ACTIONS(13352),
    [sym_continue_as_identifier] = ACTIONS(12124),
    [sym_preproc_close] = ACTIONS(12124),
  },
  [STATE(5372)] = {
    [anon_sym_SEMI] = ACTIONS(13354),
    [aux_sym_where_condition_token1] = ACTIONS(13356),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13354),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13354),
    [anon_sym_LBRACK] = ACTIONS(13354),
    [aux_sym_basic_type_token6] = ACTIONS(13356),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13354),
    [aux_sym_addafter_modification_token1] = ACTIONS(13354),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13354),
    [aux_sym_modify_modification_token1] = ACTIONS(13354),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13354),
    [aux_sym_movelast_modification_token1] = ACTIONS(13354),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13354),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13354),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13354),
    [anon_sym_POUNDif] = ACTIONS(13354),
    [anon_sym_POUNDIF] = ACTIONS(13354),
    [anon_sym_POUNDIf] = ACTIONS(13354),
    [anon_sym_POUNDelif] = ACTIONS(13354),
    [anon_sym_POUNDELIF] = ACTIONS(13354),
    [anon_sym_POUNDElif] = ACTIONS(13354),
    [anon_sym_POUNDelse] = ACTIONS(13354),
    [anon_sym_POUNDELSE] = ACTIONS(13354),
    [anon_sym_POUNDElse] = ACTIONS(13354),
    [anon_sym_POUNDelse2] = ACTIONS(13354),
    [anon_sym_POUNDELSE2] = ACTIONS(13354),
    [anon_sym_POUNDElse2] = ACTIONS(13354),
    [anon_sym_POUNDendif] = ACTIONS(13354),
    [anon_sym_POUNDENDIF] = ACTIONS(13354),
    [anon_sym_POUNDEndif] = ACTIONS(13354),
    [anon_sym_POUNDendif2] = ACTIONS(13354),
    [anon_sym_POUNDENDIF2] = ACTIONS(13354),
    [anon_sym_POUNDEndif2] = ACTIONS(13354),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13354),
    [sym_trigger_keyword] = ACTIONS(13354),
    [sym_var_keyword] = ACTIONS(13354),
    [sym_local_keyword] = ACTIONS(13354),
    [sym_internal_keyword] = ACTIONS(13354),
    [sym_protected_keyword] = ACTIONS(13354),
    [sym_event_keyword] = ACTIONS(13354),
    [sym_fields_keyword] = ACTIONS(13354),
    [sym_keys_keyword] = ACTIONS(13354),
    [sym_fieldgroups_keyword] = ACTIONS(13354),
    [sym_actions_keyword] = ACTIONS(13354),
    [sym_layout_keyword] = ACTIONS(13354),
    [sym_area_keyword] = ACTIONS(13354),
    [sym_group_keyword] = ACTIONS(13354),
    [sym_repeater_keyword] = ACTIONS(13354),
    [sym_cuegroup_keyword] = ACTIONS(13354),
    [sym_fixed_keyword] = ACTIONS(13354),
    [sym_grid_keyword] = ACTIONS(13354),
    [sym_part_keyword] = ACTIONS(13354),
    [sym_systempart_keyword] = ACTIONS(13354),
    [sym_usercontrol_keyword] = ACTIONS(13354),
    [sym_dataset_keyword] = ACTIONS(13354),
    [sym_elements_keyword] = ACTIONS(13354),
    [sym_labels_keyword] = ACTIONS(13354),
    [sym_rendering_keyword] = ACTIONS(13354),
    [sym_requestpage_keyword] = ACTIONS(13354),
    [sym_schema_keyword] = ACTIONS(13354),
    [sym_views_keyword] = ACTIONS(13354),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13354),
    [sym_preproc_open] = ACTIONS(13354),
    [sym_preproc_close] = ACTIONS(13354),
  },
  [STATE(5373)] = {
    [anon_sym_SEMI] = ACTIONS(13358),
    [aux_sym_where_condition_token1] = ACTIONS(13360),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13358),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13358),
    [anon_sym_LBRACK] = ACTIONS(13358),
    [aux_sym_basic_type_token6] = ACTIONS(13360),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13358),
    [aux_sym_addafter_modification_token1] = ACTIONS(13358),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13358),
    [aux_sym_modify_modification_token1] = ACTIONS(13358),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13358),
    [aux_sym_movelast_modification_token1] = ACTIONS(13358),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13358),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13358),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13358),
    [anon_sym_POUNDif] = ACTIONS(13358),
    [anon_sym_POUNDIF] = ACTIONS(13358),
    [anon_sym_POUNDIf] = ACTIONS(13358),
    [anon_sym_POUNDelif] = ACTIONS(13358),
    [anon_sym_POUNDELIF] = ACTIONS(13358),
    [anon_sym_POUNDElif] = ACTIONS(13358),
    [anon_sym_POUNDelse] = ACTIONS(13358),
    [anon_sym_POUNDELSE] = ACTIONS(13358),
    [anon_sym_POUNDElse] = ACTIONS(13358),
    [anon_sym_POUNDelse2] = ACTIONS(13358),
    [anon_sym_POUNDELSE2] = ACTIONS(13358),
    [anon_sym_POUNDElse2] = ACTIONS(13358),
    [anon_sym_POUNDendif] = ACTIONS(13358),
    [anon_sym_POUNDENDIF] = ACTIONS(13358),
    [anon_sym_POUNDEndif] = ACTIONS(13358),
    [anon_sym_POUNDendif2] = ACTIONS(13358),
    [anon_sym_POUNDENDIF2] = ACTIONS(13358),
    [anon_sym_POUNDEndif2] = ACTIONS(13358),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13358),
    [sym_trigger_keyword] = ACTIONS(13358),
    [sym_var_keyword] = ACTIONS(13358),
    [sym_local_keyword] = ACTIONS(13358),
    [sym_internal_keyword] = ACTIONS(13358),
    [sym_protected_keyword] = ACTIONS(13358),
    [sym_event_keyword] = ACTIONS(13358),
    [sym_fields_keyword] = ACTIONS(13358),
    [sym_keys_keyword] = ACTIONS(13358),
    [sym_fieldgroups_keyword] = ACTIONS(13358),
    [sym_actions_keyword] = ACTIONS(13358),
    [sym_layout_keyword] = ACTIONS(13358),
    [sym_area_keyword] = ACTIONS(13358),
    [sym_group_keyword] = ACTIONS(13358),
    [sym_repeater_keyword] = ACTIONS(13358),
    [sym_cuegroup_keyword] = ACTIONS(13358),
    [sym_fixed_keyword] = ACTIONS(13358),
    [sym_grid_keyword] = ACTIONS(13358),
    [sym_part_keyword] = ACTIONS(13358),
    [sym_systempart_keyword] = ACTIONS(13358),
    [sym_usercontrol_keyword] = ACTIONS(13358),
    [sym_dataset_keyword] = ACTIONS(13358),
    [sym_elements_keyword] = ACTIONS(13358),
    [sym_labels_keyword] = ACTIONS(13358),
    [sym_rendering_keyword] = ACTIONS(13358),
    [sym_requestpage_keyword] = ACTIONS(13358),
    [sym_schema_keyword] = ACTIONS(13358),
    [sym_views_keyword] = ACTIONS(13358),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13358),
    [sym_preproc_open] = ACTIONS(13358),
    [sym_preproc_close] = ACTIONS(13358),
  },
  [STATE(5374)] = {
    [anon_sym_SEMI] = ACTIONS(7420),
    [aux_sym_where_condition_token1] = ACTIONS(7418),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7420),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7420),
    [anon_sym_LBRACK] = ACTIONS(7420),
    [aux_sym_basic_type_token6] = ACTIONS(7418),
    [aux_sym_basic_type_token22] = ACTIONS(7418),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7420),
    [aux_sym_addafter_modification_token1] = ACTIONS(7420),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7420),
    [aux_sym_modify_modification_token1] = ACTIONS(7420),
    [aux_sym_movefirst_modification_token1] = ACTIONS(7420),
    [aux_sym_movelast_modification_token1] = ACTIONS(7420),
    [aux_sym_moveafter_modification_token1] = ACTIONS(7420),
    [aux_sym_movebefore_modification_token1] = ACTIONS(7420),
    [aux_sym_separator_action_token1] = ACTIONS(7420),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7420),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7420),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7420),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7420),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7420),
    [anon_sym_POUNDif] = ACTIONS(7420),
    [anon_sym_POUNDIF] = ACTIONS(7420),
    [anon_sym_POUNDIf] = ACTIONS(7420),
    [anon_sym_POUNDendif] = ACTIONS(7420),
    [anon_sym_POUNDENDIF] = ACTIONS(7420),
    [anon_sym_POUNDEndif] = ACTIONS(7420),
    [anon_sym_POUNDendif2] = ACTIONS(7420),
    [anon_sym_POUNDENDIF2] = ACTIONS(7420),
    [anon_sym_POUNDEndif2] = ACTIONS(7420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(7420),
    [sym_trigger_keyword] = ACTIONS(7420),
    [sym_var_keyword] = ACTIONS(7420),
    [sym_local_keyword] = ACTIONS(7420),
    [sym_internal_keyword] = ACTIONS(7420),
    [sym_protected_keyword] = ACTIONS(7420),
    [sym_event_keyword] = ACTIONS(7420),
    [sym_fields_keyword] = ACTIONS(7420),
    [sym_keys_keyword] = ACTIONS(7420),
    [sym_fieldgroups_keyword] = ACTIONS(7420),
    [sym_actions_keyword] = ACTIONS(7420),
    [sym_layout_keyword] = ACTIONS(7420),
    [sym_area_keyword] = ACTIONS(7420),
    [sym_group_keyword] = ACTIONS(7420),
    [sym_repeater_keyword] = ACTIONS(7420),
    [sym_cuegroup_keyword] = ACTIONS(7420),
    [sym_fixed_keyword] = ACTIONS(7420),
    [sym_grid_keyword] = ACTIONS(7420),
    [sym_part_keyword] = ACTIONS(7420),
    [sym_systempart_keyword] = ACTIONS(7420),
    [sym_usercontrol_keyword] = ACTIONS(7420),
    [sym_dataset_keyword] = ACTIONS(7420),
    [sym_elements_keyword] = ACTIONS(7420),
    [sym_dataitem_keyword] = ACTIONS(7420),
    [sym_column_keyword] = ACTIONS(7420),
    [sym_filter_keyword] = ACTIONS(7420),
    [sym_labels_keyword] = ACTIONS(7420),
    [sym_rendering_keyword] = ACTIONS(7420),
    [sym_requestpage_keyword] = ACTIONS(7420),
    [sym_schema_keyword] = ACTIONS(7420),
    [sym_views_keyword] = ACTIONS(7420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7420),
    [sym_preproc_open] = ACTIONS(7420),
    [sym_preproc_close] = ACTIONS(7420),
  },
  [STATE(5375)] = {
    [anon_sym_SEMI] = ACTIONS(13362),
    [aux_sym_where_condition_token1] = ACTIONS(13364),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13362),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13362),
    [anon_sym_LBRACK] = ACTIONS(13362),
    [aux_sym_basic_type_token6] = ACTIONS(13364),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13362),
    [aux_sym_addafter_modification_token1] = ACTIONS(13362),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13362),
    [aux_sym_modify_modification_token1] = ACTIONS(13362),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13362),
    [aux_sym_movelast_modification_token1] = ACTIONS(13362),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13362),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13362),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13362),
    [anon_sym_POUNDif] = ACTIONS(13362),
    [anon_sym_POUNDIF] = ACTIONS(13362),
    [anon_sym_POUNDIf] = ACTIONS(13362),
    [anon_sym_POUNDelif] = ACTIONS(13362),
    [anon_sym_POUNDELIF] = ACTIONS(13362),
    [anon_sym_POUNDElif] = ACTIONS(13362),
    [anon_sym_POUNDelse] = ACTIONS(13362),
    [anon_sym_POUNDELSE] = ACTIONS(13362),
    [anon_sym_POUNDElse] = ACTIONS(13362),
    [anon_sym_POUNDelse2] = ACTIONS(13362),
    [anon_sym_POUNDELSE2] = ACTIONS(13362),
    [anon_sym_POUNDElse2] = ACTIONS(13362),
    [anon_sym_POUNDendif] = ACTIONS(13362),
    [anon_sym_POUNDENDIF] = ACTIONS(13362),
    [anon_sym_POUNDEndif] = ACTIONS(13362),
    [anon_sym_POUNDendif2] = ACTIONS(13362),
    [anon_sym_POUNDENDIF2] = ACTIONS(13362),
    [anon_sym_POUNDEndif2] = ACTIONS(13362),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13362),
    [sym_trigger_keyword] = ACTIONS(13362),
    [sym_var_keyword] = ACTIONS(13362),
    [sym_local_keyword] = ACTIONS(13362),
    [sym_internal_keyword] = ACTIONS(13362),
    [sym_protected_keyword] = ACTIONS(13362),
    [sym_event_keyword] = ACTIONS(13362),
    [sym_fields_keyword] = ACTIONS(13362),
    [sym_keys_keyword] = ACTIONS(13362),
    [sym_fieldgroups_keyword] = ACTIONS(13362),
    [sym_actions_keyword] = ACTIONS(13362),
    [sym_layout_keyword] = ACTIONS(13362),
    [sym_area_keyword] = ACTIONS(13362),
    [sym_group_keyword] = ACTIONS(13362),
    [sym_repeater_keyword] = ACTIONS(13362),
    [sym_cuegroup_keyword] = ACTIONS(13362),
    [sym_fixed_keyword] = ACTIONS(13362),
    [sym_grid_keyword] = ACTIONS(13362),
    [sym_part_keyword] = ACTIONS(13362),
    [sym_systempart_keyword] = ACTIONS(13362),
    [sym_usercontrol_keyword] = ACTIONS(13362),
    [sym_dataset_keyword] = ACTIONS(13362),
    [sym_elements_keyword] = ACTIONS(13362),
    [sym_labels_keyword] = ACTIONS(13362),
    [sym_rendering_keyword] = ACTIONS(13362),
    [sym_requestpage_keyword] = ACTIONS(13362),
    [sym_schema_keyword] = ACTIONS(13362),
    [sym_views_keyword] = ACTIONS(13362),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13362),
    [sym_preproc_open] = ACTIONS(13362),
    [sym_preproc_close] = ACTIONS(13362),
  },
  [STATE(5376)] = {
    [anon_sym_SEMI] = ACTIONS(13366),
    [aux_sym_where_condition_token1] = ACTIONS(13368),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13366),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13366),
    [anon_sym_LBRACK] = ACTIONS(13366),
    [aux_sym_basic_type_token6] = ACTIONS(13368),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13366),
    [aux_sym_addafter_modification_token1] = ACTIONS(13366),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13366),
    [aux_sym_modify_modification_token1] = ACTIONS(13366),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13366),
    [aux_sym_movelast_modification_token1] = ACTIONS(13366),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13366),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13366),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13366),
    [anon_sym_POUNDif] = ACTIONS(13366),
    [anon_sym_POUNDIF] = ACTIONS(13366),
    [anon_sym_POUNDIf] = ACTIONS(13366),
    [anon_sym_POUNDelif] = ACTIONS(13366),
    [anon_sym_POUNDELIF] = ACTIONS(13366),
    [anon_sym_POUNDElif] = ACTIONS(13366),
    [anon_sym_POUNDelse] = ACTIONS(13366),
    [anon_sym_POUNDELSE] = ACTIONS(13366),
    [anon_sym_POUNDElse] = ACTIONS(13366),
    [anon_sym_POUNDelse2] = ACTIONS(13366),
    [anon_sym_POUNDELSE2] = ACTIONS(13366),
    [anon_sym_POUNDElse2] = ACTIONS(13366),
    [anon_sym_POUNDendif] = ACTIONS(13366),
    [anon_sym_POUNDENDIF] = ACTIONS(13366),
    [anon_sym_POUNDEndif] = ACTIONS(13366),
    [anon_sym_POUNDendif2] = ACTIONS(13366),
    [anon_sym_POUNDENDIF2] = ACTIONS(13366),
    [anon_sym_POUNDEndif2] = ACTIONS(13366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13366),
    [sym_trigger_keyword] = ACTIONS(13366),
    [sym_var_keyword] = ACTIONS(13366),
    [sym_local_keyword] = ACTIONS(13366),
    [sym_internal_keyword] = ACTIONS(13366),
    [sym_protected_keyword] = ACTIONS(13366),
    [sym_event_keyword] = ACTIONS(13366),
    [sym_fields_keyword] = ACTIONS(13366),
    [sym_keys_keyword] = ACTIONS(13366),
    [sym_fieldgroups_keyword] = ACTIONS(13366),
    [sym_actions_keyword] = ACTIONS(13366),
    [sym_layout_keyword] = ACTIONS(13366),
    [sym_area_keyword] = ACTIONS(13366),
    [sym_group_keyword] = ACTIONS(13366),
    [sym_repeater_keyword] = ACTIONS(13366),
    [sym_cuegroup_keyword] = ACTIONS(13366),
    [sym_fixed_keyword] = ACTIONS(13366),
    [sym_grid_keyword] = ACTIONS(13366),
    [sym_part_keyword] = ACTIONS(13366),
    [sym_systempart_keyword] = ACTIONS(13366),
    [sym_usercontrol_keyword] = ACTIONS(13366),
    [sym_dataset_keyword] = ACTIONS(13366),
    [sym_elements_keyword] = ACTIONS(13366),
    [sym_labels_keyword] = ACTIONS(13366),
    [sym_rendering_keyword] = ACTIONS(13366),
    [sym_requestpage_keyword] = ACTIONS(13366),
    [sym_schema_keyword] = ACTIONS(13366),
    [sym_views_keyword] = ACTIONS(13366),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13366),
    [sym_preproc_open] = ACTIONS(13366),
    [sym_preproc_close] = ACTIONS(13366),
  },
  [STATE(5377)] = {
    [anon_sym_SEMI] = ACTIONS(13370),
    [aux_sym_where_condition_token1] = ACTIONS(13372),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13374),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13374),
    [anon_sym_LBRACK] = ACTIONS(13370),
    [aux_sym_basic_type_token6] = ACTIONS(13372),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13370),
    [aux_sym_addafter_modification_token1] = ACTIONS(13374),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13374),
    [aux_sym_modify_modification_token1] = ACTIONS(13376),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13374),
    [aux_sym_movelast_modification_token1] = ACTIONS(13374),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13374),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13374),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13370),
    [anon_sym_POUNDif] = ACTIONS(13376),
    [anon_sym_POUNDIF] = ACTIONS(13376),
    [anon_sym_POUNDIf] = ACTIONS(13376),
    [anon_sym_POUNDelif] = ACTIONS(13376),
    [anon_sym_POUNDELIF] = ACTIONS(13376),
    [anon_sym_POUNDElif] = ACTIONS(13376),
    [anon_sym_POUNDelse] = ACTIONS(13376),
    [anon_sym_POUNDELSE] = ACTIONS(13376),
    [anon_sym_POUNDElse] = ACTIONS(13376),
    [anon_sym_POUNDelse2] = ACTIONS(13376),
    [anon_sym_POUNDELSE2] = ACTIONS(13376),
    [anon_sym_POUNDElse2] = ACTIONS(13376),
    [anon_sym_POUNDendif] = ACTIONS(13376),
    [anon_sym_POUNDENDIF] = ACTIONS(13376),
    [anon_sym_POUNDEndif] = ACTIONS(13376),
    [anon_sym_POUNDendif2] = ACTIONS(13376),
    [anon_sym_POUNDENDIF2] = ACTIONS(13376),
    [anon_sym_POUNDEndif2] = ACTIONS(13376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13370),
    [sym_trigger_keyword] = ACTIONS(13370),
    [sym_var_keyword] = ACTIONS(13370),
    [sym_local_keyword] = ACTIONS(13370),
    [sym_internal_keyword] = ACTIONS(13370),
    [sym_protected_keyword] = ACTIONS(13370),
    [sym_event_keyword] = ACTIONS(13370),
    [sym_fields_keyword] = ACTIONS(13370),
    [sym_keys_keyword] = ACTIONS(13370),
    [sym_fieldgroups_keyword] = ACTIONS(13370),
    [sym_actions_keyword] = ACTIONS(13370),
    [sym_layout_keyword] = ACTIONS(13370),
    [sym_area_keyword] = ACTIONS(13374),
    [sym_group_keyword] = ACTIONS(13374),
    [sym_repeater_keyword] = ACTIONS(13374),
    [sym_cuegroup_keyword] = ACTIONS(13374),
    [sym_fixed_keyword] = ACTIONS(13374),
    [sym_grid_keyword] = ACTIONS(13374),
    [sym_part_keyword] = ACTIONS(13374),
    [sym_systempart_keyword] = ACTIONS(13374),
    [sym_usercontrol_keyword] = ACTIONS(13374),
    [sym_dataset_keyword] = ACTIONS(13370),
    [sym_elements_keyword] = ACTIONS(13370),
    [sym_labels_keyword] = ACTIONS(13370),
    [sym_rendering_keyword] = ACTIONS(13370),
    [sym_requestpage_keyword] = ACTIONS(13370),
    [sym_schema_keyword] = ACTIONS(13370),
    [sym_views_keyword] = ACTIONS(13370),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13370),
    [sym_preproc_open] = ACTIONS(13376),
    [sym_preproc_close] = ACTIONS(13376),
  },
  [STATE(5378)] = {
    [anon_sym_SEMI] = ACTIONS(13379),
    [aux_sym_where_condition_token1] = ACTIONS(13381),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13379),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13379),
    [anon_sym_LBRACK] = ACTIONS(13379),
    [aux_sym_basic_type_token6] = ACTIONS(13381),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13379),
    [aux_sym_addafter_modification_token1] = ACTIONS(13379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13379),
    [aux_sym_modify_modification_token1] = ACTIONS(13379),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13379),
    [aux_sym_movelast_modification_token1] = ACTIONS(13379),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13379),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13379),
    [anon_sym_POUNDif] = ACTIONS(13379),
    [anon_sym_POUNDIF] = ACTIONS(13379),
    [anon_sym_POUNDIf] = ACTIONS(13379),
    [anon_sym_POUNDelif] = ACTIONS(13379),
    [anon_sym_POUNDELIF] = ACTIONS(13379),
    [anon_sym_POUNDElif] = ACTIONS(13379),
    [anon_sym_POUNDelse] = ACTIONS(13379),
    [anon_sym_POUNDELSE] = ACTIONS(13379),
    [anon_sym_POUNDElse] = ACTIONS(13379),
    [anon_sym_POUNDelse2] = ACTIONS(13379),
    [anon_sym_POUNDELSE2] = ACTIONS(13379),
    [anon_sym_POUNDElse2] = ACTIONS(13379),
    [anon_sym_POUNDendif] = ACTIONS(13379),
    [anon_sym_POUNDENDIF] = ACTIONS(13379),
    [anon_sym_POUNDEndif] = ACTIONS(13379),
    [anon_sym_POUNDendif2] = ACTIONS(13379),
    [anon_sym_POUNDENDIF2] = ACTIONS(13379),
    [anon_sym_POUNDEndif2] = ACTIONS(13379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13379),
    [sym_trigger_keyword] = ACTIONS(13379),
    [sym_var_keyword] = ACTIONS(13379),
    [sym_local_keyword] = ACTIONS(13379),
    [sym_internal_keyword] = ACTIONS(13379),
    [sym_protected_keyword] = ACTIONS(13379),
    [sym_event_keyword] = ACTIONS(13379),
    [sym_fields_keyword] = ACTIONS(13379),
    [sym_keys_keyword] = ACTIONS(13379),
    [sym_fieldgroups_keyword] = ACTIONS(13379),
    [sym_actions_keyword] = ACTIONS(13379),
    [sym_layout_keyword] = ACTIONS(13379),
    [sym_area_keyword] = ACTIONS(13379),
    [sym_group_keyword] = ACTIONS(13379),
    [sym_repeater_keyword] = ACTIONS(13379),
    [sym_cuegroup_keyword] = ACTIONS(13379),
    [sym_fixed_keyword] = ACTIONS(13379),
    [sym_grid_keyword] = ACTIONS(13379),
    [sym_part_keyword] = ACTIONS(13379),
    [sym_systempart_keyword] = ACTIONS(13379),
    [sym_usercontrol_keyword] = ACTIONS(13379),
    [sym_dataset_keyword] = ACTIONS(13379),
    [sym_elements_keyword] = ACTIONS(13379),
    [sym_labels_keyword] = ACTIONS(13379),
    [sym_rendering_keyword] = ACTIONS(13379),
    [sym_requestpage_keyword] = ACTIONS(13379),
    [sym_schema_keyword] = ACTIONS(13379),
    [sym_views_keyword] = ACTIONS(13379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13379),
    [sym_preproc_open] = ACTIONS(13379),
    [sym_preproc_close] = ACTIONS(13379),
  },
  [STATE(5379)] = {
    [anon_sym_SEMI] = ACTIONS(13383),
    [aux_sym_where_condition_token1] = ACTIONS(13385),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13383),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13383),
    [anon_sym_LBRACK] = ACTIONS(13383),
    [aux_sym_basic_type_token6] = ACTIONS(13385),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13383),
    [aux_sym_addafter_modification_token1] = ACTIONS(13383),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13383),
    [aux_sym_modify_modification_token1] = ACTIONS(13383),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13383),
    [aux_sym_movelast_modification_token1] = ACTIONS(13383),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13383),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13383),
    [anon_sym_POUNDif] = ACTIONS(13383),
    [anon_sym_POUNDIF] = ACTIONS(13383),
    [anon_sym_POUNDIf] = ACTIONS(13383),
    [anon_sym_POUNDelif] = ACTIONS(13383),
    [anon_sym_POUNDELIF] = ACTIONS(13383),
    [anon_sym_POUNDElif] = ACTIONS(13383),
    [anon_sym_POUNDelse] = ACTIONS(13383),
    [anon_sym_POUNDELSE] = ACTIONS(13383),
    [anon_sym_POUNDElse] = ACTIONS(13383),
    [anon_sym_POUNDelse2] = ACTIONS(13383),
    [anon_sym_POUNDELSE2] = ACTIONS(13383),
    [anon_sym_POUNDElse2] = ACTIONS(13383),
    [anon_sym_POUNDendif] = ACTIONS(13383),
    [anon_sym_POUNDENDIF] = ACTIONS(13383),
    [anon_sym_POUNDEndif] = ACTIONS(13383),
    [anon_sym_POUNDendif2] = ACTIONS(13383),
    [anon_sym_POUNDENDIF2] = ACTIONS(13383),
    [anon_sym_POUNDEndif2] = ACTIONS(13383),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13383),
    [sym_trigger_keyword] = ACTIONS(13383),
    [sym_var_keyword] = ACTIONS(13383),
    [sym_local_keyword] = ACTIONS(13383),
    [sym_internal_keyword] = ACTIONS(13383),
    [sym_protected_keyword] = ACTIONS(13383),
    [sym_event_keyword] = ACTIONS(13383),
    [sym_fields_keyword] = ACTIONS(13383),
    [sym_keys_keyword] = ACTIONS(13383),
    [sym_fieldgroups_keyword] = ACTIONS(13383),
    [sym_actions_keyword] = ACTIONS(13383),
    [sym_layout_keyword] = ACTIONS(13383),
    [sym_area_keyword] = ACTIONS(13383),
    [sym_group_keyword] = ACTIONS(13383),
    [sym_repeater_keyword] = ACTIONS(13383),
    [sym_cuegroup_keyword] = ACTIONS(13383),
    [sym_fixed_keyword] = ACTIONS(13383),
    [sym_grid_keyword] = ACTIONS(13383),
    [sym_part_keyword] = ACTIONS(13383),
    [sym_systempart_keyword] = ACTIONS(13383),
    [sym_usercontrol_keyword] = ACTIONS(13383),
    [sym_dataset_keyword] = ACTIONS(13383),
    [sym_elements_keyword] = ACTIONS(13383),
    [sym_labels_keyword] = ACTIONS(13383),
    [sym_rendering_keyword] = ACTIONS(13383),
    [sym_requestpage_keyword] = ACTIONS(13383),
    [sym_schema_keyword] = ACTIONS(13383),
    [sym_views_keyword] = ACTIONS(13383),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13383),
    [sym_preproc_open] = ACTIONS(13383),
    [sym_preproc_close] = ACTIONS(13383),
  },
  [STATE(5380)] = {
    [anon_sym_SEMI] = ACTIONS(13387),
    [aux_sym_where_condition_token1] = ACTIONS(13389),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13387),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13387),
    [anon_sym_LBRACK] = ACTIONS(13387),
    [aux_sym_basic_type_token6] = ACTIONS(13389),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13387),
    [aux_sym_addafter_modification_token1] = ACTIONS(13387),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13387),
    [aux_sym_modify_modification_token1] = ACTIONS(13387),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13387),
    [aux_sym_movelast_modification_token1] = ACTIONS(13387),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13387),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13387),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13387),
    [anon_sym_POUNDif] = ACTIONS(13387),
    [anon_sym_POUNDIF] = ACTIONS(13387),
    [anon_sym_POUNDIf] = ACTIONS(13387),
    [anon_sym_POUNDelif] = ACTIONS(13387),
    [anon_sym_POUNDELIF] = ACTIONS(13387),
    [anon_sym_POUNDElif] = ACTIONS(13387),
    [anon_sym_POUNDelse] = ACTIONS(13387),
    [anon_sym_POUNDELSE] = ACTIONS(13387),
    [anon_sym_POUNDElse] = ACTIONS(13387),
    [anon_sym_POUNDelse2] = ACTIONS(13387),
    [anon_sym_POUNDELSE2] = ACTIONS(13387),
    [anon_sym_POUNDElse2] = ACTIONS(13387),
    [anon_sym_POUNDendif] = ACTIONS(13387),
    [anon_sym_POUNDENDIF] = ACTIONS(13387),
    [anon_sym_POUNDEndif] = ACTIONS(13387),
    [anon_sym_POUNDendif2] = ACTIONS(13387),
    [anon_sym_POUNDENDIF2] = ACTIONS(13387),
    [anon_sym_POUNDEndif2] = ACTIONS(13387),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13387),
    [sym_trigger_keyword] = ACTIONS(13387),
    [sym_var_keyword] = ACTIONS(13387),
    [sym_local_keyword] = ACTIONS(13387),
    [sym_internal_keyword] = ACTIONS(13387),
    [sym_protected_keyword] = ACTIONS(13387),
    [sym_event_keyword] = ACTIONS(13387),
    [sym_fields_keyword] = ACTIONS(13387),
    [sym_keys_keyword] = ACTIONS(13387),
    [sym_fieldgroups_keyword] = ACTIONS(13387),
    [sym_actions_keyword] = ACTIONS(13387),
    [sym_layout_keyword] = ACTIONS(13387),
    [sym_area_keyword] = ACTIONS(13387),
    [sym_group_keyword] = ACTIONS(13387),
    [sym_repeater_keyword] = ACTIONS(13387),
    [sym_cuegroup_keyword] = ACTIONS(13387),
    [sym_fixed_keyword] = ACTIONS(13387),
    [sym_grid_keyword] = ACTIONS(13387),
    [sym_part_keyword] = ACTIONS(13387),
    [sym_systempart_keyword] = ACTIONS(13387),
    [sym_usercontrol_keyword] = ACTIONS(13387),
    [sym_dataset_keyword] = ACTIONS(13387),
    [sym_elements_keyword] = ACTIONS(13387),
    [sym_labels_keyword] = ACTIONS(13387),
    [sym_rendering_keyword] = ACTIONS(13387),
    [sym_requestpage_keyword] = ACTIONS(13387),
    [sym_schema_keyword] = ACTIONS(13387),
    [sym_views_keyword] = ACTIONS(13387),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13387),
    [sym_preproc_open] = ACTIONS(13387),
    [sym_preproc_close] = ACTIONS(13387),
  },
  [STATE(5381)] = {
    [anon_sym_SEMI] = ACTIONS(13391),
    [aux_sym_where_condition_token1] = ACTIONS(13393),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13391),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13391),
    [anon_sym_LBRACK] = ACTIONS(13391),
    [aux_sym_basic_type_token6] = ACTIONS(13393),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13391),
    [aux_sym_addafter_modification_token1] = ACTIONS(13391),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13391),
    [aux_sym_modify_modification_token1] = ACTIONS(13391),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13391),
    [aux_sym_movelast_modification_token1] = ACTIONS(13391),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13391),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13391),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13391),
    [anon_sym_POUNDif] = ACTIONS(13391),
    [anon_sym_POUNDIF] = ACTIONS(13391),
    [anon_sym_POUNDIf] = ACTIONS(13391),
    [anon_sym_POUNDelif] = ACTIONS(13391),
    [anon_sym_POUNDELIF] = ACTIONS(13391),
    [anon_sym_POUNDElif] = ACTIONS(13391),
    [anon_sym_POUNDelse] = ACTIONS(13391),
    [anon_sym_POUNDELSE] = ACTIONS(13391),
    [anon_sym_POUNDElse] = ACTIONS(13391),
    [anon_sym_POUNDelse2] = ACTIONS(13391),
    [anon_sym_POUNDELSE2] = ACTIONS(13391),
    [anon_sym_POUNDElse2] = ACTIONS(13391),
    [anon_sym_POUNDendif] = ACTIONS(13391),
    [anon_sym_POUNDENDIF] = ACTIONS(13391),
    [anon_sym_POUNDEndif] = ACTIONS(13391),
    [anon_sym_POUNDendif2] = ACTIONS(13391),
    [anon_sym_POUNDENDIF2] = ACTIONS(13391),
    [anon_sym_POUNDEndif2] = ACTIONS(13391),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13391),
    [sym_trigger_keyword] = ACTIONS(13391),
    [sym_var_keyword] = ACTIONS(13391),
    [sym_local_keyword] = ACTIONS(13391),
    [sym_internal_keyword] = ACTIONS(13391),
    [sym_protected_keyword] = ACTIONS(13391),
    [sym_event_keyword] = ACTIONS(13391),
    [sym_fields_keyword] = ACTIONS(13391),
    [sym_keys_keyword] = ACTIONS(13391),
    [sym_fieldgroups_keyword] = ACTIONS(13391),
    [sym_actions_keyword] = ACTIONS(13391),
    [sym_layout_keyword] = ACTIONS(13391),
    [sym_area_keyword] = ACTIONS(13391),
    [sym_group_keyword] = ACTIONS(13391),
    [sym_repeater_keyword] = ACTIONS(13391),
    [sym_cuegroup_keyword] = ACTIONS(13391),
    [sym_fixed_keyword] = ACTIONS(13391),
    [sym_grid_keyword] = ACTIONS(13391),
    [sym_part_keyword] = ACTIONS(13391),
    [sym_systempart_keyword] = ACTIONS(13391),
    [sym_usercontrol_keyword] = ACTIONS(13391),
    [sym_dataset_keyword] = ACTIONS(13391),
    [sym_elements_keyword] = ACTIONS(13391),
    [sym_labels_keyword] = ACTIONS(13391),
    [sym_rendering_keyword] = ACTIONS(13391),
    [sym_requestpage_keyword] = ACTIONS(13391),
    [sym_schema_keyword] = ACTIONS(13391),
    [sym_views_keyword] = ACTIONS(13391),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13391),
    [sym_preproc_open] = ACTIONS(13391),
    [sym_preproc_close] = ACTIONS(13391),
  },
  [STATE(5382)] = {
    [anon_sym_SEMI] = ACTIONS(13395),
    [aux_sym_where_condition_token1] = ACTIONS(13397),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13395),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13395),
    [anon_sym_LBRACK] = ACTIONS(13395),
    [aux_sym_basic_type_token6] = ACTIONS(13397),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13395),
    [aux_sym_addafter_modification_token1] = ACTIONS(13395),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13395),
    [aux_sym_modify_modification_token1] = ACTIONS(13395),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13395),
    [aux_sym_movelast_modification_token1] = ACTIONS(13395),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13395),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13395),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13395),
    [anon_sym_POUNDif] = ACTIONS(13395),
    [anon_sym_POUNDIF] = ACTIONS(13395),
    [anon_sym_POUNDIf] = ACTIONS(13395),
    [anon_sym_POUNDelif] = ACTIONS(13395),
    [anon_sym_POUNDELIF] = ACTIONS(13395),
    [anon_sym_POUNDElif] = ACTIONS(13395),
    [anon_sym_POUNDelse] = ACTIONS(13395),
    [anon_sym_POUNDELSE] = ACTIONS(13395),
    [anon_sym_POUNDElse] = ACTIONS(13395),
    [anon_sym_POUNDelse2] = ACTIONS(13395),
    [anon_sym_POUNDELSE2] = ACTIONS(13395),
    [anon_sym_POUNDElse2] = ACTIONS(13395),
    [anon_sym_POUNDendif] = ACTIONS(13395),
    [anon_sym_POUNDENDIF] = ACTIONS(13395),
    [anon_sym_POUNDEndif] = ACTIONS(13395),
    [anon_sym_POUNDendif2] = ACTIONS(13395),
    [anon_sym_POUNDENDIF2] = ACTIONS(13395),
    [anon_sym_POUNDEndif2] = ACTIONS(13395),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13395),
    [sym_trigger_keyword] = ACTIONS(13395),
    [sym_var_keyword] = ACTIONS(13395),
    [sym_local_keyword] = ACTIONS(13395),
    [sym_internal_keyword] = ACTIONS(13395),
    [sym_protected_keyword] = ACTIONS(13395),
    [sym_event_keyword] = ACTIONS(13395),
    [sym_fields_keyword] = ACTIONS(13395),
    [sym_keys_keyword] = ACTIONS(13395),
    [sym_fieldgroups_keyword] = ACTIONS(13395),
    [sym_actions_keyword] = ACTIONS(13395),
    [sym_layout_keyword] = ACTIONS(13395),
    [sym_area_keyword] = ACTIONS(13395),
    [sym_group_keyword] = ACTIONS(13395),
    [sym_repeater_keyword] = ACTIONS(13395),
    [sym_cuegroup_keyword] = ACTIONS(13395),
    [sym_fixed_keyword] = ACTIONS(13395),
    [sym_grid_keyword] = ACTIONS(13395),
    [sym_part_keyword] = ACTIONS(13395),
    [sym_systempart_keyword] = ACTIONS(13395),
    [sym_usercontrol_keyword] = ACTIONS(13395),
    [sym_dataset_keyword] = ACTIONS(13395),
    [sym_elements_keyword] = ACTIONS(13395),
    [sym_labels_keyword] = ACTIONS(13395),
    [sym_rendering_keyword] = ACTIONS(13395),
    [sym_requestpage_keyword] = ACTIONS(13395),
    [sym_schema_keyword] = ACTIONS(13395),
    [sym_views_keyword] = ACTIONS(13395),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13395),
    [sym_preproc_open] = ACTIONS(13395),
    [sym_preproc_close] = ACTIONS(13395),
  },
  [STATE(5383)] = {
    [anon_sym_SEMI] = ACTIONS(13399),
    [aux_sym_where_condition_token1] = ACTIONS(13401),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13399),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13399),
    [anon_sym_LBRACK] = ACTIONS(13399),
    [aux_sym_basic_type_token6] = ACTIONS(13401),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13399),
    [aux_sym_addafter_modification_token1] = ACTIONS(13399),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13399),
    [aux_sym_modify_modification_token1] = ACTIONS(13399),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13399),
    [aux_sym_movelast_modification_token1] = ACTIONS(13399),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13399),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13399),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13399),
    [anon_sym_POUNDif] = ACTIONS(13399),
    [anon_sym_POUNDIF] = ACTIONS(13399),
    [anon_sym_POUNDIf] = ACTIONS(13399),
    [anon_sym_POUNDelif] = ACTIONS(13399),
    [anon_sym_POUNDELIF] = ACTIONS(13399),
    [anon_sym_POUNDElif] = ACTIONS(13399),
    [anon_sym_POUNDelse] = ACTIONS(13399),
    [anon_sym_POUNDELSE] = ACTIONS(13399),
    [anon_sym_POUNDElse] = ACTIONS(13399),
    [anon_sym_POUNDelse2] = ACTIONS(13399),
    [anon_sym_POUNDELSE2] = ACTIONS(13399),
    [anon_sym_POUNDElse2] = ACTIONS(13399),
    [anon_sym_POUNDendif] = ACTIONS(13399),
    [anon_sym_POUNDENDIF] = ACTIONS(13399),
    [anon_sym_POUNDEndif] = ACTIONS(13399),
    [anon_sym_POUNDendif2] = ACTIONS(13399),
    [anon_sym_POUNDENDIF2] = ACTIONS(13399),
    [anon_sym_POUNDEndif2] = ACTIONS(13399),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13399),
    [sym_trigger_keyword] = ACTIONS(13399),
    [sym_var_keyword] = ACTIONS(13399),
    [sym_local_keyword] = ACTIONS(13399),
    [sym_internal_keyword] = ACTIONS(13399),
    [sym_protected_keyword] = ACTIONS(13399),
    [sym_event_keyword] = ACTIONS(13399),
    [sym_fields_keyword] = ACTIONS(13399),
    [sym_keys_keyword] = ACTIONS(13399),
    [sym_fieldgroups_keyword] = ACTIONS(13399),
    [sym_actions_keyword] = ACTIONS(13399),
    [sym_layout_keyword] = ACTIONS(13399),
    [sym_area_keyword] = ACTIONS(13399),
    [sym_group_keyword] = ACTIONS(13399),
    [sym_repeater_keyword] = ACTIONS(13399),
    [sym_cuegroup_keyword] = ACTIONS(13399),
    [sym_fixed_keyword] = ACTIONS(13399),
    [sym_grid_keyword] = ACTIONS(13399),
    [sym_part_keyword] = ACTIONS(13399),
    [sym_systempart_keyword] = ACTIONS(13399),
    [sym_usercontrol_keyword] = ACTIONS(13399),
    [sym_dataset_keyword] = ACTIONS(13399),
    [sym_elements_keyword] = ACTIONS(13399),
    [sym_labels_keyword] = ACTIONS(13399),
    [sym_rendering_keyword] = ACTIONS(13399),
    [sym_requestpage_keyword] = ACTIONS(13399),
    [sym_schema_keyword] = ACTIONS(13399),
    [sym_views_keyword] = ACTIONS(13399),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13399),
    [sym_preproc_open] = ACTIONS(13399),
    [sym_preproc_close] = ACTIONS(13399),
  },
  [STATE(5384)] = {
    [anon_sym_SEMI] = ACTIONS(13403),
    [aux_sym_where_condition_token1] = ACTIONS(13405),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13403),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13403),
    [anon_sym_LBRACK] = ACTIONS(13403),
    [aux_sym_basic_type_token6] = ACTIONS(13405),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13403),
    [aux_sym_addafter_modification_token1] = ACTIONS(13403),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13403),
    [aux_sym_modify_modification_token1] = ACTIONS(13403),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13403),
    [aux_sym_movelast_modification_token1] = ACTIONS(13403),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13403),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13403),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13403),
    [anon_sym_POUNDif] = ACTIONS(13403),
    [anon_sym_POUNDIF] = ACTIONS(13403),
    [anon_sym_POUNDIf] = ACTIONS(13403),
    [anon_sym_POUNDelif] = ACTIONS(13403),
    [anon_sym_POUNDELIF] = ACTIONS(13403),
    [anon_sym_POUNDElif] = ACTIONS(13403),
    [anon_sym_POUNDelse] = ACTIONS(13403),
    [anon_sym_POUNDELSE] = ACTIONS(13403),
    [anon_sym_POUNDElse] = ACTIONS(13403),
    [anon_sym_POUNDelse2] = ACTIONS(13403),
    [anon_sym_POUNDELSE2] = ACTIONS(13403),
    [anon_sym_POUNDElse2] = ACTIONS(13403),
    [anon_sym_POUNDendif] = ACTIONS(13403),
    [anon_sym_POUNDENDIF] = ACTIONS(13403),
    [anon_sym_POUNDEndif] = ACTIONS(13403),
    [anon_sym_POUNDendif2] = ACTIONS(13403),
    [anon_sym_POUNDENDIF2] = ACTIONS(13403),
    [anon_sym_POUNDEndif2] = ACTIONS(13403),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13403),
    [sym_trigger_keyword] = ACTIONS(13403),
    [sym_var_keyword] = ACTIONS(13403),
    [sym_local_keyword] = ACTIONS(13403),
    [sym_internal_keyword] = ACTIONS(13403),
    [sym_protected_keyword] = ACTIONS(13403),
    [sym_event_keyword] = ACTIONS(13403),
    [sym_fields_keyword] = ACTIONS(13403),
    [sym_keys_keyword] = ACTIONS(13403),
    [sym_fieldgroups_keyword] = ACTIONS(13403),
    [sym_actions_keyword] = ACTIONS(13403),
    [sym_layout_keyword] = ACTIONS(13403),
    [sym_area_keyword] = ACTIONS(13403),
    [sym_group_keyword] = ACTIONS(13403),
    [sym_repeater_keyword] = ACTIONS(13403),
    [sym_cuegroup_keyword] = ACTIONS(13403),
    [sym_fixed_keyword] = ACTIONS(13403),
    [sym_grid_keyword] = ACTIONS(13403),
    [sym_part_keyword] = ACTIONS(13403),
    [sym_systempart_keyword] = ACTIONS(13403),
    [sym_usercontrol_keyword] = ACTIONS(13403),
    [sym_dataset_keyword] = ACTIONS(13403),
    [sym_elements_keyword] = ACTIONS(13403),
    [sym_labels_keyword] = ACTIONS(13403),
    [sym_rendering_keyword] = ACTIONS(13403),
    [sym_requestpage_keyword] = ACTIONS(13403),
    [sym_schema_keyword] = ACTIONS(13403),
    [sym_views_keyword] = ACTIONS(13403),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13403),
    [sym_preproc_open] = ACTIONS(13403),
    [sym_preproc_close] = ACTIONS(13403),
  },
  [STATE(5385)] = {
    [anon_sym_SEMI] = ACTIONS(13407),
    [aux_sym_where_condition_token1] = ACTIONS(13409),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13407),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13407),
    [anon_sym_LBRACK] = ACTIONS(13407),
    [aux_sym_basic_type_token6] = ACTIONS(13409),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13407),
    [aux_sym_addafter_modification_token1] = ACTIONS(13407),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13407),
    [aux_sym_modify_modification_token1] = ACTIONS(13407),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13407),
    [aux_sym_movelast_modification_token1] = ACTIONS(13407),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13407),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13407),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13407),
    [anon_sym_POUNDif] = ACTIONS(13407),
    [anon_sym_POUNDIF] = ACTIONS(13407),
    [anon_sym_POUNDIf] = ACTIONS(13407),
    [anon_sym_POUNDelif] = ACTIONS(13407),
    [anon_sym_POUNDELIF] = ACTIONS(13407),
    [anon_sym_POUNDElif] = ACTIONS(13407),
    [anon_sym_POUNDelse] = ACTIONS(13407),
    [anon_sym_POUNDELSE] = ACTIONS(13407),
    [anon_sym_POUNDElse] = ACTIONS(13407),
    [anon_sym_POUNDelse2] = ACTIONS(13407),
    [anon_sym_POUNDELSE2] = ACTIONS(13407),
    [anon_sym_POUNDElse2] = ACTIONS(13407),
    [anon_sym_POUNDendif] = ACTIONS(13407),
    [anon_sym_POUNDENDIF] = ACTIONS(13407),
    [anon_sym_POUNDEndif] = ACTIONS(13407),
    [anon_sym_POUNDendif2] = ACTIONS(13407),
    [anon_sym_POUNDENDIF2] = ACTIONS(13407),
    [anon_sym_POUNDEndif2] = ACTIONS(13407),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13407),
    [sym_trigger_keyword] = ACTIONS(13407),
    [sym_var_keyword] = ACTIONS(13407),
    [sym_local_keyword] = ACTIONS(13407),
    [sym_internal_keyword] = ACTIONS(13407),
    [sym_protected_keyword] = ACTIONS(13407),
    [sym_event_keyword] = ACTIONS(13407),
    [sym_fields_keyword] = ACTIONS(13407),
    [sym_keys_keyword] = ACTIONS(13407),
    [sym_fieldgroups_keyword] = ACTIONS(13407),
    [sym_actions_keyword] = ACTIONS(13407),
    [sym_layout_keyword] = ACTIONS(13407),
    [sym_area_keyword] = ACTIONS(13407),
    [sym_group_keyword] = ACTIONS(13407),
    [sym_repeater_keyword] = ACTIONS(13407),
    [sym_cuegroup_keyword] = ACTIONS(13407),
    [sym_fixed_keyword] = ACTIONS(13407),
    [sym_grid_keyword] = ACTIONS(13407),
    [sym_part_keyword] = ACTIONS(13407),
    [sym_systempart_keyword] = ACTIONS(13407),
    [sym_usercontrol_keyword] = ACTIONS(13407),
    [sym_dataset_keyword] = ACTIONS(13407),
    [sym_elements_keyword] = ACTIONS(13407),
    [sym_labels_keyword] = ACTIONS(13407),
    [sym_rendering_keyword] = ACTIONS(13407),
    [sym_requestpage_keyword] = ACTIONS(13407),
    [sym_schema_keyword] = ACTIONS(13407),
    [sym_views_keyword] = ACTIONS(13407),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13407),
    [sym_preproc_open] = ACTIONS(13407),
    [sym_preproc_close] = ACTIONS(13407),
  },
  [STATE(5386)] = {
    [anon_sym_SEMI] = ACTIONS(13411),
    [aux_sym_where_condition_token1] = ACTIONS(13413),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13411),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13411),
    [anon_sym_LBRACK] = ACTIONS(13411),
    [aux_sym_basic_type_token6] = ACTIONS(13413),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13411),
    [aux_sym_addafter_modification_token1] = ACTIONS(13411),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13411),
    [aux_sym_modify_modification_token1] = ACTIONS(13411),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13411),
    [aux_sym_movelast_modification_token1] = ACTIONS(13411),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13411),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13411),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13411),
    [anon_sym_POUNDif] = ACTIONS(13411),
    [anon_sym_POUNDIF] = ACTIONS(13411),
    [anon_sym_POUNDIf] = ACTIONS(13411),
    [anon_sym_POUNDelif] = ACTIONS(13411),
    [anon_sym_POUNDELIF] = ACTIONS(13411),
    [anon_sym_POUNDElif] = ACTIONS(13411),
    [anon_sym_POUNDelse] = ACTIONS(13411),
    [anon_sym_POUNDELSE] = ACTIONS(13411),
    [anon_sym_POUNDElse] = ACTIONS(13411),
    [anon_sym_POUNDelse2] = ACTIONS(13411),
    [anon_sym_POUNDELSE2] = ACTIONS(13411),
    [anon_sym_POUNDElse2] = ACTIONS(13411),
    [anon_sym_POUNDendif] = ACTIONS(13411),
    [anon_sym_POUNDENDIF] = ACTIONS(13411),
    [anon_sym_POUNDEndif] = ACTIONS(13411),
    [anon_sym_POUNDendif2] = ACTIONS(13411),
    [anon_sym_POUNDENDIF2] = ACTIONS(13411),
    [anon_sym_POUNDEndif2] = ACTIONS(13411),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13411),
    [sym_trigger_keyword] = ACTIONS(13411),
    [sym_var_keyword] = ACTIONS(13411),
    [sym_local_keyword] = ACTIONS(13411),
    [sym_internal_keyword] = ACTIONS(13411),
    [sym_protected_keyword] = ACTIONS(13411),
    [sym_event_keyword] = ACTIONS(13411),
    [sym_fields_keyword] = ACTIONS(13411),
    [sym_keys_keyword] = ACTIONS(13411),
    [sym_fieldgroups_keyword] = ACTIONS(13411),
    [sym_actions_keyword] = ACTIONS(13411),
    [sym_layout_keyword] = ACTIONS(13411),
    [sym_area_keyword] = ACTIONS(13411),
    [sym_group_keyword] = ACTIONS(13411),
    [sym_repeater_keyword] = ACTIONS(13411),
    [sym_cuegroup_keyword] = ACTIONS(13411),
    [sym_fixed_keyword] = ACTIONS(13411),
    [sym_grid_keyword] = ACTIONS(13411),
    [sym_part_keyword] = ACTIONS(13411),
    [sym_systempart_keyword] = ACTIONS(13411),
    [sym_usercontrol_keyword] = ACTIONS(13411),
    [sym_dataset_keyword] = ACTIONS(13411),
    [sym_elements_keyword] = ACTIONS(13411),
    [sym_labels_keyword] = ACTIONS(13411),
    [sym_rendering_keyword] = ACTIONS(13411),
    [sym_requestpage_keyword] = ACTIONS(13411),
    [sym_schema_keyword] = ACTIONS(13411),
    [sym_views_keyword] = ACTIONS(13411),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13411),
    [sym_preproc_open] = ACTIONS(13411),
    [sym_preproc_close] = ACTIONS(13411),
  },
  [STATE(5387)] = {
    [anon_sym_SEMI] = ACTIONS(13415),
    [aux_sym_where_condition_token1] = ACTIONS(13417),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13415),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13415),
    [anon_sym_LBRACK] = ACTIONS(13415),
    [aux_sym_basic_type_token6] = ACTIONS(13417),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13415),
    [aux_sym_addafter_modification_token1] = ACTIONS(13415),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13415),
    [aux_sym_modify_modification_token1] = ACTIONS(13415),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13415),
    [aux_sym_movelast_modification_token1] = ACTIONS(13415),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13415),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13415),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13415),
    [anon_sym_POUNDif] = ACTIONS(13415),
    [anon_sym_POUNDIF] = ACTIONS(13415),
    [anon_sym_POUNDIf] = ACTIONS(13415),
    [anon_sym_POUNDelif] = ACTIONS(13415),
    [anon_sym_POUNDELIF] = ACTIONS(13415),
    [anon_sym_POUNDElif] = ACTIONS(13415),
    [anon_sym_POUNDelse] = ACTIONS(13415),
    [anon_sym_POUNDELSE] = ACTIONS(13415),
    [anon_sym_POUNDElse] = ACTIONS(13415),
    [anon_sym_POUNDelse2] = ACTIONS(13415),
    [anon_sym_POUNDELSE2] = ACTIONS(13415),
    [anon_sym_POUNDElse2] = ACTIONS(13415),
    [anon_sym_POUNDendif] = ACTIONS(13415),
    [anon_sym_POUNDENDIF] = ACTIONS(13415),
    [anon_sym_POUNDEndif] = ACTIONS(13415),
    [anon_sym_POUNDendif2] = ACTIONS(13415),
    [anon_sym_POUNDENDIF2] = ACTIONS(13415),
    [anon_sym_POUNDEndif2] = ACTIONS(13415),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13415),
    [sym_trigger_keyword] = ACTIONS(13415),
    [sym_var_keyword] = ACTIONS(13415),
    [sym_local_keyword] = ACTIONS(13415),
    [sym_internal_keyword] = ACTIONS(13415),
    [sym_protected_keyword] = ACTIONS(13415),
    [sym_event_keyword] = ACTIONS(13415),
    [sym_fields_keyword] = ACTIONS(13415),
    [sym_keys_keyword] = ACTIONS(13415),
    [sym_fieldgroups_keyword] = ACTIONS(13415),
    [sym_actions_keyword] = ACTIONS(13415),
    [sym_layout_keyword] = ACTIONS(13415),
    [sym_area_keyword] = ACTIONS(13415),
    [sym_group_keyword] = ACTIONS(13415),
    [sym_repeater_keyword] = ACTIONS(13415),
    [sym_cuegroup_keyword] = ACTIONS(13415),
    [sym_fixed_keyword] = ACTIONS(13415),
    [sym_grid_keyword] = ACTIONS(13415),
    [sym_part_keyword] = ACTIONS(13415),
    [sym_systempart_keyword] = ACTIONS(13415),
    [sym_usercontrol_keyword] = ACTIONS(13415),
    [sym_dataset_keyword] = ACTIONS(13415),
    [sym_elements_keyword] = ACTIONS(13415),
    [sym_labels_keyword] = ACTIONS(13415),
    [sym_rendering_keyword] = ACTIONS(13415),
    [sym_requestpage_keyword] = ACTIONS(13415),
    [sym_schema_keyword] = ACTIONS(13415),
    [sym_views_keyword] = ACTIONS(13415),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13415),
    [sym_preproc_open] = ACTIONS(13415),
    [sym_preproc_close] = ACTIONS(13415),
  },
  [STATE(5388)] = {
    [anon_sym_SEMI] = ACTIONS(13419),
    [aux_sym_where_condition_token1] = ACTIONS(13422),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13424),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13424),
    [anon_sym_LBRACK] = ACTIONS(13419),
    [aux_sym_basic_type_token6] = ACTIONS(13422),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13419),
    [aux_sym_addafter_modification_token1] = ACTIONS(13424),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13424),
    [aux_sym_modify_modification_token1] = ACTIONS(13419),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13424),
    [aux_sym_movelast_modification_token1] = ACTIONS(13424),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13424),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13424),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13419),
    [anon_sym_POUNDif] = ACTIONS(13419),
    [anon_sym_POUNDIF] = ACTIONS(13419),
    [anon_sym_POUNDIf] = ACTIONS(13419),
    [anon_sym_POUNDelif] = ACTIONS(13419),
    [anon_sym_POUNDELIF] = ACTIONS(13419),
    [anon_sym_POUNDElif] = ACTIONS(13419),
    [anon_sym_POUNDelse] = ACTIONS(13419),
    [anon_sym_POUNDELSE] = ACTIONS(13419),
    [anon_sym_POUNDElse] = ACTIONS(13419),
    [anon_sym_POUNDelse2] = ACTIONS(13419),
    [anon_sym_POUNDELSE2] = ACTIONS(13419),
    [anon_sym_POUNDElse2] = ACTIONS(13419),
    [anon_sym_POUNDendif] = ACTIONS(13419),
    [anon_sym_POUNDENDIF] = ACTIONS(13419),
    [anon_sym_POUNDEndif] = ACTIONS(13419),
    [anon_sym_POUNDendif2] = ACTIONS(13419),
    [anon_sym_POUNDENDIF2] = ACTIONS(13419),
    [anon_sym_POUNDEndif2] = ACTIONS(13419),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13419),
    [sym_trigger_keyword] = ACTIONS(13419),
    [sym_var_keyword] = ACTIONS(13419),
    [sym_local_keyword] = ACTIONS(13419),
    [sym_internal_keyword] = ACTIONS(13419),
    [sym_protected_keyword] = ACTIONS(13419),
    [sym_event_keyword] = ACTIONS(13419),
    [sym_fields_keyword] = ACTIONS(13419),
    [sym_keys_keyword] = ACTIONS(13419),
    [sym_fieldgroups_keyword] = ACTIONS(13419),
    [sym_actions_keyword] = ACTIONS(13419),
    [sym_layout_keyword] = ACTIONS(13419),
    [sym_area_keyword] = ACTIONS(13424),
    [sym_group_keyword] = ACTIONS(13424),
    [sym_repeater_keyword] = ACTIONS(13424),
    [sym_cuegroup_keyword] = ACTIONS(13424),
    [sym_fixed_keyword] = ACTIONS(13424),
    [sym_grid_keyword] = ACTIONS(13424),
    [sym_part_keyword] = ACTIONS(13424),
    [sym_systempart_keyword] = ACTIONS(13424),
    [sym_usercontrol_keyword] = ACTIONS(13424),
    [sym_dataset_keyword] = ACTIONS(13419),
    [sym_elements_keyword] = ACTIONS(13419),
    [sym_labels_keyword] = ACTIONS(13419),
    [sym_rendering_keyword] = ACTIONS(13419),
    [sym_requestpage_keyword] = ACTIONS(13419),
    [sym_schema_keyword] = ACTIONS(13419),
    [sym_views_keyword] = ACTIONS(13419),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13419),
    [sym_preproc_open] = ACTIONS(13419),
    [sym_preproc_close] = ACTIONS(13419),
  },
  [STATE(5389)] = {
    [anon_sym_SEMI] = ACTIONS(13376),
    [aux_sym_where_condition_token1] = ACTIONS(13426),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13376),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13376),
    [anon_sym_LBRACK] = ACTIONS(13376),
    [aux_sym_basic_type_token6] = ACTIONS(13426),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13376),
    [aux_sym_addafter_modification_token1] = ACTIONS(13376),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13376),
    [aux_sym_modify_modification_token1] = ACTIONS(13376),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13376),
    [aux_sym_movelast_modification_token1] = ACTIONS(13376),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13376),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13376),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13376),
    [anon_sym_POUNDif] = ACTIONS(13376),
    [anon_sym_POUNDIF] = ACTIONS(13376),
    [anon_sym_POUNDIf] = ACTIONS(13376),
    [anon_sym_POUNDelif] = ACTIONS(13376),
    [anon_sym_POUNDELIF] = ACTIONS(13376),
    [anon_sym_POUNDElif] = ACTIONS(13376),
    [anon_sym_POUNDelse] = ACTIONS(13376),
    [anon_sym_POUNDELSE] = ACTIONS(13376),
    [anon_sym_POUNDElse] = ACTIONS(13376),
    [anon_sym_POUNDelse2] = ACTIONS(13376),
    [anon_sym_POUNDELSE2] = ACTIONS(13376),
    [anon_sym_POUNDElse2] = ACTIONS(13376),
    [anon_sym_POUNDendif] = ACTIONS(13376),
    [anon_sym_POUNDENDIF] = ACTIONS(13376),
    [anon_sym_POUNDEndif] = ACTIONS(13376),
    [anon_sym_POUNDendif2] = ACTIONS(13376),
    [anon_sym_POUNDENDIF2] = ACTIONS(13376),
    [anon_sym_POUNDEndif2] = ACTIONS(13376),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13376),
    [sym_trigger_keyword] = ACTIONS(13376),
    [sym_var_keyword] = ACTIONS(13376),
    [sym_local_keyword] = ACTIONS(13376),
    [sym_internal_keyword] = ACTIONS(13376),
    [sym_protected_keyword] = ACTIONS(13376),
    [sym_event_keyword] = ACTIONS(13376),
    [sym_fields_keyword] = ACTIONS(13376),
    [sym_keys_keyword] = ACTIONS(13376),
    [sym_fieldgroups_keyword] = ACTIONS(13376),
    [sym_actions_keyword] = ACTIONS(13376),
    [sym_layout_keyword] = ACTIONS(13376),
    [sym_area_keyword] = ACTIONS(13376),
    [sym_group_keyword] = ACTIONS(13376),
    [sym_repeater_keyword] = ACTIONS(13376),
    [sym_cuegroup_keyword] = ACTIONS(13376),
    [sym_fixed_keyword] = ACTIONS(13376),
    [sym_grid_keyword] = ACTIONS(13376),
    [sym_part_keyword] = ACTIONS(13376),
    [sym_systempart_keyword] = ACTIONS(13376),
    [sym_usercontrol_keyword] = ACTIONS(13376),
    [sym_dataset_keyword] = ACTIONS(13376),
    [sym_elements_keyword] = ACTIONS(13376),
    [sym_labels_keyword] = ACTIONS(13376),
    [sym_rendering_keyword] = ACTIONS(13376),
    [sym_requestpage_keyword] = ACTIONS(13376),
    [sym_schema_keyword] = ACTIONS(13376),
    [sym_views_keyword] = ACTIONS(13376),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13376),
    [sym_preproc_open] = ACTIONS(13376),
    [sym_preproc_close] = ACTIONS(13376),
  },
  [STATE(5390)] = {
    [anon_sym_SEMI] = ACTIONS(13429),
    [aux_sym_where_condition_token1] = ACTIONS(13431),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13429),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13429),
    [anon_sym_LBRACK] = ACTIONS(13429),
    [aux_sym_basic_type_token6] = ACTIONS(13431),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13429),
    [aux_sym_addafter_modification_token1] = ACTIONS(13429),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13429),
    [aux_sym_modify_modification_token1] = ACTIONS(13429),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13429),
    [aux_sym_movelast_modification_token1] = ACTIONS(13429),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13429),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13429),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13429),
    [anon_sym_POUNDif] = ACTIONS(13429),
    [anon_sym_POUNDIF] = ACTIONS(13429),
    [anon_sym_POUNDIf] = ACTIONS(13429),
    [anon_sym_POUNDelif] = ACTIONS(13429),
    [anon_sym_POUNDELIF] = ACTIONS(13429),
    [anon_sym_POUNDElif] = ACTIONS(13429),
    [anon_sym_POUNDelse] = ACTIONS(13429),
    [anon_sym_POUNDELSE] = ACTIONS(13429),
    [anon_sym_POUNDElse] = ACTIONS(13429),
    [anon_sym_POUNDelse2] = ACTIONS(13429),
    [anon_sym_POUNDELSE2] = ACTIONS(13429),
    [anon_sym_POUNDElse2] = ACTIONS(13429),
    [anon_sym_POUNDendif] = ACTIONS(13429),
    [anon_sym_POUNDENDIF] = ACTIONS(13429),
    [anon_sym_POUNDEndif] = ACTIONS(13429),
    [anon_sym_POUNDendif2] = ACTIONS(13429),
    [anon_sym_POUNDENDIF2] = ACTIONS(13429),
    [anon_sym_POUNDEndif2] = ACTIONS(13429),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13429),
    [sym_trigger_keyword] = ACTIONS(13429),
    [sym_var_keyword] = ACTIONS(13429),
    [sym_local_keyword] = ACTIONS(13429),
    [sym_internal_keyword] = ACTIONS(13429),
    [sym_protected_keyword] = ACTIONS(13429),
    [sym_event_keyword] = ACTIONS(13429),
    [sym_fields_keyword] = ACTIONS(13429),
    [sym_keys_keyword] = ACTIONS(13429),
    [sym_fieldgroups_keyword] = ACTIONS(13429),
    [sym_actions_keyword] = ACTIONS(13429),
    [sym_layout_keyword] = ACTIONS(13429),
    [sym_area_keyword] = ACTIONS(13429),
    [sym_group_keyword] = ACTIONS(13429),
    [sym_repeater_keyword] = ACTIONS(13429),
    [sym_cuegroup_keyword] = ACTIONS(13429),
    [sym_fixed_keyword] = ACTIONS(13429),
    [sym_grid_keyword] = ACTIONS(13429),
    [sym_part_keyword] = ACTIONS(13429),
    [sym_systempart_keyword] = ACTIONS(13429),
    [sym_usercontrol_keyword] = ACTIONS(13429),
    [sym_dataset_keyword] = ACTIONS(13429),
    [sym_elements_keyword] = ACTIONS(13429),
    [sym_labels_keyword] = ACTIONS(13429),
    [sym_rendering_keyword] = ACTIONS(13429),
    [sym_requestpage_keyword] = ACTIONS(13429),
    [sym_schema_keyword] = ACTIONS(13429),
    [sym_views_keyword] = ACTIONS(13429),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13429),
    [sym_preproc_open] = ACTIONS(13429),
    [sym_preproc_close] = ACTIONS(13429),
  },
  [STATE(5391)] = {
    [anon_sym_SEMI] = ACTIONS(13433),
    [aux_sym_where_condition_token1] = ACTIONS(13435),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13433),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13433),
    [anon_sym_LBRACK] = ACTIONS(13433),
    [aux_sym_basic_type_token6] = ACTIONS(13435),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13433),
    [aux_sym_addafter_modification_token1] = ACTIONS(13433),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13433),
    [aux_sym_modify_modification_token1] = ACTIONS(13433),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13433),
    [aux_sym_movelast_modification_token1] = ACTIONS(13433),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13433),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13433),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13433),
    [anon_sym_POUNDif] = ACTIONS(13433),
    [anon_sym_POUNDIF] = ACTIONS(13433),
    [anon_sym_POUNDIf] = ACTIONS(13433),
    [anon_sym_POUNDelif] = ACTIONS(13433),
    [anon_sym_POUNDELIF] = ACTIONS(13433),
    [anon_sym_POUNDElif] = ACTIONS(13433),
    [anon_sym_POUNDelse] = ACTIONS(13433),
    [anon_sym_POUNDELSE] = ACTIONS(13433),
    [anon_sym_POUNDElse] = ACTIONS(13433),
    [anon_sym_POUNDelse2] = ACTIONS(13433),
    [anon_sym_POUNDELSE2] = ACTIONS(13433),
    [anon_sym_POUNDElse2] = ACTIONS(13433),
    [anon_sym_POUNDendif] = ACTIONS(13433),
    [anon_sym_POUNDENDIF] = ACTIONS(13433),
    [anon_sym_POUNDEndif] = ACTIONS(13433),
    [anon_sym_POUNDendif2] = ACTIONS(13433),
    [anon_sym_POUNDENDIF2] = ACTIONS(13433),
    [anon_sym_POUNDEndif2] = ACTIONS(13433),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13433),
    [sym_trigger_keyword] = ACTIONS(13433),
    [sym_var_keyword] = ACTIONS(13433),
    [sym_local_keyword] = ACTIONS(13433),
    [sym_internal_keyword] = ACTIONS(13433),
    [sym_protected_keyword] = ACTIONS(13433),
    [sym_event_keyword] = ACTIONS(13433),
    [sym_fields_keyword] = ACTIONS(13433),
    [sym_keys_keyword] = ACTIONS(13433),
    [sym_fieldgroups_keyword] = ACTIONS(13433),
    [sym_actions_keyword] = ACTIONS(13433),
    [sym_layout_keyword] = ACTIONS(13433),
    [sym_area_keyword] = ACTIONS(13433),
    [sym_group_keyword] = ACTIONS(13433),
    [sym_repeater_keyword] = ACTIONS(13433),
    [sym_cuegroup_keyword] = ACTIONS(13433),
    [sym_fixed_keyword] = ACTIONS(13433),
    [sym_grid_keyword] = ACTIONS(13433),
    [sym_part_keyword] = ACTIONS(13433),
    [sym_systempart_keyword] = ACTIONS(13433),
    [sym_usercontrol_keyword] = ACTIONS(13433),
    [sym_dataset_keyword] = ACTIONS(13433),
    [sym_elements_keyword] = ACTIONS(13433),
    [sym_labels_keyword] = ACTIONS(13433),
    [sym_rendering_keyword] = ACTIONS(13433),
    [sym_requestpage_keyword] = ACTIONS(13433),
    [sym_schema_keyword] = ACTIONS(13433),
    [sym_views_keyword] = ACTIONS(13433),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13433),
    [sym_preproc_open] = ACTIONS(13433),
    [sym_preproc_close] = ACTIONS(13433),
  },
  [STATE(5392)] = {
    [anon_sym_SEMI] = ACTIONS(13437),
    [aux_sym_where_condition_token1] = ACTIONS(13439),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13437),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13437),
    [anon_sym_LBRACK] = ACTIONS(13437),
    [aux_sym_basic_type_token6] = ACTIONS(13439),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13437),
    [aux_sym_addafter_modification_token1] = ACTIONS(13437),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13437),
    [aux_sym_modify_modification_token1] = ACTIONS(13437),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13437),
    [aux_sym_movelast_modification_token1] = ACTIONS(13437),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13437),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13437),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13437),
    [anon_sym_POUNDif] = ACTIONS(13437),
    [anon_sym_POUNDIF] = ACTIONS(13437),
    [anon_sym_POUNDIf] = ACTIONS(13437),
    [anon_sym_POUNDelif] = ACTIONS(13437),
    [anon_sym_POUNDELIF] = ACTIONS(13437),
    [anon_sym_POUNDElif] = ACTIONS(13437),
    [anon_sym_POUNDelse] = ACTIONS(13437),
    [anon_sym_POUNDELSE] = ACTIONS(13437),
    [anon_sym_POUNDElse] = ACTIONS(13437),
    [anon_sym_POUNDelse2] = ACTIONS(13437),
    [anon_sym_POUNDELSE2] = ACTIONS(13437),
    [anon_sym_POUNDElse2] = ACTIONS(13437),
    [anon_sym_POUNDendif] = ACTIONS(13437),
    [anon_sym_POUNDENDIF] = ACTIONS(13437),
    [anon_sym_POUNDEndif] = ACTIONS(13437),
    [anon_sym_POUNDendif2] = ACTIONS(13437),
    [anon_sym_POUNDENDIF2] = ACTIONS(13437),
    [anon_sym_POUNDEndif2] = ACTIONS(13437),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13437),
    [sym_trigger_keyword] = ACTIONS(13437),
    [sym_var_keyword] = ACTIONS(13437),
    [sym_local_keyword] = ACTIONS(13437),
    [sym_internal_keyword] = ACTIONS(13437),
    [sym_protected_keyword] = ACTIONS(13437),
    [sym_event_keyword] = ACTIONS(13437),
    [sym_fields_keyword] = ACTIONS(13437),
    [sym_keys_keyword] = ACTIONS(13437),
    [sym_fieldgroups_keyword] = ACTIONS(13437),
    [sym_actions_keyword] = ACTIONS(13437),
    [sym_layout_keyword] = ACTIONS(13437),
    [sym_area_keyword] = ACTIONS(13437),
    [sym_group_keyword] = ACTIONS(13437),
    [sym_repeater_keyword] = ACTIONS(13437),
    [sym_cuegroup_keyword] = ACTIONS(13437),
    [sym_fixed_keyword] = ACTIONS(13437),
    [sym_grid_keyword] = ACTIONS(13437),
    [sym_part_keyword] = ACTIONS(13437),
    [sym_systempart_keyword] = ACTIONS(13437),
    [sym_usercontrol_keyword] = ACTIONS(13437),
    [sym_dataset_keyword] = ACTIONS(13437),
    [sym_elements_keyword] = ACTIONS(13437),
    [sym_labels_keyword] = ACTIONS(13437),
    [sym_rendering_keyword] = ACTIONS(13437),
    [sym_requestpage_keyword] = ACTIONS(13437),
    [sym_schema_keyword] = ACTIONS(13437),
    [sym_views_keyword] = ACTIONS(13437),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13437),
    [sym_preproc_open] = ACTIONS(13437),
    [sym_preproc_close] = ACTIONS(13437),
  },
  [STATE(5393)] = {
    [anon_sym_SEMI] = ACTIONS(13441),
    [aux_sym_where_condition_token1] = ACTIONS(13443),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13441),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13441),
    [anon_sym_LBRACK] = ACTIONS(13441),
    [aux_sym_basic_type_token6] = ACTIONS(13443),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13441),
    [aux_sym_addafter_modification_token1] = ACTIONS(13441),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13441),
    [aux_sym_modify_modification_token1] = ACTIONS(13441),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13441),
    [aux_sym_movelast_modification_token1] = ACTIONS(13441),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13441),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13441),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13441),
    [anon_sym_POUNDif] = ACTIONS(13441),
    [anon_sym_POUNDIF] = ACTIONS(13441),
    [anon_sym_POUNDIf] = ACTIONS(13441),
    [anon_sym_POUNDelif] = ACTIONS(13441),
    [anon_sym_POUNDELIF] = ACTIONS(13441),
    [anon_sym_POUNDElif] = ACTIONS(13441),
    [anon_sym_POUNDelse] = ACTIONS(13441),
    [anon_sym_POUNDELSE] = ACTIONS(13441),
    [anon_sym_POUNDElse] = ACTIONS(13441),
    [anon_sym_POUNDelse2] = ACTIONS(13441),
    [anon_sym_POUNDELSE2] = ACTIONS(13441),
    [anon_sym_POUNDElse2] = ACTIONS(13441),
    [anon_sym_POUNDendif] = ACTIONS(13441),
    [anon_sym_POUNDENDIF] = ACTIONS(13441),
    [anon_sym_POUNDEndif] = ACTIONS(13441),
    [anon_sym_POUNDendif2] = ACTIONS(13441),
    [anon_sym_POUNDENDIF2] = ACTIONS(13441),
    [anon_sym_POUNDEndif2] = ACTIONS(13441),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13441),
    [sym_trigger_keyword] = ACTIONS(13441),
    [sym_var_keyword] = ACTIONS(13441),
    [sym_local_keyword] = ACTIONS(13441),
    [sym_internal_keyword] = ACTIONS(13441),
    [sym_protected_keyword] = ACTIONS(13441),
    [sym_event_keyword] = ACTIONS(13441),
    [sym_fields_keyword] = ACTIONS(13441),
    [sym_keys_keyword] = ACTIONS(13441),
    [sym_fieldgroups_keyword] = ACTIONS(13441),
    [sym_actions_keyword] = ACTIONS(13441),
    [sym_layout_keyword] = ACTIONS(13441),
    [sym_area_keyword] = ACTIONS(13441),
    [sym_group_keyword] = ACTIONS(13441),
    [sym_repeater_keyword] = ACTIONS(13441),
    [sym_cuegroup_keyword] = ACTIONS(13441),
    [sym_fixed_keyword] = ACTIONS(13441),
    [sym_grid_keyword] = ACTIONS(13441),
    [sym_part_keyword] = ACTIONS(13441),
    [sym_systempart_keyword] = ACTIONS(13441),
    [sym_usercontrol_keyword] = ACTIONS(13441),
    [sym_dataset_keyword] = ACTIONS(13441),
    [sym_elements_keyword] = ACTIONS(13441),
    [sym_labels_keyword] = ACTIONS(13441),
    [sym_rendering_keyword] = ACTIONS(13441),
    [sym_requestpage_keyword] = ACTIONS(13441),
    [sym_schema_keyword] = ACTIONS(13441),
    [sym_views_keyword] = ACTIONS(13441),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13441),
    [sym_preproc_open] = ACTIONS(13441),
    [sym_preproc_close] = ACTIONS(13441),
  },
  [STATE(5394)] = {
    [anon_sym_SEMI] = ACTIONS(13445),
    [aux_sym_where_condition_token1] = ACTIONS(13447),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13445),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13445),
    [anon_sym_LBRACK] = ACTIONS(13445),
    [aux_sym_basic_type_token6] = ACTIONS(13447),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13445),
    [aux_sym_addafter_modification_token1] = ACTIONS(13445),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13445),
    [aux_sym_modify_modification_token1] = ACTIONS(13445),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13445),
    [aux_sym_movelast_modification_token1] = ACTIONS(13445),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13445),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13445),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13445),
    [anon_sym_POUNDif] = ACTIONS(13445),
    [anon_sym_POUNDIF] = ACTIONS(13445),
    [anon_sym_POUNDIf] = ACTIONS(13445),
    [anon_sym_POUNDelif] = ACTIONS(13445),
    [anon_sym_POUNDELIF] = ACTIONS(13445),
    [anon_sym_POUNDElif] = ACTIONS(13445),
    [anon_sym_POUNDelse] = ACTIONS(13445),
    [anon_sym_POUNDELSE] = ACTIONS(13445),
    [anon_sym_POUNDElse] = ACTIONS(13445),
    [anon_sym_POUNDelse2] = ACTIONS(13445),
    [anon_sym_POUNDELSE2] = ACTIONS(13445),
    [anon_sym_POUNDElse2] = ACTIONS(13445),
    [anon_sym_POUNDendif] = ACTIONS(13445),
    [anon_sym_POUNDENDIF] = ACTIONS(13445),
    [anon_sym_POUNDEndif] = ACTIONS(13445),
    [anon_sym_POUNDendif2] = ACTIONS(13445),
    [anon_sym_POUNDENDIF2] = ACTIONS(13445),
    [anon_sym_POUNDEndif2] = ACTIONS(13445),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13445),
    [sym_trigger_keyword] = ACTIONS(13445),
    [sym_var_keyword] = ACTIONS(13445),
    [sym_local_keyword] = ACTIONS(13445),
    [sym_internal_keyword] = ACTIONS(13445),
    [sym_protected_keyword] = ACTIONS(13445),
    [sym_event_keyword] = ACTIONS(13445),
    [sym_fields_keyword] = ACTIONS(13445),
    [sym_keys_keyword] = ACTIONS(13445),
    [sym_fieldgroups_keyword] = ACTIONS(13445),
    [sym_actions_keyword] = ACTIONS(13445),
    [sym_layout_keyword] = ACTIONS(13445),
    [sym_area_keyword] = ACTIONS(13445),
    [sym_group_keyword] = ACTIONS(13445),
    [sym_repeater_keyword] = ACTIONS(13445),
    [sym_cuegroup_keyword] = ACTIONS(13445),
    [sym_fixed_keyword] = ACTIONS(13445),
    [sym_grid_keyword] = ACTIONS(13445),
    [sym_part_keyword] = ACTIONS(13445),
    [sym_systempart_keyword] = ACTIONS(13445),
    [sym_usercontrol_keyword] = ACTIONS(13445),
    [sym_dataset_keyword] = ACTIONS(13445),
    [sym_elements_keyword] = ACTIONS(13445),
    [sym_labels_keyword] = ACTIONS(13445),
    [sym_rendering_keyword] = ACTIONS(13445),
    [sym_requestpage_keyword] = ACTIONS(13445),
    [sym_schema_keyword] = ACTIONS(13445),
    [sym_views_keyword] = ACTIONS(13445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13445),
    [sym_preproc_open] = ACTIONS(13445),
    [sym_preproc_close] = ACTIONS(13445),
  },
  [STATE(5395)] = {
    [anon_sym_SEMI] = ACTIONS(13449),
    [aux_sym_where_condition_token1] = ACTIONS(13451),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13449),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13449),
    [anon_sym_LBRACK] = ACTIONS(13449),
    [aux_sym_basic_type_token6] = ACTIONS(13451),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13449),
    [aux_sym_addafter_modification_token1] = ACTIONS(13449),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13449),
    [aux_sym_modify_modification_token1] = ACTIONS(13449),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13449),
    [aux_sym_movelast_modification_token1] = ACTIONS(13449),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13449),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13449),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13449),
    [anon_sym_POUNDif] = ACTIONS(13449),
    [anon_sym_POUNDIF] = ACTIONS(13449),
    [anon_sym_POUNDIf] = ACTIONS(13449),
    [anon_sym_POUNDelif] = ACTIONS(13449),
    [anon_sym_POUNDELIF] = ACTIONS(13449),
    [anon_sym_POUNDElif] = ACTIONS(13449),
    [anon_sym_POUNDelse] = ACTIONS(13449),
    [anon_sym_POUNDELSE] = ACTIONS(13449),
    [anon_sym_POUNDElse] = ACTIONS(13449),
    [anon_sym_POUNDelse2] = ACTIONS(13449),
    [anon_sym_POUNDELSE2] = ACTIONS(13449),
    [anon_sym_POUNDElse2] = ACTIONS(13449),
    [anon_sym_POUNDendif] = ACTIONS(13449),
    [anon_sym_POUNDENDIF] = ACTIONS(13449),
    [anon_sym_POUNDEndif] = ACTIONS(13449),
    [anon_sym_POUNDendif2] = ACTIONS(13449),
    [anon_sym_POUNDENDIF2] = ACTIONS(13449),
    [anon_sym_POUNDEndif2] = ACTIONS(13449),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13449),
    [sym_trigger_keyword] = ACTIONS(13449),
    [sym_var_keyword] = ACTIONS(13449),
    [sym_local_keyword] = ACTIONS(13449),
    [sym_internal_keyword] = ACTIONS(13449),
    [sym_protected_keyword] = ACTIONS(13449),
    [sym_event_keyword] = ACTIONS(13449),
    [sym_fields_keyword] = ACTIONS(13449),
    [sym_keys_keyword] = ACTIONS(13449),
    [sym_fieldgroups_keyword] = ACTIONS(13449),
    [sym_actions_keyword] = ACTIONS(13449),
    [sym_layout_keyword] = ACTIONS(13449),
    [sym_area_keyword] = ACTIONS(13449),
    [sym_group_keyword] = ACTIONS(13449),
    [sym_repeater_keyword] = ACTIONS(13449),
    [sym_cuegroup_keyword] = ACTIONS(13449),
    [sym_fixed_keyword] = ACTIONS(13449),
    [sym_grid_keyword] = ACTIONS(13449),
    [sym_part_keyword] = ACTIONS(13449),
    [sym_systempart_keyword] = ACTIONS(13449),
    [sym_usercontrol_keyword] = ACTIONS(13449),
    [sym_dataset_keyword] = ACTIONS(13449),
    [sym_elements_keyword] = ACTIONS(13449),
    [sym_labels_keyword] = ACTIONS(13449),
    [sym_rendering_keyword] = ACTIONS(13449),
    [sym_requestpage_keyword] = ACTIONS(13449),
    [sym_schema_keyword] = ACTIONS(13449),
    [sym_views_keyword] = ACTIONS(13449),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13449),
    [sym_preproc_open] = ACTIONS(13449),
    [sym_preproc_close] = ACTIONS(13449),
  },
  [STATE(5396)] = {
    [anon_sym_SEMI] = ACTIONS(13453),
    [aux_sym_where_condition_token1] = ACTIONS(13455),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13453),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13453),
    [anon_sym_LBRACK] = ACTIONS(13453),
    [aux_sym_basic_type_token6] = ACTIONS(13455),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13453),
    [aux_sym_addafter_modification_token1] = ACTIONS(13453),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13453),
    [aux_sym_modify_modification_token1] = ACTIONS(13453),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13453),
    [aux_sym_movelast_modification_token1] = ACTIONS(13453),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13453),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13453),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13453),
    [anon_sym_POUNDif] = ACTIONS(13453),
    [anon_sym_POUNDIF] = ACTIONS(13453),
    [anon_sym_POUNDIf] = ACTIONS(13453),
    [anon_sym_POUNDelif] = ACTIONS(13453),
    [anon_sym_POUNDELIF] = ACTIONS(13453),
    [anon_sym_POUNDElif] = ACTIONS(13453),
    [anon_sym_POUNDelse] = ACTIONS(13453),
    [anon_sym_POUNDELSE] = ACTIONS(13453),
    [anon_sym_POUNDElse] = ACTIONS(13453),
    [anon_sym_POUNDelse2] = ACTIONS(13453),
    [anon_sym_POUNDELSE2] = ACTIONS(13453),
    [anon_sym_POUNDElse2] = ACTIONS(13453),
    [anon_sym_POUNDendif] = ACTIONS(13453),
    [anon_sym_POUNDENDIF] = ACTIONS(13453),
    [anon_sym_POUNDEndif] = ACTIONS(13453),
    [anon_sym_POUNDendif2] = ACTIONS(13453),
    [anon_sym_POUNDENDIF2] = ACTIONS(13453),
    [anon_sym_POUNDEndif2] = ACTIONS(13453),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13453),
    [sym_trigger_keyword] = ACTIONS(13453),
    [sym_var_keyword] = ACTIONS(13453),
    [sym_local_keyword] = ACTIONS(13453),
    [sym_internal_keyword] = ACTIONS(13453),
    [sym_protected_keyword] = ACTIONS(13453),
    [sym_event_keyword] = ACTIONS(13453),
    [sym_fields_keyword] = ACTIONS(13453),
    [sym_keys_keyword] = ACTIONS(13453),
    [sym_fieldgroups_keyword] = ACTIONS(13453),
    [sym_actions_keyword] = ACTIONS(13453),
    [sym_layout_keyword] = ACTIONS(13453),
    [sym_area_keyword] = ACTIONS(13453),
    [sym_group_keyword] = ACTIONS(13453),
    [sym_repeater_keyword] = ACTIONS(13453),
    [sym_cuegroup_keyword] = ACTIONS(13453),
    [sym_fixed_keyword] = ACTIONS(13453),
    [sym_grid_keyword] = ACTIONS(13453),
    [sym_part_keyword] = ACTIONS(13453),
    [sym_systempart_keyword] = ACTIONS(13453),
    [sym_usercontrol_keyword] = ACTIONS(13453),
    [sym_dataset_keyword] = ACTIONS(13453),
    [sym_elements_keyword] = ACTIONS(13453),
    [sym_labels_keyword] = ACTIONS(13453),
    [sym_rendering_keyword] = ACTIONS(13453),
    [sym_requestpage_keyword] = ACTIONS(13453),
    [sym_schema_keyword] = ACTIONS(13453),
    [sym_views_keyword] = ACTIONS(13453),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13453),
    [sym_preproc_open] = ACTIONS(13453),
    [sym_preproc_close] = ACTIONS(13453),
  },
  [STATE(5397)] = {
    [anon_sym_SEMI] = ACTIONS(13457),
    [aux_sym_where_condition_token1] = ACTIONS(13459),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13457),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13457),
    [anon_sym_LBRACK] = ACTIONS(13457),
    [aux_sym_basic_type_token6] = ACTIONS(13459),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13457),
    [aux_sym_addafter_modification_token1] = ACTIONS(13457),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13457),
    [aux_sym_modify_modification_token1] = ACTIONS(13457),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13457),
    [aux_sym_movelast_modification_token1] = ACTIONS(13457),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13457),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13457),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13457),
    [anon_sym_POUNDif] = ACTIONS(13457),
    [anon_sym_POUNDIF] = ACTIONS(13457),
    [anon_sym_POUNDIf] = ACTIONS(13457),
    [anon_sym_POUNDelif] = ACTIONS(13457),
    [anon_sym_POUNDELIF] = ACTIONS(13457),
    [anon_sym_POUNDElif] = ACTIONS(13457),
    [anon_sym_POUNDelse] = ACTIONS(13457),
    [anon_sym_POUNDELSE] = ACTIONS(13457),
    [anon_sym_POUNDElse] = ACTIONS(13457),
    [anon_sym_POUNDelse2] = ACTIONS(13457),
    [anon_sym_POUNDELSE2] = ACTIONS(13457),
    [anon_sym_POUNDElse2] = ACTIONS(13457),
    [anon_sym_POUNDendif] = ACTIONS(13457),
    [anon_sym_POUNDENDIF] = ACTIONS(13457),
    [anon_sym_POUNDEndif] = ACTIONS(13457),
    [anon_sym_POUNDendif2] = ACTIONS(13457),
    [anon_sym_POUNDENDIF2] = ACTIONS(13457),
    [anon_sym_POUNDEndif2] = ACTIONS(13457),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13457),
    [sym_trigger_keyword] = ACTIONS(13457),
    [sym_var_keyword] = ACTIONS(13457),
    [sym_local_keyword] = ACTIONS(13457),
    [sym_internal_keyword] = ACTIONS(13457),
    [sym_protected_keyword] = ACTIONS(13457),
    [sym_event_keyword] = ACTIONS(13457),
    [sym_fields_keyword] = ACTIONS(13457),
    [sym_keys_keyword] = ACTIONS(13457),
    [sym_fieldgroups_keyword] = ACTIONS(13457),
    [sym_actions_keyword] = ACTIONS(13457),
    [sym_layout_keyword] = ACTIONS(13457),
    [sym_area_keyword] = ACTIONS(13457),
    [sym_group_keyword] = ACTIONS(13457),
    [sym_repeater_keyword] = ACTIONS(13457),
    [sym_cuegroup_keyword] = ACTIONS(13457),
    [sym_fixed_keyword] = ACTIONS(13457),
    [sym_grid_keyword] = ACTIONS(13457),
    [sym_part_keyword] = ACTIONS(13457),
    [sym_systempart_keyword] = ACTIONS(13457),
    [sym_usercontrol_keyword] = ACTIONS(13457),
    [sym_dataset_keyword] = ACTIONS(13457),
    [sym_elements_keyword] = ACTIONS(13457),
    [sym_labels_keyword] = ACTIONS(13457),
    [sym_rendering_keyword] = ACTIONS(13457),
    [sym_requestpage_keyword] = ACTIONS(13457),
    [sym_schema_keyword] = ACTIONS(13457),
    [sym_views_keyword] = ACTIONS(13457),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13457),
    [sym_preproc_open] = ACTIONS(13457),
    [sym_preproc_close] = ACTIONS(13457),
  },
  [STATE(5398)] = {
    [anon_sym_SEMI] = ACTIONS(13461),
    [aux_sym_where_condition_token1] = ACTIONS(13463),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13461),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13461),
    [anon_sym_LBRACK] = ACTIONS(13461),
    [aux_sym_basic_type_token6] = ACTIONS(13463),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13461),
    [aux_sym_addafter_modification_token1] = ACTIONS(13461),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13461),
    [aux_sym_modify_modification_token1] = ACTIONS(13461),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13461),
    [aux_sym_movelast_modification_token1] = ACTIONS(13461),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13461),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13461),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13461),
    [anon_sym_POUNDif] = ACTIONS(13461),
    [anon_sym_POUNDIF] = ACTIONS(13461),
    [anon_sym_POUNDIf] = ACTIONS(13461),
    [anon_sym_POUNDelif] = ACTIONS(13461),
    [anon_sym_POUNDELIF] = ACTIONS(13461),
    [anon_sym_POUNDElif] = ACTIONS(13461),
    [anon_sym_POUNDelse] = ACTIONS(13461),
    [anon_sym_POUNDELSE] = ACTIONS(13461),
    [anon_sym_POUNDElse] = ACTIONS(13461),
    [anon_sym_POUNDelse2] = ACTIONS(13461),
    [anon_sym_POUNDELSE2] = ACTIONS(13461),
    [anon_sym_POUNDElse2] = ACTIONS(13461),
    [anon_sym_POUNDendif] = ACTIONS(13461),
    [anon_sym_POUNDENDIF] = ACTIONS(13461),
    [anon_sym_POUNDEndif] = ACTIONS(13461),
    [anon_sym_POUNDendif2] = ACTIONS(13461),
    [anon_sym_POUNDENDIF2] = ACTIONS(13461),
    [anon_sym_POUNDEndif2] = ACTIONS(13461),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13461),
    [sym_trigger_keyword] = ACTIONS(13461),
    [sym_var_keyword] = ACTIONS(13461),
    [sym_local_keyword] = ACTIONS(13461),
    [sym_internal_keyword] = ACTIONS(13461),
    [sym_protected_keyword] = ACTIONS(13461),
    [sym_event_keyword] = ACTIONS(13461),
    [sym_fields_keyword] = ACTIONS(13461),
    [sym_keys_keyword] = ACTIONS(13461),
    [sym_fieldgroups_keyword] = ACTIONS(13461),
    [sym_actions_keyword] = ACTIONS(13461),
    [sym_layout_keyword] = ACTIONS(13461),
    [sym_area_keyword] = ACTIONS(13461),
    [sym_group_keyword] = ACTIONS(13461),
    [sym_repeater_keyword] = ACTIONS(13461),
    [sym_cuegroup_keyword] = ACTIONS(13461),
    [sym_fixed_keyword] = ACTIONS(13461),
    [sym_grid_keyword] = ACTIONS(13461),
    [sym_part_keyword] = ACTIONS(13461),
    [sym_systempart_keyword] = ACTIONS(13461),
    [sym_usercontrol_keyword] = ACTIONS(13461),
    [sym_dataset_keyword] = ACTIONS(13461),
    [sym_elements_keyword] = ACTIONS(13461),
    [sym_labels_keyword] = ACTIONS(13461),
    [sym_rendering_keyword] = ACTIONS(13461),
    [sym_requestpage_keyword] = ACTIONS(13461),
    [sym_schema_keyword] = ACTIONS(13461),
    [sym_views_keyword] = ACTIONS(13461),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13461),
    [sym_preproc_open] = ACTIONS(13461),
    [sym_preproc_close] = ACTIONS(13461),
  },
  [STATE(5399)] = {
    [anon_sym_SEMI] = ACTIONS(13465),
    [aux_sym_where_condition_token1] = ACTIONS(13467),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13465),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13465),
    [anon_sym_LBRACK] = ACTIONS(13465),
    [aux_sym_basic_type_token6] = ACTIONS(13467),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13465),
    [aux_sym_addafter_modification_token1] = ACTIONS(13465),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13465),
    [aux_sym_modify_modification_token1] = ACTIONS(13465),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13465),
    [aux_sym_movelast_modification_token1] = ACTIONS(13465),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13465),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13465),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13465),
    [anon_sym_POUNDif] = ACTIONS(13465),
    [anon_sym_POUNDIF] = ACTIONS(13465),
    [anon_sym_POUNDIf] = ACTIONS(13465),
    [anon_sym_POUNDelif] = ACTIONS(13465),
    [anon_sym_POUNDELIF] = ACTIONS(13465),
    [anon_sym_POUNDElif] = ACTIONS(13465),
    [anon_sym_POUNDelse] = ACTIONS(13465),
    [anon_sym_POUNDELSE] = ACTIONS(13465),
    [anon_sym_POUNDElse] = ACTIONS(13465),
    [anon_sym_POUNDelse2] = ACTIONS(13465),
    [anon_sym_POUNDELSE2] = ACTIONS(13465),
    [anon_sym_POUNDElse2] = ACTIONS(13465),
    [anon_sym_POUNDendif] = ACTIONS(13465),
    [anon_sym_POUNDENDIF] = ACTIONS(13465),
    [anon_sym_POUNDEndif] = ACTIONS(13465),
    [anon_sym_POUNDendif2] = ACTIONS(13465),
    [anon_sym_POUNDENDIF2] = ACTIONS(13465),
    [anon_sym_POUNDEndif2] = ACTIONS(13465),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13465),
    [sym_trigger_keyword] = ACTIONS(13465),
    [sym_var_keyword] = ACTIONS(13465),
    [sym_local_keyword] = ACTIONS(13465),
    [sym_internal_keyword] = ACTIONS(13465),
    [sym_protected_keyword] = ACTIONS(13465),
    [sym_event_keyword] = ACTIONS(13465),
    [sym_fields_keyword] = ACTIONS(13465),
    [sym_keys_keyword] = ACTIONS(13465),
    [sym_fieldgroups_keyword] = ACTIONS(13465),
    [sym_actions_keyword] = ACTIONS(13465),
    [sym_layout_keyword] = ACTIONS(13465),
    [sym_area_keyword] = ACTIONS(13465),
    [sym_group_keyword] = ACTIONS(13465),
    [sym_repeater_keyword] = ACTIONS(13465),
    [sym_cuegroup_keyword] = ACTIONS(13465),
    [sym_fixed_keyword] = ACTIONS(13465),
    [sym_grid_keyword] = ACTIONS(13465),
    [sym_part_keyword] = ACTIONS(13465),
    [sym_systempart_keyword] = ACTIONS(13465),
    [sym_usercontrol_keyword] = ACTIONS(13465),
    [sym_dataset_keyword] = ACTIONS(13465),
    [sym_elements_keyword] = ACTIONS(13465),
    [sym_labels_keyword] = ACTIONS(13465),
    [sym_rendering_keyword] = ACTIONS(13465),
    [sym_requestpage_keyword] = ACTIONS(13465),
    [sym_schema_keyword] = ACTIONS(13465),
    [sym_views_keyword] = ACTIONS(13465),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13465),
    [sym_preproc_open] = ACTIONS(13465),
    [sym_preproc_close] = ACTIONS(13465),
  },
  [STATE(5400)] = {
    [anon_sym_SEMI] = ACTIONS(13469),
    [aux_sym_where_condition_token1] = ACTIONS(13471),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13469),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13469),
    [anon_sym_LBRACK] = ACTIONS(13469),
    [aux_sym_basic_type_token6] = ACTIONS(13471),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13469),
    [aux_sym_addafter_modification_token1] = ACTIONS(13469),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13469),
    [aux_sym_modify_modification_token1] = ACTIONS(13469),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13469),
    [aux_sym_movelast_modification_token1] = ACTIONS(13469),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13469),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13469),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13469),
    [anon_sym_POUNDif] = ACTIONS(13469),
    [anon_sym_POUNDIF] = ACTIONS(13469),
    [anon_sym_POUNDIf] = ACTIONS(13469),
    [anon_sym_POUNDelif] = ACTIONS(13469),
    [anon_sym_POUNDELIF] = ACTIONS(13469),
    [anon_sym_POUNDElif] = ACTIONS(13469),
    [anon_sym_POUNDelse] = ACTIONS(13469),
    [anon_sym_POUNDELSE] = ACTIONS(13469),
    [anon_sym_POUNDElse] = ACTIONS(13469),
    [anon_sym_POUNDelse2] = ACTIONS(13469),
    [anon_sym_POUNDELSE2] = ACTIONS(13469),
    [anon_sym_POUNDElse2] = ACTIONS(13469),
    [anon_sym_POUNDendif] = ACTIONS(13469),
    [anon_sym_POUNDENDIF] = ACTIONS(13469),
    [anon_sym_POUNDEndif] = ACTIONS(13469),
    [anon_sym_POUNDendif2] = ACTIONS(13469),
    [anon_sym_POUNDENDIF2] = ACTIONS(13469),
    [anon_sym_POUNDEndif2] = ACTIONS(13469),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13469),
    [sym_trigger_keyword] = ACTIONS(13469),
    [sym_var_keyword] = ACTIONS(13469),
    [sym_local_keyword] = ACTIONS(13469),
    [sym_internal_keyword] = ACTIONS(13469),
    [sym_protected_keyword] = ACTIONS(13469),
    [sym_event_keyword] = ACTIONS(13469),
    [sym_fields_keyword] = ACTIONS(13469),
    [sym_keys_keyword] = ACTIONS(13469),
    [sym_fieldgroups_keyword] = ACTIONS(13469),
    [sym_actions_keyword] = ACTIONS(13469),
    [sym_layout_keyword] = ACTIONS(13469),
    [sym_area_keyword] = ACTIONS(13469),
    [sym_group_keyword] = ACTIONS(13469),
    [sym_repeater_keyword] = ACTIONS(13469),
    [sym_cuegroup_keyword] = ACTIONS(13469),
    [sym_fixed_keyword] = ACTIONS(13469),
    [sym_grid_keyword] = ACTIONS(13469),
    [sym_part_keyword] = ACTIONS(13469),
    [sym_systempart_keyword] = ACTIONS(13469),
    [sym_usercontrol_keyword] = ACTIONS(13469),
    [sym_dataset_keyword] = ACTIONS(13469),
    [sym_elements_keyword] = ACTIONS(13469),
    [sym_labels_keyword] = ACTIONS(13469),
    [sym_rendering_keyword] = ACTIONS(13469),
    [sym_requestpage_keyword] = ACTIONS(13469),
    [sym_schema_keyword] = ACTIONS(13469),
    [sym_views_keyword] = ACTIONS(13469),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13469),
    [sym_preproc_open] = ACTIONS(13469),
    [sym_preproc_close] = ACTIONS(13469),
  },
  [STATE(5401)] = {
    [anon_sym_SEMI] = ACTIONS(13473),
    [aux_sym_where_condition_token1] = ACTIONS(13475),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13473),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13473),
    [anon_sym_LBRACK] = ACTIONS(13473),
    [aux_sym_basic_type_token6] = ACTIONS(13475),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13473),
    [aux_sym_addafter_modification_token1] = ACTIONS(13473),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13473),
    [aux_sym_modify_modification_token1] = ACTIONS(13473),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13473),
    [aux_sym_movelast_modification_token1] = ACTIONS(13473),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13473),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13473),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13473),
    [anon_sym_POUNDif] = ACTIONS(13473),
    [anon_sym_POUNDIF] = ACTIONS(13473),
    [anon_sym_POUNDIf] = ACTIONS(13473),
    [anon_sym_POUNDelif] = ACTIONS(13473),
    [anon_sym_POUNDELIF] = ACTIONS(13473),
    [anon_sym_POUNDElif] = ACTIONS(13473),
    [anon_sym_POUNDelse] = ACTIONS(13473),
    [anon_sym_POUNDELSE] = ACTIONS(13473),
    [anon_sym_POUNDElse] = ACTIONS(13473),
    [anon_sym_POUNDelse2] = ACTIONS(13473),
    [anon_sym_POUNDELSE2] = ACTIONS(13473),
    [anon_sym_POUNDElse2] = ACTIONS(13473),
    [anon_sym_POUNDendif] = ACTIONS(13473),
    [anon_sym_POUNDENDIF] = ACTIONS(13473),
    [anon_sym_POUNDEndif] = ACTIONS(13473),
    [anon_sym_POUNDendif2] = ACTIONS(13473),
    [anon_sym_POUNDENDIF2] = ACTIONS(13473),
    [anon_sym_POUNDEndif2] = ACTIONS(13473),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13473),
    [sym_trigger_keyword] = ACTIONS(13473),
    [sym_var_keyword] = ACTIONS(13473),
    [sym_local_keyword] = ACTIONS(13473),
    [sym_internal_keyword] = ACTIONS(13473),
    [sym_protected_keyword] = ACTIONS(13473),
    [sym_event_keyword] = ACTIONS(13473),
    [sym_fields_keyword] = ACTIONS(13473),
    [sym_keys_keyword] = ACTIONS(13473),
    [sym_fieldgroups_keyword] = ACTIONS(13473),
    [sym_actions_keyword] = ACTIONS(13473),
    [sym_layout_keyword] = ACTIONS(13473),
    [sym_area_keyword] = ACTIONS(13473),
    [sym_group_keyword] = ACTIONS(13473),
    [sym_repeater_keyword] = ACTIONS(13473),
    [sym_cuegroup_keyword] = ACTIONS(13473),
    [sym_fixed_keyword] = ACTIONS(13473),
    [sym_grid_keyword] = ACTIONS(13473),
    [sym_part_keyword] = ACTIONS(13473),
    [sym_systempart_keyword] = ACTIONS(13473),
    [sym_usercontrol_keyword] = ACTIONS(13473),
    [sym_dataset_keyword] = ACTIONS(13473),
    [sym_elements_keyword] = ACTIONS(13473),
    [sym_labels_keyword] = ACTIONS(13473),
    [sym_rendering_keyword] = ACTIONS(13473),
    [sym_requestpage_keyword] = ACTIONS(13473),
    [sym_schema_keyword] = ACTIONS(13473),
    [sym_views_keyword] = ACTIONS(13473),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13473),
    [sym_preproc_open] = ACTIONS(13473),
    [sym_preproc_close] = ACTIONS(13473),
  },
  [STATE(5402)] = {
    [anon_sym_SEMI] = ACTIONS(12802),
    [aux_sym_where_condition_token1] = ACTIONS(13477),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13479),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13479),
    [anon_sym_LBRACK] = ACTIONS(12802),
    [aux_sym_basic_type_token6] = ACTIONS(13477),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(12802),
    [aux_sym_addafter_modification_token1] = ACTIONS(13479),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13479),
    [aux_sym_modify_modification_token1] = ACTIONS(13481),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13479),
    [aux_sym_movelast_modification_token1] = ACTIONS(13479),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13479),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13479),
    [aux_sym_assembly_declaration_token1] = ACTIONS(12802),
    [anon_sym_POUNDif] = ACTIONS(13481),
    [anon_sym_POUNDIF] = ACTIONS(13481),
    [anon_sym_POUNDIf] = ACTIONS(13481),
    [anon_sym_POUNDelif] = ACTIONS(13481),
    [anon_sym_POUNDELIF] = ACTIONS(13481),
    [anon_sym_POUNDElif] = ACTIONS(13481),
    [anon_sym_POUNDelse] = ACTIONS(13481),
    [anon_sym_POUNDELSE] = ACTIONS(13481),
    [anon_sym_POUNDElse] = ACTIONS(13481),
    [anon_sym_POUNDelse2] = ACTIONS(13481),
    [anon_sym_POUNDELSE2] = ACTIONS(13481),
    [anon_sym_POUNDElse2] = ACTIONS(13481),
    [anon_sym_POUNDendif] = ACTIONS(13481),
    [anon_sym_POUNDENDIF] = ACTIONS(13481),
    [anon_sym_POUNDEndif] = ACTIONS(13481),
    [anon_sym_POUNDendif2] = ACTIONS(13481),
    [anon_sym_POUNDENDIF2] = ACTIONS(13481),
    [anon_sym_POUNDEndif2] = ACTIONS(13481),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12802),
    [sym_trigger_keyword] = ACTIONS(12802),
    [sym_var_keyword] = ACTIONS(12802),
    [sym_local_keyword] = ACTIONS(12802),
    [sym_internal_keyword] = ACTIONS(12802),
    [sym_protected_keyword] = ACTIONS(12802),
    [sym_event_keyword] = ACTIONS(12802),
    [sym_fields_keyword] = ACTIONS(12802),
    [sym_keys_keyword] = ACTIONS(12802),
    [sym_fieldgroups_keyword] = ACTIONS(12802),
    [sym_actions_keyword] = ACTIONS(12802),
    [sym_layout_keyword] = ACTIONS(12802),
    [sym_area_keyword] = ACTIONS(13479),
    [sym_group_keyword] = ACTIONS(13479),
    [sym_repeater_keyword] = ACTIONS(13479),
    [sym_cuegroup_keyword] = ACTIONS(13479),
    [sym_fixed_keyword] = ACTIONS(13479),
    [sym_grid_keyword] = ACTIONS(13479),
    [sym_part_keyword] = ACTIONS(13479),
    [sym_systempart_keyword] = ACTIONS(13479),
    [sym_usercontrol_keyword] = ACTIONS(13479),
    [sym_dataset_keyword] = ACTIONS(12802),
    [sym_elements_keyword] = ACTIONS(12802),
    [sym_labels_keyword] = ACTIONS(12802),
    [sym_rendering_keyword] = ACTIONS(12802),
    [sym_requestpage_keyword] = ACTIONS(12802),
    [sym_schema_keyword] = ACTIONS(12802),
    [sym_views_keyword] = ACTIONS(12802),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12802),
    [sym_preproc_open] = ACTIONS(13481),
    [sym_preproc_close] = ACTIONS(13481),
  },
  [STATE(5403)] = {
    [anon_sym_SEMI] = ACTIONS(13484),
    [aux_sym_where_condition_token1] = ACTIONS(13486),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13484),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13484),
    [anon_sym_LBRACK] = ACTIONS(13484),
    [aux_sym_basic_type_token6] = ACTIONS(13486),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13484),
    [aux_sym_addafter_modification_token1] = ACTIONS(13484),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13484),
    [aux_sym_modify_modification_token1] = ACTIONS(13484),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13484),
    [aux_sym_movelast_modification_token1] = ACTIONS(13484),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13484),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13484),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13484),
    [anon_sym_POUNDif] = ACTIONS(13484),
    [anon_sym_POUNDIF] = ACTIONS(13484),
    [anon_sym_POUNDIf] = ACTIONS(13484),
    [anon_sym_POUNDelif] = ACTIONS(13484),
    [anon_sym_POUNDELIF] = ACTIONS(13484),
    [anon_sym_POUNDElif] = ACTIONS(13484),
    [anon_sym_POUNDelse] = ACTIONS(13484),
    [anon_sym_POUNDELSE] = ACTIONS(13484),
    [anon_sym_POUNDElse] = ACTIONS(13484),
    [anon_sym_POUNDelse2] = ACTIONS(13484),
    [anon_sym_POUNDELSE2] = ACTIONS(13484),
    [anon_sym_POUNDElse2] = ACTIONS(13484),
    [anon_sym_POUNDendif] = ACTIONS(13484),
    [anon_sym_POUNDENDIF] = ACTIONS(13484),
    [anon_sym_POUNDEndif] = ACTIONS(13484),
    [anon_sym_POUNDendif2] = ACTIONS(13484),
    [anon_sym_POUNDENDIF2] = ACTIONS(13484),
    [anon_sym_POUNDEndif2] = ACTIONS(13484),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13484),
    [sym_trigger_keyword] = ACTIONS(13484),
    [sym_var_keyword] = ACTIONS(13484),
    [sym_local_keyword] = ACTIONS(13484),
    [sym_internal_keyword] = ACTIONS(13484),
    [sym_protected_keyword] = ACTIONS(13484),
    [sym_event_keyword] = ACTIONS(13484),
    [sym_fields_keyword] = ACTIONS(13484),
    [sym_keys_keyword] = ACTIONS(13484),
    [sym_fieldgroups_keyword] = ACTIONS(13484),
    [sym_actions_keyword] = ACTIONS(13484),
    [sym_layout_keyword] = ACTIONS(13484),
    [sym_area_keyword] = ACTIONS(13484),
    [sym_group_keyword] = ACTIONS(13484),
    [sym_repeater_keyword] = ACTIONS(13484),
    [sym_cuegroup_keyword] = ACTIONS(13484),
    [sym_fixed_keyword] = ACTIONS(13484),
    [sym_grid_keyword] = ACTIONS(13484),
    [sym_part_keyword] = ACTIONS(13484),
    [sym_systempart_keyword] = ACTIONS(13484),
    [sym_usercontrol_keyword] = ACTIONS(13484),
    [sym_dataset_keyword] = ACTIONS(13484),
    [sym_elements_keyword] = ACTIONS(13484),
    [sym_labels_keyword] = ACTIONS(13484),
    [sym_rendering_keyword] = ACTIONS(13484),
    [sym_requestpage_keyword] = ACTIONS(13484),
    [sym_schema_keyword] = ACTIONS(13484),
    [sym_views_keyword] = ACTIONS(13484),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13484),
    [sym_preproc_open] = ACTIONS(13484),
    [sym_preproc_close] = ACTIONS(13484),
  },
  [STATE(5404)] = {
    [anon_sym_SEMI] = ACTIONS(13488),
    [aux_sym_where_condition_token1] = ACTIONS(13490),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13488),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13488),
    [anon_sym_LBRACK] = ACTIONS(13488),
    [aux_sym_basic_type_token6] = ACTIONS(13490),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13488),
    [aux_sym_addafter_modification_token1] = ACTIONS(13488),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13488),
    [aux_sym_modify_modification_token1] = ACTIONS(13488),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13488),
    [aux_sym_movelast_modification_token1] = ACTIONS(13488),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13488),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13488),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13488),
    [anon_sym_POUNDif] = ACTIONS(13488),
    [anon_sym_POUNDIF] = ACTIONS(13488),
    [anon_sym_POUNDIf] = ACTIONS(13488),
    [anon_sym_POUNDelif] = ACTIONS(13488),
    [anon_sym_POUNDELIF] = ACTIONS(13488),
    [anon_sym_POUNDElif] = ACTIONS(13488),
    [anon_sym_POUNDelse] = ACTIONS(13488),
    [anon_sym_POUNDELSE] = ACTIONS(13488),
    [anon_sym_POUNDElse] = ACTIONS(13488),
    [anon_sym_POUNDelse2] = ACTIONS(13488),
    [anon_sym_POUNDELSE2] = ACTIONS(13488),
    [anon_sym_POUNDElse2] = ACTIONS(13488),
    [anon_sym_POUNDendif] = ACTIONS(13488),
    [anon_sym_POUNDENDIF] = ACTIONS(13488),
    [anon_sym_POUNDEndif] = ACTIONS(13488),
    [anon_sym_POUNDendif2] = ACTIONS(13488),
    [anon_sym_POUNDENDIF2] = ACTIONS(13488),
    [anon_sym_POUNDEndif2] = ACTIONS(13488),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13488),
    [sym_trigger_keyword] = ACTIONS(13488),
    [sym_var_keyword] = ACTIONS(13488),
    [sym_local_keyword] = ACTIONS(13488),
    [sym_internal_keyword] = ACTIONS(13488),
    [sym_protected_keyword] = ACTIONS(13488),
    [sym_event_keyword] = ACTIONS(13488),
    [sym_fields_keyword] = ACTIONS(13488),
    [sym_keys_keyword] = ACTIONS(13488),
    [sym_fieldgroups_keyword] = ACTIONS(13488),
    [sym_actions_keyword] = ACTIONS(13488),
    [sym_layout_keyword] = ACTIONS(13488),
    [sym_area_keyword] = ACTIONS(13488),
    [sym_group_keyword] = ACTIONS(13488),
    [sym_repeater_keyword] = ACTIONS(13488),
    [sym_cuegroup_keyword] = ACTIONS(13488),
    [sym_fixed_keyword] = ACTIONS(13488),
    [sym_grid_keyword] = ACTIONS(13488),
    [sym_part_keyword] = ACTIONS(13488),
    [sym_systempart_keyword] = ACTIONS(13488),
    [sym_usercontrol_keyword] = ACTIONS(13488),
    [sym_dataset_keyword] = ACTIONS(13488),
    [sym_elements_keyword] = ACTIONS(13488),
    [sym_labels_keyword] = ACTIONS(13488),
    [sym_rendering_keyword] = ACTIONS(13488),
    [sym_requestpage_keyword] = ACTIONS(13488),
    [sym_schema_keyword] = ACTIONS(13488),
    [sym_views_keyword] = ACTIONS(13488),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13488),
    [sym_preproc_open] = ACTIONS(13488),
    [sym_preproc_close] = ACTIONS(13488),
  },
  [STATE(5405)] = {
    [anon_sym_SEMI] = ACTIONS(13492),
    [aux_sym_where_condition_token1] = ACTIONS(13494),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13492),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13492),
    [anon_sym_LBRACK] = ACTIONS(13492),
    [aux_sym_basic_type_token6] = ACTIONS(13494),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13492),
    [aux_sym_addafter_modification_token1] = ACTIONS(13492),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13492),
    [aux_sym_modify_modification_token1] = ACTIONS(13492),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13492),
    [aux_sym_movelast_modification_token1] = ACTIONS(13492),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13492),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13492),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13492),
    [anon_sym_POUNDif] = ACTIONS(13492),
    [anon_sym_POUNDIF] = ACTIONS(13492),
    [anon_sym_POUNDIf] = ACTIONS(13492),
    [anon_sym_POUNDelif] = ACTIONS(13492),
    [anon_sym_POUNDELIF] = ACTIONS(13492),
    [anon_sym_POUNDElif] = ACTIONS(13492),
    [anon_sym_POUNDelse] = ACTIONS(13492),
    [anon_sym_POUNDELSE] = ACTIONS(13492),
    [anon_sym_POUNDElse] = ACTIONS(13492),
    [anon_sym_POUNDelse2] = ACTIONS(13492),
    [anon_sym_POUNDELSE2] = ACTIONS(13492),
    [anon_sym_POUNDElse2] = ACTIONS(13492),
    [anon_sym_POUNDendif] = ACTIONS(13492),
    [anon_sym_POUNDENDIF] = ACTIONS(13492),
    [anon_sym_POUNDEndif] = ACTIONS(13492),
    [anon_sym_POUNDendif2] = ACTIONS(13492),
    [anon_sym_POUNDENDIF2] = ACTIONS(13492),
    [anon_sym_POUNDEndif2] = ACTIONS(13492),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13492),
    [sym_trigger_keyword] = ACTIONS(13492),
    [sym_var_keyword] = ACTIONS(13492),
    [sym_local_keyword] = ACTIONS(13492),
    [sym_internal_keyword] = ACTIONS(13492),
    [sym_protected_keyword] = ACTIONS(13492),
    [sym_event_keyword] = ACTIONS(13492),
    [sym_fields_keyword] = ACTIONS(13492),
    [sym_keys_keyword] = ACTIONS(13492),
    [sym_fieldgroups_keyword] = ACTIONS(13492),
    [sym_actions_keyword] = ACTIONS(13492),
    [sym_layout_keyword] = ACTIONS(13492),
    [sym_area_keyword] = ACTIONS(13492),
    [sym_group_keyword] = ACTIONS(13492),
    [sym_repeater_keyword] = ACTIONS(13492),
    [sym_cuegroup_keyword] = ACTIONS(13492),
    [sym_fixed_keyword] = ACTIONS(13492),
    [sym_grid_keyword] = ACTIONS(13492),
    [sym_part_keyword] = ACTIONS(13492),
    [sym_systempart_keyword] = ACTIONS(13492),
    [sym_usercontrol_keyword] = ACTIONS(13492),
    [sym_dataset_keyword] = ACTIONS(13492),
    [sym_elements_keyword] = ACTIONS(13492),
    [sym_labels_keyword] = ACTIONS(13492),
    [sym_rendering_keyword] = ACTIONS(13492),
    [sym_requestpage_keyword] = ACTIONS(13492),
    [sym_schema_keyword] = ACTIONS(13492),
    [sym_views_keyword] = ACTIONS(13492),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13492),
    [sym_preproc_open] = ACTIONS(13492),
    [sym_preproc_close] = ACTIONS(13492),
  },
  [STATE(5406)] = {
    [anon_sym_SEMI] = ACTIONS(13424),
    [aux_sym_where_condition_token1] = ACTIONS(13496),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13499),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13499),
    [anon_sym_LBRACK] = ACTIONS(13424),
    [aux_sym_basic_type_token6] = ACTIONS(13496),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13424),
    [aux_sym_addafter_modification_token1] = ACTIONS(13499),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13499),
    [aux_sym_modify_modification_token1] = ACTIONS(13499),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13499),
    [aux_sym_movelast_modification_token1] = ACTIONS(13499),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13499),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13499),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13424),
    [anon_sym_POUNDif] = ACTIONS(13499),
    [anon_sym_POUNDIF] = ACTIONS(13499),
    [anon_sym_POUNDIf] = ACTIONS(13499),
    [anon_sym_POUNDelif] = ACTIONS(13499),
    [anon_sym_POUNDELIF] = ACTIONS(13499),
    [anon_sym_POUNDElif] = ACTIONS(13499),
    [anon_sym_POUNDelse] = ACTIONS(13499),
    [anon_sym_POUNDELSE] = ACTIONS(13499),
    [anon_sym_POUNDElse] = ACTIONS(13499),
    [anon_sym_POUNDelse2] = ACTIONS(13499),
    [anon_sym_POUNDELSE2] = ACTIONS(13499),
    [anon_sym_POUNDElse2] = ACTIONS(13499),
    [anon_sym_POUNDendif] = ACTIONS(13499),
    [anon_sym_POUNDENDIF] = ACTIONS(13499),
    [anon_sym_POUNDEndif] = ACTIONS(13499),
    [anon_sym_POUNDendif2] = ACTIONS(13499),
    [anon_sym_POUNDENDIF2] = ACTIONS(13499),
    [anon_sym_POUNDEndif2] = ACTIONS(13499),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13424),
    [sym_trigger_keyword] = ACTIONS(13424),
    [sym_var_keyword] = ACTIONS(13424),
    [sym_local_keyword] = ACTIONS(13424),
    [sym_internal_keyword] = ACTIONS(13424),
    [sym_protected_keyword] = ACTIONS(13424),
    [sym_event_keyword] = ACTIONS(13424),
    [sym_fields_keyword] = ACTIONS(13424),
    [sym_keys_keyword] = ACTIONS(13424),
    [sym_fieldgroups_keyword] = ACTIONS(13424),
    [sym_actions_keyword] = ACTIONS(13424),
    [sym_layout_keyword] = ACTIONS(13424),
    [sym_area_keyword] = ACTIONS(13499),
    [sym_group_keyword] = ACTIONS(13499),
    [sym_repeater_keyword] = ACTIONS(13499),
    [sym_cuegroup_keyword] = ACTIONS(13499),
    [sym_fixed_keyword] = ACTIONS(13499),
    [sym_grid_keyword] = ACTIONS(13499),
    [sym_part_keyword] = ACTIONS(13499),
    [sym_systempart_keyword] = ACTIONS(13499),
    [sym_usercontrol_keyword] = ACTIONS(13499),
    [sym_dataset_keyword] = ACTIONS(13424),
    [sym_elements_keyword] = ACTIONS(13424),
    [sym_labels_keyword] = ACTIONS(13424),
    [sym_rendering_keyword] = ACTIONS(13424),
    [sym_requestpage_keyword] = ACTIONS(13424),
    [sym_schema_keyword] = ACTIONS(13424),
    [sym_views_keyword] = ACTIONS(13424),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13424),
    [sym_preproc_open] = ACTIONS(13499),
    [sym_preproc_close] = ACTIONS(13499),
  },
  [STATE(5407)] = {
    [anon_sym_SEMI] = ACTIONS(13502),
    [aux_sym_where_condition_token1] = ACTIONS(13504),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13502),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13502),
    [anon_sym_LBRACK] = ACTIONS(13502),
    [aux_sym_basic_type_token6] = ACTIONS(13504),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13502),
    [aux_sym_addafter_modification_token1] = ACTIONS(13502),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13502),
    [aux_sym_modify_modification_token1] = ACTIONS(13502),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13502),
    [aux_sym_movelast_modification_token1] = ACTIONS(13502),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13502),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13502),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13502),
    [anon_sym_POUNDif] = ACTIONS(13502),
    [anon_sym_POUNDIF] = ACTIONS(13502),
    [anon_sym_POUNDIf] = ACTIONS(13502),
    [anon_sym_POUNDelif] = ACTIONS(13502),
    [anon_sym_POUNDELIF] = ACTIONS(13502),
    [anon_sym_POUNDElif] = ACTIONS(13502),
    [anon_sym_POUNDelse] = ACTIONS(13502),
    [anon_sym_POUNDELSE] = ACTIONS(13502),
    [anon_sym_POUNDElse] = ACTIONS(13502),
    [anon_sym_POUNDelse2] = ACTIONS(13502),
    [anon_sym_POUNDELSE2] = ACTIONS(13502),
    [anon_sym_POUNDElse2] = ACTIONS(13502),
    [anon_sym_POUNDendif] = ACTIONS(13502),
    [anon_sym_POUNDENDIF] = ACTIONS(13502),
    [anon_sym_POUNDEndif] = ACTIONS(13502),
    [anon_sym_POUNDendif2] = ACTIONS(13502),
    [anon_sym_POUNDENDIF2] = ACTIONS(13502),
    [anon_sym_POUNDEndif2] = ACTIONS(13502),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13502),
    [sym_trigger_keyword] = ACTIONS(13502),
    [sym_var_keyword] = ACTIONS(13502),
    [sym_local_keyword] = ACTIONS(13502),
    [sym_internal_keyword] = ACTIONS(13502),
    [sym_protected_keyword] = ACTIONS(13502),
    [sym_event_keyword] = ACTIONS(13502),
    [sym_fields_keyword] = ACTIONS(13502),
    [sym_keys_keyword] = ACTIONS(13502),
    [sym_fieldgroups_keyword] = ACTIONS(13502),
    [sym_actions_keyword] = ACTIONS(13502),
    [sym_layout_keyword] = ACTIONS(13502),
    [sym_area_keyword] = ACTIONS(13502),
    [sym_group_keyword] = ACTIONS(13502),
    [sym_repeater_keyword] = ACTIONS(13502),
    [sym_cuegroup_keyword] = ACTIONS(13502),
    [sym_fixed_keyword] = ACTIONS(13502),
    [sym_grid_keyword] = ACTIONS(13502),
    [sym_part_keyword] = ACTIONS(13502),
    [sym_systempart_keyword] = ACTIONS(13502),
    [sym_usercontrol_keyword] = ACTIONS(13502),
    [sym_dataset_keyword] = ACTIONS(13502),
    [sym_elements_keyword] = ACTIONS(13502),
    [sym_labels_keyword] = ACTIONS(13502),
    [sym_rendering_keyword] = ACTIONS(13502),
    [sym_requestpage_keyword] = ACTIONS(13502),
    [sym_schema_keyword] = ACTIONS(13502),
    [sym_views_keyword] = ACTIONS(13502),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13502),
    [sym_preproc_open] = ACTIONS(13502),
    [sym_preproc_close] = ACTIONS(13502),
  },
  [STATE(5408)] = {
    [anon_sym_SEMI] = ACTIONS(13506),
    [aux_sym_where_condition_token1] = ACTIONS(13508),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13506),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13506),
    [anon_sym_LBRACK] = ACTIONS(13506),
    [aux_sym_basic_type_token6] = ACTIONS(13508),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13506),
    [aux_sym_addafter_modification_token1] = ACTIONS(13506),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13506),
    [aux_sym_modify_modification_token1] = ACTIONS(13506),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13506),
    [aux_sym_movelast_modification_token1] = ACTIONS(13506),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13506),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13506),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13506),
    [anon_sym_POUNDif] = ACTIONS(13506),
    [anon_sym_POUNDIF] = ACTIONS(13506),
    [anon_sym_POUNDIf] = ACTIONS(13506),
    [anon_sym_POUNDelif] = ACTIONS(13506),
    [anon_sym_POUNDELIF] = ACTIONS(13506),
    [anon_sym_POUNDElif] = ACTIONS(13506),
    [anon_sym_POUNDelse] = ACTIONS(13506),
    [anon_sym_POUNDELSE] = ACTIONS(13506),
    [anon_sym_POUNDElse] = ACTIONS(13506),
    [anon_sym_POUNDelse2] = ACTIONS(13506),
    [anon_sym_POUNDELSE2] = ACTIONS(13506),
    [anon_sym_POUNDElse2] = ACTIONS(13506),
    [anon_sym_POUNDendif] = ACTIONS(13506),
    [anon_sym_POUNDENDIF] = ACTIONS(13506),
    [anon_sym_POUNDEndif] = ACTIONS(13506),
    [anon_sym_POUNDendif2] = ACTIONS(13506),
    [anon_sym_POUNDENDIF2] = ACTIONS(13506),
    [anon_sym_POUNDEndif2] = ACTIONS(13506),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13506),
    [sym_trigger_keyword] = ACTIONS(13506),
    [sym_var_keyword] = ACTIONS(13506),
    [sym_local_keyword] = ACTIONS(13506),
    [sym_internal_keyword] = ACTIONS(13506),
    [sym_protected_keyword] = ACTIONS(13506),
    [sym_event_keyword] = ACTIONS(13506),
    [sym_fields_keyword] = ACTIONS(13506),
    [sym_keys_keyword] = ACTIONS(13506),
    [sym_fieldgroups_keyword] = ACTIONS(13506),
    [sym_actions_keyword] = ACTIONS(13506),
    [sym_layout_keyword] = ACTIONS(13506),
    [sym_area_keyword] = ACTIONS(13506),
    [sym_group_keyword] = ACTIONS(13506),
    [sym_repeater_keyword] = ACTIONS(13506),
    [sym_cuegroup_keyword] = ACTIONS(13506),
    [sym_fixed_keyword] = ACTIONS(13506),
    [sym_grid_keyword] = ACTIONS(13506),
    [sym_part_keyword] = ACTIONS(13506),
    [sym_systempart_keyword] = ACTIONS(13506),
    [sym_usercontrol_keyword] = ACTIONS(13506),
    [sym_dataset_keyword] = ACTIONS(13506),
    [sym_elements_keyword] = ACTIONS(13506),
    [sym_labels_keyword] = ACTIONS(13506),
    [sym_rendering_keyword] = ACTIONS(13506),
    [sym_requestpage_keyword] = ACTIONS(13506),
    [sym_schema_keyword] = ACTIONS(13506),
    [sym_views_keyword] = ACTIONS(13506),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13506),
    [sym_preproc_open] = ACTIONS(13506),
    [sym_preproc_close] = ACTIONS(13506),
  },
  [STATE(5409)] = {
    [anon_sym_SEMI] = ACTIONS(13510),
    [aux_sym_where_condition_token1] = ACTIONS(13512),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13510),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13510),
    [anon_sym_LBRACK] = ACTIONS(13510),
    [aux_sym_basic_type_token6] = ACTIONS(13512),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13510),
    [aux_sym_addafter_modification_token1] = ACTIONS(13510),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13510),
    [aux_sym_modify_modification_token1] = ACTIONS(13510),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13510),
    [aux_sym_movelast_modification_token1] = ACTIONS(13510),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13510),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13510),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13510),
    [anon_sym_POUNDif] = ACTIONS(13510),
    [anon_sym_POUNDIF] = ACTIONS(13510),
    [anon_sym_POUNDIf] = ACTIONS(13510),
    [anon_sym_POUNDelif] = ACTIONS(13510),
    [anon_sym_POUNDELIF] = ACTIONS(13510),
    [anon_sym_POUNDElif] = ACTIONS(13510),
    [anon_sym_POUNDelse] = ACTIONS(13510),
    [anon_sym_POUNDELSE] = ACTIONS(13510),
    [anon_sym_POUNDElse] = ACTIONS(13510),
    [anon_sym_POUNDelse2] = ACTIONS(13510),
    [anon_sym_POUNDELSE2] = ACTIONS(13510),
    [anon_sym_POUNDElse2] = ACTIONS(13510),
    [anon_sym_POUNDendif] = ACTIONS(13510),
    [anon_sym_POUNDENDIF] = ACTIONS(13510),
    [anon_sym_POUNDEndif] = ACTIONS(13510),
    [anon_sym_POUNDendif2] = ACTIONS(13510),
    [anon_sym_POUNDENDIF2] = ACTIONS(13510),
    [anon_sym_POUNDEndif2] = ACTIONS(13510),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13510),
    [sym_trigger_keyword] = ACTIONS(13510),
    [sym_var_keyword] = ACTIONS(13510),
    [sym_local_keyword] = ACTIONS(13510),
    [sym_internal_keyword] = ACTIONS(13510),
    [sym_protected_keyword] = ACTIONS(13510),
    [sym_event_keyword] = ACTIONS(13510),
    [sym_fields_keyword] = ACTIONS(13510),
    [sym_keys_keyword] = ACTIONS(13510),
    [sym_fieldgroups_keyword] = ACTIONS(13510),
    [sym_actions_keyword] = ACTIONS(13510),
    [sym_layout_keyword] = ACTIONS(13510),
    [sym_area_keyword] = ACTIONS(13510),
    [sym_group_keyword] = ACTIONS(13510),
    [sym_repeater_keyword] = ACTIONS(13510),
    [sym_cuegroup_keyword] = ACTIONS(13510),
    [sym_fixed_keyword] = ACTIONS(13510),
    [sym_grid_keyword] = ACTIONS(13510),
    [sym_part_keyword] = ACTIONS(13510),
    [sym_systempart_keyword] = ACTIONS(13510),
    [sym_usercontrol_keyword] = ACTIONS(13510),
    [sym_dataset_keyword] = ACTIONS(13510),
    [sym_elements_keyword] = ACTIONS(13510),
    [sym_labels_keyword] = ACTIONS(13510),
    [sym_rendering_keyword] = ACTIONS(13510),
    [sym_requestpage_keyword] = ACTIONS(13510),
    [sym_schema_keyword] = ACTIONS(13510),
    [sym_views_keyword] = ACTIONS(13510),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13510),
    [sym_preproc_open] = ACTIONS(13510),
    [sym_preproc_close] = ACTIONS(13510),
  },
  [STATE(5410)] = {
    [anon_sym_SEMI] = ACTIONS(13481),
    [aux_sym_where_condition_token1] = ACTIONS(13514),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13481),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13481),
    [anon_sym_LBRACK] = ACTIONS(13481),
    [aux_sym_basic_type_token6] = ACTIONS(13514),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13481),
    [aux_sym_addafter_modification_token1] = ACTIONS(13481),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13481),
    [aux_sym_modify_modification_token1] = ACTIONS(13481),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13481),
    [aux_sym_movelast_modification_token1] = ACTIONS(13481),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13481),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13481),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13481),
    [anon_sym_POUNDif] = ACTIONS(13481),
    [anon_sym_POUNDIF] = ACTIONS(13481),
    [anon_sym_POUNDIf] = ACTIONS(13481),
    [anon_sym_POUNDelif] = ACTIONS(13481),
    [anon_sym_POUNDELIF] = ACTIONS(13481),
    [anon_sym_POUNDElif] = ACTIONS(13481),
    [anon_sym_POUNDelse] = ACTIONS(13481),
    [anon_sym_POUNDELSE] = ACTIONS(13481),
    [anon_sym_POUNDElse] = ACTIONS(13481),
    [anon_sym_POUNDelse2] = ACTIONS(13481),
    [anon_sym_POUNDELSE2] = ACTIONS(13481),
    [anon_sym_POUNDElse2] = ACTIONS(13481),
    [anon_sym_POUNDendif] = ACTIONS(13481),
    [anon_sym_POUNDENDIF] = ACTIONS(13481),
    [anon_sym_POUNDEndif] = ACTIONS(13481),
    [anon_sym_POUNDendif2] = ACTIONS(13481),
    [anon_sym_POUNDENDIF2] = ACTIONS(13481),
    [anon_sym_POUNDEndif2] = ACTIONS(13481),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13481),
    [sym_trigger_keyword] = ACTIONS(13481),
    [sym_var_keyword] = ACTIONS(13481),
    [sym_local_keyword] = ACTIONS(13481),
    [sym_internal_keyword] = ACTIONS(13481),
    [sym_protected_keyword] = ACTIONS(13481),
    [sym_event_keyword] = ACTIONS(13481),
    [sym_fields_keyword] = ACTIONS(13481),
    [sym_keys_keyword] = ACTIONS(13481),
    [sym_fieldgroups_keyword] = ACTIONS(13481),
    [sym_actions_keyword] = ACTIONS(13481),
    [sym_layout_keyword] = ACTIONS(13481),
    [sym_area_keyword] = ACTIONS(13481),
    [sym_group_keyword] = ACTIONS(13481),
    [sym_repeater_keyword] = ACTIONS(13481),
    [sym_cuegroup_keyword] = ACTIONS(13481),
    [sym_fixed_keyword] = ACTIONS(13481),
    [sym_grid_keyword] = ACTIONS(13481),
    [sym_part_keyword] = ACTIONS(13481),
    [sym_systempart_keyword] = ACTIONS(13481),
    [sym_usercontrol_keyword] = ACTIONS(13481),
    [sym_dataset_keyword] = ACTIONS(13481),
    [sym_elements_keyword] = ACTIONS(13481),
    [sym_labels_keyword] = ACTIONS(13481),
    [sym_rendering_keyword] = ACTIONS(13481),
    [sym_requestpage_keyword] = ACTIONS(13481),
    [sym_schema_keyword] = ACTIONS(13481),
    [sym_views_keyword] = ACTIONS(13481),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13481),
    [sym_preproc_open] = ACTIONS(13481),
    [sym_preproc_close] = ACTIONS(13481),
  },
  [STATE(5411)] = {
    [anon_sym_SEMI] = ACTIONS(13285),
    [aux_sym_where_condition_token1] = ACTIONS(13283),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13285),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13285),
    [anon_sym_LBRACK] = ACTIONS(13285),
    [aux_sym_basic_type_token6] = ACTIONS(13283),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13285),
    [aux_sym_addafter_modification_token1] = ACTIONS(13285),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13285),
    [aux_sym_modify_modification_token1] = ACTIONS(13285),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13285),
    [aux_sym_movelast_modification_token1] = ACTIONS(13285),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13285),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13285),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13285),
    [anon_sym_POUNDif] = ACTIONS(13285),
    [anon_sym_POUNDIF] = ACTIONS(13285),
    [anon_sym_POUNDIf] = ACTIONS(13285),
    [anon_sym_POUNDelif] = ACTIONS(13285),
    [anon_sym_POUNDELIF] = ACTIONS(13285),
    [anon_sym_POUNDElif] = ACTIONS(13285),
    [anon_sym_POUNDelse] = ACTIONS(13285),
    [anon_sym_POUNDELSE] = ACTIONS(13285),
    [anon_sym_POUNDElse] = ACTIONS(13285),
    [anon_sym_POUNDelse2] = ACTIONS(13285),
    [anon_sym_POUNDELSE2] = ACTIONS(13285),
    [anon_sym_POUNDElse2] = ACTIONS(13285),
    [anon_sym_POUNDendif] = ACTIONS(13285),
    [anon_sym_POUNDENDIF] = ACTIONS(13285),
    [anon_sym_POUNDEndif] = ACTIONS(13285),
    [anon_sym_POUNDendif2] = ACTIONS(13285),
    [anon_sym_POUNDENDIF2] = ACTIONS(13285),
    [anon_sym_POUNDEndif2] = ACTIONS(13285),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13285),
    [sym_trigger_keyword] = ACTIONS(13285),
    [sym_var_keyword] = ACTIONS(13285),
    [sym_local_keyword] = ACTIONS(13285),
    [sym_internal_keyword] = ACTIONS(13285),
    [sym_protected_keyword] = ACTIONS(13285),
    [sym_event_keyword] = ACTIONS(13285),
    [sym_fields_keyword] = ACTIONS(13285),
    [sym_keys_keyword] = ACTIONS(13285),
    [sym_fieldgroups_keyword] = ACTIONS(13285),
    [sym_actions_keyword] = ACTIONS(13285),
    [sym_layout_keyword] = ACTIONS(13285),
    [sym_area_keyword] = ACTIONS(13285),
    [sym_group_keyword] = ACTIONS(13285),
    [sym_repeater_keyword] = ACTIONS(13285),
    [sym_cuegroup_keyword] = ACTIONS(13285),
    [sym_fixed_keyword] = ACTIONS(13285),
    [sym_grid_keyword] = ACTIONS(13285),
    [sym_part_keyword] = ACTIONS(13285),
    [sym_systempart_keyword] = ACTIONS(13285),
    [sym_usercontrol_keyword] = ACTIONS(13285),
    [sym_dataset_keyword] = ACTIONS(13285),
    [sym_elements_keyword] = ACTIONS(13285),
    [sym_labels_keyword] = ACTIONS(13285),
    [sym_rendering_keyword] = ACTIONS(13285),
    [sym_requestpage_keyword] = ACTIONS(13285),
    [sym_schema_keyword] = ACTIONS(13285),
    [sym_views_keyword] = ACTIONS(13285),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13285),
    [sym_preproc_open] = ACTIONS(13285),
    [sym_preproc_close] = ACTIONS(13285),
  },
  [STATE(5412)] = {
    [aux_sym_where_condition_token1] = ACTIONS(7420),
    [anon_sym_LBRACK] = ACTIONS(7420),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(7420),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [anon_sym_if] = ACTIONS(7420),
    [anon_sym_IF] = ACTIONS(7420),
    [anon_sym_If] = ACTIONS(7420),
    [sym_table_keyword] = ACTIONS(7418),
    [anon_sym_tableextension] = ACTIONS(7420),
    [anon_sym_TABLEEXTENSION] = ACTIONS(7420),
    [anon_sym_Tableextension] = ACTIONS(7420),
    [anon_sym_TableExtension] = ACTIONS(7420),
    [anon_sym_tableExtension] = ACTIONS(7420),
    [sym_page_keyword] = ACTIONS(7418),
    [anon_sym_pageextension] = ACTIONS(7420),
    [anon_sym_PAGEEXTENSION] = ACTIONS(7420),
    [anon_sym_Pageextension] = ACTIONS(7420),
    [anon_sym_PageExtension] = ACTIONS(7420),
    [anon_sym_pageExtension] = ACTIONS(7420),
    [anon_sym_codeunit] = ACTIONS(7420),
    [anon_sym_CODEUNIT] = ACTIONS(7420),
    [anon_sym_Codeunit] = ACTIONS(7420),
    [anon_sym_CodeUnit] = ACTIONS(7420),
    [anon_sym_COdeunit] = ACTIONS(7420),
    [anon_sym_codeUnit] = ACTIONS(7420),
    [sym_report_keyword] = ACTIONS(7418),
    [anon_sym_reportextension] = ACTIONS(7420),
    [anon_sym_REPORTEXTENSION] = ACTIONS(7420),
    [anon_sym_Reportextension] = ACTIONS(7420),
    [anon_sym_ReportExtension] = ACTIONS(7420),
    [anon_sym_reportExtension] = ACTIONS(7420),
    [sym_query_keyword] = ACTIONS(7420),
    [anon_sym_xmlport] = ACTIONS(7420),
    [anon_sym_XMLPORT] = ACTIONS(7420),
    [anon_sym_Xmlport] = ACTIONS(7420),
    [anon_sym_XMLport] = ACTIONS(7420),
    [anon_sym_XMLPort] = ACTIONS(7420),
    [anon_sym_XmlPort] = ACTIONS(7420),
    [anon_sym_enum] = ACTIONS(7418),
    [anon_sym_ENUM] = ACTIONS(7418),
    [anon_sym_Enum] = ACTIONS(7418),
    [anon_sym_eNUM] = ACTIONS(7420),
    [anon_sym_eNum] = ACTIONS(7420),
    [anon_sym_ENum] = ACTIONS(7420),
    [anon_sym_enumextension] = ACTIONS(7420),
    [anon_sym_ENUMEXTENSION] = ACTIONS(7420),
    [anon_sym_Enumextension] = ACTIONS(7420),
    [anon_sym_EnumExtension] = ACTIONS(7420),
    [anon_sym_enumExtension] = ACTIONS(7420),
    [sym_interface_keyword] = ACTIONS(7420),
    [anon_sym_permissionset] = ACTIONS(7418),
    [anon_sym_PERMISSIONSET] = ACTIONS(7418),
    [anon_sym_Permissionset] = ACTIONS(7418),
    [anon_sym_PermissionSet] = ACTIONS(7418),
    [anon_sym_permissionSet] = ACTIONS(7418),
    [anon_sym_permissionsetextension] = ACTIONS(7420),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(7420),
    [anon_sym_Permissionsetextension] = ACTIONS(7420),
    [anon_sym_PermissionSetExtension] = ACTIONS(7420),
    [anon_sym_permissionSetExtension] = ACTIONS(7420),
    [sym_procedure_keyword] = ACTIONS(7420),
    [sym_var_keyword] = ACTIONS(7420),
    [sym_local_keyword] = ACTIONS(7420),
    [sym_internal_keyword] = ACTIONS(7420),
    [sym_protected_keyword] = ACTIONS(7420),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5413)] = {
    [anon_sym_SEMI] = ACTIONS(13287),
    [aux_sym_where_condition_token1] = ACTIONS(13517),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13287),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13287),
    [anon_sym_LBRACK] = ACTIONS(13287),
    [aux_sym_basic_type_token6] = ACTIONS(13517),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13287),
    [aux_sym_addafter_modification_token1] = ACTIONS(13287),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13287),
    [aux_sym_modify_modification_token1] = ACTIONS(13287),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13287),
    [aux_sym_movelast_modification_token1] = ACTIONS(13287),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13287),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13287),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13287),
    [anon_sym_POUNDif] = ACTIONS(13287),
    [anon_sym_POUNDIF] = ACTIONS(13287),
    [anon_sym_POUNDIf] = ACTIONS(13287),
    [anon_sym_POUNDelif] = ACTIONS(13287),
    [anon_sym_POUNDELIF] = ACTIONS(13287),
    [anon_sym_POUNDElif] = ACTIONS(13287),
    [anon_sym_POUNDelse] = ACTIONS(13287),
    [anon_sym_POUNDELSE] = ACTIONS(13287),
    [anon_sym_POUNDElse] = ACTIONS(13287),
    [anon_sym_POUNDelse2] = ACTIONS(13287),
    [anon_sym_POUNDELSE2] = ACTIONS(13287),
    [anon_sym_POUNDElse2] = ACTIONS(13287),
    [anon_sym_POUNDendif] = ACTIONS(13287),
    [anon_sym_POUNDENDIF] = ACTIONS(13287),
    [anon_sym_POUNDEndif] = ACTIONS(13287),
    [anon_sym_POUNDendif2] = ACTIONS(13287),
    [anon_sym_POUNDENDIF2] = ACTIONS(13287),
    [anon_sym_POUNDEndif2] = ACTIONS(13287),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13287),
    [sym_trigger_keyword] = ACTIONS(13287),
    [sym_var_keyword] = ACTIONS(13287),
    [sym_local_keyword] = ACTIONS(13287),
    [sym_internal_keyword] = ACTIONS(13287),
    [sym_protected_keyword] = ACTIONS(13287),
    [sym_event_keyword] = ACTIONS(13287),
    [sym_fields_keyword] = ACTIONS(13287),
    [sym_keys_keyword] = ACTIONS(13287),
    [sym_fieldgroups_keyword] = ACTIONS(13287),
    [sym_actions_keyword] = ACTIONS(13287),
    [sym_layout_keyword] = ACTIONS(13287),
    [sym_area_keyword] = ACTIONS(13287),
    [sym_group_keyword] = ACTIONS(13287),
    [sym_repeater_keyword] = ACTIONS(13287),
    [sym_cuegroup_keyword] = ACTIONS(13287),
    [sym_fixed_keyword] = ACTIONS(13287),
    [sym_grid_keyword] = ACTIONS(13287),
    [sym_part_keyword] = ACTIONS(13287),
    [sym_systempart_keyword] = ACTIONS(13287),
    [sym_usercontrol_keyword] = ACTIONS(13287),
    [sym_dataset_keyword] = ACTIONS(13287),
    [sym_elements_keyword] = ACTIONS(13287),
    [sym_labels_keyword] = ACTIONS(13287),
    [sym_rendering_keyword] = ACTIONS(13287),
    [sym_requestpage_keyword] = ACTIONS(13287),
    [sym_schema_keyword] = ACTIONS(13287),
    [sym_views_keyword] = ACTIONS(13287),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13287),
    [sym_preproc_open] = ACTIONS(13287),
    [sym_preproc_close] = ACTIONS(13287),
  },
  [STATE(5414)] = {
    [anon_sym_SEMI] = ACTIONS(13520),
    [aux_sym_where_condition_token1] = ACTIONS(13522),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13520),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13520),
    [anon_sym_LBRACK] = ACTIONS(13520),
    [aux_sym_basic_type_token6] = ACTIONS(13522),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13520),
    [aux_sym_addafter_modification_token1] = ACTIONS(13520),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13520),
    [aux_sym_modify_modification_token1] = ACTIONS(13520),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13520),
    [aux_sym_movelast_modification_token1] = ACTIONS(13520),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13520),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13520),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13520),
    [anon_sym_POUNDif] = ACTIONS(13520),
    [anon_sym_POUNDIF] = ACTIONS(13520),
    [anon_sym_POUNDIf] = ACTIONS(13520),
    [anon_sym_POUNDelif] = ACTIONS(13520),
    [anon_sym_POUNDELIF] = ACTIONS(13520),
    [anon_sym_POUNDElif] = ACTIONS(13520),
    [anon_sym_POUNDelse] = ACTIONS(13520),
    [anon_sym_POUNDELSE] = ACTIONS(13520),
    [anon_sym_POUNDElse] = ACTIONS(13520),
    [anon_sym_POUNDelse2] = ACTIONS(13520),
    [anon_sym_POUNDELSE2] = ACTIONS(13520),
    [anon_sym_POUNDElse2] = ACTIONS(13520),
    [anon_sym_POUNDendif] = ACTIONS(13520),
    [anon_sym_POUNDENDIF] = ACTIONS(13520),
    [anon_sym_POUNDEndif] = ACTIONS(13520),
    [anon_sym_POUNDendif2] = ACTIONS(13520),
    [anon_sym_POUNDENDIF2] = ACTIONS(13520),
    [anon_sym_POUNDEndif2] = ACTIONS(13520),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13520),
    [sym_trigger_keyword] = ACTIONS(13520),
    [sym_var_keyword] = ACTIONS(13520),
    [sym_local_keyword] = ACTIONS(13520),
    [sym_internal_keyword] = ACTIONS(13520),
    [sym_protected_keyword] = ACTIONS(13520),
    [sym_event_keyword] = ACTIONS(13520),
    [sym_fields_keyword] = ACTIONS(13520),
    [sym_keys_keyword] = ACTIONS(13520),
    [sym_fieldgroups_keyword] = ACTIONS(13520),
    [sym_actions_keyword] = ACTIONS(13520),
    [sym_layout_keyword] = ACTIONS(13520),
    [sym_area_keyword] = ACTIONS(13520),
    [sym_group_keyword] = ACTIONS(13520),
    [sym_repeater_keyword] = ACTIONS(13520),
    [sym_cuegroup_keyword] = ACTIONS(13520),
    [sym_fixed_keyword] = ACTIONS(13520),
    [sym_grid_keyword] = ACTIONS(13520),
    [sym_part_keyword] = ACTIONS(13520),
    [sym_systempart_keyword] = ACTIONS(13520),
    [sym_usercontrol_keyword] = ACTIONS(13520),
    [sym_dataset_keyword] = ACTIONS(13520),
    [sym_elements_keyword] = ACTIONS(13520),
    [sym_labels_keyword] = ACTIONS(13520),
    [sym_rendering_keyword] = ACTIONS(13520),
    [sym_requestpage_keyword] = ACTIONS(13520),
    [sym_schema_keyword] = ACTIONS(13520),
    [sym_views_keyword] = ACTIONS(13520),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13520),
    [sym_preproc_open] = ACTIONS(13520),
    [sym_preproc_close] = ACTIONS(13520),
  },
  [STATE(5415)] = {
    [anon_sym_SEMI] = ACTIONS(13524),
    [aux_sym_where_condition_token1] = ACTIONS(13526),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(13524),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(13524),
    [anon_sym_LBRACK] = ACTIONS(13524),
    [aux_sym_basic_type_token6] = ACTIONS(13526),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13524),
    [aux_sym_addafter_modification_token1] = ACTIONS(13524),
    [aux_sym_addbefore_modification_token1] = ACTIONS(13524),
    [aux_sym_modify_modification_token1] = ACTIONS(13524),
    [aux_sym_movefirst_modification_token1] = ACTIONS(13524),
    [aux_sym_movelast_modification_token1] = ACTIONS(13524),
    [aux_sym_moveafter_modification_token1] = ACTIONS(13524),
    [aux_sym_movebefore_modification_token1] = ACTIONS(13524),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13524),
    [anon_sym_POUNDif] = ACTIONS(13524),
    [anon_sym_POUNDIF] = ACTIONS(13524),
    [anon_sym_POUNDIf] = ACTIONS(13524),
    [anon_sym_POUNDelif] = ACTIONS(13524),
    [anon_sym_POUNDELIF] = ACTIONS(13524),
    [anon_sym_POUNDElif] = ACTIONS(13524),
    [anon_sym_POUNDelse] = ACTIONS(13524),
    [anon_sym_POUNDELSE] = ACTIONS(13524),
    [anon_sym_POUNDElse] = ACTIONS(13524),
    [anon_sym_POUNDelse2] = ACTIONS(13524),
    [anon_sym_POUNDELSE2] = ACTIONS(13524),
    [anon_sym_POUNDElse2] = ACTIONS(13524),
    [anon_sym_POUNDendif] = ACTIONS(13524),
    [anon_sym_POUNDENDIF] = ACTIONS(13524),
    [anon_sym_POUNDEndif] = ACTIONS(13524),
    [anon_sym_POUNDendif2] = ACTIONS(13524),
    [anon_sym_POUNDENDIF2] = ACTIONS(13524),
    [anon_sym_POUNDEndif2] = ACTIONS(13524),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13524),
    [sym_trigger_keyword] = ACTIONS(13524),
    [sym_var_keyword] = ACTIONS(13524),
    [sym_local_keyword] = ACTIONS(13524),
    [sym_internal_keyword] = ACTIONS(13524),
    [sym_protected_keyword] = ACTIONS(13524),
    [sym_event_keyword] = ACTIONS(13524),
    [sym_fields_keyword] = ACTIONS(13524),
    [sym_keys_keyword] = ACTIONS(13524),
    [sym_fieldgroups_keyword] = ACTIONS(13524),
    [sym_actions_keyword] = ACTIONS(13524),
    [sym_layout_keyword] = ACTIONS(13524),
    [sym_area_keyword] = ACTIONS(13524),
    [sym_group_keyword] = ACTIONS(13524),
    [sym_repeater_keyword] = ACTIONS(13524),
    [sym_cuegroup_keyword] = ACTIONS(13524),
    [sym_fixed_keyword] = ACTIONS(13524),
    [sym_grid_keyword] = ACTIONS(13524),
    [sym_part_keyword] = ACTIONS(13524),
    [sym_systempart_keyword] = ACTIONS(13524),
    [sym_usercontrol_keyword] = ACTIONS(13524),
    [sym_dataset_keyword] = ACTIONS(13524),
    [sym_elements_keyword] = ACTIONS(13524),
    [sym_labels_keyword] = ACTIONS(13524),
    [sym_rendering_keyword] = ACTIONS(13524),
    [sym_requestpage_keyword] = ACTIONS(13524),
    [sym_schema_keyword] = ACTIONS(13524),
    [sym_views_keyword] = ACTIONS(13524),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13524),
    [sym_preproc_open] = ACTIONS(13524),
    [sym_preproc_close] = ACTIONS(13524),
  },
  [STATE(5416)] = {
    [sym__object_header] = STATE(14375),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5417)] = {
    [sym__object_header] = STATE(14126),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5418)] = {
    [sym__object_header] = STATE(13745),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5419)] = {
    [sym_preproc_conditional_controladdin] = STATE(5420),
    [sym__body_element] = STATE(5420),
    [sym_empty_statement] = STATE(5420),
    [sym_property] = STATE(5420),
    [sym_permissions_property] = STATE(5420),
    [sym_table_relation_property] = STATE(5420),
    [sym_fields_section] = STATE(5420),
    [sym_keys_section] = STATE(5420),
    [sym_fieldgroups_section] = STATE(5420),
    [sym_enum_value_declaration] = STATE(5420),
    [sym_labels_section] = STATE(5420),
    [sym_layout_section] = STATE(5420),
    [sym_modify_modification] = STATE(5420),
    [sym_actions_section] = STATE(5420),
    [sym_views_section] = STATE(5420),
    [sym_dataset_section] = STATE(5420),
    [sym_requestpage_section] = STATE(5420),
    [sym_rendering_section] = STATE(5420),
    [sym_elements_section] = STATE(5420),
    [sym_schema_section] = STATE(5420),
    [sym_assembly_declaration] = STATE(5420),
    [sym_event_declaration] = STATE(5420),
    [sym_procedure] = STATE(5420),
    [sym_preproc_split_procedure] = STATE(5420),
    [sym_preproc_split_procedure_preamble] = STATE(5420),
    [sym_interface_procedure] = STATE(5420),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5420),
    [sym_var_section] = STATE(5420),
    [sym_attribute_item] = STATE(5420),
    [sym_preproc_conditional] = STATE(5420),
    [sym_preproc_if] = STATE(3599),
    [aux_sym_controladdin_declaration_repeat1] = STATE(5420),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13528),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5420)] = {
    [sym_preproc_conditional_controladdin] = STATE(5420),
    [sym__body_element] = STATE(5420),
    [sym_empty_statement] = STATE(5420),
    [sym_property] = STATE(5420),
    [sym_permissions_property] = STATE(5420),
    [sym_table_relation_property] = STATE(5420),
    [sym_fields_section] = STATE(5420),
    [sym_keys_section] = STATE(5420),
    [sym_fieldgroups_section] = STATE(5420),
    [sym_enum_value_declaration] = STATE(5420),
    [sym_labels_section] = STATE(5420),
    [sym_layout_section] = STATE(5420),
    [sym_modify_modification] = STATE(5420),
    [sym_actions_section] = STATE(5420),
    [sym_views_section] = STATE(5420),
    [sym_dataset_section] = STATE(5420),
    [sym_requestpage_section] = STATE(5420),
    [sym_rendering_section] = STATE(5420),
    [sym_elements_section] = STATE(5420),
    [sym_schema_section] = STATE(5420),
    [sym_assembly_declaration] = STATE(5420),
    [sym_event_declaration] = STATE(5420),
    [sym_procedure] = STATE(5420),
    [sym_preproc_split_procedure] = STATE(5420),
    [sym_preproc_split_procedure_preamble] = STATE(5420),
    [sym_interface_procedure] = STATE(5420),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5420),
    [sym_var_section] = STATE(5420),
    [sym_attribute_item] = STATE(5420),
    [sym_preproc_conditional] = STATE(5420),
    [sym_preproc_if] = STATE(3599),
    [aux_sym_controladdin_declaration_repeat1] = STATE(5420),
    [anon_sym_SEMI] = ACTIONS(13532),
    [anon_sym_RBRACE] = ACTIONS(8809),
    [anon_sym_LBRACK] = ACTIONS(13535),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13538),
    [aux_sym_modify_modification_token1] = ACTIONS(13541),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13544),
    [anon_sym_POUNDif] = ACTIONS(8806),
    [anon_sym_POUNDIF] = ACTIONS(8806),
    [anon_sym_POUNDIf] = ACTIONS(8806),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13547),
    [sym_trigger_keyword] = ACTIONS(13550),
    [sym_var_keyword] = ACTIONS(13553),
    [sym_local_keyword] = ACTIONS(13556),
    [sym_internal_keyword] = ACTIONS(8823),
    [sym_protected_keyword] = ACTIONS(13556),
    [sym_event_keyword] = ACTIONS(13559),
    [sym_fields_keyword] = ACTIONS(13562),
    [sym_keys_keyword] = ACTIONS(13565),
    [sym_fieldgroups_keyword] = ACTIONS(13568),
    [sym_actions_keyword] = ACTIONS(13571),
    [sym_layout_keyword] = ACTIONS(13574),
    [sym_dataset_keyword] = ACTIONS(13577),
    [sym_elements_keyword] = ACTIONS(13580),
    [sym_labels_keyword] = ACTIONS(13583),
    [sym_rendering_keyword] = ACTIONS(13586),
    [sym_requestpage_keyword] = ACTIONS(13589),
    [sym_schema_keyword] = ACTIONS(13592),
    [sym_views_keyword] = ACTIONS(13595),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13598),
    [sym_preproc_open] = ACTIONS(8806),
  },
  [STATE(5421)] = {
    [sym_boolean] = STATE(12461),
    [sym_option_member] = STATE(12464),
    [sym_keyword_identifier] = STATE(12461),
    [sym_codeunit_keyword] = STATE(12463),
    [sym_xmlport_keyword] = STATE(12463),
    [sym_enum_keyword] = STATE(12463),
    [sym_keyword_as_identifier] = STATE(12461),
    [sym_identifier] = ACTIONS(13232),
    [anon_sym_SEMI] = ACTIONS(611),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(13236),
    [aux_sym_boolean_token1] = ACTIONS(13238),
    [aux_sym_boolean_token2] = ACTIONS(13238),
    [aux_sym_where_condition_token1] = ACTIONS(13240),
    [aux_sym_tabledata_permission_token2] = ACTIONS(13242),
    [aux_sym_record_type_token1] = ACTIONS(13242),
    [aux_sym_basic_type_token21] = ACTIONS(13242),
    [aux_sym_basic_type_token22] = ACTIONS(13244),
    [aux_sym_basic_type_token48] = ACTIONS(13242),
    [aux_sym_basic_type_token53] = ACTIONS(13240),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13240),
    [aux_sym_separator_action_token1] = ACTIONS(13240),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13240),
    [aux_sym_type_declaration_token1] = ACTIONS(13240),
    [aux_sym_preproc_split_procedure_body_token1] = ACTIONS(613),
    [anon_sym_POUNDif] = ACTIONS(611),
    [anon_sym_POUNDIF] = ACTIONS(611),
    [anon_sym_POUNDIf] = ACTIONS(611),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(13242),
    [aux_sym_keyword_identifier_token2] = ACTIONS(13242),
    [sym_table_keyword] = ACTIONS(13240),
    [sym_page_keyword] = ACTIONS(13242),
    [anon_sym_codeunit] = ACTIONS(13246),
    [anon_sym_CODEUNIT] = ACTIONS(13246),
    [anon_sym_Codeunit] = ACTIONS(13246),
    [anon_sym_CodeUnit] = ACTIONS(13246),
    [anon_sym_COdeunit] = ACTIONS(13246),
    [anon_sym_codeUnit] = ACTIONS(13246),
    [sym_report_keyword] = ACTIONS(13242),
    [sym_query_keyword] = ACTIONS(13242),
    [anon_sym_xmlport] = ACTIONS(13248),
    [anon_sym_XMLPORT] = ACTIONS(13248),
    [anon_sym_Xmlport] = ACTIONS(13248),
    [anon_sym_XMLport] = ACTIONS(13248),
    [anon_sym_XMLPort] = ACTIONS(13248),
    [anon_sym_XmlPort] = ACTIONS(13248),
    [anon_sym_enum] = ACTIONS(13250),
    [anon_sym_ENUM] = ACTIONS(13250),
    [anon_sym_Enum] = ACTIONS(13250),
    [anon_sym_eNUM] = ACTIONS(13250),
    [anon_sym_eNum] = ACTIONS(13250),
    [anon_sym_ENum] = ACTIONS(13250),
    [sym_var_keyword] = ACTIONS(613),
    [sym_local_keyword] = ACTIONS(13601),
    [sym_internal_keyword] = ACTIONS(13232),
    [sym_protected_keyword] = ACTIONS(13601),
    [sym_key_keyword] = ACTIONS(13240),
    [sym_dataset_keyword] = ACTIONS(13240),
    [sym_quoted_identifier] = ACTIONS(13252),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(13252),
    [sym_integer] = ACTIONS(13252),
    [sym_preproc_open] = ACTIONS(611),
    [sym_begin_keyword] = ACTIONS(611),
  },
  [STATE(5422)] = {
    [sym__object_header] = STATE(10683),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5423)] = {
    [sym__object_header] = STATE(10902),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5424)] = {
    [sym__object_header] = STATE(10904),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5425)] = {
    [sym__object_header] = STATE(14382),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5426)] = {
    [sym__object_header] = STATE(14383),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5427)] = {
    [sym__object_header] = STATE(14397),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5428)] = {
    [sym__object_header] = STATE(11420),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5429)] = {
    [sym__object_header] = STATE(11014),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5430)] = {
    [sym_preproc_conditional_controladdin] = STATE(5420),
    [sym__body_element] = STATE(5420),
    [sym_empty_statement] = STATE(5420),
    [sym_property] = STATE(5420),
    [sym_permissions_property] = STATE(5420),
    [sym_table_relation_property] = STATE(5420),
    [sym_fields_section] = STATE(5420),
    [sym_keys_section] = STATE(5420),
    [sym_fieldgroups_section] = STATE(5420),
    [sym_enum_value_declaration] = STATE(5420),
    [sym_labels_section] = STATE(5420),
    [sym_layout_section] = STATE(5420),
    [sym_modify_modification] = STATE(5420),
    [sym_actions_section] = STATE(5420),
    [sym_views_section] = STATE(5420),
    [sym_dataset_section] = STATE(5420),
    [sym_requestpage_section] = STATE(5420),
    [sym_rendering_section] = STATE(5420),
    [sym_elements_section] = STATE(5420),
    [sym_schema_section] = STATE(5420),
    [sym_assembly_declaration] = STATE(5420),
    [sym_event_declaration] = STATE(5420),
    [sym_procedure] = STATE(5420),
    [sym_preproc_split_procedure] = STATE(5420),
    [sym_preproc_split_procedure_preamble] = STATE(5420),
    [sym_interface_procedure] = STATE(5420),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5420),
    [sym_var_section] = STATE(5420),
    [sym_attribute_item] = STATE(5420),
    [sym_preproc_conditional] = STATE(5420),
    [sym_preproc_if] = STATE(3599),
    [aux_sym_controladdin_declaration_repeat1] = STATE(5420),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13604),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5431)] = {
    [sym_preproc_conditional_controladdin] = STATE(5430),
    [sym__body_element] = STATE(5430),
    [sym_empty_statement] = STATE(5430),
    [sym_property] = STATE(5430),
    [sym_permissions_property] = STATE(5430),
    [sym_table_relation_property] = STATE(5430),
    [sym_fields_section] = STATE(5430),
    [sym_keys_section] = STATE(5430),
    [sym_fieldgroups_section] = STATE(5430),
    [sym_enum_value_declaration] = STATE(5430),
    [sym_labels_section] = STATE(5430),
    [sym_layout_section] = STATE(5430),
    [sym_modify_modification] = STATE(5430),
    [sym_actions_section] = STATE(5430),
    [sym_views_section] = STATE(5430),
    [sym_dataset_section] = STATE(5430),
    [sym_requestpage_section] = STATE(5430),
    [sym_rendering_section] = STATE(5430),
    [sym_elements_section] = STATE(5430),
    [sym_schema_section] = STATE(5430),
    [sym_assembly_declaration] = STATE(5430),
    [sym_event_declaration] = STATE(5430),
    [sym_procedure] = STATE(5430),
    [sym_preproc_split_procedure] = STATE(5430),
    [sym_preproc_split_procedure_preamble] = STATE(5430),
    [sym_interface_procedure] = STATE(5430),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5430),
    [sym_var_section] = STATE(5430),
    [sym_attribute_item] = STATE(5430),
    [sym_preproc_conditional] = STATE(5430),
    [sym_preproc_if] = STATE(3599),
    [aux_sym_controladdin_declaration_repeat1] = STATE(5430),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13606),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5432)] = {
    [sym__object_header] = STATE(13712),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5433)] = {
    [sym_preproc_conditional_controladdin] = STATE(5419),
    [sym__body_element] = STATE(5419),
    [sym_empty_statement] = STATE(5419),
    [sym_property] = STATE(5419),
    [sym_permissions_property] = STATE(5419),
    [sym_table_relation_property] = STATE(5419),
    [sym_fields_section] = STATE(5419),
    [sym_keys_section] = STATE(5419),
    [sym_fieldgroups_section] = STATE(5419),
    [sym_enum_value_declaration] = STATE(5419),
    [sym_labels_section] = STATE(5419),
    [sym_layout_section] = STATE(5419),
    [sym_modify_modification] = STATE(5419),
    [sym_actions_section] = STATE(5419),
    [sym_views_section] = STATE(5419),
    [sym_dataset_section] = STATE(5419),
    [sym_requestpage_section] = STATE(5419),
    [sym_rendering_section] = STATE(5419),
    [sym_elements_section] = STATE(5419),
    [sym_schema_section] = STATE(5419),
    [sym_assembly_declaration] = STATE(5419),
    [sym_event_declaration] = STATE(5419),
    [sym_procedure] = STATE(5419),
    [sym_preproc_split_procedure] = STATE(5419),
    [sym_preproc_split_procedure_preamble] = STATE(5419),
    [sym_interface_procedure] = STATE(5419),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5419),
    [sym_var_section] = STATE(5419),
    [sym_attribute_item] = STATE(5419),
    [sym_preproc_conditional] = STATE(5419),
    [sym_preproc_if] = STATE(3599),
    [aux_sym_controladdin_declaration_repeat1] = STATE(5419),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13608),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5434)] = {
    [sym__object_header] = STATE(14133),
    [sym_tableextension_keyword] = STATE(17366),
    [sym_pageextension_keyword] = STATE(17366),
    [sym_codeunit_keyword] = STATE(18056),
    [sym_reportextension_keyword] = STATE(17366),
    [sym_xmlport_keyword] = STATE(17065),
    [sym_enum_keyword] = STATE(18056),
    [sym_enumextension_keyword] = STATE(17366),
    [sym_permissionset_keyword] = STATE(17065),
    [sym_permissionsetextension_keyword] = STATE(17366),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(12136),
    [anon_sym_tableextension] = ACTIONS(11),
    [anon_sym_TABLEEXTENSION] = ACTIONS(11),
    [anon_sym_Tableextension] = ACTIONS(11),
    [anon_sym_TableExtension] = ACTIONS(11),
    [anon_sym_tableExtension] = ACTIONS(11),
    [sym_page_keyword] = ACTIONS(12136),
    [anon_sym_pageextension] = ACTIONS(15),
    [anon_sym_PAGEEXTENSION] = ACTIONS(15),
    [anon_sym_Pageextension] = ACTIONS(15),
    [anon_sym_PageExtension] = ACTIONS(15),
    [anon_sym_pageExtension] = ACTIONS(15),
    [anon_sym_codeunit] = ACTIONS(17),
    [anon_sym_CODEUNIT] = ACTIONS(17),
    [anon_sym_Codeunit] = ACTIONS(17),
    [anon_sym_CodeUnit] = ACTIONS(17),
    [anon_sym_COdeunit] = ACTIONS(17),
    [anon_sym_codeUnit] = ACTIONS(17),
    [sym_report_keyword] = ACTIONS(12136),
    [anon_sym_reportextension] = ACTIONS(21),
    [anon_sym_REPORTEXTENSION] = ACTIONS(21),
    [anon_sym_Reportextension] = ACTIONS(21),
    [anon_sym_ReportExtension] = ACTIONS(21),
    [anon_sym_reportExtension] = ACTIONS(21),
    [sym_query_keyword] = ACTIONS(12138),
    [anon_sym_xmlport] = ACTIONS(25),
    [anon_sym_XMLPORT] = ACTIONS(25),
    [anon_sym_Xmlport] = ACTIONS(25),
    [anon_sym_XMLport] = ACTIONS(25),
    [anon_sym_XMLPort] = ACTIONS(25),
    [anon_sym_XmlPort] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(29),
    [anon_sym_eNum] = ACTIONS(29),
    [anon_sym_ENum] = ACTIONS(29),
    [anon_sym_enumextension] = ACTIONS(31),
    [anon_sym_ENUMEXTENSION] = ACTIONS(31),
    [anon_sym_Enumextension] = ACTIONS(31),
    [anon_sym_EnumExtension] = ACTIONS(31),
    [anon_sym_enumExtension] = ACTIONS(31),
    [sym_interface_keyword] = ACTIONS(12140),
    [anon_sym_permissionset] = ACTIONS(43),
    [anon_sym_PERMISSIONSET] = ACTIONS(43),
    [anon_sym_Permissionset] = ACTIONS(43),
    [anon_sym_PermissionSet] = ACTIONS(43),
    [anon_sym_permissionSet] = ACTIONS(43),
    [anon_sym_permissionsetextension] = ACTIONS(45),
    [anon_sym_PERMISSIONSETEXTENSION] = ACTIONS(45),
    [anon_sym_Permissionsetextension] = ACTIONS(45),
    [anon_sym_PermissionSetExtension] = ACTIONS(45),
    [anon_sym_permissionSetExtension] = ACTIONS(45),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
  },
  [STATE(5435)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13610),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5436)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13612),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5437)] = {
    [sym__body_element] = STATE(5435),
    [sym_empty_statement] = STATE(5435),
    [sym_property] = STATE(5435),
    [sym_permissions_property] = STATE(5435),
    [sym_table_relation_property] = STATE(5435),
    [sym_fields_section] = STATE(5435),
    [sym_keys_section] = STATE(5435),
    [sym_fieldgroups_section] = STATE(5435),
    [sym_enum_value_declaration] = STATE(5435),
    [sym_labels_section] = STATE(5435),
    [sym_layout_section] = STATE(5435),
    [sym_modify_modification] = STATE(5435),
    [sym_actions_section] = STATE(5435),
    [sym_views_section] = STATE(5435),
    [sym_dataset_section] = STATE(5435),
    [sym_requestpage_section] = STATE(5435),
    [sym_rendering_section] = STATE(5435),
    [sym_elements_section] = STATE(5435),
    [sym_schema_section] = STATE(5435),
    [sym_assembly_declaration] = STATE(5435),
    [sym_event_declaration] = STATE(5435),
    [sym_procedure] = STATE(5435),
    [sym_preproc_split_procedure] = STATE(5435),
    [sym_preproc_split_procedure_preamble] = STATE(5435),
    [sym_interface_procedure] = STATE(5435),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5435),
    [sym_var_section] = STATE(5435),
    [sym_attribute_item] = STATE(5435),
    [sym_preproc_conditional] = STATE(5435),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5435),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13614),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5438)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13616),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5439)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(5452),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_DOT] = ACTIONS(13618),
    [anon_sym_RBRACE] = ACTIONS(3695),
    [aux_sym_where_clause_token1] = ACTIONS(3695),
    [aux_sym_where_condition_token1] = ACTIONS(3693),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3695),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3695),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3695),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [aux_sym_basic_type_token6] = ACTIONS(3693),
    [aux_sym_basic_type_token22] = ACTIONS(3693),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3695),
    [aux_sym_addafter_modification_token1] = ACTIONS(3695),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3695),
    [aux_sym_modify_modification_token1] = ACTIONS(3695),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3695),
    [aux_sym_movelast_modification_token1] = ACTIONS(3695),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3695),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3695),
    [aux_sym_separator_action_token1] = ACTIONS(3695),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3695),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3695),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3695),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3695),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3695),
    [anon_sym_POUNDif] = ACTIONS(3695),
    [anon_sym_POUNDIF] = ACTIONS(3695),
    [anon_sym_POUNDIf] = ACTIONS(3695),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3695),
    [sym_trigger_keyword] = ACTIONS(3695),
    [sym_var_keyword] = ACTIONS(3695),
    [sym_local_keyword] = ACTIONS(3695),
    [sym_internal_keyword] = ACTIONS(3695),
    [sym_protected_keyword] = ACTIONS(3695),
    [sym_event_keyword] = ACTIONS(3695),
    [sym_fields_keyword] = ACTIONS(3695),
    [sym_keys_keyword] = ACTIONS(3695),
    [sym_fieldgroups_keyword] = ACTIONS(3695),
    [sym_actions_keyword] = ACTIONS(3695),
    [sym_layout_keyword] = ACTIONS(3695),
    [sym_area_keyword] = ACTIONS(3695),
    [sym_group_keyword] = ACTIONS(3695),
    [sym_repeater_keyword] = ACTIONS(3695),
    [sym_cuegroup_keyword] = ACTIONS(3695),
    [sym_fixed_keyword] = ACTIONS(3695),
    [sym_grid_keyword] = ACTIONS(3695),
    [sym_part_keyword] = ACTIONS(3695),
    [sym_systempart_keyword] = ACTIONS(3695),
    [sym_usercontrol_keyword] = ACTIONS(3695),
    [sym_dataset_keyword] = ACTIONS(3695),
    [sym_elements_keyword] = ACTIONS(3695),
    [sym_dataitem_keyword] = ACTIONS(3695),
    [sym_column_keyword] = ACTIONS(3695),
    [sym_filter_keyword] = ACTIONS(3695),
    [sym_labels_keyword] = ACTIONS(3695),
    [sym_rendering_keyword] = ACTIONS(3695),
    [sym_requestpage_keyword] = ACTIONS(3695),
    [sym_schema_keyword] = ACTIONS(3695),
    [sym_views_keyword] = ACTIONS(3695),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3695),
    [sym_preproc_open] = ACTIONS(3695),
  },
  [STATE(5440)] = {
    [sym__body_element] = STATE(5449),
    [sym_empty_statement] = STATE(5449),
    [sym_property] = STATE(5449),
    [sym_permissions_property] = STATE(5449),
    [sym_table_relation_property] = STATE(5449),
    [sym_fields_section] = STATE(5449),
    [sym_keys_section] = STATE(5449),
    [sym_fieldgroups_section] = STATE(5449),
    [sym_enum_value_declaration] = STATE(5449),
    [sym_labels_section] = STATE(5449),
    [sym_layout_section] = STATE(5449),
    [sym_modify_modification] = STATE(5449),
    [sym_actions_section] = STATE(5449),
    [sym_views_section] = STATE(5449),
    [sym_dataset_section] = STATE(5449),
    [sym_requestpage_section] = STATE(5449),
    [sym_rendering_section] = STATE(5449),
    [sym_elements_section] = STATE(5449),
    [sym_schema_section] = STATE(5449),
    [sym_assembly_declaration] = STATE(5449),
    [sym_event_declaration] = STATE(5449),
    [sym_procedure] = STATE(5449),
    [sym_preproc_split_procedure] = STATE(5449),
    [sym_preproc_split_procedure_preamble] = STATE(5449),
    [sym_interface_procedure] = STATE(5449),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5449),
    [sym_var_section] = STATE(5449),
    [sym_attribute_item] = STATE(5449),
    [sym_preproc_conditional] = STATE(5449),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5449),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13620),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5441)] = {
    [sym__body_element] = STATE(5436),
    [sym_empty_statement] = STATE(5436),
    [sym_property] = STATE(5436),
    [sym_permissions_property] = STATE(5436),
    [sym_table_relation_property] = STATE(5436),
    [sym_fields_section] = STATE(5436),
    [sym_keys_section] = STATE(5436),
    [sym_fieldgroups_section] = STATE(5436),
    [sym_enum_value_declaration] = STATE(5436),
    [sym_labels_section] = STATE(5436),
    [sym_layout_section] = STATE(5436),
    [sym_modify_modification] = STATE(5436),
    [sym_actions_section] = STATE(5436),
    [sym_views_section] = STATE(5436),
    [sym_dataset_section] = STATE(5436),
    [sym_requestpage_section] = STATE(5436),
    [sym_rendering_section] = STATE(5436),
    [sym_elements_section] = STATE(5436),
    [sym_schema_section] = STATE(5436),
    [sym_assembly_declaration] = STATE(5436),
    [sym_event_declaration] = STATE(5436),
    [sym_procedure] = STATE(5436),
    [sym_preproc_split_procedure] = STATE(5436),
    [sym_preproc_split_procedure_preamble] = STATE(5436),
    [sym_interface_procedure] = STATE(5436),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5436),
    [sym_var_section] = STATE(5436),
    [sym_attribute_item] = STATE(5436),
    [sym_preproc_conditional] = STATE(5436),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5436),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13622),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5442)] = {
    [sym__body_element] = STATE(5448),
    [sym_empty_statement] = STATE(5448),
    [sym_property] = STATE(5448),
    [sym_permissions_property] = STATE(5448),
    [sym_table_relation_property] = STATE(5448),
    [sym_fields_section] = STATE(5448),
    [sym_keys_section] = STATE(5448),
    [sym_fieldgroups_section] = STATE(5448),
    [sym_enum_value_declaration] = STATE(5448),
    [sym_labels_section] = STATE(5448),
    [sym_layout_section] = STATE(5448),
    [sym_modify_modification] = STATE(5448),
    [sym_actions_section] = STATE(5448),
    [sym_views_section] = STATE(5448),
    [sym_dataset_section] = STATE(5448),
    [sym_requestpage_section] = STATE(5448),
    [sym_rendering_section] = STATE(5448),
    [sym_elements_section] = STATE(5448),
    [sym_schema_section] = STATE(5448),
    [sym_assembly_declaration] = STATE(5448),
    [sym_event_declaration] = STATE(5448),
    [sym_procedure] = STATE(5448),
    [sym_preproc_split_procedure] = STATE(5448),
    [sym_preproc_split_procedure_preamble] = STATE(5448),
    [sym_interface_procedure] = STATE(5448),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5448),
    [sym_var_section] = STATE(5448),
    [sym_attribute_item] = STATE(5448),
    [sym_preproc_conditional] = STATE(5448),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5448),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13624),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5443)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13626),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5444)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13628),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5445)] = {
    [sym__body_element] = STATE(5438),
    [sym_empty_statement] = STATE(5438),
    [sym_property] = STATE(5438),
    [sym_permissions_property] = STATE(5438),
    [sym_table_relation_property] = STATE(5438),
    [sym_fields_section] = STATE(5438),
    [sym_keys_section] = STATE(5438),
    [sym_fieldgroups_section] = STATE(5438),
    [sym_enum_value_declaration] = STATE(5438),
    [sym_labels_section] = STATE(5438),
    [sym_layout_section] = STATE(5438),
    [sym_modify_modification] = STATE(5438),
    [sym_actions_section] = STATE(5438),
    [sym_views_section] = STATE(5438),
    [sym_dataset_section] = STATE(5438),
    [sym_requestpage_section] = STATE(5438),
    [sym_rendering_section] = STATE(5438),
    [sym_elements_section] = STATE(5438),
    [sym_schema_section] = STATE(5438),
    [sym_assembly_declaration] = STATE(5438),
    [sym_event_declaration] = STATE(5438),
    [sym_procedure] = STATE(5438),
    [sym_preproc_split_procedure] = STATE(5438),
    [sym_preproc_split_procedure_preamble] = STATE(5438),
    [sym_interface_procedure] = STATE(5438),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5438),
    [sym_var_section] = STATE(5438),
    [sym_attribute_item] = STATE(5438),
    [sym_preproc_conditional] = STATE(5438),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5438),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13630),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5446)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(13632),
    [anon_sym_RBRACE] = ACTIONS(13635),
    [anon_sym_LBRACK] = ACTIONS(13637),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13640),
    [aux_sym_modify_modification_token1] = ACTIONS(13643),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13646),
    [anon_sym_POUNDif] = ACTIONS(13649),
    [anon_sym_POUNDIF] = ACTIONS(13649),
    [anon_sym_POUNDIf] = ACTIONS(13649),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13652),
    [sym_trigger_keyword] = ACTIONS(13655),
    [sym_var_keyword] = ACTIONS(13658),
    [sym_local_keyword] = ACTIONS(13661),
    [sym_internal_keyword] = ACTIONS(13664),
    [sym_protected_keyword] = ACTIONS(13661),
    [sym_event_keyword] = ACTIONS(13667),
    [sym_fields_keyword] = ACTIONS(13670),
    [sym_keys_keyword] = ACTIONS(13673),
    [sym_fieldgroups_keyword] = ACTIONS(13676),
    [sym_actions_keyword] = ACTIONS(13679),
    [sym_layout_keyword] = ACTIONS(13682),
    [sym_dataset_keyword] = ACTIONS(13685),
    [sym_elements_keyword] = ACTIONS(13688),
    [sym_labels_keyword] = ACTIONS(13691),
    [sym_rendering_keyword] = ACTIONS(13694),
    [sym_requestpage_keyword] = ACTIONS(13697),
    [sym_schema_keyword] = ACTIONS(13700),
    [sym_views_keyword] = ACTIONS(13703),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(13706),
    [sym_preproc_open] = ACTIONS(13649),
  },
  [STATE(5447)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(5447),
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(13709),
    [anon_sym_RBRACE] = ACTIONS(3705),
    [aux_sym_where_clause_token1] = ACTIONS(3705),
    [aux_sym_where_condition_token1] = ACTIONS(3703),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3705),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3705),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3705),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_basic_type_token6] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3705),
    [aux_sym_addafter_modification_token1] = ACTIONS(3705),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3705),
    [aux_sym_modify_modification_token1] = ACTIONS(3705),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3705),
    [aux_sym_movelast_modification_token1] = ACTIONS(3705),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3705),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3705),
    [aux_sym_separator_action_token1] = ACTIONS(3705),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3705),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3705),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3705),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3705),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3705),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3705),
    [sym_trigger_keyword] = ACTIONS(3705),
    [sym_var_keyword] = ACTIONS(3705),
    [sym_local_keyword] = ACTIONS(3705),
    [sym_internal_keyword] = ACTIONS(3705),
    [sym_protected_keyword] = ACTIONS(3705),
    [sym_event_keyword] = ACTIONS(3705),
    [sym_fields_keyword] = ACTIONS(3705),
    [sym_keys_keyword] = ACTIONS(3705),
    [sym_fieldgroups_keyword] = ACTIONS(3705),
    [sym_actions_keyword] = ACTIONS(3705),
    [sym_layout_keyword] = ACTIONS(3705),
    [sym_area_keyword] = ACTIONS(3705),
    [sym_group_keyword] = ACTIONS(3705),
    [sym_repeater_keyword] = ACTIONS(3705),
    [sym_cuegroup_keyword] = ACTIONS(3705),
    [sym_fixed_keyword] = ACTIONS(3705),
    [sym_grid_keyword] = ACTIONS(3705),
    [sym_part_keyword] = ACTIONS(3705),
    [sym_systempart_keyword] = ACTIONS(3705),
    [sym_usercontrol_keyword] = ACTIONS(3705),
    [sym_dataset_keyword] = ACTIONS(3705),
    [sym_elements_keyword] = ACTIONS(3705),
    [sym_dataitem_keyword] = ACTIONS(3705),
    [sym_column_keyword] = ACTIONS(3705),
    [sym_filter_keyword] = ACTIONS(3705),
    [sym_labels_keyword] = ACTIONS(3705),
    [sym_rendering_keyword] = ACTIONS(3705),
    [sym_requestpage_keyword] = ACTIONS(3705),
    [sym_schema_keyword] = ACTIONS(3705),
    [sym_views_keyword] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
  },
  [STATE(5448)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13712),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5449)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13714),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5450)] = {
    [sym__body_element] = STATE(5443),
    [sym_empty_statement] = STATE(5443),
    [sym_property] = STATE(5443),
    [sym_permissions_property] = STATE(5443),
    [sym_table_relation_property] = STATE(5443),
    [sym_fields_section] = STATE(5443),
    [sym_keys_section] = STATE(5443),
    [sym_fieldgroups_section] = STATE(5443),
    [sym_enum_value_declaration] = STATE(5443),
    [sym_labels_section] = STATE(5443),
    [sym_layout_section] = STATE(5443),
    [sym_modify_modification] = STATE(5443),
    [sym_actions_section] = STATE(5443),
    [sym_views_section] = STATE(5443),
    [sym_dataset_section] = STATE(5443),
    [sym_requestpage_section] = STATE(5443),
    [sym_rendering_section] = STATE(5443),
    [sym_elements_section] = STATE(5443),
    [sym_schema_section] = STATE(5443),
    [sym_assembly_declaration] = STATE(5443),
    [sym_event_declaration] = STATE(5443),
    [sym_procedure] = STATE(5443),
    [sym_preproc_split_procedure] = STATE(5443),
    [sym_preproc_split_procedure_preamble] = STATE(5443),
    [sym_interface_procedure] = STATE(5443),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5443),
    [sym_var_section] = STATE(5443),
    [sym_attribute_item] = STATE(5443),
    [sym_preproc_conditional] = STATE(5443),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5443),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13716),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5451)] = {
    [sym__body_element] = STATE(5454),
    [sym_empty_statement] = STATE(5454),
    [sym_property] = STATE(5454),
    [sym_permissions_property] = STATE(5454),
    [sym_table_relation_property] = STATE(5454),
    [sym_fields_section] = STATE(5454),
    [sym_keys_section] = STATE(5454),
    [sym_fieldgroups_section] = STATE(5454),
    [sym_enum_value_declaration] = STATE(5454),
    [sym_labels_section] = STATE(5454),
    [sym_layout_section] = STATE(5454),
    [sym_modify_modification] = STATE(5454),
    [sym_actions_section] = STATE(5454),
    [sym_views_section] = STATE(5454),
    [sym_dataset_section] = STATE(5454),
    [sym_requestpage_section] = STATE(5454),
    [sym_rendering_section] = STATE(5454),
    [sym_elements_section] = STATE(5454),
    [sym_schema_section] = STATE(5454),
    [sym_assembly_declaration] = STATE(5454),
    [sym_event_declaration] = STATE(5454),
    [sym_procedure] = STATE(5454),
    [sym_preproc_split_procedure] = STATE(5454),
    [sym_preproc_split_procedure_preamble] = STATE(5454),
    [sym_interface_procedure] = STATE(5454),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5454),
    [sym_var_section] = STATE(5454),
    [sym_attribute_item] = STATE(5454),
    [sym_preproc_conditional] = STATE(5454),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5454),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13718),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5452)] = {
    [aux_sym__namespaced_or_simple_ref_repeat1] = STATE(5447),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(13618),
    [anon_sym_RBRACE] = ACTIONS(3701),
    [aux_sym_where_clause_token1] = ACTIONS(3701),
    [aux_sym_where_condition_token1] = ACTIONS(3699),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3701),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3701),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3701),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [aux_sym_basic_type_token6] = ACTIONS(3699),
    [aux_sym_basic_type_token22] = ACTIONS(3699),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3701),
    [aux_sym_addafter_modification_token1] = ACTIONS(3701),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3701),
    [aux_sym_modify_modification_token1] = ACTIONS(3701),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3701),
    [aux_sym_movelast_modification_token1] = ACTIONS(3701),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3701),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3701),
    [aux_sym_separator_action_token1] = ACTIONS(3701),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3701),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3701),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3701),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3701),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3701),
    [anon_sym_POUNDif] = ACTIONS(3701),
    [anon_sym_POUNDIF] = ACTIONS(3701),
    [anon_sym_POUNDIf] = ACTIONS(3701),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3701),
    [sym_trigger_keyword] = ACTIONS(3701),
    [sym_var_keyword] = ACTIONS(3701),
    [sym_local_keyword] = ACTIONS(3701),
    [sym_internal_keyword] = ACTIONS(3701),
    [sym_protected_keyword] = ACTIONS(3701),
    [sym_event_keyword] = ACTIONS(3701),
    [sym_fields_keyword] = ACTIONS(3701),
    [sym_keys_keyword] = ACTIONS(3701),
    [sym_fieldgroups_keyword] = ACTIONS(3701),
    [sym_actions_keyword] = ACTIONS(3701),
    [sym_layout_keyword] = ACTIONS(3701),
    [sym_area_keyword] = ACTIONS(3701),
    [sym_group_keyword] = ACTIONS(3701),
    [sym_repeater_keyword] = ACTIONS(3701),
    [sym_cuegroup_keyword] = ACTIONS(3701),
    [sym_fixed_keyword] = ACTIONS(3701),
    [sym_grid_keyword] = ACTIONS(3701),
    [sym_part_keyword] = ACTIONS(3701),
    [sym_systempart_keyword] = ACTIONS(3701),
    [sym_usercontrol_keyword] = ACTIONS(3701),
    [sym_dataset_keyword] = ACTIONS(3701),
    [sym_elements_keyword] = ACTIONS(3701),
    [sym_dataitem_keyword] = ACTIONS(3701),
    [sym_column_keyword] = ACTIONS(3701),
    [sym_filter_keyword] = ACTIONS(3701),
    [sym_labels_keyword] = ACTIONS(3701),
    [sym_rendering_keyword] = ACTIONS(3701),
    [sym_requestpage_keyword] = ACTIONS(3701),
    [sym_schema_keyword] = ACTIONS(3701),
    [sym_views_keyword] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3701),
    [sym_preproc_open] = ACTIONS(3701),
  },
  [STATE(5453)] = {
    [sym__body_element] = STATE(5444),
    [sym_empty_statement] = STATE(5444),
    [sym_property] = STATE(5444),
    [sym_permissions_property] = STATE(5444),
    [sym_table_relation_property] = STATE(5444),
    [sym_fields_section] = STATE(5444),
    [sym_keys_section] = STATE(5444),
    [sym_fieldgroups_section] = STATE(5444),
    [sym_enum_value_declaration] = STATE(5444),
    [sym_labels_section] = STATE(5444),
    [sym_layout_section] = STATE(5444),
    [sym_modify_modification] = STATE(5444),
    [sym_actions_section] = STATE(5444),
    [sym_views_section] = STATE(5444),
    [sym_dataset_section] = STATE(5444),
    [sym_requestpage_section] = STATE(5444),
    [sym_rendering_section] = STATE(5444),
    [sym_elements_section] = STATE(5444),
    [sym_schema_section] = STATE(5444),
    [sym_assembly_declaration] = STATE(5444),
    [sym_event_declaration] = STATE(5444),
    [sym_procedure] = STATE(5444),
    [sym_preproc_split_procedure] = STATE(5444),
    [sym_preproc_split_procedure_preamble] = STATE(5444),
    [sym_interface_procedure] = STATE(5444),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5444),
    [sym_var_section] = STATE(5444),
    [sym_attribute_item] = STATE(5444),
    [sym_preproc_conditional] = STATE(5444),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5444),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13720),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5454)] = {
    [sym__body_element] = STATE(5446),
    [sym_empty_statement] = STATE(5446),
    [sym_property] = STATE(5446),
    [sym_permissions_property] = STATE(5446),
    [sym_table_relation_property] = STATE(5446),
    [sym_fields_section] = STATE(5446),
    [sym_keys_section] = STATE(5446),
    [sym_fieldgroups_section] = STATE(5446),
    [sym_enum_value_declaration] = STATE(5446),
    [sym_labels_section] = STATE(5446),
    [sym_layout_section] = STATE(5446),
    [sym_modify_modification] = STATE(5446),
    [sym_actions_section] = STATE(5446),
    [sym_views_section] = STATE(5446),
    [sym_dataset_section] = STATE(5446),
    [sym_requestpage_section] = STATE(5446),
    [sym_rendering_section] = STATE(5446),
    [sym_elements_section] = STATE(5446),
    [sym_schema_section] = STATE(5446),
    [sym_assembly_declaration] = STATE(5446),
    [sym_event_declaration] = STATE(5446),
    [sym_procedure] = STATE(5446),
    [sym_preproc_split_procedure] = STATE(5446),
    [sym_preproc_split_procedure_preamble] = STATE(5446),
    [sym_interface_procedure] = STATE(5446),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5446),
    [sym_var_section] = STATE(5446),
    [sym_attribute_item] = STATE(5446),
    [sym_preproc_conditional] = STATE(5446),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_interface_declaration_repeat1] = STATE(5446),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13722),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(13530),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5455)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13724),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5456)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13726),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5457)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13728),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5458)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13730),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5459)] = {
    [sym__body_element] = STATE(5600),
    [sym_empty_statement] = STATE(5600),
    [sym_property] = STATE(5600),
    [sym_permissions_property] = STATE(5600),
    [sym_table_relation_property] = STATE(5600),
    [sym_fields_section] = STATE(5600),
    [sym_keys_section] = STATE(5600),
    [sym_fieldgroups_section] = STATE(5600),
    [sym_enum_value_declaration] = STATE(5600),
    [sym_labels_section] = STATE(5600),
    [sym_layout_section] = STATE(5600),
    [sym_modify_modification] = STATE(5600),
    [sym_actions_section] = STATE(5600),
    [sym_views_section] = STATE(5600),
    [sym_dataset_section] = STATE(5600),
    [sym_requestpage_section] = STATE(5600),
    [sym_rendering_section] = STATE(5600),
    [sym_elements_section] = STATE(5600),
    [sym_schema_section] = STATE(5600),
    [sym_assembly_declaration] = STATE(5600),
    [sym_event_declaration] = STATE(5600),
    [sym_procedure] = STATE(5600),
    [sym_preproc_split_procedure] = STATE(5600),
    [sym_preproc_split_procedure_preamble] = STATE(5600),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5600),
    [sym_var_section] = STATE(5600),
    [sym_attribute_item] = STATE(5600),
    [sym_preproc_conditional] = STATE(5600),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5600),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13732),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5460)] = {
    [sym__body_element] = STATE(5474),
    [sym_empty_statement] = STATE(5474),
    [sym_property] = STATE(5474),
    [sym_permissions_property] = STATE(5474),
    [sym_table_relation_property] = STATE(5474),
    [sym_fields_section] = STATE(5474),
    [sym_keys_section] = STATE(5474),
    [sym_fieldgroups_section] = STATE(5474),
    [sym_enum_value_declaration] = STATE(5474),
    [sym_labels_section] = STATE(5474),
    [sym_layout_section] = STATE(5474),
    [sym_modify_modification] = STATE(5474),
    [sym_actions_section] = STATE(5474),
    [sym_views_section] = STATE(5474),
    [sym_dataset_section] = STATE(5474),
    [sym_requestpage_section] = STATE(5474),
    [sym_rendering_section] = STATE(5474),
    [sym_elements_section] = STATE(5474),
    [sym_schema_section] = STATE(5474),
    [sym_assembly_declaration] = STATE(5474),
    [sym_event_declaration] = STATE(5474),
    [sym_procedure] = STATE(5474),
    [sym_preproc_split_procedure] = STATE(5474),
    [sym_preproc_split_procedure_preamble] = STATE(5474),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5474),
    [sym_var_section] = STATE(5474),
    [sym_attribute_item] = STATE(5474),
    [sym_preproc_conditional] = STATE(5474),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5474),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13734),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5461)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13736),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5462)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13738),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5463)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13740),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5464)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13742),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5465)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13744),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5466)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13746),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5467)] = {
    [sym__body_element] = STATE(5559),
    [sym_empty_statement] = STATE(5559),
    [sym_property] = STATE(5559),
    [sym_permissions_property] = STATE(5559),
    [sym_table_relation_property] = STATE(5559),
    [sym_fields_section] = STATE(5559),
    [sym_keys_section] = STATE(5559),
    [sym_fieldgroups_section] = STATE(5559),
    [sym_enum_value_declaration] = STATE(5559),
    [sym_labels_section] = STATE(5559),
    [sym_layout_section] = STATE(5559),
    [sym_modify_modification] = STATE(5559),
    [sym_actions_section] = STATE(5559),
    [sym_views_section] = STATE(5559),
    [sym_dataset_section] = STATE(5559),
    [sym_requestpage_section] = STATE(5559),
    [sym_rendering_section] = STATE(5559),
    [sym_elements_section] = STATE(5559),
    [sym_schema_section] = STATE(5559),
    [sym_assembly_declaration] = STATE(5559),
    [sym_event_declaration] = STATE(5559),
    [sym_procedure] = STATE(5559),
    [sym_preproc_split_procedure] = STATE(5559),
    [sym_preproc_split_procedure_preamble] = STATE(5559),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5559),
    [sym_var_section] = STATE(5559),
    [sym_attribute_item] = STATE(5559),
    [sym_preproc_conditional] = STATE(5559),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5559),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13748),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5468)] = {
    [sym__body_element] = STATE(5560),
    [sym_empty_statement] = STATE(5560),
    [sym_property] = STATE(5560),
    [sym_permissions_property] = STATE(5560),
    [sym_table_relation_property] = STATE(5560),
    [sym_fields_section] = STATE(5560),
    [sym_keys_section] = STATE(5560),
    [sym_fieldgroups_section] = STATE(5560),
    [sym_enum_value_declaration] = STATE(5560),
    [sym_labels_section] = STATE(5560),
    [sym_layout_section] = STATE(5560),
    [sym_modify_modification] = STATE(5560),
    [sym_actions_section] = STATE(5560),
    [sym_views_section] = STATE(5560),
    [sym_dataset_section] = STATE(5560),
    [sym_requestpage_section] = STATE(5560),
    [sym_rendering_section] = STATE(5560),
    [sym_elements_section] = STATE(5560),
    [sym_schema_section] = STATE(5560),
    [sym_assembly_declaration] = STATE(5560),
    [sym_event_declaration] = STATE(5560),
    [sym_procedure] = STATE(5560),
    [sym_preproc_split_procedure] = STATE(5560),
    [sym_preproc_split_procedure_preamble] = STATE(5560),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5560),
    [sym_var_section] = STATE(5560),
    [sym_attribute_item] = STATE(5560),
    [sym_preproc_conditional] = STATE(5560),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5560),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13750),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5469)] = {
    [sym__body_element] = STATE(5561),
    [sym_empty_statement] = STATE(5561),
    [sym_property] = STATE(5561),
    [sym_permissions_property] = STATE(5561),
    [sym_table_relation_property] = STATE(5561),
    [sym_fields_section] = STATE(5561),
    [sym_keys_section] = STATE(5561),
    [sym_fieldgroups_section] = STATE(5561),
    [sym_enum_value_declaration] = STATE(5561),
    [sym_labels_section] = STATE(5561),
    [sym_layout_section] = STATE(5561),
    [sym_modify_modification] = STATE(5561),
    [sym_actions_section] = STATE(5561),
    [sym_views_section] = STATE(5561),
    [sym_dataset_section] = STATE(5561),
    [sym_requestpage_section] = STATE(5561),
    [sym_rendering_section] = STATE(5561),
    [sym_elements_section] = STATE(5561),
    [sym_schema_section] = STATE(5561),
    [sym_assembly_declaration] = STATE(5561),
    [sym_event_declaration] = STATE(5561),
    [sym_procedure] = STATE(5561),
    [sym_preproc_split_procedure] = STATE(5561),
    [sym_preproc_split_procedure_preamble] = STATE(5561),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5561),
    [sym_var_section] = STATE(5561),
    [sym_attribute_item] = STATE(5561),
    [sym_preproc_conditional] = STATE(5561),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5561),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13752),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5470)] = {
    [sym__body_element] = STATE(5466),
    [sym_empty_statement] = STATE(5466),
    [sym_property] = STATE(5466),
    [sym_permissions_property] = STATE(5466),
    [sym_table_relation_property] = STATE(5466),
    [sym_fields_section] = STATE(5466),
    [sym_keys_section] = STATE(5466),
    [sym_fieldgroups_section] = STATE(5466),
    [sym_enum_value_declaration] = STATE(5466),
    [sym_labels_section] = STATE(5466),
    [sym_layout_section] = STATE(5466),
    [sym_modify_modification] = STATE(5466),
    [sym_actions_section] = STATE(5466),
    [sym_views_section] = STATE(5466),
    [sym_dataset_section] = STATE(5466),
    [sym_requestpage_section] = STATE(5466),
    [sym_rendering_section] = STATE(5466),
    [sym_elements_section] = STATE(5466),
    [sym_schema_section] = STATE(5466),
    [sym_assembly_declaration] = STATE(5466),
    [sym_event_declaration] = STATE(5466),
    [sym_procedure] = STATE(5466),
    [sym_preproc_split_procedure] = STATE(5466),
    [sym_preproc_split_procedure_preamble] = STATE(5466),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5466),
    [sym_var_section] = STATE(5466),
    [sym_attribute_item] = STATE(5466),
    [sym_preproc_conditional] = STATE(5466),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5466),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13754),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5471)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13756),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5472)] = {
    [sym__body_element] = STATE(5562),
    [sym_empty_statement] = STATE(5562),
    [sym_property] = STATE(5562),
    [sym_permissions_property] = STATE(5562),
    [sym_table_relation_property] = STATE(5562),
    [sym_fields_section] = STATE(5562),
    [sym_keys_section] = STATE(5562),
    [sym_fieldgroups_section] = STATE(5562),
    [sym_enum_value_declaration] = STATE(5562),
    [sym_labels_section] = STATE(5562),
    [sym_layout_section] = STATE(5562),
    [sym_modify_modification] = STATE(5562),
    [sym_actions_section] = STATE(5562),
    [sym_views_section] = STATE(5562),
    [sym_dataset_section] = STATE(5562),
    [sym_requestpage_section] = STATE(5562),
    [sym_rendering_section] = STATE(5562),
    [sym_elements_section] = STATE(5562),
    [sym_schema_section] = STATE(5562),
    [sym_assembly_declaration] = STATE(5562),
    [sym_event_declaration] = STATE(5562),
    [sym_procedure] = STATE(5562),
    [sym_preproc_split_procedure] = STATE(5562),
    [sym_preproc_split_procedure_preamble] = STATE(5562),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5562),
    [sym_var_section] = STATE(5562),
    [sym_attribute_item] = STATE(5562),
    [sym_preproc_conditional] = STATE(5562),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5562),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13758),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5473)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13760),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5474)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13762),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5475)] = {
    [sym__body_element] = STATE(5478),
    [sym_empty_statement] = STATE(5478),
    [sym_property] = STATE(5478),
    [sym_permissions_property] = STATE(5478),
    [sym_table_relation_property] = STATE(5478),
    [sym_fields_section] = STATE(5478),
    [sym_keys_section] = STATE(5478),
    [sym_fieldgroups_section] = STATE(5478),
    [sym_enum_value_declaration] = STATE(5478),
    [sym_labels_section] = STATE(5478),
    [sym_layout_section] = STATE(5478),
    [sym_modify_modification] = STATE(5478),
    [sym_actions_section] = STATE(5478),
    [sym_views_section] = STATE(5478),
    [sym_dataset_section] = STATE(5478),
    [sym_requestpage_section] = STATE(5478),
    [sym_rendering_section] = STATE(5478),
    [sym_elements_section] = STATE(5478),
    [sym_schema_section] = STATE(5478),
    [sym_assembly_declaration] = STATE(5478),
    [sym_event_declaration] = STATE(5478),
    [sym_procedure] = STATE(5478),
    [sym_preproc_split_procedure] = STATE(5478),
    [sym_preproc_split_procedure_preamble] = STATE(5478),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5478),
    [sym_var_section] = STATE(5478),
    [sym_attribute_item] = STATE(5478),
    [sym_preproc_conditional] = STATE(5478),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5478),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13764),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5476)] = {
    [sym__body_element] = STATE(5702),
    [sym_empty_statement] = STATE(5702),
    [sym_property] = STATE(5702),
    [sym_permissions_property] = STATE(5702),
    [sym_table_relation_property] = STATE(5702),
    [sym_fields_section] = STATE(5702),
    [sym_keys_section] = STATE(5702),
    [sym_fieldgroups_section] = STATE(5702),
    [sym_enum_value_declaration] = STATE(5702),
    [sym_labels_section] = STATE(5702),
    [sym_layout_section] = STATE(5702),
    [sym_modify_modification] = STATE(5702),
    [sym_actions_section] = STATE(5702),
    [sym_views_section] = STATE(5702),
    [sym_dataset_section] = STATE(5702),
    [sym_requestpage_section] = STATE(5702),
    [sym_rendering_section] = STATE(5702),
    [sym_elements_section] = STATE(5702),
    [sym_schema_section] = STATE(5702),
    [sym_assembly_declaration] = STATE(5702),
    [sym_event_declaration] = STATE(5702),
    [sym_procedure] = STATE(5702),
    [sym_preproc_split_procedure] = STATE(5702),
    [sym_preproc_split_procedure_preamble] = STATE(5702),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5702),
    [sym_var_section] = STATE(5702),
    [sym_attribute_item] = STATE(5702),
    [sym_preproc_conditional] = STATE(5702),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5702),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13766),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5477)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13768),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5478)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13770),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5479)] = {
    [sym__body_element] = STATE(5471),
    [sym_empty_statement] = STATE(5471),
    [sym_property] = STATE(5471),
    [sym_permissions_property] = STATE(5471),
    [sym_table_relation_property] = STATE(5471),
    [sym_fields_section] = STATE(5471),
    [sym_keys_section] = STATE(5471),
    [sym_fieldgroups_section] = STATE(5471),
    [sym_enum_value_declaration] = STATE(5471),
    [sym_labels_section] = STATE(5471),
    [sym_layout_section] = STATE(5471),
    [sym_modify_modification] = STATE(5471),
    [sym_actions_section] = STATE(5471),
    [sym_views_section] = STATE(5471),
    [sym_dataset_section] = STATE(5471),
    [sym_requestpage_section] = STATE(5471),
    [sym_rendering_section] = STATE(5471),
    [sym_elements_section] = STATE(5471),
    [sym_schema_section] = STATE(5471),
    [sym_assembly_declaration] = STATE(5471),
    [sym_event_declaration] = STATE(5471),
    [sym_procedure] = STATE(5471),
    [sym_preproc_split_procedure] = STATE(5471),
    [sym_preproc_split_procedure_preamble] = STATE(5471),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5471),
    [sym_var_section] = STATE(5471),
    [sym_attribute_item] = STATE(5471),
    [sym_preproc_conditional] = STATE(5471),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5471),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13772),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5480)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13774),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5481)] = {
    [sym_identifier] = ACTIONS(6176),
    [anon_sym_SEMI] = ACTIONS(6178),
    [anon_sym_RBRACE] = ACTIONS(6178),
    [aux_sym_where_condition_token1] = ACTIONS(6176),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6176),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6176),
    [anon_sym_LBRACK] = ACTIONS(6178),
    [aux_sym_basic_type_token6] = ACTIONS(6176),
    [aux_sym_basic_type_token22] = ACTIONS(6176),
    [aux_sym_basic_type_token53] = ACTIONS(6176),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6176),
    [aux_sym_addafter_modification_token1] = ACTIONS(6176),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6176),
    [aux_sym_modify_modification_token1] = ACTIONS(6176),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6176),
    [aux_sym_movelast_modification_token1] = ACTIONS(6176),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6176),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6176),
    [aux_sym_separator_action_token1] = ACTIONS(6176),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6176),
    [aux_sym_type_declaration_token1] = ACTIONS(6176),
    [anon_sym_POUNDif] = ACTIONS(6178),
    [anon_sym_POUNDIF] = ACTIONS(6178),
    [anon_sym_POUNDIf] = ACTIONS(6178),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6176),
    [sym_procedure_keyword] = ACTIONS(6176),
    [sym_trigger_keyword] = ACTIONS(6176),
    [sym_var_keyword] = ACTIONS(6176),
    [sym_local_keyword] = ACTIONS(6176),
    [sym_internal_keyword] = ACTIONS(6176),
    [sym_protected_keyword] = ACTIONS(6176),
    [sym_event_keyword] = ACTIONS(6176),
    [sym_fields_keyword] = ACTIONS(6176),
    [sym_keys_keyword] = ACTIONS(6176),
    [sym_key_keyword] = ACTIONS(6176),
    [sym_fieldgroups_keyword] = ACTIONS(6176),
    [sym_actions_keyword] = ACTIONS(6176),
    [sym_layout_keyword] = ACTIONS(6176),
    [sym_area_keyword] = ACTIONS(6176),
    [sym_group_keyword] = ACTIONS(6176),
    [sym_repeater_keyword] = ACTIONS(6176),
    [sym_cuegroup_keyword] = ACTIONS(6176),
    [sym_fixed_keyword] = ACTIONS(6176),
    [sym_grid_keyword] = ACTIONS(6176),
    [sym_part_keyword] = ACTIONS(6176),
    [sym_systempart_keyword] = ACTIONS(6176),
    [sym_usercontrol_keyword] = ACTIONS(6176),
    [sym_dataset_keyword] = ACTIONS(6176),
    [sym_elements_keyword] = ACTIONS(6176),
    [sym_dataitem_keyword] = ACTIONS(6176),
    [sym_column_keyword] = ACTIONS(6176),
    [sym_filter_keyword] = ACTIONS(6176),
    [sym_labels_keyword] = ACTIONS(6176),
    [sym_rendering_keyword] = ACTIONS(6176),
    [sym_requestpage_keyword] = ACTIONS(6176),
    [sym_schema_keyword] = ACTIONS(6176),
    [sym_views_keyword] = ACTIONS(6176),
    [sym_quoted_identifier] = ACTIONS(6178),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6178),
    [sym_preproc_open] = ACTIONS(6178),
    [sym_var_attribute_open] = ACTIONS(6178),
  },
  [STATE(5482)] = {
    [sym_identifier] = ACTIONS(6180),
    [anon_sym_SEMI] = ACTIONS(6182),
    [anon_sym_RBRACE] = ACTIONS(6182),
    [aux_sym_where_condition_token1] = ACTIONS(6180),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6180),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6180),
    [anon_sym_LBRACK] = ACTIONS(6182),
    [aux_sym_basic_type_token6] = ACTIONS(6180),
    [aux_sym_basic_type_token22] = ACTIONS(6180),
    [aux_sym_basic_type_token53] = ACTIONS(6180),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6180),
    [aux_sym_addafter_modification_token1] = ACTIONS(6180),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6180),
    [aux_sym_modify_modification_token1] = ACTIONS(6180),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6180),
    [aux_sym_movelast_modification_token1] = ACTIONS(6180),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6180),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6180),
    [aux_sym_separator_action_token1] = ACTIONS(6180),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6180),
    [aux_sym_type_declaration_token1] = ACTIONS(6180),
    [anon_sym_POUNDif] = ACTIONS(6182),
    [anon_sym_POUNDIF] = ACTIONS(6182),
    [anon_sym_POUNDIf] = ACTIONS(6182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6180),
    [sym_procedure_keyword] = ACTIONS(6180),
    [sym_trigger_keyword] = ACTIONS(6180),
    [sym_var_keyword] = ACTIONS(6180),
    [sym_local_keyword] = ACTIONS(6180),
    [sym_internal_keyword] = ACTIONS(6180),
    [sym_protected_keyword] = ACTIONS(6180),
    [sym_event_keyword] = ACTIONS(6180),
    [sym_fields_keyword] = ACTIONS(6180),
    [sym_keys_keyword] = ACTIONS(6180),
    [sym_key_keyword] = ACTIONS(6180),
    [sym_fieldgroups_keyword] = ACTIONS(6180),
    [sym_actions_keyword] = ACTIONS(6180),
    [sym_layout_keyword] = ACTIONS(6180),
    [sym_area_keyword] = ACTIONS(6180),
    [sym_group_keyword] = ACTIONS(6180),
    [sym_repeater_keyword] = ACTIONS(6180),
    [sym_cuegroup_keyword] = ACTIONS(6180),
    [sym_fixed_keyword] = ACTIONS(6180),
    [sym_grid_keyword] = ACTIONS(6180),
    [sym_part_keyword] = ACTIONS(6180),
    [sym_systempart_keyword] = ACTIONS(6180),
    [sym_usercontrol_keyword] = ACTIONS(6180),
    [sym_dataset_keyword] = ACTIONS(6180),
    [sym_elements_keyword] = ACTIONS(6180),
    [sym_dataitem_keyword] = ACTIONS(6180),
    [sym_column_keyword] = ACTIONS(6180),
    [sym_filter_keyword] = ACTIONS(6180),
    [sym_labels_keyword] = ACTIONS(6180),
    [sym_rendering_keyword] = ACTIONS(6180),
    [sym_requestpage_keyword] = ACTIONS(6180),
    [sym_schema_keyword] = ACTIONS(6180),
    [sym_views_keyword] = ACTIONS(6180),
    [sym_quoted_identifier] = ACTIONS(6182),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6182),
    [sym_preproc_open] = ACTIONS(6182),
    [sym_var_attribute_open] = ACTIONS(6182),
  },
  [STATE(5483)] = {
    [sym_identifier] = ACTIONS(6184),
    [anon_sym_SEMI] = ACTIONS(6186),
    [anon_sym_RBRACE] = ACTIONS(6186),
    [aux_sym_where_condition_token1] = ACTIONS(6184),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6184),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6184),
    [anon_sym_LBRACK] = ACTIONS(6186),
    [aux_sym_basic_type_token6] = ACTIONS(6184),
    [aux_sym_basic_type_token22] = ACTIONS(6184),
    [aux_sym_basic_type_token53] = ACTIONS(6184),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6184),
    [aux_sym_addafter_modification_token1] = ACTIONS(6184),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6184),
    [aux_sym_modify_modification_token1] = ACTIONS(6184),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6184),
    [aux_sym_movelast_modification_token1] = ACTIONS(6184),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6184),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6184),
    [aux_sym_separator_action_token1] = ACTIONS(6184),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6184),
    [aux_sym_type_declaration_token1] = ACTIONS(6184),
    [anon_sym_POUNDif] = ACTIONS(6186),
    [anon_sym_POUNDIF] = ACTIONS(6186),
    [anon_sym_POUNDIf] = ACTIONS(6186),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6184),
    [sym_procedure_keyword] = ACTIONS(6184),
    [sym_trigger_keyword] = ACTIONS(6184),
    [sym_var_keyword] = ACTIONS(6184),
    [sym_local_keyword] = ACTIONS(6184),
    [sym_internal_keyword] = ACTIONS(6184),
    [sym_protected_keyword] = ACTIONS(6184),
    [sym_event_keyword] = ACTIONS(6184),
    [sym_fields_keyword] = ACTIONS(6184),
    [sym_keys_keyword] = ACTIONS(6184),
    [sym_key_keyword] = ACTIONS(6184),
    [sym_fieldgroups_keyword] = ACTIONS(6184),
    [sym_actions_keyword] = ACTIONS(6184),
    [sym_layout_keyword] = ACTIONS(6184),
    [sym_area_keyword] = ACTIONS(6184),
    [sym_group_keyword] = ACTIONS(6184),
    [sym_repeater_keyword] = ACTIONS(6184),
    [sym_cuegroup_keyword] = ACTIONS(6184),
    [sym_fixed_keyword] = ACTIONS(6184),
    [sym_grid_keyword] = ACTIONS(6184),
    [sym_part_keyword] = ACTIONS(6184),
    [sym_systempart_keyword] = ACTIONS(6184),
    [sym_usercontrol_keyword] = ACTIONS(6184),
    [sym_dataset_keyword] = ACTIONS(6184),
    [sym_elements_keyword] = ACTIONS(6184),
    [sym_dataitem_keyword] = ACTIONS(6184),
    [sym_column_keyword] = ACTIONS(6184),
    [sym_filter_keyword] = ACTIONS(6184),
    [sym_labels_keyword] = ACTIONS(6184),
    [sym_rendering_keyword] = ACTIONS(6184),
    [sym_requestpage_keyword] = ACTIONS(6184),
    [sym_schema_keyword] = ACTIONS(6184),
    [sym_views_keyword] = ACTIONS(6184),
    [sym_quoted_identifier] = ACTIONS(6186),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6186),
    [sym_preproc_open] = ACTIONS(6186),
    [sym_var_attribute_open] = ACTIONS(6186),
  },
  [STATE(5484)] = {
    [sym_identifier] = ACTIONS(6188),
    [anon_sym_SEMI] = ACTIONS(6190),
    [anon_sym_RBRACE] = ACTIONS(6190),
    [aux_sym_where_condition_token1] = ACTIONS(6188),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6188),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6188),
    [anon_sym_LBRACK] = ACTIONS(6190),
    [aux_sym_basic_type_token6] = ACTIONS(6188),
    [aux_sym_basic_type_token22] = ACTIONS(6188),
    [aux_sym_basic_type_token53] = ACTIONS(6188),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6188),
    [aux_sym_addafter_modification_token1] = ACTIONS(6188),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6188),
    [aux_sym_modify_modification_token1] = ACTIONS(6188),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6188),
    [aux_sym_movelast_modification_token1] = ACTIONS(6188),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6188),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6188),
    [aux_sym_separator_action_token1] = ACTIONS(6188),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6188),
    [aux_sym_type_declaration_token1] = ACTIONS(6188),
    [anon_sym_POUNDif] = ACTIONS(6190),
    [anon_sym_POUNDIF] = ACTIONS(6190),
    [anon_sym_POUNDIf] = ACTIONS(6190),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6188),
    [sym_procedure_keyword] = ACTIONS(6188),
    [sym_trigger_keyword] = ACTIONS(6188),
    [sym_var_keyword] = ACTIONS(6188),
    [sym_local_keyword] = ACTIONS(6188),
    [sym_internal_keyword] = ACTIONS(6188),
    [sym_protected_keyword] = ACTIONS(6188),
    [sym_event_keyword] = ACTIONS(6188),
    [sym_fields_keyword] = ACTIONS(6188),
    [sym_keys_keyword] = ACTIONS(6188),
    [sym_key_keyword] = ACTIONS(6188),
    [sym_fieldgroups_keyword] = ACTIONS(6188),
    [sym_actions_keyword] = ACTIONS(6188),
    [sym_layout_keyword] = ACTIONS(6188),
    [sym_area_keyword] = ACTIONS(6188),
    [sym_group_keyword] = ACTIONS(6188),
    [sym_repeater_keyword] = ACTIONS(6188),
    [sym_cuegroup_keyword] = ACTIONS(6188),
    [sym_fixed_keyword] = ACTIONS(6188),
    [sym_grid_keyword] = ACTIONS(6188),
    [sym_part_keyword] = ACTIONS(6188),
    [sym_systempart_keyword] = ACTIONS(6188),
    [sym_usercontrol_keyword] = ACTIONS(6188),
    [sym_dataset_keyword] = ACTIONS(6188),
    [sym_elements_keyword] = ACTIONS(6188),
    [sym_dataitem_keyword] = ACTIONS(6188),
    [sym_column_keyword] = ACTIONS(6188),
    [sym_filter_keyword] = ACTIONS(6188),
    [sym_labels_keyword] = ACTIONS(6188),
    [sym_rendering_keyword] = ACTIONS(6188),
    [sym_requestpage_keyword] = ACTIONS(6188),
    [sym_schema_keyword] = ACTIONS(6188),
    [sym_views_keyword] = ACTIONS(6188),
    [sym_quoted_identifier] = ACTIONS(6190),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6190),
    [sym_preproc_open] = ACTIONS(6190),
    [sym_var_attribute_open] = ACTIONS(6190),
  },
  [STATE(5485)] = {
    [sym__body_element] = STATE(5621),
    [sym_empty_statement] = STATE(5621),
    [sym_property] = STATE(5621),
    [sym_permissions_property] = STATE(5621),
    [sym_table_relation_property] = STATE(5621),
    [sym_fields_section] = STATE(5621),
    [sym_keys_section] = STATE(5621),
    [sym_fieldgroups_section] = STATE(5621),
    [sym_enum_value_declaration] = STATE(5621),
    [sym_labels_section] = STATE(5621),
    [sym_layout_section] = STATE(5621),
    [sym_modify_modification] = STATE(5621),
    [sym_actions_section] = STATE(5621),
    [sym_views_section] = STATE(5621),
    [sym_dataset_section] = STATE(5621),
    [sym_requestpage_section] = STATE(5621),
    [sym_rendering_section] = STATE(5621),
    [sym_elements_section] = STATE(5621),
    [sym_schema_section] = STATE(5621),
    [sym_assembly_declaration] = STATE(5621),
    [sym_event_declaration] = STATE(5621),
    [sym_procedure] = STATE(5621),
    [sym_preproc_split_procedure] = STATE(5621),
    [sym_preproc_split_procedure_preamble] = STATE(5621),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5621),
    [sym_var_section] = STATE(5621),
    [sym_attribute_item] = STATE(5621),
    [sym_preproc_conditional] = STATE(5621),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5621),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13776),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5486)] = {
    [sym__body_element] = STATE(5499),
    [sym_empty_statement] = STATE(5499),
    [sym_property] = STATE(5499),
    [sym_permissions_property] = STATE(5499),
    [sym_table_relation_property] = STATE(5499),
    [sym_fields_section] = STATE(5499),
    [sym_keys_section] = STATE(5499),
    [sym_fieldgroups_section] = STATE(5499),
    [sym_enum_value_declaration] = STATE(5499),
    [sym_labels_section] = STATE(5499),
    [sym_layout_section] = STATE(5499),
    [sym_modify_modification] = STATE(5499),
    [sym_actions_section] = STATE(5499),
    [sym_views_section] = STATE(5499),
    [sym_dataset_section] = STATE(5499),
    [sym_requestpage_section] = STATE(5499),
    [sym_rendering_section] = STATE(5499),
    [sym_elements_section] = STATE(5499),
    [sym_schema_section] = STATE(5499),
    [sym_assembly_declaration] = STATE(5499),
    [sym_event_declaration] = STATE(5499),
    [sym_procedure] = STATE(5499),
    [sym_preproc_split_procedure] = STATE(5499),
    [sym_preproc_split_procedure_preamble] = STATE(5499),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5499),
    [sym_var_section] = STATE(5499),
    [sym_attribute_item] = STATE(5499),
    [sym_preproc_conditional] = STATE(5499),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5499),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13778),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5487)] = {
    [sym__body_element] = STATE(5548),
    [sym_empty_statement] = STATE(5548),
    [sym_property] = STATE(5548),
    [sym_permissions_property] = STATE(5548),
    [sym_table_relation_property] = STATE(5548),
    [sym_fields_section] = STATE(5548),
    [sym_keys_section] = STATE(5548),
    [sym_fieldgroups_section] = STATE(5548),
    [sym_enum_value_declaration] = STATE(5548),
    [sym_labels_section] = STATE(5548),
    [sym_layout_section] = STATE(5548),
    [sym_modify_modification] = STATE(5548),
    [sym_actions_section] = STATE(5548),
    [sym_views_section] = STATE(5548),
    [sym_dataset_section] = STATE(5548),
    [sym_requestpage_section] = STATE(5548),
    [sym_rendering_section] = STATE(5548),
    [sym_elements_section] = STATE(5548),
    [sym_schema_section] = STATE(5548),
    [sym_assembly_declaration] = STATE(5548),
    [sym_event_declaration] = STATE(5548),
    [sym_procedure] = STATE(5548),
    [sym_preproc_split_procedure] = STATE(5548),
    [sym_preproc_split_procedure_preamble] = STATE(5548),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5548),
    [sym_var_section] = STATE(5548),
    [sym_attribute_item] = STATE(5548),
    [sym_preproc_conditional] = STATE(5548),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5548),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13780),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5488)] = {
    [sym__body_element] = STATE(5500),
    [sym_empty_statement] = STATE(5500),
    [sym_property] = STATE(5500),
    [sym_permissions_property] = STATE(5500),
    [sym_table_relation_property] = STATE(5500),
    [sym_fields_section] = STATE(5500),
    [sym_keys_section] = STATE(5500),
    [sym_fieldgroups_section] = STATE(5500),
    [sym_enum_value_declaration] = STATE(5500),
    [sym_labels_section] = STATE(5500),
    [sym_layout_section] = STATE(5500),
    [sym_modify_modification] = STATE(5500),
    [sym_actions_section] = STATE(5500),
    [sym_views_section] = STATE(5500),
    [sym_dataset_section] = STATE(5500),
    [sym_requestpage_section] = STATE(5500),
    [sym_rendering_section] = STATE(5500),
    [sym_elements_section] = STATE(5500),
    [sym_schema_section] = STATE(5500),
    [sym_assembly_declaration] = STATE(5500),
    [sym_event_declaration] = STATE(5500),
    [sym_procedure] = STATE(5500),
    [sym_preproc_split_procedure] = STATE(5500),
    [sym_preproc_split_procedure_preamble] = STATE(5500),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5500),
    [sym_var_section] = STATE(5500),
    [sym_attribute_item] = STATE(5500),
    [sym_preproc_conditional] = STATE(5500),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5500),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13782),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5489)] = {
    [sym__body_element] = STATE(5547),
    [sym_empty_statement] = STATE(5547),
    [sym_property] = STATE(5547),
    [sym_permissions_property] = STATE(5547),
    [sym_table_relation_property] = STATE(5547),
    [sym_fields_section] = STATE(5547),
    [sym_keys_section] = STATE(5547),
    [sym_fieldgroups_section] = STATE(5547),
    [sym_enum_value_declaration] = STATE(5547),
    [sym_labels_section] = STATE(5547),
    [sym_layout_section] = STATE(5547),
    [sym_modify_modification] = STATE(5547),
    [sym_actions_section] = STATE(5547),
    [sym_views_section] = STATE(5547),
    [sym_dataset_section] = STATE(5547),
    [sym_requestpage_section] = STATE(5547),
    [sym_rendering_section] = STATE(5547),
    [sym_elements_section] = STATE(5547),
    [sym_schema_section] = STATE(5547),
    [sym_assembly_declaration] = STATE(5547),
    [sym_event_declaration] = STATE(5547),
    [sym_procedure] = STATE(5547),
    [sym_preproc_split_procedure] = STATE(5547),
    [sym_preproc_split_procedure_preamble] = STATE(5547),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5547),
    [sym_var_section] = STATE(5547),
    [sym_attribute_item] = STATE(5547),
    [sym_preproc_conditional] = STATE(5547),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5547),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13784),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5490)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13786),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5491)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13788),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5492)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13790),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5493)] = {
    [sym__body_element] = STATE(5546),
    [sym_empty_statement] = STATE(5546),
    [sym_property] = STATE(5546),
    [sym_permissions_property] = STATE(5546),
    [sym_table_relation_property] = STATE(5546),
    [sym_fields_section] = STATE(5546),
    [sym_keys_section] = STATE(5546),
    [sym_fieldgroups_section] = STATE(5546),
    [sym_enum_value_declaration] = STATE(5546),
    [sym_labels_section] = STATE(5546),
    [sym_layout_section] = STATE(5546),
    [sym_modify_modification] = STATE(5546),
    [sym_actions_section] = STATE(5546),
    [sym_views_section] = STATE(5546),
    [sym_dataset_section] = STATE(5546),
    [sym_requestpage_section] = STATE(5546),
    [sym_rendering_section] = STATE(5546),
    [sym_elements_section] = STATE(5546),
    [sym_schema_section] = STATE(5546),
    [sym_assembly_declaration] = STATE(5546),
    [sym_event_declaration] = STATE(5546),
    [sym_procedure] = STATE(5546),
    [sym_preproc_split_procedure] = STATE(5546),
    [sym_preproc_split_procedure_preamble] = STATE(5546),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5546),
    [sym_var_section] = STATE(5546),
    [sym_attribute_item] = STATE(5546),
    [sym_preproc_conditional] = STATE(5546),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5546),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13792),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5494)] = {
    [sym__body_element] = STATE(5497),
    [sym_empty_statement] = STATE(5497),
    [sym_property] = STATE(5497),
    [sym_permissions_property] = STATE(5497),
    [sym_table_relation_property] = STATE(5497),
    [sym_fields_section] = STATE(5497),
    [sym_keys_section] = STATE(5497),
    [sym_fieldgroups_section] = STATE(5497),
    [sym_enum_value_declaration] = STATE(5497),
    [sym_labels_section] = STATE(5497),
    [sym_layout_section] = STATE(5497),
    [sym_modify_modification] = STATE(5497),
    [sym_actions_section] = STATE(5497),
    [sym_views_section] = STATE(5497),
    [sym_dataset_section] = STATE(5497),
    [sym_requestpage_section] = STATE(5497),
    [sym_rendering_section] = STATE(5497),
    [sym_elements_section] = STATE(5497),
    [sym_schema_section] = STATE(5497),
    [sym_assembly_declaration] = STATE(5497),
    [sym_event_declaration] = STATE(5497),
    [sym_procedure] = STATE(5497),
    [sym_preproc_split_procedure] = STATE(5497),
    [sym_preproc_split_procedure_preamble] = STATE(5497),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5497),
    [sym_var_section] = STATE(5497),
    [sym_attribute_item] = STATE(5497),
    [sym_preproc_conditional] = STATE(5497),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5497),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13794),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5495)] = {
    [sym__body_element] = STATE(5542),
    [sym_empty_statement] = STATE(5542),
    [sym_property] = STATE(5542),
    [sym_permissions_property] = STATE(5542),
    [sym_table_relation_property] = STATE(5542),
    [sym_fields_section] = STATE(5542),
    [sym_keys_section] = STATE(5542),
    [sym_fieldgroups_section] = STATE(5542),
    [sym_enum_value_declaration] = STATE(5542),
    [sym_labels_section] = STATE(5542),
    [sym_layout_section] = STATE(5542),
    [sym_modify_modification] = STATE(5542),
    [sym_actions_section] = STATE(5542),
    [sym_views_section] = STATE(5542),
    [sym_dataset_section] = STATE(5542),
    [sym_requestpage_section] = STATE(5542),
    [sym_rendering_section] = STATE(5542),
    [sym_elements_section] = STATE(5542),
    [sym_schema_section] = STATE(5542),
    [sym_assembly_declaration] = STATE(5542),
    [sym_event_declaration] = STATE(5542),
    [sym_procedure] = STATE(5542),
    [sym_preproc_split_procedure] = STATE(5542),
    [sym_preproc_split_procedure_preamble] = STATE(5542),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5542),
    [sym_var_section] = STATE(5542),
    [sym_attribute_item] = STATE(5542),
    [sym_preproc_conditional] = STATE(5542),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5542),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13796),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5496)] = {
    [anon_sym_SEMI] = ACTIONS(8379),
    [anon_sym_RBRACE] = ACTIONS(8379),
    [anon_sym_COMMA] = ACTIONS(13798),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8379),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8383),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8379),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8379),
    [anon_sym_LBRACK] = ACTIONS(8379),
    [aux_sym_basic_type_token22] = ACTIONS(8383),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8379),
    [aux_sym_addafter_modification_token1] = ACTIONS(8379),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8379),
    [aux_sym_modify_modification_token1] = ACTIONS(8379),
    [aux_sym_separator_action_token1] = ACTIONS(8379),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8379),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8379),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8379),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8379),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8379),
    [anon_sym_POUNDif] = ACTIONS(8379),
    [anon_sym_POUNDIF] = ACTIONS(8379),
    [anon_sym_POUNDIf] = ACTIONS(8379),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8383),
    [sym_page_keyword] = ACTIONS(8379),
    [anon_sym_codeunit] = ACTIONS(8379),
    [anon_sym_CODEUNIT] = ACTIONS(8379),
    [anon_sym_Codeunit] = ACTIONS(8379),
    [anon_sym_CodeUnit] = ACTIONS(8379),
    [anon_sym_COdeunit] = ACTIONS(8379),
    [anon_sym_codeUnit] = ACTIONS(8379),
    [sym_report_keyword] = ACTIONS(8379),
    [sym_query_keyword] = ACTIONS(8379),
    [anon_sym_xmlport] = ACTIONS(8379),
    [anon_sym_XMLPORT] = ACTIONS(8379),
    [anon_sym_Xmlport] = ACTIONS(8379),
    [anon_sym_XMLport] = ACTIONS(8379),
    [anon_sym_XMLPort] = ACTIONS(8379),
    [anon_sym_XmlPort] = ACTIONS(8379),
    [sym_procedure_keyword] = ACTIONS(8379),
    [sym_trigger_keyword] = ACTIONS(8379),
    [sym_var_keyword] = ACTIONS(8379),
    [sym_local_keyword] = ACTIONS(8379),
    [sym_internal_keyword] = ACTIONS(8379),
    [sym_protected_keyword] = ACTIONS(8379),
    [sym_event_keyword] = ACTIONS(8379),
    [sym_fields_keyword] = ACTIONS(8379),
    [sym_keys_keyword] = ACTIONS(8379),
    [sym_fieldgroups_keyword] = ACTIONS(8379),
    [sym_actions_keyword] = ACTIONS(8379),
    [sym_layout_keyword] = ACTIONS(8379),
    [sym_area_keyword] = ACTIONS(8379),
    [sym_group_keyword] = ACTIONS(8379),
    [sym_dataset_keyword] = ACTIONS(8379),
    [sym_elements_keyword] = ACTIONS(8379),
    [sym_labels_keyword] = ACTIONS(8379),
    [sym_rendering_keyword] = ACTIONS(8379),
    [sym_requestpage_keyword] = ACTIONS(8379),
    [sym_schema_keyword] = ACTIONS(8379),
    [sym_views_keyword] = ACTIONS(8379),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8379),
    [sym_preproc_open] = ACTIONS(8379),
  },
  [STATE(5497)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13800),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5498)] = {
    [sym__body_element] = STATE(5556),
    [sym_empty_statement] = STATE(5556),
    [sym_property] = STATE(5556),
    [sym_permissions_property] = STATE(5556),
    [sym_table_relation_property] = STATE(5556),
    [sym_fields_section] = STATE(5556),
    [sym_keys_section] = STATE(5556),
    [sym_fieldgroups_section] = STATE(5556),
    [sym_enum_value_declaration] = STATE(5556),
    [sym_labels_section] = STATE(5556),
    [sym_layout_section] = STATE(5556),
    [sym_modify_modification] = STATE(5556),
    [sym_actions_section] = STATE(5556),
    [sym_views_section] = STATE(5556),
    [sym_dataset_section] = STATE(5556),
    [sym_requestpage_section] = STATE(5556),
    [sym_rendering_section] = STATE(5556),
    [sym_elements_section] = STATE(5556),
    [sym_schema_section] = STATE(5556),
    [sym_assembly_declaration] = STATE(5556),
    [sym_event_declaration] = STATE(5556),
    [sym_procedure] = STATE(5556),
    [sym_preproc_split_procedure] = STATE(5556),
    [sym_preproc_split_procedure_preamble] = STATE(5556),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5556),
    [sym_var_section] = STATE(5556),
    [sym_attribute_item] = STATE(5556),
    [sym_preproc_conditional] = STATE(5556),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5556),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13802),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5499)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13804),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5500)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13806),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5501)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13808),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5502)] = {
    [sym__body_element] = STATE(5506),
    [sym_empty_statement] = STATE(5506),
    [sym_property] = STATE(5506),
    [sym_permissions_property] = STATE(5506),
    [sym_table_relation_property] = STATE(5506),
    [sym_fields_section] = STATE(5506),
    [sym_keys_section] = STATE(5506),
    [sym_fieldgroups_section] = STATE(5506),
    [sym_enum_value_declaration] = STATE(5506),
    [sym_labels_section] = STATE(5506),
    [sym_layout_section] = STATE(5506),
    [sym_modify_modification] = STATE(5506),
    [sym_actions_section] = STATE(5506),
    [sym_views_section] = STATE(5506),
    [sym_dataset_section] = STATE(5506),
    [sym_requestpage_section] = STATE(5506),
    [sym_rendering_section] = STATE(5506),
    [sym_elements_section] = STATE(5506),
    [sym_schema_section] = STATE(5506),
    [sym_assembly_declaration] = STATE(5506),
    [sym_event_declaration] = STATE(5506),
    [sym_procedure] = STATE(5506),
    [sym_preproc_split_procedure] = STATE(5506),
    [sym_preproc_split_procedure_preamble] = STATE(5506),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5506),
    [sym_var_section] = STATE(5506),
    [sym_attribute_item] = STATE(5506),
    [sym_preproc_conditional] = STATE(5506),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5506),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13810),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5503)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13812),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5504)] = {
    [sym__body_element] = STATE(5732),
    [sym_empty_statement] = STATE(5732),
    [sym_property] = STATE(5732),
    [sym_permissions_property] = STATE(5732),
    [sym_table_relation_property] = STATE(5732),
    [sym_fields_section] = STATE(5732),
    [sym_keys_section] = STATE(5732),
    [sym_fieldgroups_section] = STATE(5732),
    [sym_enum_value_declaration] = STATE(5732),
    [sym_labels_section] = STATE(5732),
    [sym_layout_section] = STATE(5732),
    [sym_modify_modification] = STATE(5732),
    [sym_actions_section] = STATE(5732),
    [sym_views_section] = STATE(5732),
    [sym_dataset_section] = STATE(5732),
    [sym_requestpage_section] = STATE(5732),
    [sym_rendering_section] = STATE(5732),
    [sym_elements_section] = STATE(5732),
    [sym_schema_section] = STATE(5732),
    [sym_assembly_declaration] = STATE(5732),
    [sym_event_declaration] = STATE(5732),
    [sym_procedure] = STATE(5732),
    [sym_preproc_split_procedure] = STATE(5732),
    [sym_preproc_split_procedure_preamble] = STATE(5732),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5732),
    [sym_var_section] = STATE(5732),
    [sym_attribute_item] = STATE(5732),
    [sym_preproc_conditional] = STATE(5732),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5732),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13814),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5505)] = {
    [sym__body_element] = STATE(5507),
    [sym_empty_statement] = STATE(5507),
    [sym_property] = STATE(5507),
    [sym_permissions_property] = STATE(5507),
    [sym_table_relation_property] = STATE(5507),
    [sym_fields_section] = STATE(5507),
    [sym_keys_section] = STATE(5507),
    [sym_fieldgroups_section] = STATE(5507),
    [sym_enum_value_declaration] = STATE(5507),
    [sym_labels_section] = STATE(5507),
    [sym_layout_section] = STATE(5507),
    [sym_modify_modification] = STATE(5507),
    [sym_actions_section] = STATE(5507),
    [sym_views_section] = STATE(5507),
    [sym_dataset_section] = STATE(5507),
    [sym_requestpage_section] = STATE(5507),
    [sym_rendering_section] = STATE(5507),
    [sym_elements_section] = STATE(5507),
    [sym_schema_section] = STATE(5507),
    [sym_assembly_declaration] = STATE(5507),
    [sym_event_declaration] = STATE(5507),
    [sym_procedure] = STATE(5507),
    [sym_preproc_split_procedure] = STATE(5507),
    [sym_preproc_split_procedure_preamble] = STATE(5507),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5507),
    [sym_var_section] = STATE(5507),
    [sym_attribute_item] = STATE(5507),
    [sym_preproc_conditional] = STATE(5507),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5507),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13816),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5506)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13818),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5507)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13820),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5508)] = {
    [sym__body_element] = STATE(5582),
    [sym_empty_statement] = STATE(5582),
    [sym_property] = STATE(5582),
    [sym_permissions_property] = STATE(5582),
    [sym_table_relation_property] = STATE(5582),
    [sym_fields_section] = STATE(5582),
    [sym_keys_section] = STATE(5582),
    [sym_fieldgroups_section] = STATE(5582),
    [sym_enum_value_declaration] = STATE(5582),
    [sym_labels_section] = STATE(5582),
    [sym_layout_section] = STATE(5582),
    [sym_modify_modification] = STATE(5582),
    [sym_actions_section] = STATE(5582),
    [sym_views_section] = STATE(5582),
    [sym_dataset_section] = STATE(5582),
    [sym_requestpage_section] = STATE(5582),
    [sym_rendering_section] = STATE(5582),
    [sym_elements_section] = STATE(5582),
    [sym_schema_section] = STATE(5582),
    [sym_assembly_declaration] = STATE(5582),
    [sym_event_declaration] = STATE(5582),
    [sym_procedure] = STATE(5582),
    [sym_preproc_split_procedure] = STATE(5582),
    [sym_preproc_split_procedure_preamble] = STATE(5582),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5582),
    [sym_var_section] = STATE(5582),
    [sym_attribute_item] = STATE(5582),
    [sym_preproc_conditional] = STATE(5582),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5582),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13822),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5509)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_RBRACE] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5279),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token6] = ACTIONS(5279),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_addafter_modification_token1] = ACTIONS(5279),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5279),
    [aux_sym_movelast_modification_token1] = ACTIONS(5279),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5279),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_area_keyword] = ACTIONS(5279),
    [sym_group_keyword] = ACTIONS(5279),
    [sym_repeater_keyword] = ACTIONS(5279),
    [sym_cuegroup_keyword] = ACTIONS(5279),
    [sym_fixed_keyword] = ACTIONS(5279),
    [sym_grid_keyword] = ACTIONS(5279),
    [sym_part_keyword] = ACTIONS(5279),
    [sym_systempart_keyword] = ACTIONS(5279),
    [sym_usercontrol_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_dataitem_keyword] = ACTIONS(5279),
    [sym_column_keyword] = ACTIONS(5279),
    [sym_filter_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_var_attribute_open] = ACTIONS(5277),
  },
  [STATE(5510)] = {
    [sym__body_element] = STATE(5675),
    [sym_empty_statement] = STATE(5675),
    [sym_property] = STATE(5675),
    [sym_permissions_property] = STATE(5675),
    [sym_table_relation_property] = STATE(5675),
    [sym_fields_section] = STATE(5675),
    [sym_keys_section] = STATE(5675),
    [sym_fieldgroups_section] = STATE(5675),
    [sym_enum_value_declaration] = STATE(5675),
    [sym_labels_section] = STATE(5675),
    [sym_layout_section] = STATE(5675),
    [sym_modify_modification] = STATE(5675),
    [sym_actions_section] = STATE(5675),
    [sym_views_section] = STATE(5675),
    [sym_dataset_section] = STATE(5675),
    [sym_requestpage_section] = STATE(5675),
    [sym_rendering_section] = STATE(5675),
    [sym_elements_section] = STATE(5675),
    [sym_schema_section] = STATE(5675),
    [sym_assembly_declaration] = STATE(5675),
    [sym_event_declaration] = STATE(5675),
    [sym_procedure] = STATE(5675),
    [sym_preproc_split_procedure] = STATE(5675),
    [sym_preproc_split_procedure_preamble] = STATE(5675),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5675),
    [sym_var_section] = STATE(5675),
    [sym_attribute_item] = STATE(5675),
    [sym_preproc_conditional] = STATE(5675),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5675),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13824),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5511)] = {
    [sym__body_element] = STATE(5651),
    [sym_empty_statement] = STATE(5651),
    [sym_property] = STATE(5651),
    [sym_permissions_property] = STATE(5651),
    [sym_table_relation_property] = STATE(5651),
    [sym_fields_section] = STATE(5651),
    [sym_keys_section] = STATE(5651),
    [sym_fieldgroups_section] = STATE(5651),
    [sym_enum_value_declaration] = STATE(5651),
    [sym_labels_section] = STATE(5651),
    [sym_layout_section] = STATE(5651),
    [sym_modify_modification] = STATE(5651),
    [sym_actions_section] = STATE(5651),
    [sym_views_section] = STATE(5651),
    [sym_dataset_section] = STATE(5651),
    [sym_requestpage_section] = STATE(5651),
    [sym_rendering_section] = STATE(5651),
    [sym_elements_section] = STATE(5651),
    [sym_schema_section] = STATE(5651),
    [sym_assembly_declaration] = STATE(5651),
    [sym_event_declaration] = STATE(5651),
    [sym_procedure] = STATE(5651),
    [sym_preproc_split_procedure] = STATE(5651),
    [sym_preproc_split_procedure_preamble] = STATE(5651),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5651),
    [sym_var_section] = STATE(5651),
    [sym_attribute_item] = STATE(5651),
    [sym_preproc_conditional] = STATE(5651),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5651),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13826),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5512)] = {
    [sym_identifier] = ACTIONS(7757),
    [anon_sym_SEMI] = ACTIONS(7760),
    [anon_sym_RBRACE] = ACTIONS(7775),
    [aux_sym_where_condition_token1] = ACTIONS(7757),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7770),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [anon_sym_LBRACK] = ACTIONS(7775),
    [aux_sym_basic_type_token22] = ACTIONS(7757),
    [aux_sym_basic_type_token53] = ACTIONS(7757),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7765),
    [aux_sym_modify_modification_token1] = ACTIONS(7772),
    [aux_sym_separator_action_token1] = ACTIONS(7757),
    [aux_sym_xmlport_element_token1] = ACTIONS(7772),
    [aux_sym_xmlport_element_token2] = ACTIONS(7772),
    [aux_sym_xmlport_element_token3] = ACTIONS(7772),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7772),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7772),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7765),
    [aux_sym_type_declaration_token1] = ACTIONS(7757),
    [anon_sym_POUNDif] = ACTIONS(7760),
    [anon_sym_POUNDIF] = ACTIONS(7760),
    [anon_sym_POUNDIf] = ACTIONS(7760),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7778),
    [sym_page_keyword] = ACTIONS(7770),
    [anon_sym_codeunit] = ACTIONS(7770),
    [anon_sym_CODEUNIT] = ACTIONS(7770),
    [anon_sym_Codeunit] = ACTIONS(7770),
    [anon_sym_CodeUnit] = ACTIONS(7770),
    [anon_sym_COdeunit] = ACTIONS(7770),
    [anon_sym_codeUnit] = ACTIONS(7770),
    [sym_report_keyword] = ACTIONS(7770),
    [sym_query_keyword] = ACTIONS(7770),
    [anon_sym_xmlport] = ACTIONS(7770),
    [anon_sym_XMLPORT] = ACTIONS(7770),
    [anon_sym_Xmlport] = ACTIONS(7770),
    [anon_sym_XMLport] = ACTIONS(7770),
    [anon_sym_XMLPort] = ACTIONS(7770),
    [anon_sym_XmlPort] = ACTIONS(7770),
    [sym_procedure_keyword] = ACTIONS(7772),
    [sym_trigger_keyword] = ACTIONS(7772),
    [sym_var_keyword] = ACTIONS(7772),
    [sym_local_keyword] = ACTIONS(7772),
    [sym_internal_keyword] = ACTIONS(7772),
    [sym_protected_keyword] = ACTIONS(7772),
    [sym_event_keyword] = ACTIONS(7772),
    [sym_fields_keyword] = ACTIONS(7772),
    [sym_keys_keyword] = ACTIONS(7772),
    [sym_key_keyword] = ACTIONS(7757),
    [sym_fieldgroups_keyword] = ACTIONS(7772),
    [sym_actions_keyword] = ACTIONS(7772),
    [sym_layout_keyword] = ACTIONS(7772),
    [sym_dataset_keyword] = ACTIONS(7765),
    [sym_elements_keyword] = ACTIONS(7772),
    [sym_labels_keyword] = ACTIONS(7772),
    [sym_rendering_keyword] = ACTIONS(7772),
    [sym_requestpage_keyword] = ACTIONS(7772),
    [sym_schema_keyword] = ACTIONS(7772),
    [sym_views_keyword] = ACTIONS(7772),
    [sym_quoted_identifier] = ACTIONS(7782),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7775),
    [sym_preproc_open] = ACTIONS(7760),
  },
  [STATE(5513)] = {
    [sym__body_element] = STATE(5626),
    [sym_empty_statement] = STATE(5626),
    [sym_property] = STATE(5626),
    [sym_permissions_property] = STATE(5626),
    [sym_table_relation_property] = STATE(5626),
    [sym_fields_section] = STATE(5626),
    [sym_keys_section] = STATE(5626),
    [sym_fieldgroups_section] = STATE(5626),
    [sym_enum_value_declaration] = STATE(5626),
    [sym_labels_section] = STATE(5626),
    [sym_layout_section] = STATE(5626),
    [sym_modify_modification] = STATE(5626),
    [sym_actions_section] = STATE(5626),
    [sym_views_section] = STATE(5626),
    [sym_dataset_section] = STATE(5626),
    [sym_requestpage_section] = STATE(5626),
    [sym_rendering_section] = STATE(5626),
    [sym_elements_section] = STATE(5626),
    [sym_schema_section] = STATE(5626),
    [sym_assembly_declaration] = STATE(5626),
    [sym_event_declaration] = STATE(5626),
    [sym_procedure] = STATE(5626),
    [sym_preproc_split_procedure] = STATE(5626),
    [sym_preproc_split_procedure_preamble] = STATE(5626),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5626),
    [sym_var_section] = STATE(5626),
    [sym_attribute_item] = STATE(5626),
    [sym_preproc_conditional] = STATE(5626),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5626),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13828),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5514)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13830),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5515)] = {
    [sym__body_element] = STATE(5631),
    [sym_empty_statement] = STATE(5631),
    [sym_property] = STATE(5631),
    [sym_permissions_property] = STATE(5631),
    [sym_table_relation_property] = STATE(5631),
    [sym_fields_section] = STATE(5631),
    [sym_keys_section] = STATE(5631),
    [sym_fieldgroups_section] = STATE(5631),
    [sym_enum_value_declaration] = STATE(5631),
    [sym_labels_section] = STATE(5631),
    [sym_layout_section] = STATE(5631),
    [sym_modify_modification] = STATE(5631),
    [sym_actions_section] = STATE(5631),
    [sym_views_section] = STATE(5631),
    [sym_dataset_section] = STATE(5631),
    [sym_requestpage_section] = STATE(5631),
    [sym_rendering_section] = STATE(5631),
    [sym_elements_section] = STATE(5631),
    [sym_schema_section] = STATE(5631),
    [sym_assembly_declaration] = STATE(5631),
    [sym_event_declaration] = STATE(5631),
    [sym_procedure] = STATE(5631),
    [sym_preproc_split_procedure] = STATE(5631),
    [sym_preproc_split_procedure_preamble] = STATE(5631),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5631),
    [sym_var_section] = STATE(5631),
    [sym_attribute_item] = STATE(5631),
    [sym_preproc_conditional] = STATE(5631),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5631),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13832),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5516)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13834),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5517)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13836),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5518)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [anon_sym_RBRACE] = ACTIONS(6194),
    [aux_sym_where_condition_token1] = ACTIONS(6192),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6192),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [aux_sym_basic_type_token6] = ACTIONS(6192),
    [aux_sym_basic_type_token22] = ACTIONS(6192),
    [aux_sym_basic_type_token53] = ACTIONS(6192),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6192),
    [aux_sym_addafter_modification_token1] = ACTIONS(6192),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6192),
    [aux_sym_modify_modification_token1] = ACTIONS(6192),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6192),
    [aux_sym_movelast_modification_token1] = ACTIONS(6192),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6192),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6192),
    [aux_sym_separator_action_token1] = ACTIONS(6192),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6192),
    [aux_sym_type_declaration_token1] = ACTIONS(6192),
    [anon_sym_POUNDif] = ACTIONS(6194),
    [anon_sym_POUNDIF] = ACTIONS(6194),
    [anon_sym_POUNDIf] = ACTIONS(6194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6192),
    [sym_procedure_keyword] = ACTIONS(6192),
    [sym_trigger_keyword] = ACTIONS(6192),
    [sym_var_keyword] = ACTIONS(6192),
    [sym_local_keyword] = ACTIONS(6192),
    [sym_internal_keyword] = ACTIONS(6192),
    [sym_protected_keyword] = ACTIONS(6192),
    [sym_event_keyword] = ACTIONS(6192),
    [sym_fields_keyword] = ACTIONS(6192),
    [sym_keys_keyword] = ACTIONS(6192),
    [sym_key_keyword] = ACTIONS(6192),
    [sym_fieldgroups_keyword] = ACTIONS(6192),
    [sym_actions_keyword] = ACTIONS(6192),
    [sym_layout_keyword] = ACTIONS(6192),
    [sym_area_keyword] = ACTIONS(6192),
    [sym_group_keyword] = ACTIONS(6192),
    [sym_repeater_keyword] = ACTIONS(6192),
    [sym_cuegroup_keyword] = ACTIONS(6192),
    [sym_fixed_keyword] = ACTIONS(6192),
    [sym_grid_keyword] = ACTIONS(6192),
    [sym_part_keyword] = ACTIONS(6192),
    [sym_systempart_keyword] = ACTIONS(6192),
    [sym_usercontrol_keyword] = ACTIONS(6192),
    [sym_dataset_keyword] = ACTIONS(6192),
    [sym_elements_keyword] = ACTIONS(6192),
    [sym_dataitem_keyword] = ACTIONS(6192),
    [sym_column_keyword] = ACTIONS(6192),
    [sym_filter_keyword] = ACTIONS(6192),
    [sym_labels_keyword] = ACTIONS(6192),
    [sym_rendering_keyword] = ACTIONS(6192),
    [sym_requestpage_keyword] = ACTIONS(6192),
    [sym_schema_keyword] = ACTIONS(6192),
    [sym_views_keyword] = ACTIONS(6192),
    [sym_quoted_identifier] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6194),
    [sym_preproc_open] = ACTIONS(6194),
    [sym_var_attribute_open] = ACTIONS(6194),
  },
  [STATE(5519)] = {
    [sym__body_element] = STATE(5686),
    [sym_empty_statement] = STATE(5686),
    [sym_property] = STATE(5686),
    [sym_permissions_property] = STATE(5686),
    [sym_table_relation_property] = STATE(5686),
    [sym_fields_section] = STATE(5686),
    [sym_keys_section] = STATE(5686),
    [sym_fieldgroups_section] = STATE(5686),
    [sym_enum_value_declaration] = STATE(5686),
    [sym_labels_section] = STATE(5686),
    [sym_layout_section] = STATE(5686),
    [sym_modify_modification] = STATE(5686),
    [sym_actions_section] = STATE(5686),
    [sym_views_section] = STATE(5686),
    [sym_dataset_section] = STATE(5686),
    [sym_requestpage_section] = STATE(5686),
    [sym_rendering_section] = STATE(5686),
    [sym_elements_section] = STATE(5686),
    [sym_schema_section] = STATE(5686),
    [sym_assembly_declaration] = STATE(5686),
    [sym_event_declaration] = STATE(5686),
    [sym_procedure] = STATE(5686),
    [sym_preproc_split_procedure] = STATE(5686),
    [sym_preproc_split_procedure_preamble] = STATE(5686),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5686),
    [sym_var_section] = STATE(5686),
    [sym_attribute_item] = STATE(5686),
    [sym_preproc_conditional] = STATE(5686),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5686),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13838),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5520)] = {
    [sym__body_element] = STATE(5638),
    [sym_empty_statement] = STATE(5638),
    [sym_property] = STATE(5638),
    [sym_permissions_property] = STATE(5638),
    [sym_table_relation_property] = STATE(5638),
    [sym_fields_section] = STATE(5638),
    [sym_keys_section] = STATE(5638),
    [sym_fieldgroups_section] = STATE(5638),
    [sym_enum_value_declaration] = STATE(5638),
    [sym_labels_section] = STATE(5638),
    [sym_layout_section] = STATE(5638),
    [sym_modify_modification] = STATE(5638),
    [sym_actions_section] = STATE(5638),
    [sym_views_section] = STATE(5638),
    [sym_dataset_section] = STATE(5638),
    [sym_requestpage_section] = STATE(5638),
    [sym_rendering_section] = STATE(5638),
    [sym_elements_section] = STATE(5638),
    [sym_schema_section] = STATE(5638),
    [sym_assembly_declaration] = STATE(5638),
    [sym_event_declaration] = STATE(5638),
    [sym_procedure] = STATE(5638),
    [sym_preproc_split_procedure] = STATE(5638),
    [sym_preproc_split_procedure_preamble] = STATE(5638),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5638),
    [sym_var_section] = STATE(5638),
    [sym_attribute_item] = STATE(5638),
    [sym_preproc_conditional] = STATE(5638),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5638),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13840),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5521)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13842),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5522)] = {
    [sym__body_element] = STATE(5673),
    [sym_empty_statement] = STATE(5673),
    [sym_property] = STATE(5673),
    [sym_permissions_property] = STATE(5673),
    [sym_table_relation_property] = STATE(5673),
    [sym_fields_section] = STATE(5673),
    [sym_keys_section] = STATE(5673),
    [sym_fieldgroups_section] = STATE(5673),
    [sym_enum_value_declaration] = STATE(5673),
    [sym_labels_section] = STATE(5673),
    [sym_layout_section] = STATE(5673),
    [sym_modify_modification] = STATE(5673),
    [sym_actions_section] = STATE(5673),
    [sym_views_section] = STATE(5673),
    [sym_dataset_section] = STATE(5673),
    [sym_requestpage_section] = STATE(5673),
    [sym_rendering_section] = STATE(5673),
    [sym_elements_section] = STATE(5673),
    [sym_schema_section] = STATE(5673),
    [sym_assembly_declaration] = STATE(5673),
    [sym_event_declaration] = STATE(5673),
    [sym_procedure] = STATE(5673),
    [sym_preproc_split_procedure] = STATE(5673),
    [sym_preproc_split_procedure_preamble] = STATE(5673),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5673),
    [sym_var_section] = STATE(5673),
    [sym_attribute_item] = STATE(5673),
    [sym_preproc_conditional] = STATE(5673),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5673),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13844),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5523)] = {
    [sym__body_element] = STATE(5678),
    [sym_empty_statement] = STATE(5678),
    [sym_property] = STATE(5678),
    [sym_permissions_property] = STATE(5678),
    [sym_table_relation_property] = STATE(5678),
    [sym_fields_section] = STATE(5678),
    [sym_keys_section] = STATE(5678),
    [sym_fieldgroups_section] = STATE(5678),
    [sym_enum_value_declaration] = STATE(5678),
    [sym_labels_section] = STATE(5678),
    [sym_layout_section] = STATE(5678),
    [sym_modify_modification] = STATE(5678),
    [sym_actions_section] = STATE(5678),
    [sym_views_section] = STATE(5678),
    [sym_dataset_section] = STATE(5678),
    [sym_requestpage_section] = STATE(5678),
    [sym_rendering_section] = STATE(5678),
    [sym_elements_section] = STATE(5678),
    [sym_schema_section] = STATE(5678),
    [sym_assembly_declaration] = STATE(5678),
    [sym_event_declaration] = STATE(5678),
    [sym_procedure] = STATE(5678),
    [sym_preproc_split_procedure] = STATE(5678),
    [sym_preproc_split_procedure_preamble] = STATE(5678),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5678),
    [sym_var_section] = STATE(5678),
    [sym_attribute_item] = STATE(5678),
    [sym_preproc_conditional] = STATE(5678),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5678),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13846),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5524)] = {
    [anon_sym_SEMI] = ACTIONS(3705),
    [anon_sym_DOT] = ACTIONS(3705),
    [anon_sym_RBRACE] = ACTIONS(3705),
    [aux_sym_where_clause_token1] = ACTIONS(3705),
    [aux_sym_where_condition_token1] = ACTIONS(3703),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(3705),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(3705),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(3705),
    [anon_sym_LBRACK] = ACTIONS(3705),
    [aux_sym_basic_type_token6] = ACTIONS(3703),
    [aux_sym_basic_type_token22] = ACTIONS(3703),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(3705),
    [aux_sym_addafter_modification_token1] = ACTIONS(3705),
    [aux_sym_addbefore_modification_token1] = ACTIONS(3705),
    [aux_sym_modify_modification_token1] = ACTIONS(3705),
    [aux_sym_movefirst_modification_token1] = ACTIONS(3705),
    [aux_sym_movelast_modification_token1] = ACTIONS(3705),
    [aux_sym_moveafter_modification_token1] = ACTIONS(3705),
    [aux_sym_movebefore_modification_token1] = ACTIONS(3705),
    [aux_sym_separator_action_token1] = ACTIONS(3705),
    [aux_sym_actionref_declaration_token1] = ACTIONS(3705),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(3705),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(3705),
    [aux_sym_customaction_declaration_token1] = ACTIONS(3705),
    [aux_sym_assembly_declaration_token1] = ACTIONS(3705),
    [anon_sym_POUNDif] = ACTIONS(3705),
    [anon_sym_POUNDIF] = ACTIONS(3705),
    [anon_sym_POUNDIf] = ACTIONS(3705),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(3705),
    [sym_trigger_keyword] = ACTIONS(3705),
    [sym_var_keyword] = ACTIONS(3705),
    [sym_local_keyword] = ACTIONS(3705),
    [sym_internal_keyword] = ACTIONS(3705),
    [sym_protected_keyword] = ACTIONS(3705),
    [sym_event_keyword] = ACTIONS(3705),
    [sym_fields_keyword] = ACTIONS(3705),
    [sym_keys_keyword] = ACTIONS(3705),
    [sym_fieldgroups_keyword] = ACTIONS(3705),
    [sym_actions_keyword] = ACTIONS(3705),
    [sym_layout_keyword] = ACTIONS(3705),
    [sym_area_keyword] = ACTIONS(3705),
    [sym_group_keyword] = ACTIONS(3705),
    [sym_repeater_keyword] = ACTIONS(3705),
    [sym_cuegroup_keyword] = ACTIONS(3705),
    [sym_fixed_keyword] = ACTIONS(3705),
    [sym_grid_keyword] = ACTIONS(3705),
    [sym_part_keyword] = ACTIONS(3705),
    [sym_systempart_keyword] = ACTIONS(3705),
    [sym_usercontrol_keyword] = ACTIONS(3705),
    [sym_dataset_keyword] = ACTIONS(3705),
    [sym_elements_keyword] = ACTIONS(3705),
    [sym_dataitem_keyword] = ACTIONS(3705),
    [sym_column_keyword] = ACTIONS(3705),
    [sym_filter_keyword] = ACTIONS(3705),
    [sym_labels_keyword] = ACTIONS(3705),
    [sym_rendering_keyword] = ACTIONS(3705),
    [sym_requestpage_keyword] = ACTIONS(3705),
    [sym_schema_keyword] = ACTIONS(3705),
    [sym_views_keyword] = ACTIONS(3705),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(3705),
    [sym_preproc_open] = ACTIONS(3705),
  },
  [STATE(5525)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13848),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5526)] = {
    [sym__body_element] = STATE(5535),
    [sym_empty_statement] = STATE(5535),
    [sym_property] = STATE(5535),
    [sym_permissions_property] = STATE(5535),
    [sym_table_relation_property] = STATE(5535),
    [sym_fields_section] = STATE(5535),
    [sym_keys_section] = STATE(5535),
    [sym_fieldgroups_section] = STATE(5535),
    [sym_enum_value_declaration] = STATE(5535),
    [sym_labels_section] = STATE(5535),
    [sym_layout_section] = STATE(5535),
    [sym_modify_modification] = STATE(5535),
    [sym_actions_section] = STATE(5535),
    [sym_views_section] = STATE(5535),
    [sym_dataset_section] = STATE(5535),
    [sym_requestpage_section] = STATE(5535),
    [sym_rendering_section] = STATE(5535),
    [sym_elements_section] = STATE(5535),
    [sym_schema_section] = STATE(5535),
    [sym_assembly_declaration] = STATE(5535),
    [sym_event_declaration] = STATE(5535),
    [sym_procedure] = STATE(5535),
    [sym_preproc_split_procedure] = STATE(5535),
    [sym_preproc_split_procedure_preamble] = STATE(5535),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5535),
    [sym_var_section] = STATE(5535),
    [sym_attribute_item] = STATE(5535),
    [sym_preproc_conditional] = STATE(5535),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5535),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13850),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5527)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13852),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5528)] = {
    [sym__body_element] = STATE(5503),
    [sym_empty_statement] = STATE(5503),
    [sym_property] = STATE(5503),
    [sym_permissions_property] = STATE(5503),
    [sym_table_relation_property] = STATE(5503),
    [sym_fields_section] = STATE(5503),
    [sym_keys_section] = STATE(5503),
    [sym_fieldgroups_section] = STATE(5503),
    [sym_enum_value_declaration] = STATE(5503),
    [sym_labels_section] = STATE(5503),
    [sym_layout_section] = STATE(5503),
    [sym_modify_modification] = STATE(5503),
    [sym_actions_section] = STATE(5503),
    [sym_views_section] = STATE(5503),
    [sym_dataset_section] = STATE(5503),
    [sym_requestpage_section] = STATE(5503),
    [sym_rendering_section] = STATE(5503),
    [sym_elements_section] = STATE(5503),
    [sym_schema_section] = STATE(5503),
    [sym_assembly_declaration] = STATE(5503),
    [sym_event_declaration] = STATE(5503),
    [sym_procedure] = STATE(5503),
    [sym_preproc_split_procedure] = STATE(5503),
    [sym_preproc_split_procedure_preamble] = STATE(5503),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5503),
    [sym_var_section] = STATE(5503),
    [sym_attribute_item] = STATE(5503),
    [sym_preproc_conditional] = STATE(5503),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5503),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13854),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5529)] = {
    [sym_identifier] = ACTIONS(8889),
    [anon_sym_SEMI] = ACTIONS(8891),
    [anon_sym_RBRACE] = ACTIONS(8891),
    [aux_sym_where_condition_token1] = ACTIONS(8889),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8889),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8889),
    [anon_sym_LBRACK] = ACTIONS(8891),
    [aux_sym_basic_type_token6] = ACTIONS(8889),
    [aux_sym_basic_type_token22] = ACTIONS(8889),
    [aux_sym_basic_type_token53] = ACTIONS(8889),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8889),
    [aux_sym_addafter_modification_token1] = ACTIONS(8889),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8889),
    [aux_sym_modify_modification_token1] = ACTIONS(8889),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8889),
    [aux_sym_movelast_modification_token1] = ACTIONS(8889),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8889),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8889),
    [aux_sym_separator_action_token1] = ACTIONS(8889),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8889),
    [aux_sym_type_declaration_token1] = ACTIONS(8889),
    [anon_sym_POUNDif] = ACTIONS(8891),
    [anon_sym_POUNDIF] = ACTIONS(8891),
    [anon_sym_POUNDIf] = ACTIONS(8891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8889),
    [sym_procedure_keyword] = ACTIONS(8889),
    [sym_trigger_keyword] = ACTIONS(8889),
    [sym_var_keyword] = ACTIONS(8889),
    [sym_local_keyword] = ACTIONS(8889),
    [sym_internal_keyword] = ACTIONS(8889),
    [sym_protected_keyword] = ACTIONS(8889),
    [sym_event_keyword] = ACTIONS(8889),
    [sym_fields_keyword] = ACTIONS(8889),
    [sym_keys_keyword] = ACTIONS(8889),
    [sym_key_keyword] = ACTIONS(8889),
    [sym_fieldgroups_keyword] = ACTIONS(8889),
    [sym_actions_keyword] = ACTIONS(8889),
    [sym_layout_keyword] = ACTIONS(8889),
    [sym_area_keyword] = ACTIONS(8889),
    [sym_group_keyword] = ACTIONS(8889),
    [sym_repeater_keyword] = ACTIONS(8889),
    [sym_cuegroup_keyword] = ACTIONS(8889),
    [sym_fixed_keyword] = ACTIONS(8889),
    [sym_grid_keyword] = ACTIONS(8889),
    [sym_part_keyword] = ACTIONS(8889),
    [sym_systempart_keyword] = ACTIONS(8889),
    [sym_usercontrol_keyword] = ACTIONS(8889),
    [sym_dataset_keyword] = ACTIONS(8889),
    [sym_elements_keyword] = ACTIONS(8889),
    [sym_dataitem_keyword] = ACTIONS(8889),
    [sym_column_keyword] = ACTIONS(8889),
    [sym_filter_keyword] = ACTIONS(8889),
    [sym_labels_keyword] = ACTIONS(8889),
    [sym_rendering_keyword] = ACTIONS(8889),
    [sym_requestpage_keyword] = ACTIONS(8889),
    [sym_schema_keyword] = ACTIONS(8889),
    [sym_views_keyword] = ACTIONS(8889),
    [sym_quoted_identifier] = ACTIONS(8891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8891),
    [sym_preproc_open] = ACTIONS(8891),
    [sym_var_attribute_open] = ACTIONS(8891),
  },
  [STATE(5530)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13856),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5531)] = {
    [sym_identifier] = ACTIONS(8889),
    [anon_sym_SEMI] = ACTIONS(8891),
    [anon_sym_RBRACE] = ACTIONS(8891),
    [aux_sym_where_condition_token1] = ACTIONS(8889),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8889),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8889),
    [anon_sym_LBRACK] = ACTIONS(8891),
    [aux_sym_basic_type_token6] = ACTIONS(8889),
    [aux_sym_basic_type_token22] = ACTIONS(8889),
    [aux_sym_basic_type_token53] = ACTIONS(8889),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8889),
    [aux_sym_addafter_modification_token1] = ACTIONS(8889),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8889),
    [aux_sym_modify_modification_token1] = ACTIONS(8889),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8889),
    [aux_sym_movelast_modification_token1] = ACTIONS(8889),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8889),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8889),
    [aux_sym_separator_action_token1] = ACTIONS(8889),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8889),
    [aux_sym_type_declaration_token1] = ACTIONS(8889),
    [anon_sym_POUNDif] = ACTIONS(8891),
    [anon_sym_POUNDIF] = ACTIONS(8891),
    [anon_sym_POUNDIf] = ACTIONS(8891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8889),
    [sym_procedure_keyword] = ACTIONS(8889),
    [sym_trigger_keyword] = ACTIONS(8889),
    [sym_var_keyword] = ACTIONS(8889),
    [sym_local_keyword] = ACTIONS(8889),
    [sym_internal_keyword] = ACTIONS(8889),
    [sym_protected_keyword] = ACTIONS(8889),
    [sym_event_keyword] = ACTIONS(8889),
    [sym_fields_keyword] = ACTIONS(8889),
    [sym_keys_keyword] = ACTIONS(8889),
    [sym_key_keyword] = ACTIONS(8889),
    [sym_fieldgroups_keyword] = ACTIONS(8889),
    [sym_actions_keyword] = ACTIONS(8889),
    [sym_layout_keyword] = ACTIONS(8889),
    [sym_area_keyword] = ACTIONS(8889),
    [sym_group_keyword] = ACTIONS(8889),
    [sym_repeater_keyword] = ACTIONS(8889),
    [sym_cuegroup_keyword] = ACTIONS(8889),
    [sym_fixed_keyword] = ACTIONS(8889),
    [sym_grid_keyword] = ACTIONS(8889),
    [sym_part_keyword] = ACTIONS(8889),
    [sym_systempart_keyword] = ACTIONS(8889),
    [sym_usercontrol_keyword] = ACTIONS(8889),
    [sym_dataset_keyword] = ACTIONS(8889),
    [sym_elements_keyword] = ACTIONS(8889),
    [sym_dataitem_keyword] = ACTIONS(8889),
    [sym_column_keyword] = ACTIONS(8889),
    [sym_filter_keyword] = ACTIONS(8889),
    [sym_labels_keyword] = ACTIONS(8889),
    [sym_rendering_keyword] = ACTIONS(8889),
    [sym_requestpage_keyword] = ACTIONS(8889),
    [sym_schema_keyword] = ACTIONS(8889),
    [sym_views_keyword] = ACTIONS(8889),
    [sym_quoted_identifier] = ACTIONS(8891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8891),
    [sym_preproc_open] = ACTIONS(8891),
    [sym_var_attribute_open] = ACTIONS(8891),
  },
  [STATE(5532)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13858),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5533)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13860),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5534)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13862),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5535)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13864),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5536)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13866),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5537)] = {
    [sym__body_element] = STATE(5652),
    [sym_empty_statement] = STATE(5652),
    [sym_property] = STATE(5652),
    [sym_permissions_property] = STATE(5652),
    [sym_table_relation_property] = STATE(5652),
    [sym_fields_section] = STATE(5652),
    [sym_keys_section] = STATE(5652),
    [sym_fieldgroups_section] = STATE(5652),
    [sym_enum_value_declaration] = STATE(5652),
    [sym_labels_section] = STATE(5652),
    [sym_layout_section] = STATE(5652),
    [sym_modify_modification] = STATE(5652),
    [sym_actions_section] = STATE(5652),
    [sym_views_section] = STATE(5652),
    [sym_dataset_section] = STATE(5652),
    [sym_requestpage_section] = STATE(5652),
    [sym_rendering_section] = STATE(5652),
    [sym_elements_section] = STATE(5652),
    [sym_schema_section] = STATE(5652),
    [sym_assembly_declaration] = STATE(5652),
    [sym_event_declaration] = STATE(5652),
    [sym_procedure] = STATE(5652),
    [sym_preproc_split_procedure] = STATE(5652),
    [sym_preproc_split_procedure_preamble] = STATE(5652),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5652),
    [sym_var_section] = STATE(5652),
    [sym_attribute_item] = STATE(5652),
    [sym_preproc_conditional] = STATE(5652),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5652),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13868),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5538)] = {
    [sym_identifier] = ACTIONS(8990),
    [anon_sym_SEMI] = ACTIONS(8992),
    [anon_sym_RBRACE] = ACTIONS(8992),
    [aux_sym_where_condition_token1] = ACTIONS(8990),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8990),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8990),
    [anon_sym_LBRACK] = ACTIONS(8992),
    [aux_sym_basic_type_token6] = ACTIONS(8990),
    [aux_sym_basic_type_token22] = ACTIONS(8990),
    [aux_sym_basic_type_token53] = ACTIONS(8990),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8990),
    [aux_sym_addafter_modification_token1] = ACTIONS(8990),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8990),
    [aux_sym_modify_modification_token1] = ACTIONS(8990),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8990),
    [aux_sym_movelast_modification_token1] = ACTIONS(8990),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8990),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8990),
    [aux_sym_separator_action_token1] = ACTIONS(8990),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8990),
    [aux_sym_type_declaration_token1] = ACTIONS(8990),
    [anon_sym_POUNDif] = ACTIONS(8992),
    [anon_sym_POUNDIF] = ACTIONS(8992),
    [anon_sym_POUNDIf] = ACTIONS(8992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8990),
    [sym_procedure_keyword] = ACTIONS(8990),
    [sym_trigger_keyword] = ACTIONS(8990),
    [sym_var_keyword] = ACTIONS(8990),
    [sym_local_keyword] = ACTIONS(8990),
    [sym_internal_keyword] = ACTIONS(8990),
    [sym_protected_keyword] = ACTIONS(8990),
    [sym_event_keyword] = ACTIONS(8990),
    [sym_fields_keyword] = ACTIONS(8990),
    [sym_keys_keyword] = ACTIONS(8990),
    [sym_key_keyword] = ACTIONS(8990),
    [sym_fieldgroups_keyword] = ACTIONS(8990),
    [sym_actions_keyword] = ACTIONS(8990),
    [sym_layout_keyword] = ACTIONS(8990),
    [sym_area_keyword] = ACTIONS(8990),
    [sym_group_keyword] = ACTIONS(8990),
    [sym_repeater_keyword] = ACTIONS(8990),
    [sym_cuegroup_keyword] = ACTIONS(8990),
    [sym_fixed_keyword] = ACTIONS(8990),
    [sym_grid_keyword] = ACTIONS(8990),
    [sym_part_keyword] = ACTIONS(8990),
    [sym_systempart_keyword] = ACTIONS(8990),
    [sym_usercontrol_keyword] = ACTIONS(8990),
    [sym_dataset_keyword] = ACTIONS(8990),
    [sym_elements_keyword] = ACTIONS(8990),
    [sym_dataitem_keyword] = ACTIONS(8990),
    [sym_column_keyword] = ACTIONS(8990),
    [sym_filter_keyword] = ACTIONS(8990),
    [sym_labels_keyword] = ACTIONS(8990),
    [sym_rendering_keyword] = ACTIONS(8990),
    [sym_requestpage_keyword] = ACTIONS(8990),
    [sym_schema_keyword] = ACTIONS(8990),
    [sym_views_keyword] = ACTIONS(8990),
    [sym_quoted_identifier] = ACTIONS(8992),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8992),
    [sym_preproc_open] = ACTIONS(8992),
    [sym_var_attribute_open] = ACTIONS(8992),
  },
  [STATE(5539)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13870),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5540)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_RBRACE] = ACTIONS(5937),
    [aux_sym_where_condition_token1] = ACTIONS(5935),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5935),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_basic_type_token6] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token53] = ACTIONS(5935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5935),
    [aux_sym_addafter_modification_token1] = ACTIONS(5935),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5935),
    [aux_sym_modify_modification_token1] = ACTIONS(5935),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5935),
    [aux_sym_movelast_modification_token1] = ACTIONS(5935),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5935),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5935),
    [aux_sym_separator_action_token1] = ACTIONS(5935),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5935),
    [aux_sym_type_declaration_token1] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5935),
    [sym_procedure_keyword] = ACTIONS(5935),
    [sym_trigger_keyword] = ACTIONS(5935),
    [sym_var_keyword] = ACTIONS(5935),
    [sym_local_keyword] = ACTIONS(5935),
    [sym_internal_keyword] = ACTIONS(5935),
    [sym_protected_keyword] = ACTIONS(5935),
    [sym_event_keyword] = ACTIONS(5935),
    [sym_fields_keyword] = ACTIONS(5935),
    [sym_keys_keyword] = ACTIONS(5935),
    [sym_key_keyword] = ACTIONS(5935),
    [sym_fieldgroups_keyword] = ACTIONS(5935),
    [sym_actions_keyword] = ACTIONS(5935),
    [sym_layout_keyword] = ACTIONS(5935),
    [sym_area_keyword] = ACTIONS(5935),
    [sym_group_keyword] = ACTIONS(5935),
    [sym_repeater_keyword] = ACTIONS(5935),
    [sym_cuegroup_keyword] = ACTIONS(5935),
    [sym_fixed_keyword] = ACTIONS(5935),
    [sym_grid_keyword] = ACTIONS(5935),
    [sym_part_keyword] = ACTIONS(5935),
    [sym_systempart_keyword] = ACTIONS(5935),
    [sym_usercontrol_keyword] = ACTIONS(5935),
    [sym_dataset_keyword] = ACTIONS(5935),
    [sym_elements_keyword] = ACTIONS(5935),
    [sym_dataitem_keyword] = ACTIONS(5935),
    [sym_column_keyword] = ACTIONS(5935),
    [sym_filter_keyword] = ACTIONS(5935),
    [sym_labels_keyword] = ACTIONS(5935),
    [sym_rendering_keyword] = ACTIONS(5935),
    [sym_requestpage_keyword] = ACTIONS(5935),
    [sym_schema_keyword] = ACTIONS(5935),
    [sym_views_keyword] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_var_attribute_open] = ACTIONS(5937),
  },
  [STATE(5541)] = {
    [sym__body_element] = STATE(5787),
    [sym_empty_statement] = STATE(5787),
    [sym_property] = STATE(5787),
    [sym_permissions_property] = STATE(5787),
    [sym_table_relation_property] = STATE(5787),
    [sym_fields_section] = STATE(5787),
    [sym_keys_section] = STATE(5787),
    [sym_fieldgroups_section] = STATE(5787),
    [sym_enum_value_declaration] = STATE(5787),
    [sym_labels_section] = STATE(5787),
    [sym_layout_section] = STATE(5787),
    [sym_modify_modification] = STATE(5787),
    [sym_actions_section] = STATE(5787),
    [sym_views_section] = STATE(5787),
    [sym_dataset_section] = STATE(5787),
    [sym_requestpage_section] = STATE(5787),
    [sym_rendering_section] = STATE(5787),
    [sym_elements_section] = STATE(5787),
    [sym_schema_section] = STATE(5787),
    [sym_assembly_declaration] = STATE(5787),
    [sym_event_declaration] = STATE(5787),
    [sym_procedure] = STATE(5787),
    [sym_preproc_split_procedure] = STATE(5787),
    [sym_preproc_split_procedure_preamble] = STATE(5787),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5787),
    [sym_var_section] = STATE(5787),
    [sym_attribute_item] = STATE(5787),
    [sym_preproc_conditional] = STATE(5787),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5787),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13872),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5542)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13874),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5543)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13876),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5544)] = {
    [sym_identifier] = ACTIONS(8885),
    [anon_sym_SEMI] = ACTIONS(8887),
    [anon_sym_RBRACE] = ACTIONS(8887),
    [aux_sym_where_condition_token1] = ACTIONS(8885),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8885),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8885),
    [anon_sym_LBRACK] = ACTIONS(8887),
    [aux_sym_basic_type_token6] = ACTIONS(8885),
    [aux_sym_basic_type_token22] = ACTIONS(8885),
    [aux_sym_basic_type_token53] = ACTIONS(8885),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8885),
    [aux_sym_addafter_modification_token1] = ACTIONS(8885),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8885),
    [aux_sym_modify_modification_token1] = ACTIONS(8885),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8885),
    [aux_sym_movelast_modification_token1] = ACTIONS(8885),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8885),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8885),
    [aux_sym_separator_action_token1] = ACTIONS(8885),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8885),
    [aux_sym_type_declaration_token1] = ACTIONS(8885),
    [anon_sym_POUNDif] = ACTIONS(8887),
    [anon_sym_POUNDIF] = ACTIONS(8887),
    [anon_sym_POUNDIf] = ACTIONS(8887),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8885),
    [sym_procedure_keyword] = ACTIONS(8885),
    [sym_trigger_keyword] = ACTIONS(8885),
    [sym_var_keyword] = ACTIONS(8885),
    [sym_local_keyword] = ACTIONS(8885),
    [sym_internal_keyword] = ACTIONS(8885),
    [sym_protected_keyword] = ACTIONS(8885),
    [sym_event_keyword] = ACTIONS(8885),
    [sym_fields_keyword] = ACTIONS(8885),
    [sym_keys_keyword] = ACTIONS(8885),
    [sym_key_keyword] = ACTIONS(8885),
    [sym_fieldgroups_keyword] = ACTIONS(8885),
    [sym_actions_keyword] = ACTIONS(8885),
    [sym_layout_keyword] = ACTIONS(8885),
    [sym_area_keyword] = ACTIONS(8885),
    [sym_group_keyword] = ACTIONS(8885),
    [sym_repeater_keyword] = ACTIONS(8885),
    [sym_cuegroup_keyword] = ACTIONS(8885),
    [sym_fixed_keyword] = ACTIONS(8885),
    [sym_grid_keyword] = ACTIONS(8885),
    [sym_part_keyword] = ACTIONS(8885),
    [sym_systempart_keyword] = ACTIONS(8885),
    [sym_usercontrol_keyword] = ACTIONS(8885),
    [sym_dataset_keyword] = ACTIONS(8885),
    [sym_elements_keyword] = ACTIONS(8885),
    [sym_dataitem_keyword] = ACTIONS(8885),
    [sym_column_keyword] = ACTIONS(8885),
    [sym_filter_keyword] = ACTIONS(8885),
    [sym_labels_keyword] = ACTIONS(8885),
    [sym_rendering_keyword] = ACTIONS(8885),
    [sym_requestpage_keyword] = ACTIONS(8885),
    [sym_schema_keyword] = ACTIONS(8885),
    [sym_views_keyword] = ACTIONS(8885),
    [sym_quoted_identifier] = ACTIONS(8887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8887),
    [sym_preproc_open] = ACTIONS(8887),
    [sym_var_attribute_open] = ACTIONS(8887),
  },
  [STATE(5545)] = {
    [sym_identifier] = ACTIONS(9026),
    [anon_sym_SEMI] = ACTIONS(9028),
    [anon_sym_RBRACE] = ACTIONS(9028),
    [aux_sym_where_condition_token1] = ACTIONS(9026),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9026),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9026),
    [anon_sym_LBRACK] = ACTIONS(9028),
    [aux_sym_basic_type_token6] = ACTIONS(9026),
    [aux_sym_basic_type_token22] = ACTIONS(9026),
    [aux_sym_basic_type_token53] = ACTIONS(9026),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9026),
    [aux_sym_addafter_modification_token1] = ACTIONS(9026),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9026),
    [aux_sym_modify_modification_token1] = ACTIONS(9026),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9026),
    [aux_sym_movelast_modification_token1] = ACTIONS(9026),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9026),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9026),
    [aux_sym_separator_action_token1] = ACTIONS(9026),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9026),
    [aux_sym_type_declaration_token1] = ACTIONS(9026),
    [anon_sym_POUNDif] = ACTIONS(9028),
    [anon_sym_POUNDIF] = ACTIONS(9028),
    [anon_sym_POUNDIf] = ACTIONS(9028),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9026),
    [sym_procedure_keyword] = ACTIONS(9026),
    [sym_trigger_keyword] = ACTIONS(9026),
    [sym_var_keyword] = ACTIONS(9026),
    [sym_local_keyword] = ACTIONS(9026),
    [sym_internal_keyword] = ACTIONS(9026),
    [sym_protected_keyword] = ACTIONS(9026),
    [sym_event_keyword] = ACTIONS(9026),
    [sym_fields_keyword] = ACTIONS(9026),
    [sym_keys_keyword] = ACTIONS(9026),
    [sym_key_keyword] = ACTIONS(9026),
    [sym_fieldgroups_keyword] = ACTIONS(9026),
    [sym_actions_keyword] = ACTIONS(9026),
    [sym_layout_keyword] = ACTIONS(9026),
    [sym_area_keyword] = ACTIONS(9026),
    [sym_group_keyword] = ACTIONS(9026),
    [sym_repeater_keyword] = ACTIONS(9026),
    [sym_cuegroup_keyword] = ACTIONS(9026),
    [sym_fixed_keyword] = ACTIONS(9026),
    [sym_grid_keyword] = ACTIONS(9026),
    [sym_part_keyword] = ACTIONS(9026),
    [sym_systempart_keyword] = ACTIONS(9026),
    [sym_usercontrol_keyword] = ACTIONS(9026),
    [sym_dataset_keyword] = ACTIONS(9026),
    [sym_elements_keyword] = ACTIONS(9026),
    [sym_dataitem_keyword] = ACTIONS(9026),
    [sym_column_keyword] = ACTIONS(9026),
    [sym_filter_keyword] = ACTIONS(9026),
    [sym_labels_keyword] = ACTIONS(9026),
    [sym_rendering_keyword] = ACTIONS(9026),
    [sym_requestpage_keyword] = ACTIONS(9026),
    [sym_schema_keyword] = ACTIONS(9026),
    [sym_views_keyword] = ACTIONS(9026),
    [sym_quoted_identifier] = ACTIONS(9028),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9028),
    [sym_preproc_open] = ACTIONS(9028),
    [sym_var_attribute_open] = ACTIONS(9028),
  },
  [STATE(5546)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13878),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5547)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13880),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5548)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13882),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5549)] = {
    [sym__body_element] = STATE(5698),
    [sym_empty_statement] = STATE(5698),
    [sym_property] = STATE(5698),
    [sym_permissions_property] = STATE(5698),
    [sym_table_relation_property] = STATE(5698),
    [sym_fields_section] = STATE(5698),
    [sym_keys_section] = STATE(5698),
    [sym_fieldgroups_section] = STATE(5698),
    [sym_enum_value_declaration] = STATE(5698),
    [sym_labels_section] = STATE(5698),
    [sym_layout_section] = STATE(5698),
    [sym_modify_modification] = STATE(5698),
    [sym_actions_section] = STATE(5698),
    [sym_views_section] = STATE(5698),
    [sym_dataset_section] = STATE(5698),
    [sym_requestpage_section] = STATE(5698),
    [sym_rendering_section] = STATE(5698),
    [sym_elements_section] = STATE(5698),
    [sym_schema_section] = STATE(5698),
    [sym_assembly_declaration] = STATE(5698),
    [sym_event_declaration] = STATE(5698),
    [sym_procedure] = STATE(5698),
    [sym_preproc_split_procedure] = STATE(5698),
    [sym_preproc_split_procedure_preamble] = STATE(5698),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5698),
    [sym_var_section] = STATE(5698),
    [sym_attribute_item] = STATE(5698),
    [sym_preproc_conditional] = STATE(5698),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5698),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13884),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5550)] = {
    [sym_identifier] = ACTIONS(9030),
    [anon_sym_SEMI] = ACTIONS(9032),
    [anon_sym_RBRACE] = ACTIONS(9032),
    [aux_sym_where_condition_token1] = ACTIONS(9030),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9030),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9030),
    [anon_sym_LBRACK] = ACTIONS(9032),
    [aux_sym_basic_type_token6] = ACTIONS(9030),
    [aux_sym_basic_type_token22] = ACTIONS(9030),
    [aux_sym_basic_type_token53] = ACTIONS(9030),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9030),
    [aux_sym_addafter_modification_token1] = ACTIONS(9030),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9030),
    [aux_sym_modify_modification_token1] = ACTIONS(9030),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9030),
    [aux_sym_movelast_modification_token1] = ACTIONS(9030),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9030),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9030),
    [aux_sym_separator_action_token1] = ACTIONS(9030),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9030),
    [aux_sym_type_declaration_token1] = ACTIONS(9030),
    [anon_sym_POUNDif] = ACTIONS(9032),
    [anon_sym_POUNDIF] = ACTIONS(9032),
    [anon_sym_POUNDIf] = ACTIONS(9032),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9030),
    [sym_procedure_keyword] = ACTIONS(9030),
    [sym_trigger_keyword] = ACTIONS(9030),
    [sym_var_keyword] = ACTIONS(9030),
    [sym_local_keyword] = ACTIONS(9030),
    [sym_internal_keyword] = ACTIONS(9030),
    [sym_protected_keyword] = ACTIONS(9030),
    [sym_event_keyword] = ACTIONS(9030),
    [sym_fields_keyword] = ACTIONS(9030),
    [sym_keys_keyword] = ACTIONS(9030),
    [sym_key_keyword] = ACTIONS(9030),
    [sym_fieldgroups_keyword] = ACTIONS(9030),
    [sym_actions_keyword] = ACTIONS(9030),
    [sym_layout_keyword] = ACTIONS(9030),
    [sym_area_keyword] = ACTIONS(9030),
    [sym_group_keyword] = ACTIONS(9030),
    [sym_repeater_keyword] = ACTIONS(9030),
    [sym_cuegroup_keyword] = ACTIONS(9030),
    [sym_fixed_keyword] = ACTIONS(9030),
    [sym_grid_keyword] = ACTIONS(9030),
    [sym_part_keyword] = ACTIONS(9030),
    [sym_systempart_keyword] = ACTIONS(9030),
    [sym_usercontrol_keyword] = ACTIONS(9030),
    [sym_dataset_keyword] = ACTIONS(9030),
    [sym_elements_keyword] = ACTIONS(9030),
    [sym_dataitem_keyword] = ACTIONS(9030),
    [sym_column_keyword] = ACTIONS(9030),
    [sym_filter_keyword] = ACTIONS(9030),
    [sym_labels_keyword] = ACTIONS(9030),
    [sym_rendering_keyword] = ACTIONS(9030),
    [sym_requestpage_keyword] = ACTIONS(9030),
    [sym_schema_keyword] = ACTIONS(9030),
    [sym_views_keyword] = ACTIONS(9030),
    [sym_quoted_identifier] = ACTIONS(9032),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9032),
    [sym_preproc_open] = ACTIONS(9032),
    [sym_var_attribute_open] = ACTIONS(9032),
  },
  [STATE(5551)] = {
    [sym_identifier] = ACTIONS(9034),
    [anon_sym_SEMI] = ACTIONS(9036),
    [anon_sym_RBRACE] = ACTIONS(9036),
    [aux_sym_where_condition_token1] = ACTIONS(9034),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9034),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9034),
    [anon_sym_LBRACK] = ACTIONS(9036),
    [aux_sym_basic_type_token6] = ACTIONS(9034),
    [aux_sym_basic_type_token22] = ACTIONS(9034),
    [aux_sym_basic_type_token53] = ACTIONS(9034),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9034),
    [aux_sym_addafter_modification_token1] = ACTIONS(9034),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9034),
    [aux_sym_modify_modification_token1] = ACTIONS(9034),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9034),
    [aux_sym_movelast_modification_token1] = ACTIONS(9034),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9034),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9034),
    [aux_sym_separator_action_token1] = ACTIONS(9034),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9034),
    [aux_sym_type_declaration_token1] = ACTIONS(9034),
    [anon_sym_POUNDif] = ACTIONS(9036),
    [anon_sym_POUNDIF] = ACTIONS(9036),
    [anon_sym_POUNDIf] = ACTIONS(9036),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9034),
    [sym_procedure_keyword] = ACTIONS(9034),
    [sym_trigger_keyword] = ACTIONS(9034),
    [sym_var_keyword] = ACTIONS(9034),
    [sym_local_keyword] = ACTIONS(9034),
    [sym_internal_keyword] = ACTIONS(9034),
    [sym_protected_keyword] = ACTIONS(9034),
    [sym_event_keyword] = ACTIONS(9034),
    [sym_fields_keyword] = ACTIONS(9034),
    [sym_keys_keyword] = ACTIONS(9034),
    [sym_key_keyword] = ACTIONS(9034),
    [sym_fieldgroups_keyword] = ACTIONS(9034),
    [sym_actions_keyword] = ACTIONS(9034),
    [sym_layout_keyword] = ACTIONS(9034),
    [sym_area_keyword] = ACTIONS(9034),
    [sym_group_keyword] = ACTIONS(9034),
    [sym_repeater_keyword] = ACTIONS(9034),
    [sym_cuegroup_keyword] = ACTIONS(9034),
    [sym_fixed_keyword] = ACTIONS(9034),
    [sym_grid_keyword] = ACTIONS(9034),
    [sym_part_keyword] = ACTIONS(9034),
    [sym_systempart_keyword] = ACTIONS(9034),
    [sym_usercontrol_keyword] = ACTIONS(9034),
    [sym_dataset_keyword] = ACTIONS(9034),
    [sym_elements_keyword] = ACTIONS(9034),
    [sym_dataitem_keyword] = ACTIONS(9034),
    [sym_column_keyword] = ACTIONS(9034),
    [sym_filter_keyword] = ACTIONS(9034),
    [sym_labels_keyword] = ACTIONS(9034),
    [sym_rendering_keyword] = ACTIONS(9034),
    [sym_requestpage_keyword] = ACTIONS(9034),
    [sym_schema_keyword] = ACTIONS(9034),
    [sym_views_keyword] = ACTIONS(9034),
    [sym_quoted_identifier] = ACTIONS(9036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9036),
    [sym_preproc_open] = ACTIONS(9036),
    [sym_var_attribute_open] = ACTIONS(9036),
  },
  [STATE(5552)] = {
    [sym_identifier] = ACTIONS(9040),
    [anon_sym_SEMI] = ACTIONS(9042),
    [anon_sym_RBRACE] = ACTIONS(9042),
    [aux_sym_where_condition_token1] = ACTIONS(9040),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9040),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9040),
    [anon_sym_LBRACK] = ACTIONS(9042),
    [aux_sym_basic_type_token6] = ACTIONS(9040),
    [aux_sym_basic_type_token22] = ACTIONS(9040),
    [aux_sym_basic_type_token53] = ACTIONS(9040),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9040),
    [aux_sym_addafter_modification_token1] = ACTIONS(9040),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9040),
    [aux_sym_modify_modification_token1] = ACTIONS(9040),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9040),
    [aux_sym_movelast_modification_token1] = ACTIONS(9040),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9040),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9040),
    [aux_sym_separator_action_token1] = ACTIONS(9040),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9040),
    [aux_sym_type_declaration_token1] = ACTIONS(9040),
    [anon_sym_POUNDif] = ACTIONS(9042),
    [anon_sym_POUNDIF] = ACTIONS(9042),
    [anon_sym_POUNDIf] = ACTIONS(9042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9040),
    [sym_procedure_keyword] = ACTIONS(9040),
    [sym_trigger_keyword] = ACTIONS(9040),
    [sym_var_keyword] = ACTIONS(9040),
    [sym_local_keyword] = ACTIONS(9040),
    [sym_internal_keyword] = ACTIONS(9040),
    [sym_protected_keyword] = ACTIONS(9040),
    [sym_event_keyword] = ACTIONS(9040),
    [sym_fields_keyword] = ACTIONS(9040),
    [sym_keys_keyword] = ACTIONS(9040),
    [sym_key_keyword] = ACTIONS(9040),
    [sym_fieldgroups_keyword] = ACTIONS(9040),
    [sym_actions_keyword] = ACTIONS(9040),
    [sym_layout_keyword] = ACTIONS(9040),
    [sym_area_keyword] = ACTIONS(9040),
    [sym_group_keyword] = ACTIONS(9040),
    [sym_repeater_keyword] = ACTIONS(9040),
    [sym_cuegroup_keyword] = ACTIONS(9040),
    [sym_fixed_keyword] = ACTIONS(9040),
    [sym_grid_keyword] = ACTIONS(9040),
    [sym_part_keyword] = ACTIONS(9040),
    [sym_systempart_keyword] = ACTIONS(9040),
    [sym_usercontrol_keyword] = ACTIONS(9040),
    [sym_dataset_keyword] = ACTIONS(9040),
    [sym_elements_keyword] = ACTIONS(9040),
    [sym_dataitem_keyword] = ACTIONS(9040),
    [sym_column_keyword] = ACTIONS(9040),
    [sym_filter_keyword] = ACTIONS(9040),
    [sym_labels_keyword] = ACTIONS(9040),
    [sym_rendering_keyword] = ACTIONS(9040),
    [sym_requestpage_keyword] = ACTIONS(9040),
    [sym_schema_keyword] = ACTIONS(9040),
    [sym_views_keyword] = ACTIONS(9040),
    [sym_quoted_identifier] = ACTIONS(9042),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9042),
    [sym_preproc_open] = ACTIONS(9042),
    [sym_var_attribute_open] = ACTIONS(9042),
  },
  [STATE(5553)] = {
    [sym__body_element] = STATE(5699),
    [sym_empty_statement] = STATE(5699),
    [sym_property] = STATE(5699),
    [sym_permissions_property] = STATE(5699),
    [sym_table_relation_property] = STATE(5699),
    [sym_fields_section] = STATE(5699),
    [sym_keys_section] = STATE(5699),
    [sym_fieldgroups_section] = STATE(5699),
    [sym_enum_value_declaration] = STATE(5699),
    [sym_labels_section] = STATE(5699),
    [sym_layout_section] = STATE(5699),
    [sym_modify_modification] = STATE(5699),
    [sym_actions_section] = STATE(5699),
    [sym_views_section] = STATE(5699),
    [sym_dataset_section] = STATE(5699),
    [sym_requestpage_section] = STATE(5699),
    [sym_rendering_section] = STATE(5699),
    [sym_elements_section] = STATE(5699),
    [sym_schema_section] = STATE(5699),
    [sym_assembly_declaration] = STATE(5699),
    [sym_event_declaration] = STATE(5699),
    [sym_procedure] = STATE(5699),
    [sym_preproc_split_procedure] = STATE(5699),
    [sym_preproc_split_procedure_preamble] = STATE(5699),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5699),
    [sym_var_section] = STATE(5699),
    [sym_attribute_item] = STATE(5699),
    [sym_preproc_conditional] = STATE(5699),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5699),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13886),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5554)] = {
    [sym__body_element] = STATE(5742),
    [sym_empty_statement] = STATE(5742),
    [sym_property] = STATE(5742),
    [sym_permissions_property] = STATE(5742),
    [sym_table_relation_property] = STATE(5742),
    [sym_fields_section] = STATE(5742),
    [sym_keys_section] = STATE(5742),
    [sym_fieldgroups_section] = STATE(5742),
    [sym_enum_value_declaration] = STATE(5742),
    [sym_labels_section] = STATE(5742),
    [sym_layout_section] = STATE(5742),
    [sym_modify_modification] = STATE(5742),
    [sym_actions_section] = STATE(5742),
    [sym_views_section] = STATE(5742),
    [sym_dataset_section] = STATE(5742),
    [sym_requestpage_section] = STATE(5742),
    [sym_rendering_section] = STATE(5742),
    [sym_elements_section] = STATE(5742),
    [sym_schema_section] = STATE(5742),
    [sym_assembly_declaration] = STATE(5742),
    [sym_event_declaration] = STATE(5742),
    [sym_procedure] = STATE(5742),
    [sym_preproc_split_procedure] = STATE(5742),
    [sym_preproc_split_procedure_preamble] = STATE(5742),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5742),
    [sym_var_section] = STATE(5742),
    [sym_attribute_item] = STATE(5742),
    [sym_preproc_conditional] = STATE(5742),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5742),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13888),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5555)] = {
    [sym__body_element] = STATE(5853),
    [sym_empty_statement] = STATE(5853),
    [sym_property] = STATE(5853),
    [sym_permissions_property] = STATE(5853),
    [sym_table_relation_property] = STATE(5853),
    [sym_fields_section] = STATE(5853),
    [sym_keys_section] = STATE(5853),
    [sym_fieldgroups_section] = STATE(5853),
    [sym_enum_value_declaration] = STATE(5853),
    [sym_labels_section] = STATE(5853),
    [sym_layout_section] = STATE(5853),
    [sym_modify_modification] = STATE(5853),
    [sym_actions_section] = STATE(5853),
    [sym_views_section] = STATE(5853),
    [sym_dataset_section] = STATE(5853),
    [sym_requestpage_section] = STATE(5853),
    [sym_rendering_section] = STATE(5853),
    [sym_elements_section] = STATE(5853),
    [sym_schema_section] = STATE(5853),
    [sym_assembly_declaration] = STATE(5853),
    [sym_event_declaration] = STATE(5853),
    [sym_procedure] = STATE(5853),
    [sym_preproc_split_procedure] = STATE(5853),
    [sym_preproc_split_procedure_preamble] = STATE(5853),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5853),
    [sym_var_section] = STATE(5853),
    [sym_attribute_item] = STATE(5853),
    [sym_preproc_conditional] = STATE(5853),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5853),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13890),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5556)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13892),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5557)] = {
    [anon_sym_SEMI] = ACTIONS(8333),
    [anon_sym_RBRACE] = ACTIONS(8333),
    [anon_sym_COMMA] = ACTIONS(8333),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8333),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8335),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8333),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8333),
    [anon_sym_LBRACK] = ACTIONS(8333),
    [aux_sym_basic_type_token22] = ACTIONS(8335),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8333),
    [aux_sym_addafter_modification_token1] = ACTIONS(8333),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8333),
    [aux_sym_modify_modification_token1] = ACTIONS(8333),
    [aux_sym_separator_action_token1] = ACTIONS(8333),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8333),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8333),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8333),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8333),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8333),
    [anon_sym_POUNDif] = ACTIONS(8333),
    [anon_sym_POUNDIF] = ACTIONS(8333),
    [anon_sym_POUNDIf] = ACTIONS(8333),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8335),
    [sym_page_keyword] = ACTIONS(8333),
    [anon_sym_codeunit] = ACTIONS(8333),
    [anon_sym_CODEUNIT] = ACTIONS(8333),
    [anon_sym_Codeunit] = ACTIONS(8333),
    [anon_sym_CodeUnit] = ACTIONS(8333),
    [anon_sym_COdeunit] = ACTIONS(8333),
    [anon_sym_codeUnit] = ACTIONS(8333),
    [sym_report_keyword] = ACTIONS(8333),
    [sym_query_keyword] = ACTIONS(8333),
    [anon_sym_xmlport] = ACTIONS(8333),
    [anon_sym_XMLPORT] = ACTIONS(8333),
    [anon_sym_Xmlport] = ACTIONS(8333),
    [anon_sym_XMLport] = ACTIONS(8333),
    [anon_sym_XMLPort] = ACTIONS(8333),
    [anon_sym_XmlPort] = ACTIONS(8333),
    [sym_procedure_keyword] = ACTIONS(8333),
    [sym_trigger_keyword] = ACTIONS(8333),
    [sym_var_keyword] = ACTIONS(8333),
    [sym_local_keyword] = ACTIONS(8333),
    [sym_internal_keyword] = ACTIONS(8333),
    [sym_protected_keyword] = ACTIONS(8333),
    [sym_event_keyword] = ACTIONS(8333),
    [sym_fields_keyword] = ACTIONS(8333),
    [sym_keys_keyword] = ACTIONS(8333),
    [sym_fieldgroups_keyword] = ACTIONS(8333),
    [sym_actions_keyword] = ACTIONS(8333),
    [sym_layout_keyword] = ACTIONS(8333),
    [sym_area_keyword] = ACTIONS(8333),
    [sym_group_keyword] = ACTIONS(8333),
    [sym_dataset_keyword] = ACTIONS(8333),
    [sym_elements_keyword] = ACTIONS(8333),
    [sym_labels_keyword] = ACTIONS(8333),
    [sym_rendering_keyword] = ACTIONS(8333),
    [sym_requestpage_keyword] = ACTIONS(8333),
    [sym_schema_keyword] = ACTIONS(8333),
    [sym_views_keyword] = ACTIONS(8333),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8333),
    [sym_preproc_open] = ACTIONS(8333),
  },
  [STATE(5558)] = {
    [sym__body_element] = STATE(5788),
    [sym_empty_statement] = STATE(5788),
    [sym_property] = STATE(5788),
    [sym_permissions_property] = STATE(5788),
    [sym_table_relation_property] = STATE(5788),
    [sym_fields_section] = STATE(5788),
    [sym_keys_section] = STATE(5788),
    [sym_fieldgroups_section] = STATE(5788),
    [sym_enum_value_declaration] = STATE(5788),
    [sym_labels_section] = STATE(5788),
    [sym_layout_section] = STATE(5788),
    [sym_modify_modification] = STATE(5788),
    [sym_actions_section] = STATE(5788),
    [sym_views_section] = STATE(5788),
    [sym_dataset_section] = STATE(5788),
    [sym_requestpage_section] = STATE(5788),
    [sym_rendering_section] = STATE(5788),
    [sym_elements_section] = STATE(5788),
    [sym_schema_section] = STATE(5788),
    [sym_assembly_declaration] = STATE(5788),
    [sym_event_declaration] = STATE(5788),
    [sym_procedure] = STATE(5788),
    [sym_preproc_split_procedure] = STATE(5788),
    [sym_preproc_split_procedure_preamble] = STATE(5788),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5788),
    [sym_var_section] = STATE(5788),
    [sym_attribute_item] = STATE(5788),
    [sym_preproc_conditional] = STATE(5788),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5788),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13894),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5559)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13896),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5560)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13898),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5561)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13900),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5562)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13902),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5563)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13904),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5564)] = {
    [sym__body_element] = STATE(5462),
    [sym_empty_statement] = STATE(5462),
    [sym_property] = STATE(5462),
    [sym_permissions_property] = STATE(5462),
    [sym_table_relation_property] = STATE(5462),
    [sym_fields_section] = STATE(5462),
    [sym_keys_section] = STATE(5462),
    [sym_fieldgroups_section] = STATE(5462),
    [sym_enum_value_declaration] = STATE(5462),
    [sym_labels_section] = STATE(5462),
    [sym_layout_section] = STATE(5462),
    [sym_modify_modification] = STATE(5462),
    [sym_actions_section] = STATE(5462),
    [sym_views_section] = STATE(5462),
    [sym_dataset_section] = STATE(5462),
    [sym_requestpage_section] = STATE(5462),
    [sym_rendering_section] = STATE(5462),
    [sym_elements_section] = STATE(5462),
    [sym_schema_section] = STATE(5462),
    [sym_assembly_declaration] = STATE(5462),
    [sym_event_declaration] = STATE(5462),
    [sym_procedure] = STATE(5462),
    [sym_preproc_split_procedure] = STATE(5462),
    [sym_preproc_split_procedure_preamble] = STATE(5462),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5462),
    [sym_var_section] = STATE(5462),
    [sym_attribute_item] = STATE(5462),
    [sym_preproc_conditional] = STATE(5462),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5462),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13906),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5565)] = {
    [sym__body_element] = STATE(5648),
    [sym_empty_statement] = STATE(5648),
    [sym_property] = STATE(5648),
    [sym_permissions_property] = STATE(5648),
    [sym_table_relation_property] = STATE(5648),
    [sym_fields_section] = STATE(5648),
    [sym_keys_section] = STATE(5648),
    [sym_fieldgroups_section] = STATE(5648),
    [sym_enum_value_declaration] = STATE(5648),
    [sym_labels_section] = STATE(5648),
    [sym_layout_section] = STATE(5648),
    [sym_modify_modification] = STATE(5648),
    [sym_actions_section] = STATE(5648),
    [sym_views_section] = STATE(5648),
    [sym_dataset_section] = STATE(5648),
    [sym_requestpage_section] = STATE(5648),
    [sym_rendering_section] = STATE(5648),
    [sym_elements_section] = STATE(5648),
    [sym_schema_section] = STATE(5648),
    [sym_assembly_declaration] = STATE(5648),
    [sym_event_declaration] = STATE(5648),
    [sym_procedure] = STATE(5648),
    [sym_preproc_split_procedure] = STATE(5648),
    [sym_preproc_split_procedure_preamble] = STATE(5648),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5648),
    [sym_var_section] = STATE(5648),
    [sym_attribute_item] = STATE(5648),
    [sym_preproc_conditional] = STATE(5648),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5648),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13908),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5566)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13910),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5567)] = {
    [sym__body_element] = STATE(5655),
    [sym_empty_statement] = STATE(5655),
    [sym_property] = STATE(5655),
    [sym_permissions_property] = STATE(5655),
    [sym_table_relation_property] = STATE(5655),
    [sym_fields_section] = STATE(5655),
    [sym_keys_section] = STATE(5655),
    [sym_fieldgroups_section] = STATE(5655),
    [sym_enum_value_declaration] = STATE(5655),
    [sym_labels_section] = STATE(5655),
    [sym_layout_section] = STATE(5655),
    [sym_modify_modification] = STATE(5655),
    [sym_actions_section] = STATE(5655),
    [sym_views_section] = STATE(5655),
    [sym_dataset_section] = STATE(5655),
    [sym_requestpage_section] = STATE(5655),
    [sym_rendering_section] = STATE(5655),
    [sym_elements_section] = STATE(5655),
    [sym_schema_section] = STATE(5655),
    [sym_assembly_declaration] = STATE(5655),
    [sym_event_declaration] = STATE(5655),
    [sym_procedure] = STATE(5655),
    [sym_preproc_split_procedure] = STATE(5655),
    [sym_preproc_split_procedure_preamble] = STATE(5655),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5655),
    [sym_var_section] = STATE(5655),
    [sym_attribute_item] = STATE(5655),
    [sym_preproc_conditional] = STATE(5655),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5655),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13912),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5568)] = {
    [sym__body_element] = STATE(5658),
    [sym_empty_statement] = STATE(5658),
    [sym_property] = STATE(5658),
    [sym_permissions_property] = STATE(5658),
    [sym_table_relation_property] = STATE(5658),
    [sym_fields_section] = STATE(5658),
    [sym_keys_section] = STATE(5658),
    [sym_fieldgroups_section] = STATE(5658),
    [sym_enum_value_declaration] = STATE(5658),
    [sym_labels_section] = STATE(5658),
    [sym_layout_section] = STATE(5658),
    [sym_modify_modification] = STATE(5658),
    [sym_actions_section] = STATE(5658),
    [sym_views_section] = STATE(5658),
    [sym_dataset_section] = STATE(5658),
    [sym_requestpage_section] = STATE(5658),
    [sym_rendering_section] = STATE(5658),
    [sym_elements_section] = STATE(5658),
    [sym_schema_section] = STATE(5658),
    [sym_assembly_declaration] = STATE(5658),
    [sym_event_declaration] = STATE(5658),
    [sym_procedure] = STATE(5658),
    [sym_preproc_split_procedure] = STATE(5658),
    [sym_preproc_split_procedure_preamble] = STATE(5658),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5658),
    [sym_var_section] = STATE(5658),
    [sym_attribute_item] = STATE(5658),
    [sym_preproc_conditional] = STATE(5658),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5658),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13914),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5569)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13916),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5570)] = {
    [sym__body_element] = STATE(5683),
    [sym_empty_statement] = STATE(5683),
    [sym_property] = STATE(5683),
    [sym_permissions_property] = STATE(5683),
    [sym_table_relation_property] = STATE(5683),
    [sym_fields_section] = STATE(5683),
    [sym_keys_section] = STATE(5683),
    [sym_fieldgroups_section] = STATE(5683),
    [sym_enum_value_declaration] = STATE(5683),
    [sym_labels_section] = STATE(5683),
    [sym_layout_section] = STATE(5683),
    [sym_modify_modification] = STATE(5683),
    [sym_actions_section] = STATE(5683),
    [sym_views_section] = STATE(5683),
    [sym_dataset_section] = STATE(5683),
    [sym_requestpage_section] = STATE(5683),
    [sym_rendering_section] = STATE(5683),
    [sym_elements_section] = STATE(5683),
    [sym_schema_section] = STATE(5683),
    [sym_assembly_declaration] = STATE(5683),
    [sym_event_declaration] = STATE(5683),
    [sym_procedure] = STATE(5683),
    [sym_preproc_split_procedure] = STATE(5683),
    [sym_preproc_split_procedure_preamble] = STATE(5683),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5683),
    [sym_var_section] = STATE(5683),
    [sym_attribute_item] = STATE(5683),
    [sym_preproc_conditional] = STATE(5683),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5683),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13918),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5571)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13920),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5572)] = {
    [sym__body_element] = STATE(5815),
    [sym_empty_statement] = STATE(5815),
    [sym_property] = STATE(5815),
    [sym_permissions_property] = STATE(5815),
    [sym_table_relation_property] = STATE(5815),
    [sym_fields_section] = STATE(5815),
    [sym_keys_section] = STATE(5815),
    [sym_fieldgroups_section] = STATE(5815),
    [sym_enum_value_declaration] = STATE(5815),
    [sym_labels_section] = STATE(5815),
    [sym_layout_section] = STATE(5815),
    [sym_modify_modification] = STATE(5815),
    [sym_actions_section] = STATE(5815),
    [sym_views_section] = STATE(5815),
    [sym_dataset_section] = STATE(5815),
    [sym_requestpage_section] = STATE(5815),
    [sym_rendering_section] = STATE(5815),
    [sym_elements_section] = STATE(5815),
    [sym_schema_section] = STATE(5815),
    [sym_assembly_declaration] = STATE(5815),
    [sym_event_declaration] = STATE(5815),
    [sym_procedure] = STATE(5815),
    [sym_preproc_split_procedure] = STATE(5815),
    [sym_preproc_split_procedure_preamble] = STATE(5815),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5815),
    [sym_var_section] = STATE(5815),
    [sym_attribute_item] = STATE(5815),
    [sym_preproc_conditional] = STATE(5815),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5815),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13922),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5573)] = {
    [sym__body_element] = STATE(5685),
    [sym_empty_statement] = STATE(5685),
    [sym_property] = STATE(5685),
    [sym_permissions_property] = STATE(5685),
    [sym_table_relation_property] = STATE(5685),
    [sym_fields_section] = STATE(5685),
    [sym_keys_section] = STATE(5685),
    [sym_fieldgroups_section] = STATE(5685),
    [sym_enum_value_declaration] = STATE(5685),
    [sym_labels_section] = STATE(5685),
    [sym_layout_section] = STATE(5685),
    [sym_modify_modification] = STATE(5685),
    [sym_actions_section] = STATE(5685),
    [sym_views_section] = STATE(5685),
    [sym_dataset_section] = STATE(5685),
    [sym_requestpage_section] = STATE(5685),
    [sym_rendering_section] = STATE(5685),
    [sym_elements_section] = STATE(5685),
    [sym_schema_section] = STATE(5685),
    [sym_assembly_declaration] = STATE(5685),
    [sym_event_declaration] = STATE(5685),
    [sym_procedure] = STATE(5685),
    [sym_preproc_split_procedure] = STATE(5685),
    [sym_preproc_split_procedure_preamble] = STATE(5685),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5685),
    [sym_var_section] = STATE(5685),
    [sym_attribute_item] = STATE(5685),
    [sym_preproc_conditional] = STATE(5685),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5685),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13924),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5574)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13926),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5575)] = {
    [sym__body_element] = STATE(5734),
    [sym_empty_statement] = STATE(5734),
    [sym_property] = STATE(5734),
    [sym_permissions_property] = STATE(5734),
    [sym_table_relation_property] = STATE(5734),
    [sym_fields_section] = STATE(5734),
    [sym_keys_section] = STATE(5734),
    [sym_fieldgroups_section] = STATE(5734),
    [sym_enum_value_declaration] = STATE(5734),
    [sym_labels_section] = STATE(5734),
    [sym_layout_section] = STATE(5734),
    [sym_modify_modification] = STATE(5734),
    [sym_actions_section] = STATE(5734),
    [sym_views_section] = STATE(5734),
    [sym_dataset_section] = STATE(5734),
    [sym_requestpage_section] = STATE(5734),
    [sym_rendering_section] = STATE(5734),
    [sym_elements_section] = STATE(5734),
    [sym_schema_section] = STATE(5734),
    [sym_assembly_declaration] = STATE(5734),
    [sym_event_declaration] = STATE(5734),
    [sym_procedure] = STATE(5734),
    [sym_preproc_split_procedure] = STATE(5734),
    [sym_preproc_split_procedure_preamble] = STATE(5734),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5734),
    [sym_var_section] = STATE(5734),
    [sym_attribute_item] = STATE(5734),
    [sym_preproc_conditional] = STATE(5734),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5734),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13928),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5576)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13930),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5577)] = {
    [sym_where_clause] = STATE(5936),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_RBRACE] = ACTIONS(5386),
    [aux_sym_where_clause_token1] = ACTIONS(6997),
    [aux_sym_where_condition_token1] = ACTIONS(5392),
    [aux_sym_else_table_relation_fragment_token1] = ACTIONS(5386),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5386),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5386),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [aux_sym_basic_type_token6] = ACTIONS(5392),
    [aux_sym_basic_type_token22] = ACTIONS(5392),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5386),
    [aux_sym_addafter_modification_token1] = ACTIONS(5386),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5386),
    [aux_sym_modify_modification_token1] = ACTIONS(5386),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5386),
    [aux_sym_movelast_modification_token1] = ACTIONS(5386),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5386),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5386),
    [aux_sym_separator_action_token1] = ACTIONS(5386),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5386),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5386),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5386),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5386),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5386),
    [anon_sym_POUNDif] = ACTIONS(5386),
    [anon_sym_POUNDIF] = ACTIONS(5386),
    [anon_sym_POUNDIf] = ACTIONS(5386),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(5386),
    [sym_trigger_keyword] = ACTIONS(5386),
    [sym_var_keyword] = ACTIONS(5386),
    [sym_local_keyword] = ACTIONS(5386),
    [sym_internal_keyword] = ACTIONS(5386),
    [sym_protected_keyword] = ACTIONS(5386),
    [sym_event_keyword] = ACTIONS(5386),
    [sym_fields_keyword] = ACTIONS(5386),
    [sym_keys_keyword] = ACTIONS(5386),
    [sym_fieldgroups_keyword] = ACTIONS(5386),
    [sym_actions_keyword] = ACTIONS(5386),
    [sym_layout_keyword] = ACTIONS(5386),
    [sym_area_keyword] = ACTIONS(5386),
    [sym_group_keyword] = ACTIONS(5386),
    [sym_repeater_keyword] = ACTIONS(5386),
    [sym_cuegroup_keyword] = ACTIONS(5386),
    [sym_fixed_keyword] = ACTIONS(5386),
    [sym_grid_keyword] = ACTIONS(5386),
    [sym_part_keyword] = ACTIONS(5386),
    [sym_systempart_keyword] = ACTIONS(5386),
    [sym_usercontrol_keyword] = ACTIONS(5386),
    [sym_dataset_keyword] = ACTIONS(5386),
    [sym_elements_keyword] = ACTIONS(5386),
    [sym_dataitem_keyword] = ACTIONS(5386),
    [sym_column_keyword] = ACTIONS(5386),
    [sym_filter_keyword] = ACTIONS(5386),
    [sym_labels_keyword] = ACTIONS(5386),
    [sym_rendering_keyword] = ACTIONS(5386),
    [sym_requestpage_keyword] = ACTIONS(5386),
    [sym_schema_keyword] = ACTIONS(5386),
    [sym_views_keyword] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5386),
    [sym_preproc_open] = ACTIONS(5386),
  },
  [STATE(5578)] = {
    [sym__body_element] = STATE(5566),
    [sym_empty_statement] = STATE(5566),
    [sym_property] = STATE(5566),
    [sym_permissions_property] = STATE(5566),
    [sym_table_relation_property] = STATE(5566),
    [sym_fields_section] = STATE(5566),
    [sym_keys_section] = STATE(5566),
    [sym_fieldgroups_section] = STATE(5566),
    [sym_enum_value_declaration] = STATE(5566),
    [sym_labels_section] = STATE(5566),
    [sym_layout_section] = STATE(5566),
    [sym_modify_modification] = STATE(5566),
    [sym_actions_section] = STATE(5566),
    [sym_views_section] = STATE(5566),
    [sym_dataset_section] = STATE(5566),
    [sym_requestpage_section] = STATE(5566),
    [sym_rendering_section] = STATE(5566),
    [sym_elements_section] = STATE(5566),
    [sym_schema_section] = STATE(5566),
    [sym_assembly_declaration] = STATE(5566),
    [sym_event_declaration] = STATE(5566),
    [sym_procedure] = STATE(5566),
    [sym_preproc_split_procedure] = STATE(5566),
    [sym_preproc_split_procedure_preamble] = STATE(5566),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5566),
    [sym_var_section] = STATE(5566),
    [sym_attribute_item] = STATE(5566),
    [sym_preproc_conditional] = STATE(5566),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5566),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13932),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5579)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(13934),
    [anon_sym_RBRACE] = ACTIONS(5965),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5961),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_addafter_modification_token1] = ACTIONS(5961),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5961),
    [aux_sym_movelast_modification_token1] = ACTIONS(5961),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5961),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_area_keyword] = ACTIONS(5961),
    [sym_group_keyword] = ACTIONS(5961),
    [sym_repeater_keyword] = ACTIONS(5961),
    [sym_cuegroup_keyword] = ACTIONS(5961),
    [sym_fixed_keyword] = ACTIONS(5961),
    [sym_grid_keyword] = ACTIONS(5961),
    [sym_part_keyword] = ACTIONS(5961),
    [sym_systempart_keyword] = ACTIONS(5961),
    [sym_usercontrol_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_dataitem_keyword] = ACTIONS(5961),
    [sym_column_keyword] = ACTIONS(5961),
    [sym_filter_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(5580)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(13936),
    [anon_sym_RBRACE] = ACTIONS(5965),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5961),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_addafter_modification_token1] = ACTIONS(5961),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5961),
    [aux_sym_movelast_modification_token1] = ACTIONS(5961),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5961),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_area_keyword] = ACTIONS(5961),
    [sym_group_keyword] = ACTIONS(5961),
    [sym_repeater_keyword] = ACTIONS(5961),
    [sym_cuegroup_keyword] = ACTIONS(5961),
    [sym_fixed_keyword] = ACTIONS(5961),
    [sym_grid_keyword] = ACTIONS(5961),
    [sym_part_keyword] = ACTIONS(5961),
    [sym_systempart_keyword] = ACTIONS(5961),
    [sym_usercontrol_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_dataitem_keyword] = ACTIONS(5961),
    [sym_column_keyword] = ACTIONS(5961),
    [sym_filter_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(5581)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5965),
    [anon_sym_RBRACE] = ACTIONS(5965),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5961),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token6] = ACTIONS(5961),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_addafter_modification_token1] = ACTIONS(5961),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5961),
    [aux_sym_movelast_modification_token1] = ACTIONS(5961),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5961),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_area_keyword] = ACTIONS(5961),
    [sym_group_keyword] = ACTIONS(5961),
    [sym_repeater_keyword] = ACTIONS(5961),
    [sym_cuegroup_keyword] = ACTIONS(5961),
    [sym_fixed_keyword] = ACTIONS(5961),
    [sym_grid_keyword] = ACTIONS(5961),
    [sym_part_keyword] = ACTIONS(5961),
    [sym_systempart_keyword] = ACTIONS(5961),
    [sym_usercontrol_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_dataitem_keyword] = ACTIONS(5961),
    [sym_column_keyword] = ACTIONS(5961),
    [sym_filter_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(5582)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13938),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5583)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [anon_sym_RBRACE] = ACTIONS(5937),
    [aux_sym_where_condition_token1] = ACTIONS(5935),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5935),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_basic_type_token6] = ACTIONS(5935),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token53] = ACTIONS(5935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5935),
    [aux_sym_addafter_modification_token1] = ACTIONS(5935),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5935),
    [aux_sym_modify_modification_token1] = ACTIONS(5935),
    [aux_sym_movefirst_modification_token1] = ACTIONS(5935),
    [aux_sym_movelast_modification_token1] = ACTIONS(5935),
    [aux_sym_moveafter_modification_token1] = ACTIONS(5935),
    [aux_sym_movebefore_modification_token1] = ACTIONS(5935),
    [aux_sym_separator_action_token1] = ACTIONS(5935),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5935),
    [aux_sym_type_declaration_token1] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5935),
    [sym_procedure_keyword] = ACTIONS(5935),
    [sym_trigger_keyword] = ACTIONS(5935),
    [sym_var_keyword] = ACTIONS(5935),
    [sym_local_keyword] = ACTIONS(5935),
    [sym_internal_keyword] = ACTIONS(5935),
    [sym_protected_keyword] = ACTIONS(5935),
    [sym_event_keyword] = ACTIONS(5935),
    [sym_fields_keyword] = ACTIONS(5935),
    [sym_keys_keyword] = ACTIONS(5935),
    [sym_key_keyword] = ACTIONS(5935),
    [sym_fieldgroups_keyword] = ACTIONS(5935),
    [sym_actions_keyword] = ACTIONS(5935),
    [sym_layout_keyword] = ACTIONS(5935),
    [sym_area_keyword] = ACTIONS(5935),
    [sym_group_keyword] = ACTIONS(5935),
    [sym_repeater_keyword] = ACTIONS(5935),
    [sym_cuegroup_keyword] = ACTIONS(5935),
    [sym_fixed_keyword] = ACTIONS(5935),
    [sym_grid_keyword] = ACTIONS(5935),
    [sym_part_keyword] = ACTIONS(5935),
    [sym_systempart_keyword] = ACTIONS(5935),
    [sym_usercontrol_keyword] = ACTIONS(5935),
    [sym_dataset_keyword] = ACTIONS(5935),
    [sym_elements_keyword] = ACTIONS(5935),
    [sym_dataitem_keyword] = ACTIONS(5935),
    [sym_column_keyword] = ACTIONS(5935),
    [sym_filter_keyword] = ACTIONS(5935),
    [sym_labels_keyword] = ACTIONS(5935),
    [sym_rendering_keyword] = ACTIONS(5935),
    [sym_requestpage_keyword] = ACTIONS(5935),
    [sym_schema_keyword] = ACTIONS(5935),
    [sym_views_keyword] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_var_attribute_open] = ACTIONS(5937),
  },
  [STATE(5584)] = {
    [sym_identifier] = ACTIONS(8998),
    [anon_sym_SEMI] = ACTIONS(9000),
    [anon_sym_RBRACE] = ACTIONS(9000),
    [aux_sym_where_condition_token1] = ACTIONS(8998),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8998),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8998),
    [anon_sym_LBRACK] = ACTIONS(9000),
    [aux_sym_basic_type_token6] = ACTIONS(8998),
    [aux_sym_basic_type_token22] = ACTIONS(8998),
    [aux_sym_basic_type_token53] = ACTIONS(8998),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8998),
    [aux_sym_addafter_modification_token1] = ACTIONS(8998),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8998),
    [aux_sym_modify_modification_token1] = ACTIONS(8998),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8998),
    [aux_sym_movelast_modification_token1] = ACTIONS(8998),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8998),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8998),
    [aux_sym_separator_action_token1] = ACTIONS(8998),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8998),
    [aux_sym_type_declaration_token1] = ACTIONS(8998),
    [anon_sym_POUNDif] = ACTIONS(9000),
    [anon_sym_POUNDIF] = ACTIONS(9000),
    [anon_sym_POUNDIf] = ACTIONS(9000),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8998),
    [sym_procedure_keyword] = ACTIONS(8998),
    [sym_trigger_keyword] = ACTIONS(8998),
    [sym_var_keyword] = ACTIONS(8998),
    [sym_local_keyword] = ACTIONS(8998),
    [sym_internal_keyword] = ACTIONS(8998),
    [sym_protected_keyword] = ACTIONS(8998),
    [sym_event_keyword] = ACTIONS(8998),
    [sym_fields_keyword] = ACTIONS(8998),
    [sym_keys_keyword] = ACTIONS(8998),
    [sym_key_keyword] = ACTIONS(8998),
    [sym_fieldgroups_keyword] = ACTIONS(8998),
    [sym_actions_keyword] = ACTIONS(8998),
    [sym_layout_keyword] = ACTIONS(8998),
    [sym_area_keyword] = ACTIONS(8998),
    [sym_group_keyword] = ACTIONS(8998),
    [sym_repeater_keyword] = ACTIONS(8998),
    [sym_cuegroup_keyword] = ACTIONS(8998),
    [sym_fixed_keyword] = ACTIONS(8998),
    [sym_grid_keyword] = ACTIONS(8998),
    [sym_part_keyword] = ACTIONS(8998),
    [sym_systempart_keyword] = ACTIONS(8998),
    [sym_usercontrol_keyword] = ACTIONS(8998),
    [sym_dataset_keyword] = ACTIONS(8998),
    [sym_elements_keyword] = ACTIONS(8998),
    [sym_dataitem_keyword] = ACTIONS(8998),
    [sym_column_keyword] = ACTIONS(8998),
    [sym_filter_keyword] = ACTIONS(8998),
    [sym_labels_keyword] = ACTIONS(8998),
    [sym_rendering_keyword] = ACTIONS(8998),
    [sym_requestpage_keyword] = ACTIONS(8998),
    [sym_schema_keyword] = ACTIONS(8998),
    [sym_views_keyword] = ACTIONS(8998),
    [sym_quoted_identifier] = ACTIONS(9000),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9000),
    [sym_preproc_open] = ACTIONS(9000),
    [sym_var_attribute_open] = ACTIONS(9000),
  },
  [STATE(5585)] = {
    [sym_identifier] = ACTIONS(9002),
    [anon_sym_SEMI] = ACTIONS(9004),
    [anon_sym_RBRACE] = ACTIONS(9004),
    [aux_sym_where_condition_token1] = ACTIONS(9002),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9002),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9002),
    [anon_sym_LBRACK] = ACTIONS(9004),
    [aux_sym_basic_type_token6] = ACTIONS(9002),
    [aux_sym_basic_type_token22] = ACTIONS(9002),
    [aux_sym_basic_type_token53] = ACTIONS(9002),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9002),
    [aux_sym_addafter_modification_token1] = ACTIONS(9002),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9002),
    [aux_sym_modify_modification_token1] = ACTIONS(9002),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9002),
    [aux_sym_movelast_modification_token1] = ACTIONS(9002),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9002),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9002),
    [aux_sym_separator_action_token1] = ACTIONS(9002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9002),
    [aux_sym_type_declaration_token1] = ACTIONS(9002),
    [anon_sym_POUNDif] = ACTIONS(9004),
    [anon_sym_POUNDIF] = ACTIONS(9004),
    [anon_sym_POUNDIf] = ACTIONS(9004),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9002),
    [sym_procedure_keyword] = ACTIONS(9002),
    [sym_trigger_keyword] = ACTIONS(9002),
    [sym_var_keyword] = ACTIONS(9002),
    [sym_local_keyword] = ACTIONS(9002),
    [sym_internal_keyword] = ACTIONS(9002),
    [sym_protected_keyword] = ACTIONS(9002),
    [sym_event_keyword] = ACTIONS(9002),
    [sym_fields_keyword] = ACTIONS(9002),
    [sym_keys_keyword] = ACTIONS(9002),
    [sym_key_keyword] = ACTIONS(9002),
    [sym_fieldgroups_keyword] = ACTIONS(9002),
    [sym_actions_keyword] = ACTIONS(9002),
    [sym_layout_keyword] = ACTIONS(9002),
    [sym_area_keyword] = ACTIONS(9002),
    [sym_group_keyword] = ACTIONS(9002),
    [sym_repeater_keyword] = ACTIONS(9002),
    [sym_cuegroup_keyword] = ACTIONS(9002),
    [sym_fixed_keyword] = ACTIONS(9002),
    [sym_grid_keyword] = ACTIONS(9002),
    [sym_part_keyword] = ACTIONS(9002),
    [sym_systempart_keyword] = ACTIONS(9002),
    [sym_usercontrol_keyword] = ACTIONS(9002),
    [sym_dataset_keyword] = ACTIONS(9002),
    [sym_elements_keyword] = ACTIONS(9002),
    [sym_dataitem_keyword] = ACTIONS(9002),
    [sym_column_keyword] = ACTIONS(9002),
    [sym_filter_keyword] = ACTIONS(9002),
    [sym_labels_keyword] = ACTIONS(9002),
    [sym_rendering_keyword] = ACTIONS(9002),
    [sym_requestpage_keyword] = ACTIONS(9002),
    [sym_schema_keyword] = ACTIONS(9002),
    [sym_views_keyword] = ACTIONS(9002),
    [sym_quoted_identifier] = ACTIONS(9004),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9004),
    [sym_preproc_open] = ACTIONS(9004),
    [sym_var_attribute_open] = ACTIONS(9004),
  },
  [STATE(5586)] = {
    [sym_identifier] = ACTIONS(9002),
    [anon_sym_SEMI] = ACTIONS(9004),
    [anon_sym_RBRACE] = ACTIONS(9004),
    [aux_sym_where_condition_token1] = ACTIONS(9002),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9002),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9002),
    [anon_sym_LBRACK] = ACTIONS(9004),
    [aux_sym_basic_type_token6] = ACTIONS(9002),
    [aux_sym_basic_type_token22] = ACTIONS(9002),
    [aux_sym_basic_type_token53] = ACTIONS(9002),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9002),
    [aux_sym_addafter_modification_token1] = ACTIONS(9002),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9002),
    [aux_sym_modify_modification_token1] = ACTIONS(9002),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9002),
    [aux_sym_movelast_modification_token1] = ACTIONS(9002),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9002),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9002),
    [aux_sym_separator_action_token1] = ACTIONS(9002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9002),
    [aux_sym_type_declaration_token1] = ACTIONS(9002),
    [anon_sym_POUNDif] = ACTIONS(9004),
    [anon_sym_POUNDIF] = ACTIONS(9004),
    [anon_sym_POUNDIf] = ACTIONS(9004),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9002),
    [sym_procedure_keyword] = ACTIONS(9002),
    [sym_trigger_keyword] = ACTIONS(9002),
    [sym_var_keyword] = ACTIONS(9002),
    [sym_local_keyword] = ACTIONS(9002),
    [sym_internal_keyword] = ACTIONS(9002),
    [sym_protected_keyword] = ACTIONS(9002),
    [sym_event_keyword] = ACTIONS(9002),
    [sym_fields_keyword] = ACTIONS(9002),
    [sym_keys_keyword] = ACTIONS(9002),
    [sym_key_keyword] = ACTIONS(9002),
    [sym_fieldgroups_keyword] = ACTIONS(9002),
    [sym_actions_keyword] = ACTIONS(9002),
    [sym_layout_keyword] = ACTIONS(9002),
    [sym_area_keyword] = ACTIONS(9002),
    [sym_group_keyword] = ACTIONS(9002),
    [sym_repeater_keyword] = ACTIONS(9002),
    [sym_cuegroup_keyword] = ACTIONS(9002),
    [sym_fixed_keyword] = ACTIONS(9002),
    [sym_grid_keyword] = ACTIONS(9002),
    [sym_part_keyword] = ACTIONS(9002),
    [sym_systempart_keyword] = ACTIONS(9002),
    [sym_usercontrol_keyword] = ACTIONS(9002),
    [sym_dataset_keyword] = ACTIONS(9002),
    [sym_elements_keyword] = ACTIONS(9002),
    [sym_dataitem_keyword] = ACTIONS(9002),
    [sym_column_keyword] = ACTIONS(9002),
    [sym_filter_keyword] = ACTIONS(9002),
    [sym_labels_keyword] = ACTIONS(9002),
    [sym_rendering_keyword] = ACTIONS(9002),
    [sym_requestpage_keyword] = ACTIONS(9002),
    [sym_schema_keyword] = ACTIONS(9002),
    [sym_views_keyword] = ACTIONS(9002),
    [sym_quoted_identifier] = ACTIONS(9004),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9004),
    [sym_preproc_open] = ACTIONS(9004),
    [sym_var_attribute_open] = ACTIONS(9004),
  },
  [STATE(5587)] = {
    [sym__body_element] = STATE(5690),
    [sym_empty_statement] = STATE(5690),
    [sym_property] = STATE(5690),
    [sym_permissions_property] = STATE(5690),
    [sym_table_relation_property] = STATE(5690),
    [sym_fields_section] = STATE(5690),
    [sym_keys_section] = STATE(5690),
    [sym_fieldgroups_section] = STATE(5690),
    [sym_enum_value_declaration] = STATE(5690),
    [sym_labels_section] = STATE(5690),
    [sym_layout_section] = STATE(5690),
    [sym_modify_modification] = STATE(5690),
    [sym_actions_section] = STATE(5690),
    [sym_views_section] = STATE(5690),
    [sym_dataset_section] = STATE(5690),
    [sym_requestpage_section] = STATE(5690),
    [sym_rendering_section] = STATE(5690),
    [sym_elements_section] = STATE(5690),
    [sym_schema_section] = STATE(5690),
    [sym_assembly_declaration] = STATE(5690),
    [sym_event_declaration] = STATE(5690),
    [sym_procedure] = STATE(5690),
    [sym_preproc_split_procedure] = STATE(5690),
    [sym_preproc_split_procedure_preamble] = STATE(5690),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5690),
    [sym_var_section] = STATE(5690),
    [sym_attribute_item] = STATE(5690),
    [sym_preproc_conditional] = STATE(5690),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5690),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13940),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5588)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [anon_sym_RBRACE] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9006),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_addafter_modification_token1] = ACTIONS(9006),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9006),
    [aux_sym_movelast_modification_token1] = ACTIONS(9006),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9006),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_area_keyword] = ACTIONS(9006),
    [sym_group_keyword] = ACTIONS(9006),
    [sym_repeater_keyword] = ACTIONS(9006),
    [sym_cuegroup_keyword] = ACTIONS(9006),
    [sym_fixed_keyword] = ACTIONS(9006),
    [sym_grid_keyword] = ACTIONS(9006),
    [sym_part_keyword] = ACTIONS(9006),
    [sym_systempart_keyword] = ACTIONS(9006),
    [sym_usercontrol_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_dataitem_keyword] = ACTIONS(9006),
    [sym_column_keyword] = ACTIONS(9006),
    [sym_filter_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(5589)] = {
    [sym__body_element] = STATE(5595),
    [sym_empty_statement] = STATE(5595),
    [sym_property] = STATE(5595),
    [sym_permissions_property] = STATE(5595),
    [sym_table_relation_property] = STATE(5595),
    [sym_fields_section] = STATE(5595),
    [sym_keys_section] = STATE(5595),
    [sym_fieldgroups_section] = STATE(5595),
    [sym_enum_value_declaration] = STATE(5595),
    [sym_labels_section] = STATE(5595),
    [sym_layout_section] = STATE(5595),
    [sym_modify_modification] = STATE(5595),
    [sym_actions_section] = STATE(5595),
    [sym_views_section] = STATE(5595),
    [sym_dataset_section] = STATE(5595),
    [sym_requestpage_section] = STATE(5595),
    [sym_rendering_section] = STATE(5595),
    [sym_elements_section] = STATE(5595),
    [sym_schema_section] = STATE(5595),
    [sym_assembly_declaration] = STATE(5595),
    [sym_event_declaration] = STATE(5595),
    [sym_procedure] = STATE(5595),
    [sym_preproc_split_procedure] = STATE(5595),
    [sym_preproc_split_procedure_preamble] = STATE(5595),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5595),
    [sym_var_section] = STATE(5595),
    [sym_attribute_item] = STATE(5595),
    [sym_preproc_conditional] = STATE(5595),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5595),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13942),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5590)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [anon_sym_RBRACE] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9006),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_addafter_modification_token1] = ACTIONS(9006),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9006),
    [aux_sym_movelast_modification_token1] = ACTIONS(9006),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9006),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_area_keyword] = ACTIONS(9006),
    [sym_group_keyword] = ACTIONS(9006),
    [sym_repeater_keyword] = ACTIONS(9006),
    [sym_cuegroup_keyword] = ACTIONS(9006),
    [sym_fixed_keyword] = ACTIONS(9006),
    [sym_grid_keyword] = ACTIONS(9006),
    [sym_part_keyword] = ACTIONS(9006),
    [sym_systempart_keyword] = ACTIONS(9006),
    [sym_usercontrol_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_dataitem_keyword] = ACTIONS(9006),
    [sym_column_keyword] = ACTIONS(9006),
    [sym_filter_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(5591)] = {
    [sym__body_element] = STATE(5516),
    [sym_empty_statement] = STATE(5516),
    [sym_property] = STATE(5516),
    [sym_permissions_property] = STATE(5516),
    [sym_table_relation_property] = STATE(5516),
    [sym_fields_section] = STATE(5516),
    [sym_keys_section] = STATE(5516),
    [sym_fieldgroups_section] = STATE(5516),
    [sym_enum_value_declaration] = STATE(5516),
    [sym_labels_section] = STATE(5516),
    [sym_layout_section] = STATE(5516),
    [sym_modify_modification] = STATE(5516),
    [sym_actions_section] = STATE(5516),
    [sym_views_section] = STATE(5516),
    [sym_dataset_section] = STATE(5516),
    [sym_requestpage_section] = STATE(5516),
    [sym_rendering_section] = STATE(5516),
    [sym_elements_section] = STATE(5516),
    [sym_schema_section] = STATE(5516),
    [sym_assembly_declaration] = STATE(5516),
    [sym_event_declaration] = STATE(5516),
    [sym_procedure] = STATE(5516),
    [sym_preproc_split_procedure] = STATE(5516),
    [sym_preproc_split_procedure_preamble] = STATE(5516),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5516),
    [sym_var_section] = STATE(5516),
    [sym_attribute_item] = STATE(5516),
    [sym_preproc_conditional] = STATE(5516),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5516),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13944),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5592)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [anon_sym_RBRACE] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9006),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token6] = ACTIONS(9006),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_addafter_modification_token1] = ACTIONS(9006),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9006),
    [aux_sym_movelast_modification_token1] = ACTIONS(9006),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9006),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_area_keyword] = ACTIONS(9006),
    [sym_group_keyword] = ACTIONS(9006),
    [sym_repeater_keyword] = ACTIONS(9006),
    [sym_cuegroup_keyword] = ACTIONS(9006),
    [sym_fixed_keyword] = ACTIONS(9006),
    [sym_grid_keyword] = ACTIONS(9006),
    [sym_part_keyword] = ACTIONS(9006),
    [sym_systempart_keyword] = ACTIONS(9006),
    [sym_usercontrol_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_dataitem_keyword] = ACTIONS(9006),
    [sym_column_keyword] = ACTIONS(9006),
    [sym_filter_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(5593)] = {
    [sym__body_element] = STATE(5616),
    [sym_empty_statement] = STATE(5616),
    [sym_property] = STATE(5616),
    [sym_permissions_property] = STATE(5616),
    [sym_table_relation_property] = STATE(5616),
    [sym_fields_section] = STATE(5616),
    [sym_keys_section] = STATE(5616),
    [sym_fieldgroups_section] = STATE(5616),
    [sym_enum_value_declaration] = STATE(5616),
    [sym_labels_section] = STATE(5616),
    [sym_layout_section] = STATE(5616),
    [sym_modify_modification] = STATE(5616),
    [sym_actions_section] = STATE(5616),
    [sym_views_section] = STATE(5616),
    [sym_dataset_section] = STATE(5616),
    [sym_requestpage_section] = STATE(5616),
    [sym_rendering_section] = STATE(5616),
    [sym_elements_section] = STATE(5616),
    [sym_schema_section] = STATE(5616),
    [sym_assembly_declaration] = STATE(5616),
    [sym_event_declaration] = STATE(5616),
    [sym_procedure] = STATE(5616),
    [sym_preproc_split_procedure] = STATE(5616),
    [sym_preproc_split_procedure_preamble] = STATE(5616),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5616),
    [sym_var_section] = STATE(5616),
    [sym_attribute_item] = STATE(5616),
    [sym_preproc_conditional] = STATE(5616),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5616),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13946),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5594)] = {
    [sym__body_element] = STATE(5455),
    [sym_empty_statement] = STATE(5455),
    [sym_property] = STATE(5455),
    [sym_permissions_property] = STATE(5455),
    [sym_table_relation_property] = STATE(5455),
    [sym_fields_section] = STATE(5455),
    [sym_keys_section] = STATE(5455),
    [sym_fieldgroups_section] = STATE(5455),
    [sym_enum_value_declaration] = STATE(5455),
    [sym_labels_section] = STATE(5455),
    [sym_layout_section] = STATE(5455),
    [sym_modify_modification] = STATE(5455),
    [sym_actions_section] = STATE(5455),
    [sym_views_section] = STATE(5455),
    [sym_dataset_section] = STATE(5455),
    [sym_requestpage_section] = STATE(5455),
    [sym_rendering_section] = STATE(5455),
    [sym_elements_section] = STATE(5455),
    [sym_schema_section] = STATE(5455),
    [sym_assembly_declaration] = STATE(5455),
    [sym_event_declaration] = STATE(5455),
    [sym_procedure] = STATE(5455),
    [sym_preproc_split_procedure] = STATE(5455),
    [sym_preproc_split_procedure_preamble] = STATE(5455),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5455),
    [sym_var_section] = STATE(5455),
    [sym_attribute_item] = STATE(5455),
    [sym_preproc_conditional] = STATE(5455),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5455),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13948),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5595)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13950),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5596)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13952),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5597)] = {
    [sym__body_element] = STATE(5656),
    [sym_empty_statement] = STATE(5656),
    [sym_property] = STATE(5656),
    [sym_permissions_property] = STATE(5656),
    [sym_table_relation_property] = STATE(5656),
    [sym_fields_section] = STATE(5656),
    [sym_keys_section] = STATE(5656),
    [sym_fieldgroups_section] = STATE(5656),
    [sym_enum_value_declaration] = STATE(5656),
    [sym_labels_section] = STATE(5656),
    [sym_layout_section] = STATE(5656),
    [sym_modify_modification] = STATE(5656),
    [sym_actions_section] = STATE(5656),
    [sym_views_section] = STATE(5656),
    [sym_dataset_section] = STATE(5656),
    [sym_requestpage_section] = STATE(5656),
    [sym_rendering_section] = STATE(5656),
    [sym_elements_section] = STATE(5656),
    [sym_schema_section] = STATE(5656),
    [sym_assembly_declaration] = STATE(5656),
    [sym_event_declaration] = STATE(5656),
    [sym_procedure] = STATE(5656),
    [sym_preproc_split_procedure] = STATE(5656),
    [sym_preproc_split_procedure_preamble] = STATE(5656),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5656),
    [sym_var_section] = STATE(5656),
    [sym_attribute_item] = STATE(5656),
    [sym_preproc_conditional] = STATE(5656),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5656),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13952),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5598)] = {
    [sym__body_element] = STATE(5756),
    [sym_empty_statement] = STATE(5756),
    [sym_property] = STATE(5756),
    [sym_permissions_property] = STATE(5756),
    [sym_table_relation_property] = STATE(5756),
    [sym_fields_section] = STATE(5756),
    [sym_keys_section] = STATE(5756),
    [sym_fieldgroups_section] = STATE(5756),
    [sym_enum_value_declaration] = STATE(5756),
    [sym_labels_section] = STATE(5756),
    [sym_layout_section] = STATE(5756),
    [sym_modify_modification] = STATE(5756),
    [sym_actions_section] = STATE(5756),
    [sym_views_section] = STATE(5756),
    [sym_dataset_section] = STATE(5756),
    [sym_requestpage_section] = STATE(5756),
    [sym_rendering_section] = STATE(5756),
    [sym_elements_section] = STATE(5756),
    [sym_schema_section] = STATE(5756),
    [sym_assembly_declaration] = STATE(5756),
    [sym_event_declaration] = STATE(5756),
    [sym_procedure] = STATE(5756),
    [sym_preproc_split_procedure] = STATE(5756),
    [sym_preproc_split_procedure_preamble] = STATE(5756),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5756),
    [sym_var_section] = STATE(5756),
    [sym_attribute_item] = STATE(5756),
    [sym_preproc_conditional] = STATE(5756),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5756),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13954),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5599)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [anon_sym_RBRACE] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9044),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_addafter_modification_token1] = ACTIONS(9044),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9044),
    [aux_sym_movelast_modification_token1] = ACTIONS(9044),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9044),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_area_keyword] = ACTIONS(9044),
    [sym_group_keyword] = ACTIONS(9044),
    [sym_repeater_keyword] = ACTIONS(9044),
    [sym_cuegroup_keyword] = ACTIONS(9044),
    [sym_fixed_keyword] = ACTIONS(9044),
    [sym_grid_keyword] = ACTIONS(9044),
    [sym_part_keyword] = ACTIONS(9044),
    [sym_systempart_keyword] = ACTIONS(9044),
    [sym_usercontrol_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_dataitem_keyword] = ACTIONS(9044),
    [sym_column_keyword] = ACTIONS(9044),
    [sym_filter_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(5600)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13956),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5601)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13958),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5602)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13960),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5603)] = {
    [sym__body_element] = STATE(5691),
    [sym_empty_statement] = STATE(5691),
    [sym_property] = STATE(5691),
    [sym_permissions_property] = STATE(5691),
    [sym_table_relation_property] = STATE(5691),
    [sym_fields_section] = STATE(5691),
    [sym_keys_section] = STATE(5691),
    [sym_fieldgroups_section] = STATE(5691),
    [sym_enum_value_declaration] = STATE(5691),
    [sym_labels_section] = STATE(5691),
    [sym_layout_section] = STATE(5691),
    [sym_modify_modification] = STATE(5691),
    [sym_actions_section] = STATE(5691),
    [sym_views_section] = STATE(5691),
    [sym_dataset_section] = STATE(5691),
    [sym_requestpage_section] = STATE(5691),
    [sym_rendering_section] = STATE(5691),
    [sym_elements_section] = STATE(5691),
    [sym_schema_section] = STATE(5691),
    [sym_assembly_declaration] = STATE(5691),
    [sym_event_declaration] = STATE(5691),
    [sym_procedure] = STATE(5691),
    [sym_preproc_split_procedure] = STATE(5691),
    [sym_preproc_split_procedure_preamble] = STATE(5691),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5691),
    [sym_var_section] = STATE(5691),
    [sym_attribute_item] = STATE(5691),
    [sym_preproc_conditional] = STATE(5691),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5691),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13962),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5604)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13964),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5605)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13966),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5606)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13968),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5607)] = {
    [sym__body_element] = STATE(5720),
    [sym_empty_statement] = STATE(5720),
    [sym_property] = STATE(5720),
    [sym_permissions_property] = STATE(5720),
    [sym_table_relation_property] = STATE(5720),
    [sym_fields_section] = STATE(5720),
    [sym_keys_section] = STATE(5720),
    [sym_fieldgroups_section] = STATE(5720),
    [sym_enum_value_declaration] = STATE(5720),
    [sym_labels_section] = STATE(5720),
    [sym_layout_section] = STATE(5720),
    [sym_modify_modification] = STATE(5720),
    [sym_actions_section] = STATE(5720),
    [sym_views_section] = STATE(5720),
    [sym_dataset_section] = STATE(5720),
    [sym_requestpage_section] = STATE(5720),
    [sym_rendering_section] = STATE(5720),
    [sym_elements_section] = STATE(5720),
    [sym_schema_section] = STATE(5720),
    [sym_assembly_declaration] = STATE(5720),
    [sym_event_declaration] = STATE(5720),
    [sym_procedure] = STATE(5720),
    [sym_preproc_split_procedure] = STATE(5720),
    [sym_preproc_split_procedure_preamble] = STATE(5720),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5720),
    [sym_var_section] = STATE(5720),
    [sym_attribute_item] = STATE(5720),
    [sym_preproc_conditional] = STATE(5720),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5720),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13970),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5608)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13972),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5609)] = {
    [sym__body_element] = STATE(5819),
    [sym_empty_statement] = STATE(5819),
    [sym_property] = STATE(5819),
    [sym_permissions_property] = STATE(5819),
    [sym_table_relation_property] = STATE(5819),
    [sym_fields_section] = STATE(5819),
    [sym_keys_section] = STATE(5819),
    [sym_fieldgroups_section] = STATE(5819),
    [sym_enum_value_declaration] = STATE(5819),
    [sym_labels_section] = STATE(5819),
    [sym_layout_section] = STATE(5819),
    [sym_modify_modification] = STATE(5819),
    [sym_actions_section] = STATE(5819),
    [sym_views_section] = STATE(5819),
    [sym_dataset_section] = STATE(5819),
    [sym_requestpage_section] = STATE(5819),
    [sym_rendering_section] = STATE(5819),
    [sym_elements_section] = STATE(5819),
    [sym_schema_section] = STATE(5819),
    [sym_assembly_declaration] = STATE(5819),
    [sym_event_declaration] = STATE(5819),
    [sym_procedure] = STATE(5819),
    [sym_preproc_split_procedure] = STATE(5819),
    [sym_preproc_split_procedure_preamble] = STATE(5819),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5819),
    [sym_var_section] = STATE(5819),
    [sym_attribute_item] = STATE(5819),
    [sym_preproc_conditional] = STATE(5819),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5819),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13974),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5610)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [anon_sym_RBRACE] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9044),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_addafter_modification_token1] = ACTIONS(9044),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9044),
    [aux_sym_movelast_modification_token1] = ACTIONS(9044),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9044),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_area_keyword] = ACTIONS(9044),
    [sym_group_keyword] = ACTIONS(9044),
    [sym_repeater_keyword] = ACTIONS(9044),
    [sym_cuegroup_keyword] = ACTIONS(9044),
    [sym_fixed_keyword] = ACTIONS(9044),
    [sym_grid_keyword] = ACTIONS(9044),
    [sym_part_keyword] = ACTIONS(9044),
    [sym_systempart_keyword] = ACTIONS(9044),
    [sym_usercontrol_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_dataitem_keyword] = ACTIONS(9044),
    [sym_column_keyword] = ACTIONS(9044),
    [sym_filter_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(5611)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13976),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5612)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [anon_sym_RBRACE] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9044),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token6] = ACTIONS(9044),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_addafter_modification_token1] = ACTIONS(9044),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9044),
    [aux_sym_movelast_modification_token1] = ACTIONS(9044),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9044),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_area_keyword] = ACTIONS(9044),
    [sym_group_keyword] = ACTIONS(9044),
    [sym_repeater_keyword] = ACTIONS(9044),
    [sym_cuegroup_keyword] = ACTIONS(9044),
    [sym_fixed_keyword] = ACTIONS(9044),
    [sym_grid_keyword] = ACTIONS(9044),
    [sym_part_keyword] = ACTIONS(9044),
    [sym_systempart_keyword] = ACTIONS(9044),
    [sym_usercontrol_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_dataitem_keyword] = ACTIONS(9044),
    [sym_column_keyword] = ACTIONS(9044),
    [sym_filter_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(5613)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [anon_sym_RBRACE] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token1] = ACTIONS(5279),
    [aux_sym_tabledata_permission_token2] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_xmlport_element_token1] = ACTIONS(5279),
    [aux_sym_xmlport_element_token2] = ACTIONS(5279),
    [aux_sym_xmlport_element_token3] = ACTIONS(5279),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5279),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_page_keyword] = ACTIONS(5279),
    [anon_sym_codeunit] = ACTIONS(5279),
    [anon_sym_CODEUNIT] = ACTIONS(5279),
    [anon_sym_Codeunit] = ACTIONS(5279),
    [anon_sym_CodeUnit] = ACTIONS(5279),
    [anon_sym_COdeunit] = ACTIONS(5279),
    [anon_sym_codeUnit] = ACTIONS(5279),
    [sym_report_keyword] = ACTIONS(5279),
    [sym_query_keyword] = ACTIONS(5279),
    [anon_sym_xmlport] = ACTIONS(5279),
    [anon_sym_XMLPORT] = ACTIONS(5279),
    [anon_sym_Xmlport] = ACTIONS(5279),
    [anon_sym_XMLport] = ACTIONS(5279),
    [anon_sym_XMLPort] = ACTIONS(5279),
    [anon_sym_XmlPort] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
  },
  [STATE(5614)] = {
    [sym__body_element] = STATE(5749),
    [sym_empty_statement] = STATE(5749),
    [sym_property] = STATE(5749),
    [sym_permissions_property] = STATE(5749),
    [sym_table_relation_property] = STATE(5749),
    [sym_fields_section] = STATE(5749),
    [sym_keys_section] = STATE(5749),
    [sym_fieldgroups_section] = STATE(5749),
    [sym_enum_value_declaration] = STATE(5749),
    [sym_labels_section] = STATE(5749),
    [sym_layout_section] = STATE(5749),
    [sym_modify_modification] = STATE(5749),
    [sym_actions_section] = STATE(5749),
    [sym_views_section] = STATE(5749),
    [sym_dataset_section] = STATE(5749),
    [sym_requestpage_section] = STATE(5749),
    [sym_rendering_section] = STATE(5749),
    [sym_elements_section] = STATE(5749),
    [sym_schema_section] = STATE(5749),
    [sym_assembly_declaration] = STATE(5749),
    [sym_event_declaration] = STATE(5749),
    [sym_procedure] = STATE(5749),
    [sym_preproc_split_procedure] = STATE(5749),
    [sym_preproc_split_procedure_preamble] = STATE(5749),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5749),
    [sym_var_section] = STATE(5749),
    [sym_attribute_item] = STATE(5749),
    [sym_preproc_conditional] = STATE(5749),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5749),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13978),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5615)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13980),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5616)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13982),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5617)] = {
    [sym_identifier] = ACTIONS(6140),
    [anon_sym_SEMI] = ACTIONS(6142),
    [anon_sym_RBRACE] = ACTIONS(6142),
    [aux_sym_where_condition_token1] = ACTIONS(6140),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6140),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6140),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [aux_sym_basic_type_token6] = ACTIONS(6140),
    [aux_sym_basic_type_token22] = ACTIONS(6140),
    [aux_sym_basic_type_token53] = ACTIONS(6140),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6140),
    [aux_sym_addafter_modification_token1] = ACTIONS(6140),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6140),
    [aux_sym_modify_modification_token1] = ACTIONS(6140),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6140),
    [aux_sym_movelast_modification_token1] = ACTIONS(6140),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6140),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6140),
    [aux_sym_separator_action_token1] = ACTIONS(6140),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6140),
    [aux_sym_type_declaration_token1] = ACTIONS(6140),
    [anon_sym_POUNDif] = ACTIONS(6142),
    [anon_sym_POUNDIF] = ACTIONS(6142),
    [anon_sym_POUNDIf] = ACTIONS(6142),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6140),
    [sym_procedure_keyword] = ACTIONS(6140),
    [sym_trigger_keyword] = ACTIONS(6140),
    [sym_var_keyword] = ACTIONS(6140),
    [sym_local_keyword] = ACTIONS(6140),
    [sym_internal_keyword] = ACTIONS(6140),
    [sym_protected_keyword] = ACTIONS(6140),
    [sym_event_keyword] = ACTIONS(6140),
    [sym_fields_keyword] = ACTIONS(6140),
    [sym_keys_keyword] = ACTIONS(6140),
    [sym_key_keyword] = ACTIONS(6140),
    [sym_fieldgroups_keyword] = ACTIONS(6140),
    [sym_actions_keyword] = ACTIONS(6140),
    [sym_layout_keyword] = ACTIONS(6140),
    [sym_area_keyword] = ACTIONS(6140),
    [sym_group_keyword] = ACTIONS(6140),
    [sym_repeater_keyword] = ACTIONS(6140),
    [sym_cuegroup_keyword] = ACTIONS(6140),
    [sym_fixed_keyword] = ACTIONS(6140),
    [sym_grid_keyword] = ACTIONS(6140),
    [sym_part_keyword] = ACTIONS(6140),
    [sym_systempart_keyword] = ACTIONS(6140),
    [sym_usercontrol_keyword] = ACTIONS(6140),
    [sym_dataset_keyword] = ACTIONS(6140),
    [sym_elements_keyword] = ACTIONS(6140),
    [sym_dataitem_keyword] = ACTIONS(6140),
    [sym_column_keyword] = ACTIONS(6140),
    [sym_filter_keyword] = ACTIONS(6140),
    [sym_labels_keyword] = ACTIONS(6140),
    [sym_rendering_keyword] = ACTIONS(6140),
    [sym_requestpage_keyword] = ACTIONS(6140),
    [sym_schema_keyword] = ACTIONS(6140),
    [sym_views_keyword] = ACTIONS(6140),
    [sym_quoted_identifier] = ACTIONS(6142),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6142),
    [sym_preproc_open] = ACTIONS(6142),
    [sym_var_attribute_open] = ACTIONS(6142),
  },
  [STATE(5618)] = {
    [sym_identifier] = ACTIONS(6144),
    [anon_sym_SEMI] = ACTIONS(6146),
    [anon_sym_RBRACE] = ACTIONS(6146),
    [aux_sym_where_condition_token1] = ACTIONS(6144),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6144),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6144),
    [anon_sym_LBRACK] = ACTIONS(6146),
    [aux_sym_basic_type_token6] = ACTIONS(6144),
    [aux_sym_basic_type_token22] = ACTIONS(6144),
    [aux_sym_basic_type_token53] = ACTIONS(6144),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6144),
    [aux_sym_addafter_modification_token1] = ACTIONS(6144),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6144),
    [aux_sym_modify_modification_token1] = ACTIONS(6144),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6144),
    [aux_sym_movelast_modification_token1] = ACTIONS(6144),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6144),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6144),
    [aux_sym_separator_action_token1] = ACTIONS(6144),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6144),
    [aux_sym_type_declaration_token1] = ACTIONS(6144),
    [anon_sym_POUNDif] = ACTIONS(6146),
    [anon_sym_POUNDIF] = ACTIONS(6146),
    [anon_sym_POUNDIf] = ACTIONS(6146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6144),
    [sym_procedure_keyword] = ACTIONS(6144),
    [sym_trigger_keyword] = ACTIONS(6144),
    [sym_var_keyword] = ACTIONS(6144),
    [sym_local_keyword] = ACTIONS(6144),
    [sym_internal_keyword] = ACTIONS(6144),
    [sym_protected_keyword] = ACTIONS(6144),
    [sym_event_keyword] = ACTIONS(6144),
    [sym_fields_keyword] = ACTIONS(6144),
    [sym_keys_keyword] = ACTIONS(6144),
    [sym_key_keyword] = ACTIONS(6144),
    [sym_fieldgroups_keyword] = ACTIONS(6144),
    [sym_actions_keyword] = ACTIONS(6144),
    [sym_layout_keyword] = ACTIONS(6144),
    [sym_area_keyword] = ACTIONS(6144),
    [sym_group_keyword] = ACTIONS(6144),
    [sym_repeater_keyword] = ACTIONS(6144),
    [sym_cuegroup_keyword] = ACTIONS(6144),
    [sym_fixed_keyword] = ACTIONS(6144),
    [sym_grid_keyword] = ACTIONS(6144),
    [sym_part_keyword] = ACTIONS(6144),
    [sym_systempart_keyword] = ACTIONS(6144),
    [sym_usercontrol_keyword] = ACTIONS(6144),
    [sym_dataset_keyword] = ACTIONS(6144),
    [sym_elements_keyword] = ACTIONS(6144),
    [sym_dataitem_keyword] = ACTIONS(6144),
    [sym_column_keyword] = ACTIONS(6144),
    [sym_filter_keyword] = ACTIONS(6144),
    [sym_labels_keyword] = ACTIONS(6144),
    [sym_rendering_keyword] = ACTIONS(6144),
    [sym_requestpage_keyword] = ACTIONS(6144),
    [sym_schema_keyword] = ACTIONS(6144),
    [sym_views_keyword] = ACTIONS(6144),
    [sym_quoted_identifier] = ACTIONS(6146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6146),
    [sym_preproc_open] = ACTIONS(6146),
    [sym_var_attribute_open] = ACTIONS(6146),
  },
  [STATE(5619)] = {
    [sym__body_element] = STATE(5733),
    [sym_empty_statement] = STATE(5733),
    [sym_property] = STATE(5733),
    [sym_permissions_property] = STATE(5733),
    [sym_table_relation_property] = STATE(5733),
    [sym_fields_section] = STATE(5733),
    [sym_keys_section] = STATE(5733),
    [sym_fieldgroups_section] = STATE(5733),
    [sym_enum_value_declaration] = STATE(5733),
    [sym_labels_section] = STATE(5733),
    [sym_layout_section] = STATE(5733),
    [sym_modify_modification] = STATE(5733),
    [sym_actions_section] = STATE(5733),
    [sym_views_section] = STATE(5733),
    [sym_dataset_section] = STATE(5733),
    [sym_requestpage_section] = STATE(5733),
    [sym_rendering_section] = STATE(5733),
    [sym_elements_section] = STATE(5733),
    [sym_schema_section] = STATE(5733),
    [sym_assembly_declaration] = STATE(5733),
    [sym_event_declaration] = STATE(5733),
    [sym_procedure] = STATE(5733),
    [sym_preproc_split_procedure] = STATE(5733),
    [sym_preproc_split_procedure_preamble] = STATE(5733),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5733),
    [sym_var_section] = STATE(5733),
    [sym_attribute_item] = STATE(5733),
    [sym_preproc_conditional] = STATE(5733),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5733),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13984),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5620)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(13986),
    [anon_sym_RBRACE] = ACTIONS(8931),
    [anon_sym_LBRACK] = ACTIONS(13989),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(13992),
    [aux_sym_modify_modification_token1] = ACTIONS(13995),
    [aux_sym_assembly_declaration_token1] = ACTIONS(13998),
    [anon_sym_POUNDif] = ACTIONS(8928),
    [anon_sym_POUNDIF] = ACTIONS(8928),
    [anon_sym_POUNDIf] = ACTIONS(8928),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(14001),
    [sym_trigger_keyword] = ACTIONS(14004),
    [sym_var_keyword] = ACTIONS(14007),
    [sym_local_keyword] = ACTIONS(14010),
    [sym_internal_keyword] = ACTIONS(8945),
    [sym_protected_keyword] = ACTIONS(14010),
    [sym_event_keyword] = ACTIONS(14013),
    [sym_fields_keyword] = ACTIONS(14016),
    [sym_keys_keyword] = ACTIONS(14019),
    [sym_fieldgroups_keyword] = ACTIONS(14022),
    [sym_actions_keyword] = ACTIONS(14025),
    [sym_layout_keyword] = ACTIONS(14028),
    [sym_dataset_keyword] = ACTIONS(14031),
    [sym_elements_keyword] = ACTIONS(14034),
    [sym_labels_keyword] = ACTIONS(14037),
    [sym_rendering_keyword] = ACTIONS(14040),
    [sym_requestpage_keyword] = ACTIONS(14043),
    [sym_schema_keyword] = ACTIONS(14046),
    [sym_views_keyword] = ACTIONS(14049),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(14052),
    [sym_preproc_open] = ACTIONS(8928),
  },
  [STATE(5621)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14055),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5622)] = {
    [sym_identifier] = ACTIONS(9048),
    [anon_sym_SEMI] = ACTIONS(9050),
    [anon_sym_RBRACE] = ACTIONS(9050),
    [aux_sym_where_condition_token1] = ACTIONS(9048),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9048),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9048),
    [anon_sym_LBRACK] = ACTIONS(9050),
    [aux_sym_basic_type_token6] = ACTIONS(9048),
    [aux_sym_basic_type_token22] = ACTIONS(9048),
    [aux_sym_basic_type_token53] = ACTIONS(9048),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9048),
    [aux_sym_addafter_modification_token1] = ACTIONS(9048),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9048),
    [aux_sym_modify_modification_token1] = ACTIONS(9048),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9048),
    [aux_sym_movelast_modification_token1] = ACTIONS(9048),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9048),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9048),
    [aux_sym_separator_action_token1] = ACTIONS(9048),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9048),
    [aux_sym_type_declaration_token1] = ACTIONS(9048),
    [anon_sym_POUNDif] = ACTIONS(9050),
    [anon_sym_POUNDIF] = ACTIONS(9050),
    [anon_sym_POUNDIf] = ACTIONS(9050),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9048),
    [sym_procedure_keyword] = ACTIONS(9048),
    [sym_trigger_keyword] = ACTIONS(9048),
    [sym_var_keyword] = ACTIONS(9048),
    [sym_local_keyword] = ACTIONS(9048),
    [sym_internal_keyword] = ACTIONS(9048),
    [sym_protected_keyword] = ACTIONS(9048),
    [sym_event_keyword] = ACTIONS(9048),
    [sym_fields_keyword] = ACTIONS(9048),
    [sym_keys_keyword] = ACTIONS(9048),
    [sym_key_keyword] = ACTIONS(9048),
    [sym_fieldgroups_keyword] = ACTIONS(9048),
    [sym_actions_keyword] = ACTIONS(9048),
    [sym_layout_keyword] = ACTIONS(9048),
    [sym_area_keyword] = ACTIONS(9048),
    [sym_group_keyword] = ACTIONS(9048),
    [sym_repeater_keyword] = ACTIONS(9048),
    [sym_cuegroup_keyword] = ACTIONS(9048),
    [sym_fixed_keyword] = ACTIONS(9048),
    [sym_grid_keyword] = ACTIONS(9048),
    [sym_part_keyword] = ACTIONS(9048),
    [sym_systempart_keyword] = ACTIONS(9048),
    [sym_usercontrol_keyword] = ACTIONS(9048),
    [sym_dataset_keyword] = ACTIONS(9048),
    [sym_elements_keyword] = ACTIONS(9048),
    [sym_dataitem_keyword] = ACTIONS(9048),
    [sym_column_keyword] = ACTIONS(9048),
    [sym_filter_keyword] = ACTIONS(9048),
    [sym_labels_keyword] = ACTIONS(9048),
    [sym_rendering_keyword] = ACTIONS(9048),
    [sym_requestpage_keyword] = ACTIONS(9048),
    [sym_schema_keyword] = ACTIONS(9048),
    [sym_views_keyword] = ACTIONS(9048),
    [sym_quoted_identifier] = ACTIONS(9050),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9050),
    [sym_preproc_open] = ACTIONS(9050),
    [sym_var_attribute_open] = ACTIONS(9050),
  },
  [STATE(5623)] = {
    [sym__body_element] = STATE(5601),
    [sym_empty_statement] = STATE(5601),
    [sym_property] = STATE(5601),
    [sym_permissions_property] = STATE(5601),
    [sym_table_relation_property] = STATE(5601),
    [sym_fields_section] = STATE(5601),
    [sym_keys_section] = STATE(5601),
    [sym_fieldgroups_section] = STATE(5601),
    [sym_enum_value_declaration] = STATE(5601),
    [sym_labels_section] = STATE(5601),
    [sym_layout_section] = STATE(5601),
    [sym_modify_modification] = STATE(5601),
    [sym_actions_section] = STATE(5601),
    [sym_views_section] = STATE(5601),
    [sym_dataset_section] = STATE(5601),
    [sym_requestpage_section] = STATE(5601),
    [sym_rendering_section] = STATE(5601),
    [sym_elements_section] = STATE(5601),
    [sym_schema_section] = STATE(5601),
    [sym_assembly_declaration] = STATE(5601),
    [sym_event_declaration] = STATE(5601),
    [sym_procedure] = STATE(5601),
    [sym_preproc_split_procedure] = STATE(5601),
    [sym_preproc_split_procedure_preamble] = STATE(5601),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5601),
    [sym_var_section] = STATE(5601),
    [sym_attribute_item] = STATE(5601),
    [sym_preproc_conditional] = STATE(5601),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5601),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14057),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5624)] = {
    [sym_identifier] = ACTIONS(6148),
    [anon_sym_SEMI] = ACTIONS(6150),
    [anon_sym_RBRACE] = ACTIONS(6150),
    [aux_sym_where_condition_token1] = ACTIONS(6148),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6148),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6148),
    [anon_sym_LBRACK] = ACTIONS(6150),
    [aux_sym_basic_type_token6] = ACTIONS(6148),
    [aux_sym_basic_type_token22] = ACTIONS(6148),
    [aux_sym_basic_type_token53] = ACTIONS(6148),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6148),
    [aux_sym_addafter_modification_token1] = ACTIONS(6148),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6148),
    [aux_sym_modify_modification_token1] = ACTIONS(6148),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6148),
    [aux_sym_movelast_modification_token1] = ACTIONS(6148),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6148),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6148),
    [aux_sym_separator_action_token1] = ACTIONS(6148),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6148),
    [aux_sym_type_declaration_token1] = ACTIONS(6148),
    [anon_sym_POUNDif] = ACTIONS(6150),
    [anon_sym_POUNDIF] = ACTIONS(6150),
    [anon_sym_POUNDIf] = ACTIONS(6150),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6148),
    [sym_procedure_keyword] = ACTIONS(6148),
    [sym_trigger_keyword] = ACTIONS(6148),
    [sym_var_keyword] = ACTIONS(6148),
    [sym_local_keyword] = ACTIONS(6148),
    [sym_internal_keyword] = ACTIONS(6148),
    [sym_protected_keyword] = ACTIONS(6148),
    [sym_event_keyword] = ACTIONS(6148),
    [sym_fields_keyword] = ACTIONS(6148),
    [sym_keys_keyword] = ACTIONS(6148),
    [sym_key_keyword] = ACTIONS(6148),
    [sym_fieldgroups_keyword] = ACTIONS(6148),
    [sym_actions_keyword] = ACTIONS(6148),
    [sym_layout_keyword] = ACTIONS(6148),
    [sym_area_keyword] = ACTIONS(6148),
    [sym_group_keyword] = ACTIONS(6148),
    [sym_repeater_keyword] = ACTIONS(6148),
    [sym_cuegroup_keyword] = ACTIONS(6148),
    [sym_fixed_keyword] = ACTIONS(6148),
    [sym_grid_keyword] = ACTIONS(6148),
    [sym_part_keyword] = ACTIONS(6148),
    [sym_systempart_keyword] = ACTIONS(6148),
    [sym_usercontrol_keyword] = ACTIONS(6148),
    [sym_dataset_keyword] = ACTIONS(6148),
    [sym_elements_keyword] = ACTIONS(6148),
    [sym_dataitem_keyword] = ACTIONS(6148),
    [sym_column_keyword] = ACTIONS(6148),
    [sym_filter_keyword] = ACTIONS(6148),
    [sym_labels_keyword] = ACTIONS(6148),
    [sym_rendering_keyword] = ACTIONS(6148),
    [sym_requestpage_keyword] = ACTIONS(6148),
    [sym_schema_keyword] = ACTIONS(6148),
    [sym_views_keyword] = ACTIONS(6148),
    [sym_quoted_identifier] = ACTIONS(6150),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6150),
    [sym_preproc_open] = ACTIONS(6150),
    [sym_var_attribute_open] = ACTIONS(6150),
  },
  [STATE(5625)] = {
    [sym_identifier] = ACTIONS(9052),
    [anon_sym_SEMI] = ACTIONS(9054),
    [anon_sym_RBRACE] = ACTIONS(9054),
    [aux_sym_where_condition_token1] = ACTIONS(9052),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9052),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9052),
    [anon_sym_LBRACK] = ACTIONS(9054),
    [aux_sym_basic_type_token6] = ACTIONS(9052),
    [aux_sym_basic_type_token22] = ACTIONS(9052),
    [aux_sym_basic_type_token53] = ACTIONS(9052),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9052),
    [aux_sym_addafter_modification_token1] = ACTIONS(9052),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9052),
    [aux_sym_modify_modification_token1] = ACTIONS(9052),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9052),
    [aux_sym_movelast_modification_token1] = ACTIONS(9052),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9052),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9052),
    [aux_sym_separator_action_token1] = ACTIONS(9052),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9052),
    [aux_sym_type_declaration_token1] = ACTIONS(9052),
    [anon_sym_POUNDif] = ACTIONS(9054),
    [anon_sym_POUNDIF] = ACTIONS(9054),
    [anon_sym_POUNDIf] = ACTIONS(9054),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9052),
    [sym_procedure_keyword] = ACTIONS(9052),
    [sym_trigger_keyword] = ACTIONS(9052),
    [sym_var_keyword] = ACTIONS(9052),
    [sym_local_keyword] = ACTIONS(9052),
    [sym_internal_keyword] = ACTIONS(9052),
    [sym_protected_keyword] = ACTIONS(9052),
    [sym_event_keyword] = ACTIONS(9052),
    [sym_fields_keyword] = ACTIONS(9052),
    [sym_keys_keyword] = ACTIONS(9052),
    [sym_key_keyword] = ACTIONS(9052),
    [sym_fieldgroups_keyword] = ACTIONS(9052),
    [sym_actions_keyword] = ACTIONS(9052),
    [sym_layout_keyword] = ACTIONS(9052),
    [sym_area_keyword] = ACTIONS(9052),
    [sym_group_keyword] = ACTIONS(9052),
    [sym_repeater_keyword] = ACTIONS(9052),
    [sym_cuegroup_keyword] = ACTIONS(9052),
    [sym_fixed_keyword] = ACTIONS(9052),
    [sym_grid_keyword] = ACTIONS(9052),
    [sym_part_keyword] = ACTIONS(9052),
    [sym_systempart_keyword] = ACTIONS(9052),
    [sym_usercontrol_keyword] = ACTIONS(9052),
    [sym_dataset_keyword] = ACTIONS(9052),
    [sym_elements_keyword] = ACTIONS(9052),
    [sym_dataitem_keyword] = ACTIONS(9052),
    [sym_column_keyword] = ACTIONS(9052),
    [sym_filter_keyword] = ACTIONS(9052),
    [sym_labels_keyword] = ACTIONS(9052),
    [sym_rendering_keyword] = ACTIONS(9052),
    [sym_requestpage_keyword] = ACTIONS(9052),
    [sym_schema_keyword] = ACTIONS(9052),
    [sym_views_keyword] = ACTIONS(9052),
    [sym_quoted_identifier] = ACTIONS(9054),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9054),
    [sym_preproc_open] = ACTIONS(9054),
    [sym_var_attribute_open] = ACTIONS(9054),
  },
  [STATE(5626)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14059),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5627)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14061),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5628)] = {
    [sym__body_element] = STATE(5514),
    [sym_empty_statement] = STATE(5514),
    [sym_property] = STATE(5514),
    [sym_permissions_property] = STATE(5514),
    [sym_table_relation_property] = STATE(5514),
    [sym_fields_section] = STATE(5514),
    [sym_keys_section] = STATE(5514),
    [sym_fieldgroups_section] = STATE(5514),
    [sym_enum_value_declaration] = STATE(5514),
    [sym_labels_section] = STATE(5514),
    [sym_layout_section] = STATE(5514),
    [sym_modify_modification] = STATE(5514),
    [sym_actions_section] = STATE(5514),
    [sym_views_section] = STATE(5514),
    [sym_dataset_section] = STATE(5514),
    [sym_requestpage_section] = STATE(5514),
    [sym_rendering_section] = STATE(5514),
    [sym_elements_section] = STATE(5514),
    [sym_schema_section] = STATE(5514),
    [sym_assembly_declaration] = STATE(5514),
    [sym_event_declaration] = STATE(5514),
    [sym_procedure] = STATE(5514),
    [sym_preproc_split_procedure] = STATE(5514),
    [sym_preproc_split_procedure_preamble] = STATE(5514),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5514),
    [sym_var_section] = STATE(5514),
    [sym_attribute_item] = STATE(5514),
    [sym_preproc_conditional] = STATE(5514),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5514),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14063),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5629)] = {
    [sym__body_element] = STATE(5606),
    [sym_empty_statement] = STATE(5606),
    [sym_property] = STATE(5606),
    [sym_permissions_property] = STATE(5606),
    [sym_table_relation_property] = STATE(5606),
    [sym_fields_section] = STATE(5606),
    [sym_keys_section] = STATE(5606),
    [sym_fieldgroups_section] = STATE(5606),
    [sym_enum_value_declaration] = STATE(5606),
    [sym_labels_section] = STATE(5606),
    [sym_layout_section] = STATE(5606),
    [sym_modify_modification] = STATE(5606),
    [sym_actions_section] = STATE(5606),
    [sym_views_section] = STATE(5606),
    [sym_dataset_section] = STATE(5606),
    [sym_requestpage_section] = STATE(5606),
    [sym_rendering_section] = STATE(5606),
    [sym_elements_section] = STATE(5606),
    [sym_schema_section] = STATE(5606),
    [sym_assembly_declaration] = STATE(5606),
    [sym_event_declaration] = STATE(5606),
    [sym_procedure] = STATE(5606),
    [sym_preproc_split_procedure] = STATE(5606),
    [sym_preproc_split_procedure_preamble] = STATE(5606),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5606),
    [sym_var_section] = STATE(5606),
    [sym_attribute_item] = STATE(5606),
    [sym_preproc_conditional] = STATE(5606),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5606),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14065),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5630)] = {
    [sym__body_element] = STATE(5527),
    [sym_empty_statement] = STATE(5527),
    [sym_property] = STATE(5527),
    [sym_permissions_property] = STATE(5527),
    [sym_table_relation_property] = STATE(5527),
    [sym_fields_section] = STATE(5527),
    [sym_keys_section] = STATE(5527),
    [sym_fieldgroups_section] = STATE(5527),
    [sym_enum_value_declaration] = STATE(5527),
    [sym_labels_section] = STATE(5527),
    [sym_layout_section] = STATE(5527),
    [sym_modify_modification] = STATE(5527),
    [sym_actions_section] = STATE(5527),
    [sym_views_section] = STATE(5527),
    [sym_dataset_section] = STATE(5527),
    [sym_requestpage_section] = STATE(5527),
    [sym_rendering_section] = STATE(5527),
    [sym_elements_section] = STATE(5527),
    [sym_schema_section] = STATE(5527),
    [sym_assembly_declaration] = STATE(5527),
    [sym_event_declaration] = STATE(5527),
    [sym_procedure] = STATE(5527),
    [sym_preproc_split_procedure] = STATE(5527),
    [sym_preproc_split_procedure_preamble] = STATE(5527),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5527),
    [sym_var_section] = STATE(5527),
    [sym_attribute_item] = STATE(5527),
    [sym_preproc_conditional] = STATE(5527),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5527),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14067),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5631)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14069),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5632)] = {
    [sym__body_element] = STATE(5627),
    [sym_empty_statement] = STATE(5627),
    [sym_property] = STATE(5627),
    [sym_permissions_property] = STATE(5627),
    [sym_table_relation_property] = STATE(5627),
    [sym_fields_section] = STATE(5627),
    [sym_keys_section] = STATE(5627),
    [sym_fieldgroups_section] = STATE(5627),
    [sym_enum_value_declaration] = STATE(5627),
    [sym_labels_section] = STATE(5627),
    [sym_layout_section] = STATE(5627),
    [sym_modify_modification] = STATE(5627),
    [sym_actions_section] = STATE(5627),
    [sym_views_section] = STATE(5627),
    [sym_dataset_section] = STATE(5627),
    [sym_requestpage_section] = STATE(5627),
    [sym_rendering_section] = STATE(5627),
    [sym_elements_section] = STATE(5627),
    [sym_schema_section] = STATE(5627),
    [sym_assembly_declaration] = STATE(5627),
    [sym_event_declaration] = STATE(5627),
    [sym_procedure] = STATE(5627),
    [sym_preproc_split_procedure] = STATE(5627),
    [sym_preproc_split_procedure_preamble] = STATE(5627),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5627),
    [sym_var_section] = STATE(5627),
    [sym_attribute_item] = STATE(5627),
    [sym_preproc_conditional] = STATE(5627),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5627),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14071),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5633)] = {
    [sym__body_element] = STATE(5811),
    [sym_empty_statement] = STATE(5811),
    [sym_property] = STATE(5811),
    [sym_permissions_property] = STATE(5811),
    [sym_table_relation_property] = STATE(5811),
    [sym_fields_section] = STATE(5811),
    [sym_keys_section] = STATE(5811),
    [sym_fieldgroups_section] = STATE(5811),
    [sym_enum_value_declaration] = STATE(5811),
    [sym_labels_section] = STATE(5811),
    [sym_layout_section] = STATE(5811),
    [sym_modify_modification] = STATE(5811),
    [sym_actions_section] = STATE(5811),
    [sym_views_section] = STATE(5811),
    [sym_dataset_section] = STATE(5811),
    [sym_requestpage_section] = STATE(5811),
    [sym_rendering_section] = STATE(5811),
    [sym_elements_section] = STATE(5811),
    [sym_schema_section] = STATE(5811),
    [sym_assembly_declaration] = STATE(5811),
    [sym_event_declaration] = STATE(5811),
    [sym_procedure] = STATE(5811),
    [sym_preproc_split_procedure] = STATE(5811),
    [sym_preproc_split_procedure_preamble] = STATE(5811),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5811),
    [sym_var_section] = STATE(5811),
    [sym_attribute_item] = STATE(5811),
    [sym_preproc_conditional] = STATE(5811),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5811),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14073),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5634)] = {
    [sym__body_element] = STATE(5852),
    [sym_empty_statement] = STATE(5852),
    [sym_property] = STATE(5852),
    [sym_permissions_property] = STATE(5852),
    [sym_table_relation_property] = STATE(5852),
    [sym_fields_section] = STATE(5852),
    [sym_keys_section] = STATE(5852),
    [sym_fieldgroups_section] = STATE(5852),
    [sym_enum_value_declaration] = STATE(5852),
    [sym_labels_section] = STATE(5852),
    [sym_layout_section] = STATE(5852),
    [sym_modify_modification] = STATE(5852),
    [sym_actions_section] = STATE(5852),
    [sym_views_section] = STATE(5852),
    [sym_dataset_section] = STATE(5852),
    [sym_requestpage_section] = STATE(5852),
    [sym_rendering_section] = STATE(5852),
    [sym_elements_section] = STATE(5852),
    [sym_schema_section] = STATE(5852),
    [sym_assembly_declaration] = STATE(5852),
    [sym_event_declaration] = STATE(5852),
    [sym_procedure] = STATE(5852),
    [sym_preproc_split_procedure] = STATE(5852),
    [sym_preproc_split_procedure_preamble] = STATE(5852),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5852),
    [sym_var_section] = STATE(5852),
    [sym_attribute_item] = STATE(5852),
    [sym_preproc_conditional] = STATE(5852),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5852),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14075),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5635)] = {
    [sym__body_element] = STATE(5608),
    [sym_empty_statement] = STATE(5608),
    [sym_property] = STATE(5608),
    [sym_permissions_property] = STATE(5608),
    [sym_table_relation_property] = STATE(5608),
    [sym_fields_section] = STATE(5608),
    [sym_keys_section] = STATE(5608),
    [sym_fieldgroups_section] = STATE(5608),
    [sym_enum_value_declaration] = STATE(5608),
    [sym_labels_section] = STATE(5608),
    [sym_layout_section] = STATE(5608),
    [sym_modify_modification] = STATE(5608),
    [sym_actions_section] = STATE(5608),
    [sym_views_section] = STATE(5608),
    [sym_dataset_section] = STATE(5608),
    [sym_requestpage_section] = STATE(5608),
    [sym_rendering_section] = STATE(5608),
    [sym_elements_section] = STATE(5608),
    [sym_schema_section] = STATE(5608),
    [sym_assembly_declaration] = STATE(5608),
    [sym_event_declaration] = STATE(5608),
    [sym_procedure] = STATE(5608),
    [sym_preproc_split_procedure] = STATE(5608),
    [sym_preproc_split_procedure_preamble] = STATE(5608),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5608),
    [sym_var_section] = STATE(5608),
    [sym_attribute_item] = STATE(5608),
    [sym_preproc_conditional] = STATE(5608),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5608),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14077),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5636)] = {
    [sym_identifier] = ACTIONS(9052),
    [anon_sym_SEMI] = ACTIONS(9054),
    [anon_sym_RBRACE] = ACTIONS(9054),
    [aux_sym_where_condition_token1] = ACTIONS(9052),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9052),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9052),
    [anon_sym_LBRACK] = ACTIONS(9054),
    [aux_sym_basic_type_token6] = ACTIONS(9052),
    [aux_sym_basic_type_token22] = ACTIONS(9052),
    [aux_sym_basic_type_token53] = ACTIONS(9052),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9052),
    [aux_sym_addafter_modification_token1] = ACTIONS(9052),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9052),
    [aux_sym_modify_modification_token1] = ACTIONS(9052),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9052),
    [aux_sym_movelast_modification_token1] = ACTIONS(9052),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9052),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9052),
    [aux_sym_separator_action_token1] = ACTIONS(9052),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9052),
    [aux_sym_type_declaration_token1] = ACTIONS(9052),
    [anon_sym_POUNDif] = ACTIONS(9054),
    [anon_sym_POUNDIF] = ACTIONS(9054),
    [anon_sym_POUNDIf] = ACTIONS(9054),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9052),
    [sym_procedure_keyword] = ACTIONS(9052),
    [sym_trigger_keyword] = ACTIONS(9052),
    [sym_var_keyword] = ACTIONS(9052),
    [sym_local_keyword] = ACTIONS(9052),
    [sym_internal_keyword] = ACTIONS(9052),
    [sym_protected_keyword] = ACTIONS(9052),
    [sym_event_keyword] = ACTIONS(9052),
    [sym_fields_keyword] = ACTIONS(9052),
    [sym_keys_keyword] = ACTIONS(9052),
    [sym_key_keyword] = ACTIONS(9052),
    [sym_fieldgroups_keyword] = ACTIONS(9052),
    [sym_actions_keyword] = ACTIONS(9052),
    [sym_layout_keyword] = ACTIONS(9052),
    [sym_area_keyword] = ACTIONS(9052),
    [sym_group_keyword] = ACTIONS(9052),
    [sym_repeater_keyword] = ACTIONS(9052),
    [sym_cuegroup_keyword] = ACTIONS(9052),
    [sym_fixed_keyword] = ACTIONS(9052),
    [sym_grid_keyword] = ACTIONS(9052),
    [sym_part_keyword] = ACTIONS(9052),
    [sym_systempart_keyword] = ACTIONS(9052),
    [sym_usercontrol_keyword] = ACTIONS(9052),
    [sym_dataset_keyword] = ACTIONS(9052),
    [sym_elements_keyword] = ACTIONS(9052),
    [sym_dataitem_keyword] = ACTIONS(9052),
    [sym_column_keyword] = ACTIONS(9052),
    [sym_filter_keyword] = ACTIONS(9052),
    [sym_labels_keyword] = ACTIONS(9052),
    [sym_rendering_keyword] = ACTIONS(9052),
    [sym_requestpage_keyword] = ACTIONS(9052),
    [sym_schema_keyword] = ACTIONS(9052),
    [sym_views_keyword] = ACTIONS(9052),
    [sym_quoted_identifier] = ACTIONS(9054),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9054),
    [sym_preproc_open] = ACTIONS(9054),
    [sym_var_attribute_open] = ACTIONS(9054),
  },
  [STATE(5637)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14079),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5638)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14081),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5639)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14083),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5640)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14085),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5641)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14087),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5642)] = {
    [sym__body_element] = STATE(5657),
    [sym_empty_statement] = STATE(5657),
    [sym_property] = STATE(5657),
    [sym_permissions_property] = STATE(5657),
    [sym_table_relation_property] = STATE(5657),
    [sym_fields_section] = STATE(5657),
    [sym_keys_section] = STATE(5657),
    [sym_fieldgroups_section] = STATE(5657),
    [sym_enum_value_declaration] = STATE(5657),
    [sym_labels_section] = STATE(5657),
    [sym_layout_section] = STATE(5657),
    [sym_modify_modification] = STATE(5657),
    [sym_actions_section] = STATE(5657),
    [sym_views_section] = STATE(5657),
    [sym_dataset_section] = STATE(5657),
    [sym_requestpage_section] = STATE(5657),
    [sym_rendering_section] = STATE(5657),
    [sym_elements_section] = STATE(5657),
    [sym_schema_section] = STATE(5657),
    [sym_assembly_declaration] = STATE(5657),
    [sym_event_declaration] = STATE(5657),
    [sym_procedure] = STATE(5657),
    [sym_preproc_split_procedure] = STATE(5657),
    [sym_preproc_split_procedure_preamble] = STATE(5657),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5657),
    [sym_var_section] = STATE(5657),
    [sym_attribute_item] = STATE(5657),
    [sym_preproc_conditional] = STATE(5657),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5657),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14089),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5643)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14091),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5644)] = {
    [sym__body_element] = STATE(5569),
    [sym_empty_statement] = STATE(5569),
    [sym_property] = STATE(5569),
    [sym_permissions_property] = STATE(5569),
    [sym_table_relation_property] = STATE(5569),
    [sym_fields_section] = STATE(5569),
    [sym_keys_section] = STATE(5569),
    [sym_fieldgroups_section] = STATE(5569),
    [sym_enum_value_declaration] = STATE(5569),
    [sym_labels_section] = STATE(5569),
    [sym_layout_section] = STATE(5569),
    [sym_modify_modification] = STATE(5569),
    [sym_actions_section] = STATE(5569),
    [sym_views_section] = STATE(5569),
    [sym_dataset_section] = STATE(5569),
    [sym_requestpage_section] = STATE(5569),
    [sym_rendering_section] = STATE(5569),
    [sym_elements_section] = STATE(5569),
    [sym_schema_section] = STATE(5569),
    [sym_assembly_declaration] = STATE(5569),
    [sym_event_declaration] = STATE(5569),
    [sym_procedure] = STATE(5569),
    [sym_preproc_split_procedure] = STATE(5569),
    [sym_preproc_split_procedure_preamble] = STATE(5569),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5569),
    [sym_var_section] = STATE(5569),
    [sym_attribute_item] = STATE(5569),
    [sym_preproc_conditional] = STATE(5569),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5569),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(13938),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5645)] = {
    [sym__body_element] = STATE(5703),
    [sym_empty_statement] = STATE(5703),
    [sym_property] = STATE(5703),
    [sym_permissions_property] = STATE(5703),
    [sym_table_relation_property] = STATE(5703),
    [sym_fields_section] = STATE(5703),
    [sym_keys_section] = STATE(5703),
    [sym_fieldgroups_section] = STATE(5703),
    [sym_enum_value_declaration] = STATE(5703),
    [sym_labels_section] = STATE(5703),
    [sym_layout_section] = STATE(5703),
    [sym_modify_modification] = STATE(5703),
    [sym_actions_section] = STATE(5703),
    [sym_views_section] = STATE(5703),
    [sym_dataset_section] = STATE(5703),
    [sym_requestpage_section] = STATE(5703),
    [sym_rendering_section] = STATE(5703),
    [sym_elements_section] = STATE(5703),
    [sym_schema_section] = STATE(5703),
    [sym_assembly_declaration] = STATE(5703),
    [sym_event_declaration] = STATE(5703),
    [sym_procedure] = STATE(5703),
    [sym_preproc_split_procedure] = STATE(5703),
    [sym_preproc_split_procedure_preamble] = STATE(5703),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5703),
    [sym_var_section] = STATE(5703),
    [sym_attribute_item] = STATE(5703),
    [sym_preproc_conditional] = STATE(5703),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5703),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14093),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5646)] = {
    [sym__body_element] = STATE(5738),
    [sym_empty_statement] = STATE(5738),
    [sym_property] = STATE(5738),
    [sym_permissions_property] = STATE(5738),
    [sym_table_relation_property] = STATE(5738),
    [sym_fields_section] = STATE(5738),
    [sym_keys_section] = STATE(5738),
    [sym_fieldgroups_section] = STATE(5738),
    [sym_enum_value_declaration] = STATE(5738),
    [sym_labels_section] = STATE(5738),
    [sym_layout_section] = STATE(5738),
    [sym_modify_modification] = STATE(5738),
    [sym_actions_section] = STATE(5738),
    [sym_views_section] = STATE(5738),
    [sym_dataset_section] = STATE(5738),
    [sym_requestpage_section] = STATE(5738),
    [sym_rendering_section] = STATE(5738),
    [sym_elements_section] = STATE(5738),
    [sym_schema_section] = STATE(5738),
    [sym_assembly_declaration] = STATE(5738),
    [sym_event_declaration] = STATE(5738),
    [sym_procedure] = STATE(5738),
    [sym_preproc_split_procedure] = STATE(5738),
    [sym_preproc_split_procedure_preamble] = STATE(5738),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5738),
    [sym_var_section] = STATE(5738),
    [sym_attribute_item] = STATE(5738),
    [sym_preproc_conditional] = STATE(5738),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5738),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14095),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5647)] = {
    [sym__body_element] = STATE(5680),
    [sym_empty_statement] = STATE(5680),
    [sym_property] = STATE(5680),
    [sym_permissions_property] = STATE(5680),
    [sym_table_relation_property] = STATE(5680),
    [sym_fields_section] = STATE(5680),
    [sym_keys_section] = STATE(5680),
    [sym_fieldgroups_section] = STATE(5680),
    [sym_enum_value_declaration] = STATE(5680),
    [sym_labels_section] = STATE(5680),
    [sym_layout_section] = STATE(5680),
    [sym_modify_modification] = STATE(5680),
    [sym_actions_section] = STATE(5680),
    [sym_views_section] = STATE(5680),
    [sym_dataset_section] = STATE(5680),
    [sym_requestpage_section] = STATE(5680),
    [sym_rendering_section] = STATE(5680),
    [sym_elements_section] = STATE(5680),
    [sym_schema_section] = STATE(5680),
    [sym_assembly_declaration] = STATE(5680),
    [sym_event_declaration] = STATE(5680),
    [sym_procedure] = STATE(5680),
    [sym_preproc_split_procedure] = STATE(5680),
    [sym_preproc_split_procedure_preamble] = STATE(5680),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5680),
    [sym_var_section] = STATE(5680),
    [sym_attribute_item] = STATE(5680),
    [sym_preproc_conditional] = STATE(5680),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5680),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14097),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5648)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14099),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5649)] = {
    [sym__body_element] = STATE(5604),
    [sym_empty_statement] = STATE(5604),
    [sym_property] = STATE(5604),
    [sym_permissions_property] = STATE(5604),
    [sym_table_relation_property] = STATE(5604),
    [sym_fields_section] = STATE(5604),
    [sym_keys_section] = STATE(5604),
    [sym_fieldgroups_section] = STATE(5604),
    [sym_enum_value_declaration] = STATE(5604),
    [sym_labels_section] = STATE(5604),
    [sym_layout_section] = STATE(5604),
    [sym_modify_modification] = STATE(5604),
    [sym_actions_section] = STATE(5604),
    [sym_views_section] = STATE(5604),
    [sym_dataset_section] = STATE(5604),
    [sym_requestpage_section] = STATE(5604),
    [sym_rendering_section] = STATE(5604),
    [sym_elements_section] = STATE(5604),
    [sym_schema_section] = STATE(5604),
    [sym_assembly_declaration] = STATE(5604),
    [sym_event_declaration] = STATE(5604),
    [sym_procedure] = STATE(5604),
    [sym_preproc_split_procedure] = STATE(5604),
    [sym_preproc_split_procedure_preamble] = STATE(5604),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5604),
    [sym_var_section] = STATE(5604),
    [sym_attribute_item] = STATE(5604),
    [sym_preproc_conditional] = STATE(5604),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5604),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14101),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5650)] = {
    [sym__body_element] = STATE(5696),
    [sym_empty_statement] = STATE(5696),
    [sym_property] = STATE(5696),
    [sym_permissions_property] = STATE(5696),
    [sym_table_relation_property] = STATE(5696),
    [sym_fields_section] = STATE(5696),
    [sym_keys_section] = STATE(5696),
    [sym_fieldgroups_section] = STATE(5696),
    [sym_enum_value_declaration] = STATE(5696),
    [sym_labels_section] = STATE(5696),
    [sym_layout_section] = STATE(5696),
    [sym_modify_modification] = STATE(5696),
    [sym_actions_section] = STATE(5696),
    [sym_views_section] = STATE(5696),
    [sym_dataset_section] = STATE(5696),
    [sym_requestpage_section] = STATE(5696),
    [sym_rendering_section] = STATE(5696),
    [sym_elements_section] = STATE(5696),
    [sym_schema_section] = STATE(5696),
    [sym_assembly_declaration] = STATE(5696),
    [sym_event_declaration] = STATE(5696),
    [sym_procedure] = STATE(5696),
    [sym_preproc_split_procedure] = STATE(5696),
    [sym_preproc_split_procedure_preamble] = STATE(5696),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5696),
    [sym_var_section] = STATE(5696),
    [sym_attribute_item] = STATE(5696),
    [sym_preproc_conditional] = STATE(5696),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5696),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14103),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5651)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14105),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5652)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14107),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5653)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14109),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5654)] = {
    [sym__body_element] = STATE(5718),
    [sym_empty_statement] = STATE(5718),
    [sym_property] = STATE(5718),
    [sym_permissions_property] = STATE(5718),
    [sym_table_relation_property] = STATE(5718),
    [sym_fields_section] = STATE(5718),
    [sym_keys_section] = STATE(5718),
    [sym_fieldgroups_section] = STATE(5718),
    [sym_enum_value_declaration] = STATE(5718),
    [sym_labels_section] = STATE(5718),
    [sym_layout_section] = STATE(5718),
    [sym_modify_modification] = STATE(5718),
    [sym_actions_section] = STATE(5718),
    [sym_views_section] = STATE(5718),
    [sym_dataset_section] = STATE(5718),
    [sym_requestpage_section] = STATE(5718),
    [sym_rendering_section] = STATE(5718),
    [sym_elements_section] = STATE(5718),
    [sym_schema_section] = STATE(5718),
    [sym_assembly_declaration] = STATE(5718),
    [sym_event_declaration] = STATE(5718),
    [sym_procedure] = STATE(5718),
    [sym_preproc_split_procedure] = STATE(5718),
    [sym_preproc_split_procedure_preamble] = STATE(5718),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5718),
    [sym_var_section] = STATE(5718),
    [sym_attribute_item] = STATE(5718),
    [sym_preproc_conditional] = STATE(5718),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5718),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14111),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5655)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14113),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5656)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14115),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5657)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14117),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5658)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14119),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5659)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14121),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5660)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14123),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5661)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14125),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5662)] = {
    [sym__body_element] = STATE(5821),
    [sym_empty_statement] = STATE(5821),
    [sym_property] = STATE(5821),
    [sym_permissions_property] = STATE(5821),
    [sym_table_relation_property] = STATE(5821),
    [sym_fields_section] = STATE(5821),
    [sym_keys_section] = STATE(5821),
    [sym_fieldgroups_section] = STATE(5821),
    [sym_enum_value_declaration] = STATE(5821),
    [sym_labels_section] = STATE(5821),
    [sym_layout_section] = STATE(5821),
    [sym_modify_modification] = STATE(5821),
    [sym_actions_section] = STATE(5821),
    [sym_views_section] = STATE(5821),
    [sym_dataset_section] = STATE(5821),
    [sym_requestpage_section] = STATE(5821),
    [sym_rendering_section] = STATE(5821),
    [sym_elements_section] = STATE(5821),
    [sym_schema_section] = STATE(5821),
    [sym_assembly_declaration] = STATE(5821),
    [sym_event_declaration] = STATE(5821),
    [sym_procedure] = STATE(5821),
    [sym_preproc_split_procedure] = STATE(5821),
    [sym_preproc_split_procedure_preamble] = STATE(5821),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5821),
    [sym_var_section] = STATE(5821),
    [sym_attribute_item] = STATE(5821),
    [sym_preproc_conditional] = STATE(5821),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5821),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14127),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5663)] = {
    [sym__body_element] = STATE(5814),
    [sym_empty_statement] = STATE(5814),
    [sym_property] = STATE(5814),
    [sym_permissions_property] = STATE(5814),
    [sym_table_relation_property] = STATE(5814),
    [sym_fields_section] = STATE(5814),
    [sym_keys_section] = STATE(5814),
    [sym_fieldgroups_section] = STATE(5814),
    [sym_enum_value_declaration] = STATE(5814),
    [sym_labels_section] = STATE(5814),
    [sym_layout_section] = STATE(5814),
    [sym_modify_modification] = STATE(5814),
    [sym_actions_section] = STATE(5814),
    [sym_views_section] = STATE(5814),
    [sym_dataset_section] = STATE(5814),
    [sym_requestpage_section] = STATE(5814),
    [sym_rendering_section] = STATE(5814),
    [sym_elements_section] = STATE(5814),
    [sym_schema_section] = STATE(5814),
    [sym_assembly_declaration] = STATE(5814),
    [sym_event_declaration] = STATE(5814),
    [sym_procedure] = STATE(5814),
    [sym_preproc_split_procedure] = STATE(5814),
    [sym_preproc_split_procedure_preamble] = STATE(5814),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5814),
    [sym_var_section] = STATE(5814),
    [sym_attribute_item] = STATE(5814),
    [sym_preproc_conditional] = STATE(5814),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5814),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14129),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5664)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14131),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5665)] = {
    [sym__body_element] = STATE(5653),
    [sym_empty_statement] = STATE(5653),
    [sym_property] = STATE(5653),
    [sym_permissions_property] = STATE(5653),
    [sym_table_relation_property] = STATE(5653),
    [sym_fields_section] = STATE(5653),
    [sym_keys_section] = STATE(5653),
    [sym_fieldgroups_section] = STATE(5653),
    [sym_enum_value_declaration] = STATE(5653),
    [sym_labels_section] = STATE(5653),
    [sym_layout_section] = STATE(5653),
    [sym_modify_modification] = STATE(5653),
    [sym_actions_section] = STATE(5653),
    [sym_views_section] = STATE(5653),
    [sym_dataset_section] = STATE(5653),
    [sym_requestpage_section] = STATE(5653),
    [sym_rendering_section] = STATE(5653),
    [sym_elements_section] = STATE(5653),
    [sym_schema_section] = STATE(5653),
    [sym_assembly_declaration] = STATE(5653),
    [sym_event_declaration] = STATE(5653),
    [sym_procedure] = STATE(5653),
    [sym_preproc_split_procedure] = STATE(5653),
    [sym_preproc_split_procedure_preamble] = STATE(5653),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5653),
    [sym_var_section] = STATE(5653),
    [sym_attribute_item] = STATE(5653),
    [sym_preproc_conditional] = STATE(5653),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5653),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14133),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5666)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14135),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5667)] = {
    [sym__body_element] = STATE(5782),
    [sym_empty_statement] = STATE(5782),
    [sym_property] = STATE(5782),
    [sym_permissions_property] = STATE(5782),
    [sym_table_relation_property] = STATE(5782),
    [sym_fields_section] = STATE(5782),
    [sym_keys_section] = STATE(5782),
    [sym_fieldgroups_section] = STATE(5782),
    [sym_enum_value_declaration] = STATE(5782),
    [sym_labels_section] = STATE(5782),
    [sym_layout_section] = STATE(5782),
    [sym_modify_modification] = STATE(5782),
    [sym_actions_section] = STATE(5782),
    [sym_views_section] = STATE(5782),
    [sym_dataset_section] = STATE(5782),
    [sym_requestpage_section] = STATE(5782),
    [sym_rendering_section] = STATE(5782),
    [sym_elements_section] = STATE(5782),
    [sym_schema_section] = STATE(5782),
    [sym_assembly_declaration] = STATE(5782),
    [sym_event_declaration] = STATE(5782),
    [sym_procedure] = STATE(5782),
    [sym_preproc_split_procedure] = STATE(5782),
    [sym_preproc_split_procedure_preamble] = STATE(5782),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5782),
    [sym_var_section] = STATE(5782),
    [sym_attribute_item] = STATE(5782),
    [sym_preproc_conditional] = STATE(5782),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5782),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14137),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5668)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14139),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5669)] = {
    [sym_identifier] = ACTIONS(9010),
    [anon_sym_SEMI] = ACTIONS(9012),
    [anon_sym_RBRACE] = ACTIONS(9012),
    [aux_sym_where_condition_token1] = ACTIONS(9010),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9010),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9010),
    [anon_sym_LBRACK] = ACTIONS(9012),
    [aux_sym_basic_type_token6] = ACTIONS(9010),
    [aux_sym_basic_type_token22] = ACTIONS(9010),
    [aux_sym_basic_type_token53] = ACTIONS(9010),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9010),
    [aux_sym_addafter_modification_token1] = ACTIONS(9010),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9010),
    [aux_sym_modify_modification_token1] = ACTIONS(9010),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9010),
    [aux_sym_movelast_modification_token1] = ACTIONS(9010),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9010),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9010),
    [aux_sym_separator_action_token1] = ACTIONS(9010),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9010),
    [aux_sym_type_declaration_token1] = ACTIONS(9010),
    [anon_sym_POUNDif] = ACTIONS(9012),
    [anon_sym_POUNDIF] = ACTIONS(9012),
    [anon_sym_POUNDIf] = ACTIONS(9012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9010),
    [sym_procedure_keyword] = ACTIONS(9010),
    [sym_trigger_keyword] = ACTIONS(9010),
    [sym_var_keyword] = ACTIONS(9010),
    [sym_local_keyword] = ACTIONS(9010),
    [sym_internal_keyword] = ACTIONS(9010),
    [sym_protected_keyword] = ACTIONS(9010),
    [sym_event_keyword] = ACTIONS(9010),
    [sym_fields_keyword] = ACTIONS(9010),
    [sym_keys_keyword] = ACTIONS(9010),
    [sym_key_keyword] = ACTIONS(9010),
    [sym_fieldgroups_keyword] = ACTIONS(9010),
    [sym_actions_keyword] = ACTIONS(9010),
    [sym_layout_keyword] = ACTIONS(9010),
    [sym_area_keyword] = ACTIONS(9010),
    [sym_group_keyword] = ACTIONS(9010),
    [sym_repeater_keyword] = ACTIONS(9010),
    [sym_cuegroup_keyword] = ACTIONS(9010),
    [sym_fixed_keyword] = ACTIONS(9010),
    [sym_grid_keyword] = ACTIONS(9010),
    [sym_part_keyword] = ACTIONS(9010),
    [sym_systempart_keyword] = ACTIONS(9010),
    [sym_usercontrol_keyword] = ACTIONS(9010),
    [sym_dataset_keyword] = ACTIONS(9010),
    [sym_elements_keyword] = ACTIONS(9010),
    [sym_dataitem_keyword] = ACTIONS(9010),
    [sym_column_keyword] = ACTIONS(9010),
    [sym_filter_keyword] = ACTIONS(9010),
    [sym_labels_keyword] = ACTIONS(9010),
    [sym_rendering_keyword] = ACTIONS(9010),
    [sym_requestpage_keyword] = ACTIONS(9010),
    [sym_schema_keyword] = ACTIONS(9010),
    [sym_views_keyword] = ACTIONS(9010),
    [sym_quoted_identifier] = ACTIONS(9012),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9012),
    [sym_preproc_open] = ACTIONS(9012),
    [sym_var_attribute_open] = ACTIONS(9012),
  },
  [STATE(5670)] = {
    [sym__body_element] = STATE(5574),
    [sym_empty_statement] = STATE(5574),
    [sym_property] = STATE(5574),
    [sym_permissions_property] = STATE(5574),
    [sym_table_relation_property] = STATE(5574),
    [sym_fields_section] = STATE(5574),
    [sym_keys_section] = STATE(5574),
    [sym_fieldgroups_section] = STATE(5574),
    [sym_enum_value_declaration] = STATE(5574),
    [sym_labels_section] = STATE(5574),
    [sym_layout_section] = STATE(5574),
    [sym_modify_modification] = STATE(5574),
    [sym_actions_section] = STATE(5574),
    [sym_views_section] = STATE(5574),
    [sym_dataset_section] = STATE(5574),
    [sym_requestpage_section] = STATE(5574),
    [sym_rendering_section] = STATE(5574),
    [sym_elements_section] = STATE(5574),
    [sym_schema_section] = STATE(5574),
    [sym_assembly_declaration] = STATE(5574),
    [sym_event_declaration] = STATE(5574),
    [sym_procedure] = STATE(5574),
    [sym_preproc_split_procedure] = STATE(5574),
    [sym_preproc_split_procedure_preamble] = STATE(5574),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5574),
    [sym_var_section] = STATE(5574),
    [sym_attribute_item] = STATE(5574),
    [sym_preproc_conditional] = STATE(5574),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5574),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14141),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5671)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14143),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5672)] = {
    [sym__body_element] = STATE(5706),
    [sym_empty_statement] = STATE(5706),
    [sym_property] = STATE(5706),
    [sym_permissions_property] = STATE(5706),
    [sym_table_relation_property] = STATE(5706),
    [sym_fields_section] = STATE(5706),
    [sym_keys_section] = STATE(5706),
    [sym_fieldgroups_section] = STATE(5706),
    [sym_enum_value_declaration] = STATE(5706),
    [sym_labels_section] = STATE(5706),
    [sym_layout_section] = STATE(5706),
    [sym_modify_modification] = STATE(5706),
    [sym_actions_section] = STATE(5706),
    [sym_views_section] = STATE(5706),
    [sym_dataset_section] = STATE(5706),
    [sym_requestpage_section] = STATE(5706),
    [sym_rendering_section] = STATE(5706),
    [sym_elements_section] = STATE(5706),
    [sym_schema_section] = STATE(5706),
    [sym_assembly_declaration] = STATE(5706),
    [sym_event_declaration] = STATE(5706),
    [sym_procedure] = STATE(5706),
    [sym_preproc_split_procedure] = STATE(5706),
    [sym_preproc_split_procedure_preamble] = STATE(5706),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5706),
    [sym_var_section] = STATE(5706),
    [sym_attribute_item] = STATE(5706),
    [sym_preproc_conditional] = STATE(5706),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5706),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14145),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5673)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14147),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5674)] = {
    [sym__body_element] = STATE(5704),
    [sym_empty_statement] = STATE(5704),
    [sym_property] = STATE(5704),
    [sym_permissions_property] = STATE(5704),
    [sym_table_relation_property] = STATE(5704),
    [sym_fields_section] = STATE(5704),
    [sym_keys_section] = STATE(5704),
    [sym_fieldgroups_section] = STATE(5704),
    [sym_enum_value_declaration] = STATE(5704),
    [sym_labels_section] = STATE(5704),
    [sym_layout_section] = STATE(5704),
    [sym_modify_modification] = STATE(5704),
    [sym_actions_section] = STATE(5704),
    [sym_views_section] = STATE(5704),
    [sym_dataset_section] = STATE(5704),
    [sym_requestpage_section] = STATE(5704),
    [sym_rendering_section] = STATE(5704),
    [sym_elements_section] = STATE(5704),
    [sym_schema_section] = STATE(5704),
    [sym_assembly_declaration] = STATE(5704),
    [sym_event_declaration] = STATE(5704),
    [sym_procedure] = STATE(5704),
    [sym_preproc_split_procedure] = STATE(5704),
    [sym_preproc_split_procedure_preamble] = STATE(5704),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5704),
    [sym_var_section] = STATE(5704),
    [sym_attribute_item] = STATE(5704),
    [sym_preproc_conditional] = STATE(5704),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5704),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14149),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5675)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14151),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5676)] = {
    [sym__body_element] = STATE(5750),
    [sym_empty_statement] = STATE(5750),
    [sym_property] = STATE(5750),
    [sym_permissions_property] = STATE(5750),
    [sym_table_relation_property] = STATE(5750),
    [sym_fields_section] = STATE(5750),
    [sym_keys_section] = STATE(5750),
    [sym_fieldgroups_section] = STATE(5750),
    [sym_enum_value_declaration] = STATE(5750),
    [sym_labels_section] = STATE(5750),
    [sym_layout_section] = STATE(5750),
    [sym_modify_modification] = STATE(5750),
    [sym_actions_section] = STATE(5750),
    [sym_views_section] = STATE(5750),
    [sym_dataset_section] = STATE(5750),
    [sym_requestpage_section] = STATE(5750),
    [sym_rendering_section] = STATE(5750),
    [sym_elements_section] = STATE(5750),
    [sym_schema_section] = STATE(5750),
    [sym_assembly_declaration] = STATE(5750),
    [sym_event_declaration] = STATE(5750),
    [sym_procedure] = STATE(5750),
    [sym_preproc_split_procedure] = STATE(5750),
    [sym_preproc_split_procedure_preamble] = STATE(5750),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5750),
    [sym_var_section] = STATE(5750),
    [sym_attribute_item] = STATE(5750),
    [sym_preproc_conditional] = STATE(5750),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5750),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14153),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5677)] = {
    [sym__body_element] = STATE(5660),
    [sym_empty_statement] = STATE(5660),
    [sym_property] = STATE(5660),
    [sym_permissions_property] = STATE(5660),
    [sym_table_relation_property] = STATE(5660),
    [sym_fields_section] = STATE(5660),
    [sym_keys_section] = STATE(5660),
    [sym_fieldgroups_section] = STATE(5660),
    [sym_enum_value_declaration] = STATE(5660),
    [sym_labels_section] = STATE(5660),
    [sym_layout_section] = STATE(5660),
    [sym_modify_modification] = STATE(5660),
    [sym_actions_section] = STATE(5660),
    [sym_views_section] = STATE(5660),
    [sym_dataset_section] = STATE(5660),
    [sym_requestpage_section] = STATE(5660),
    [sym_rendering_section] = STATE(5660),
    [sym_elements_section] = STATE(5660),
    [sym_schema_section] = STATE(5660),
    [sym_assembly_declaration] = STATE(5660),
    [sym_event_declaration] = STATE(5660),
    [sym_procedure] = STATE(5660),
    [sym_preproc_split_procedure] = STATE(5660),
    [sym_preproc_split_procedure_preamble] = STATE(5660),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5660),
    [sym_var_section] = STATE(5660),
    [sym_attribute_item] = STATE(5660),
    [sym_preproc_conditional] = STATE(5660),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5660),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14155),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5678)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14157),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5679)] = {
    [sym_identifier] = ACTIONS(8901),
    [anon_sym_SEMI] = ACTIONS(8903),
    [anon_sym_RBRACE] = ACTIONS(8903),
    [aux_sym_where_condition_token1] = ACTIONS(8901),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8901),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8901),
    [anon_sym_LBRACK] = ACTIONS(8903),
    [aux_sym_basic_type_token6] = ACTIONS(8901),
    [aux_sym_basic_type_token22] = ACTIONS(8901),
    [aux_sym_basic_type_token53] = ACTIONS(8901),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8901),
    [aux_sym_addafter_modification_token1] = ACTIONS(8901),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8901),
    [aux_sym_modify_modification_token1] = ACTIONS(8901),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8901),
    [aux_sym_movelast_modification_token1] = ACTIONS(8901),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8901),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8901),
    [aux_sym_separator_action_token1] = ACTIONS(8901),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8901),
    [aux_sym_type_declaration_token1] = ACTIONS(8901),
    [anon_sym_POUNDif] = ACTIONS(8903),
    [anon_sym_POUNDIF] = ACTIONS(8903),
    [anon_sym_POUNDIf] = ACTIONS(8903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8901),
    [sym_procedure_keyword] = ACTIONS(8901),
    [sym_trigger_keyword] = ACTIONS(8901),
    [sym_var_keyword] = ACTIONS(8901),
    [sym_local_keyword] = ACTIONS(8901),
    [sym_internal_keyword] = ACTIONS(8901),
    [sym_protected_keyword] = ACTIONS(8901),
    [sym_event_keyword] = ACTIONS(8901),
    [sym_fields_keyword] = ACTIONS(8901),
    [sym_keys_keyword] = ACTIONS(8901),
    [sym_key_keyword] = ACTIONS(8901),
    [sym_fieldgroups_keyword] = ACTIONS(8901),
    [sym_actions_keyword] = ACTIONS(8901),
    [sym_layout_keyword] = ACTIONS(8901),
    [sym_area_keyword] = ACTIONS(8901),
    [sym_group_keyword] = ACTIONS(8901),
    [sym_repeater_keyword] = ACTIONS(8901),
    [sym_cuegroup_keyword] = ACTIONS(8901),
    [sym_fixed_keyword] = ACTIONS(8901),
    [sym_grid_keyword] = ACTIONS(8901),
    [sym_part_keyword] = ACTIONS(8901),
    [sym_systempart_keyword] = ACTIONS(8901),
    [sym_usercontrol_keyword] = ACTIONS(8901),
    [sym_dataset_keyword] = ACTIONS(8901),
    [sym_elements_keyword] = ACTIONS(8901),
    [sym_dataitem_keyword] = ACTIONS(8901),
    [sym_column_keyword] = ACTIONS(8901),
    [sym_filter_keyword] = ACTIONS(8901),
    [sym_labels_keyword] = ACTIONS(8901),
    [sym_rendering_keyword] = ACTIONS(8901),
    [sym_requestpage_keyword] = ACTIONS(8901),
    [sym_schema_keyword] = ACTIONS(8901),
    [sym_views_keyword] = ACTIONS(8901),
    [sym_quoted_identifier] = ACTIONS(8903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8903),
    [sym_preproc_open] = ACTIONS(8903),
    [sym_var_attribute_open] = ACTIONS(8903),
  },
  [STATE(5680)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14159),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5681)] = {
    [sym__body_element] = STATE(5492),
    [sym_empty_statement] = STATE(5492),
    [sym_property] = STATE(5492),
    [sym_permissions_property] = STATE(5492),
    [sym_table_relation_property] = STATE(5492),
    [sym_fields_section] = STATE(5492),
    [sym_keys_section] = STATE(5492),
    [sym_fieldgroups_section] = STATE(5492),
    [sym_enum_value_declaration] = STATE(5492),
    [sym_labels_section] = STATE(5492),
    [sym_layout_section] = STATE(5492),
    [sym_modify_modification] = STATE(5492),
    [sym_actions_section] = STATE(5492),
    [sym_views_section] = STATE(5492),
    [sym_dataset_section] = STATE(5492),
    [sym_requestpage_section] = STATE(5492),
    [sym_rendering_section] = STATE(5492),
    [sym_elements_section] = STATE(5492),
    [sym_schema_section] = STATE(5492),
    [sym_assembly_declaration] = STATE(5492),
    [sym_event_declaration] = STATE(5492),
    [sym_procedure] = STATE(5492),
    [sym_preproc_split_procedure] = STATE(5492),
    [sym_preproc_split_procedure_preamble] = STATE(5492),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5492),
    [sym_var_section] = STATE(5492),
    [sym_attribute_item] = STATE(5492),
    [sym_preproc_conditional] = STATE(5492),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5492),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14161),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5682)] = {
    [sym__body_element] = STATE(5491),
    [sym_empty_statement] = STATE(5491),
    [sym_property] = STATE(5491),
    [sym_permissions_property] = STATE(5491),
    [sym_table_relation_property] = STATE(5491),
    [sym_fields_section] = STATE(5491),
    [sym_keys_section] = STATE(5491),
    [sym_fieldgroups_section] = STATE(5491),
    [sym_enum_value_declaration] = STATE(5491),
    [sym_labels_section] = STATE(5491),
    [sym_layout_section] = STATE(5491),
    [sym_modify_modification] = STATE(5491),
    [sym_actions_section] = STATE(5491),
    [sym_views_section] = STATE(5491),
    [sym_dataset_section] = STATE(5491),
    [sym_requestpage_section] = STATE(5491),
    [sym_rendering_section] = STATE(5491),
    [sym_elements_section] = STATE(5491),
    [sym_schema_section] = STATE(5491),
    [sym_assembly_declaration] = STATE(5491),
    [sym_event_declaration] = STATE(5491),
    [sym_procedure] = STATE(5491),
    [sym_preproc_split_procedure] = STATE(5491),
    [sym_preproc_split_procedure_preamble] = STATE(5491),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5491),
    [sym_var_section] = STATE(5491),
    [sym_attribute_item] = STATE(5491),
    [sym_preproc_conditional] = STATE(5491),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5491),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14163),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5683)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14165),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5684)] = {
    [sym__body_element] = STATE(5534),
    [sym_empty_statement] = STATE(5534),
    [sym_property] = STATE(5534),
    [sym_permissions_property] = STATE(5534),
    [sym_table_relation_property] = STATE(5534),
    [sym_fields_section] = STATE(5534),
    [sym_keys_section] = STATE(5534),
    [sym_fieldgroups_section] = STATE(5534),
    [sym_enum_value_declaration] = STATE(5534),
    [sym_labels_section] = STATE(5534),
    [sym_layout_section] = STATE(5534),
    [sym_modify_modification] = STATE(5534),
    [sym_actions_section] = STATE(5534),
    [sym_views_section] = STATE(5534),
    [sym_dataset_section] = STATE(5534),
    [sym_requestpage_section] = STATE(5534),
    [sym_rendering_section] = STATE(5534),
    [sym_elements_section] = STATE(5534),
    [sym_schema_section] = STATE(5534),
    [sym_assembly_declaration] = STATE(5534),
    [sym_event_declaration] = STATE(5534),
    [sym_procedure] = STATE(5534),
    [sym_preproc_split_procedure] = STATE(5534),
    [sym_preproc_split_procedure_preamble] = STATE(5534),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5534),
    [sym_var_section] = STATE(5534),
    [sym_attribute_item] = STATE(5534),
    [sym_preproc_conditional] = STATE(5534),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5534),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14167),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5685)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14169),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5686)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14171),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5687)] = {
    [sym__body_element] = STATE(5850),
    [sym_empty_statement] = STATE(5850),
    [sym_property] = STATE(5850),
    [sym_permissions_property] = STATE(5850),
    [sym_table_relation_property] = STATE(5850),
    [sym_fields_section] = STATE(5850),
    [sym_keys_section] = STATE(5850),
    [sym_fieldgroups_section] = STATE(5850),
    [sym_enum_value_declaration] = STATE(5850),
    [sym_labels_section] = STATE(5850),
    [sym_layout_section] = STATE(5850),
    [sym_modify_modification] = STATE(5850),
    [sym_actions_section] = STATE(5850),
    [sym_views_section] = STATE(5850),
    [sym_dataset_section] = STATE(5850),
    [sym_requestpage_section] = STATE(5850),
    [sym_rendering_section] = STATE(5850),
    [sym_elements_section] = STATE(5850),
    [sym_schema_section] = STATE(5850),
    [sym_assembly_declaration] = STATE(5850),
    [sym_event_declaration] = STATE(5850),
    [sym_procedure] = STATE(5850),
    [sym_preproc_split_procedure] = STATE(5850),
    [sym_preproc_split_procedure_preamble] = STATE(5850),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5850),
    [sym_var_section] = STATE(5850),
    [sym_attribute_item] = STATE(5850),
    [sym_preproc_conditional] = STATE(5850),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5850),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14173),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5688)] = {
    [sym__body_element] = STATE(5724),
    [sym_empty_statement] = STATE(5724),
    [sym_property] = STATE(5724),
    [sym_permissions_property] = STATE(5724),
    [sym_table_relation_property] = STATE(5724),
    [sym_fields_section] = STATE(5724),
    [sym_keys_section] = STATE(5724),
    [sym_fieldgroups_section] = STATE(5724),
    [sym_enum_value_declaration] = STATE(5724),
    [sym_labels_section] = STATE(5724),
    [sym_layout_section] = STATE(5724),
    [sym_modify_modification] = STATE(5724),
    [sym_actions_section] = STATE(5724),
    [sym_views_section] = STATE(5724),
    [sym_dataset_section] = STATE(5724),
    [sym_requestpage_section] = STATE(5724),
    [sym_rendering_section] = STATE(5724),
    [sym_elements_section] = STATE(5724),
    [sym_schema_section] = STATE(5724),
    [sym_assembly_declaration] = STATE(5724),
    [sym_event_declaration] = STATE(5724),
    [sym_procedure] = STATE(5724),
    [sym_preproc_split_procedure] = STATE(5724),
    [sym_preproc_split_procedure_preamble] = STATE(5724),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5724),
    [sym_var_section] = STATE(5724),
    [sym_attribute_item] = STATE(5724),
    [sym_preproc_conditional] = STATE(5724),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5724),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14175),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5689)] = {
    [sym__body_element] = STATE(5723),
    [sym_empty_statement] = STATE(5723),
    [sym_property] = STATE(5723),
    [sym_permissions_property] = STATE(5723),
    [sym_table_relation_property] = STATE(5723),
    [sym_fields_section] = STATE(5723),
    [sym_keys_section] = STATE(5723),
    [sym_fieldgroups_section] = STATE(5723),
    [sym_enum_value_declaration] = STATE(5723),
    [sym_labels_section] = STATE(5723),
    [sym_layout_section] = STATE(5723),
    [sym_modify_modification] = STATE(5723),
    [sym_actions_section] = STATE(5723),
    [sym_views_section] = STATE(5723),
    [sym_dataset_section] = STATE(5723),
    [sym_requestpage_section] = STATE(5723),
    [sym_rendering_section] = STATE(5723),
    [sym_elements_section] = STATE(5723),
    [sym_schema_section] = STATE(5723),
    [sym_assembly_declaration] = STATE(5723),
    [sym_event_declaration] = STATE(5723),
    [sym_procedure] = STATE(5723),
    [sym_preproc_split_procedure] = STATE(5723),
    [sym_preproc_split_procedure_preamble] = STATE(5723),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5723),
    [sym_var_section] = STATE(5723),
    [sym_attribute_item] = STATE(5723),
    [sym_preproc_conditional] = STATE(5723),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5723),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14177),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5690)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14179),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5691)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14181),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5692)] = {
    [sym__body_element] = STATE(5754),
    [sym_empty_statement] = STATE(5754),
    [sym_property] = STATE(5754),
    [sym_permissions_property] = STATE(5754),
    [sym_table_relation_property] = STATE(5754),
    [sym_fields_section] = STATE(5754),
    [sym_keys_section] = STATE(5754),
    [sym_fieldgroups_section] = STATE(5754),
    [sym_enum_value_declaration] = STATE(5754),
    [sym_labels_section] = STATE(5754),
    [sym_layout_section] = STATE(5754),
    [sym_modify_modification] = STATE(5754),
    [sym_actions_section] = STATE(5754),
    [sym_views_section] = STATE(5754),
    [sym_dataset_section] = STATE(5754),
    [sym_requestpage_section] = STATE(5754),
    [sym_rendering_section] = STATE(5754),
    [sym_elements_section] = STATE(5754),
    [sym_schema_section] = STATE(5754),
    [sym_assembly_declaration] = STATE(5754),
    [sym_event_declaration] = STATE(5754),
    [sym_procedure] = STATE(5754),
    [sym_preproc_split_procedure] = STATE(5754),
    [sym_preproc_split_procedure_preamble] = STATE(5754),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5754),
    [sym_var_section] = STATE(5754),
    [sym_attribute_item] = STATE(5754),
    [sym_preproc_conditional] = STATE(5754),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5754),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14183),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5693)] = {
    [sym_identifier] = ACTIONS(9014),
    [anon_sym_SEMI] = ACTIONS(9016),
    [anon_sym_RBRACE] = ACTIONS(9016),
    [aux_sym_where_condition_token1] = ACTIONS(9014),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9014),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9014),
    [anon_sym_LBRACK] = ACTIONS(9016),
    [aux_sym_basic_type_token6] = ACTIONS(9014),
    [aux_sym_basic_type_token22] = ACTIONS(9014),
    [aux_sym_basic_type_token53] = ACTIONS(9014),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9014),
    [aux_sym_addafter_modification_token1] = ACTIONS(9014),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9014),
    [aux_sym_modify_modification_token1] = ACTIONS(9014),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9014),
    [aux_sym_movelast_modification_token1] = ACTIONS(9014),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9014),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9014),
    [aux_sym_separator_action_token1] = ACTIONS(9014),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9014),
    [aux_sym_type_declaration_token1] = ACTIONS(9014),
    [anon_sym_POUNDif] = ACTIONS(9016),
    [anon_sym_POUNDIF] = ACTIONS(9016),
    [anon_sym_POUNDIf] = ACTIONS(9016),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9014),
    [sym_procedure_keyword] = ACTIONS(9014),
    [sym_trigger_keyword] = ACTIONS(9014),
    [sym_var_keyword] = ACTIONS(9014),
    [sym_local_keyword] = ACTIONS(9014),
    [sym_internal_keyword] = ACTIONS(9014),
    [sym_protected_keyword] = ACTIONS(9014),
    [sym_event_keyword] = ACTIONS(9014),
    [sym_fields_keyword] = ACTIONS(9014),
    [sym_keys_keyword] = ACTIONS(9014),
    [sym_key_keyword] = ACTIONS(9014),
    [sym_fieldgroups_keyword] = ACTIONS(9014),
    [sym_actions_keyword] = ACTIONS(9014),
    [sym_layout_keyword] = ACTIONS(9014),
    [sym_area_keyword] = ACTIONS(9014),
    [sym_group_keyword] = ACTIONS(9014),
    [sym_repeater_keyword] = ACTIONS(9014),
    [sym_cuegroup_keyword] = ACTIONS(9014),
    [sym_fixed_keyword] = ACTIONS(9014),
    [sym_grid_keyword] = ACTIONS(9014),
    [sym_part_keyword] = ACTIONS(9014),
    [sym_systempart_keyword] = ACTIONS(9014),
    [sym_usercontrol_keyword] = ACTIONS(9014),
    [sym_dataset_keyword] = ACTIONS(9014),
    [sym_elements_keyword] = ACTIONS(9014),
    [sym_dataitem_keyword] = ACTIONS(9014),
    [sym_column_keyword] = ACTIONS(9014),
    [sym_filter_keyword] = ACTIONS(9014),
    [sym_labels_keyword] = ACTIONS(9014),
    [sym_rendering_keyword] = ACTIONS(9014),
    [sym_requestpage_keyword] = ACTIONS(9014),
    [sym_schema_keyword] = ACTIONS(9014),
    [sym_views_keyword] = ACTIONS(9014),
    [sym_quoted_identifier] = ACTIONS(9016),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9016),
    [sym_preproc_open] = ACTIONS(9016),
    [sym_var_attribute_open] = ACTIONS(9016),
  },
  [STATE(5694)] = {
    [sym__body_element] = STATE(5521),
    [sym_empty_statement] = STATE(5521),
    [sym_property] = STATE(5521),
    [sym_permissions_property] = STATE(5521),
    [sym_table_relation_property] = STATE(5521),
    [sym_fields_section] = STATE(5521),
    [sym_keys_section] = STATE(5521),
    [sym_fieldgroups_section] = STATE(5521),
    [sym_enum_value_declaration] = STATE(5521),
    [sym_labels_section] = STATE(5521),
    [sym_layout_section] = STATE(5521),
    [sym_modify_modification] = STATE(5521),
    [sym_actions_section] = STATE(5521),
    [sym_views_section] = STATE(5521),
    [sym_dataset_section] = STATE(5521),
    [sym_requestpage_section] = STATE(5521),
    [sym_rendering_section] = STATE(5521),
    [sym_elements_section] = STATE(5521),
    [sym_schema_section] = STATE(5521),
    [sym_assembly_declaration] = STATE(5521),
    [sym_event_declaration] = STATE(5521),
    [sym_procedure] = STATE(5521),
    [sym_preproc_split_procedure] = STATE(5521),
    [sym_preproc_split_procedure_preamble] = STATE(5521),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5521),
    [sym_var_section] = STATE(5521),
    [sym_attribute_item] = STATE(5521),
    [sym_preproc_conditional] = STATE(5521),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5521),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14185),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5695)] = {
    [sym__body_element] = STATE(5796),
    [sym_empty_statement] = STATE(5796),
    [sym_property] = STATE(5796),
    [sym_permissions_property] = STATE(5796),
    [sym_table_relation_property] = STATE(5796),
    [sym_fields_section] = STATE(5796),
    [sym_keys_section] = STATE(5796),
    [sym_fieldgroups_section] = STATE(5796),
    [sym_enum_value_declaration] = STATE(5796),
    [sym_labels_section] = STATE(5796),
    [sym_layout_section] = STATE(5796),
    [sym_modify_modification] = STATE(5796),
    [sym_actions_section] = STATE(5796),
    [sym_views_section] = STATE(5796),
    [sym_dataset_section] = STATE(5796),
    [sym_requestpage_section] = STATE(5796),
    [sym_rendering_section] = STATE(5796),
    [sym_elements_section] = STATE(5796),
    [sym_schema_section] = STATE(5796),
    [sym_assembly_declaration] = STATE(5796),
    [sym_event_declaration] = STATE(5796),
    [sym_procedure] = STATE(5796),
    [sym_preproc_split_procedure] = STATE(5796),
    [sym_preproc_split_procedure_preamble] = STATE(5796),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5796),
    [sym_var_section] = STATE(5796),
    [sym_attribute_item] = STATE(5796),
    [sym_preproc_conditional] = STATE(5796),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5796),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14187),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5696)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14189),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5697)] = {
    [sym_identifier] = ACTIONS(9064),
    [anon_sym_SEMI] = ACTIONS(9066),
    [anon_sym_RBRACE] = ACTIONS(9066),
    [aux_sym_where_condition_token1] = ACTIONS(9064),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9064),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9064),
    [anon_sym_LBRACK] = ACTIONS(9066),
    [aux_sym_basic_type_token6] = ACTIONS(9064),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token53] = ACTIONS(9064),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9064),
    [aux_sym_addafter_modification_token1] = ACTIONS(9064),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9064),
    [aux_sym_modify_modification_token1] = ACTIONS(9064),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9064),
    [aux_sym_movelast_modification_token1] = ACTIONS(9064),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9064),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9064),
    [aux_sym_separator_action_token1] = ACTIONS(9064),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9064),
    [aux_sym_type_declaration_token1] = ACTIONS(9064),
    [anon_sym_POUNDif] = ACTIONS(9066),
    [anon_sym_POUNDIF] = ACTIONS(9066),
    [anon_sym_POUNDIf] = ACTIONS(9066),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9064),
    [sym_procedure_keyword] = ACTIONS(9064),
    [sym_trigger_keyword] = ACTIONS(9064),
    [sym_var_keyword] = ACTIONS(9064),
    [sym_local_keyword] = ACTIONS(9064),
    [sym_internal_keyword] = ACTIONS(9064),
    [sym_protected_keyword] = ACTIONS(9064),
    [sym_event_keyword] = ACTIONS(9064),
    [sym_fields_keyword] = ACTIONS(9064),
    [sym_keys_keyword] = ACTIONS(9064),
    [sym_key_keyword] = ACTIONS(9064),
    [sym_fieldgroups_keyword] = ACTIONS(9064),
    [sym_actions_keyword] = ACTIONS(9064),
    [sym_layout_keyword] = ACTIONS(9064),
    [sym_area_keyword] = ACTIONS(9064),
    [sym_group_keyword] = ACTIONS(9064),
    [sym_repeater_keyword] = ACTIONS(9064),
    [sym_cuegroup_keyword] = ACTIONS(9064),
    [sym_fixed_keyword] = ACTIONS(9064),
    [sym_grid_keyword] = ACTIONS(9064),
    [sym_part_keyword] = ACTIONS(9064),
    [sym_systempart_keyword] = ACTIONS(9064),
    [sym_usercontrol_keyword] = ACTIONS(9064),
    [sym_dataset_keyword] = ACTIONS(9064),
    [sym_elements_keyword] = ACTIONS(9064),
    [sym_dataitem_keyword] = ACTIONS(9064),
    [sym_column_keyword] = ACTIONS(9064),
    [sym_filter_keyword] = ACTIONS(9064),
    [sym_labels_keyword] = ACTIONS(9064),
    [sym_rendering_keyword] = ACTIONS(9064),
    [sym_requestpage_keyword] = ACTIONS(9064),
    [sym_schema_keyword] = ACTIONS(9064),
    [sym_views_keyword] = ACTIONS(9064),
    [sym_quoted_identifier] = ACTIONS(9066),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9066),
    [sym_preproc_open] = ACTIONS(9066),
    [sym_var_attribute_open] = ACTIONS(9066),
  },
  [STATE(5698)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14191),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5699)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14193),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5700)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14195),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5701)] = {
    [sym_identifier] = ACTIONS(7712),
    [anon_sym_SEMI] = ACTIONS(7715),
    [anon_sym_RBRACE] = ACTIONS(7730),
    [aux_sym_where_condition_token1] = ACTIONS(7712),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7725),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [anon_sym_LBRACK] = ACTIONS(7730),
    [aux_sym_basic_type_token22] = ACTIONS(7712),
    [aux_sym_basic_type_token53] = ACTIONS(7712),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7720),
    [aux_sym_modify_modification_token1] = ACTIONS(7727),
    [aux_sym_separator_action_token1] = ACTIONS(7712),
    [aux_sym_xmlport_element_token1] = ACTIONS(7727),
    [aux_sym_xmlport_element_token2] = ACTIONS(7727),
    [aux_sym_xmlport_element_token3] = ACTIONS(7727),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(7727),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(7727),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7720),
    [aux_sym_type_declaration_token1] = ACTIONS(7712),
    [anon_sym_POUNDif] = ACTIONS(7715),
    [anon_sym_POUNDIF] = ACTIONS(7715),
    [anon_sym_POUNDIf] = ACTIONS(7715),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7733),
    [sym_page_keyword] = ACTIONS(7725),
    [anon_sym_codeunit] = ACTIONS(7725),
    [anon_sym_CODEUNIT] = ACTIONS(7725),
    [anon_sym_Codeunit] = ACTIONS(7725),
    [anon_sym_CodeUnit] = ACTIONS(7725),
    [anon_sym_COdeunit] = ACTIONS(7725),
    [anon_sym_codeUnit] = ACTIONS(7725),
    [sym_report_keyword] = ACTIONS(7725),
    [sym_query_keyword] = ACTIONS(7725),
    [anon_sym_xmlport] = ACTIONS(7725),
    [anon_sym_XMLPORT] = ACTIONS(7725),
    [anon_sym_Xmlport] = ACTIONS(7725),
    [anon_sym_XMLport] = ACTIONS(7725),
    [anon_sym_XMLPort] = ACTIONS(7725),
    [anon_sym_XmlPort] = ACTIONS(7725),
    [sym_procedure_keyword] = ACTIONS(7727),
    [sym_trigger_keyword] = ACTIONS(7727),
    [sym_var_keyword] = ACTIONS(7727),
    [sym_local_keyword] = ACTIONS(7727),
    [sym_internal_keyword] = ACTIONS(7727),
    [sym_protected_keyword] = ACTIONS(7727),
    [sym_event_keyword] = ACTIONS(7727),
    [sym_fields_keyword] = ACTIONS(7727),
    [sym_keys_keyword] = ACTIONS(7727),
    [sym_key_keyword] = ACTIONS(7712),
    [sym_fieldgroups_keyword] = ACTIONS(7727),
    [sym_actions_keyword] = ACTIONS(7727),
    [sym_layout_keyword] = ACTIONS(7727),
    [sym_dataset_keyword] = ACTIONS(7720),
    [sym_elements_keyword] = ACTIONS(7727),
    [sym_labels_keyword] = ACTIONS(7727),
    [sym_rendering_keyword] = ACTIONS(7727),
    [sym_requestpage_keyword] = ACTIONS(7727),
    [sym_schema_keyword] = ACTIONS(7727),
    [sym_views_keyword] = ACTIONS(7727),
    [sym_quoted_identifier] = ACTIONS(7737),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7730),
    [sym_preproc_open] = ACTIONS(7715),
  },
  [STATE(5702)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14197),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5703)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14199),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5704)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14201),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5705)] = {
    [sym_identifier] = ACTIONS(9064),
    [anon_sym_SEMI] = ACTIONS(9066),
    [anon_sym_RBRACE] = ACTIONS(9066),
    [aux_sym_where_condition_token1] = ACTIONS(9064),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9064),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9064),
    [anon_sym_LBRACK] = ACTIONS(9066),
    [aux_sym_basic_type_token6] = ACTIONS(9064),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token53] = ACTIONS(9064),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9064),
    [aux_sym_addafter_modification_token1] = ACTIONS(9064),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9064),
    [aux_sym_modify_modification_token1] = ACTIONS(9064),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9064),
    [aux_sym_movelast_modification_token1] = ACTIONS(9064),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9064),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9064),
    [aux_sym_separator_action_token1] = ACTIONS(9064),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9064),
    [aux_sym_type_declaration_token1] = ACTIONS(9064),
    [anon_sym_POUNDif] = ACTIONS(9066),
    [anon_sym_POUNDIF] = ACTIONS(9066),
    [anon_sym_POUNDIf] = ACTIONS(9066),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9064),
    [sym_procedure_keyword] = ACTIONS(9064),
    [sym_trigger_keyword] = ACTIONS(9064),
    [sym_var_keyword] = ACTIONS(9064),
    [sym_local_keyword] = ACTIONS(9064),
    [sym_internal_keyword] = ACTIONS(9064),
    [sym_protected_keyword] = ACTIONS(9064),
    [sym_event_keyword] = ACTIONS(9064),
    [sym_fields_keyword] = ACTIONS(9064),
    [sym_keys_keyword] = ACTIONS(9064),
    [sym_key_keyword] = ACTIONS(9064),
    [sym_fieldgroups_keyword] = ACTIONS(9064),
    [sym_actions_keyword] = ACTIONS(9064),
    [sym_layout_keyword] = ACTIONS(9064),
    [sym_area_keyword] = ACTIONS(9064),
    [sym_group_keyword] = ACTIONS(9064),
    [sym_repeater_keyword] = ACTIONS(9064),
    [sym_cuegroup_keyword] = ACTIONS(9064),
    [sym_fixed_keyword] = ACTIONS(9064),
    [sym_grid_keyword] = ACTIONS(9064),
    [sym_part_keyword] = ACTIONS(9064),
    [sym_systempart_keyword] = ACTIONS(9064),
    [sym_usercontrol_keyword] = ACTIONS(9064),
    [sym_dataset_keyword] = ACTIONS(9064),
    [sym_elements_keyword] = ACTIONS(9064),
    [sym_dataitem_keyword] = ACTIONS(9064),
    [sym_column_keyword] = ACTIONS(9064),
    [sym_filter_keyword] = ACTIONS(9064),
    [sym_labels_keyword] = ACTIONS(9064),
    [sym_rendering_keyword] = ACTIONS(9064),
    [sym_requestpage_keyword] = ACTIONS(9064),
    [sym_schema_keyword] = ACTIONS(9064),
    [sym_views_keyword] = ACTIONS(9064),
    [sym_quoted_identifier] = ACTIONS(9066),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9066),
    [sym_preproc_open] = ACTIONS(9066),
    [sym_var_attribute_open] = ACTIONS(9066),
  },
  [STATE(5706)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14203),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5707)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [anon_sym_RBRACE] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9068),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_addafter_modification_token1] = ACTIONS(9068),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9068),
    [aux_sym_movelast_modification_token1] = ACTIONS(9068),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9068),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_area_keyword] = ACTIONS(9068),
    [sym_group_keyword] = ACTIONS(9068),
    [sym_repeater_keyword] = ACTIONS(9068),
    [sym_cuegroup_keyword] = ACTIONS(9068),
    [sym_fixed_keyword] = ACTIONS(9068),
    [sym_grid_keyword] = ACTIONS(9068),
    [sym_part_keyword] = ACTIONS(9068),
    [sym_systempart_keyword] = ACTIONS(9068),
    [sym_usercontrol_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_dataitem_keyword] = ACTIONS(9068),
    [sym_column_keyword] = ACTIONS(9068),
    [sym_filter_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(5708)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [anon_sym_RBRACE] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9068),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_addafter_modification_token1] = ACTIONS(9068),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9068),
    [aux_sym_movelast_modification_token1] = ACTIONS(9068),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9068),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_area_keyword] = ACTIONS(9068),
    [sym_group_keyword] = ACTIONS(9068),
    [sym_repeater_keyword] = ACTIONS(9068),
    [sym_cuegroup_keyword] = ACTIONS(9068),
    [sym_fixed_keyword] = ACTIONS(9068),
    [sym_grid_keyword] = ACTIONS(9068),
    [sym_part_keyword] = ACTIONS(9068),
    [sym_systempart_keyword] = ACTIONS(9068),
    [sym_usercontrol_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_dataitem_keyword] = ACTIONS(9068),
    [sym_column_keyword] = ACTIONS(9068),
    [sym_filter_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(5709)] = {
    [sym__body_element] = STATE(5501),
    [sym_empty_statement] = STATE(5501),
    [sym_property] = STATE(5501),
    [sym_permissions_property] = STATE(5501),
    [sym_table_relation_property] = STATE(5501),
    [sym_fields_section] = STATE(5501),
    [sym_keys_section] = STATE(5501),
    [sym_fieldgroups_section] = STATE(5501),
    [sym_enum_value_declaration] = STATE(5501),
    [sym_labels_section] = STATE(5501),
    [sym_layout_section] = STATE(5501),
    [sym_modify_modification] = STATE(5501),
    [sym_actions_section] = STATE(5501),
    [sym_views_section] = STATE(5501),
    [sym_dataset_section] = STATE(5501),
    [sym_requestpage_section] = STATE(5501),
    [sym_rendering_section] = STATE(5501),
    [sym_elements_section] = STATE(5501),
    [sym_schema_section] = STATE(5501),
    [sym_assembly_declaration] = STATE(5501),
    [sym_event_declaration] = STATE(5501),
    [sym_procedure] = STATE(5501),
    [sym_preproc_split_procedure] = STATE(5501),
    [sym_preproc_split_procedure_preamble] = STATE(5501),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5501),
    [sym_var_section] = STATE(5501),
    [sym_attribute_item] = STATE(5501),
    [sym_preproc_conditional] = STATE(5501),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5501),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14205),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5710)] = {
    [sym__body_element] = STATE(5775),
    [sym_empty_statement] = STATE(5775),
    [sym_property] = STATE(5775),
    [sym_permissions_property] = STATE(5775),
    [sym_table_relation_property] = STATE(5775),
    [sym_fields_section] = STATE(5775),
    [sym_keys_section] = STATE(5775),
    [sym_fieldgroups_section] = STATE(5775),
    [sym_enum_value_declaration] = STATE(5775),
    [sym_labels_section] = STATE(5775),
    [sym_layout_section] = STATE(5775),
    [sym_modify_modification] = STATE(5775),
    [sym_actions_section] = STATE(5775),
    [sym_views_section] = STATE(5775),
    [sym_dataset_section] = STATE(5775),
    [sym_requestpage_section] = STATE(5775),
    [sym_rendering_section] = STATE(5775),
    [sym_elements_section] = STATE(5775),
    [sym_schema_section] = STATE(5775),
    [sym_assembly_declaration] = STATE(5775),
    [sym_event_declaration] = STATE(5775),
    [sym_procedure] = STATE(5775),
    [sym_preproc_split_procedure] = STATE(5775),
    [sym_preproc_split_procedure_preamble] = STATE(5775),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5775),
    [sym_var_section] = STATE(5775),
    [sym_attribute_item] = STATE(5775),
    [sym_preproc_conditional] = STATE(5775),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5775),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14207),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5711)] = {
    [sym__body_element] = STATE(5576),
    [sym_empty_statement] = STATE(5576),
    [sym_property] = STATE(5576),
    [sym_permissions_property] = STATE(5576),
    [sym_table_relation_property] = STATE(5576),
    [sym_fields_section] = STATE(5576),
    [sym_keys_section] = STATE(5576),
    [sym_fieldgroups_section] = STATE(5576),
    [sym_enum_value_declaration] = STATE(5576),
    [sym_labels_section] = STATE(5576),
    [sym_layout_section] = STATE(5576),
    [sym_modify_modification] = STATE(5576),
    [sym_actions_section] = STATE(5576),
    [sym_views_section] = STATE(5576),
    [sym_dataset_section] = STATE(5576),
    [sym_requestpage_section] = STATE(5576),
    [sym_rendering_section] = STATE(5576),
    [sym_elements_section] = STATE(5576),
    [sym_schema_section] = STATE(5576),
    [sym_assembly_declaration] = STATE(5576),
    [sym_event_declaration] = STATE(5576),
    [sym_procedure] = STATE(5576),
    [sym_preproc_split_procedure] = STATE(5576),
    [sym_preproc_split_procedure_preamble] = STATE(5576),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5576),
    [sym_var_section] = STATE(5576),
    [sym_attribute_item] = STATE(5576),
    [sym_preproc_conditional] = STATE(5576),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5576),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14209),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5712)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(14211),
    [anon_sym_RBRACE] = ACTIONS(6122),
    [aux_sym_where_condition_token1] = ACTIONS(6118),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6118),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_basic_type_token6] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token53] = ACTIONS(6118),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6118),
    [aux_sym_addafter_modification_token1] = ACTIONS(6118),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6118),
    [aux_sym_modify_modification_token1] = ACTIONS(6118),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6118),
    [aux_sym_movelast_modification_token1] = ACTIONS(6118),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6118),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6118),
    [aux_sym_separator_action_token1] = ACTIONS(6118),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6118),
    [aux_sym_type_declaration_token1] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6118),
    [sym_procedure_keyword] = ACTIONS(6118),
    [sym_trigger_keyword] = ACTIONS(6118),
    [sym_var_keyword] = ACTIONS(6118),
    [sym_local_keyword] = ACTIONS(6118),
    [sym_internal_keyword] = ACTIONS(6118),
    [sym_protected_keyword] = ACTIONS(6118),
    [sym_event_keyword] = ACTIONS(6118),
    [sym_fields_keyword] = ACTIONS(6118),
    [sym_keys_keyword] = ACTIONS(6118),
    [sym_key_keyword] = ACTIONS(6118),
    [sym_fieldgroups_keyword] = ACTIONS(6118),
    [sym_actions_keyword] = ACTIONS(6118),
    [sym_layout_keyword] = ACTIONS(6118),
    [sym_area_keyword] = ACTIONS(6118),
    [sym_group_keyword] = ACTIONS(6118),
    [sym_repeater_keyword] = ACTIONS(6118),
    [sym_cuegroup_keyword] = ACTIONS(6118),
    [sym_fixed_keyword] = ACTIONS(6118),
    [sym_grid_keyword] = ACTIONS(6118),
    [sym_part_keyword] = ACTIONS(6118),
    [sym_systempart_keyword] = ACTIONS(6118),
    [sym_usercontrol_keyword] = ACTIONS(6118),
    [sym_dataset_keyword] = ACTIONS(6118),
    [sym_elements_keyword] = ACTIONS(6118),
    [sym_dataitem_keyword] = ACTIONS(6118),
    [sym_column_keyword] = ACTIONS(6118),
    [sym_filter_keyword] = ACTIONS(6118),
    [sym_labels_keyword] = ACTIONS(6118),
    [sym_rendering_keyword] = ACTIONS(6118),
    [sym_requestpage_keyword] = ACTIONS(6118),
    [sym_schema_keyword] = ACTIONS(6118),
    [sym_views_keyword] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_var_attribute_open] = ACTIONS(6122),
  },
  [STATE(5713)] = {
    [sym__body_element] = STATE(5841),
    [sym_empty_statement] = STATE(5841),
    [sym_property] = STATE(5841),
    [sym_permissions_property] = STATE(5841),
    [sym_table_relation_property] = STATE(5841),
    [sym_fields_section] = STATE(5841),
    [sym_keys_section] = STATE(5841),
    [sym_fieldgroups_section] = STATE(5841),
    [sym_enum_value_declaration] = STATE(5841),
    [sym_labels_section] = STATE(5841),
    [sym_layout_section] = STATE(5841),
    [sym_modify_modification] = STATE(5841),
    [sym_actions_section] = STATE(5841),
    [sym_views_section] = STATE(5841),
    [sym_dataset_section] = STATE(5841),
    [sym_requestpage_section] = STATE(5841),
    [sym_rendering_section] = STATE(5841),
    [sym_elements_section] = STATE(5841),
    [sym_schema_section] = STATE(5841),
    [sym_assembly_declaration] = STATE(5841),
    [sym_event_declaration] = STATE(5841),
    [sym_procedure] = STATE(5841),
    [sym_preproc_split_procedure] = STATE(5841),
    [sym_preproc_split_procedure_preamble] = STATE(5841),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5841),
    [sym_var_section] = STATE(5841),
    [sym_attribute_item] = STATE(5841),
    [sym_preproc_conditional] = STATE(5841),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5841),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14213),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5714)] = {
    [sym__body_element] = STATE(5664),
    [sym_empty_statement] = STATE(5664),
    [sym_property] = STATE(5664),
    [sym_permissions_property] = STATE(5664),
    [sym_table_relation_property] = STATE(5664),
    [sym_fields_section] = STATE(5664),
    [sym_keys_section] = STATE(5664),
    [sym_fieldgroups_section] = STATE(5664),
    [sym_enum_value_declaration] = STATE(5664),
    [sym_labels_section] = STATE(5664),
    [sym_layout_section] = STATE(5664),
    [sym_modify_modification] = STATE(5664),
    [sym_actions_section] = STATE(5664),
    [sym_views_section] = STATE(5664),
    [sym_dataset_section] = STATE(5664),
    [sym_requestpage_section] = STATE(5664),
    [sym_rendering_section] = STATE(5664),
    [sym_elements_section] = STATE(5664),
    [sym_schema_section] = STATE(5664),
    [sym_assembly_declaration] = STATE(5664),
    [sym_event_declaration] = STATE(5664),
    [sym_procedure] = STATE(5664),
    [sym_preproc_split_procedure] = STATE(5664),
    [sym_preproc_split_procedure_preamble] = STATE(5664),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5664),
    [sym_var_section] = STATE(5664),
    [sym_attribute_item] = STATE(5664),
    [sym_preproc_conditional] = STATE(5664),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5664),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14215),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5715)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14217),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5716)] = {
    [sym__body_element] = STATE(5700),
    [sym_empty_statement] = STATE(5700),
    [sym_property] = STATE(5700),
    [sym_permissions_property] = STATE(5700),
    [sym_table_relation_property] = STATE(5700),
    [sym_fields_section] = STATE(5700),
    [sym_keys_section] = STATE(5700),
    [sym_fieldgroups_section] = STATE(5700),
    [sym_enum_value_declaration] = STATE(5700),
    [sym_labels_section] = STATE(5700),
    [sym_layout_section] = STATE(5700),
    [sym_modify_modification] = STATE(5700),
    [sym_actions_section] = STATE(5700),
    [sym_views_section] = STATE(5700),
    [sym_dataset_section] = STATE(5700),
    [sym_requestpage_section] = STATE(5700),
    [sym_rendering_section] = STATE(5700),
    [sym_elements_section] = STATE(5700),
    [sym_schema_section] = STATE(5700),
    [sym_assembly_declaration] = STATE(5700),
    [sym_event_declaration] = STATE(5700),
    [sym_procedure] = STATE(5700),
    [sym_preproc_split_procedure] = STATE(5700),
    [sym_preproc_split_procedure_preamble] = STATE(5700),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5700),
    [sym_var_section] = STATE(5700),
    [sym_attribute_item] = STATE(5700),
    [sym_preproc_conditional] = STATE(5700),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5700),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14219),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5717)] = {
    [sym__body_element] = STATE(5777),
    [sym_empty_statement] = STATE(5777),
    [sym_property] = STATE(5777),
    [sym_permissions_property] = STATE(5777),
    [sym_table_relation_property] = STATE(5777),
    [sym_fields_section] = STATE(5777),
    [sym_keys_section] = STATE(5777),
    [sym_fieldgroups_section] = STATE(5777),
    [sym_enum_value_declaration] = STATE(5777),
    [sym_labels_section] = STATE(5777),
    [sym_layout_section] = STATE(5777),
    [sym_modify_modification] = STATE(5777),
    [sym_actions_section] = STATE(5777),
    [sym_views_section] = STATE(5777),
    [sym_dataset_section] = STATE(5777),
    [sym_requestpage_section] = STATE(5777),
    [sym_rendering_section] = STATE(5777),
    [sym_elements_section] = STATE(5777),
    [sym_schema_section] = STATE(5777),
    [sym_assembly_declaration] = STATE(5777),
    [sym_event_declaration] = STATE(5777),
    [sym_procedure] = STATE(5777),
    [sym_preproc_split_procedure] = STATE(5777),
    [sym_preproc_split_procedure_preamble] = STATE(5777),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5777),
    [sym_var_section] = STATE(5777),
    [sym_attribute_item] = STATE(5777),
    [sym_preproc_conditional] = STATE(5777),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5777),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14221),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5718)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14223),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5719)] = {
    [sym_identifier] = ACTIONS(9056),
    [anon_sym_SEMI] = ACTIONS(9058),
    [anon_sym_RBRACE] = ACTIONS(9058),
    [aux_sym_where_condition_token1] = ACTIONS(9056),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9056),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9056),
    [anon_sym_LBRACK] = ACTIONS(9058),
    [aux_sym_basic_type_token6] = ACTIONS(9056),
    [aux_sym_basic_type_token22] = ACTIONS(9056),
    [aux_sym_basic_type_token53] = ACTIONS(9056),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9056),
    [aux_sym_addafter_modification_token1] = ACTIONS(9056),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9056),
    [aux_sym_modify_modification_token1] = ACTIONS(9056),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9056),
    [aux_sym_movelast_modification_token1] = ACTIONS(9056),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9056),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9056),
    [aux_sym_separator_action_token1] = ACTIONS(9056),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9056),
    [aux_sym_type_declaration_token1] = ACTIONS(9056),
    [anon_sym_POUNDif] = ACTIONS(9058),
    [anon_sym_POUNDIF] = ACTIONS(9058),
    [anon_sym_POUNDIf] = ACTIONS(9058),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9056),
    [sym_procedure_keyword] = ACTIONS(9056),
    [sym_trigger_keyword] = ACTIONS(9056),
    [sym_var_keyword] = ACTIONS(9056),
    [sym_local_keyword] = ACTIONS(9056),
    [sym_internal_keyword] = ACTIONS(9056),
    [sym_protected_keyword] = ACTIONS(9056),
    [sym_event_keyword] = ACTIONS(9056),
    [sym_fields_keyword] = ACTIONS(9056),
    [sym_keys_keyword] = ACTIONS(9056),
    [sym_key_keyword] = ACTIONS(9056),
    [sym_fieldgroups_keyword] = ACTIONS(9056),
    [sym_actions_keyword] = ACTIONS(9056),
    [sym_layout_keyword] = ACTIONS(9056),
    [sym_area_keyword] = ACTIONS(9056),
    [sym_group_keyword] = ACTIONS(9056),
    [sym_repeater_keyword] = ACTIONS(9056),
    [sym_cuegroup_keyword] = ACTIONS(9056),
    [sym_fixed_keyword] = ACTIONS(9056),
    [sym_grid_keyword] = ACTIONS(9056),
    [sym_part_keyword] = ACTIONS(9056),
    [sym_systempart_keyword] = ACTIONS(9056),
    [sym_usercontrol_keyword] = ACTIONS(9056),
    [sym_dataset_keyword] = ACTIONS(9056),
    [sym_elements_keyword] = ACTIONS(9056),
    [sym_dataitem_keyword] = ACTIONS(9056),
    [sym_column_keyword] = ACTIONS(9056),
    [sym_filter_keyword] = ACTIONS(9056),
    [sym_labels_keyword] = ACTIONS(9056),
    [sym_rendering_keyword] = ACTIONS(9056),
    [sym_requestpage_keyword] = ACTIONS(9056),
    [sym_schema_keyword] = ACTIONS(9056),
    [sym_views_keyword] = ACTIONS(9056),
    [sym_quoted_identifier] = ACTIONS(9058),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9058),
    [sym_preproc_open] = ACTIONS(9058),
    [sym_var_attribute_open] = ACTIONS(9058),
  },
  [STATE(5720)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14225),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5721)] = {
    [sym__body_element] = STATE(5778),
    [sym_empty_statement] = STATE(5778),
    [sym_property] = STATE(5778),
    [sym_permissions_property] = STATE(5778),
    [sym_table_relation_property] = STATE(5778),
    [sym_fields_section] = STATE(5778),
    [sym_keys_section] = STATE(5778),
    [sym_fieldgroups_section] = STATE(5778),
    [sym_enum_value_declaration] = STATE(5778),
    [sym_labels_section] = STATE(5778),
    [sym_layout_section] = STATE(5778),
    [sym_modify_modification] = STATE(5778),
    [sym_actions_section] = STATE(5778),
    [sym_views_section] = STATE(5778),
    [sym_dataset_section] = STATE(5778),
    [sym_requestpage_section] = STATE(5778),
    [sym_rendering_section] = STATE(5778),
    [sym_elements_section] = STATE(5778),
    [sym_schema_section] = STATE(5778),
    [sym_assembly_declaration] = STATE(5778),
    [sym_event_declaration] = STATE(5778),
    [sym_procedure] = STATE(5778),
    [sym_preproc_split_procedure] = STATE(5778),
    [sym_preproc_split_procedure_preamble] = STATE(5778),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5778),
    [sym_var_section] = STATE(5778),
    [sym_attribute_item] = STATE(5778),
    [sym_preproc_conditional] = STATE(5778),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5778),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14227),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5722)] = {
    [sym__body_element] = STATE(5779),
    [sym_empty_statement] = STATE(5779),
    [sym_property] = STATE(5779),
    [sym_permissions_property] = STATE(5779),
    [sym_table_relation_property] = STATE(5779),
    [sym_fields_section] = STATE(5779),
    [sym_keys_section] = STATE(5779),
    [sym_fieldgroups_section] = STATE(5779),
    [sym_enum_value_declaration] = STATE(5779),
    [sym_labels_section] = STATE(5779),
    [sym_layout_section] = STATE(5779),
    [sym_modify_modification] = STATE(5779),
    [sym_actions_section] = STATE(5779),
    [sym_views_section] = STATE(5779),
    [sym_dataset_section] = STATE(5779),
    [sym_requestpage_section] = STATE(5779),
    [sym_rendering_section] = STATE(5779),
    [sym_elements_section] = STATE(5779),
    [sym_schema_section] = STATE(5779),
    [sym_assembly_declaration] = STATE(5779),
    [sym_event_declaration] = STATE(5779),
    [sym_procedure] = STATE(5779),
    [sym_preproc_split_procedure] = STATE(5779),
    [sym_preproc_split_procedure_preamble] = STATE(5779),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5779),
    [sym_var_section] = STATE(5779),
    [sym_attribute_item] = STATE(5779),
    [sym_preproc_conditional] = STATE(5779),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5779),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14229),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5723)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14231),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5724)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14233),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5725)] = {
    [sym__body_element] = STATE(5848),
    [sym_empty_statement] = STATE(5848),
    [sym_property] = STATE(5848),
    [sym_permissions_property] = STATE(5848),
    [sym_table_relation_property] = STATE(5848),
    [sym_fields_section] = STATE(5848),
    [sym_keys_section] = STATE(5848),
    [sym_fieldgroups_section] = STATE(5848),
    [sym_enum_value_declaration] = STATE(5848),
    [sym_labels_section] = STATE(5848),
    [sym_layout_section] = STATE(5848),
    [sym_modify_modification] = STATE(5848),
    [sym_actions_section] = STATE(5848),
    [sym_views_section] = STATE(5848),
    [sym_dataset_section] = STATE(5848),
    [sym_requestpage_section] = STATE(5848),
    [sym_rendering_section] = STATE(5848),
    [sym_elements_section] = STATE(5848),
    [sym_schema_section] = STATE(5848),
    [sym_assembly_declaration] = STATE(5848),
    [sym_event_declaration] = STATE(5848),
    [sym_procedure] = STATE(5848),
    [sym_preproc_split_procedure] = STATE(5848),
    [sym_preproc_split_procedure_preamble] = STATE(5848),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5848),
    [sym_var_section] = STATE(5848),
    [sym_attribute_item] = STATE(5848),
    [sym_preproc_conditional] = STATE(5848),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5848),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14235),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5726)] = {
    [sym__body_element] = STATE(5780),
    [sym_empty_statement] = STATE(5780),
    [sym_property] = STATE(5780),
    [sym_permissions_property] = STATE(5780),
    [sym_table_relation_property] = STATE(5780),
    [sym_fields_section] = STATE(5780),
    [sym_keys_section] = STATE(5780),
    [sym_fieldgroups_section] = STATE(5780),
    [sym_enum_value_declaration] = STATE(5780),
    [sym_labels_section] = STATE(5780),
    [sym_layout_section] = STATE(5780),
    [sym_modify_modification] = STATE(5780),
    [sym_actions_section] = STATE(5780),
    [sym_views_section] = STATE(5780),
    [sym_dataset_section] = STATE(5780),
    [sym_requestpage_section] = STATE(5780),
    [sym_rendering_section] = STATE(5780),
    [sym_elements_section] = STATE(5780),
    [sym_schema_section] = STATE(5780),
    [sym_assembly_declaration] = STATE(5780),
    [sym_event_declaration] = STATE(5780),
    [sym_procedure] = STATE(5780),
    [sym_preproc_split_procedure] = STATE(5780),
    [sym_preproc_split_procedure_preamble] = STATE(5780),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5780),
    [sym_var_section] = STATE(5780),
    [sym_attribute_item] = STATE(5780),
    [sym_preproc_conditional] = STATE(5780),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5780),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14237),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5727)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [anon_sym_RBRACE] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9068),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token6] = ACTIONS(9068),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_addafter_modification_token1] = ACTIONS(9068),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9068),
    [aux_sym_movelast_modification_token1] = ACTIONS(9068),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9068),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_area_keyword] = ACTIONS(9068),
    [sym_group_keyword] = ACTIONS(9068),
    [sym_repeater_keyword] = ACTIONS(9068),
    [sym_cuegroup_keyword] = ACTIONS(9068),
    [sym_fixed_keyword] = ACTIONS(9068),
    [sym_grid_keyword] = ACTIONS(9068),
    [sym_part_keyword] = ACTIONS(9068),
    [sym_systempart_keyword] = ACTIONS(9068),
    [sym_usercontrol_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_dataitem_keyword] = ACTIONS(9068),
    [sym_column_keyword] = ACTIONS(9068),
    [sym_filter_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(5728)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(6122),
    [anon_sym_RBRACE] = ACTIONS(6122),
    [aux_sym_where_condition_token1] = ACTIONS(6118),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6118),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_basic_type_token6] = ACTIONS(6118),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token53] = ACTIONS(6118),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6118),
    [aux_sym_addafter_modification_token1] = ACTIONS(6118),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6118),
    [aux_sym_modify_modification_token1] = ACTIONS(6118),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6118),
    [aux_sym_movelast_modification_token1] = ACTIONS(6118),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6118),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6118),
    [aux_sym_separator_action_token1] = ACTIONS(6118),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6118),
    [aux_sym_type_declaration_token1] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6118),
    [sym_procedure_keyword] = ACTIONS(6118),
    [sym_trigger_keyword] = ACTIONS(6118),
    [sym_var_keyword] = ACTIONS(6118),
    [sym_local_keyword] = ACTIONS(6118),
    [sym_internal_keyword] = ACTIONS(6118),
    [sym_protected_keyword] = ACTIONS(6118),
    [sym_event_keyword] = ACTIONS(6118),
    [sym_fields_keyword] = ACTIONS(6118),
    [sym_keys_keyword] = ACTIONS(6118),
    [sym_key_keyword] = ACTIONS(6118),
    [sym_fieldgroups_keyword] = ACTIONS(6118),
    [sym_actions_keyword] = ACTIONS(6118),
    [sym_layout_keyword] = ACTIONS(6118),
    [sym_area_keyword] = ACTIONS(6118),
    [sym_group_keyword] = ACTIONS(6118),
    [sym_repeater_keyword] = ACTIONS(6118),
    [sym_cuegroup_keyword] = ACTIONS(6118),
    [sym_fixed_keyword] = ACTIONS(6118),
    [sym_grid_keyword] = ACTIONS(6118),
    [sym_part_keyword] = ACTIONS(6118),
    [sym_systempart_keyword] = ACTIONS(6118),
    [sym_usercontrol_keyword] = ACTIONS(6118),
    [sym_dataset_keyword] = ACTIONS(6118),
    [sym_elements_keyword] = ACTIONS(6118),
    [sym_dataitem_keyword] = ACTIONS(6118),
    [sym_column_keyword] = ACTIONS(6118),
    [sym_filter_keyword] = ACTIONS(6118),
    [sym_labels_keyword] = ACTIONS(6118),
    [sym_rendering_keyword] = ACTIONS(6118),
    [sym_requestpage_keyword] = ACTIONS(6118),
    [sym_schema_keyword] = ACTIONS(6118),
    [sym_views_keyword] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_var_attribute_open] = ACTIONS(6122),
  },
  [STATE(5729)] = {
    [sym__body_element] = STATE(5525),
    [sym_empty_statement] = STATE(5525),
    [sym_property] = STATE(5525),
    [sym_permissions_property] = STATE(5525),
    [sym_table_relation_property] = STATE(5525),
    [sym_fields_section] = STATE(5525),
    [sym_keys_section] = STATE(5525),
    [sym_fieldgroups_section] = STATE(5525),
    [sym_enum_value_declaration] = STATE(5525),
    [sym_labels_section] = STATE(5525),
    [sym_layout_section] = STATE(5525),
    [sym_modify_modification] = STATE(5525),
    [sym_actions_section] = STATE(5525),
    [sym_views_section] = STATE(5525),
    [sym_dataset_section] = STATE(5525),
    [sym_requestpage_section] = STATE(5525),
    [sym_rendering_section] = STATE(5525),
    [sym_elements_section] = STATE(5525),
    [sym_schema_section] = STATE(5525),
    [sym_assembly_declaration] = STATE(5525),
    [sym_event_declaration] = STATE(5525),
    [sym_procedure] = STATE(5525),
    [sym_preproc_split_procedure] = STATE(5525),
    [sym_preproc_split_procedure_preamble] = STATE(5525),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5525),
    [sym_var_section] = STATE(5525),
    [sym_attribute_item] = STATE(5525),
    [sym_preproc_conditional] = STATE(5525),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5525),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14239),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5730)] = {
    [sym__body_element] = STATE(5715),
    [sym_empty_statement] = STATE(5715),
    [sym_property] = STATE(5715),
    [sym_permissions_property] = STATE(5715),
    [sym_table_relation_property] = STATE(5715),
    [sym_fields_section] = STATE(5715),
    [sym_keys_section] = STATE(5715),
    [sym_fieldgroups_section] = STATE(5715),
    [sym_enum_value_declaration] = STATE(5715),
    [sym_labels_section] = STATE(5715),
    [sym_layout_section] = STATE(5715),
    [sym_modify_modification] = STATE(5715),
    [sym_actions_section] = STATE(5715),
    [sym_views_section] = STATE(5715),
    [sym_dataset_section] = STATE(5715),
    [sym_requestpage_section] = STATE(5715),
    [sym_rendering_section] = STATE(5715),
    [sym_elements_section] = STATE(5715),
    [sym_schema_section] = STATE(5715),
    [sym_assembly_declaration] = STATE(5715),
    [sym_event_declaration] = STATE(5715),
    [sym_procedure] = STATE(5715),
    [sym_preproc_split_procedure] = STATE(5715),
    [sym_preproc_split_procedure_preamble] = STATE(5715),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5715),
    [sym_var_section] = STATE(5715),
    [sym_attribute_item] = STATE(5715),
    [sym_preproc_conditional] = STATE(5715),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5715),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14241),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5731)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14243),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5732)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14245),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5733)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14247),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5734)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14249),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5735)] = {
    [sym__body_element] = STATE(5789),
    [sym_empty_statement] = STATE(5789),
    [sym_property] = STATE(5789),
    [sym_permissions_property] = STATE(5789),
    [sym_table_relation_property] = STATE(5789),
    [sym_fields_section] = STATE(5789),
    [sym_keys_section] = STATE(5789),
    [sym_fieldgroups_section] = STATE(5789),
    [sym_enum_value_declaration] = STATE(5789),
    [sym_labels_section] = STATE(5789),
    [sym_layout_section] = STATE(5789),
    [sym_modify_modification] = STATE(5789),
    [sym_actions_section] = STATE(5789),
    [sym_views_section] = STATE(5789),
    [sym_dataset_section] = STATE(5789),
    [sym_requestpage_section] = STATE(5789),
    [sym_rendering_section] = STATE(5789),
    [sym_elements_section] = STATE(5789),
    [sym_schema_section] = STATE(5789),
    [sym_assembly_declaration] = STATE(5789),
    [sym_event_declaration] = STATE(5789),
    [sym_procedure] = STATE(5789),
    [sym_preproc_split_procedure] = STATE(5789),
    [sym_preproc_split_procedure_preamble] = STATE(5789),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5789),
    [sym_var_section] = STATE(5789),
    [sym_attribute_item] = STATE(5789),
    [sym_preproc_conditional] = STATE(5789),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5789),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14251),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5736)] = {
    [sym_identifier] = ACTIONS(9060),
    [anon_sym_SEMI] = ACTIONS(9062),
    [anon_sym_RBRACE] = ACTIONS(9062),
    [aux_sym_where_condition_token1] = ACTIONS(9060),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9060),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9060),
    [anon_sym_LBRACK] = ACTIONS(9062),
    [aux_sym_basic_type_token6] = ACTIONS(9060),
    [aux_sym_basic_type_token22] = ACTIONS(9060),
    [aux_sym_basic_type_token53] = ACTIONS(9060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9060),
    [aux_sym_addafter_modification_token1] = ACTIONS(9060),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9060),
    [aux_sym_modify_modification_token1] = ACTIONS(9060),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9060),
    [aux_sym_movelast_modification_token1] = ACTIONS(9060),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9060),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9060),
    [aux_sym_separator_action_token1] = ACTIONS(9060),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9060),
    [aux_sym_type_declaration_token1] = ACTIONS(9060),
    [anon_sym_POUNDif] = ACTIONS(9062),
    [anon_sym_POUNDIF] = ACTIONS(9062),
    [anon_sym_POUNDIf] = ACTIONS(9062),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9060),
    [sym_procedure_keyword] = ACTIONS(9060),
    [sym_trigger_keyword] = ACTIONS(9060),
    [sym_var_keyword] = ACTIONS(9060),
    [sym_local_keyword] = ACTIONS(9060),
    [sym_internal_keyword] = ACTIONS(9060),
    [sym_protected_keyword] = ACTIONS(9060),
    [sym_event_keyword] = ACTIONS(9060),
    [sym_fields_keyword] = ACTIONS(9060),
    [sym_keys_keyword] = ACTIONS(9060),
    [sym_key_keyword] = ACTIONS(9060),
    [sym_fieldgroups_keyword] = ACTIONS(9060),
    [sym_actions_keyword] = ACTIONS(9060),
    [sym_layout_keyword] = ACTIONS(9060),
    [sym_area_keyword] = ACTIONS(9060),
    [sym_group_keyword] = ACTIONS(9060),
    [sym_repeater_keyword] = ACTIONS(9060),
    [sym_cuegroup_keyword] = ACTIONS(9060),
    [sym_fixed_keyword] = ACTIONS(9060),
    [sym_grid_keyword] = ACTIONS(9060),
    [sym_part_keyword] = ACTIONS(9060),
    [sym_systempart_keyword] = ACTIONS(9060),
    [sym_usercontrol_keyword] = ACTIONS(9060),
    [sym_dataset_keyword] = ACTIONS(9060),
    [sym_elements_keyword] = ACTIONS(9060),
    [sym_dataitem_keyword] = ACTIONS(9060),
    [sym_column_keyword] = ACTIONS(9060),
    [sym_filter_keyword] = ACTIONS(9060),
    [sym_labels_keyword] = ACTIONS(9060),
    [sym_rendering_keyword] = ACTIONS(9060),
    [sym_requestpage_keyword] = ACTIONS(9060),
    [sym_schema_keyword] = ACTIONS(9060),
    [sym_views_keyword] = ACTIONS(9060),
    [sym_quoted_identifier] = ACTIONS(9062),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9062),
    [sym_preproc_open] = ACTIONS(9062),
    [sym_var_attribute_open] = ACTIONS(9062),
  },
  [STATE(5737)] = {
    [sym__body_element] = STATE(5605),
    [sym_empty_statement] = STATE(5605),
    [sym_property] = STATE(5605),
    [sym_permissions_property] = STATE(5605),
    [sym_table_relation_property] = STATE(5605),
    [sym_fields_section] = STATE(5605),
    [sym_keys_section] = STATE(5605),
    [sym_fieldgroups_section] = STATE(5605),
    [sym_enum_value_declaration] = STATE(5605),
    [sym_labels_section] = STATE(5605),
    [sym_layout_section] = STATE(5605),
    [sym_modify_modification] = STATE(5605),
    [sym_actions_section] = STATE(5605),
    [sym_views_section] = STATE(5605),
    [sym_dataset_section] = STATE(5605),
    [sym_requestpage_section] = STATE(5605),
    [sym_rendering_section] = STATE(5605),
    [sym_elements_section] = STATE(5605),
    [sym_schema_section] = STATE(5605),
    [sym_assembly_declaration] = STATE(5605),
    [sym_event_declaration] = STATE(5605),
    [sym_procedure] = STATE(5605),
    [sym_preproc_split_procedure] = STATE(5605),
    [sym_preproc_split_procedure_preamble] = STATE(5605),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5605),
    [sym_var_section] = STATE(5605),
    [sym_attribute_item] = STATE(5605),
    [sym_preproc_conditional] = STATE(5605),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5605),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14253),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5738)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14255),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5739)] = {
    [sym__body_element] = STATE(5798),
    [sym_empty_statement] = STATE(5798),
    [sym_property] = STATE(5798),
    [sym_permissions_property] = STATE(5798),
    [sym_table_relation_property] = STATE(5798),
    [sym_fields_section] = STATE(5798),
    [sym_keys_section] = STATE(5798),
    [sym_fieldgroups_section] = STATE(5798),
    [sym_enum_value_declaration] = STATE(5798),
    [sym_labels_section] = STATE(5798),
    [sym_layout_section] = STATE(5798),
    [sym_modify_modification] = STATE(5798),
    [sym_actions_section] = STATE(5798),
    [sym_views_section] = STATE(5798),
    [sym_dataset_section] = STATE(5798),
    [sym_requestpage_section] = STATE(5798),
    [sym_rendering_section] = STATE(5798),
    [sym_elements_section] = STATE(5798),
    [sym_schema_section] = STATE(5798),
    [sym_assembly_declaration] = STATE(5798),
    [sym_event_declaration] = STATE(5798),
    [sym_procedure] = STATE(5798),
    [sym_preproc_split_procedure] = STATE(5798),
    [sym_preproc_split_procedure_preamble] = STATE(5798),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5798),
    [sym_var_section] = STATE(5798),
    [sym_attribute_item] = STATE(5798),
    [sym_preproc_conditional] = STATE(5798),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5798),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14257),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5740)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [anon_sym_RBRACE] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8905),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_addafter_modification_token1] = ACTIONS(8905),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8905),
    [aux_sym_movelast_modification_token1] = ACTIONS(8905),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8905),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_area_keyword] = ACTIONS(8905),
    [sym_group_keyword] = ACTIONS(8905),
    [sym_repeater_keyword] = ACTIONS(8905),
    [sym_cuegroup_keyword] = ACTIONS(8905),
    [sym_fixed_keyword] = ACTIONS(8905),
    [sym_grid_keyword] = ACTIONS(8905),
    [sym_part_keyword] = ACTIONS(8905),
    [sym_systempart_keyword] = ACTIONS(8905),
    [sym_usercontrol_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_dataitem_keyword] = ACTIONS(8905),
    [sym_column_keyword] = ACTIONS(8905),
    [sym_filter_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(5741)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [anon_sym_RBRACE] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8905),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_addafter_modification_token1] = ACTIONS(8905),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8905),
    [aux_sym_movelast_modification_token1] = ACTIONS(8905),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8905),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_area_keyword] = ACTIONS(8905),
    [sym_group_keyword] = ACTIONS(8905),
    [sym_repeater_keyword] = ACTIONS(8905),
    [sym_cuegroup_keyword] = ACTIONS(8905),
    [sym_fixed_keyword] = ACTIONS(8905),
    [sym_grid_keyword] = ACTIONS(8905),
    [sym_part_keyword] = ACTIONS(8905),
    [sym_systempart_keyword] = ACTIONS(8905),
    [sym_usercontrol_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_dataitem_keyword] = ACTIONS(8905),
    [sym_column_keyword] = ACTIONS(8905),
    [sym_filter_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(5742)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14259),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5743)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [anon_sym_RBRACE] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8905),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token6] = ACTIONS(8905),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_addafter_modification_token1] = ACTIONS(8905),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8905),
    [aux_sym_movelast_modification_token1] = ACTIONS(8905),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8905),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_area_keyword] = ACTIONS(8905),
    [sym_group_keyword] = ACTIONS(8905),
    [sym_repeater_keyword] = ACTIONS(8905),
    [sym_cuegroup_keyword] = ACTIONS(8905),
    [sym_fixed_keyword] = ACTIONS(8905),
    [sym_grid_keyword] = ACTIONS(8905),
    [sym_part_keyword] = ACTIONS(8905),
    [sym_systempart_keyword] = ACTIONS(8905),
    [sym_usercontrol_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_dataitem_keyword] = ACTIONS(8905),
    [sym_column_keyword] = ACTIONS(8905),
    [sym_filter_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(5744)] = {
    [sym_identifier] = ACTIONS(8909),
    [anon_sym_SEMI] = ACTIONS(8911),
    [anon_sym_RBRACE] = ACTIONS(8911),
    [aux_sym_where_condition_token1] = ACTIONS(8909),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8909),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8909),
    [anon_sym_LBRACK] = ACTIONS(8911),
    [aux_sym_basic_type_token6] = ACTIONS(8909),
    [aux_sym_basic_type_token22] = ACTIONS(8909),
    [aux_sym_basic_type_token53] = ACTIONS(8909),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8909),
    [aux_sym_addafter_modification_token1] = ACTIONS(8909),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8909),
    [aux_sym_modify_modification_token1] = ACTIONS(8909),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8909),
    [aux_sym_movelast_modification_token1] = ACTIONS(8909),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8909),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8909),
    [aux_sym_separator_action_token1] = ACTIONS(8909),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8909),
    [aux_sym_type_declaration_token1] = ACTIONS(8909),
    [anon_sym_POUNDif] = ACTIONS(8911),
    [anon_sym_POUNDIF] = ACTIONS(8911),
    [anon_sym_POUNDIf] = ACTIONS(8911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8909),
    [sym_procedure_keyword] = ACTIONS(8909),
    [sym_trigger_keyword] = ACTIONS(8909),
    [sym_var_keyword] = ACTIONS(8909),
    [sym_local_keyword] = ACTIONS(8909),
    [sym_internal_keyword] = ACTIONS(8909),
    [sym_protected_keyword] = ACTIONS(8909),
    [sym_event_keyword] = ACTIONS(8909),
    [sym_fields_keyword] = ACTIONS(8909),
    [sym_keys_keyword] = ACTIONS(8909),
    [sym_key_keyword] = ACTIONS(8909),
    [sym_fieldgroups_keyword] = ACTIONS(8909),
    [sym_actions_keyword] = ACTIONS(8909),
    [sym_layout_keyword] = ACTIONS(8909),
    [sym_area_keyword] = ACTIONS(8909),
    [sym_group_keyword] = ACTIONS(8909),
    [sym_repeater_keyword] = ACTIONS(8909),
    [sym_cuegroup_keyword] = ACTIONS(8909),
    [sym_fixed_keyword] = ACTIONS(8909),
    [sym_grid_keyword] = ACTIONS(8909),
    [sym_part_keyword] = ACTIONS(8909),
    [sym_systempart_keyword] = ACTIONS(8909),
    [sym_usercontrol_keyword] = ACTIONS(8909),
    [sym_dataset_keyword] = ACTIONS(8909),
    [sym_elements_keyword] = ACTIONS(8909),
    [sym_dataitem_keyword] = ACTIONS(8909),
    [sym_column_keyword] = ACTIONS(8909),
    [sym_filter_keyword] = ACTIONS(8909),
    [sym_labels_keyword] = ACTIONS(8909),
    [sym_rendering_keyword] = ACTIONS(8909),
    [sym_requestpage_keyword] = ACTIONS(8909),
    [sym_schema_keyword] = ACTIONS(8909),
    [sym_views_keyword] = ACTIONS(8909),
    [sym_quoted_identifier] = ACTIONS(8911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8911),
    [sym_preproc_open] = ACTIONS(8911),
    [sym_var_attribute_open] = ACTIONS(8911),
  },
  [STATE(5745)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14261),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5746)] = {
    [sym__body_element] = STATE(5799),
    [sym_empty_statement] = STATE(5799),
    [sym_property] = STATE(5799),
    [sym_permissions_property] = STATE(5799),
    [sym_table_relation_property] = STATE(5799),
    [sym_fields_section] = STATE(5799),
    [sym_keys_section] = STATE(5799),
    [sym_fieldgroups_section] = STATE(5799),
    [sym_enum_value_declaration] = STATE(5799),
    [sym_labels_section] = STATE(5799),
    [sym_layout_section] = STATE(5799),
    [sym_modify_modification] = STATE(5799),
    [sym_actions_section] = STATE(5799),
    [sym_views_section] = STATE(5799),
    [sym_dataset_section] = STATE(5799),
    [sym_requestpage_section] = STATE(5799),
    [sym_rendering_section] = STATE(5799),
    [sym_elements_section] = STATE(5799),
    [sym_schema_section] = STATE(5799),
    [sym_assembly_declaration] = STATE(5799),
    [sym_event_declaration] = STATE(5799),
    [sym_procedure] = STATE(5799),
    [sym_preproc_split_procedure] = STATE(5799),
    [sym_preproc_split_procedure_preamble] = STATE(5799),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5799),
    [sym_var_section] = STATE(5799),
    [sym_attribute_item] = STATE(5799),
    [sym_preproc_conditional] = STATE(5799),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5799),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14263),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5747)] = {
    [sym__body_element] = STATE(5639),
    [sym_empty_statement] = STATE(5639),
    [sym_property] = STATE(5639),
    [sym_permissions_property] = STATE(5639),
    [sym_table_relation_property] = STATE(5639),
    [sym_fields_section] = STATE(5639),
    [sym_keys_section] = STATE(5639),
    [sym_fieldgroups_section] = STATE(5639),
    [sym_enum_value_declaration] = STATE(5639),
    [sym_labels_section] = STATE(5639),
    [sym_layout_section] = STATE(5639),
    [sym_modify_modification] = STATE(5639),
    [sym_actions_section] = STATE(5639),
    [sym_views_section] = STATE(5639),
    [sym_dataset_section] = STATE(5639),
    [sym_requestpage_section] = STATE(5639),
    [sym_rendering_section] = STATE(5639),
    [sym_elements_section] = STATE(5639),
    [sym_schema_section] = STATE(5639),
    [sym_assembly_declaration] = STATE(5639),
    [sym_event_declaration] = STATE(5639),
    [sym_procedure] = STATE(5639),
    [sym_preproc_split_procedure] = STATE(5639),
    [sym_preproc_split_procedure_preamble] = STATE(5639),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5639),
    [sym_var_section] = STATE(5639),
    [sym_attribute_item] = STATE(5639),
    [sym_preproc_conditional] = STATE(5639),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5639),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14265),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5748)] = {
    [sym__body_element] = STATE(5596),
    [sym_empty_statement] = STATE(5596),
    [sym_property] = STATE(5596),
    [sym_permissions_property] = STATE(5596),
    [sym_table_relation_property] = STATE(5596),
    [sym_fields_section] = STATE(5596),
    [sym_keys_section] = STATE(5596),
    [sym_fieldgroups_section] = STATE(5596),
    [sym_enum_value_declaration] = STATE(5596),
    [sym_labels_section] = STATE(5596),
    [sym_layout_section] = STATE(5596),
    [sym_modify_modification] = STATE(5596),
    [sym_actions_section] = STATE(5596),
    [sym_views_section] = STATE(5596),
    [sym_dataset_section] = STATE(5596),
    [sym_requestpage_section] = STATE(5596),
    [sym_rendering_section] = STATE(5596),
    [sym_elements_section] = STATE(5596),
    [sym_schema_section] = STATE(5596),
    [sym_assembly_declaration] = STATE(5596),
    [sym_event_declaration] = STATE(5596),
    [sym_procedure] = STATE(5596),
    [sym_preproc_split_procedure] = STATE(5596),
    [sym_preproc_split_procedure_preamble] = STATE(5596),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5596),
    [sym_var_section] = STATE(5596),
    [sym_attribute_item] = STATE(5596),
    [sym_preproc_conditional] = STATE(5596),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5596),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14267),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5749)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14269),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5750)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14271),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5751)] = {
    [sym__body_element] = STATE(5611),
    [sym_empty_statement] = STATE(5611),
    [sym_property] = STATE(5611),
    [sym_permissions_property] = STATE(5611),
    [sym_table_relation_property] = STATE(5611),
    [sym_fields_section] = STATE(5611),
    [sym_keys_section] = STATE(5611),
    [sym_fieldgroups_section] = STATE(5611),
    [sym_enum_value_declaration] = STATE(5611),
    [sym_labels_section] = STATE(5611),
    [sym_layout_section] = STATE(5611),
    [sym_modify_modification] = STATE(5611),
    [sym_actions_section] = STATE(5611),
    [sym_views_section] = STATE(5611),
    [sym_dataset_section] = STATE(5611),
    [sym_requestpage_section] = STATE(5611),
    [sym_rendering_section] = STATE(5611),
    [sym_elements_section] = STATE(5611),
    [sym_schema_section] = STATE(5611),
    [sym_assembly_declaration] = STATE(5611),
    [sym_event_declaration] = STATE(5611),
    [sym_procedure] = STATE(5611),
    [sym_preproc_split_procedure] = STATE(5611),
    [sym_preproc_split_procedure_preamble] = STATE(5611),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5611),
    [sym_var_section] = STATE(5611),
    [sym_attribute_item] = STATE(5611),
    [sym_preproc_conditional] = STATE(5611),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5611),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14269),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5752)] = {
    [sym__body_element] = STATE(5800),
    [sym_empty_statement] = STATE(5800),
    [sym_property] = STATE(5800),
    [sym_permissions_property] = STATE(5800),
    [sym_table_relation_property] = STATE(5800),
    [sym_fields_section] = STATE(5800),
    [sym_keys_section] = STATE(5800),
    [sym_fieldgroups_section] = STATE(5800),
    [sym_enum_value_declaration] = STATE(5800),
    [sym_labels_section] = STATE(5800),
    [sym_layout_section] = STATE(5800),
    [sym_modify_modification] = STATE(5800),
    [sym_actions_section] = STATE(5800),
    [sym_views_section] = STATE(5800),
    [sym_dataset_section] = STATE(5800),
    [sym_requestpage_section] = STATE(5800),
    [sym_rendering_section] = STATE(5800),
    [sym_elements_section] = STATE(5800),
    [sym_schema_section] = STATE(5800),
    [sym_assembly_declaration] = STATE(5800),
    [sym_event_declaration] = STATE(5800),
    [sym_procedure] = STATE(5800),
    [sym_preproc_split_procedure] = STATE(5800),
    [sym_preproc_split_procedure_preamble] = STATE(5800),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5800),
    [sym_var_section] = STATE(5800),
    [sym_attribute_item] = STATE(5800),
    [sym_preproc_conditional] = STATE(5800),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5800),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14273),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5753)] = {
    [sym__body_element] = STATE(5801),
    [sym_empty_statement] = STATE(5801),
    [sym_property] = STATE(5801),
    [sym_permissions_property] = STATE(5801),
    [sym_table_relation_property] = STATE(5801),
    [sym_fields_section] = STATE(5801),
    [sym_keys_section] = STATE(5801),
    [sym_fieldgroups_section] = STATE(5801),
    [sym_enum_value_declaration] = STATE(5801),
    [sym_labels_section] = STATE(5801),
    [sym_layout_section] = STATE(5801),
    [sym_modify_modification] = STATE(5801),
    [sym_actions_section] = STATE(5801),
    [sym_views_section] = STATE(5801),
    [sym_dataset_section] = STATE(5801),
    [sym_requestpage_section] = STATE(5801),
    [sym_rendering_section] = STATE(5801),
    [sym_elements_section] = STATE(5801),
    [sym_schema_section] = STATE(5801),
    [sym_assembly_declaration] = STATE(5801),
    [sym_event_declaration] = STATE(5801),
    [sym_procedure] = STATE(5801),
    [sym_preproc_split_procedure] = STATE(5801),
    [sym_preproc_split_procedure_preamble] = STATE(5801),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5801),
    [sym_var_section] = STATE(5801),
    [sym_attribute_item] = STATE(5801),
    [sym_preproc_conditional] = STATE(5801),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5801),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14275),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5754)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14277),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5755)] = {
    [sym__body_element] = STATE(5804),
    [sym_empty_statement] = STATE(5804),
    [sym_property] = STATE(5804),
    [sym_permissions_property] = STATE(5804),
    [sym_table_relation_property] = STATE(5804),
    [sym_fields_section] = STATE(5804),
    [sym_keys_section] = STATE(5804),
    [sym_fieldgroups_section] = STATE(5804),
    [sym_enum_value_declaration] = STATE(5804),
    [sym_labels_section] = STATE(5804),
    [sym_layout_section] = STATE(5804),
    [sym_modify_modification] = STATE(5804),
    [sym_actions_section] = STATE(5804),
    [sym_views_section] = STATE(5804),
    [sym_dataset_section] = STATE(5804),
    [sym_requestpage_section] = STATE(5804),
    [sym_rendering_section] = STATE(5804),
    [sym_elements_section] = STATE(5804),
    [sym_schema_section] = STATE(5804),
    [sym_assembly_declaration] = STATE(5804),
    [sym_event_declaration] = STATE(5804),
    [sym_procedure] = STATE(5804),
    [sym_preproc_split_procedure] = STATE(5804),
    [sym_preproc_split_procedure_preamble] = STATE(5804),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5804),
    [sym_var_section] = STATE(5804),
    [sym_attribute_item] = STATE(5804),
    [sym_preproc_conditional] = STATE(5804),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5804),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14279),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5756)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14281),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5757)] = {
    [sym__body_element] = STATE(5802),
    [sym_empty_statement] = STATE(5802),
    [sym_property] = STATE(5802),
    [sym_permissions_property] = STATE(5802),
    [sym_table_relation_property] = STATE(5802),
    [sym_fields_section] = STATE(5802),
    [sym_keys_section] = STATE(5802),
    [sym_fieldgroups_section] = STATE(5802),
    [sym_enum_value_declaration] = STATE(5802),
    [sym_labels_section] = STATE(5802),
    [sym_layout_section] = STATE(5802),
    [sym_modify_modification] = STATE(5802),
    [sym_actions_section] = STATE(5802),
    [sym_views_section] = STATE(5802),
    [sym_dataset_section] = STATE(5802),
    [sym_requestpage_section] = STATE(5802),
    [sym_rendering_section] = STATE(5802),
    [sym_elements_section] = STATE(5802),
    [sym_schema_section] = STATE(5802),
    [sym_assembly_declaration] = STATE(5802),
    [sym_event_declaration] = STATE(5802),
    [sym_procedure] = STATE(5802),
    [sym_preproc_split_procedure] = STATE(5802),
    [sym_preproc_split_procedure_preamble] = STATE(5802),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5802),
    [sym_var_section] = STATE(5802),
    [sym_attribute_item] = STATE(5802),
    [sym_preproc_conditional] = STATE(5802),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5802),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14283),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5758)] = {
    [sym__body_element] = STATE(5803),
    [sym_empty_statement] = STATE(5803),
    [sym_property] = STATE(5803),
    [sym_permissions_property] = STATE(5803),
    [sym_table_relation_property] = STATE(5803),
    [sym_fields_section] = STATE(5803),
    [sym_keys_section] = STATE(5803),
    [sym_fieldgroups_section] = STATE(5803),
    [sym_enum_value_declaration] = STATE(5803),
    [sym_labels_section] = STATE(5803),
    [sym_layout_section] = STATE(5803),
    [sym_modify_modification] = STATE(5803),
    [sym_actions_section] = STATE(5803),
    [sym_views_section] = STATE(5803),
    [sym_dataset_section] = STATE(5803),
    [sym_requestpage_section] = STATE(5803),
    [sym_rendering_section] = STATE(5803),
    [sym_elements_section] = STATE(5803),
    [sym_schema_section] = STATE(5803),
    [sym_assembly_declaration] = STATE(5803),
    [sym_event_declaration] = STATE(5803),
    [sym_procedure] = STATE(5803),
    [sym_preproc_split_procedure] = STATE(5803),
    [sym_preproc_split_procedure_preamble] = STATE(5803),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5803),
    [sym_var_section] = STATE(5803),
    [sym_attribute_item] = STATE(5803),
    [sym_preproc_conditional] = STATE(5803),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5803),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14285),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5759)] = {
    [sym_identifier] = ACTIONS(9018),
    [anon_sym_SEMI] = ACTIONS(9020),
    [anon_sym_RBRACE] = ACTIONS(9020),
    [aux_sym_where_condition_token1] = ACTIONS(9018),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9018),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9018),
    [anon_sym_LBRACK] = ACTIONS(9020),
    [aux_sym_basic_type_token6] = ACTIONS(9018),
    [aux_sym_basic_type_token22] = ACTIONS(9018),
    [aux_sym_basic_type_token53] = ACTIONS(9018),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9018),
    [aux_sym_addafter_modification_token1] = ACTIONS(9018),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9018),
    [aux_sym_modify_modification_token1] = ACTIONS(9018),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9018),
    [aux_sym_movelast_modification_token1] = ACTIONS(9018),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9018),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9018),
    [aux_sym_separator_action_token1] = ACTIONS(9018),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9018),
    [aux_sym_type_declaration_token1] = ACTIONS(9018),
    [anon_sym_POUNDif] = ACTIONS(9020),
    [anon_sym_POUNDIF] = ACTIONS(9020),
    [anon_sym_POUNDIf] = ACTIONS(9020),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9018),
    [sym_procedure_keyword] = ACTIONS(9018),
    [sym_trigger_keyword] = ACTIONS(9018),
    [sym_var_keyword] = ACTIONS(9018),
    [sym_local_keyword] = ACTIONS(9018),
    [sym_internal_keyword] = ACTIONS(9018),
    [sym_protected_keyword] = ACTIONS(9018),
    [sym_event_keyword] = ACTIONS(9018),
    [sym_fields_keyword] = ACTIONS(9018),
    [sym_keys_keyword] = ACTIONS(9018),
    [sym_key_keyword] = ACTIONS(9018),
    [sym_fieldgroups_keyword] = ACTIONS(9018),
    [sym_actions_keyword] = ACTIONS(9018),
    [sym_layout_keyword] = ACTIONS(9018),
    [sym_area_keyword] = ACTIONS(9018),
    [sym_group_keyword] = ACTIONS(9018),
    [sym_repeater_keyword] = ACTIONS(9018),
    [sym_cuegroup_keyword] = ACTIONS(9018),
    [sym_fixed_keyword] = ACTIONS(9018),
    [sym_grid_keyword] = ACTIONS(9018),
    [sym_part_keyword] = ACTIONS(9018),
    [sym_systempart_keyword] = ACTIONS(9018),
    [sym_usercontrol_keyword] = ACTIONS(9018),
    [sym_dataset_keyword] = ACTIONS(9018),
    [sym_elements_keyword] = ACTIONS(9018),
    [sym_dataitem_keyword] = ACTIONS(9018),
    [sym_column_keyword] = ACTIONS(9018),
    [sym_filter_keyword] = ACTIONS(9018),
    [sym_labels_keyword] = ACTIONS(9018),
    [sym_rendering_keyword] = ACTIONS(9018),
    [sym_requestpage_keyword] = ACTIONS(9018),
    [sym_schema_keyword] = ACTIONS(9018),
    [sym_views_keyword] = ACTIONS(9018),
    [sym_quoted_identifier] = ACTIONS(9020),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9020),
    [sym_preproc_open] = ACTIONS(9020),
    [sym_var_attribute_open] = ACTIONS(9020),
  },
  [STATE(5760)] = {
    [sym__body_element] = STATE(5563),
    [sym_empty_statement] = STATE(5563),
    [sym_property] = STATE(5563),
    [sym_permissions_property] = STATE(5563),
    [sym_table_relation_property] = STATE(5563),
    [sym_fields_section] = STATE(5563),
    [sym_keys_section] = STATE(5563),
    [sym_fieldgroups_section] = STATE(5563),
    [sym_enum_value_declaration] = STATE(5563),
    [sym_labels_section] = STATE(5563),
    [sym_layout_section] = STATE(5563),
    [sym_modify_modification] = STATE(5563),
    [sym_actions_section] = STATE(5563),
    [sym_views_section] = STATE(5563),
    [sym_dataset_section] = STATE(5563),
    [sym_requestpage_section] = STATE(5563),
    [sym_rendering_section] = STATE(5563),
    [sym_elements_section] = STATE(5563),
    [sym_schema_section] = STATE(5563),
    [sym_assembly_declaration] = STATE(5563),
    [sym_event_declaration] = STATE(5563),
    [sym_procedure] = STATE(5563),
    [sym_preproc_split_procedure] = STATE(5563),
    [sym_preproc_split_procedure_preamble] = STATE(5563),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5563),
    [sym_var_section] = STATE(5563),
    [sym_attribute_item] = STATE(5563),
    [sym_preproc_conditional] = STATE(5563),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5563),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14287),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5761)] = {
    [sym__body_element] = STATE(5783),
    [sym_empty_statement] = STATE(5783),
    [sym_property] = STATE(5783),
    [sym_permissions_property] = STATE(5783),
    [sym_table_relation_property] = STATE(5783),
    [sym_fields_section] = STATE(5783),
    [sym_keys_section] = STATE(5783),
    [sym_fieldgroups_section] = STATE(5783),
    [sym_enum_value_declaration] = STATE(5783),
    [sym_labels_section] = STATE(5783),
    [sym_layout_section] = STATE(5783),
    [sym_modify_modification] = STATE(5783),
    [sym_actions_section] = STATE(5783),
    [sym_views_section] = STATE(5783),
    [sym_dataset_section] = STATE(5783),
    [sym_requestpage_section] = STATE(5783),
    [sym_rendering_section] = STATE(5783),
    [sym_elements_section] = STATE(5783),
    [sym_schema_section] = STATE(5783),
    [sym_assembly_declaration] = STATE(5783),
    [sym_event_declaration] = STATE(5783),
    [sym_procedure] = STATE(5783),
    [sym_preproc_split_procedure] = STATE(5783),
    [sym_preproc_split_procedure_preamble] = STATE(5783),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5783),
    [sym_var_section] = STATE(5783),
    [sym_attribute_item] = STATE(5783),
    [sym_preproc_conditional] = STATE(5783),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5783),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14289),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5762)] = {
    [sym_identifier] = ACTIONS(6152),
    [anon_sym_SEMI] = ACTIONS(6154),
    [anon_sym_RBRACE] = ACTIONS(6154),
    [aux_sym_where_condition_token1] = ACTIONS(6152),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6152),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6152),
    [anon_sym_LBRACK] = ACTIONS(6154),
    [aux_sym_basic_type_token6] = ACTIONS(6152),
    [aux_sym_basic_type_token22] = ACTIONS(6152),
    [aux_sym_basic_type_token53] = ACTIONS(6152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6152),
    [aux_sym_addafter_modification_token1] = ACTIONS(6152),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6152),
    [aux_sym_modify_modification_token1] = ACTIONS(6152),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6152),
    [aux_sym_movelast_modification_token1] = ACTIONS(6152),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6152),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6152),
    [aux_sym_separator_action_token1] = ACTIONS(6152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6152),
    [aux_sym_type_declaration_token1] = ACTIONS(6152),
    [anon_sym_POUNDif] = ACTIONS(6154),
    [anon_sym_POUNDIF] = ACTIONS(6154),
    [anon_sym_POUNDIf] = ACTIONS(6154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6152),
    [sym_procedure_keyword] = ACTIONS(6152),
    [sym_trigger_keyword] = ACTIONS(6152),
    [sym_var_keyword] = ACTIONS(6152),
    [sym_local_keyword] = ACTIONS(6152),
    [sym_internal_keyword] = ACTIONS(6152),
    [sym_protected_keyword] = ACTIONS(6152),
    [sym_event_keyword] = ACTIONS(6152),
    [sym_fields_keyword] = ACTIONS(6152),
    [sym_keys_keyword] = ACTIONS(6152),
    [sym_key_keyword] = ACTIONS(6152),
    [sym_fieldgroups_keyword] = ACTIONS(6152),
    [sym_actions_keyword] = ACTIONS(6152),
    [sym_layout_keyword] = ACTIONS(6152),
    [sym_area_keyword] = ACTIONS(6152),
    [sym_group_keyword] = ACTIONS(6152),
    [sym_repeater_keyword] = ACTIONS(6152),
    [sym_cuegroup_keyword] = ACTIONS(6152),
    [sym_fixed_keyword] = ACTIONS(6152),
    [sym_grid_keyword] = ACTIONS(6152),
    [sym_part_keyword] = ACTIONS(6152),
    [sym_systempart_keyword] = ACTIONS(6152),
    [sym_usercontrol_keyword] = ACTIONS(6152),
    [sym_dataset_keyword] = ACTIONS(6152),
    [sym_elements_keyword] = ACTIONS(6152),
    [sym_dataitem_keyword] = ACTIONS(6152),
    [sym_column_keyword] = ACTIONS(6152),
    [sym_filter_keyword] = ACTIONS(6152),
    [sym_labels_keyword] = ACTIONS(6152),
    [sym_rendering_keyword] = ACTIONS(6152),
    [sym_requestpage_keyword] = ACTIONS(6152),
    [sym_schema_keyword] = ACTIONS(6152),
    [sym_views_keyword] = ACTIONS(6152),
    [sym_quoted_identifier] = ACTIONS(6154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6154),
    [sym_preproc_open] = ACTIONS(6154),
    [sym_var_attribute_open] = ACTIONS(6154),
  },
  [STATE(5763)] = {
    [sym_identifier] = ACTIONS(6156),
    [anon_sym_SEMI] = ACTIONS(6158),
    [anon_sym_RBRACE] = ACTIONS(6158),
    [aux_sym_where_condition_token1] = ACTIONS(6156),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6156),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6156),
    [anon_sym_LBRACK] = ACTIONS(6158),
    [aux_sym_basic_type_token6] = ACTIONS(6156),
    [aux_sym_basic_type_token22] = ACTIONS(6156),
    [aux_sym_basic_type_token53] = ACTIONS(6156),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6156),
    [aux_sym_addafter_modification_token1] = ACTIONS(6156),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6156),
    [aux_sym_modify_modification_token1] = ACTIONS(6156),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6156),
    [aux_sym_movelast_modification_token1] = ACTIONS(6156),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6156),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6156),
    [aux_sym_separator_action_token1] = ACTIONS(6156),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6156),
    [aux_sym_type_declaration_token1] = ACTIONS(6156),
    [anon_sym_POUNDif] = ACTIONS(6158),
    [anon_sym_POUNDIF] = ACTIONS(6158),
    [anon_sym_POUNDIf] = ACTIONS(6158),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6156),
    [sym_procedure_keyword] = ACTIONS(6156),
    [sym_trigger_keyword] = ACTIONS(6156),
    [sym_var_keyword] = ACTIONS(6156),
    [sym_local_keyword] = ACTIONS(6156),
    [sym_internal_keyword] = ACTIONS(6156),
    [sym_protected_keyword] = ACTIONS(6156),
    [sym_event_keyword] = ACTIONS(6156),
    [sym_fields_keyword] = ACTIONS(6156),
    [sym_keys_keyword] = ACTIONS(6156),
    [sym_key_keyword] = ACTIONS(6156),
    [sym_fieldgroups_keyword] = ACTIONS(6156),
    [sym_actions_keyword] = ACTIONS(6156),
    [sym_layout_keyword] = ACTIONS(6156),
    [sym_area_keyword] = ACTIONS(6156),
    [sym_group_keyword] = ACTIONS(6156),
    [sym_repeater_keyword] = ACTIONS(6156),
    [sym_cuegroup_keyword] = ACTIONS(6156),
    [sym_fixed_keyword] = ACTIONS(6156),
    [sym_grid_keyword] = ACTIONS(6156),
    [sym_part_keyword] = ACTIONS(6156),
    [sym_systempart_keyword] = ACTIONS(6156),
    [sym_usercontrol_keyword] = ACTIONS(6156),
    [sym_dataset_keyword] = ACTIONS(6156),
    [sym_elements_keyword] = ACTIONS(6156),
    [sym_dataitem_keyword] = ACTIONS(6156),
    [sym_column_keyword] = ACTIONS(6156),
    [sym_filter_keyword] = ACTIONS(6156),
    [sym_labels_keyword] = ACTIONS(6156),
    [sym_rendering_keyword] = ACTIONS(6156),
    [sym_requestpage_keyword] = ACTIONS(6156),
    [sym_schema_keyword] = ACTIONS(6156),
    [sym_views_keyword] = ACTIONS(6156),
    [sym_quoted_identifier] = ACTIONS(6158),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6158),
    [sym_preproc_open] = ACTIONS(6158),
    [sym_var_attribute_open] = ACTIONS(6158),
  },
  [STATE(5764)] = {
    [sym__body_element] = STATE(5602),
    [sym_empty_statement] = STATE(5602),
    [sym_property] = STATE(5602),
    [sym_permissions_property] = STATE(5602),
    [sym_table_relation_property] = STATE(5602),
    [sym_fields_section] = STATE(5602),
    [sym_keys_section] = STATE(5602),
    [sym_fieldgroups_section] = STATE(5602),
    [sym_enum_value_declaration] = STATE(5602),
    [sym_labels_section] = STATE(5602),
    [sym_layout_section] = STATE(5602),
    [sym_modify_modification] = STATE(5602),
    [sym_actions_section] = STATE(5602),
    [sym_views_section] = STATE(5602),
    [sym_dataset_section] = STATE(5602),
    [sym_requestpage_section] = STATE(5602),
    [sym_rendering_section] = STATE(5602),
    [sym_elements_section] = STATE(5602),
    [sym_schema_section] = STATE(5602),
    [sym_assembly_declaration] = STATE(5602),
    [sym_event_declaration] = STATE(5602),
    [sym_procedure] = STATE(5602),
    [sym_preproc_split_procedure] = STATE(5602),
    [sym_preproc_split_procedure_preamble] = STATE(5602),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5602),
    [sym_var_section] = STATE(5602),
    [sym_attribute_item] = STATE(5602),
    [sym_preproc_conditional] = STATE(5602),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5602),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14291),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5765)] = {
    [sym__body_element] = STATE(5641),
    [sym_empty_statement] = STATE(5641),
    [sym_property] = STATE(5641),
    [sym_permissions_property] = STATE(5641),
    [sym_table_relation_property] = STATE(5641),
    [sym_fields_section] = STATE(5641),
    [sym_keys_section] = STATE(5641),
    [sym_fieldgroups_section] = STATE(5641),
    [sym_enum_value_declaration] = STATE(5641),
    [sym_labels_section] = STATE(5641),
    [sym_layout_section] = STATE(5641),
    [sym_modify_modification] = STATE(5641),
    [sym_actions_section] = STATE(5641),
    [sym_views_section] = STATE(5641),
    [sym_dataset_section] = STATE(5641),
    [sym_requestpage_section] = STATE(5641),
    [sym_rendering_section] = STATE(5641),
    [sym_elements_section] = STATE(5641),
    [sym_schema_section] = STATE(5641),
    [sym_assembly_declaration] = STATE(5641),
    [sym_event_declaration] = STATE(5641),
    [sym_procedure] = STATE(5641),
    [sym_preproc_split_procedure] = STATE(5641),
    [sym_preproc_split_procedure_preamble] = STATE(5641),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5641),
    [sym_var_section] = STATE(5641),
    [sym_attribute_item] = STATE(5641),
    [sym_preproc_conditional] = STATE(5641),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5641),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14293),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5766)] = {
    [sym__body_element] = STATE(5659),
    [sym_empty_statement] = STATE(5659),
    [sym_property] = STATE(5659),
    [sym_permissions_property] = STATE(5659),
    [sym_table_relation_property] = STATE(5659),
    [sym_fields_section] = STATE(5659),
    [sym_keys_section] = STATE(5659),
    [sym_fieldgroups_section] = STATE(5659),
    [sym_enum_value_declaration] = STATE(5659),
    [sym_labels_section] = STATE(5659),
    [sym_layout_section] = STATE(5659),
    [sym_modify_modification] = STATE(5659),
    [sym_actions_section] = STATE(5659),
    [sym_views_section] = STATE(5659),
    [sym_dataset_section] = STATE(5659),
    [sym_requestpage_section] = STATE(5659),
    [sym_rendering_section] = STATE(5659),
    [sym_elements_section] = STATE(5659),
    [sym_schema_section] = STATE(5659),
    [sym_assembly_declaration] = STATE(5659),
    [sym_event_declaration] = STATE(5659),
    [sym_procedure] = STATE(5659),
    [sym_preproc_split_procedure] = STATE(5659),
    [sym_preproc_split_procedure_preamble] = STATE(5659),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5659),
    [sym_var_section] = STATE(5659),
    [sym_attribute_item] = STATE(5659),
    [sym_preproc_conditional] = STATE(5659),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5659),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14295),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5767)] = {
    [sym_identifier] = ACTIONS(6160),
    [anon_sym_SEMI] = ACTIONS(6162),
    [anon_sym_RBRACE] = ACTIONS(6162),
    [aux_sym_where_condition_token1] = ACTIONS(6160),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6160),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6160),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [aux_sym_basic_type_token6] = ACTIONS(6160),
    [aux_sym_basic_type_token22] = ACTIONS(6160),
    [aux_sym_basic_type_token53] = ACTIONS(6160),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6160),
    [aux_sym_addafter_modification_token1] = ACTIONS(6160),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6160),
    [aux_sym_modify_modification_token1] = ACTIONS(6160),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6160),
    [aux_sym_movelast_modification_token1] = ACTIONS(6160),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6160),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6160),
    [aux_sym_separator_action_token1] = ACTIONS(6160),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6160),
    [aux_sym_type_declaration_token1] = ACTIONS(6160),
    [anon_sym_POUNDif] = ACTIONS(6162),
    [anon_sym_POUNDIF] = ACTIONS(6162),
    [anon_sym_POUNDIf] = ACTIONS(6162),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6160),
    [sym_procedure_keyword] = ACTIONS(6160),
    [sym_trigger_keyword] = ACTIONS(6160),
    [sym_var_keyword] = ACTIONS(6160),
    [sym_local_keyword] = ACTIONS(6160),
    [sym_internal_keyword] = ACTIONS(6160),
    [sym_protected_keyword] = ACTIONS(6160),
    [sym_event_keyword] = ACTIONS(6160),
    [sym_fields_keyword] = ACTIONS(6160),
    [sym_keys_keyword] = ACTIONS(6160),
    [sym_key_keyword] = ACTIONS(6160),
    [sym_fieldgroups_keyword] = ACTIONS(6160),
    [sym_actions_keyword] = ACTIONS(6160),
    [sym_layout_keyword] = ACTIONS(6160),
    [sym_area_keyword] = ACTIONS(6160),
    [sym_group_keyword] = ACTIONS(6160),
    [sym_repeater_keyword] = ACTIONS(6160),
    [sym_cuegroup_keyword] = ACTIONS(6160),
    [sym_fixed_keyword] = ACTIONS(6160),
    [sym_grid_keyword] = ACTIONS(6160),
    [sym_part_keyword] = ACTIONS(6160),
    [sym_systempart_keyword] = ACTIONS(6160),
    [sym_usercontrol_keyword] = ACTIONS(6160),
    [sym_dataset_keyword] = ACTIONS(6160),
    [sym_elements_keyword] = ACTIONS(6160),
    [sym_dataitem_keyword] = ACTIONS(6160),
    [sym_column_keyword] = ACTIONS(6160),
    [sym_filter_keyword] = ACTIONS(6160),
    [sym_labels_keyword] = ACTIONS(6160),
    [sym_rendering_keyword] = ACTIONS(6160),
    [sym_requestpage_keyword] = ACTIONS(6160),
    [sym_schema_keyword] = ACTIONS(6160),
    [sym_views_keyword] = ACTIONS(6160),
    [sym_quoted_identifier] = ACTIONS(6162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6162),
    [sym_preproc_open] = ACTIONS(6162),
    [sym_var_attribute_open] = ACTIONS(6162),
  },
  [STATE(5768)] = {
    [sym__body_element] = STATE(5661),
    [sym_empty_statement] = STATE(5661),
    [sym_property] = STATE(5661),
    [sym_permissions_property] = STATE(5661),
    [sym_table_relation_property] = STATE(5661),
    [sym_fields_section] = STATE(5661),
    [sym_keys_section] = STATE(5661),
    [sym_fieldgroups_section] = STATE(5661),
    [sym_enum_value_declaration] = STATE(5661),
    [sym_labels_section] = STATE(5661),
    [sym_layout_section] = STATE(5661),
    [sym_modify_modification] = STATE(5661),
    [sym_actions_section] = STATE(5661),
    [sym_views_section] = STATE(5661),
    [sym_dataset_section] = STATE(5661),
    [sym_requestpage_section] = STATE(5661),
    [sym_rendering_section] = STATE(5661),
    [sym_elements_section] = STATE(5661),
    [sym_schema_section] = STATE(5661),
    [sym_assembly_declaration] = STATE(5661),
    [sym_event_declaration] = STATE(5661),
    [sym_procedure] = STATE(5661),
    [sym_preproc_split_procedure] = STATE(5661),
    [sym_preproc_split_procedure_preamble] = STATE(5661),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5661),
    [sym_var_section] = STATE(5661),
    [sym_attribute_item] = STATE(5661),
    [sym_preproc_conditional] = STATE(5661),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5661),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14297),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5769)] = {
    [sym__body_element] = STATE(5668),
    [sym_empty_statement] = STATE(5668),
    [sym_property] = STATE(5668),
    [sym_permissions_property] = STATE(5668),
    [sym_table_relation_property] = STATE(5668),
    [sym_fields_section] = STATE(5668),
    [sym_keys_section] = STATE(5668),
    [sym_fieldgroups_section] = STATE(5668),
    [sym_enum_value_declaration] = STATE(5668),
    [sym_labels_section] = STATE(5668),
    [sym_layout_section] = STATE(5668),
    [sym_modify_modification] = STATE(5668),
    [sym_actions_section] = STATE(5668),
    [sym_views_section] = STATE(5668),
    [sym_dataset_section] = STATE(5668),
    [sym_requestpage_section] = STATE(5668),
    [sym_rendering_section] = STATE(5668),
    [sym_elements_section] = STATE(5668),
    [sym_schema_section] = STATE(5668),
    [sym_assembly_declaration] = STATE(5668),
    [sym_event_declaration] = STATE(5668),
    [sym_procedure] = STATE(5668),
    [sym_preproc_split_procedure] = STATE(5668),
    [sym_preproc_split_procedure_preamble] = STATE(5668),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5668),
    [sym_var_section] = STATE(5668),
    [sym_attribute_item] = STATE(5668),
    [sym_preproc_conditional] = STATE(5668),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5668),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14299),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5770)] = {
    [sym__body_element] = STATE(5671),
    [sym_empty_statement] = STATE(5671),
    [sym_property] = STATE(5671),
    [sym_permissions_property] = STATE(5671),
    [sym_table_relation_property] = STATE(5671),
    [sym_fields_section] = STATE(5671),
    [sym_keys_section] = STATE(5671),
    [sym_fieldgroups_section] = STATE(5671),
    [sym_enum_value_declaration] = STATE(5671),
    [sym_labels_section] = STATE(5671),
    [sym_layout_section] = STATE(5671),
    [sym_modify_modification] = STATE(5671),
    [sym_actions_section] = STATE(5671),
    [sym_views_section] = STATE(5671),
    [sym_dataset_section] = STATE(5671),
    [sym_requestpage_section] = STATE(5671),
    [sym_rendering_section] = STATE(5671),
    [sym_elements_section] = STATE(5671),
    [sym_schema_section] = STATE(5671),
    [sym_assembly_declaration] = STATE(5671),
    [sym_event_declaration] = STATE(5671),
    [sym_procedure] = STATE(5671),
    [sym_preproc_split_procedure] = STATE(5671),
    [sym_preproc_split_procedure_preamble] = STATE(5671),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5671),
    [sym_var_section] = STATE(5671),
    [sym_attribute_item] = STATE(5671),
    [sym_preproc_conditional] = STATE(5671),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5671),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14301),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5771)] = {
    [sym__body_element] = STATE(5806),
    [sym_empty_statement] = STATE(5806),
    [sym_property] = STATE(5806),
    [sym_permissions_property] = STATE(5806),
    [sym_table_relation_property] = STATE(5806),
    [sym_fields_section] = STATE(5806),
    [sym_keys_section] = STATE(5806),
    [sym_fieldgroups_section] = STATE(5806),
    [sym_enum_value_declaration] = STATE(5806),
    [sym_labels_section] = STATE(5806),
    [sym_layout_section] = STATE(5806),
    [sym_modify_modification] = STATE(5806),
    [sym_actions_section] = STATE(5806),
    [sym_views_section] = STATE(5806),
    [sym_dataset_section] = STATE(5806),
    [sym_requestpage_section] = STATE(5806),
    [sym_rendering_section] = STATE(5806),
    [sym_elements_section] = STATE(5806),
    [sym_schema_section] = STATE(5806),
    [sym_assembly_declaration] = STATE(5806),
    [sym_event_declaration] = STATE(5806),
    [sym_procedure] = STATE(5806),
    [sym_preproc_split_procedure] = STATE(5806),
    [sym_preproc_split_procedure_preamble] = STATE(5806),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5806),
    [sym_var_section] = STATE(5806),
    [sym_attribute_item] = STATE(5806),
    [sym_preproc_conditional] = STATE(5806),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5806),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14303),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5772)] = {
    [sym_identifier] = ACTIONS(6164),
    [anon_sym_SEMI] = ACTIONS(6166),
    [anon_sym_RBRACE] = ACTIONS(6166),
    [aux_sym_where_condition_token1] = ACTIONS(6164),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6164),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6164),
    [anon_sym_LBRACK] = ACTIONS(6166),
    [aux_sym_basic_type_token6] = ACTIONS(6164),
    [aux_sym_basic_type_token22] = ACTIONS(6164),
    [aux_sym_basic_type_token53] = ACTIONS(6164),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6164),
    [aux_sym_addafter_modification_token1] = ACTIONS(6164),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6164),
    [aux_sym_modify_modification_token1] = ACTIONS(6164),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6164),
    [aux_sym_movelast_modification_token1] = ACTIONS(6164),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6164),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6164),
    [aux_sym_separator_action_token1] = ACTIONS(6164),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6164),
    [aux_sym_type_declaration_token1] = ACTIONS(6164),
    [anon_sym_POUNDif] = ACTIONS(6166),
    [anon_sym_POUNDIF] = ACTIONS(6166),
    [anon_sym_POUNDIf] = ACTIONS(6166),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6164),
    [sym_procedure_keyword] = ACTIONS(6164),
    [sym_trigger_keyword] = ACTIONS(6164),
    [sym_var_keyword] = ACTIONS(6164),
    [sym_local_keyword] = ACTIONS(6164),
    [sym_internal_keyword] = ACTIONS(6164),
    [sym_protected_keyword] = ACTIONS(6164),
    [sym_event_keyword] = ACTIONS(6164),
    [sym_fields_keyword] = ACTIONS(6164),
    [sym_keys_keyword] = ACTIONS(6164),
    [sym_key_keyword] = ACTIONS(6164),
    [sym_fieldgroups_keyword] = ACTIONS(6164),
    [sym_actions_keyword] = ACTIONS(6164),
    [sym_layout_keyword] = ACTIONS(6164),
    [sym_area_keyword] = ACTIONS(6164),
    [sym_group_keyword] = ACTIONS(6164),
    [sym_repeater_keyword] = ACTIONS(6164),
    [sym_cuegroup_keyword] = ACTIONS(6164),
    [sym_fixed_keyword] = ACTIONS(6164),
    [sym_grid_keyword] = ACTIONS(6164),
    [sym_part_keyword] = ACTIONS(6164),
    [sym_systempart_keyword] = ACTIONS(6164),
    [sym_usercontrol_keyword] = ACTIONS(6164),
    [sym_dataset_keyword] = ACTIONS(6164),
    [sym_elements_keyword] = ACTIONS(6164),
    [sym_dataitem_keyword] = ACTIONS(6164),
    [sym_column_keyword] = ACTIONS(6164),
    [sym_filter_keyword] = ACTIONS(6164),
    [sym_labels_keyword] = ACTIONS(6164),
    [sym_rendering_keyword] = ACTIONS(6164),
    [sym_requestpage_keyword] = ACTIONS(6164),
    [sym_schema_keyword] = ACTIONS(6164),
    [sym_views_keyword] = ACTIONS(6164),
    [sym_quoted_identifier] = ACTIONS(6166),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6166),
    [sym_preproc_open] = ACTIONS(6166),
    [sym_var_attribute_open] = ACTIONS(6166),
  },
  [STATE(5773)] = {
    [sym_identifier] = ACTIONS(6168),
    [anon_sym_SEMI] = ACTIONS(6170),
    [anon_sym_RBRACE] = ACTIONS(6170),
    [aux_sym_where_condition_token1] = ACTIONS(6168),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6168),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6168),
    [anon_sym_LBRACK] = ACTIONS(6170),
    [aux_sym_basic_type_token6] = ACTIONS(6168),
    [aux_sym_basic_type_token22] = ACTIONS(6168),
    [aux_sym_basic_type_token53] = ACTIONS(6168),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6168),
    [aux_sym_addafter_modification_token1] = ACTIONS(6168),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6168),
    [aux_sym_modify_modification_token1] = ACTIONS(6168),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6168),
    [aux_sym_movelast_modification_token1] = ACTIONS(6168),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6168),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6168),
    [aux_sym_separator_action_token1] = ACTIONS(6168),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6168),
    [aux_sym_type_declaration_token1] = ACTIONS(6168),
    [anon_sym_POUNDif] = ACTIONS(6170),
    [anon_sym_POUNDIF] = ACTIONS(6170),
    [anon_sym_POUNDIf] = ACTIONS(6170),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6168),
    [sym_procedure_keyword] = ACTIONS(6168),
    [sym_trigger_keyword] = ACTIONS(6168),
    [sym_var_keyword] = ACTIONS(6168),
    [sym_local_keyword] = ACTIONS(6168),
    [sym_internal_keyword] = ACTIONS(6168),
    [sym_protected_keyword] = ACTIONS(6168),
    [sym_event_keyword] = ACTIONS(6168),
    [sym_fields_keyword] = ACTIONS(6168),
    [sym_keys_keyword] = ACTIONS(6168),
    [sym_key_keyword] = ACTIONS(6168),
    [sym_fieldgroups_keyword] = ACTIONS(6168),
    [sym_actions_keyword] = ACTIONS(6168),
    [sym_layout_keyword] = ACTIONS(6168),
    [sym_area_keyword] = ACTIONS(6168),
    [sym_group_keyword] = ACTIONS(6168),
    [sym_repeater_keyword] = ACTIONS(6168),
    [sym_cuegroup_keyword] = ACTIONS(6168),
    [sym_fixed_keyword] = ACTIONS(6168),
    [sym_grid_keyword] = ACTIONS(6168),
    [sym_part_keyword] = ACTIONS(6168),
    [sym_systempart_keyword] = ACTIONS(6168),
    [sym_usercontrol_keyword] = ACTIONS(6168),
    [sym_dataset_keyword] = ACTIONS(6168),
    [sym_elements_keyword] = ACTIONS(6168),
    [sym_dataitem_keyword] = ACTIONS(6168),
    [sym_column_keyword] = ACTIONS(6168),
    [sym_filter_keyword] = ACTIONS(6168),
    [sym_labels_keyword] = ACTIONS(6168),
    [sym_rendering_keyword] = ACTIONS(6168),
    [sym_requestpage_keyword] = ACTIONS(6168),
    [sym_schema_keyword] = ACTIONS(6168),
    [sym_views_keyword] = ACTIONS(6168),
    [sym_quoted_identifier] = ACTIONS(6170),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6170),
    [sym_preproc_open] = ACTIONS(6170),
    [sym_var_attribute_open] = ACTIONS(6170),
  },
  [STATE(5774)] = {
    [sym_identifier] = ACTIONS(6172),
    [anon_sym_SEMI] = ACTIONS(6174),
    [anon_sym_RBRACE] = ACTIONS(6174),
    [aux_sym_where_condition_token1] = ACTIONS(6172),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6172),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6172),
    [anon_sym_LBRACK] = ACTIONS(6174),
    [aux_sym_basic_type_token6] = ACTIONS(6172),
    [aux_sym_basic_type_token22] = ACTIONS(6172),
    [aux_sym_basic_type_token53] = ACTIONS(6172),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6172),
    [aux_sym_addafter_modification_token1] = ACTIONS(6172),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6172),
    [aux_sym_modify_modification_token1] = ACTIONS(6172),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6172),
    [aux_sym_movelast_modification_token1] = ACTIONS(6172),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6172),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6172),
    [aux_sym_separator_action_token1] = ACTIONS(6172),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6172),
    [aux_sym_type_declaration_token1] = ACTIONS(6172),
    [anon_sym_POUNDif] = ACTIONS(6174),
    [anon_sym_POUNDIF] = ACTIONS(6174),
    [anon_sym_POUNDIf] = ACTIONS(6174),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6172),
    [sym_procedure_keyword] = ACTIONS(6172),
    [sym_trigger_keyword] = ACTIONS(6172),
    [sym_var_keyword] = ACTIONS(6172),
    [sym_local_keyword] = ACTIONS(6172),
    [sym_internal_keyword] = ACTIONS(6172),
    [sym_protected_keyword] = ACTIONS(6172),
    [sym_event_keyword] = ACTIONS(6172),
    [sym_fields_keyword] = ACTIONS(6172),
    [sym_keys_keyword] = ACTIONS(6172),
    [sym_key_keyword] = ACTIONS(6172),
    [sym_fieldgroups_keyword] = ACTIONS(6172),
    [sym_actions_keyword] = ACTIONS(6172),
    [sym_layout_keyword] = ACTIONS(6172),
    [sym_area_keyword] = ACTIONS(6172),
    [sym_group_keyword] = ACTIONS(6172),
    [sym_repeater_keyword] = ACTIONS(6172),
    [sym_cuegroup_keyword] = ACTIONS(6172),
    [sym_fixed_keyword] = ACTIONS(6172),
    [sym_grid_keyword] = ACTIONS(6172),
    [sym_part_keyword] = ACTIONS(6172),
    [sym_systempart_keyword] = ACTIONS(6172),
    [sym_usercontrol_keyword] = ACTIONS(6172),
    [sym_dataset_keyword] = ACTIONS(6172),
    [sym_elements_keyword] = ACTIONS(6172),
    [sym_dataitem_keyword] = ACTIONS(6172),
    [sym_column_keyword] = ACTIONS(6172),
    [sym_filter_keyword] = ACTIONS(6172),
    [sym_labels_keyword] = ACTIONS(6172),
    [sym_rendering_keyword] = ACTIONS(6172),
    [sym_requestpage_keyword] = ACTIONS(6172),
    [sym_schema_keyword] = ACTIONS(6172),
    [sym_views_keyword] = ACTIONS(6172),
    [sym_quoted_identifier] = ACTIONS(6174),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6174),
    [sym_preproc_open] = ACTIONS(6174),
    [sym_var_attribute_open] = ACTIONS(6174),
  },
  [STATE(5775)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14305),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5776)] = {
    [sym__body_element] = STATE(5473),
    [sym_empty_statement] = STATE(5473),
    [sym_property] = STATE(5473),
    [sym_permissions_property] = STATE(5473),
    [sym_table_relation_property] = STATE(5473),
    [sym_fields_section] = STATE(5473),
    [sym_keys_section] = STATE(5473),
    [sym_fieldgroups_section] = STATE(5473),
    [sym_enum_value_declaration] = STATE(5473),
    [sym_labels_section] = STATE(5473),
    [sym_layout_section] = STATE(5473),
    [sym_modify_modification] = STATE(5473),
    [sym_actions_section] = STATE(5473),
    [sym_views_section] = STATE(5473),
    [sym_dataset_section] = STATE(5473),
    [sym_requestpage_section] = STATE(5473),
    [sym_rendering_section] = STATE(5473),
    [sym_elements_section] = STATE(5473),
    [sym_schema_section] = STATE(5473),
    [sym_assembly_declaration] = STATE(5473),
    [sym_event_declaration] = STATE(5473),
    [sym_procedure] = STATE(5473),
    [sym_preproc_split_procedure] = STATE(5473),
    [sym_preproc_split_procedure_preamble] = STATE(5473),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5473),
    [sym_var_section] = STATE(5473),
    [sym_attribute_item] = STATE(5473),
    [sym_preproc_conditional] = STATE(5473),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5473),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14307),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5777)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14309),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5778)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14311),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5779)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14313),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5780)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14315),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5781)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14317),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5782)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14319),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5783)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14321),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5784)] = {
    [sym__body_element] = STATE(5810),
    [sym_empty_statement] = STATE(5810),
    [sym_property] = STATE(5810),
    [sym_permissions_property] = STATE(5810),
    [sym_table_relation_property] = STATE(5810),
    [sym_fields_section] = STATE(5810),
    [sym_keys_section] = STATE(5810),
    [sym_fieldgroups_section] = STATE(5810),
    [sym_enum_value_declaration] = STATE(5810),
    [sym_labels_section] = STATE(5810),
    [sym_layout_section] = STATE(5810),
    [sym_modify_modification] = STATE(5810),
    [sym_actions_section] = STATE(5810),
    [sym_views_section] = STATE(5810),
    [sym_dataset_section] = STATE(5810),
    [sym_requestpage_section] = STATE(5810),
    [sym_rendering_section] = STATE(5810),
    [sym_elements_section] = STATE(5810),
    [sym_schema_section] = STATE(5810),
    [sym_assembly_declaration] = STATE(5810),
    [sym_event_declaration] = STATE(5810),
    [sym_procedure] = STATE(5810),
    [sym_preproc_split_procedure] = STATE(5810),
    [sym_preproc_split_procedure_preamble] = STATE(5810),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5810),
    [sym_var_section] = STATE(5810),
    [sym_attribute_item] = STATE(5810),
    [sym_preproc_conditional] = STATE(5810),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5810),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14323),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5785)] = {
    [sym_identifier] = ACTIONS(8893),
    [anon_sym_SEMI] = ACTIONS(8895),
    [anon_sym_RBRACE] = ACTIONS(8895),
    [aux_sym_where_condition_token1] = ACTIONS(8893),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8893),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8893),
    [anon_sym_LBRACK] = ACTIONS(8895),
    [aux_sym_basic_type_token6] = ACTIONS(8893),
    [aux_sym_basic_type_token22] = ACTIONS(8893),
    [aux_sym_basic_type_token53] = ACTIONS(8893),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8893),
    [aux_sym_addafter_modification_token1] = ACTIONS(8893),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8893),
    [aux_sym_modify_modification_token1] = ACTIONS(8893),
    [aux_sym_movefirst_modification_token1] = ACTIONS(8893),
    [aux_sym_movelast_modification_token1] = ACTIONS(8893),
    [aux_sym_moveafter_modification_token1] = ACTIONS(8893),
    [aux_sym_movebefore_modification_token1] = ACTIONS(8893),
    [aux_sym_separator_action_token1] = ACTIONS(8893),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8893),
    [aux_sym_type_declaration_token1] = ACTIONS(8893),
    [anon_sym_POUNDif] = ACTIONS(8895),
    [anon_sym_POUNDIF] = ACTIONS(8895),
    [anon_sym_POUNDIf] = ACTIONS(8895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8893),
    [sym_procedure_keyword] = ACTIONS(8893),
    [sym_trigger_keyword] = ACTIONS(8893),
    [sym_var_keyword] = ACTIONS(8893),
    [sym_local_keyword] = ACTIONS(8893),
    [sym_internal_keyword] = ACTIONS(8893),
    [sym_protected_keyword] = ACTIONS(8893),
    [sym_event_keyword] = ACTIONS(8893),
    [sym_fields_keyword] = ACTIONS(8893),
    [sym_keys_keyword] = ACTIONS(8893),
    [sym_key_keyword] = ACTIONS(8893),
    [sym_fieldgroups_keyword] = ACTIONS(8893),
    [sym_actions_keyword] = ACTIONS(8893),
    [sym_layout_keyword] = ACTIONS(8893),
    [sym_area_keyword] = ACTIONS(8893),
    [sym_group_keyword] = ACTIONS(8893),
    [sym_repeater_keyword] = ACTIONS(8893),
    [sym_cuegroup_keyword] = ACTIONS(8893),
    [sym_fixed_keyword] = ACTIONS(8893),
    [sym_grid_keyword] = ACTIONS(8893),
    [sym_part_keyword] = ACTIONS(8893),
    [sym_systempart_keyword] = ACTIONS(8893),
    [sym_usercontrol_keyword] = ACTIONS(8893),
    [sym_dataset_keyword] = ACTIONS(8893),
    [sym_elements_keyword] = ACTIONS(8893),
    [sym_dataitem_keyword] = ACTIONS(8893),
    [sym_column_keyword] = ACTIONS(8893),
    [sym_filter_keyword] = ACTIONS(8893),
    [sym_labels_keyword] = ACTIONS(8893),
    [sym_rendering_keyword] = ACTIONS(8893),
    [sym_requestpage_keyword] = ACTIONS(8893),
    [sym_schema_keyword] = ACTIONS(8893),
    [sym_views_keyword] = ACTIONS(8893),
    [sym_quoted_identifier] = ACTIONS(8895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8895),
    [sym_preproc_open] = ACTIONS(8895),
    [sym_var_attribute_open] = ACTIONS(8895),
  },
  [STATE(5786)] = {
    [sym__body_element] = STATE(5825),
    [sym_empty_statement] = STATE(5825),
    [sym_property] = STATE(5825),
    [sym_permissions_property] = STATE(5825),
    [sym_table_relation_property] = STATE(5825),
    [sym_fields_section] = STATE(5825),
    [sym_keys_section] = STATE(5825),
    [sym_fieldgroups_section] = STATE(5825),
    [sym_enum_value_declaration] = STATE(5825),
    [sym_labels_section] = STATE(5825),
    [sym_layout_section] = STATE(5825),
    [sym_modify_modification] = STATE(5825),
    [sym_actions_section] = STATE(5825),
    [sym_views_section] = STATE(5825),
    [sym_dataset_section] = STATE(5825),
    [sym_requestpage_section] = STATE(5825),
    [sym_rendering_section] = STATE(5825),
    [sym_elements_section] = STATE(5825),
    [sym_schema_section] = STATE(5825),
    [sym_assembly_declaration] = STATE(5825),
    [sym_event_declaration] = STATE(5825),
    [sym_procedure] = STATE(5825),
    [sym_preproc_split_procedure] = STATE(5825),
    [sym_preproc_split_procedure_preamble] = STATE(5825),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5825),
    [sym_var_section] = STATE(5825),
    [sym_attribute_item] = STATE(5825),
    [sym_preproc_conditional] = STATE(5825),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5825),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14325),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5787)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14327),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5788)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14329),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5789)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14331),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5790)] = {
    [sym__body_element] = STATE(5615),
    [sym_empty_statement] = STATE(5615),
    [sym_property] = STATE(5615),
    [sym_permissions_property] = STATE(5615),
    [sym_table_relation_property] = STATE(5615),
    [sym_fields_section] = STATE(5615),
    [sym_keys_section] = STATE(5615),
    [sym_fieldgroups_section] = STATE(5615),
    [sym_enum_value_declaration] = STATE(5615),
    [sym_labels_section] = STATE(5615),
    [sym_layout_section] = STATE(5615),
    [sym_modify_modification] = STATE(5615),
    [sym_actions_section] = STATE(5615),
    [sym_views_section] = STATE(5615),
    [sym_dataset_section] = STATE(5615),
    [sym_requestpage_section] = STATE(5615),
    [sym_rendering_section] = STATE(5615),
    [sym_elements_section] = STATE(5615),
    [sym_schema_section] = STATE(5615),
    [sym_assembly_declaration] = STATE(5615),
    [sym_event_declaration] = STATE(5615),
    [sym_procedure] = STATE(5615),
    [sym_preproc_split_procedure] = STATE(5615),
    [sym_preproc_split_procedure_preamble] = STATE(5615),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5615),
    [sym_var_section] = STATE(5615),
    [sym_attribute_item] = STATE(5615),
    [sym_preproc_conditional] = STATE(5615),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5615),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14333),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5791)] = {
    [sym__body_element] = STATE(5792),
    [sym_empty_statement] = STATE(5792),
    [sym_property] = STATE(5792),
    [sym_permissions_property] = STATE(5792),
    [sym_table_relation_property] = STATE(5792),
    [sym_fields_section] = STATE(5792),
    [sym_keys_section] = STATE(5792),
    [sym_fieldgroups_section] = STATE(5792),
    [sym_enum_value_declaration] = STATE(5792),
    [sym_labels_section] = STATE(5792),
    [sym_layout_section] = STATE(5792),
    [sym_modify_modification] = STATE(5792),
    [sym_actions_section] = STATE(5792),
    [sym_views_section] = STATE(5792),
    [sym_dataset_section] = STATE(5792),
    [sym_requestpage_section] = STATE(5792),
    [sym_rendering_section] = STATE(5792),
    [sym_elements_section] = STATE(5792),
    [sym_schema_section] = STATE(5792),
    [sym_assembly_declaration] = STATE(5792),
    [sym_event_declaration] = STATE(5792),
    [sym_procedure] = STATE(5792),
    [sym_preproc_split_procedure] = STATE(5792),
    [sym_preproc_split_procedure_preamble] = STATE(5792),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5792),
    [sym_var_section] = STATE(5792),
    [sym_attribute_item] = STATE(5792),
    [sym_preproc_conditional] = STATE(5792),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5792),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14335),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5792)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14337),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5793)] = {
    [sym_identifier] = ACTIONS(6136),
    [anon_sym_SEMI] = ACTIONS(6138),
    [anon_sym_RBRACE] = ACTIONS(6138),
    [aux_sym_where_condition_token1] = ACTIONS(6136),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6136),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6136),
    [anon_sym_LBRACK] = ACTIONS(6138),
    [aux_sym_basic_type_token6] = ACTIONS(6136),
    [aux_sym_basic_type_token22] = ACTIONS(6136),
    [aux_sym_basic_type_token53] = ACTIONS(6136),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6136),
    [aux_sym_addafter_modification_token1] = ACTIONS(6136),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6136),
    [aux_sym_modify_modification_token1] = ACTIONS(6136),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6136),
    [aux_sym_movelast_modification_token1] = ACTIONS(6136),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6136),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6136),
    [aux_sym_separator_action_token1] = ACTIONS(6136),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6136),
    [aux_sym_type_declaration_token1] = ACTIONS(6136),
    [anon_sym_POUNDif] = ACTIONS(6138),
    [anon_sym_POUNDIF] = ACTIONS(6138),
    [anon_sym_POUNDIf] = ACTIONS(6138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6136),
    [sym_procedure_keyword] = ACTIONS(6136),
    [sym_trigger_keyword] = ACTIONS(6136),
    [sym_var_keyword] = ACTIONS(6136),
    [sym_local_keyword] = ACTIONS(6136),
    [sym_internal_keyword] = ACTIONS(6136),
    [sym_protected_keyword] = ACTIONS(6136),
    [sym_event_keyword] = ACTIONS(6136),
    [sym_fields_keyword] = ACTIONS(6136),
    [sym_keys_keyword] = ACTIONS(6136),
    [sym_key_keyword] = ACTIONS(6136),
    [sym_fieldgroups_keyword] = ACTIONS(6136),
    [sym_actions_keyword] = ACTIONS(6136),
    [sym_layout_keyword] = ACTIONS(6136),
    [sym_area_keyword] = ACTIONS(6136),
    [sym_group_keyword] = ACTIONS(6136),
    [sym_repeater_keyword] = ACTIONS(6136),
    [sym_cuegroup_keyword] = ACTIONS(6136),
    [sym_fixed_keyword] = ACTIONS(6136),
    [sym_grid_keyword] = ACTIONS(6136),
    [sym_part_keyword] = ACTIONS(6136),
    [sym_systempart_keyword] = ACTIONS(6136),
    [sym_usercontrol_keyword] = ACTIONS(6136),
    [sym_dataset_keyword] = ACTIONS(6136),
    [sym_elements_keyword] = ACTIONS(6136),
    [sym_dataitem_keyword] = ACTIONS(6136),
    [sym_column_keyword] = ACTIONS(6136),
    [sym_filter_keyword] = ACTIONS(6136),
    [sym_labels_keyword] = ACTIONS(6136),
    [sym_rendering_keyword] = ACTIONS(6136),
    [sym_requestpage_keyword] = ACTIONS(6136),
    [sym_schema_keyword] = ACTIONS(6136),
    [sym_views_keyword] = ACTIONS(6136),
    [sym_quoted_identifier] = ACTIONS(6138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6138),
    [sym_preproc_open] = ACTIONS(6138),
    [sym_var_attribute_open] = ACTIONS(6138),
  },
  [STATE(5794)] = {
    [sym__body_element] = STATE(5490),
    [sym_empty_statement] = STATE(5490),
    [sym_property] = STATE(5490),
    [sym_permissions_property] = STATE(5490),
    [sym_table_relation_property] = STATE(5490),
    [sym_fields_section] = STATE(5490),
    [sym_keys_section] = STATE(5490),
    [sym_fieldgroups_section] = STATE(5490),
    [sym_enum_value_declaration] = STATE(5490),
    [sym_labels_section] = STATE(5490),
    [sym_layout_section] = STATE(5490),
    [sym_modify_modification] = STATE(5490),
    [sym_actions_section] = STATE(5490),
    [sym_views_section] = STATE(5490),
    [sym_dataset_section] = STATE(5490),
    [sym_requestpage_section] = STATE(5490),
    [sym_rendering_section] = STATE(5490),
    [sym_elements_section] = STATE(5490),
    [sym_schema_section] = STATE(5490),
    [sym_assembly_declaration] = STATE(5490),
    [sym_event_declaration] = STATE(5490),
    [sym_procedure] = STATE(5490),
    [sym_preproc_split_procedure] = STATE(5490),
    [sym_preproc_split_procedure_preamble] = STATE(5490),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5490),
    [sym_var_section] = STATE(5490),
    [sym_attribute_item] = STATE(5490),
    [sym_preproc_conditional] = STATE(5490),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5490),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14339),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5795)] = {
    [sym__body_element] = STATE(5745),
    [sym_empty_statement] = STATE(5745),
    [sym_property] = STATE(5745),
    [sym_permissions_property] = STATE(5745),
    [sym_table_relation_property] = STATE(5745),
    [sym_fields_section] = STATE(5745),
    [sym_keys_section] = STATE(5745),
    [sym_fieldgroups_section] = STATE(5745),
    [sym_enum_value_declaration] = STATE(5745),
    [sym_labels_section] = STATE(5745),
    [sym_layout_section] = STATE(5745),
    [sym_modify_modification] = STATE(5745),
    [sym_actions_section] = STATE(5745),
    [sym_views_section] = STATE(5745),
    [sym_dataset_section] = STATE(5745),
    [sym_requestpage_section] = STATE(5745),
    [sym_rendering_section] = STATE(5745),
    [sym_elements_section] = STATE(5745),
    [sym_schema_section] = STATE(5745),
    [sym_assembly_declaration] = STATE(5745),
    [sym_event_declaration] = STATE(5745),
    [sym_procedure] = STATE(5745),
    [sym_preproc_split_procedure] = STATE(5745),
    [sym_preproc_split_procedure_preamble] = STATE(5745),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5745),
    [sym_var_section] = STATE(5745),
    [sym_attribute_item] = STATE(5745),
    [sym_preproc_conditional] = STATE(5745),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5745),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14341),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5796)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14343),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5797)] = {
    [sym__body_element] = STATE(5536),
    [sym_empty_statement] = STATE(5536),
    [sym_property] = STATE(5536),
    [sym_permissions_property] = STATE(5536),
    [sym_table_relation_property] = STATE(5536),
    [sym_fields_section] = STATE(5536),
    [sym_keys_section] = STATE(5536),
    [sym_fieldgroups_section] = STATE(5536),
    [sym_enum_value_declaration] = STATE(5536),
    [sym_labels_section] = STATE(5536),
    [sym_layout_section] = STATE(5536),
    [sym_modify_modification] = STATE(5536),
    [sym_actions_section] = STATE(5536),
    [sym_views_section] = STATE(5536),
    [sym_dataset_section] = STATE(5536),
    [sym_requestpage_section] = STATE(5536),
    [sym_rendering_section] = STATE(5536),
    [sym_elements_section] = STATE(5536),
    [sym_schema_section] = STATE(5536),
    [sym_assembly_declaration] = STATE(5536),
    [sym_event_declaration] = STATE(5536),
    [sym_procedure] = STATE(5536),
    [sym_preproc_split_procedure] = STATE(5536),
    [sym_preproc_split_procedure_preamble] = STATE(5536),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5536),
    [sym_var_section] = STATE(5536),
    [sym_attribute_item] = STATE(5536),
    [sym_preproc_conditional] = STATE(5536),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5536),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14345),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5798)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14347),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5799)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14349),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5800)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14351),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5801)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14353),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5802)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14355),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5803)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14357),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5804)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14359),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5805)] = {
    [sym__body_element] = STATE(5637),
    [sym_empty_statement] = STATE(5637),
    [sym_property] = STATE(5637),
    [sym_permissions_property] = STATE(5637),
    [sym_table_relation_property] = STATE(5637),
    [sym_fields_section] = STATE(5637),
    [sym_keys_section] = STATE(5637),
    [sym_fieldgroups_section] = STATE(5637),
    [sym_enum_value_declaration] = STATE(5637),
    [sym_labels_section] = STATE(5637),
    [sym_layout_section] = STATE(5637),
    [sym_modify_modification] = STATE(5637),
    [sym_actions_section] = STATE(5637),
    [sym_views_section] = STATE(5637),
    [sym_dataset_section] = STATE(5637),
    [sym_requestpage_section] = STATE(5637),
    [sym_rendering_section] = STATE(5637),
    [sym_elements_section] = STATE(5637),
    [sym_schema_section] = STATE(5637),
    [sym_assembly_declaration] = STATE(5637),
    [sym_event_declaration] = STATE(5637),
    [sym_procedure] = STATE(5637),
    [sym_preproc_split_procedure] = STATE(5637),
    [sym_preproc_split_procedure_preamble] = STATE(5637),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5637),
    [sym_var_section] = STATE(5637),
    [sym_attribute_item] = STATE(5637),
    [sym_preproc_conditional] = STATE(5637),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5637),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14361),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5806)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14363),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5807)] = {
    [sym__body_element] = STATE(5640),
    [sym_empty_statement] = STATE(5640),
    [sym_property] = STATE(5640),
    [sym_permissions_property] = STATE(5640),
    [sym_table_relation_property] = STATE(5640),
    [sym_fields_section] = STATE(5640),
    [sym_keys_section] = STATE(5640),
    [sym_fieldgroups_section] = STATE(5640),
    [sym_enum_value_declaration] = STATE(5640),
    [sym_labels_section] = STATE(5640),
    [sym_layout_section] = STATE(5640),
    [sym_modify_modification] = STATE(5640),
    [sym_actions_section] = STATE(5640),
    [sym_views_section] = STATE(5640),
    [sym_dataset_section] = STATE(5640),
    [sym_requestpage_section] = STATE(5640),
    [sym_rendering_section] = STATE(5640),
    [sym_elements_section] = STATE(5640),
    [sym_schema_section] = STATE(5640),
    [sym_assembly_declaration] = STATE(5640),
    [sym_event_declaration] = STATE(5640),
    [sym_procedure] = STATE(5640),
    [sym_preproc_split_procedure] = STATE(5640),
    [sym_preproc_split_procedure_preamble] = STATE(5640),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5640),
    [sym_var_section] = STATE(5640),
    [sym_attribute_item] = STATE(5640),
    [sym_preproc_conditional] = STATE(5640),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5640),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14365),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5808)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14367),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5809)] = {
    [sym__body_element] = STATE(5829),
    [sym_empty_statement] = STATE(5829),
    [sym_property] = STATE(5829),
    [sym_permissions_property] = STATE(5829),
    [sym_table_relation_property] = STATE(5829),
    [sym_fields_section] = STATE(5829),
    [sym_keys_section] = STATE(5829),
    [sym_fieldgroups_section] = STATE(5829),
    [sym_enum_value_declaration] = STATE(5829),
    [sym_labels_section] = STATE(5829),
    [sym_layout_section] = STATE(5829),
    [sym_modify_modification] = STATE(5829),
    [sym_actions_section] = STATE(5829),
    [sym_views_section] = STATE(5829),
    [sym_dataset_section] = STATE(5829),
    [sym_requestpage_section] = STATE(5829),
    [sym_rendering_section] = STATE(5829),
    [sym_elements_section] = STATE(5829),
    [sym_schema_section] = STATE(5829),
    [sym_assembly_declaration] = STATE(5829),
    [sym_event_declaration] = STATE(5829),
    [sym_procedure] = STATE(5829),
    [sym_preproc_split_procedure] = STATE(5829),
    [sym_preproc_split_procedure_preamble] = STATE(5829),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5829),
    [sym_var_section] = STATE(5829),
    [sym_attribute_item] = STATE(5829),
    [sym_preproc_conditional] = STATE(5829),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5829),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14369),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5810)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14371),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5811)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14373),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5812)] = {
    [sym__body_element] = STATE(5456),
    [sym_empty_statement] = STATE(5456),
    [sym_property] = STATE(5456),
    [sym_permissions_property] = STATE(5456),
    [sym_table_relation_property] = STATE(5456),
    [sym_fields_section] = STATE(5456),
    [sym_keys_section] = STATE(5456),
    [sym_fieldgroups_section] = STATE(5456),
    [sym_enum_value_declaration] = STATE(5456),
    [sym_labels_section] = STATE(5456),
    [sym_layout_section] = STATE(5456),
    [sym_modify_modification] = STATE(5456),
    [sym_actions_section] = STATE(5456),
    [sym_views_section] = STATE(5456),
    [sym_dataset_section] = STATE(5456),
    [sym_requestpage_section] = STATE(5456),
    [sym_rendering_section] = STATE(5456),
    [sym_elements_section] = STATE(5456),
    [sym_schema_section] = STATE(5456),
    [sym_assembly_declaration] = STATE(5456),
    [sym_event_declaration] = STATE(5456),
    [sym_procedure] = STATE(5456),
    [sym_preproc_split_procedure] = STATE(5456),
    [sym_preproc_split_procedure_preamble] = STATE(5456),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5456),
    [sym_var_section] = STATE(5456),
    [sym_attribute_item] = STATE(5456),
    [sym_preproc_conditional] = STATE(5456),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5456),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14375),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5813)] = {
    [sym__body_element] = STATE(5458),
    [sym_empty_statement] = STATE(5458),
    [sym_property] = STATE(5458),
    [sym_permissions_property] = STATE(5458),
    [sym_table_relation_property] = STATE(5458),
    [sym_fields_section] = STATE(5458),
    [sym_keys_section] = STATE(5458),
    [sym_fieldgroups_section] = STATE(5458),
    [sym_enum_value_declaration] = STATE(5458),
    [sym_labels_section] = STATE(5458),
    [sym_layout_section] = STATE(5458),
    [sym_modify_modification] = STATE(5458),
    [sym_actions_section] = STATE(5458),
    [sym_views_section] = STATE(5458),
    [sym_dataset_section] = STATE(5458),
    [sym_requestpage_section] = STATE(5458),
    [sym_rendering_section] = STATE(5458),
    [sym_elements_section] = STATE(5458),
    [sym_schema_section] = STATE(5458),
    [sym_assembly_declaration] = STATE(5458),
    [sym_event_declaration] = STATE(5458),
    [sym_procedure] = STATE(5458),
    [sym_preproc_split_procedure] = STATE(5458),
    [sym_preproc_split_procedure_preamble] = STATE(5458),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5458),
    [sym_var_section] = STATE(5458),
    [sym_attribute_item] = STATE(5458),
    [sym_preproc_conditional] = STATE(5458),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5458),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14377),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5814)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14379),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5815)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14381),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5816)] = {
    [sym__body_element] = STATE(5461),
    [sym_empty_statement] = STATE(5461),
    [sym_property] = STATE(5461),
    [sym_permissions_property] = STATE(5461),
    [sym_table_relation_property] = STATE(5461),
    [sym_fields_section] = STATE(5461),
    [sym_keys_section] = STATE(5461),
    [sym_fieldgroups_section] = STATE(5461),
    [sym_enum_value_declaration] = STATE(5461),
    [sym_labels_section] = STATE(5461),
    [sym_layout_section] = STATE(5461),
    [sym_modify_modification] = STATE(5461),
    [sym_actions_section] = STATE(5461),
    [sym_views_section] = STATE(5461),
    [sym_dataset_section] = STATE(5461),
    [sym_requestpage_section] = STATE(5461),
    [sym_rendering_section] = STATE(5461),
    [sym_elements_section] = STATE(5461),
    [sym_schema_section] = STATE(5461),
    [sym_assembly_declaration] = STATE(5461),
    [sym_event_declaration] = STATE(5461),
    [sym_procedure] = STATE(5461),
    [sym_preproc_split_procedure] = STATE(5461),
    [sym_preproc_split_procedure_preamble] = STATE(5461),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5461),
    [sym_var_section] = STATE(5461),
    [sym_attribute_item] = STATE(5461),
    [sym_preproc_conditional] = STATE(5461),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5461),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14383),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5817)] = {
    [sym__body_element] = STATE(5463),
    [sym_empty_statement] = STATE(5463),
    [sym_property] = STATE(5463),
    [sym_permissions_property] = STATE(5463),
    [sym_table_relation_property] = STATE(5463),
    [sym_fields_section] = STATE(5463),
    [sym_keys_section] = STATE(5463),
    [sym_fieldgroups_section] = STATE(5463),
    [sym_enum_value_declaration] = STATE(5463),
    [sym_labels_section] = STATE(5463),
    [sym_layout_section] = STATE(5463),
    [sym_modify_modification] = STATE(5463),
    [sym_actions_section] = STATE(5463),
    [sym_views_section] = STATE(5463),
    [sym_dataset_section] = STATE(5463),
    [sym_requestpage_section] = STATE(5463),
    [sym_rendering_section] = STATE(5463),
    [sym_elements_section] = STATE(5463),
    [sym_schema_section] = STATE(5463),
    [sym_assembly_declaration] = STATE(5463),
    [sym_event_declaration] = STATE(5463),
    [sym_procedure] = STATE(5463),
    [sym_preproc_split_procedure] = STATE(5463),
    [sym_preproc_split_procedure_preamble] = STATE(5463),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5463),
    [sym_var_section] = STATE(5463),
    [sym_attribute_item] = STATE(5463),
    [sym_preproc_conditional] = STATE(5463),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5463),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14385),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5818)] = {
    [sym_identifier] = ACTIONS(6124),
    [anon_sym_SEMI] = ACTIONS(6126),
    [anon_sym_RBRACE] = ACTIONS(6126),
    [aux_sym_where_condition_token1] = ACTIONS(6124),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(6124),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(6124),
    [anon_sym_LBRACK] = ACTIONS(6126),
    [aux_sym_basic_type_token6] = ACTIONS(6124),
    [aux_sym_basic_type_token22] = ACTIONS(6124),
    [aux_sym_basic_type_token53] = ACTIONS(6124),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6124),
    [aux_sym_addafter_modification_token1] = ACTIONS(6124),
    [aux_sym_addbefore_modification_token1] = ACTIONS(6124),
    [aux_sym_modify_modification_token1] = ACTIONS(6124),
    [aux_sym_movefirst_modification_token1] = ACTIONS(6124),
    [aux_sym_movelast_modification_token1] = ACTIONS(6124),
    [aux_sym_moveafter_modification_token1] = ACTIONS(6124),
    [aux_sym_movebefore_modification_token1] = ACTIONS(6124),
    [aux_sym_separator_action_token1] = ACTIONS(6124),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6124),
    [aux_sym_type_declaration_token1] = ACTIONS(6124),
    [anon_sym_POUNDif] = ACTIONS(6126),
    [anon_sym_POUNDIF] = ACTIONS(6126),
    [anon_sym_POUNDIf] = ACTIONS(6126),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6124),
    [sym_procedure_keyword] = ACTIONS(6124),
    [sym_trigger_keyword] = ACTIONS(6124),
    [sym_var_keyword] = ACTIONS(6124),
    [sym_local_keyword] = ACTIONS(6124),
    [sym_internal_keyword] = ACTIONS(6124),
    [sym_protected_keyword] = ACTIONS(6124),
    [sym_event_keyword] = ACTIONS(6124),
    [sym_fields_keyword] = ACTIONS(6124),
    [sym_keys_keyword] = ACTIONS(6124),
    [sym_key_keyword] = ACTIONS(6124),
    [sym_fieldgroups_keyword] = ACTIONS(6124),
    [sym_actions_keyword] = ACTIONS(6124),
    [sym_layout_keyword] = ACTIONS(6124),
    [sym_area_keyword] = ACTIONS(6124),
    [sym_group_keyword] = ACTIONS(6124),
    [sym_repeater_keyword] = ACTIONS(6124),
    [sym_cuegroup_keyword] = ACTIONS(6124),
    [sym_fixed_keyword] = ACTIONS(6124),
    [sym_grid_keyword] = ACTIONS(6124),
    [sym_part_keyword] = ACTIONS(6124),
    [sym_systempart_keyword] = ACTIONS(6124),
    [sym_usercontrol_keyword] = ACTIONS(6124),
    [sym_dataset_keyword] = ACTIONS(6124),
    [sym_elements_keyword] = ACTIONS(6124),
    [sym_dataitem_keyword] = ACTIONS(6124),
    [sym_column_keyword] = ACTIONS(6124),
    [sym_filter_keyword] = ACTIONS(6124),
    [sym_labels_keyword] = ACTIONS(6124),
    [sym_rendering_keyword] = ACTIONS(6124),
    [sym_requestpage_keyword] = ACTIONS(6124),
    [sym_schema_keyword] = ACTIONS(6124),
    [sym_views_keyword] = ACTIONS(6124),
    [sym_quoted_identifier] = ACTIONS(6126),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6126),
    [sym_preproc_open] = ACTIONS(6126),
    [sym_var_attribute_open] = ACTIONS(6126),
  },
  [STATE(5819)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14387),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5820)] = {
    [sym__body_element] = STATE(5835),
    [sym_empty_statement] = STATE(5835),
    [sym_property] = STATE(5835),
    [sym_permissions_property] = STATE(5835),
    [sym_table_relation_property] = STATE(5835),
    [sym_fields_section] = STATE(5835),
    [sym_keys_section] = STATE(5835),
    [sym_fieldgroups_section] = STATE(5835),
    [sym_enum_value_declaration] = STATE(5835),
    [sym_labels_section] = STATE(5835),
    [sym_layout_section] = STATE(5835),
    [sym_modify_modification] = STATE(5835),
    [sym_actions_section] = STATE(5835),
    [sym_views_section] = STATE(5835),
    [sym_dataset_section] = STATE(5835),
    [sym_requestpage_section] = STATE(5835),
    [sym_rendering_section] = STATE(5835),
    [sym_elements_section] = STATE(5835),
    [sym_schema_section] = STATE(5835),
    [sym_assembly_declaration] = STATE(5835),
    [sym_event_declaration] = STATE(5835),
    [sym_procedure] = STATE(5835),
    [sym_preproc_split_procedure] = STATE(5835),
    [sym_preproc_split_procedure_preamble] = STATE(5835),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5835),
    [sym_var_section] = STATE(5835),
    [sym_attribute_item] = STATE(5835),
    [sym_preproc_conditional] = STATE(5835),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5835),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14389),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5821)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14391),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5822)] = {
    [sym__body_element] = STATE(5731),
    [sym_empty_statement] = STATE(5731),
    [sym_property] = STATE(5731),
    [sym_permissions_property] = STATE(5731),
    [sym_table_relation_property] = STATE(5731),
    [sym_fields_section] = STATE(5731),
    [sym_keys_section] = STATE(5731),
    [sym_fieldgroups_section] = STATE(5731),
    [sym_enum_value_declaration] = STATE(5731),
    [sym_labels_section] = STATE(5731),
    [sym_layout_section] = STATE(5731),
    [sym_modify_modification] = STATE(5731),
    [sym_actions_section] = STATE(5731),
    [sym_views_section] = STATE(5731),
    [sym_dataset_section] = STATE(5731),
    [sym_requestpage_section] = STATE(5731),
    [sym_rendering_section] = STATE(5731),
    [sym_elements_section] = STATE(5731),
    [sym_schema_section] = STATE(5731),
    [sym_assembly_declaration] = STATE(5731),
    [sym_event_declaration] = STATE(5731),
    [sym_procedure] = STATE(5731),
    [sym_preproc_split_procedure] = STATE(5731),
    [sym_preproc_split_procedure_preamble] = STATE(5731),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5731),
    [sym_var_section] = STATE(5731),
    [sym_attribute_item] = STATE(5731),
    [sym_preproc_conditional] = STATE(5731),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5731),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14393),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5823)] = {
    [sym__body_element] = STATE(5836),
    [sym_empty_statement] = STATE(5836),
    [sym_property] = STATE(5836),
    [sym_permissions_property] = STATE(5836),
    [sym_table_relation_property] = STATE(5836),
    [sym_fields_section] = STATE(5836),
    [sym_keys_section] = STATE(5836),
    [sym_fieldgroups_section] = STATE(5836),
    [sym_enum_value_declaration] = STATE(5836),
    [sym_labels_section] = STATE(5836),
    [sym_layout_section] = STATE(5836),
    [sym_modify_modification] = STATE(5836),
    [sym_actions_section] = STATE(5836),
    [sym_views_section] = STATE(5836),
    [sym_dataset_section] = STATE(5836),
    [sym_requestpage_section] = STATE(5836),
    [sym_rendering_section] = STATE(5836),
    [sym_elements_section] = STATE(5836),
    [sym_schema_section] = STATE(5836),
    [sym_assembly_declaration] = STATE(5836),
    [sym_event_declaration] = STATE(5836),
    [sym_procedure] = STATE(5836),
    [sym_preproc_split_procedure] = STATE(5836),
    [sym_preproc_split_procedure_preamble] = STATE(5836),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5836),
    [sym_var_section] = STATE(5836),
    [sym_attribute_item] = STATE(5836),
    [sym_preproc_conditional] = STATE(5836),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5836),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14395),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5824)] = {
    [sym__body_element] = STATE(5543),
    [sym_empty_statement] = STATE(5543),
    [sym_property] = STATE(5543),
    [sym_permissions_property] = STATE(5543),
    [sym_table_relation_property] = STATE(5543),
    [sym_fields_section] = STATE(5543),
    [sym_keys_section] = STATE(5543),
    [sym_fieldgroups_section] = STATE(5543),
    [sym_enum_value_declaration] = STATE(5543),
    [sym_labels_section] = STATE(5543),
    [sym_layout_section] = STATE(5543),
    [sym_modify_modification] = STATE(5543),
    [sym_actions_section] = STATE(5543),
    [sym_views_section] = STATE(5543),
    [sym_dataset_section] = STATE(5543),
    [sym_requestpage_section] = STATE(5543),
    [sym_rendering_section] = STATE(5543),
    [sym_elements_section] = STATE(5543),
    [sym_schema_section] = STATE(5543),
    [sym_assembly_declaration] = STATE(5543),
    [sym_event_declaration] = STATE(5543),
    [sym_procedure] = STATE(5543),
    [sym_preproc_split_procedure] = STATE(5543),
    [sym_preproc_split_procedure_preamble] = STATE(5543),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5543),
    [sym_var_section] = STATE(5543),
    [sym_attribute_item] = STATE(5543),
    [sym_preproc_conditional] = STATE(5543),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5543),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14397),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5825)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14399),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5826)] = {
    [sym__body_element] = STATE(5837),
    [sym_empty_statement] = STATE(5837),
    [sym_property] = STATE(5837),
    [sym_permissions_property] = STATE(5837),
    [sym_table_relation_property] = STATE(5837),
    [sym_fields_section] = STATE(5837),
    [sym_keys_section] = STATE(5837),
    [sym_fieldgroups_section] = STATE(5837),
    [sym_enum_value_declaration] = STATE(5837),
    [sym_labels_section] = STATE(5837),
    [sym_layout_section] = STATE(5837),
    [sym_modify_modification] = STATE(5837),
    [sym_actions_section] = STATE(5837),
    [sym_views_section] = STATE(5837),
    [sym_dataset_section] = STATE(5837),
    [sym_requestpage_section] = STATE(5837),
    [sym_rendering_section] = STATE(5837),
    [sym_elements_section] = STATE(5837),
    [sym_schema_section] = STATE(5837),
    [sym_assembly_declaration] = STATE(5837),
    [sym_event_declaration] = STATE(5837),
    [sym_procedure] = STATE(5837),
    [sym_preproc_split_procedure] = STATE(5837),
    [sym_preproc_split_procedure_preamble] = STATE(5837),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5837),
    [sym_var_section] = STATE(5837),
    [sym_attribute_item] = STATE(5837),
    [sym_preproc_conditional] = STATE(5837),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5837),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14401),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5827)] = {
    [sym__body_element] = STATE(5838),
    [sym_empty_statement] = STATE(5838),
    [sym_property] = STATE(5838),
    [sym_permissions_property] = STATE(5838),
    [sym_table_relation_property] = STATE(5838),
    [sym_fields_section] = STATE(5838),
    [sym_keys_section] = STATE(5838),
    [sym_fieldgroups_section] = STATE(5838),
    [sym_enum_value_declaration] = STATE(5838),
    [sym_labels_section] = STATE(5838),
    [sym_layout_section] = STATE(5838),
    [sym_modify_modification] = STATE(5838),
    [sym_actions_section] = STATE(5838),
    [sym_views_section] = STATE(5838),
    [sym_dataset_section] = STATE(5838),
    [sym_requestpage_section] = STATE(5838),
    [sym_rendering_section] = STATE(5838),
    [sym_elements_section] = STATE(5838),
    [sym_schema_section] = STATE(5838),
    [sym_assembly_declaration] = STATE(5838),
    [sym_event_declaration] = STATE(5838),
    [sym_procedure] = STATE(5838),
    [sym_preproc_split_procedure] = STATE(5838),
    [sym_preproc_split_procedure_preamble] = STATE(5838),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5838),
    [sym_var_section] = STATE(5838),
    [sym_attribute_item] = STATE(5838),
    [sym_preproc_conditional] = STATE(5838),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5838),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14403),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5828)] = {
    [sym__body_element] = STATE(5839),
    [sym_empty_statement] = STATE(5839),
    [sym_property] = STATE(5839),
    [sym_permissions_property] = STATE(5839),
    [sym_table_relation_property] = STATE(5839),
    [sym_fields_section] = STATE(5839),
    [sym_keys_section] = STATE(5839),
    [sym_fieldgroups_section] = STATE(5839),
    [sym_enum_value_declaration] = STATE(5839),
    [sym_labels_section] = STATE(5839),
    [sym_layout_section] = STATE(5839),
    [sym_modify_modification] = STATE(5839),
    [sym_actions_section] = STATE(5839),
    [sym_views_section] = STATE(5839),
    [sym_dataset_section] = STATE(5839),
    [sym_requestpage_section] = STATE(5839),
    [sym_rendering_section] = STATE(5839),
    [sym_elements_section] = STATE(5839),
    [sym_schema_section] = STATE(5839),
    [sym_assembly_declaration] = STATE(5839),
    [sym_event_declaration] = STATE(5839),
    [sym_procedure] = STATE(5839),
    [sym_preproc_split_procedure] = STATE(5839),
    [sym_preproc_split_procedure_preamble] = STATE(5839),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5839),
    [sym_var_section] = STATE(5839),
    [sym_attribute_item] = STATE(5839),
    [sym_preproc_conditional] = STATE(5839),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5839),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14405),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5829)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14407),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5830)] = {
    [sym__body_element] = STATE(5840),
    [sym_empty_statement] = STATE(5840),
    [sym_property] = STATE(5840),
    [sym_permissions_property] = STATE(5840),
    [sym_table_relation_property] = STATE(5840),
    [sym_fields_section] = STATE(5840),
    [sym_keys_section] = STATE(5840),
    [sym_fieldgroups_section] = STATE(5840),
    [sym_enum_value_declaration] = STATE(5840),
    [sym_labels_section] = STATE(5840),
    [sym_layout_section] = STATE(5840),
    [sym_modify_modification] = STATE(5840),
    [sym_actions_section] = STATE(5840),
    [sym_views_section] = STATE(5840),
    [sym_dataset_section] = STATE(5840),
    [sym_requestpage_section] = STATE(5840),
    [sym_rendering_section] = STATE(5840),
    [sym_elements_section] = STATE(5840),
    [sym_schema_section] = STATE(5840),
    [sym_assembly_declaration] = STATE(5840),
    [sym_event_declaration] = STATE(5840),
    [sym_procedure] = STATE(5840),
    [sym_preproc_split_procedure] = STATE(5840),
    [sym_preproc_split_procedure_preamble] = STATE(5840),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5840),
    [sym_var_section] = STATE(5840),
    [sym_attribute_item] = STATE(5840),
    [sym_preproc_conditional] = STATE(5840),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5840),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14409),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5831)] = {
    [sym__body_element] = STATE(5464),
    [sym_empty_statement] = STATE(5464),
    [sym_property] = STATE(5464),
    [sym_permissions_property] = STATE(5464),
    [sym_table_relation_property] = STATE(5464),
    [sym_fields_section] = STATE(5464),
    [sym_keys_section] = STATE(5464),
    [sym_fieldgroups_section] = STATE(5464),
    [sym_enum_value_declaration] = STATE(5464),
    [sym_labels_section] = STATE(5464),
    [sym_layout_section] = STATE(5464),
    [sym_modify_modification] = STATE(5464),
    [sym_actions_section] = STATE(5464),
    [sym_views_section] = STATE(5464),
    [sym_dataset_section] = STATE(5464),
    [sym_requestpage_section] = STATE(5464),
    [sym_rendering_section] = STATE(5464),
    [sym_elements_section] = STATE(5464),
    [sym_schema_section] = STATE(5464),
    [sym_assembly_declaration] = STATE(5464),
    [sym_event_declaration] = STATE(5464),
    [sym_procedure] = STATE(5464),
    [sym_preproc_split_procedure] = STATE(5464),
    [sym_preproc_split_procedure_preamble] = STATE(5464),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5464),
    [sym_var_section] = STATE(5464),
    [sym_attribute_item] = STATE(5464),
    [sym_preproc_conditional] = STATE(5464),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5464),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14411),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5832)] = {
    [sym__body_element] = STATE(5781),
    [sym_empty_statement] = STATE(5781),
    [sym_property] = STATE(5781),
    [sym_permissions_property] = STATE(5781),
    [sym_table_relation_property] = STATE(5781),
    [sym_fields_section] = STATE(5781),
    [sym_keys_section] = STATE(5781),
    [sym_fieldgroups_section] = STATE(5781),
    [sym_enum_value_declaration] = STATE(5781),
    [sym_labels_section] = STATE(5781),
    [sym_layout_section] = STATE(5781),
    [sym_modify_modification] = STATE(5781),
    [sym_actions_section] = STATE(5781),
    [sym_views_section] = STATE(5781),
    [sym_dataset_section] = STATE(5781),
    [sym_requestpage_section] = STATE(5781),
    [sym_rendering_section] = STATE(5781),
    [sym_elements_section] = STATE(5781),
    [sym_schema_section] = STATE(5781),
    [sym_assembly_declaration] = STATE(5781),
    [sym_event_declaration] = STATE(5781),
    [sym_procedure] = STATE(5781),
    [sym_preproc_split_procedure] = STATE(5781),
    [sym_preproc_split_procedure_preamble] = STATE(5781),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5781),
    [sym_var_section] = STATE(5781),
    [sym_attribute_item] = STATE(5781),
    [sym_preproc_conditional] = STATE(5781),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5781),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14413),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5833)] = {
    [sym__body_element] = STATE(5465),
    [sym_empty_statement] = STATE(5465),
    [sym_property] = STATE(5465),
    [sym_permissions_property] = STATE(5465),
    [sym_table_relation_property] = STATE(5465),
    [sym_fields_section] = STATE(5465),
    [sym_keys_section] = STATE(5465),
    [sym_fieldgroups_section] = STATE(5465),
    [sym_enum_value_declaration] = STATE(5465),
    [sym_labels_section] = STATE(5465),
    [sym_layout_section] = STATE(5465),
    [sym_modify_modification] = STATE(5465),
    [sym_actions_section] = STATE(5465),
    [sym_views_section] = STATE(5465),
    [sym_dataset_section] = STATE(5465),
    [sym_requestpage_section] = STATE(5465),
    [sym_rendering_section] = STATE(5465),
    [sym_elements_section] = STATE(5465),
    [sym_schema_section] = STATE(5465),
    [sym_assembly_declaration] = STATE(5465),
    [sym_event_declaration] = STATE(5465),
    [sym_procedure] = STATE(5465),
    [sym_preproc_split_procedure] = STATE(5465),
    [sym_preproc_split_procedure_preamble] = STATE(5465),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5465),
    [sym_var_section] = STATE(5465),
    [sym_attribute_item] = STATE(5465),
    [sym_preproc_conditional] = STATE(5465),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5465),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14415),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5834)] = {
    [sym__body_element] = STATE(5539),
    [sym_empty_statement] = STATE(5539),
    [sym_property] = STATE(5539),
    [sym_permissions_property] = STATE(5539),
    [sym_table_relation_property] = STATE(5539),
    [sym_fields_section] = STATE(5539),
    [sym_keys_section] = STATE(5539),
    [sym_fieldgroups_section] = STATE(5539),
    [sym_enum_value_declaration] = STATE(5539),
    [sym_labels_section] = STATE(5539),
    [sym_layout_section] = STATE(5539),
    [sym_modify_modification] = STATE(5539),
    [sym_actions_section] = STATE(5539),
    [sym_views_section] = STATE(5539),
    [sym_dataset_section] = STATE(5539),
    [sym_requestpage_section] = STATE(5539),
    [sym_rendering_section] = STATE(5539),
    [sym_elements_section] = STATE(5539),
    [sym_schema_section] = STATE(5539),
    [sym_assembly_declaration] = STATE(5539),
    [sym_event_declaration] = STATE(5539),
    [sym_procedure] = STATE(5539),
    [sym_preproc_split_procedure] = STATE(5539),
    [sym_preproc_split_procedure_preamble] = STATE(5539),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5539),
    [sym_var_section] = STATE(5539),
    [sym_attribute_item] = STATE(5539),
    [sym_preproc_conditional] = STATE(5539),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5539),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14417),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5835)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14419),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5836)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14421),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5837)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14423),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5838)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14425),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5839)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14427),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5840)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14429),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5841)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14431),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5842)] = {
    [sym__body_element] = STATE(5666),
    [sym_empty_statement] = STATE(5666),
    [sym_property] = STATE(5666),
    [sym_permissions_property] = STATE(5666),
    [sym_table_relation_property] = STATE(5666),
    [sym_fields_section] = STATE(5666),
    [sym_keys_section] = STATE(5666),
    [sym_fieldgroups_section] = STATE(5666),
    [sym_enum_value_declaration] = STATE(5666),
    [sym_labels_section] = STATE(5666),
    [sym_layout_section] = STATE(5666),
    [sym_modify_modification] = STATE(5666),
    [sym_actions_section] = STATE(5666),
    [sym_views_section] = STATE(5666),
    [sym_dataset_section] = STATE(5666),
    [sym_requestpage_section] = STATE(5666),
    [sym_rendering_section] = STATE(5666),
    [sym_elements_section] = STATE(5666),
    [sym_schema_section] = STATE(5666),
    [sym_assembly_declaration] = STATE(5666),
    [sym_event_declaration] = STATE(5666),
    [sym_procedure] = STATE(5666),
    [sym_preproc_split_procedure] = STATE(5666),
    [sym_preproc_split_procedure_preamble] = STATE(5666),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5666),
    [sym_var_section] = STATE(5666),
    [sym_attribute_item] = STATE(5666),
    [sym_preproc_conditional] = STATE(5666),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5666),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14433),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5843)] = {
    [sym__body_element] = STATE(5477),
    [sym_empty_statement] = STATE(5477),
    [sym_property] = STATE(5477),
    [sym_permissions_property] = STATE(5477),
    [sym_table_relation_property] = STATE(5477),
    [sym_fields_section] = STATE(5477),
    [sym_keys_section] = STATE(5477),
    [sym_fieldgroups_section] = STATE(5477),
    [sym_enum_value_declaration] = STATE(5477),
    [sym_labels_section] = STATE(5477),
    [sym_layout_section] = STATE(5477),
    [sym_modify_modification] = STATE(5477),
    [sym_actions_section] = STATE(5477),
    [sym_views_section] = STATE(5477),
    [sym_dataset_section] = STATE(5477),
    [sym_requestpage_section] = STATE(5477),
    [sym_rendering_section] = STATE(5477),
    [sym_elements_section] = STATE(5477),
    [sym_schema_section] = STATE(5477),
    [sym_assembly_declaration] = STATE(5477),
    [sym_event_declaration] = STATE(5477),
    [sym_procedure] = STATE(5477),
    [sym_preproc_split_procedure] = STATE(5477),
    [sym_preproc_split_procedure_preamble] = STATE(5477),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5477),
    [sym_var_section] = STATE(5477),
    [sym_attribute_item] = STATE(5477),
    [sym_preproc_conditional] = STATE(5477),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5477),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14435),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5844)] = {
    [sym__body_element] = STATE(5643),
    [sym_empty_statement] = STATE(5643),
    [sym_property] = STATE(5643),
    [sym_permissions_property] = STATE(5643),
    [sym_table_relation_property] = STATE(5643),
    [sym_fields_section] = STATE(5643),
    [sym_keys_section] = STATE(5643),
    [sym_fieldgroups_section] = STATE(5643),
    [sym_enum_value_declaration] = STATE(5643),
    [sym_labels_section] = STATE(5643),
    [sym_layout_section] = STATE(5643),
    [sym_modify_modification] = STATE(5643),
    [sym_actions_section] = STATE(5643),
    [sym_views_section] = STATE(5643),
    [sym_dataset_section] = STATE(5643),
    [sym_requestpage_section] = STATE(5643),
    [sym_rendering_section] = STATE(5643),
    [sym_elements_section] = STATE(5643),
    [sym_schema_section] = STATE(5643),
    [sym_assembly_declaration] = STATE(5643),
    [sym_event_declaration] = STATE(5643),
    [sym_procedure] = STATE(5643),
    [sym_preproc_split_procedure] = STATE(5643),
    [sym_preproc_split_procedure_preamble] = STATE(5643),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5643),
    [sym_var_section] = STATE(5643),
    [sym_attribute_item] = STATE(5643),
    [sym_preproc_conditional] = STATE(5643),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5643),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14437),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5845)] = {
    [sym__body_element] = STATE(5517),
    [sym_empty_statement] = STATE(5517),
    [sym_property] = STATE(5517),
    [sym_permissions_property] = STATE(5517),
    [sym_table_relation_property] = STATE(5517),
    [sym_fields_section] = STATE(5517),
    [sym_keys_section] = STATE(5517),
    [sym_fieldgroups_section] = STATE(5517),
    [sym_enum_value_declaration] = STATE(5517),
    [sym_labels_section] = STATE(5517),
    [sym_layout_section] = STATE(5517),
    [sym_modify_modification] = STATE(5517),
    [sym_actions_section] = STATE(5517),
    [sym_views_section] = STATE(5517),
    [sym_dataset_section] = STATE(5517),
    [sym_requestpage_section] = STATE(5517),
    [sym_rendering_section] = STATE(5517),
    [sym_elements_section] = STATE(5517),
    [sym_schema_section] = STATE(5517),
    [sym_assembly_declaration] = STATE(5517),
    [sym_event_declaration] = STATE(5517),
    [sym_procedure] = STATE(5517),
    [sym_preproc_split_procedure] = STATE(5517),
    [sym_preproc_split_procedure_preamble] = STATE(5517),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5517),
    [sym_var_section] = STATE(5517),
    [sym_attribute_item] = STATE(5517),
    [sym_preproc_conditional] = STATE(5517),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5517),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14439),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5846)] = {
    [sym__body_element] = STATE(5530),
    [sym_empty_statement] = STATE(5530),
    [sym_property] = STATE(5530),
    [sym_permissions_property] = STATE(5530),
    [sym_table_relation_property] = STATE(5530),
    [sym_fields_section] = STATE(5530),
    [sym_keys_section] = STATE(5530),
    [sym_fieldgroups_section] = STATE(5530),
    [sym_enum_value_declaration] = STATE(5530),
    [sym_labels_section] = STATE(5530),
    [sym_layout_section] = STATE(5530),
    [sym_modify_modification] = STATE(5530),
    [sym_actions_section] = STATE(5530),
    [sym_views_section] = STATE(5530),
    [sym_dataset_section] = STATE(5530),
    [sym_requestpage_section] = STATE(5530),
    [sym_rendering_section] = STATE(5530),
    [sym_elements_section] = STATE(5530),
    [sym_schema_section] = STATE(5530),
    [sym_assembly_declaration] = STATE(5530),
    [sym_event_declaration] = STATE(5530),
    [sym_procedure] = STATE(5530),
    [sym_preproc_split_procedure] = STATE(5530),
    [sym_preproc_split_procedure_preamble] = STATE(5530),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5530),
    [sym_var_section] = STATE(5530),
    [sym_attribute_item] = STATE(5530),
    [sym_preproc_conditional] = STATE(5530),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5530),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14441),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5847)] = {
    [sym__body_element] = STATE(5532),
    [sym_empty_statement] = STATE(5532),
    [sym_property] = STATE(5532),
    [sym_permissions_property] = STATE(5532),
    [sym_table_relation_property] = STATE(5532),
    [sym_fields_section] = STATE(5532),
    [sym_keys_section] = STATE(5532),
    [sym_fieldgroups_section] = STATE(5532),
    [sym_enum_value_declaration] = STATE(5532),
    [sym_labels_section] = STATE(5532),
    [sym_layout_section] = STATE(5532),
    [sym_modify_modification] = STATE(5532),
    [sym_actions_section] = STATE(5532),
    [sym_views_section] = STATE(5532),
    [sym_dataset_section] = STATE(5532),
    [sym_requestpage_section] = STATE(5532),
    [sym_rendering_section] = STATE(5532),
    [sym_elements_section] = STATE(5532),
    [sym_schema_section] = STATE(5532),
    [sym_assembly_declaration] = STATE(5532),
    [sym_event_declaration] = STATE(5532),
    [sym_procedure] = STATE(5532),
    [sym_preproc_split_procedure] = STATE(5532),
    [sym_preproc_split_procedure_preamble] = STATE(5532),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5532),
    [sym_var_section] = STATE(5532),
    [sym_attribute_item] = STATE(5532),
    [sym_preproc_conditional] = STATE(5532),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5532),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14443),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5848)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14445),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5849)] = {
    [sym__body_element] = STATE(5533),
    [sym_empty_statement] = STATE(5533),
    [sym_property] = STATE(5533),
    [sym_permissions_property] = STATE(5533),
    [sym_table_relation_property] = STATE(5533),
    [sym_fields_section] = STATE(5533),
    [sym_keys_section] = STATE(5533),
    [sym_fieldgroups_section] = STATE(5533),
    [sym_enum_value_declaration] = STATE(5533),
    [sym_labels_section] = STATE(5533),
    [sym_layout_section] = STATE(5533),
    [sym_modify_modification] = STATE(5533),
    [sym_actions_section] = STATE(5533),
    [sym_views_section] = STATE(5533),
    [sym_dataset_section] = STATE(5533),
    [sym_requestpage_section] = STATE(5533),
    [sym_rendering_section] = STATE(5533),
    [sym_elements_section] = STATE(5533),
    [sym_schema_section] = STATE(5533),
    [sym_assembly_declaration] = STATE(5533),
    [sym_event_declaration] = STATE(5533),
    [sym_procedure] = STATE(5533),
    [sym_preproc_split_procedure] = STATE(5533),
    [sym_preproc_split_procedure_preamble] = STATE(5533),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5533),
    [sym_var_section] = STATE(5533),
    [sym_attribute_item] = STATE(5533),
    [sym_preproc_conditional] = STATE(5533),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5533),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14447),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5850)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14449),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5851)] = {
    [sym_identifier] = ACTIONS(9022),
    [anon_sym_SEMI] = ACTIONS(9024),
    [anon_sym_RBRACE] = ACTIONS(9024),
    [aux_sym_where_condition_token1] = ACTIONS(9022),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(9022),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(9022),
    [anon_sym_LBRACK] = ACTIONS(9024),
    [aux_sym_basic_type_token6] = ACTIONS(9022),
    [aux_sym_basic_type_token22] = ACTIONS(9022),
    [aux_sym_basic_type_token53] = ACTIONS(9022),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9022),
    [aux_sym_addafter_modification_token1] = ACTIONS(9022),
    [aux_sym_addbefore_modification_token1] = ACTIONS(9022),
    [aux_sym_modify_modification_token1] = ACTIONS(9022),
    [aux_sym_movefirst_modification_token1] = ACTIONS(9022),
    [aux_sym_movelast_modification_token1] = ACTIONS(9022),
    [aux_sym_moveafter_modification_token1] = ACTIONS(9022),
    [aux_sym_movebefore_modification_token1] = ACTIONS(9022),
    [aux_sym_separator_action_token1] = ACTIONS(9022),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9022),
    [aux_sym_type_declaration_token1] = ACTIONS(9022),
    [anon_sym_POUNDif] = ACTIONS(9024),
    [anon_sym_POUNDIF] = ACTIONS(9024),
    [anon_sym_POUNDIf] = ACTIONS(9024),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9022),
    [sym_procedure_keyword] = ACTIONS(9022),
    [sym_trigger_keyword] = ACTIONS(9022),
    [sym_var_keyword] = ACTIONS(9022),
    [sym_local_keyword] = ACTIONS(9022),
    [sym_internal_keyword] = ACTIONS(9022),
    [sym_protected_keyword] = ACTIONS(9022),
    [sym_event_keyword] = ACTIONS(9022),
    [sym_fields_keyword] = ACTIONS(9022),
    [sym_keys_keyword] = ACTIONS(9022),
    [sym_key_keyword] = ACTIONS(9022),
    [sym_fieldgroups_keyword] = ACTIONS(9022),
    [sym_actions_keyword] = ACTIONS(9022),
    [sym_layout_keyword] = ACTIONS(9022),
    [sym_area_keyword] = ACTIONS(9022),
    [sym_group_keyword] = ACTIONS(9022),
    [sym_repeater_keyword] = ACTIONS(9022),
    [sym_cuegroup_keyword] = ACTIONS(9022),
    [sym_fixed_keyword] = ACTIONS(9022),
    [sym_grid_keyword] = ACTIONS(9022),
    [sym_part_keyword] = ACTIONS(9022),
    [sym_systempart_keyword] = ACTIONS(9022),
    [sym_usercontrol_keyword] = ACTIONS(9022),
    [sym_dataset_keyword] = ACTIONS(9022),
    [sym_elements_keyword] = ACTIONS(9022),
    [sym_dataitem_keyword] = ACTIONS(9022),
    [sym_column_keyword] = ACTIONS(9022),
    [sym_filter_keyword] = ACTIONS(9022),
    [sym_labels_keyword] = ACTIONS(9022),
    [sym_rendering_keyword] = ACTIONS(9022),
    [sym_requestpage_keyword] = ACTIONS(9022),
    [sym_schema_keyword] = ACTIONS(9022),
    [sym_views_keyword] = ACTIONS(9022),
    [sym_quoted_identifier] = ACTIONS(9024),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9024),
    [sym_preproc_open] = ACTIONS(9024),
    [sym_var_attribute_open] = ACTIONS(9024),
  },
  [STATE(5852)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14451),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5853)] = {
    [sym__body_element] = STATE(5620),
    [sym_empty_statement] = STATE(5620),
    [sym_property] = STATE(5620),
    [sym_permissions_property] = STATE(5620),
    [sym_table_relation_property] = STATE(5620),
    [sym_fields_section] = STATE(5620),
    [sym_keys_section] = STATE(5620),
    [sym_fieldgroups_section] = STATE(5620),
    [sym_enum_value_declaration] = STATE(5620),
    [sym_labels_section] = STATE(5620),
    [sym_layout_section] = STATE(5620),
    [sym_modify_modification] = STATE(5620),
    [sym_actions_section] = STATE(5620),
    [sym_views_section] = STATE(5620),
    [sym_dataset_section] = STATE(5620),
    [sym_requestpage_section] = STATE(5620),
    [sym_rendering_section] = STATE(5620),
    [sym_elements_section] = STATE(5620),
    [sym_schema_section] = STATE(5620),
    [sym_assembly_declaration] = STATE(5620),
    [sym_event_declaration] = STATE(5620),
    [sym_procedure] = STATE(5620),
    [sym_preproc_split_procedure] = STATE(5620),
    [sym_preproc_split_procedure_preamble] = STATE(5620),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5620),
    [sym_var_section] = STATE(5620),
    [sym_attribute_item] = STATE(5620),
    [sym_preproc_conditional] = STATE(5620),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5620),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14453),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5854)] = {
    [sym__body_element] = STATE(5480),
    [sym_empty_statement] = STATE(5480),
    [sym_property] = STATE(5480),
    [sym_permissions_property] = STATE(5480),
    [sym_table_relation_property] = STATE(5480),
    [sym_fields_section] = STATE(5480),
    [sym_keys_section] = STATE(5480),
    [sym_fieldgroups_section] = STATE(5480),
    [sym_enum_value_declaration] = STATE(5480),
    [sym_labels_section] = STATE(5480),
    [sym_layout_section] = STATE(5480),
    [sym_modify_modification] = STATE(5480),
    [sym_actions_section] = STATE(5480),
    [sym_views_section] = STATE(5480),
    [sym_dataset_section] = STATE(5480),
    [sym_requestpage_section] = STATE(5480),
    [sym_rendering_section] = STATE(5480),
    [sym_elements_section] = STATE(5480),
    [sym_schema_section] = STATE(5480),
    [sym_assembly_declaration] = STATE(5480),
    [sym_event_declaration] = STATE(5480),
    [sym_procedure] = STATE(5480),
    [sym_preproc_split_procedure] = STATE(5480),
    [sym_preproc_split_procedure_preamble] = STATE(5480),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5480),
    [sym_var_section] = STATE(5480),
    [sym_attribute_item] = STATE(5480),
    [sym_preproc_conditional] = STATE(5480),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5480),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14455),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5855)] = {
    [sym__body_element] = STATE(5457),
    [sym_empty_statement] = STATE(5457),
    [sym_property] = STATE(5457),
    [sym_permissions_property] = STATE(5457),
    [sym_table_relation_property] = STATE(5457),
    [sym_fields_section] = STATE(5457),
    [sym_keys_section] = STATE(5457),
    [sym_fieldgroups_section] = STATE(5457),
    [sym_enum_value_declaration] = STATE(5457),
    [sym_labels_section] = STATE(5457),
    [sym_layout_section] = STATE(5457),
    [sym_modify_modification] = STATE(5457),
    [sym_actions_section] = STATE(5457),
    [sym_views_section] = STATE(5457),
    [sym_dataset_section] = STATE(5457),
    [sym_requestpage_section] = STATE(5457),
    [sym_rendering_section] = STATE(5457),
    [sym_elements_section] = STATE(5457),
    [sym_schema_section] = STATE(5457),
    [sym_assembly_declaration] = STATE(5457),
    [sym_event_declaration] = STATE(5457),
    [sym_procedure] = STATE(5457),
    [sym_preproc_split_procedure] = STATE(5457),
    [sym_preproc_split_procedure_preamble] = STATE(5457),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5457),
    [sym_var_section] = STATE(5457),
    [sym_attribute_item] = STATE(5457),
    [sym_preproc_conditional] = STATE(5457),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5457),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14457),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5856)] = {
    [sym__body_element] = STATE(5808),
    [sym_empty_statement] = STATE(5808),
    [sym_property] = STATE(5808),
    [sym_permissions_property] = STATE(5808),
    [sym_table_relation_property] = STATE(5808),
    [sym_fields_section] = STATE(5808),
    [sym_keys_section] = STATE(5808),
    [sym_fieldgroups_section] = STATE(5808),
    [sym_enum_value_declaration] = STATE(5808),
    [sym_labels_section] = STATE(5808),
    [sym_layout_section] = STATE(5808),
    [sym_modify_modification] = STATE(5808),
    [sym_actions_section] = STATE(5808),
    [sym_views_section] = STATE(5808),
    [sym_dataset_section] = STATE(5808),
    [sym_requestpage_section] = STATE(5808),
    [sym_rendering_section] = STATE(5808),
    [sym_elements_section] = STATE(5808),
    [sym_schema_section] = STATE(5808),
    [sym_assembly_declaration] = STATE(5808),
    [sym_event_declaration] = STATE(5808),
    [sym_procedure] = STATE(5808),
    [sym_preproc_split_procedure] = STATE(5808),
    [sym_preproc_split_procedure_preamble] = STATE(5808),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5808),
    [sym_var_section] = STATE(5808),
    [sym_attribute_item] = STATE(5808),
    [sym_preproc_conditional] = STATE(5808),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5808),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14459),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5857)] = {
    [sym__body_element] = STATE(5571),
    [sym_empty_statement] = STATE(5571),
    [sym_property] = STATE(5571),
    [sym_permissions_property] = STATE(5571),
    [sym_table_relation_property] = STATE(5571),
    [sym_fields_section] = STATE(5571),
    [sym_keys_section] = STATE(5571),
    [sym_fieldgroups_section] = STATE(5571),
    [sym_enum_value_declaration] = STATE(5571),
    [sym_labels_section] = STATE(5571),
    [sym_layout_section] = STATE(5571),
    [sym_modify_modification] = STATE(5571),
    [sym_actions_section] = STATE(5571),
    [sym_views_section] = STATE(5571),
    [sym_dataset_section] = STATE(5571),
    [sym_requestpage_section] = STATE(5571),
    [sym_rendering_section] = STATE(5571),
    [sym_elements_section] = STATE(5571),
    [sym_schema_section] = STATE(5571),
    [sym_assembly_declaration] = STATE(5571),
    [sym_event_declaration] = STATE(5571),
    [sym_procedure] = STATE(5571),
    [sym_preproc_split_procedure] = STATE(5571),
    [sym_preproc_split_procedure_preamble] = STATE(5571),
    [sym_procedure_modifier] = STATE(17708),
    [sym_trigger_declaration] = STATE(5571),
    [sym_var_section] = STATE(5571),
    [sym_attribute_item] = STATE(5571),
    [sym_preproc_conditional] = STATE(5571),
    [sym_preproc_if] = STATE(3681),
    [aux_sym_preproc_split_declaration_repeat2] = STATE(5571),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_RBRACE] = ACTIONS(14107),
    [anon_sym_LBRACK] = ACTIONS(6373),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6377),
    [aux_sym_modify_modification_token1] = ACTIONS(6383),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6393),
    [anon_sym_POUNDif] = ACTIONS(4218),
    [anon_sym_POUNDIF] = ACTIONS(4218),
    [anon_sym_POUNDIf] = ACTIONS(4218),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_procedure_keyword] = ACTIONS(12092),
    [sym_trigger_keyword] = ACTIONS(12094),
    [sym_var_keyword] = ACTIONS(6399),
    [sym_local_keyword] = ACTIONS(6401),
    [sym_internal_keyword] = ACTIONS(4234),
    [sym_protected_keyword] = ACTIONS(6401),
    [sym_event_keyword] = ACTIONS(6403),
    [sym_fields_keyword] = ACTIONS(6405),
    [sym_keys_keyword] = ACTIONS(6407),
    [sym_fieldgroups_keyword] = ACTIONS(6409),
    [sym_actions_keyword] = ACTIONS(6411),
    [sym_layout_keyword] = ACTIONS(6413),
    [sym_dataset_keyword] = ACTIONS(6433),
    [sym_elements_keyword] = ACTIONS(6435),
    [sym_labels_keyword] = ACTIONS(6437),
    [sym_rendering_keyword] = ACTIONS(6439),
    [sym_requestpage_keyword] = ACTIONS(6441),
    [sym_schema_keyword] = ACTIONS(6443),
    [sym_views_keyword] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(12102),
    [sym_preproc_open] = ACTIONS(4218),
  },
  [STATE(5858)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(14461),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_xmlport_element_token1] = ACTIONS(5961),
    [aux_sym_xmlport_element_token2] = ACTIONS(5961),
    [aux_sym_xmlport_element_token3] = ACTIONS(5961),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5961),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(5859)] = {
    [sym_property] = STATE(6551),
    [sym__action_element] = STATE(6551),
    [sym_action_area_section] = STATE(6551),
    [sym_action_group_section] = STATE(6551),
    [sym_action_declaration] = STATE(6551),
    [sym_separator_action] = STATE(6551),
    [sym_actionref_declaration] = STATE(6551),
    [sym_systemaction_declaration] = STATE(6551),
    [sym_fileuploadaction_declaration] = STATE(6551),
    [sym_customaction_declaration] = STATE(6551),
    [sym_addfirst_action_modification] = STATE(6551),
    [sym_addlast_action_modification] = STATE(6551),
    [sym_addafter_action_modification] = STATE(6551),
    [sym_addbefore_action_modification] = STATE(6551),
    [sym_modify_action_modification] = STATE(6551),
    [sym_trigger_declaration] = STATE(6551),
    [sym_attribute_item] = STATE(6551),
    [sym_preproc_if] = STATE(5874),
    [sym_preproc_elif] = STATE(6593),
    [sym_preproc_else] = STATE(8057),
    [sym_preproc_endif] = STATE(8306),
    [sym_preproc_conditional_actions] = STATE(6551),
    [aux_sym_actions_section_repeat1] = STATE(6551),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(10854),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(14463),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(14465),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [anon_sym_POUNDif] = ACTIONS(14467),
    [anon_sym_POUNDIF] = ACTIONS(14467),
    [anon_sym_POUNDIf] = ACTIONS(14467),
    [anon_sym_POUNDelif] = ACTIONS(14469),
    [anon_sym_POUNDELIF] = ACTIONS(14469),
    [anon_sym_POUNDElif] = ACTIONS(14469),
    [anon_sym_POUNDelse] = ACTIONS(14471),
    [anon_sym_POUNDELSE] = ACTIONS(14471),
    [anon_sym_POUNDElse] = ACTIONS(14471),
    [anon_sym_POUNDelse2] = ACTIONS(14471),
    [anon_sym_POUNDELSE2] = ACTIONS(14471),
    [anon_sym_POUNDElse2] = ACTIONS(14471),
    [anon_sym_POUNDendif] = ACTIONS(4224),
    [anon_sym_POUNDENDIF] = ACTIONS(4224),
    [anon_sym_POUNDEndif] = ACTIONS(4224),
    [anon_sym_POUNDendif2] = ACTIONS(4224),
    [anon_sym_POUNDENDIF2] = ACTIONS(4224),
    [anon_sym_POUNDEndif2] = ACTIONS(4224),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_trigger_keyword] = ACTIONS(14473),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(14475),
    [sym_preproc_open] = ACTIONS(14467),
    [sym_preproc_close] = ACTIONS(4224),
  },
  [STATE(5860)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_xmlport_element_token1] = ACTIONS(9006),
    [aux_sym_xmlport_element_token2] = ACTIONS(9006),
    [aux_sym_xmlport_element_token3] = ACTIONS(9006),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9006),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(5861)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_xmlport_element_token1] = ACTIONS(9006),
    [aux_sym_xmlport_element_token2] = ACTIONS(9006),
    [aux_sym_xmlport_element_token3] = ACTIONS(9006),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9006),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(5862)] = {
    [sym_identifier] = ACTIONS(6180),
    [anon_sym_SEMI] = ACTIONS(6182),
    [aux_sym_where_condition_token1] = ACTIONS(6180),
    [anon_sym_LBRACK] = ACTIONS(6182),
    [aux_sym_basic_type_token22] = ACTIONS(6180),
    [aux_sym_basic_type_token53] = ACTIONS(6180),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6180),
    [aux_sym_modify_modification_token1] = ACTIONS(6180),
    [aux_sym_separator_action_token1] = ACTIONS(6180),
    [aux_sym_xmlport_element_token1] = ACTIONS(6180),
    [aux_sym_xmlport_element_token2] = ACTIONS(6180),
    [aux_sym_xmlport_element_token3] = ACTIONS(6180),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6180),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6180),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6180),
    [aux_sym_type_declaration_token1] = ACTIONS(6180),
    [anon_sym_POUNDif] = ACTIONS(6182),
    [anon_sym_POUNDIF] = ACTIONS(6182),
    [anon_sym_POUNDIf] = ACTIONS(6182),
    [anon_sym_POUNDelif] = ACTIONS(6182),
    [anon_sym_POUNDELIF] = ACTIONS(6182),
    [anon_sym_POUNDElif] = ACTIONS(6182),
    [anon_sym_POUNDelse] = ACTIONS(6182),
    [anon_sym_POUNDELSE] = ACTIONS(6182),
    [anon_sym_POUNDElse] = ACTIONS(6182),
    [anon_sym_POUNDelse2] = ACTIONS(6182),
    [anon_sym_POUNDELSE2] = ACTIONS(6182),
    [anon_sym_POUNDElse2] = ACTIONS(6182),
    [anon_sym_POUNDendif] = ACTIONS(6182),
    [anon_sym_POUNDENDIF] = ACTIONS(6182),
    [anon_sym_POUNDEndif] = ACTIONS(6182),
    [anon_sym_POUNDendif2] = ACTIONS(6182),
    [anon_sym_POUNDENDIF2] = ACTIONS(6182),
    [anon_sym_POUNDEndif2] = ACTIONS(6182),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6180),
    [sym_procedure_keyword] = ACTIONS(6180),
    [sym_trigger_keyword] = ACTIONS(6180),
    [sym_var_keyword] = ACTIONS(6180),
    [sym_local_keyword] = ACTIONS(6180),
    [sym_internal_keyword] = ACTIONS(6180),
    [sym_protected_keyword] = ACTIONS(6180),
    [sym_event_keyword] = ACTIONS(6180),
    [sym_fields_keyword] = ACTIONS(6180),
    [sym_keys_keyword] = ACTIONS(6180),
    [sym_key_keyword] = ACTIONS(6180),
    [sym_fieldgroups_keyword] = ACTIONS(6180),
    [sym_actions_keyword] = ACTIONS(6180),
    [sym_layout_keyword] = ACTIONS(6180),
    [sym_dataset_keyword] = ACTIONS(6180),
    [sym_elements_keyword] = ACTIONS(6180),
    [sym_labels_keyword] = ACTIONS(6180),
    [sym_rendering_keyword] = ACTIONS(6180),
    [sym_requestpage_keyword] = ACTIONS(6180),
    [sym_schema_keyword] = ACTIONS(6180),
    [sym_views_keyword] = ACTIONS(6180),
    [sym_quoted_identifier] = ACTIONS(6182),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6182),
    [sym_preproc_open] = ACTIONS(6182),
    [sym_preproc_close] = ACTIONS(6182),
    [sym_var_attribute_open] = ACTIONS(6182),
  },
  [STATE(5863)] = {
    [anon_sym_SEMI] = ACTIONS(8428),
    [anon_sym_RBRACE] = ACTIONS(8428),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8428),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7725),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8428),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8428),
    [anon_sym_LBRACK] = ACTIONS(8428),
    [aux_sym_basic_type_token22] = ACTIONS(7725),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8428),
    [aux_sym_addafter_modification_token1] = ACTIONS(8428),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8428),
    [aux_sym_modify_modification_token1] = ACTIONS(8428),
    [aux_sym_separator_action_token1] = ACTIONS(8428),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8428),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8428),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8428),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8428),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8428),
    [anon_sym_POUNDif] = ACTIONS(8428),
    [anon_sym_POUNDIF] = ACTIONS(8428),
    [anon_sym_POUNDIf] = ACTIONS(8428),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7725),
    [sym_page_keyword] = ACTIONS(8428),
    [anon_sym_codeunit] = ACTIONS(8428),
    [anon_sym_CODEUNIT] = ACTIONS(8428),
    [anon_sym_Codeunit] = ACTIONS(8428),
    [anon_sym_CodeUnit] = ACTIONS(8428),
    [anon_sym_COdeunit] = ACTIONS(8428),
    [anon_sym_codeUnit] = ACTIONS(8428),
    [sym_report_keyword] = ACTIONS(8428),
    [sym_query_keyword] = ACTIONS(8428),
    [anon_sym_xmlport] = ACTIONS(8428),
    [anon_sym_XMLPORT] = ACTIONS(8428),
    [anon_sym_Xmlport] = ACTIONS(8428),
    [anon_sym_XMLport] = ACTIONS(8428),
    [anon_sym_XMLPort] = ACTIONS(8428),
    [anon_sym_XmlPort] = ACTIONS(8428),
    [sym_procedure_keyword] = ACTIONS(8428),
    [sym_trigger_keyword] = ACTIONS(8428),
    [sym_var_keyword] = ACTIONS(8428),
    [sym_local_keyword] = ACTIONS(8428),
    [sym_internal_keyword] = ACTIONS(8428),
    [sym_protected_keyword] = ACTIONS(8428),
    [sym_event_keyword] = ACTIONS(8428),
    [sym_fields_keyword] = ACTIONS(8428),
    [sym_keys_keyword] = ACTIONS(8428),
    [sym_fieldgroups_keyword] = ACTIONS(8428),
    [sym_actions_keyword] = ACTIONS(8428),
    [sym_layout_keyword] = ACTIONS(8428),
    [sym_area_keyword] = ACTIONS(8428),
    [sym_group_keyword] = ACTIONS(8428),
    [sym_dataset_keyword] = ACTIONS(8428),
    [sym_elements_keyword] = ACTIONS(8428),
    [sym_labels_keyword] = ACTIONS(8428),
    [sym_rendering_keyword] = ACTIONS(8428),
    [sym_requestpage_keyword] = ACTIONS(8428),
    [sym_schema_keyword] = ACTIONS(8428),
    [sym_views_keyword] = ACTIONS(8428),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8428),
    [sym_preproc_open] = ACTIONS(8428),
  },
  [STATE(5864)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_xmlport_element_token1] = ACTIONS(8905),
    [aux_sym_xmlport_element_token2] = ACTIONS(8905),
    [aux_sym_xmlport_element_token3] = ACTIONS(8905),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8905),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(5865)] = {
    [sym_property] = STATE(6551),
    [sym__action_element] = STATE(6551),
    [sym_action_area_section] = STATE(6551),
    [sym_action_group_section] = STATE(6551),
    [sym_action_declaration] = STATE(6551),
    [sym_separator_action] = STATE(6551),
    [sym_actionref_declaration] = STATE(6551),
    [sym_systemaction_declaration] = STATE(6551),
    [sym_fileuploadaction_declaration] = STATE(6551),
    [sym_customaction_declaration] = STATE(6551),
    [sym_addfirst_action_modification] = STATE(6551),
    [sym_addlast_action_modification] = STATE(6551),
    [sym_addafter_action_modification] = STATE(6551),
    [sym_addbefore_action_modification] = STATE(6551),
    [sym_modify_action_modification] = STATE(6551),
    [sym_trigger_declaration] = STATE(6551),
    [sym_attribute_item] = STATE(6551),
    [sym_preproc_if] = STATE(5874),
    [sym_preproc_elif] = STATE(6593),
    [sym_preproc_else] = STATE(8096),
    [sym_preproc_endif] = STATE(10579),
    [sym_preproc_conditional_actions] = STATE(6551),
    [aux_sym_actions_section_repeat1] = STATE(6551),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(10929),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(14463),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(14465),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [anon_sym_POUNDif] = ACTIONS(14467),
    [anon_sym_POUNDIF] = ACTIONS(14467),
    [anon_sym_POUNDIf] = ACTIONS(14467),
    [anon_sym_POUNDelif] = ACTIONS(14469),
    [anon_sym_POUNDELIF] = ACTIONS(14469),
    [anon_sym_POUNDElif] = ACTIONS(14469),
    [anon_sym_POUNDelse] = ACTIONS(14471),
    [anon_sym_POUNDELSE] = ACTIONS(14471),
    [anon_sym_POUNDElse] = ACTIONS(14471),
    [anon_sym_POUNDelse2] = ACTIONS(14471),
    [anon_sym_POUNDELSE2] = ACTIONS(14471),
    [anon_sym_POUNDElse2] = ACTIONS(14471),
    [anon_sym_POUNDendif] = ACTIONS(14477),
    [anon_sym_POUNDENDIF] = ACTIONS(14477),
    [anon_sym_POUNDEndif] = ACTIONS(14477),
    [anon_sym_POUNDendif2] = ACTIONS(14477),
    [anon_sym_POUNDENDIF2] = ACTIONS(14477),
    [anon_sym_POUNDEndif2] = ACTIONS(14477),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_trigger_keyword] = ACTIONS(14473),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(14475),
    [sym_preproc_open] = ACTIONS(14467),
    [sym_preproc_close] = ACTIONS(14477),
  },
  [STATE(5866)] = {
    [sym_property] = STATE(6551),
    [sym__action_element] = STATE(6551),
    [sym_action_area_section] = STATE(6551),
    [sym_action_group_section] = STATE(6551),
    [sym_action_declaration] = STATE(6551),
    [sym_separator_action] = STATE(6551),
    [sym_actionref_declaration] = STATE(6551),
    [sym_systemaction_declaration] = STATE(6551),
    [sym_fileuploadaction_declaration] = STATE(6551),
    [sym_customaction_declaration] = STATE(6551),
    [sym_addfirst_action_modification] = STATE(6551),
    [sym_addlast_action_modification] = STATE(6551),
    [sym_addafter_action_modification] = STATE(6551),
    [sym_addbefore_action_modification] = STATE(6551),
    [sym_modify_action_modification] = STATE(6551),
    [sym_trigger_declaration] = STATE(6551),
    [sym_attribute_item] = STATE(6551),
    [sym_preproc_if] = STATE(5874),
    [sym_preproc_elif] = STATE(6593),
    [sym_preproc_else] = STATE(8100),
    [sym_preproc_endif] = STATE(9098),
    [sym_preproc_conditional_actions] = STATE(6551),
    [aux_sym_actions_section_repeat1] = STATE(6551),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(10718),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(14463),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(14465),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [anon_sym_POUNDif] = ACTIONS(14467),
    [anon_sym_POUNDIF] = ACTIONS(14467),
    [anon_sym_POUNDIf] = ACTIONS(14467),
    [anon_sym_POUNDelif] = ACTIONS(14469),
    [anon_sym_POUNDELIF] = ACTIONS(14469),
    [anon_sym_POUNDElif] = ACTIONS(14469),
    [anon_sym_POUNDelse] = ACTIONS(14471),
    [anon_sym_POUNDELSE] = ACTIONS(14471),
    [anon_sym_POUNDElse] = ACTIONS(14471),
    [anon_sym_POUNDelse2] = ACTIONS(14471),
    [anon_sym_POUNDELSE2] = ACTIONS(14471),
    [anon_sym_POUNDElse2] = ACTIONS(14471),
    [anon_sym_POUNDendif] = ACTIONS(14479),
    [anon_sym_POUNDENDIF] = ACTIONS(14479),
    [anon_sym_POUNDEndif] = ACTIONS(14479),
    [anon_sym_POUNDendif2] = ACTIONS(14479),
    [anon_sym_POUNDENDIF2] = ACTIONS(14479),
    [anon_sym_POUNDEndif2] = ACTIONS(14479),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_trigger_keyword] = ACTIONS(14473),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(14475),
    [sym_preproc_open] = ACTIONS(14467),
    [sym_preproc_close] = ACTIONS(14479),
  },
  [STATE(5867)] = {
    [anon_sym_SEMI] = ACTIONS(8426),
    [anon_sym_RBRACE] = ACTIONS(8426),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8426),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7770),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8426),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8426),
    [anon_sym_LBRACK] = ACTIONS(8426),
    [aux_sym_basic_type_token22] = ACTIONS(7770),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8426),
    [aux_sym_addafter_modification_token1] = ACTIONS(8426),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8426),
    [aux_sym_modify_modification_token1] = ACTIONS(8426),
    [aux_sym_separator_action_token1] = ACTIONS(8426),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8426),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8426),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8426),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8426),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8426),
    [anon_sym_POUNDif] = ACTIONS(8426),
    [anon_sym_POUNDIF] = ACTIONS(8426),
    [anon_sym_POUNDIf] = ACTIONS(8426),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7770),
    [sym_page_keyword] = ACTIONS(8426),
    [anon_sym_codeunit] = ACTIONS(8426),
    [anon_sym_CODEUNIT] = ACTIONS(8426),
    [anon_sym_Codeunit] = ACTIONS(8426),
    [anon_sym_CodeUnit] = ACTIONS(8426),
    [anon_sym_COdeunit] = ACTIONS(8426),
    [anon_sym_codeUnit] = ACTIONS(8426),
    [sym_report_keyword] = ACTIONS(8426),
    [sym_query_keyword] = ACTIONS(8426),
    [anon_sym_xmlport] = ACTIONS(8426),
    [anon_sym_XMLPORT] = ACTIONS(8426),
    [anon_sym_Xmlport] = ACTIONS(8426),
    [anon_sym_XMLport] = ACTIONS(8426),
    [anon_sym_XMLPort] = ACTIONS(8426),
    [anon_sym_XmlPort] = ACTIONS(8426),
    [sym_procedure_keyword] = ACTIONS(8426),
    [sym_trigger_keyword] = ACTIONS(8426),
    [sym_var_keyword] = ACTIONS(8426),
    [sym_local_keyword] = ACTIONS(8426),
    [sym_internal_keyword] = ACTIONS(8426),
    [sym_protected_keyword] = ACTIONS(8426),
    [sym_event_keyword] = ACTIONS(8426),
    [sym_fields_keyword] = ACTIONS(8426),
    [sym_keys_keyword] = ACTIONS(8426),
    [sym_fieldgroups_keyword] = ACTIONS(8426),
    [sym_actions_keyword] = ACTIONS(8426),
    [sym_layout_keyword] = ACTIONS(8426),
    [sym_area_keyword] = ACTIONS(8426),
    [sym_group_keyword] = ACTIONS(8426),
    [sym_dataset_keyword] = ACTIONS(8426),
    [sym_elements_keyword] = ACTIONS(8426),
    [sym_labels_keyword] = ACTIONS(8426),
    [sym_rendering_keyword] = ACTIONS(8426),
    [sym_requestpage_keyword] = ACTIONS(8426),
    [sym_schema_keyword] = ACTIONS(8426),
    [sym_views_keyword] = ACTIONS(8426),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8426),
    [sym_preproc_open] = ACTIONS(8426),
  },
  [STATE(5868)] = {
    [sym_identifier] = ACTIONS(5279),
    [anon_sym_SEMI] = ACTIONS(5277),
    [aux_sym_where_condition_token1] = ACTIONS(5279),
    [anon_sym_LBRACK] = ACTIONS(5277),
    [aux_sym_basic_type_token22] = ACTIONS(5279),
    [aux_sym_basic_type_token53] = ACTIONS(5279),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5279),
    [aux_sym_modify_modification_token1] = ACTIONS(5279),
    [aux_sym_separator_action_token1] = ACTIONS(5279),
    [aux_sym_xmlport_element_token1] = ACTIONS(5279),
    [aux_sym_xmlport_element_token2] = ACTIONS(5279),
    [aux_sym_xmlport_element_token3] = ACTIONS(5279),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5279),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5279),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5279),
    [aux_sym_type_declaration_token1] = ACTIONS(5279),
    [anon_sym_POUNDif] = ACTIONS(5277),
    [anon_sym_POUNDIF] = ACTIONS(5277),
    [anon_sym_POUNDIf] = ACTIONS(5277),
    [anon_sym_POUNDelif] = ACTIONS(5277),
    [anon_sym_POUNDELIF] = ACTIONS(5277),
    [anon_sym_POUNDElif] = ACTIONS(5277),
    [anon_sym_POUNDelse] = ACTIONS(5277),
    [anon_sym_POUNDELSE] = ACTIONS(5277),
    [anon_sym_POUNDElse] = ACTIONS(5277),
    [anon_sym_POUNDelse2] = ACTIONS(5277),
    [anon_sym_POUNDELSE2] = ACTIONS(5277),
    [anon_sym_POUNDElse2] = ACTIONS(5277),
    [anon_sym_POUNDendif] = ACTIONS(5277),
    [anon_sym_POUNDENDIF] = ACTIONS(5277),
    [anon_sym_POUNDEndif] = ACTIONS(5277),
    [anon_sym_POUNDendif2] = ACTIONS(5277),
    [anon_sym_POUNDENDIF2] = ACTIONS(5277),
    [anon_sym_POUNDEndif2] = ACTIONS(5277),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5279),
    [sym_procedure_keyword] = ACTIONS(5279),
    [sym_trigger_keyword] = ACTIONS(5279),
    [sym_var_keyword] = ACTIONS(5279),
    [sym_local_keyword] = ACTIONS(5279),
    [sym_internal_keyword] = ACTIONS(5279),
    [sym_protected_keyword] = ACTIONS(5279),
    [sym_event_keyword] = ACTIONS(5279),
    [sym_fields_keyword] = ACTIONS(5279),
    [sym_keys_keyword] = ACTIONS(5279),
    [sym_key_keyword] = ACTIONS(5279),
    [sym_fieldgroups_keyword] = ACTIONS(5279),
    [sym_actions_keyword] = ACTIONS(5279),
    [sym_layout_keyword] = ACTIONS(5279),
    [sym_dataset_keyword] = ACTIONS(5279),
    [sym_elements_keyword] = ACTIONS(5279),
    [sym_labels_keyword] = ACTIONS(5279),
    [sym_rendering_keyword] = ACTIONS(5279),
    [sym_requestpage_keyword] = ACTIONS(5279),
    [sym_schema_keyword] = ACTIONS(5279),
    [sym_views_keyword] = ACTIONS(5279),
    [sym_quoted_identifier] = ACTIONS(5277),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5277),
    [sym_preproc_open] = ACTIONS(5277),
    [sym_preproc_close] = ACTIONS(5277),
    [sym_var_attribute_open] = ACTIONS(5277),
  },
  [STATE(5869)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_xmlport_element_token1] = ACTIONS(9044),
    [aux_sym_xmlport_element_token2] = ACTIONS(9044),
    [aux_sym_xmlport_element_token3] = ACTIONS(9044),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9044),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(5870)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_xmlport_element_token1] = ACTIONS(9044),
    [aux_sym_xmlport_element_token2] = ACTIONS(9044),
    [aux_sym_xmlport_element_token3] = ACTIONS(9044),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9044),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(5871)] = {
    [sym_identifier] = ACTIONS(9044),
    [anon_sym_SEMI] = ACTIONS(9046),
    [aux_sym_where_condition_token1] = ACTIONS(9044),
    [anon_sym_LBRACK] = ACTIONS(9046),
    [aux_sym_basic_type_token22] = ACTIONS(9044),
    [aux_sym_basic_type_token53] = ACTIONS(9044),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9044),
    [aux_sym_modify_modification_token1] = ACTIONS(9044),
    [aux_sym_separator_action_token1] = ACTIONS(9044),
    [aux_sym_xmlport_element_token1] = ACTIONS(9044),
    [aux_sym_xmlport_element_token2] = ACTIONS(9044),
    [aux_sym_xmlport_element_token3] = ACTIONS(9044),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9044),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9044),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9044),
    [aux_sym_type_declaration_token1] = ACTIONS(9044),
    [anon_sym_POUNDif] = ACTIONS(9046),
    [anon_sym_POUNDIF] = ACTIONS(9046),
    [anon_sym_POUNDIf] = ACTIONS(9046),
    [anon_sym_POUNDelif] = ACTIONS(9046),
    [anon_sym_POUNDELIF] = ACTIONS(9046),
    [anon_sym_POUNDElif] = ACTIONS(9046),
    [anon_sym_POUNDelse] = ACTIONS(9046),
    [anon_sym_POUNDELSE] = ACTIONS(9046),
    [anon_sym_POUNDElse] = ACTIONS(9046),
    [anon_sym_POUNDelse2] = ACTIONS(9046),
    [anon_sym_POUNDELSE2] = ACTIONS(9046),
    [anon_sym_POUNDElse2] = ACTIONS(9046),
    [anon_sym_POUNDendif] = ACTIONS(9046),
    [anon_sym_POUNDENDIF] = ACTIONS(9046),
    [anon_sym_POUNDEndif] = ACTIONS(9046),
    [anon_sym_POUNDendif2] = ACTIONS(9046),
    [anon_sym_POUNDENDIF2] = ACTIONS(9046),
    [anon_sym_POUNDEndif2] = ACTIONS(9046),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9044),
    [sym_procedure_keyword] = ACTIONS(9044),
    [sym_trigger_keyword] = ACTIONS(9044),
    [sym_var_keyword] = ACTIONS(9044),
    [sym_local_keyword] = ACTIONS(9044),
    [sym_internal_keyword] = ACTIONS(9044),
    [sym_protected_keyword] = ACTIONS(9044),
    [sym_event_keyword] = ACTIONS(9044),
    [sym_fields_keyword] = ACTIONS(9044),
    [sym_keys_keyword] = ACTIONS(9044),
    [sym_key_keyword] = ACTIONS(9044),
    [sym_fieldgroups_keyword] = ACTIONS(9044),
    [sym_actions_keyword] = ACTIONS(9044),
    [sym_layout_keyword] = ACTIONS(9044),
    [sym_dataset_keyword] = ACTIONS(9044),
    [sym_elements_keyword] = ACTIONS(9044),
    [sym_labels_keyword] = ACTIONS(9044),
    [sym_rendering_keyword] = ACTIONS(9044),
    [sym_requestpage_keyword] = ACTIONS(9044),
    [sym_schema_keyword] = ACTIONS(9044),
    [sym_views_keyword] = ACTIONS(9044),
    [sym_quoted_identifier] = ACTIONS(9046),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9046),
    [sym_preproc_open] = ACTIONS(9046),
    [sym_preproc_close] = ACTIONS(9046),
    [sym_var_attribute_open] = ACTIONS(9046),
  },
  [STATE(5872)] = {
    [sym_identifier] = ACTIONS(9048),
    [anon_sym_SEMI] = ACTIONS(9050),
    [aux_sym_where_condition_token1] = ACTIONS(9048),
    [anon_sym_LBRACK] = ACTIONS(9050),
    [aux_sym_basic_type_token22] = ACTIONS(9048),
    [aux_sym_basic_type_token53] = ACTIONS(9048),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9048),
    [aux_sym_modify_modification_token1] = ACTIONS(9048),
    [aux_sym_separator_action_token1] = ACTIONS(9048),
    [aux_sym_xmlport_element_token1] = ACTIONS(9048),
    [aux_sym_xmlport_element_token2] = ACTIONS(9048),
    [aux_sym_xmlport_element_token3] = ACTIONS(9048),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9048),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9048),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9048),
    [aux_sym_type_declaration_token1] = ACTIONS(9048),
    [anon_sym_POUNDif] = ACTIONS(9050),
    [anon_sym_POUNDIF] = ACTIONS(9050),
    [anon_sym_POUNDIf] = ACTIONS(9050),
    [anon_sym_POUNDelif] = ACTIONS(9050),
    [anon_sym_POUNDELIF] = ACTIONS(9050),
    [anon_sym_POUNDElif] = ACTIONS(9050),
    [anon_sym_POUNDelse] = ACTIONS(9050),
    [anon_sym_POUNDELSE] = ACTIONS(9050),
    [anon_sym_POUNDElse] = ACTIONS(9050),
    [anon_sym_POUNDelse2] = ACTIONS(9050),
    [anon_sym_POUNDELSE2] = ACTIONS(9050),
    [anon_sym_POUNDElse2] = ACTIONS(9050),
    [anon_sym_POUNDendif] = ACTIONS(9050),
    [anon_sym_POUNDENDIF] = ACTIONS(9050),
    [anon_sym_POUNDEndif] = ACTIONS(9050),
    [anon_sym_POUNDendif2] = ACTIONS(9050),
    [anon_sym_POUNDENDIF2] = ACTIONS(9050),
    [anon_sym_POUNDEndif2] = ACTIONS(9050),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9048),
    [sym_procedure_keyword] = ACTIONS(9048),
    [sym_trigger_keyword] = ACTIONS(9048),
    [sym_var_keyword] = ACTIONS(9048),
    [sym_local_keyword] = ACTIONS(9048),
    [sym_internal_keyword] = ACTIONS(9048),
    [sym_protected_keyword] = ACTIONS(9048),
    [sym_event_keyword] = ACTIONS(9048),
    [sym_fields_keyword] = ACTIONS(9048),
    [sym_keys_keyword] = ACTIONS(9048),
    [sym_key_keyword] = ACTIONS(9048),
    [sym_fieldgroups_keyword] = ACTIONS(9048),
    [sym_actions_keyword] = ACTIONS(9048),
    [sym_layout_keyword] = ACTIONS(9048),
    [sym_dataset_keyword] = ACTIONS(9048),
    [sym_elements_keyword] = ACTIONS(9048),
    [sym_labels_keyword] = ACTIONS(9048),
    [sym_rendering_keyword] = ACTIONS(9048),
    [sym_requestpage_keyword] = ACTIONS(9048),
    [sym_schema_keyword] = ACTIONS(9048),
    [sym_views_keyword] = ACTIONS(9048),
    [sym_quoted_identifier] = ACTIONS(9050),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9050),
    [sym_preproc_open] = ACTIONS(9050),
    [sym_preproc_close] = ACTIONS(9050),
    [sym_var_attribute_open] = ACTIONS(9050),
  },
  [STATE(5873)] = {
    [sym_identifier] = ACTIONS(9052),
    [anon_sym_SEMI] = ACTIONS(9054),
    [aux_sym_where_condition_token1] = ACTIONS(9052),
    [anon_sym_LBRACK] = ACTIONS(9054),
    [aux_sym_basic_type_token22] = ACTIONS(9052),
    [aux_sym_basic_type_token53] = ACTIONS(9052),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9052),
    [aux_sym_modify_modification_token1] = ACTIONS(9052),
    [aux_sym_separator_action_token1] = ACTIONS(9052),
    [aux_sym_xmlport_element_token1] = ACTIONS(9052),
    [aux_sym_xmlport_element_token2] = ACTIONS(9052),
    [aux_sym_xmlport_element_token3] = ACTIONS(9052),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9052),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9052),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9052),
    [aux_sym_type_declaration_token1] = ACTIONS(9052),
    [anon_sym_POUNDif] = ACTIONS(9054),
    [anon_sym_POUNDIF] = ACTIONS(9054),
    [anon_sym_POUNDIf] = ACTIONS(9054),
    [anon_sym_POUNDelif] = ACTIONS(9054),
    [anon_sym_POUNDELIF] = ACTIONS(9054),
    [anon_sym_POUNDElif] = ACTIONS(9054),
    [anon_sym_POUNDelse] = ACTIONS(9054),
    [anon_sym_POUNDELSE] = ACTIONS(9054),
    [anon_sym_POUNDElse] = ACTIONS(9054),
    [anon_sym_POUNDelse2] = ACTIONS(9054),
    [anon_sym_POUNDELSE2] = ACTIONS(9054),
    [anon_sym_POUNDElse2] = ACTIONS(9054),
    [anon_sym_POUNDendif] = ACTIONS(9054),
    [anon_sym_POUNDENDIF] = ACTIONS(9054),
    [anon_sym_POUNDEndif] = ACTIONS(9054),
    [anon_sym_POUNDendif2] = ACTIONS(9054),
    [anon_sym_POUNDENDIF2] = ACTIONS(9054),
    [anon_sym_POUNDEndif2] = ACTIONS(9054),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9052),
    [sym_procedure_keyword] = ACTIONS(9052),
    [sym_trigger_keyword] = ACTIONS(9052),
    [sym_var_keyword] = ACTIONS(9052),
    [sym_local_keyword] = ACTIONS(9052),
    [sym_internal_keyword] = ACTIONS(9052),
    [sym_protected_keyword] = ACTIONS(9052),
    [sym_event_keyword] = ACTIONS(9052),
    [sym_fields_keyword] = ACTIONS(9052),
    [sym_keys_keyword] = ACTIONS(9052),
    [sym_key_keyword] = ACTIONS(9052),
    [sym_fieldgroups_keyword] = ACTIONS(9052),
    [sym_actions_keyword] = ACTIONS(9052),
    [sym_layout_keyword] = ACTIONS(9052),
    [sym_dataset_keyword] = ACTIONS(9052),
    [sym_elements_keyword] = ACTIONS(9052),
    [sym_labels_keyword] = ACTIONS(9052),
    [sym_rendering_keyword] = ACTIONS(9052),
    [sym_requestpage_keyword] = ACTIONS(9052),
    [sym_schema_keyword] = ACTIONS(9052),
    [sym_views_keyword] = ACTIONS(9052),
    [sym_quoted_identifier] = ACTIONS(9054),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9054),
    [sym_preproc_open] = ACTIONS(9054),
    [sym_preproc_close] = ACTIONS(9054),
    [sym_var_attribute_open] = ACTIONS(9054),
  },
  [STATE(5874)] = {
    [sym_property] = STATE(5866),
    [sym__action_element] = STATE(5866),
    [sym_action_area_section] = STATE(5866),
    [sym_action_group_section] = STATE(5866),
    [sym_action_declaration] = STATE(5866),
    [sym_separator_action] = STATE(5866),
    [sym_actionref_declaration] = STATE(5866),
    [sym_systemaction_declaration] = STATE(5866),
    [sym_fileuploadaction_declaration] = STATE(5866),
    [sym_customaction_declaration] = STATE(5866),
    [sym_addfirst_action_modification] = STATE(5866),
    [sym_addlast_action_modification] = STATE(5866),
    [sym_addafter_action_modification] = STATE(5866),
    [sym_addbefore_action_modification] = STATE(5866),
    [sym_modify_action_modification] = STATE(5866),
    [sym_trigger_declaration] = STATE(5866),
    [sym_attribute_item] = STATE(5866),
    [sym_preproc_if] = STATE(5874),
    [sym_preproc_elif] = STATE(6593),
    [sym_preproc_else] = STATE(8055),
    [sym_preproc_endif] = STATE(8929),
    [sym_preproc_conditional_actions] = STATE(5866),
    [aux_sym_actions_section_repeat1] = STATE(5866),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(10698),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(14463),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(14465),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [anon_sym_POUNDif] = ACTIONS(14467),
    [anon_sym_POUNDIF] = ACTIONS(14467),
    [anon_sym_POUNDIf] = ACTIONS(14467),
    [anon_sym_POUNDelif] = ACTIONS(14469),
    [anon_sym_POUNDELIF] = ACTIONS(14469),
    [anon_sym_POUNDElif] = ACTIONS(14469),
    [anon_sym_POUNDelse] = ACTIONS(14471),
    [anon_sym_POUNDELSE] = ACTIONS(14471),
    [anon_sym_POUNDElse] = ACTIONS(14471),
    [anon_sym_POUNDelse2] = ACTIONS(14471),
    [anon_sym_POUNDELSE2] = ACTIONS(14471),
    [anon_sym_POUNDElse2] = ACTIONS(14471),
    [anon_sym_POUNDendif] = ACTIONS(14479),
    [anon_sym_POUNDENDIF] = ACTIONS(14479),
    [anon_sym_POUNDEndif] = ACTIONS(14479),
    [anon_sym_POUNDendif2] = ACTIONS(14479),
    [anon_sym_POUNDENDIF2] = ACTIONS(14479),
    [anon_sym_POUNDEndif2] = ACTIONS(14479),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_trigger_keyword] = ACTIONS(14473),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(14475),
    [sym_preproc_open] = ACTIONS(14467),
    [sym_preproc_close] = ACTIONS(14479),
  },
  [STATE(5875)] = {
    [sym_identifier] = ACTIONS(9052),
    [anon_sym_SEMI] = ACTIONS(9054),
    [aux_sym_where_condition_token1] = ACTIONS(9052),
    [anon_sym_LBRACK] = ACTIONS(9054),
    [aux_sym_basic_type_token22] = ACTIONS(9052),
    [aux_sym_basic_type_token53] = ACTIONS(9052),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9052),
    [aux_sym_modify_modification_token1] = ACTIONS(9052),
    [aux_sym_separator_action_token1] = ACTIONS(9052),
    [aux_sym_xmlport_element_token1] = ACTIONS(9052),
    [aux_sym_xmlport_element_token2] = ACTIONS(9052),
    [aux_sym_xmlport_element_token3] = ACTIONS(9052),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9052),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9052),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9052),
    [aux_sym_type_declaration_token1] = ACTIONS(9052),
    [anon_sym_POUNDif] = ACTIONS(9054),
    [anon_sym_POUNDIF] = ACTIONS(9054),
    [anon_sym_POUNDIf] = ACTIONS(9054),
    [anon_sym_POUNDelif] = ACTIONS(9054),
    [anon_sym_POUNDELIF] = ACTIONS(9054),
    [anon_sym_POUNDElif] = ACTIONS(9054),
    [anon_sym_POUNDelse] = ACTIONS(9054),
    [anon_sym_POUNDELSE] = ACTIONS(9054),
    [anon_sym_POUNDElse] = ACTIONS(9054),
    [anon_sym_POUNDelse2] = ACTIONS(9054),
    [anon_sym_POUNDELSE2] = ACTIONS(9054),
    [anon_sym_POUNDElse2] = ACTIONS(9054),
    [anon_sym_POUNDendif] = ACTIONS(9054),
    [anon_sym_POUNDENDIF] = ACTIONS(9054),
    [anon_sym_POUNDEndif] = ACTIONS(9054),
    [anon_sym_POUNDendif2] = ACTIONS(9054),
    [anon_sym_POUNDENDIF2] = ACTIONS(9054),
    [anon_sym_POUNDEndif2] = ACTIONS(9054),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9052),
    [sym_procedure_keyword] = ACTIONS(9052),
    [sym_trigger_keyword] = ACTIONS(9052),
    [sym_var_keyword] = ACTIONS(9052),
    [sym_local_keyword] = ACTIONS(9052),
    [sym_internal_keyword] = ACTIONS(9052),
    [sym_protected_keyword] = ACTIONS(9052),
    [sym_event_keyword] = ACTIONS(9052),
    [sym_fields_keyword] = ACTIONS(9052),
    [sym_keys_keyword] = ACTIONS(9052),
    [sym_key_keyword] = ACTIONS(9052),
    [sym_fieldgroups_keyword] = ACTIONS(9052),
    [sym_actions_keyword] = ACTIONS(9052),
    [sym_layout_keyword] = ACTIONS(9052),
    [sym_dataset_keyword] = ACTIONS(9052),
    [sym_elements_keyword] = ACTIONS(9052),
    [sym_labels_keyword] = ACTIONS(9052),
    [sym_rendering_keyword] = ACTIONS(9052),
    [sym_requestpage_keyword] = ACTIONS(9052),
    [sym_schema_keyword] = ACTIONS(9052),
    [sym_views_keyword] = ACTIONS(9052),
    [sym_quoted_identifier] = ACTIONS(9054),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9054),
    [sym_preproc_open] = ACTIONS(9054),
    [sym_preproc_close] = ACTIONS(9054),
    [sym_var_attribute_open] = ACTIONS(9054),
  },
  [STATE(5876)] = {
    [sym_identifier] = ACTIONS(9018),
    [anon_sym_SEMI] = ACTIONS(9020),
    [aux_sym_where_condition_token1] = ACTIONS(9018),
    [anon_sym_LBRACK] = ACTIONS(9020),
    [aux_sym_basic_type_token22] = ACTIONS(9018),
    [aux_sym_basic_type_token53] = ACTIONS(9018),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9018),
    [aux_sym_modify_modification_token1] = ACTIONS(9018),
    [aux_sym_separator_action_token1] = ACTIONS(9018),
    [aux_sym_xmlport_element_token1] = ACTIONS(9018),
    [aux_sym_xmlport_element_token2] = ACTIONS(9018),
    [aux_sym_xmlport_element_token3] = ACTIONS(9018),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9018),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9018),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9018),
    [aux_sym_type_declaration_token1] = ACTIONS(9018),
    [anon_sym_POUNDif] = ACTIONS(9020),
    [anon_sym_POUNDIF] = ACTIONS(9020),
    [anon_sym_POUNDIf] = ACTIONS(9020),
    [anon_sym_POUNDelif] = ACTIONS(9020),
    [anon_sym_POUNDELIF] = ACTIONS(9020),
    [anon_sym_POUNDElif] = ACTIONS(9020),
    [anon_sym_POUNDelse] = ACTIONS(9020),
    [anon_sym_POUNDELSE] = ACTIONS(9020),
    [anon_sym_POUNDElse] = ACTIONS(9020),
    [anon_sym_POUNDelse2] = ACTIONS(9020),
    [anon_sym_POUNDELSE2] = ACTIONS(9020),
    [anon_sym_POUNDElse2] = ACTIONS(9020),
    [anon_sym_POUNDendif] = ACTIONS(9020),
    [anon_sym_POUNDENDIF] = ACTIONS(9020),
    [anon_sym_POUNDEndif] = ACTIONS(9020),
    [anon_sym_POUNDendif2] = ACTIONS(9020),
    [anon_sym_POUNDENDIF2] = ACTIONS(9020),
    [anon_sym_POUNDEndif2] = ACTIONS(9020),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9018),
    [sym_procedure_keyword] = ACTIONS(9018),
    [sym_trigger_keyword] = ACTIONS(9018),
    [sym_var_keyword] = ACTIONS(9018),
    [sym_local_keyword] = ACTIONS(9018),
    [sym_internal_keyword] = ACTIONS(9018),
    [sym_protected_keyword] = ACTIONS(9018),
    [sym_event_keyword] = ACTIONS(9018),
    [sym_fields_keyword] = ACTIONS(9018),
    [sym_keys_keyword] = ACTIONS(9018),
    [sym_key_keyword] = ACTIONS(9018),
    [sym_fieldgroups_keyword] = ACTIONS(9018),
    [sym_actions_keyword] = ACTIONS(9018),
    [sym_layout_keyword] = ACTIONS(9018),
    [sym_dataset_keyword] = ACTIONS(9018),
    [sym_elements_keyword] = ACTIONS(9018),
    [sym_labels_keyword] = ACTIONS(9018),
    [sym_rendering_keyword] = ACTIONS(9018),
    [sym_requestpage_keyword] = ACTIONS(9018),
    [sym_schema_keyword] = ACTIONS(9018),
    [sym_views_keyword] = ACTIONS(9018),
    [sym_quoted_identifier] = ACTIONS(9020),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9020),
    [sym_preproc_open] = ACTIONS(9020),
    [sym_preproc_close] = ACTIONS(9020),
    [sym_var_attribute_open] = ACTIONS(9020),
  },
  [STATE(5877)] = {
    [sym_identifier] = ACTIONS(6192),
    [anon_sym_SEMI] = ACTIONS(6194),
    [aux_sym_where_condition_token1] = ACTIONS(6192),
    [anon_sym_LBRACK] = ACTIONS(6194),
    [aux_sym_basic_type_token22] = ACTIONS(6192),
    [aux_sym_basic_type_token53] = ACTIONS(6192),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6192),
    [aux_sym_modify_modification_token1] = ACTIONS(6192),
    [aux_sym_separator_action_token1] = ACTIONS(6192),
    [aux_sym_xmlport_element_token1] = ACTIONS(6192),
    [aux_sym_xmlport_element_token2] = ACTIONS(6192),
    [aux_sym_xmlport_element_token3] = ACTIONS(6192),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6192),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6192),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6192),
    [aux_sym_type_declaration_token1] = ACTIONS(6192),
    [anon_sym_POUNDif] = ACTIONS(6194),
    [anon_sym_POUNDIF] = ACTIONS(6194),
    [anon_sym_POUNDIf] = ACTIONS(6194),
    [anon_sym_POUNDelif] = ACTIONS(6194),
    [anon_sym_POUNDELIF] = ACTIONS(6194),
    [anon_sym_POUNDElif] = ACTIONS(6194),
    [anon_sym_POUNDelse] = ACTIONS(6194),
    [anon_sym_POUNDELSE] = ACTIONS(6194),
    [anon_sym_POUNDElse] = ACTIONS(6194),
    [anon_sym_POUNDelse2] = ACTIONS(6194),
    [anon_sym_POUNDELSE2] = ACTIONS(6194),
    [anon_sym_POUNDElse2] = ACTIONS(6194),
    [anon_sym_POUNDendif] = ACTIONS(6194),
    [anon_sym_POUNDENDIF] = ACTIONS(6194),
    [anon_sym_POUNDEndif] = ACTIONS(6194),
    [anon_sym_POUNDendif2] = ACTIONS(6194),
    [anon_sym_POUNDENDIF2] = ACTIONS(6194),
    [anon_sym_POUNDEndif2] = ACTIONS(6194),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6192),
    [sym_procedure_keyword] = ACTIONS(6192),
    [sym_trigger_keyword] = ACTIONS(6192),
    [sym_var_keyword] = ACTIONS(6192),
    [sym_local_keyword] = ACTIONS(6192),
    [sym_internal_keyword] = ACTIONS(6192),
    [sym_protected_keyword] = ACTIONS(6192),
    [sym_event_keyword] = ACTIONS(6192),
    [sym_fields_keyword] = ACTIONS(6192),
    [sym_keys_keyword] = ACTIONS(6192),
    [sym_key_keyword] = ACTIONS(6192),
    [sym_fieldgroups_keyword] = ACTIONS(6192),
    [sym_actions_keyword] = ACTIONS(6192),
    [sym_layout_keyword] = ACTIONS(6192),
    [sym_dataset_keyword] = ACTIONS(6192),
    [sym_elements_keyword] = ACTIONS(6192),
    [sym_labels_keyword] = ACTIONS(6192),
    [sym_rendering_keyword] = ACTIONS(6192),
    [sym_requestpage_keyword] = ACTIONS(6192),
    [sym_schema_keyword] = ACTIONS(6192),
    [sym_views_keyword] = ACTIONS(6192),
    [sym_quoted_identifier] = ACTIONS(6194),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6194),
    [sym_preproc_open] = ACTIONS(6194),
    [sym_preproc_close] = ACTIONS(6194),
    [sym_var_attribute_open] = ACTIONS(6194),
  },
  [STATE(5878)] = {
    [sym_identifier] = ACTIONS(9022),
    [anon_sym_SEMI] = ACTIONS(9024),
    [aux_sym_where_condition_token1] = ACTIONS(9022),
    [anon_sym_LBRACK] = ACTIONS(9024),
    [aux_sym_basic_type_token22] = ACTIONS(9022),
    [aux_sym_basic_type_token53] = ACTIONS(9022),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9022),
    [aux_sym_modify_modification_token1] = ACTIONS(9022),
    [aux_sym_separator_action_token1] = ACTIONS(9022),
    [aux_sym_xmlport_element_token1] = ACTIONS(9022),
    [aux_sym_xmlport_element_token2] = ACTIONS(9022),
    [aux_sym_xmlport_element_token3] = ACTIONS(9022),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9022),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9022),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9022),
    [aux_sym_type_declaration_token1] = ACTIONS(9022),
    [anon_sym_POUNDif] = ACTIONS(9024),
    [anon_sym_POUNDIF] = ACTIONS(9024),
    [anon_sym_POUNDIf] = ACTIONS(9024),
    [anon_sym_POUNDelif] = ACTIONS(9024),
    [anon_sym_POUNDELIF] = ACTIONS(9024),
    [anon_sym_POUNDElif] = ACTIONS(9024),
    [anon_sym_POUNDelse] = ACTIONS(9024),
    [anon_sym_POUNDELSE] = ACTIONS(9024),
    [anon_sym_POUNDElse] = ACTIONS(9024),
    [anon_sym_POUNDelse2] = ACTIONS(9024),
    [anon_sym_POUNDELSE2] = ACTIONS(9024),
    [anon_sym_POUNDElse2] = ACTIONS(9024),
    [anon_sym_POUNDendif] = ACTIONS(9024),
    [anon_sym_POUNDENDIF] = ACTIONS(9024),
    [anon_sym_POUNDEndif] = ACTIONS(9024),
    [anon_sym_POUNDendif2] = ACTIONS(9024),
    [anon_sym_POUNDENDIF2] = ACTIONS(9024),
    [anon_sym_POUNDEndif2] = ACTIONS(9024),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9022),
    [sym_procedure_keyword] = ACTIONS(9022),
    [sym_trigger_keyword] = ACTIONS(9022),
    [sym_var_keyword] = ACTIONS(9022),
    [sym_local_keyword] = ACTIONS(9022),
    [sym_internal_keyword] = ACTIONS(9022),
    [sym_protected_keyword] = ACTIONS(9022),
    [sym_event_keyword] = ACTIONS(9022),
    [sym_fields_keyword] = ACTIONS(9022),
    [sym_keys_keyword] = ACTIONS(9022),
    [sym_key_keyword] = ACTIONS(9022),
    [sym_fieldgroups_keyword] = ACTIONS(9022),
    [sym_actions_keyword] = ACTIONS(9022),
    [sym_layout_keyword] = ACTIONS(9022),
    [sym_dataset_keyword] = ACTIONS(9022),
    [sym_elements_keyword] = ACTIONS(9022),
    [sym_labels_keyword] = ACTIONS(9022),
    [sym_rendering_keyword] = ACTIONS(9022),
    [sym_requestpage_keyword] = ACTIONS(9022),
    [sym_schema_keyword] = ACTIONS(9022),
    [sym_views_keyword] = ACTIONS(9022),
    [sym_quoted_identifier] = ACTIONS(9024),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9024),
    [sym_preproc_open] = ACTIONS(9024),
    [sym_preproc_close] = ACTIONS(9024),
    [sym_var_attribute_open] = ACTIONS(9024),
  },
  [STATE(5879)] = {
    [sym_identifier] = ACTIONS(6152),
    [anon_sym_SEMI] = ACTIONS(6154),
    [aux_sym_where_condition_token1] = ACTIONS(6152),
    [anon_sym_LBRACK] = ACTIONS(6154),
    [aux_sym_basic_type_token22] = ACTIONS(6152),
    [aux_sym_basic_type_token53] = ACTIONS(6152),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6152),
    [aux_sym_modify_modification_token1] = ACTIONS(6152),
    [aux_sym_separator_action_token1] = ACTIONS(6152),
    [aux_sym_xmlport_element_token1] = ACTIONS(6152),
    [aux_sym_xmlport_element_token2] = ACTIONS(6152),
    [aux_sym_xmlport_element_token3] = ACTIONS(6152),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6152),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6152),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6152),
    [aux_sym_type_declaration_token1] = ACTIONS(6152),
    [anon_sym_POUNDif] = ACTIONS(6154),
    [anon_sym_POUNDIF] = ACTIONS(6154),
    [anon_sym_POUNDIf] = ACTIONS(6154),
    [anon_sym_POUNDelif] = ACTIONS(6154),
    [anon_sym_POUNDELIF] = ACTIONS(6154),
    [anon_sym_POUNDElif] = ACTIONS(6154),
    [anon_sym_POUNDelse] = ACTIONS(6154),
    [anon_sym_POUNDELSE] = ACTIONS(6154),
    [anon_sym_POUNDElse] = ACTIONS(6154),
    [anon_sym_POUNDelse2] = ACTIONS(6154),
    [anon_sym_POUNDELSE2] = ACTIONS(6154),
    [anon_sym_POUNDElse2] = ACTIONS(6154),
    [anon_sym_POUNDendif] = ACTIONS(6154),
    [anon_sym_POUNDENDIF] = ACTIONS(6154),
    [anon_sym_POUNDEndif] = ACTIONS(6154),
    [anon_sym_POUNDendif2] = ACTIONS(6154),
    [anon_sym_POUNDENDIF2] = ACTIONS(6154),
    [anon_sym_POUNDEndif2] = ACTIONS(6154),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6152),
    [sym_procedure_keyword] = ACTIONS(6152),
    [sym_trigger_keyword] = ACTIONS(6152),
    [sym_var_keyword] = ACTIONS(6152),
    [sym_local_keyword] = ACTIONS(6152),
    [sym_internal_keyword] = ACTIONS(6152),
    [sym_protected_keyword] = ACTIONS(6152),
    [sym_event_keyword] = ACTIONS(6152),
    [sym_fields_keyword] = ACTIONS(6152),
    [sym_keys_keyword] = ACTIONS(6152),
    [sym_key_keyword] = ACTIONS(6152),
    [sym_fieldgroups_keyword] = ACTIONS(6152),
    [sym_actions_keyword] = ACTIONS(6152),
    [sym_layout_keyword] = ACTIONS(6152),
    [sym_dataset_keyword] = ACTIONS(6152),
    [sym_elements_keyword] = ACTIONS(6152),
    [sym_labels_keyword] = ACTIONS(6152),
    [sym_rendering_keyword] = ACTIONS(6152),
    [sym_requestpage_keyword] = ACTIONS(6152),
    [sym_schema_keyword] = ACTIONS(6152),
    [sym_views_keyword] = ACTIONS(6152),
    [sym_quoted_identifier] = ACTIONS(6154),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6154),
    [sym_preproc_open] = ACTIONS(6154),
    [sym_preproc_close] = ACTIONS(6154),
    [sym_var_attribute_open] = ACTIONS(6154),
  },
  [STATE(5880)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_xmlport_element_token1] = ACTIONS(8905),
    [aux_sym_xmlport_element_token2] = ACTIONS(8905),
    [aux_sym_xmlport_element_token3] = ACTIONS(8905),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8905),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(5881)] = {
    [sym_identifier] = ACTIONS(8909),
    [anon_sym_SEMI] = ACTIONS(8911),
    [aux_sym_where_condition_token1] = ACTIONS(8909),
    [anon_sym_LBRACK] = ACTIONS(8911),
    [aux_sym_basic_type_token22] = ACTIONS(8909),
    [aux_sym_basic_type_token53] = ACTIONS(8909),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8909),
    [aux_sym_modify_modification_token1] = ACTIONS(8909),
    [aux_sym_separator_action_token1] = ACTIONS(8909),
    [aux_sym_xmlport_element_token1] = ACTIONS(8909),
    [aux_sym_xmlport_element_token2] = ACTIONS(8909),
    [aux_sym_xmlport_element_token3] = ACTIONS(8909),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8909),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8909),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8909),
    [aux_sym_type_declaration_token1] = ACTIONS(8909),
    [anon_sym_POUNDif] = ACTIONS(8911),
    [anon_sym_POUNDIF] = ACTIONS(8911),
    [anon_sym_POUNDIf] = ACTIONS(8911),
    [anon_sym_POUNDelif] = ACTIONS(8911),
    [anon_sym_POUNDELIF] = ACTIONS(8911),
    [anon_sym_POUNDElif] = ACTIONS(8911),
    [anon_sym_POUNDelse] = ACTIONS(8911),
    [anon_sym_POUNDELSE] = ACTIONS(8911),
    [anon_sym_POUNDElse] = ACTIONS(8911),
    [anon_sym_POUNDelse2] = ACTIONS(8911),
    [anon_sym_POUNDELSE2] = ACTIONS(8911),
    [anon_sym_POUNDElse2] = ACTIONS(8911),
    [anon_sym_POUNDendif] = ACTIONS(8911),
    [anon_sym_POUNDENDIF] = ACTIONS(8911),
    [anon_sym_POUNDEndif] = ACTIONS(8911),
    [anon_sym_POUNDendif2] = ACTIONS(8911),
    [anon_sym_POUNDENDIF2] = ACTIONS(8911),
    [anon_sym_POUNDEndif2] = ACTIONS(8911),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8909),
    [sym_procedure_keyword] = ACTIONS(8909),
    [sym_trigger_keyword] = ACTIONS(8909),
    [sym_var_keyword] = ACTIONS(8909),
    [sym_local_keyword] = ACTIONS(8909),
    [sym_internal_keyword] = ACTIONS(8909),
    [sym_protected_keyword] = ACTIONS(8909),
    [sym_event_keyword] = ACTIONS(8909),
    [sym_fields_keyword] = ACTIONS(8909),
    [sym_keys_keyword] = ACTIONS(8909),
    [sym_key_keyword] = ACTIONS(8909),
    [sym_fieldgroups_keyword] = ACTIONS(8909),
    [sym_actions_keyword] = ACTIONS(8909),
    [sym_layout_keyword] = ACTIONS(8909),
    [sym_dataset_keyword] = ACTIONS(8909),
    [sym_elements_keyword] = ACTIONS(8909),
    [sym_labels_keyword] = ACTIONS(8909),
    [sym_rendering_keyword] = ACTIONS(8909),
    [sym_requestpage_keyword] = ACTIONS(8909),
    [sym_schema_keyword] = ACTIONS(8909),
    [sym_views_keyword] = ACTIONS(8909),
    [sym_quoted_identifier] = ACTIONS(8911),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8911),
    [sym_preproc_open] = ACTIONS(8911),
    [sym_preproc_close] = ACTIONS(8911),
    [sym_var_attribute_open] = ACTIONS(8911),
  },
  [STATE(5882)] = {
    [sym_identifier] = ACTIONS(9064),
    [anon_sym_SEMI] = ACTIONS(9066),
    [aux_sym_where_condition_token1] = ACTIONS(9064),
    [anon_sym_LBRACK] = ACTIONS(9066),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token53] = ACTIONS(9064),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9064),
    [aux_sym_modify_modification_token1] = ACTIONS(9064),
    [aux_sym_separator_action_token1] = ACTIONS(9064),
    [aux_sym_xmlport_element_token1] = ACTIONS(9064),
    [aux_sym_xmlport_element_token2] = ACTIONS(9064),
    [aux_sym_xmlport_element_token3] = ACTIONS(9064),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9064),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9064),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9064),
    [aux_sym_type_declaration_token1] = ACTIONS(9064),
    [anon_sym_POUNDif] = ACTIONS(9066),
    [anon_sym_POUNDIF] = ACTIONS(9066),
    [anon_sym_POUNDIf] = ACTIONS(9066),
    [anon_sym_POUNDelif] = ACTIONS(9066),
    [anon_sym_POUNDELIF] = ACTIONS(9066),
    [anon_sym_POUNDElif] = ACTIONS(9066),
    [anon_sym_POUNDelse] = ACTIONS(9066),
    [anon_sym_POUNDELSE] = ACTIONS(9066),
    [anon_sym_POUNDElse] = ACTIONS(9066),
    [anon_sym_POUNDelse2] = ACTIONS(9066),
    [anon_sym_POUNDELSE2] = ACTIONS(9066),
    [anon_sym_POUNDElse2] = ACTIONS(9066),
    [anon_sym_POUNDendif] = ACTIONS(9066),
    [anon_sym_POUNDENDIF] = ACTIONS(9066),
    [anon_sym_POUNDEndif] = ACTIONS(9066),
    [anon_sym_POUNDendif2] = ACTIONS(9066),
    [anon_sym_POUNDENDIF2] = ACTIONS(9066),
    [anon_sym_POUNDEndif2] = ACTIONS(9066),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9064),
    [sym_procedure_keyword] = ACTIONS(9064),
    [sym_trigger_keyword] = ACTIONS(9064),
    [sym_var_keyword] = ACTIONS(9064),
    [sym_local_keyword] = ACTIONS(9064),
    [sym_internal_keyword] = ACTIONS(9064),
    [sym_protected_keyword] = ACTIONS(9064),
    [sym_event_keyword] = ACTIONS(9064),
    [sym_fields_keyword] = ACTIONS(9064),
    [sym_keys_keyword] = ACTIONS(9064),
    [sym_key_keyword] = ACTIONS(9064),
    [sym_fieldgroups_keyword] = ACTIONS(9064),
    [sym_actions_keyword] = ACTIONS(9064),
    [sym_layout_keyword] = ACTIONS(9064),
    [sym_dataset_keyword] = ACTIONS(9064),
    [sym_elements_keyword] = ACTIONS(9064),
    [sym_labels_keyword] = ACTIONS(9064),
    [sym_rendering_keyword] = ACTIONS(9064),
    [sym_requestpage_keyword] = ACTIONS(9064),
    [sym_schema_keyword] = ACTIONS(9064),
    [sym_views_keyword] = ACTIONS(9064),
    [sym_quoted_identifier] = ACTIONS(9066),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9066),
    [sym_preproc_open] = ACTIONS(9066),
    [sym_preproc_close] = ACTIONS(9066),
    [sym_var_attribute_open] = ACTIONS(9066),
  },
  [STATE(5883)] = {
    [sym_identifier] = ACTIONS(9026),
    [anon_sym_SEMI] = ACTIONS(9028),
    [aux_sym_where_condition_token1] = ACTIONS(9026),
    [anon_sym_LBRACK] = ACTIONS(9028),
    [aux_sym_basic_type_token22] = ACTIONS(9026),
    [aux_sym_basic_type_token53] = ACTIONS(9026),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9026),
    [aux_sym_modify_modification_token1] = ACTIONS(9026),
    [aux_sym_separator_action_token1] = ACTIONS(9026),
    [aux_sym_xmlport_element_token1] = ACTIONS(9026),
    [aux_sym_xmlport_element_token2] = ACTIONS(9026),
    [aux_sym_xmlport_element_token3] = ACTIONS(9026),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9026),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9026),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9026),
    [aux_sym_type_declaration_token1] = ACTIONS(9026),
    [anon_sym_POUNDif] = ACTIONS(9028),
    [anon_sym_POUNDIF] = ACTIONS(9028),
    [anon_sym_POUNDIf] = ACTIONS(9028),
    [anon_sym_POUNDelif] = ACTIONS(9028),
    [anon_sym_POUNDELIF] = ACTIONS(9028),
    [anon_sym_POUNDElif] = ACTIONS(9028),
    [anon_sym_POUNDelse] = ACTIONS(9028),
    [anon_sym_POUNDELSE] = ACTIONS(9028),
    [anon_sym_POUNDElse] = ACTIONS(9028),
    [anon_sym_POUNDelse2] = ACTIONS(9028),
    [anon_sym_POUNDELSE2] = ACTIONS(9028),
    [anon_sym_POUNDElse2] = ACTIONS(9028),
    [anon_sym_POUNDendif] = ACTIONS(9028),
    [anon_sym_POUNDENDIF] = ACTIONS(9028),
    [anon_sym_POUNDEndif] = ACTIONS(9028),
    [anon_sym_POUNDendif2] = ACTIONS(9028),
    [anon_sym_POUNDENDIF2] = ACTIONS(9028),
    [anon_sym_POUNDEndif2] = ACTIONS(9028),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9026),
    [sym_procedure_keyword] = ACTIONS(9026),
    [sym_trigger_keyword] = ACTIONS(9026),
    [sym_var_keyword] = ACTIONS(9026),
    [sym_local_keyword] = ACTIONS(9026),
    [sym_internal_keyword] = ACTIONS(9026),
    [sym_protected_keyword] = ACTIONS(9026),
    [sym_event_keyword] = ACTIONS(9026),
    [sym_fields_keyword] = ACTIONS(9026),
    [sym_keys_keyword] = ACTIONS(9026),
    [sym_key_keyword] = ACTIONS(9026),
    [sym_fieldgroups_keyword] = ACTIONS(9026),
    [sym_actions_keyword] = ACTIONS(9026),
    [sym_layout_keyword] = ACTIONS(9026),
    [sym_dataset_keyword] = ACTIONS(9026),
    [sym_elements_keyword] = ACTIONS(9026),
    [sym_labels_keyword] = ACTIONS(9026),
    [sym_rendering_keyword] = ACTIONS(9026),
    [sym_requestpage_keyword] = ACTIONS(9026),
    [sym_schema_keyword] = ACTIONS(9026),
    [sym_views_keyword] = ACTIONS(9026),
    [sym_quoted_identifier] = ACTIONS(9028),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9028),
    [sym_preproc_open] = ACTIONS(9028),
    [sym_preproc_close] = ACTIONS(9028),
    [sym_var_attribute_open] = ACTIONS(9028),
  },
  [STATE(5884)] = {
    [sym_identifier] = ACTIONS(8990),
    [anon_sym_SEMI] = ACTIONS(8992),
    [aux_sym_where_condition_token1] = ACTIONS(8990),
    [anon_sym_LBRACK] = ACTIONS(8992),
    [aux_sym_basic_type_token22] = ACTIONS(8990),
    [aux_sym_basic_type_token53] = ACTIONS(8990),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8990),
    [aux_sym_modify_modification_token1] = ACTIONS(8990),
    [aux_sym_separator_action_token1] = ACTIONS(8990),
    [aux_sym_xmlport_element_token1] = ACTIONS(8990),
    [aux_sym_xmlport_element_token2] = ACTIONS(8990),
    [aux_sym_xmlport_element_token3] = ACTIONS(8990),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8990),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8990),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8990),
    [aux_sym_type_declaration_token1] = ACTIONS(8990),
    [anon_sym_POUNDif] = ACTIONS(8992),
    [anon_sym_POUNDIF] = ACTIONS(8992),
    [anon_sym_POUNDIf] = ACTIONS(8992),
    [anon_sym_POUNDelif] = ACTIONS(8992),
    [anon_sym_POUNDELIF] = ACTIONS(8992),
    [anon_sym_POUNDElif] = ACTIONS(8992),
    [anon_sym_POUNDelse] = ACTIONS(8992),
    [anon_sym_POUNDELSE] = ACTIONS(8992),
    [anon_sym_POUNDElse] = ACTIONS(8992),
    [anon_sym_POUNDelse2] = ACTIONS(8992),
    [anon_sym_POUNDELSE2] = ACTIONS(8992),
    [anon_sym_POUNDElse2] = ACTIONS(8992),
    [anon_sym_POUNDendif] = ACTIONS(8992),
    [anon_sym_POUNDENDIF] = ACTIONS(8992),
    [anon_sym_POUNDEndif] = ACTIONS(8992),
    [anon_sym_POUNDendif2] = ACTIONS(8992),
    [anon_sym_POUNDENDIF2] = ACTIONS(8992),
    [anon_sym_POUNDEndif2] = ACTIONS(8992),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8990),
    [sym_procedure_keyword] = ACTIONS(8990),
    [sym_trigger_keyword] = ACTIONS(8990),
    [sym_var_keyword] = ACTIONS(8990),
    [sym_local_keyword] = ACTIONS(8990),
    [sym_internal_keyword] = ACTIONS(8990),
    [sym_protected_keyword] = ACTIONS(8990),
    [sym_event_keyword] = ACTIONS(8990),
    [sym_fields_keyword] = ACTIONS(8990),
    [sym_keys_keyword] = ACTIONS(8990),
    [sym_key_keyword] = ACTIONS(8990),
    [sym_fieldgroups_keyword] = ACTIONS(8990),
    [sym_actions_keyword] = ACTIONS(8990),
    [sym_layout_keyword] = ACTIONS(8990),
    [sym_dataset_keyword] = ACTIONS(8990),
    [sym_elements_keyword] = ACTIONS(8990),
    [sym_labels_keyword] = ACTIONS(8990),
    [sym_rendering_keyword] = ACTIONS(8990),
    [sym_requestpage_keyword] = ACTIONS(8990),
    [sym_schema_keyword] = ACTIONS(8990),
    [sym_views_keyword] = ACTIONS(8990),
    [sym_quoted_identifier] = ACTIONS(8992),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8992),
    [sym_preproc_open] = ACTIONS(8992),
    [sym_preproc_close] = ACTIONS(8992),
    [sym_var_attribute_open] = ACTIONS(8992),
  },
  [STATE(5885)] = {
    [sym_identifier] = ACTIONS(6164),
    [anon_sym_SEMI] = ACTIONS(6166),
    [aux_sym_where_condition_token1] = ACTIONS(6164),
    [anon_sym_LBRACK] = ACTIONS(6166),
    [aux_sym_basic_type_token22] = ACTIONS(6164),
    [aux_sym_basic_type_token53] = ACTIONS(6164),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6164),
    [aux_sym_modify_modification_token1] = ACTIONS(6164),
    [aux_sym_separator_action_token1] = ACTIONS(6164),
    [aux_sym_xmlport_element_token1] = ACTIONS(6164),
    [aux_sym_xmlport_element_token2] = ACTIONS(6164),
    [aux_sym_xmlport_element_token3] = ACTIONS(6164),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6164),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6164),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6164),
    [aux_sym_type_declaration_token1] = ACTIONS(6164),
    [anon_sym_POUNDif] = ACTIONS(6166),
    [anon_sym_POUNDIF] = ACTIONS(6166),
    [anon_sym_POUNDIf] = ACTIONS(6166),
    [anon_sym_POUNDelif] = ACTIONS(6166),
    [anon_sym_POUNDELIF] = ACTIONS(6166),
    [anon_sym_POUNDElif] = ACTIONS(6166),
    [anon_sym_POUNDelse] = ACTIONS(6166),
    [anon_sym_POUNDELSE] = ACTIONS(6166),
    [anon_sym_POUNDElse] = ACTIONS(6166),
    [anon_sym_POUNDelse2] = ACTIONS(6166),
    [anon_sym_POUNDELSE2] = ACTIONS(6166),
    [anon_sym_POUNDElse2] = ACTIONS(6166),
    [anon_sym_POUNDendif] = ACTIONS(6166),
    [anon_sym_POUNDENDIF] = ACTIONS(6166),
    [anon_sym_POUNDEndif] = ACTIONS(6166),
    [anon_sym_POUNDendif2] = ACTIONS(6166),
    [anon_sym_POUNDENDIF2] = ACTIONS(6166),
    [anon_sym_POUNDEndif2] = ACTIONS(6166),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6164),
    [sym_procedure_keyword] = ACTIONS(6164),
    [sym_trigger_keyword] = ACTIONS(6164),
    [sym_var_keyword] = ACTIONS(6164),
    [sym_local_keyword] = ACTIONS(6164),
    [sym_internal_keyword] = ACTIONS(6164),
    [sym_protected_keyword] = ACTIONS(6164),
    [sym_event_keyword] = ACTIONS(6164),
    [sym_fields_keyword] = ACTIONS(6164),
    [sym_keys_keyword] = ACTIONS(6164),
    [sym_key_keyword] = ACTIONS(6164),
    [sym_fieldgroups_keyword] = ACTIONS(6164),
    [sym_actions_keyword] = ACTIONS(6164),
    [sym_layout_keyword] = ACTIONS(6164),
    [sym_dataset_keyword] = ACTIONS(6164),
    [sym_elements_keyword] = ACTIONS(6164),
    [sym_labels_keyword] = ACTIONS(6164),
    [sym_rendering_keyword] = ACTIONS(6164),
    [sym_requestpage_keyword] = ACTIONS(6164),
    [sym_schema_keyword] = ACTIONS(6164),
    [sym_views_keyword] = ACTIONS(6164),
    [sym_quoted_identifier] = ACTIONS(6166),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6166),
    [sym_preproc_open] = ACTIONS(6166),
    [sym_preproc_close] = ACTIONS(6166),
    [sym_var_attribute_open] = ACTIONS(6166),
  },
  [STATE(5886)] = {
    [sym_identifier] = ACTIONS(9064),
    [anon_sym_SEMI] = ACTIONS(9066),
    [aux_sym_where_condition_token1] = ACTIONS(9064),
    [anon_sym_LBRACK] = ACTIONS(9066),
    [aux_sym_basic_type_token22] = ACTIONS(9064),
    [aux_sym_basic_type_token53] = ACTIONS(9064),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9064),
    [aux_sym_modify_modification_token1] = ACTIONS(9064),
    [aux_sym_separator_action_token1] = ACTIONS(9064),
    [aux_sym_xmlport_element_token1] = ACTIONS(9064),
    [aux_sym_xmlport_element_token2] = ACTIONS(9064),
    [aux_sym_xmlport_element_token3] = ACTIONS(9064),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9064),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9064),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9064),
    [aux_sym_type_declaration_token1] = ACTIONS(9064),
    [anon_sym_POUNDif] = ACTIONS(9066),
    [anon_sym_POUNDIF] = ACTIONS(9066),
    [anon_sym_POUNDIf] = ACTIONS(9066),
    [anon_sym_POUNDelif] = ACTIONS(9066),
    [anon_sym_POUNDELIF] = ACTIONS(9066),
    [anon_sym_POUNDElif] = ACTIONS(9066),
    [anon_sym_POUNDelse] = ACTIONS(9066),
    [anon_sym_POUNDELSE] = ACTIONS(9066),
    [anon_sym_POUNDElse] = ACTIONS(9066),
    [anon_sym_POUNDelse2] = ACTIONS(9066),
    [anon_sym_POUNDELSE2] = ACTIONS(9066),
    [anon_sym_POUNDElse2] = ACTIONS(9066),
    [anon_sym_POUNDendif] = ACTIONS(9066),
    [anon_sym_POUNDENDIF] = ACTIONS(9066),
    [anon_sym_POUNDEndif] = ACTIONS(9066),
    [anon_sym_POUNDendif2] = ACTIONS(9066),
    [anon_sym_POUNDENDIF2] = ACTIONS(9066),
    [anon_sym_POUNDEndif2] = ACTIONS(9066),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9064),
    [sym_procedure_keyword] = ACTIONS(9064),
    [sym_trigger_keyword] = ACTIONS(9064),
    [sym_var_keyword] = ACTIONS(9064),
    [sym_local_keyword] = ACTIONS(9064),
    [sym_internal_keyword] = ACTIONS(9064),
    [sym_protected_keyword] = ACTIONS(9064),
    [sym_event_keyword] = ACTIONS(9064),
    [sym_fields_keyword] = ACTIONS(9064),
    [sym_keys_keyword] = ACTIONS(9064),
    [sym_key_keyword] = ACTIONS(9064),
    [sym_fieldgroups_keyword] = ACTIONS(9064),
    [sym_actions_keyword] = ACTIONS(9064),
    [sym_layout_keyword] = ACTIONS(9064),
    [sym_dataset_keyword] = ACTIONS(9064),
    [sym_elements_keyword] = ACTIONS(9064),
    [sym_labels_keyword] = ACTIONS(9064),
    [sym_rendering_keyword] = ACTIONS(9064),
    [sym_requestpage_keyword] = ACTIONS(9064),
    [sym_schema_keyword] = ACTIONS(9064),
    [sym_views_keyword] = ACTIONS(9064),
    [sym_quoted_identifier] = ACTIONS(9066),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9066),
    [sym_preproc_open] = ACTIONS(9066),
    [sym_preproc_close] = ACTIONS(9066),
    [sym_var_attribute_open] = ACTIONS(9066),
  },
  [STATE(5887)] = {
    [sym_identifier] = ACTIONS(6168),
    [anon_sym_SEMI] = ACTIONS(6170),
    [aux_sym_where_condition_token1] = ACTIONS(6168),
    [anon_sym_LBRACK] = ACTIONS(6170),
    [aux_sym_basic_type_token22] = ACTIONS(6168),
    [aux_sym_basic_type_token53] = ACTIONS(6168),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6168),
    [aux_sym_modify_modification_token1] = ACTIONS(6168),
    [aux_sym_separator_action_token1] = ACTIONS(6168),
    [aux_sym_xmlport_element_token1] = ACTIONS(6168),
    [aux_sym_xmlport_element_token2] = ACTIONS(6168),
    [aux_sym_xmlport_element_token3] = ACTIONS(6168),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6168),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6168),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6168),
    [aux_sym_type_declaration_token1] = ACTIONS(6168),
    [anon_sym_POUNDif] = ACTIONS(6170),
    [anon_sym_POUNDIF] = ACTIONS(6170),
    [anon_sym_POUNDIf] = ACTIONS(6170),
    [anon_sym_POUNDelif] = ACTIONS(6170),
    [anon_sym_POUNDELIF] = ACTIONS(6170),
    [anon_sym_POUNDElif] = ACTIONS(6170),
    [anon_sym_POUNDelse] = ACTIONS(6170),
    [anon_sym_POUNDELSE] = ACTIONS(6170),
    [anon_sym_POUNDElse] = ACTIONS(6170),
    [anon_sym_POUNDelse2] = ACTIONS(6170),
    [anon_sym_POUNDELSE2] = ACTIONS(6170),
    [anon_sym_POUNDElse2] = ACTIONS(6170),
    [anon_sym_POUNDendif] = ACTIONS(6170),
    [anon_sym_POUNDENDIF] = ACTIONS(6170),
    [anon_sym_POUNDEndif] = ACTIONS(6170),
    [anon_sym_POUNDendif2] = ACTIONS(6170),
    [anon_sym_POUNDENDIF2] = ACTIONS(6170),
    [anon_sym_POUNDEndif2] = ACTIONS(6170),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6168),
    [sym_procedure_keyword] = ACTIONS(6168),
    [sym_trigger_keyword] = ACTIONS(6168),
    [sym_var_keyword] = ACTIONS(6168),
    [sym_local_keyword] = ACTIONS(6168),
    [sym_internal_keyword] = ACTIONS(6168),
    [sym_protected_keyword] = ACTIONS(6168),
    [sym_event_keyword] = ACTIONS(6168),
    [sym_fields_keyword] = ACTIONS(6168),
    [sym_keys_keyword] = ACTIONS(6168),
    [sym_key_keyword] = ACTIONS(6168),
    [sym_fieldgroups_keyword] = ACTIONS(6168),
    [sym_actions_keyword] = ACTIONS(6168),
    [sym_layout_keyword] = ACTIONS(6168),
    [sym_dataset_keyword] = ACTIONS(6168),
    [sym_elements_keyword] = ACTIONS(6168),
    [sym_labels_keyword] = ACTIONS(6168),
    [sym_rendering_keyword] = ACTIONS(6168),
    [sym_requestpage_keyword] = ACTIONS(6168),
    [sym_schema_keyword] = ACTIONS(6168),
    [sym_views_keyword] = ACTIONS(6168),
    [sym_quoted_identifier] = ACTIONS(6170),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6170),
    [sym_preproc_open] = ACTIONS(6170),
    [sym_preproc_close] = ACTIONS(6170),
    [sym_var_attribute_open] = ACTIONS(6170),
  },
  [STATE(5888)] = {
    [sym_identifier] = ACTIONS(6148),
    [anon_sym_SEMI] = ACTIONS(6150),
    [aux_sym_where_condition_token1] = ACTIONS(6148),
    [anon_sym_LBRACK] = ACTIONS(6150),
    [aux_sym_basic_type_token22] = ACTIONS(6148),
    [aux_sym_basic_type_token53] = ACTIONS(6148),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6148),
    [aux_sym_modify_modification_token1] = ACTIONS(6148),
    [aux_sym_separator_action_token1] = ACTIONS(6148),
    [aux_sym_xmlport_element_token1] = ACTIONS(6148),
    [aux_sym_xmlport_element_token2] = ACTIONS(6148),
    [aux_sym_xmlport_element_token3] = ACTIONS(6148),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6148),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6148),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6148),
    [aux_sym_type_declaration_token1] = ACTIONS(6148),
    [anon_sym_POUNDif] = ACTIONS(6150),
    [anon_sym_POUNDIF] = ACTIONS(6150),
    [anon_sym_POUNDIf] = ACTIONS(6150),
    [anon_sym_POUNDelif] = ACTIONS(6150),
    [anon_sym_POUNDELIF] = ACTIONS(6150),
    [anon_sym_POUNDElif] = ACTIONS(6150),
    [anon_sym_POUNDelse] = ACTIONS(6150),
    [anon_sym_POUNDELSE] = ACTIONS(6150),
    [anon_sym_POUNDElse] = ACTIONS(6150),
    [anon_sym_POUNDelse2] = ACTIONS(6150),
    [anon_sym_POUNDELSE2] = ACTIONS(6150),
    [anon_sym_POUNDElse2] = ACTIONS(6150),
    [anon_sym_POUNDendif] = ACTIONS(6150),
    [anon_sym_POUNDENDIF] = ACTIONS(6150),
    [anon_sym_POUNDEndif] = ACTIONS(6150),
    [anon_sym_POUNDendif2] = ACTIONS(6150),
    [anon_sym_POUNDENDIF2] = ACTIONS(6150),
    [anon_sym_POUNDEndif2] = ACTIONS(6150),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6148),
    [sym_procedure_keyword] = ACTIONS(6148),
    [sym_trigger_keyword] = ACTIONS(6148),
    [sym_var_keyword] = ACTIONS(6148),
    [sym_local_keyword] = ACTIONS(6148),
    [sym_internal_keyword] = ACTIONS(6148),
    [sym_protected_keyword] = ACTIONS(6148),
    [sym_event_keyword] = ACTIONS(6148),
    [sym_fields_keyword] = ACTIONS(6148),
    [sym_keys_keyword] = ACTIONS(6148),
    [sym_key_keyword] = ACTIONS(6148),
    [sym_fieldgroups_keyword] = ACTIONS(6148),
    [sym_actions_keyword] = ACTIONS(6148),
    [sym_layout_keyword] = ACTIONS(6148),
    [sym_dataset_keyword] = ACTIONS(6148),
    [sym_elements_keyword] = ACTIONS(6148),
    [sym_labels_keyword] = ACTIONS(6148),
    [sym_rendering_keyword] = ACTIONS(6148),
    [sym_requestpage_keyword] = ACTIONS(6148),
    [sym_schema_keyword] = ACTIONS(6148),
    [sym_views_keyword] = ACTIONS(6148),
    [sym_quoted_identifier] = ACTIONS(6150),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6150),
    [sym_preproc_open] = ACTIONS(6150),
    [sym_preproc_close] = ACTIONS(6150),
    [sym_var_attribute_open] = ACTIONS(6150),
  },
  [STATE(5889)] = {
    [sym_identifier] = ACTIONS(9030),
    [anon_sym_SEMI] = ACTIONS(9032),
    [aux_sym_where_condition_token1] = ACTIONS(9030),
    [anon_sym_LBRACK] = ACTIONS(9032),
    [aux_sym_basic_type_token22] = ACTIONS(9030),
    [aux_sym_basic_type_token53] = ACTIONS(9030),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9030),
    [aux_sym_modify_modification_token1] = ACTIONS(9030),
    [aux_sym_separator_action_token1] = ACTIONS(9030),
    [aux_sym_xmlport_element_token1] = ACTIONS(9030),
    [aux_sym_xmlport_element_token2] = ACTIONS(9030),
    [aux_sym_xmlport_element_token3] = ACTIONS(9030),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9030),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9030),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9030),
    [aux_sym_type_declaration_token1] = ACTIONS(9030),
    [anon_sym_POUNDif] = ACTIONS(9032),
    [anon_sym_POUNDIF] = ACTIONS(9032),
    [anon_sym_POUNDIf] = ACTIONS(9032),
    [anon_sym_POUNDelif] = ACTIONS(9032),
    [anon_sym_POUNDELIF] = ACTIONS(9032),
    [anon_sym_POUNDElif] = ACTIONS(9032),
    [anon_sym_POUNDelse] = ACTIONS(9032),
    [anon_sym_POUNDELSE] = ACTIONS(9032),
    [anon_sym_POUNDElse] = ACTIONS(9032),
    [anon_sym_POUNDelse2] = ACTIONS(9032),
    [anon_sym_POUNDELSE2] = ACTIONS(9032),
    [anon_sym_POUNDElse2] = ACTIONS(9032),
    [anon_sym_POUNDendif] = ACTIONS(9032),
    [anon_sym_POUNDENDIF] = ACTIONS(9032),
    [anon_sym_POUNDEndif] = ACTIONS(9032),
    [anon_sym_POUNDendif2] = ACTIONS(9032),
    [anon_sym_POUNDENDIF2] = ACTIONS(9032),
    [anon_sym_POUNDEndif2] = ACTIONS(9032),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9030),
    [sym_procedure_keyword] = ACTIONS(9030),
    [sym_trigger_keyword] = ACTIONS(9030),
    [sym_var_keyword] = ACTIONS(9030),
    [sym_local_keyword] = ACTIONS(9030),
    [sym_internal_keyword] = ACTIONS(9030),
    [sym_protected_keyword] = ACTIONS(9030),
    [sym_event_keyword] = ACTIONS(9030),
    [sym_fields_keyword] = ACTIONS(9030),
    [sym_keys_keyword] = ACTIONS(9030),
    [sym_key_keyword] = ACTIONS(9030),
    [sym_fieldgroups_keyword] = ACTIONS(9030),
    [sym_actions_keyword] = ACTIONS(9030),
    [sym_layout_keyword] = ACTIONS(9030),
    [sym_dataset_keyword] = ACTIONS(9030),
    [sym_elements_keyword] = ACTIONS(9030),
    [sym_labels_keyword] = ACTIONS(9030),
    [sym_rendering_keyword] = ACTIONS(9030),
    [sym_requestpage_keyword] = ACTIONS(9030),
    [sym_schema_keyword] = ACTIONS(9030),
    [sym_views_keyword] = ACTIONS(9030),
    [sym_quoted_identifier] = ACTIONS(9032),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9032),
    [sym_preproc_open] = ACTIONS(9032),
    [sym_preproc_close] = ACTIONS(9032),
    [sym_var_attribute_open] = ACTIONS(9032),
  },
  [STATE(5890)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_xmlport_element_token1] = ACTIONS(9068),
    [aux_sym_xmlport_element_token2] = ACTIONS(9068),
    [aux_sym_xmlport_element_token3] = ACTIONS(9068),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9068),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(5891)] = {
    [sym_identifier] = ACTIONS(6156),
    [anon_sym_SEMI] = ACTIONS(6158),
    [aux_sym_where_condition_token1] = ACTIONS(6156),
    [anon_sym_LBRACK] = ACTIONS(6158),
    [aux_sym_basic_type_token22] = ACTIONS(6156),
    [aux_sym_basic_type_token53] = ACTIONS(6156),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6156),
    [aux_sym_modify_modification_token1] = ACTIONS(6156),
    [aux_sym_separator_action_token1] = ACTIONS(6156),
    [aux_sym_xmlport_element_token1] = ACTIONS(6156),
    [aux_sym_xmlport_element_token2] = ACTIONS(6156),
    [aux_sym_xmlport_element_token3] = ACTIONS(6156),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6156),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6156),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6156),
    [aux_sym_type_declaration_token1] = ACTIONS(6156),
    [anon_sym_POUNDif] = ACTIONS(6158),
    [anon_sym_POUNDIF] = ACTIONS(6158),
    [anon_sym_POUNDIf] = ACTIONS(6158),
    [anon_sym_POUNDelif] = ACTIONS(6158),
    [anon_sym_POUNDELIF] = ACTIONS(6158),
    [anon_sym_POUNDElif] = ACTIONS(6158),
    [anon_sym_POUNDelse] = ACTIONS(6158),
    [anon_sym_POUNDELSE] = ACTIONS(6158),
    [anon_sym_POUNDElse] = ACTIONS(6158),
    [anon_sym_POUNDelse2] = ACTIONS(6158),
    [anon_sym_POUNDELSE2] = ACTIONS(6158),
    [anon_sym_POUNDElse2] = ACTIONS(6158),
    [anon_sym_POUNDendif] = ACTIONS(6158),
    [anon_sym_POUNDENDIF] = ACTIONS(6158),
    [anon_sym_POUNDEndif] = ACTIONS(6158),
    [anon_sym_POUNDendif2] = ACTIONS(6158),
    [anon_sym_POUNDENDIF2] = ACTIONS(6158),
    [anon_sym_POUNDEndif2] = ACTIONS(6158),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6156),
    [sym_procedure_keyword] = ACTIONS(6156),
    [sym_trigger_keyword] = ACTIONS(6156),
    [sym_var_keyword] = ACTIONS(6156),
    [sym_local_keyword] = ACTIONS(6156),
    [sym_internal_keyword] = ACTIONS(6156),
    [sym_protected_keyword] = ACTIONS(6156),
    [sym_event_keyword] = ACTIONS(6156),
    [sym_fields_keyword] = ACTIONS(6156),
    [sym_keys_keyword] = ACTIONS(6156),
    [sym_key_keyword] = ACTIONS(6156),
    [sym_fieldgroups_keyword] = ACTIONS(6156),
    [sym_actions_keyword] = ACTIONS(6156),
    [sym_layout_keyword] = ACTIONS(6156),
    [sym_dataset_keyword] = ACTIONS(6156),
    [sym_elements_keyword] = ACTIONS(6156),
    [sym_labels_keyword] = ACTIONS(6156),
    [sym_rendering_keyword] = ACTIONS(6156),
    [sym_requestpage_keyword] = ACTIONS(6156),
    [sym_schema_keyword] = ACTIONS(6156),
    [sym_views_keyword] = ACTIONS(6156),
    [sym_quoted_identifier] = ACTIONS(6158),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6158),
    [sym_preproc_open] = ACTIONS(6158),
    [sym_preproc_close] = ACTIONS(6158),
    [sym_var_attribute_open] = ACTIONS(6158),
  },
  [STATE(5892)] = {
    [anon_sym_SEMI] = ACTIONS(7785),
    [anon_sym_RBRACE] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token1] = ACTIONS(7785),
    [aux_sym_tabledata_permission_token2] = ACTIONS(7787),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(7785),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(7785),
    [anon_sym_LBRACK] = ACTIONS(7785),
    [aux_sym_basic_type_token22] = ACTIONS(7787),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(7785),
    [aux_sym_addafter_modification_token1] = ACTIONS(7785),
    [aux_sym_addbefore_modification_token1] = ACTIONS(7785),
    [aux_sym_modify_modification_token1] = ACTIONS(7785),
    [aux_sym_separator_action_token1] = ACTIONS(7785),
    [aux_sym_actionref_declaration_token1] = ACTIONS(7785),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(7785),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(7785),
    [aux_sym_customaction_declaration_token1] = ACTIONS(7785),
    [aux_sym_assembly_declaration_token1] = ACTIONS(7785),
    [anon_sym_POUNDif] = ACTIONS(7785),
    [anon_sym_POUNDIF] = ACTIONS(7785),
    [anon_sym_POUNDIf] = ACTIONS(7785),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(7787),
    [sym_page_keyword] = ACTIONS(7785),
    [anon_sym_codeunit] = ACTIONS(7785),
    [anon_sym_CODEUNIT] = ACTIONS(7785),
    [anon_sym_Codeunit] = ACTIONS(7785),
    [anon_sym_CodeUnit] = ACTIONS(7785),
    [anon_sym_COdeunit] = ACTIONS(7785),
    [anon_sym_codeUnit] = ACTIONS(7785),
    [sym_report_keyword] = ACTIONS(7785),
    [sym_query_keyword] = ACTIONS(7785),
    [anon_sym_xmlport] = ACTIONS(7785),
    [anon_sym_XMLPORT] = ACTIONS(7785),
    [anon_sym_Xmlport] = ACTIONS(7785),
    [anon_sym_XMLport] = ACTIONS(7785),
    [anon_sym_XMLPort] = ACTIONS(7785),
    [anon_sym_XmlPort] = ACTIONS(7785),
    [sym_procedure_keyword] = ACTIONS(7785),
    [sym_trigger_keyword] = ACTIONS(7785),
    [sym_var_keyword] = ACTIONS(7785),
    [sym_local_keyword] = ACTIONS(7785),
    [sym_internal_keyword] = ACTIONS(7785),
    [sym_protected_keyword] = ACTIONS(7785),
    [sym_event_keyword] = ACTIONS(7785),
    [sym_fields_keyword] = ACTIONS(7785),
    [sym_keys_keyword] = ACTIONS(7785),
    [sym_fieldgroups_keyword] = ACTIONS(7785),
    [sym_actions_keyword] = ACTIONS(7785),
    [sym_layout_keyword] = ACTIONS(7785),
    [sym_area_keyword] = ACTIONS(7785),
    [sym_group_keyword] = ACTIONS(7785),
    [sym_dataset_keyword] = ACTIONS(7785),
    [sym_elements_keyword] = ACTIONS(7785),
    [sym_labels_keyword] = ACTIONS(7785),
    [sym_rendering_keyword] = ACTIONS(7785),
    [sym_requestpage_keyword] = ACTIONS(7785),
    [sym_schema_keyword] = ACTIONS(7785),
    [sym_views_keyword] = ACTIONS(7785),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(7785),
    [sym_preproc_open] = ACTIONS(7785),
  },
  [STATE(5893)] = {
    [anon_sym_SEMI] = ACTIONS(8434),
    [anon_sym_RBRACE] = ACTIONS(8434),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8434),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8436),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8434),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8434),
    [anon_sym_LBRACK] = ACTIONS(8434),
    [aux_sym_basic_type_token22] = ACTIONS(8436),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8434),
    [aux_sym_addafter_modification_token1] = ACTIONS(8434),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8434),
    [aux_sym_modify_modification_token1] = ACTIONS(8434),
    [aux_sym_separator_action_token1] = ACTIONS(8434),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8434),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8434),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8434),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8434),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8434),
    [anon_sym_POUNDif] = ACTIONS(8434),
    [anon_sym_POUNDIF] = ACTIONS(8434),
    [anon_sym_POUNDIf] = ACTIONS(8434),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8436),
    [sym_page_keyword] = ACTIONS(8434),
    [anon_sym_codeunit] = ACTIONS(8434),
    [anon_sym_CODEUNIT] = ACTIONS(8434),
    [anon_sym_Codeunit] = ACTIONS(8434),
    [anon_sym_CodeUnit] = ACTIONS(8434),
    [anon_sym_COdeunit] = ACTIONS(8434),
    [anon_sym_codeUnit] = ACTIONS(8434),
    [sym_report_keyword] = ACTIONS(8434),
    [sym_query_keyword] = ACTIONS(8434),
    [anon_sym_xmlport] = ACTIONS(8434),
    [anon_sym_XMLPORT] = ACTIONS(8434),
    [anon_sym_Xmlport] = ACTIONS(8434),
    [anon_sym_XMLport] = ACTIONS(8434),
    [anon_sym_XMLPort] = ACTIONS(8434),
    [anon_sym_XmlPort] = ACTIONS(8434),
    [sym_procedure_keyword] = ACTIONS(8434),
    [sym_trigger_keyword] = ACTIONS(8434),
    [sym_var_keyword] = ACTIONS(8434),
    [sym_local_keyword] = ACTIONS(8434),
    [sym_internal_keyword] = ACTIONS(8434),
    [sym_protected_keyword] = ACTIONS(8434),
    [sym_event_keyword] = ACTIONS(8434),
    [sym_fields_keyword] = ACTIONS(8434),
    [sym_keys_keyword] = ACTIONS(8434),
    [sym_fieldgroups_keyword] = ACTIONS(8434),
    [sym_actions_keyword] = ACTIONS(8434),
    [sym_layout_keyword] = ACTIONS(8434),
    [sym_area_keyword] = ACTIONS(8434),
    [sym_group_keyword] = ACTIONS(8434),
    [sym_dataset_keyword] = ACTIONS(8434),
    [sym_elements_keyword] = ACTIONS(8434),
    [sym_labels_keyword] = ACTIONS(8434),
    [sym_rendering_keyword] = ACTIONS(8434),
    [sym_requestpage_keyword] = ACTIONS(8434),
    [sym_schema_keyword] = ACTIONS(8434),
    [sym_views_keyword] = ACTIONS(8434),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8434),
    [sym_preproc_open] = ACTIONS(8434),
  },
  [STATE(5894)] = {
    [sym_identifier] = ACTIONS(6160),
    [anon_sym_SEMI] = ACTIONS(6162),
    [aux_sym_where_condition_token1] = ACTIONS(6160),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [aux_sym_basic_type_token22] = ACTIONS(6160),
    [aux_sym_basic_type_token53] = ACTIONS(6160),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6160),
    [aux_sym_modify_modification_token1] = ACTIONS(6160),
    [aux_sym_separator_action_token1] = ACTIONS(6160),
    [aux_sym_xmlport_element_token1] = ACTIONS(6160),
    [aux_sym_xmlport_element_token2] = ACTIONS(6160),
    [aux_sym_xmlport_element_token3] = ACTIONS(6160),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6160),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6160),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6160),
    [aux_sym_type_declaration_token1] = ACTIONS(6160),
    [anon_sym_POUNDif] = ACTIONS(6162),
    [anon_sym_POUNDIF] = ACTIONS(6162),
    [anon_sym_POUNDIf] = ACTIONS(6162),
    [anon_sym_POUNDelif] = ACTIONS(6162),
    [anon_sym_POUNDELIF] = ACTIONS(6162),
    [anon_sym_POUNDElif] = ACTIONS(6162),
    [anon_sym_POUNDelse] = ACTIONS(6162),
    [anon_sym_POUNDELSE] = ACTIONS(6162),
    [anon_sym_POUNDElse] = ACTIONS(6162),
    [anon_sym_POUNDelse2] = ACTIONS(6162),
    [anon_sym_POUNDELSE2] = ACTIONS(6162),
    [anon_sym_POUNDElse2] = ACTIONS(6162),
    [anon_sym_POUNDendif] = ACTIONS(6162),
    [anon_sym_POUNDENDIF] = ACTIONS(6162),
    [anon_sym_POUNDEndif] = ACTIONS(6162),
    [anon_sym_POUNDendif2] = ACTIONS(6162),
    [anon_sym_POUNDENDIF2] = ACTIONS(6162),
    [anon_sym_POUNDEndif2] = ACTIONS(6162),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6160),
    [sym_procedure_keyword] = ACTIONS(6160),
    [sym_trigger_keyword] = ACTIONS(6160),
    [sym_var_keyword] = ACTIONS(6160),
    [sym_local_keyword] = ACTIONS(6160),
    [sym_internal_keyword] = ACTIONS(6160),
    [sym_protected_keyword] = ACTIONS(6160),
    [sym_event_keyword] = ACTIONS(6160),
    [sym_fields_keyword] = ACTIONS(6160),
    [sym_keys_keyword] = ACTIONS(6160),
    [sym_key_keyword] = ACTIONS(6160),
    [sym_fieldgroups_keyword] = ACTIONS(6160),
    [sym_actions_keyword] = ACTIONS(6160),
    [sym_layout_keyword] = ACTIONS(6160),
    [sym_dataset_keyword] = ACTIONS(6160),
    [sym_elements_keyword] = ACTIONS(6160),
    [sym_labels_keyword] = ACTIONS(6160),
    [sym_rendering_keyword] = ACTIONS(6160),
    [sym_requestpage_keyword] = ACTIONS(6160),
    [sym_schema_keyword] = ACTIONS(6160),
    [sym_views_keyword] = ACTIONS(6160),
    [sym_quoted_identifier] = ACTIONS(6162),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6162),
    [sym_preproc_open] = ACTIONS(6162),
    [sym_preproc_close] = ACTIONS(6162),
    [sym_var_attribute_open] = ACTIONS(6162),
  },
  [STATE(5895)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(14481),
    [aux_sym_where_condition_token1] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token53] = ACTIONS(6118),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6118),
    [aux_sym_modify_modification_token1] = ACTIONS(6118),
    [aux_sym_separator_action_token1] = ACTIONS(6118),
    [aux_sym_xmlport_element_token1] = ACTIONS(6118),
    [aux_sym_xmlport_element_token2] = ACTIONS(6118),
    [aux_sym_xmlport_element_token3] = ACTIONS(6118),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6118),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6118),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6118),
    [aux_sym_type_declaration_token1] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_POUNDelif] = ACTIONS(6122),
    [anon_sym_POUNDELIF] = ACTIONS(6122),
    [anon_sym_POUNDElif] = ACTIONS(6122),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [anon_sym_POUNDendif] = ACTIONS(6122),
    [anon_sym_POUNDENDIF] = ACTIONS(6122),
    [anon_sym_POUNDEndif] = ACTIONS(6122),
    [anon_sym_POUNDendif2] = ACTIONS(6122),
    [anon_sym_POUNDENDIF2] = ACTIONS(6122),
    [anon_sym_POUNDEndif2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6118),
    [sym_procedure_keyword] = ACTIONS(6118),
    [sym_trigger_keyword] = ACTIONS(6118),
    [sym_var_keyword] = ACTIONS(6118),
    [sym_local_keyword] = ACTIONS(6118),
    [sym_internal_keyword] = ACTIONS(6118),
    [sym_protected_keyword] = ACTIONS(6118),
    [sym_event_keyword] = ACTIONS(6118),
    [sym_fields_keyword] = ACTIONS(6118),
    [sym_keys_keyword] = ACTIONS(6118),
    [sym_key_keyword] = ACTIONS(6118),
    [sym_fieldgroups_keyword] = ACTIONS(6118),
    [sym_actions_keyword] = ACTIONS(6118),
    [sym_layout_keyword] = ACTIONS(6118),
    [sym_dataset_keyword] = ACTIONS(6118),
    [sym_elements_keyword] = ACTIONS(6118),
    [sym_labels_keyword] = ACTIONS(6118),
    [sym_rendering_keyword] = ACTIONS(6118),
    [sym_requestpage_keyword] = ACTIONS(6118),
    [sym_schema_keyword] = ACTIONS(6118),
    [sym_views_keyword] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_preproc_close] = ACTIONS(6122),
    [sym_var_attribute_open] = ACTIONS(6122),
  },
  [STATE(5896)] = {
    [sym_identifier] = ACTIONS(9006),
    [anon_sym_SEMI] = ACTIONS(9008),
    [aux_sym_where_condition_token1] = ACTIONS(9006),
    [anon_sym_LBRACK] = ACTIONS(9008),
    [aux_sym_basic_type_token22] = ACTIONS(9006),
    [aux_sym_basic_type_token53] = ACTIONS(9006),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9006),
    [aux_sym_modify_modification_token1] = ACTIONS(9006),
    [aux_sym_separator_action_token1] = ACTIONS(9006),
    [aux_sym_xmlport_element_token1] = ACTIONS(9006),
    [aux_sym_xmlport_element_token2] = ACTIONS(9006),
    [aux_sym_xmlport_element_token3] = ACTIONS(9006),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9006),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9006),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9006),
    [aux_sym_type_declaration_token1] = ACTIONS(9006),
    [anon_sym_POUNDif] = ACTIONS(9008),
    [anon_sym_POUNDIF] = ACTIONS(9008),
    [anon_sym_POUNDIf] = ACTIONS(9008),
    [anon_sym_POUNDelif] = ACTIONS(9008),
    [anon_sym_POUNDELIF] = ACTIONS(9008),
    [anon_sym_POUNDElif] = ACTIONS(9008),
    [anon_sym_POUNDelse] = ACTIONS(9008),
    [anon_sym_POUNDELSE] = ACTIONS(9008),
    [anon_sym_POUNDElse] = ACTIONS(9008),
    [anon_sym_POUNDelse2] = ACTIONS(9008),
    [anon_sym_POUNDELSE2] = ACTIONS(9008),
    [anon_sym_POUNDElse2] = ACTIONS(9008),
    [anon_sym_POUNDendif] = ACTIONS(9008),
    [anon_sym_POUNDENDIF] = ACTIONS(9008),
    [anon_sym_POUNDEndif] = ACTIONS(9008),
    [anon_sym_POUNDendif2] = ACTIONS(9008),
    [anon_sym_POUNDENDIF2] = ACTIONS(9008),
    [anon_sym_POUNDEndif2] = ACTIONS(9008),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9006),
    [sym_procedure_keyword] = ACTIONS(9006),
    [sym_trigger_keyword] = ACTIONS(9006),
    [sym_var_keyword] = ACTIONS(9006),
    [sym_local_keyword] = ACTIONS(9006),
    [sym_internal_keyword] = ACTIONS(9006),
    [sym_protected_keyword] = ACTIONS(9006),
    [sym_event_keyword] = ACTIONS(9006),
    [sym_fields_keyword] = ACTIONS(9006),
    [sym_keys_keyword] = ACTIONS(9006),
    [sym_key_keyword] = ACTIONS(9006),
    [sym_fieldgroups_keyword] = ACTIONS(9006),
    [sym_actions_keyword] = ACTIONS(9006),
    [sym_layout_keyword] = ACTIONS(9006),
    [sym_dataset_keyword] = ACTIONS(9006),
    [sym_elements_keyword] = ACTIONS(9006),
    [sym_labels_keyword] = ACTIONS(9006),
    [sym_rendering_keyword] = ACTIONS(9006),
    [sym_requestpage_keyword] = ACTIONS(9006),
    [sym_schema_keyword] = ACTIONS(9006),
    [sym_views_keyword] = ACTIONS(9006),
    [sym_quoted_identifier] = ACTIONS(9008),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9008),
    [sym_preproc_open] = ACTIONS(9008),
    [sym_preproc_close] = ACTIONS(9008),
    [sym_var_attribute_open] = ACTIONS(9008),
  },
  [STATE(5897)] = {
    [sym_identifier] = ACTIONS(6118),
    [anon_sym_SEMI] = ACTIONS(6122),
    [aux_sym_where_condition_token1] = ACTIONS(6118),
    [anon_sym_LBRACK] = ACTIONS(6122),
    [aux_sym_basic_type_token22] = ACTIONS(6118),
    [aux_sym_basic_type_token53] = ACTIONS(6118),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6118),
    [aux_sym_modify_modification_token1] = ACTIONS(6118),
    [aux_sym_separator_action_token1] = ACTIONS(6118),
    [aux_sym_xmlport_element_token1] = ACTIONS(6118),
    [aux_sym_xmlport_element_token2] = ACTIONS(6118),
    [aux_sym_xmlport_element_token3] = ACTIONS(6118),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6118),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6118),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6118),
    [aux_sym_type_declaration_token1] = ACTIONS(6118),
    [anon_sym_POUNDif] = ACTIONS(6122),
    [anon_sym_POUNDIF] = ACTIONS(6122),
    [anon_sym_POUNDIf] = ACTIONS(6122),
    [anon_sym_POUNDelif] = ACTIONS(6122),
    [anon_sym_POUNDELIF] = ACTIONS(6122),
    [anon_sym_POUNDElif] = ACTIONS(6122),
    [anon_sym_POUNDelse] = ACTIONS(6122),
    [anon_sym_POUNDELSE] = ACTIONS(6122),
    [anon_sym_POUNDElse] = ACTIONS(6122),
    [anon_sym_POUNDelse2] = ACTIONS(6122),
    [anon_sym_POUNDELSE2] = ACTIONS(6122),
    [anon_sym_POUNDElse2] = ACTIONS(6122),
    [anon_sym_POUNDendif] = ACTIONS(6122),
    [anon_sym_POUNDENDIF] = ACTIONS(6122),
    [anon_sym_POUNDEndif] = ACTIONS(6122),
    [anon_sym_POUNDendif2] = ACTIONS(6122),
    [anon_sym_POUNDENDIF2] = ACTIONS(6122),
    [anon_sym_POUNDEndif2] = ACTIONS(6122),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6118),
    [sym_procedure_keyword] = ACTIONS(6118),
    [sym_trigger_keyword] = ACTIONS(6118),
    [sym_var_keyword] = ACTIONS(6118),
    [sym_local_keyword] = ACTIONS(6118),
    [sym_internal_keyword] = ACTIONS(6118),
    [sym_protected_keyword] = ACTIONS(6118),
    [sym_event_keyword] = ACTIONS(6118),
    [sym_fields_keyword] = ACTIONS(6118),
    [sym_keys_keyword] = ACTIONS(6118),
    [sym_key_keyword] = ACTIONS(6118),
    [sym_fieldgroups_keyword] = ACTIONS(6118),
    [sym_actions_keyword] = ACTIONS(6118),
    [sym_layout_keyword] = ACTIONS(6118),
    [sym_dataset_keyword] = ACTIONS(6118),
    [sym_elements_keyword] = ACTIONS(6118),
    [sym_labels_keyword] = ACTIONS(6118),
    [sym_rendering_keyword] = ACTIONS(6118),
    [sym_requestpage_keyword] = ACTIONS(6118),
    [sym_schema_keyword] = ACTIONS(6118),
    [sym_views_keyword] = ACTIONS(6118),
    [sym_quoted_identifier] = ACTIONS(6122),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6122),
    [sym_preproc_open] = ACTIONS(6122),
    [sym_preproc_close] = ACTIONS(6122),
    [sym_var_attribute_open] = ACTIONS(6122),
  },
  [STATE(5898)] = {
    [sym_identifier] = ACTIONS(6124),
    [anon_sym_SEMI] = ACTIONS(6126),
    [aux_sym_where_condition_token1] = ACTIONS(6124),
    [anon_sym_LBRACK] = ACTIONS(6126),
    [aux_sym_basic_type_token22] = ACTIONS(6124),
    [aux_sym_basic_type_token53] = ACTIONS(6124),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6124),
    [aux_sym_modify_modification_token1] = ACTIONS(6124),
    [aux_sym_separator_action_token1] = ACTIONS(6124),
    [aux_sym_xmlport_element_token1] = ACTIONS(6124),
    [aux_sym_xmlport_element_token2] = ACTIONS(6124),
    [aux_sym_xmlport_element_token3] = ACTIONS(6124),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6124),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6124),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6124),
    [aux_sym_type_declaration_token1] = ACTIONS(6124),
    [anon_sym_POUNDif] = ACTIONS(6126),
    [anon_sym_POUNDIF] = ACTIONS(6126),
    [anon_sym_POUNDIf] = ACTIONS(6126),
    [anon_sym_POUNDelif] = ACTIONS(6126),
    [anon_sym_POUNDELIF] = ACTIONS(6126),
    [anon_sym_POUNDElif] = ACTIONS(6126),
    [anon_sym_POUNDelse] = ACTIONS(6126),
    [anon_sym_POUNDELSE] = ACTIONS(6126),
    [anon_sym_POUNDElse] = ACTIONS(6126),
    [anon_sym_POUNDelse2] = ACTIONS(6126),
    [anon_sym_POUNDELSE2] = ACTIONS(6126),
    [anon_sym_POUNDElse2] = ACTIONS(6126),
    [anon_sym_POUNDendif] = ACTIONS(6126),
    [anon_sym_POUNDENDIF] = ACTIONS(6126),
    [anon_sym_POUNDEndif] = ACTIONS(6126),
    [anon_sym_POUNDendif2] = ACTIONS(6126),
    [anon_sym_POUNDENDIF2] = ACTIONS(6126),
    [anon_sym_POUNDEndif2] = ACTIONS(6126),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6124),
    [sym_procedure_keyword] = ACTIONS(6124),
    [sym_trigger_keyword] = ACTIONS(6124),
    [sym_var_keyword] = ACTIONS(6124),
    [sym_local_keyword] = ACTIONS(6124),
    [sym_internal_keyword] = ACTIONS(6124),
    [sym_protected_keyword] = ACTIONS(6124),
    [sym_event_keyword] = ACTIONS(6124),
    [sym_fields_keyword] = ACTIONS(6124),
    [sym_keys_keyword] = ACTIONS(6124),
    [sym_key_keyword] = ACTIONS(6124),
    [sym_fieldgroups_keyword] = ACTIONS(6124),
    [sym_actions_keyword] = ACTIONS(6124),
    [sym_layout_keyword] = ACTIONS(6124),
    [sym_dataset_keyword] = ACTIONS(6124),
    [sym_elements_keyword] = ACTIONS(6124),
    [sym_labels_keyword] = ACTIONS(6124),
    [sym_rendering_keyword] = ACTIONS(6124),
    [sym_requestpage_keyword] = ACTIONS(6124),
    [sym_schema_keyword] = ACTIONS(6124),
    [sym_views_keyword] = ACTIONS(6124),
    [sym_quoted_identifier] = ACTIONS(6126),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6126),
    [sym_preproc_open] = ACTIONS(6126),
    [sym_preproc_close] = ACTIONS(6126),
    [sym_var_attribute_open] = ACTIONS(6126),
  },
  [STATE(5899)] = {
    [anon_sym_SEMI] = ACTIONS(8430),
    [anon_sym_RBRACE] = ACTIONS(8430),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8430),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8432),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8430),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8430),
    [anon_sym_LBRACK] = ACTIONS(8430),
    [aux_sym_basic_type_token22] = ACTIONS(8432),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8430),
    [aux_sym_addafter_modification_token1] = ACTIONS(8430),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8430),
    [aux_sym_modify_modification_token1] = ACTIONS(8430),
    [aux_sym_separator_action_token1] = ACTIONS(8430),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8430),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8430),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8430),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8430),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8430),
    [anon_sym_POUNDif] = ACTIONS(8430),
    [anon_sym_POUNDIF] = ACTIONS(8430),
    [anon_sym_POUNDIf] = ACTIONS(8430),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8432),
    [sym_page_keyword] = ACTIONS(8430),
    [anon_sym_codeunit] = ACTIONS(8430),
    [anon_sym_CODEUNIT] = ACTIONS(8430),
    [anon_sym_Codeunit] = ACTIONS(8430),
    [anon_sym_CodeUnit] = ACTIONS(8430),
    [anon_sym_COdeunit] = ACTIONS(8430),
    [anon_sym_codeUnit] = ACTIONS(8430),
    [sym_report_keyword] = ACTIONS(8430),
    [sym_query_keyword] = ACTIONS(8430),
    [anon_sym_xmlport] = ACTIONS(8430),
    [anon_sym_XMLPORT] = ACTIONS(8430),
    [anon_sym_Xmlport] = ACTIONS(8430),
    [anon_sym_XMLport] = ACTIONS(8430),
    [anon_sym_XMLPort] = ACTIONS(8430),
    [anon_sym_XmlPort] = ACTIONS(8430),
    [sym_procedure_keyword] = ACTIONS(8430),
    [sym_trigger_keyword] = ACTIONS(8430),
    [sym_var_keyword] = ACTIONS(8430),
    [sym_local_keyword] = ACTIONS(8430),
    [sym_internal_keyword] = ACTIONS(8430),
    [sym_protected_keyword] = ACTIONS(8430),
    [sym_event_keyword] = ACTIONS(8430),
    [sym_fields_keyword] = ACTIONS(8430),
    [sym_keys_keyword] = ACTIONS(8430),
    [sym_fieldgroups_keyword] = ACTIONS(8430),
    [sym_actions_keyword] = ACTIONS(8430),
    [sym_layout_keyword] = ACTIONS(8430),
    [sym_area_keyword] = ACTIONS(8430),
    [sym_group_keyword] = ACTIONS(8430),
    [sym_dataset_keyword] = ACTIONS(8430),
    [sym_elements_keyword] = ACTIONS(8430),
    [sym_labels_keyword] = ACTIONS(8430),
    [sym_rendering_keyword] = ACTIONS(8430),
    [sym_requestpage_keyword] = ACTIONS(8430),
    [sym_schema_keyword] = ACTIONS(8430),
    [sym_views_keyword] = ACTIONS(8430),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8430),
    [sym_preproc_open] = ACTIONS(8430),
  },
  [STATE(5900)] = {
    [sym_identifier] = ACTIONS(8905),
    [anon_sym_SEMI] = ACTIONS(8907),
    [aux_sym_where_condition_token1] = ACTIONS(8905),
    [anon_sym_LBRACK] = ACTIONS(8907),
    [aux_sym_basic_type_token22] = ACTIONS(8905),
    [aux_sym_basic_type_token53] = ACTIONS(8905),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8905),
    [aux_sym_modify_modification_token1] = ACTIONS(8905),
    [aux_sym_separator_action_token1] = ACTIONS(8905),
    [aux_sym_xmlport_element_token1] = ACTIONS(8905),
    [aux_sym_xmlport_element_token2] = ACTIONS(8905),
    [aux_sym_xmlport_element_token3] = ACTIONS(8905),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8905),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8905),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8905),
    [aux_sym_type_declaration_token1] = ACTIONS(8905),
    [anon_sym_POUNDif] = ACTIONS(8907),
    [anon_sym_POUNDIF] = ACTIONS(8907),
    [anon_sym_POUNDIf] = ACTIONS(8907),
    [anon_sym_POUNDelif] = ACTIONS(8907),
    [anon_sym_POUNDELIF] = ACTIONS(8907),
    [anon_sym_POUNDElif] = ACTIONS(8907),
    [anon_sym_POUNDelse] = ACTIONS(8907),
    [anon_sym_POUNDELSE] = ACTIONS(8907),
    [anon_sym_POUNDElse] = ACTIONS(8907),
    [anon_sym_POUNDelse2] = ACTIONS(8907),
    [anon_sym_POUNDELSE2] = ACTIONS(8907),
    [anon_sym_POUNDElse2] = ACTIONS(8907),
    [anon_sym_POUNDendif] = ACTIONS(8907),
    [anon_sym_POUNDENDIF] = ACTIONS(8907),
    [anon_sym_POUNDEndif] = ACTIONS(8907),
    [anon_sym_POUNDendif2] = ACTIONS(8907),
    [anon_sym_POUNDENDIF2] = ACTIONS(8907),
    [anon_sym_POUNDEndif2] = ACTIONS(8907),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8905),
    [sym_procedure_keyword] = ACTIONS(8905),
    [sym_trigger_keyword] = ACTIONS(8905),
    [sym_var_keyword] = ACTIONS(8905),
    [sym_local_keyword] = ACTIONS(8905),
    [sym_internal_keyword] = ACTIONS(8905),
    [sym_protected_keyword] = ACTIONS(8905),
    [sym_event_keyword] = ACTIONS(8905),
    [sym_fields_keyword] = ACTIONS(8905),
    [sym_keys_keyword] = ACTIONS(8905),
    [sym_key_keyword] = ACTIONS(8905),
    [sym_fieldgroups_keyword] = ACTIONS(8905),
    [sym_actions_keyword] = ACTIONS(8905),
    [sym_layout_keyword] = ACTIONS(8905),
    [sym_dataset_keyword] = ACTIONS(8905),
    [sym_elements_keyword] = ACTIONS(8905),
    [sym_labels_keyword] = ACTIONS(8905),
    [sym_rendering_keyword] = ACTIONS(8905),
    [sym_requestpage_keyword] = ACTIONS(8905),
    [sym_schema_keyword] = ACTIONS(8905),
    [sym_views_keyword] = ACTIONS(8905),
    [sym_quoted_identifier] = ACTIONS(8907),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8907),
    [sym_preproc_open] = ACTIONS(8907),
    [sym_preproc_close] = ACTIONS(8907),
    [sym_var_attribute_open] = ACTIONS(8907),
  },
  [STATE(5901)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(14483),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_xmlport_element_token1] = ACTIONS(5961),
    [aux_sym_xmlport_element_token2] = ACTIONS(5961),
    [aux_sym_xmlport_element_token3] = ACTIONS(5961),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5961),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(5902)] = {
    [sym_identifier] = ACTIONS(6184),
    [anon_sym_SEMI] = ACTIONS(6186),
    [aux_sym_where_condition_token1] = ACTIONS(6184),
    [anon_sym_LBRACK] = ACTIONS(6186),
    [aux_sym_basic_type_token22] = ACTIONS(6184),
    [aux_sym_basic_type_token53] = ACTIONS(6184),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6184),
    [aux_sym_modify_modification_token1] = ACTIONS(6184),
    [aux_sym_separator_action_token1] = ACTIONS(6184),
    [aux_sym_xmlport_element_token1] = ACTIONS(6184),
    [aux_sym_xmlport_element_token2] = ACTIONS(6184),
    [aux_sym_xmlport_element_token3] = ACTIONS(6184),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6184),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6184),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6184),
    [aux_sym_type_declaration_token1] = ACTIONS(6184),
    [anon_sym_POUNDif] = ACTIONS(6186),
    [anon_sym_POUNDIF] = ACTIONS(6186),
    [anon_sym_POUNDIf] = ACTIONS(6186),
    [anon_sym_POUNDelif] = ACTIONS(6186),
    [anon_sym_POUNDELIF] = ACTIONS(6186),
    [anon_sym_POUNDElif] = ACTIONS(6186),
    [anon_sym_POUNDelse] = ACTIONS(6186),
    [anon_sym_POUNDELSE] = ACTIONS(6186),
    [anon_sym_POUNDElse] = ACTIONS(6186),
    [anon_sym_POUNDelse2] = ACTIONS(6186),
    [anon_sym_POUNDELSE2] = ACTIONS(6186),
    [anon_sym_POUNDElse2] = ACTIONS(6186),
    [anon_sym_POUNDendif] = ACTIONS(6186),
    [anon_sym_POUNDENDIF] = ACTIONS(6186),
    [anon_sym_POUNDEndif] = ACTIONS(6186),
    [anon_sym_POUNDendif2] = ACTIONS(6186),
    [anon_sym_POUNDENDIF2] = ACTIONS(6186),
    [anon_sym_POUNDEndif2] = ACTIONS(6186),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6184),
    [sym_procedure_keyword] = ACTIONS(6184),
    [sym_trigger_keyword] = ACTIONS(6184),
    [sym_var_keyword] = ACTIONS(6184),
    [sym_local_keyword] = ACTIONS(6184),
    [sym_internal_keyword] = ACTIONS(6184),
    [sym_protected_keyword] = ACTIONS(6184),
    [sym_event_keyword] = ACTIONS(6184),
    [sym_fields_keyword] = ACTIONS(6184),
    [sym_keys_keyword] = ACTIONS(6184),
    [sym_key_keyword] = ACTIONS(6184),
    [sym_fieldgroups_keyword] = ACTIONS(6184),
    [sym_actions_keyword] = ACTIONS(6184),
    [sym_layout_keyword] = ACTIONS(6184),
    [sym_dataset_keyword] = ACTIONS(6184),
    [sym_elements_keyword] = ACTIONS(6184),
    [sym_labels_keyword] = ACTIONS(6184),
    [sym_rendering_keyword] = ACTIONS(6184),
    [sym_requestpage_keyword] = ACTIONS(6184),
    [sym_schema_keyword] = ACTIONS(6184),
    [sym_views_keyword] = ACTIONS(6184),
    [sym_quoted_identifier] = ACTIONS(6186),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6186),
    [sym_preproc_open] = ACTIONS(6186),
    [sym_preproc_close] = ACTIONS(6186),
    [sym_var_attribute_open] = ACTIONS(6186),
  },
  [STATE(5903)] = {
    [sym_identifier] = ACTIONS(9040),
    [anon_sym_SEMI] = ACTIONS(9042),
    [aux_sym_where_condition_token1] = ACTIONS(9040),
    [anon_sym_LBRACK] = ACTIONS(9042),
    [aux_sym_basic_type_token22] = ACTIONS(9040),
    [aux_sym_basic_type_token53] = ACTIONS(9040),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9040),
    [aux_sym_modify_modification_token1] = ACTIONS(9040),
    [aux_sym_separator_action_token1] = ACTIONS(9040),
    [aux_sym_xmlport_element_token1] = ACTIONS(9040),
    [aux_sym_xmlport_element_token2] = ACTIONS(9040),
    [aux_sym_xmlport_element_token3] = ACTIONS(9040),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9040),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9040),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9040),
    [aux_sym_type_declaration_token1] = ACTIONS(9040),
    [anon_sym_POUNDif] = ACTIONS(9042),
    [anon_sym_POUNDIF] = ACTIONS(9042),
    [anon_sym_POUNDIf] = ACTIONS(9042),
    [anon_sym_POUNDelif] = ACTIONS(9042),
    [anon_sym_POUNDELIF] = ACTIONS(9042),
    [anon_sym_POUNDElif] = ACTIONS(9042),
    [anon_sym_POUNDelse] = ACTIONS(9042),
    [anon_sym_POUNDELSE] = ACTIONS(9042),
    [anon_sym_POUNDElse] = ACTIONS(9042),
    [anon_sym_POUNDelse2] = ACTIONS(9042),
    [anon_sym_POUNDELSE2] = ACTIONS(9042),
    [anon_sym_POUNDElse2] = ACTIONS(9042),
    [anon_sym_POUNDendif] = ACTIONS(9042),
    [anon_sym_POUNDENDIF] = ACTIONS(9042),
    [anon_sym_POUNDEndif] = ACTIONS(9042),
    [anon_sym_POUNDendif2] = ACTIONS(9042),
    [anon_sym_POUNDENDIF2] = ACTIONS(9042),
    [anon_sym_POUNDEndif2] = ACTIONS(9042),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9040),
    [sym_procedure_keyword] = ACTIONS(9040),
    [sym_trigger_keyword] = ACTIONS(9040),
    [sym_var_keyword] = ACTIONS(9040),
    [sym_local_keyword] = ACTIONS(9040),
    [sym_internal_keyword] = ACTIONS(9040),
    [sym_protected_keyword] = ACTIONS(9040),
    [sym_event_keyword] = ACTIONS(9040),
    [sym_fields_keyword] = ACTIONS(9040),
    [sym_keys_keyword] = ACTIONS(9040),
    [sym_key_keyword] = ACTIONS(9040),
    [sym_fieldgroups_keyword] = ACTIONS(9040),
    [sym_actions_keyword] = ACTIONS(9040),
    [sym_layout_keyword] = ACTIONS(9040),
    [sym_dataset_keyword] = ACTIONS(9040),
    [sym_elements_keyword] = ACTIONS(9040),
    [sym_labels_keyword] = ACTIONS(9040),
    [sym_rendering_keyword] = ACTIONS(9040),
    [sym_requestpage_keyword] = ACTIONS(9040),
    [sym_schema_keyword] = ACTIONS(9040),
    [sym_views_keyword] = ACTIONS(9040),
    [sym_quoted_identifier] = ACTIONS(9042),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9042),
    [sym_preproc_open] = ACTIONS(9042),
    [sym_preproc_close] = ACTIONS(9042),
    [sym_var_attribute_open] = ACTIONS(9042),
  },
  [STATE(5904)] = {
    [anon_sym_SEMI] = ACTIONS(8438),
    [anon_sym_RBRACE] = ACTIONS(8438),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8438),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8440),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8438),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8438),
    [anon_sym_LBRACK] = ACTIONS(8438),
    [aux_sym_basic_type_token22] = ACTIONS(8440),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8438),
    [aux_sym_addafter_modification_token1] = ACTIONS(8438),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8438),
    [aux_sym_modify_modification_token1] = ACTIONS(8438),
    [aux_sym_separator_action_token1] = ACTIONS(8438),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8438),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8438),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8438),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8438),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8438),
    [anon_sym_POUNDif] = ACTIONS(8438),
    [anon_sym_POUNDIF] = ACTIONS(8438),
    [anon_sym_POUNDIf] = ACTIONS(8438),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8440),
    [sym_page_keyword] = ACTIONS(8438),
    [anon_sym_codeunit] = ACTIONS(8438),
    [anon_sym_CODEUNIT] = ACTIONS(8438),
    [anon_sym_Codeunit] = ACTIONS(8438),
    [anon_sym_CodeUnit] = ACTIONS(8438),
    [anon_sym_COdeunit] = ACTIONS(8438),
    [anon_sym_codeUnit] = ACTIONS(8438),
    [sym_report_keyword] = ACTIONS(8438),
    [sym_query_keyword] = ACTIONS(8438),
    [anon_sym_xmlport] = ACTIONS(8438),
    [anon_sym_XMLPORT] = ACTIONS(8438),
    [anon_sym_Xmlport] = ACTIONS(8438),
    [anon_sym_XMLport] = ACTIONS(8438),
    [anon_sym_XMLPort] = ACTIONS(8438),
    [anon_sym_XmlPort] = ACTIONS(8438),
    [sym_procedure_keyword] = ACTIONS(8438),
    [sym_trigger_keyword] = ACTIONS(8438),
    [sym_var_keyword] = ACTIONS(8438),
    [sym_local_keyword] = ACTIONS(8438),
    [sym_internal_keyword] = ACTIONS(8438),
    [sym_protected_keyword] = ACTIONS(8438),
    [sym_event_keyword] = ACTIONS(8438),
    [sym_fields_keyword] = ACTIONS(8438),
    [sym_keys_keyword] = ACTIONS(8438),
    [sym_fieldgroups_keyword] = ACTIONS(8438),
    [sym_actions_keyword] = ACTIONS(8438),
    [sym_layout_keyword] = ACTIONS(8438),
    [sym_area_keyword] = ACTIONS(8438),
    [sym_group_keyword] = ACTIONS(8438),
    [sym_dataset_keyword] = ACTIONS(8438),
    [sym_elements_keyword] = ACTIONS(8438),
    [sym_labels_keyword] = ACTIONS(8438),
    [sym_rendering_keyword] = ACTIONS(8438),
    [sym_requestpage_keyword] = ACTIONS(8438),
    [sym_schema_keyword] = ACTIONS(8438),
    [sym_views_keyword] = ACTIONS(8438),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8438),
    [sym_preproc_open] = ACTIONS(8438),
  },
  [STATE(5905)] = {
    [sym_identifier] = ACTIONS(6172),
    [anon_sym_SEMI] = ACTIONS(6174),
    [aux_sym_where_condition_token1] = ACTIONS(6172),
    [anon_sym_LBRACK] = ACTIONS(6174),
    [aux_sym_basic_type_token22] = ACTIONS(6172),
    [aux_sym_basic_type_token53] = ACTIONS(6172),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6172),
    [aux_sym_modify_modification_token1] = ACTIONS(6172),
    [aux_sym_separator_action_token1] = ACTIONS(6172),
    [aux_sym_xmlport_element_token1] = ACTIONS(6172),
    [aux_sym_xmlport_element_token2] = ACTIONS(6172),
    [aux_sym_xmlport_element_token3] = ACTIONS(6172),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6172),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6172),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6172),
    [aux_sym_type_declaration_token1] = ACTIONS(6172),
    [anon_sym_POUNDif] = ACTIONS(6174),
    [anon_sym_POUNDIF] = ACTIONS(6174),
    [anon_sym_POUNDIf] = ACTIONS(6174),
    [anon_sym_POUNDelif] = ACTIONS(6174),
    [anon_sym_POUNDELIF] = ACTIONS(6174),
    [anon_sym_POUNDElif] = ACTIONS(6174),
    [anon_sym_POUNDelse] = ACTIONS(6174),
    [anon_sym_POUNDELSE] = ACTIONS(6174),
    [anon_sym_POUNDElse] = ACTIONS(6174),
    [anon_sym_POUNDelse2] = ACTIONS(6174),
    [anon_sym_POUNDELSE2] = ACTIONS(6174),
    [anon_sym_POUNDElse2] = ACTIONS(6174),
    [anon_sym_POUNDendif] = ACTIONS(6174),
    [anon_sym_POUNDENDIF] = ACTIONS(6174),
    [anon_sym_POUNDEndif] = ACTIONS(6174),
    [anon_sym_POUNDendif2] = ACTIONS(6174),
    [anon_sym_POUNDENDIF2] = ACTIONS(6174),
    [anon_sym_POUNDEndif2] = ACTIONS(6174),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6172),
    [sym_procedure_keyword] = ACTIONS(6172),
    [sym_trigger_keyword] = ACTIONS(6172),
    [sym_var_keyword] = ACTIONS(6172),
    [sym_local_keyword] = ACTIONS(6172),
    [sym_internal_keyword] = ACTIONS(6172),
    [sym_protected_keyword] = ACTIONS(6172),
    [sym_event_keyword] = ACTIONS(6172),
    [sym_fields_keyword] = ACTIONS(6172),
    [sym_keys_keyword] = ACTIONS(6172),
    [sym_key_keyword] = ACTIONS(6172),
    [sym_fieldgroups_keyword] = ACTIONS(6172),
    [sym_actions_keyword] = ACTIONS(6172),
    [sym_layout_keyword] = ACTIONS(6172),
    [sym_dataset_keyword] = ACTIONS(6172),
    [sym_elements_keyword] = ACTIONS(6172),
    [sym_labels_keyword] = ACTIONS(6172),
    [sym_rendering_keyword] = ACTIONS(6172),
    [sym_requestpage_keyword] = ACTIONS(6172),
    [sym_schema_keyword] = ACTIONS(6172),
    [sym_views_keyword] = ACTIONS(6172),
    [sym_quoted_identifier] = ACTIONS(6174),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6174),
    [sym_preproc_open] = ACTIONS(6174),
    [sym_preproc_close] = ACTIONS(6174),
    [sym_var_attribute_open] = ACTIONS(6174),
  },
  [STATE(5906)] = {
    [sym_identifier] = ACTIONS(6176),
    [anon_sym_SEMI] = ACTIONS(6178),
    [aux_sym_where_condition_token1] = ACTIONS(6176),
    [anon_sym_LBRACK] = ACTIONS(6178),
    [aux_sym_basic_type_token22] = ACTIONS(6176),
    [aux_sym_basic_type_token53] = ACTIONS(6176),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6176),
    [aux_sym_modify_modification_token1] = ACTIONS(6176),
    [aux_sym_separator_action_token1] = ACTIONS(6176),
    [aux_sym_xmlport_element_token1] = ACTIONS(6176),
    [aux_sym_xmlport_element_token2] = ACTIONS(6176),
    [aux_sym_xmlport_element_token3] = ACTIONS(6176),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6176),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6176),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6176),
    [aux_sym_type_declaration_token1] = ACTIONS(6176),
    [anon_sym_POUNDif] = ACTIONS(6178),
    [anon_sym_POUNDIF] = ACTIONS(6178),
    [anon_sym_POUNDIf] = ACTIONS(6178),
    [anon_sym_POUNDelif] = ACTIONS(6178),
    [anon_sym_POUNDELIF] = ACTIONS(6178),
    [anon_sym_POUNDElif] = ACTIONS(6178),
    [anon_sym_POUNDelse] = ACTIONS(6178),
    [anon_sym_POUNDELSE] = ACTIONS(6178),
    [anon_sym_POUNDElse] = ACTIONS(6178),
    [anon_sym_POUNDelse2] = ACTIONS(6178),
    [anon_sym_POUNDELSE2] = ACTIONS(6178),
    [anon_sym_POUNDElse2] = ACTIONS(6178),
    [anon_sym_POUNDendif] = ACTIONS(6178),
    [anon_sym_POUNDENDIF] = ACTIONS(6178),
    [anon_sym_POUNDEndif] = ACTIONS(6178),
    [anon_sym_POUNDendif2] = ACTIONS(6178),
    [anon_sym_POUNDENDIF2] = ACTIONS(6178),
    [anon_sym_POUNDEndif2] = ACTIONS(6178),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6176),
    [sym_procedure_keyword] = ACTIONS(6176),
    [sym_trigger_keyword] = ACTIONS(6176),
    [sym_var_keyword] = ACTIONS(6176),
    [sym_local_keyword] = ACTIONS(6176),
    [sym_internal_keyword] = ACTIONS(6176),
    [sym_protected_keyword] = ACTIONS(6176),
    [sym_event_keyword] = ACTIONS(6176),
    [sym_fields_keyword] = ACTIONS(6176),
    [sym_keys_keyword] = ACTIONS(6176),
    [sym_key_keyword] = ACTIONS(6176),
    [sym_fieldgroups_keyword] = ACTIONS(6176),
    [sym_actions_keyword] = ACTIONS(6176),
    [sym_layout_keyword] = ACTIONS(6176),
    [sym_dataset_keyword] = ACTIONS(6176),
    [sym_elements_keyword] = ACTIONS(6176),
    [sym_labels_keyword] = ACTIONS(6176),
    [sym_rendering_keyword] = ACTIONS(6176),
    [sym_requestpage_keyword] = ACTIONS(6176),
    [sym_schema_keyword] = ACTIONS(6176),
    [sym_views_keyword] = ACTIONS(6176),
    [sym_quoted_identifier] = ACTIONS(6178),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6178),
    [sym_preproc_open] = ACTIONS(6178),
    [sym_preproc_close] = ACTIONS(6178),
    [sym_var_attribute_open] = ACTIONS(6178),
  },
  [STATE(5907)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_xmlport_element_token1] = ACTIONS(9068),
    [aux_sym_xmlport_element_token2] = ACTIONS(9068),
    [aux_sym_xmlport_element_token3] = ACTIONS(9068),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9068),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(5908)] = {
    [sym_identifier] = ACTIONS(9056),
    [anon_sym_SEMI] = ACTIONS(9058),
    [aux_sym_where_condition_token1] = ACTIONS(9056),
    [anon_sym_LBRACK] = ACTIONS(9058),
    [aux_sym_basic_type_token22] = ACTIONS(9056),
    [aux_sym_basic_type_token53] = ACTIONS(9056),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9056),
    [aux_sym_modify_modification_token1] = ACTIONS(9056),
    [aux_sym_separator_action_token1] = ACTIONS(9056),
    [aux_sym_xmlport_element_token1] = ACTIONS(9056),
    [aux_sym_xmlport_element_token2] = ACTIONS(9056),
    [aux_sym_xmlport_element_token3] = ACTIONS(9056),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9056),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9056),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9056),
    [aux_sym_type_declaration_token1] = ACTIONS(9056),
    [anon_sym_POUNDif] = ACTIONS(9058),
    [anon_sym_POUNDIF] = ACTIONS(9058),
    [anon_sym_POUNDIf] = ACTIONS(9058),
    [anon_sym_POUNDelif] = ACTIONS(9058),
    [anon_sym_POUNDELIF] = ACTIONS(9058),
    [anon_sym_POUNDElif] = ACTIONS(9058),
    [anon_sym_POUNDelse] = ACTIONS(9058),
    [anon_sym_POUNDELSE] = ACTIONS(9058),
    [anon_sym_POUNDElse] = ACTIONS(9058),
    [anon_sym_POUNDelse2] = ACTIONS(9058),
    [anon_sym_POUNDELSE2] = ACTIONS(9058),
    [anon_sym_POUNDElse2] = ACTIONS(9058),
    [anon_sym_POUNDendif] = ACTIONS(9058),
    [anon_sym_POUNDENDIF] = ACTIONS(9058),
    [anon_sym_POUNDEndif] = ACTIONS(9058),
    [anon_sym_POUNDendif2] = ACTIONS(9058),
    [anon_sym_POUNDENDIF2] = ACTIONS(9058),
    [anon_sym_POUNDEndif2] = ACTIONS(9058),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9056),
    [sym_procedure_keyword] = ACTIONS(9056),
    [sym_trigger_keyword] = ACTIONS(9056),
    [sym_var_keyword] = ACTIONS(9056),
    [sym_local_keyword] = ACTIONS(9056),
    [sym_internal_keyword] = ACTIONS(9056),
    [sym_protected_keyword] = ACTIONS(9056),
    [sym_event_keyword] = ACTIONS(9056),
    [sym_fields_keyword] = ACTIONS(9056),
    [sym_keys_keyword] = ACTIONS(9056),
    [sym_key_keyword] = ACTIONS(9056),
    [sym_fieldgroups_keyword] = ACTIONS(9056),
    [sym_actions_keyword] = ACTIONS(9056),
    [sym_layout_keyword] = ACTIONS(9056),
    [sym_dataset_keyword] = ACTIONS(9056),
    [sym_elements_keyword] = ACTIONS(9056),
    [sym_labels_keyword] = ACTIONS(9056),
    [sym_rendering_keyword] = ACTIONS(9056),
    [sym_requestpage_keyword] = ACTIONS(9056),
    [sym_schema_keyword] = ACTIONS(9056),
    [sym_views_keyword] = ACTIONS(9056),
    [sym_quoted_identifier] = ACTIONS(9058),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9058),
    [sym_preproc_open] = ACTIONS(9058),
    [sym_preproc_close] = ACTIONS(9058),
    [sym_var_attribute_open] = ACTIONS(9058),
  },
  [STATE(5909)] = {
    [anon_sym_SEMI] = ACTIONS(8442),
    [anon_sym_RBRACE] = ACTIONS(8442),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8442),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8444),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8442),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8442),
    [anon_sym_LBRACK] = ACTIONS(8442),
    [aux_sym_basic_type_token22] = ACTIONS(8444),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8442),
    [aux_sym_addafter_modification_token1] = ACTIONS(8442),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8442),
    [aux_sym_modify_modification_token1] = ACTIONS(8442),
    [aux_sym_separator_action_token1] = ACTIONS(8442),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8442),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8442),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8442),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8442),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8442),
    [anon_sym_POUNDif] = ACTIONS(8442),
    [anon_sym_POUNDIF] = ACTIONS(8442),
    [anon_sym_POUNDIf] = ACTIONS(8442),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8444),
    [sym_page_keyword] = ACTIONS(8442),
    [anon_sym_codeunit] = ACTIONS(8442),
    [anon_sym_CODEUNIT] = ACTIONS(8442),
    [anon_sym_Codeunit] = ACTIONS(8442),
    [anon_sym_CodeUnit] = ACTIONS(8442),
    [anon_sym_COdeunit] = ACTIONS(8442),
    [anon_sym_codeUnit] = ACTIONS(8442),
    [sym_report_keyword] = ACTIONS(8442),
    [sym_query_keyword] = ACTIONS(8442),
    [anon_sym_xmlport] = ACTIONS(8442),
    [anon_sym_XMLPORT] = ACTIONS(8442),
    [anon_sym_Xmlport] = ACTIONS(8442),
    [anon_sym_XMLport] = ACTIONS(8442),
    [anon_sym_XMLPort] = ACTIONS(8442),
    [anon_sym_XmlPort] = ACTIONS(8442),
    [sym_procedure_keyword] = ACTIONS(8442),
    [sym_trigger_keyword] = ACTIONS(8442),
    [sym_var_keyword] = ACTIONS(8442),
    [sym_local_keyword] = ACTIONS(8442),
    [sym_internal_keyword] = ACTIONS(8442),
    [sym_protected_keyword] = ACTIONS(8442),
    [sym_event_keyword] = ACTIONS(8442),
    [sym_fields_keyword] = ACTIONS(8442),
    [sym_keys_keyword] = ACTIONS(8442),
    [sym_fieldgroups_keyword] = ACTIONS(8442),
    [sym_actions_keyword] = ACTIONS(8442),
    [sym_layout_keyword] = ACTIONS(8442),
    [sym_area_keyword] = ACTIONS(8442),
    [sym_group_keyword] = ACTIONS(8442),
    [sym_dataset_keyword] = ACTIONS(8442),
    [sym_elements_keyword] = ACTIONS(8442),
    [sym_labels_keyword] = ACTIONS(8442),
    [sym_rendering_keyword] = ACTIONS(8442),
    [sym_requestpage_keyword] = ACTIONS(8442),
    [sym_schema_keyword] = ACTIONS(8442),
    [sym_views_keyword] = ACTIONS(8442),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8442),
    [sym_preproc_open] = ACTIONS(8442),
  },
  [STATE(5910)] = {
    [anon_sym_SEMI] = ACTIONS(8446),
    [anon_sym_RBRACE] = ACTIONS(8446),
    [aux_sym_tabledata_permission_token1] = ACTIONS(8446),
    [aux_sym_tabledata_permission_token2] = ACTIONS(8448),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(8446),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(8446),
    [anon_sym_LBRACK] = ACTIONS(8446),
    [aux_sym_basic_type_token22] = ACTIONS(8448),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8446),
    [aux_sym_addafter_modification_token1] = ACTIONS(8446),
    [aux_sym_addbefore_modification_token1] = ACTIONS(8446),
    [aux_sym_modify_modification_token1] = ACTIONS(8446),
    [aux_sym_separator_action_token1] = ACTIONS(8446),
    [aux_sym_actionref_declaration_token1] = ACTIONS(8446),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(8446),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(8446),
    [aux_sym_customaction_declaration_token1] = ACTIONS(8446),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8446),
    [anon_sym_POUNDif] = ACTIONS(8446),
    [anon_sym_POUNDIF] = ACTIONS(8446),
    [anon_sym_POUNDIf] = ACTIONS(8446),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8448),
    [sym_page_keyword] = ACTIONS(8446),
    [anon_sym_codeunit] = ACTIONS(8446),
    [anon_sym_CODEUNIT] = ACTIONS(8446),
    [anon_sym_Codeunit] = ACTIONS(8446),
    [anon_sym_CodeUnit] = ACTIONS(8446),
    [anon_sym_COdeunit] = ACTIONS(8446),
    [anon_sym_codeUnit] = ACTIONS(8446),
    [sym_report_keyword] = ACTIONS(8446),
    [sym_query_keyword] = ACTIONS(8446),
    [anon_sym_xmlport] = ACTIONS(8446),
    [anon_sym_XMLPORT] = ACTIONS(8446),
    [anon_sym_Xmlport] = ACTIONS(8446),
    [anon_sym_XMLport] = ACTIONS(8446),
    [anon_sym_XMLPort] = ACTIONS(8446),
    [anon_sym_XmlPort] = ACTIONS(8446),
    [sym_procedure_keyword] = ACTIONS(8446),
    [sym_trigger_keyword] = ACTIONS(8446),
    [sym_var_keyword] = ACTIONS(8446),
    [sym_local_keyword] = ACTIONS(8446),
    [sym_internal_keyword] = ACTIONS(8446),
    [sym_protected_keyword] = ACTIONS(8446),
    [sym_event_keyword] = ACTIONS(8446),
    [sym_fields_keyword] = ACTIONS(8446),
    [sym_keys_keyword] = ACTIONS(8446),
    [sym_fieldgroups_keyword] = ACTIONS(8446),
    [sym_actions_keyword] = ACTIONS(8446),
    [sym_layout_keyword] = ACTIONS(8446),
    [sym_area_keyword] = ACTIONS(8446),
    [sym_group_keyword] = ACTIONS(8446),
    [sym_dataset_keyword] = ACTIONS(8446),
    [sym_elements_keyword] = ACTIONS(8446),
    [sym_labels_keyword] = ACTIONS(8446),
    [sym_rendering_keyword] = ACTIONS(8446),
    [sym_requestpage_keyword] = ACTIONS(8446),
    [sym_schema_keyword] = ACTIONS(8446),
    [sym_views_keyword] = ACTIONS(8446),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8446),
    [sym_preproc_open] = ACTIONS(8446),
  },
  [STATE(5911)] = {
    [sym_identifier] = ACTIONS(6188),
    [anon_sym_SEMI] = ACTIONS(6190),
    [aux_sym_where_condition_token1] = ACTIONS(6188),
    [anon_sym_LBRACK] = ACTIONS(6190),
    [aux_sym_basic_type_token22] = ACTIONS(6188),
    [aux_sym_basic_type_token53] = ACTIONS(6188),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6188),
    [aux_sym_modify_modification_token1] = ACTIONS(6188),
    [aux_sym_separator_action_token1] = ACTIONS(6188),
    [aux_sym_xmlport_element_token1] = ACTIONS(6188),
    [aux_sym_xmlport_element_token2] = ACTIONS(6188),
    [aux_sym_xmlport_element_token3] = ACTIONS(6188),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6188),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6188),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6188),
    [aux_sym_type_declaration_token1] = ACTIONS(6188),
    [anon_sym_POUNDif] = ACTIONS(6190),
    [anon_sym_POUNDIF] = ACTIONS(6190),
    [anon_sym_POUNDIf] = ACTIONS(6190),
    [anon_sym_POUNDelif] = ACTIONS(6190),
    [anon_sym_POUNDELIF] = ACTIONS(6190),
    [anon_sym_POUNDElif] = ACTIONS(6190),
    [anon_sym_POUNDelse] = ACTIONS(6190),
    [anon_sym_POUNDELSE] = ACTIONS(6190),
    [anon_sym_POUNDElse] = ACTIONS(6190),
    [anon_sym_POUNDelse2] = ACTIONS(6190),
    [anon_sym_POUNDELSE2] = ACTIONS(6190),
    [anon_sym_POUNDElse2] = ACTIONS(6190),
    [anon_sym_POUNDendif] = ACTIONS(6190),
    [anon_sym_POUNDENDIF] = ACTIONS(6190),
    [anon_sym_POUNDEndif] = ACTIONS(6190),
    [anon_sym_POUNDendif2] = ACTIONS(6190),
    [anon_sym_POUNDENDIF2] = ACTIONS(6190),
    [anon_sym_POUNDEndif2] = ACTIONS(6190),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6188),
    [sym_procedure_keyword] = ACTIONS(6188),
    [sym_trigger_keyword] = ACTIONS(6188),
    [sym_var_keyword] = ACTIONS(6188),
    [sym_local_keyword] = ACTIONS(6188),
    [sym_internal_keyword] = ACTIONS(6188),
    [sym_protected_keyword] = ACTIONS(6188),
    [sym_event_keyword] = ACTIONS(6188),
    [sym_fields_keyword] = ACTIONS(6188),
    [sym_keys_keyword] = ACTIONS(6188),
    [sym_key_keyword] = ACTIONS(6188),
    [sym_fieldgroups_keyword] = ACTIONS(6188),
    [sym_actions_keyword] = ACTIONS(6188),
    [sym_layout_keyword] = ACTIONS(6188),
    [sym_dataset_keyword] = ACTIONS(6188),
    [sym_elements_keyword] = ACTIONS(6188),
    [sym_labels_keyword] = ACTIONS(6188),
    [sym_rendering_keyword] = ACTIONS(6188),
    [sym_requestpage_keyword] = ACTIONS(6188),
    [sym_schema_keyword] = ACTIONS(6188),
    [sym_views_keyword] = ACTIONS(6188),
    [sym_quoted_identifier] = ACTIONS(6190),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6190),
    [sym_preproc_open] = ACTIONS(6190),
    [sym_preproc_close] = ACTIONS(6190),
    [sym_var_attribute_open] = ACTIONS(6190),
  },
  [STATE(5912)] = {
    [sym_identifier] = ACTIONS(8901),
    [anon_sym_SEMI] = ACTIONS(8903),
    [aux_sym_where_condition_token1] = ACTIONS(8901),
    [anon_sym_LBRACK] = ACTIONS(8903),
    [aux_sym_basic_type_token22] = ACTIONS(8901),
    [aux_sym_basic_type_token53] = ACTIONS(8901),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8901),
    [aux_sym_modify_modification_token1] = ACTIONS(8901),
    [aux_sym_separator_action_token1] = ACTIONS(8901),
    [aux_sym_xmlport_element_token1] = ACTIONS(8901),
    [aux_sym_xmlport_element_token2] = ACTIONS(8901),
    [aux_sym_xmlport_element_token3] = ACTIONS(8901),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8901),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8901),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8901),
    [aux_sym_type_declaration_token1] = ACTIONS(8901),
    [anon_sym_POUNDif] = ACTIONS(8903),
    [anon_sym_POUNDIF] = ACTIONS(8903),
    [anon_sym_POUNDIf] = ACTIONS(8903),
    [anon_sym_POUNDelif] = ACTIONS(8903),
    [anon_sym_POUNDELIF] = ACTIONS(8903),
    [anon_sym_POUNDElif] = ACTIONS(8903),
    [anon_sym_POUNDelse] = ACTIONS(8903),
    [anon_sym_POUNDELSE] = ACTIONS(8903),
    [anon_sym_POUNDElse] = ACTIONS(8903),
    [anon_sym_POUNDelse2] = ACTIONS(8903),
    [anon_sym_POUNDELSE2] = ACTIONS(8903),
    [anon_sym_POUNDElse2] = ACTIONS(8903),
    [anon_sym_POUNDendif] = ACTIONS(8903),
    [anon_sym_POUNDENDIF] = ACTIONS(8903),
    [anon_sym_POUNDEndif] = ACTIONS(8903),
    [anon_sym_POUNDendif2] = ACTIONS(8903),
    [anon_sym_POUNDENDIF2] = ACTIONS(8903),
    [anon_sym_POUNDEndif2] = ACTIONS(8903),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8901),
    [sym_procedure_keyword] = ACTIONS(8901),
    [sym_trigger_keyword] = ACTIONS(8901),
    [sym_var_keyword] = ACTIONS(8901),
    [sym_local_keyword] = ACTIONS(8901),
    [sym_internal_keyword] = ACTIONS(8901),
    [sym_protected_keyword] = ACTIONS(8901),
    [sym_event_keyword] = ACTIONS(8901),
    [sym_fields_keyword] = ACTIONS(8901),
    [sym_keys_keyword] = ACTIONS(8901),
    [sym_key_keyword] = ACTIONS(8901),
    [sym_fieldgroups_keyword] = ACTIONS(8901),
    [sym_actions_keyword] = ACTIONS(8901),
    [sym_layout_keyword] = ACTIONS(8901),
    [sym_dataset_keyword] = ACTIONS(8901),
    [sym_elements_keyword] = ACTIONS(8901),
    [sym_labels_keyword] = ACTIONS(8901),
    [sym_rendering_keyword] = ACTIONS(8901),
    [sym_requestpage_keyword] = ACTIONS(8901),
    [sym_schema_keyword] = ACTIONS(8901),
    [sym_views_keyword] = ACTIONS(8901),
    [sym_quoted_identifier] = ACTIONS(8903),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8903),
    [sym_preproc_open] = ACTIONS(8903),
    [sym_preproc_close] = ACTIONS(8903),
    [sym_var_attribute_open] = ACTIONS(8903),
  },
  [STATE(5913)] = {
    [sym_identifier] = ACTIONS(9068),
    [anon_sym_SEMI] = ACTIONS(9070),
    [aux_sym_where_condition_token1] = ACTIONS(9068),
    [anon_sym_LBRACK] = ACTIONS(9070),
    [aux_sym_basic_type_token22] = ACTIONS(9068),
    [aux_sym_basic_type_token53] = ACTIONS(9068),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9068),
    [aux_sym_modify_modification_token1] = ACTIONS(9068),
    [aux_sym_separator_action_token1] = ACTIONS(9068),
    [aux_sym_xmlport_element_token1] = ACTIONS(9068),
    [aux_sym_xmlport_element_token2] = ACTIONS(9068),
    [aux_sym_xmlport_element_token3] = ACTIONS(9068),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9068),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9068),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9068),
    [aux_sym_type_declaration_token1] = ACTIONS(9068),
    [anon_sym_POUNDif] = ACTIONS(9070),
    [anon_sym_POUNDIF] = ACTIONS(9070),
    [anon_sym_POUNDIf] = ACTIONS(9070),
    [anon_sym_POUNDelif] = ACTIONS(9070),
    [anon_sym_POUNDELIF] = ACTIONS(9070),
    [anon_sym_POUNDElif] = ACTIONS(9070),
    [anon_sym_POUNDelse] = ACTIONS(9070),
    [anon_sym_POUNDELSE] = ACTIONS(9070),
    [anon_sym_POUNDElse] = ACTIONS(9070),
    [anon_sym_POUNDelse2] = ACTIONS(9070),
    [anon_sym_POUNDELSE2] = ACTIONS(9070),
    [anon_sym_POUNDElse2] = ACTIONS(9070),
    [anon_sym_POUNDendif] = ACTIONS(9070),
    [anon_sym_POUNDENDIF] = ACTIONS(9070),
    [anon_sym_POUNDEndif] = ACTIONS(9070),
    [anon_sym_POUNDendif2] = ACTIONS(9070),
    [anon_sym_POUNDENDIF2] = ACTIONS(9070),
    [anon_sym_POUNDEndif2] = ACTIONS(9070),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9068),
    [sym_procedure_keyword] = ACTIONS(9068),
    [sym_trigger_keyword] = ACTIONS(9068),
    [sym_var_keyword] = ACTIONS(9068),
    [sym_local_keyword] = ACTIONS(9068),
    [sym_internal_keyword] = ACTIONS(9068),
    [sym_protected_keyword] = ACTIONS(9068),
    [sym_event_keyword] = ACTIONS(9068),
    [sym_fields_keyword] = ACTIONS(9068),
    [sym_keys_keyword] = ACTIONS(9068),
    [sym_key_keyword] = ACTIONS(9068),
    [sym_fieldgroups_keyword] = ACTIONS(9068),
    [sym_actions_keyword] = ACTIONS(9068),
    [sym_layout_keyword] = ACTIONS(9068),
    [sym_dataset_keyword] = ACTIONS(9068),
    [sym_elements_keyword] = ACTIONS(9068),
    [sym_labels_keyword] = ACTIONS(9068),
    [sym_rendering_keyword] = ACTIONS(9068),
    [sym_requestpage_keyword] = ACTIONS(9068),
    [sym_schema_keyword] = ACTIONS(9068),
    [sym_views_keyword] = ACTIONS(9068),
    [sym_quoted_identifier] = ACTIONS(9070),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9070),
    [sym_preproc_open] = ACTIONS(9070),
    [sym_preproc_close] = ACTIONS(9070),
    [sym_var_attribute_open] = ACTIONS(9070),
  },
  [STATE(5914)] = {
    [sym_identifier] = ACTIONS(9010),
    [anon_sym_SEMI] = ACTIONS(9012),
    [aux_sym_where_condition_token1] = ACTIONS(9010),
    [anon_sym_LBRACK] = ACTIONS(9012),
    [aux_sym_basic_type_token22] = ACTIONS(9010),
    [aux_sym_basic_type_token53] = ACTIONS(9010),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9010),
    [aux_sym_modify_modification_token1] = ACTIONS(9010),
    [aux_sym_separator_action_token1] = ACTIONS(9010),
    [aux_sym_xmlport_element_token1] = ACTIONS(9010),
    [aux_sym_xmlport_element_token2] = ACTIONS(9010),
    [aux_sym_xmlport_element_token3] = ACTIONS(9010),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9010),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9010),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9010),
    [aux_sym_type_declaration_token1] = ACTIONS(9010),
    [anon_sym_POUNDif] = ACTIONS(9012),
    [anon_sym_POUNDIF] = ACTIONS(9012),
    [anon_sym_POUNDIf] = ACTIONS(9012),
    [anon_sym_POUNDelif] = ACTIONS(9012),
    [anon_sym_POUNDELIF] = ACTIONS(9012),
    [anon_sym_POUNDElif] = ACTIONS(9012),
    [anon_sym_POUNDelse] = ACTIONS(9012),
    [anon_sym_POUNDELSE] = ACTIONS(9012),
    [anon_sym_POUNDElse] = ACTIONS(9012),
    [anon_sym_POUNDelse2] = ACTIONS(9012),
    [anon_sym_POUNDELSE2] = ACTIONS(9012),
    [anon_sym_POUNDElse2] = ACTIONS(9012),
    [anon_sym_POUNDendif] = ACTIONS(9012),
    [anon_sym_POUNDENDIF] = ACTIONS(9012),
    [anon_sym_POUNDEndif] = ACTIONS(9012),
    [anon_sym_POUNDendif2] = ACTIONS(9012),
    [anon_sym_POUNDENDIF2] = ACTIONS(9012),
    [anon_sym_POUNDEndif2] = ACTIONS(9012),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9010),
    [sym_procedure_keyword] = ACTIONS(9010),
    [sym_trigger_keyword] = ACTIONS(9010),
    [sym_var_keyword] = ACTIONS(9010),
    [sym_local_keyword] = ACTIONS(9010),
    [sym_internal_keyword] = ACTIONS(9010),
    [sym_protected_keyword] = ACTIONS(9010),
    [sym_event_keyword] = ACTIONS(9010),
    [sym_fields_keyword] = ACTIONS(9010),
    [sym_keys_keyword] = ACTIONS(9010),
    [sym_key_keyword] = ACTIONS(9010),
    [sym_fieldgroups_keyword] = ACTIONS(9010),
    [sym_actions_keyword] = ACTIONS(9010),
    [sym_layout_keyword] = ACTIONS(9010),
    [sym_dataset_keyword] = ACTIONS(9010),
    [sym_elements_keyword] = ACTIONS(9010),
    [sym_labels_keyword] = ACTIONS(9010),
    [sym_rendering_keyword] = ACTIONS(9010),
    [sym_requestpage_keyword] = ACTIONS(9010),
    [sym_schema_keyword] = ACTIONS(9010),
    [sym_views_keyword] = ACTIONS(9010),
    [sym_quoted_identifier] = ACTIONS(9012),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9012),
    [sym_preproc_open] = ACTIONS(9012),
    [sym_preproc_close] = ACTIONS(9012),
    [sym_var_attribute_open] = ACTIONS(9012),
  },
  [STATE(5915)] = {
    [sym_identifier] = ACTIONS(9014),
    [anon_sym_SEMI] = ACTIONS(9016),
    [aux_sym_where_condition_token1] = ACTIONS(9014),
    [anon_sym_LBRACK] = ACTIONS(9016),
    [aux_sym_basic_type_token22] = ACTIONS(9014),
    [aux_sym_basic_type_token53] = ACTIONS(9014),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9014),
    [aux_sym_modify_modification_token1] = ACTIONS(9014),
    [aux_sym_separator_action_token1] = ACTIONS(9014),
    [aux_sym_xmlport_element_token1] = ACTIONS(9014),
    [aux_sym_xmlport_element_token2] = ACTIONS(9014),
    [aux_sym_xmlport_element_token3] = ACTIONS(9014),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9014),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9014),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9014),
    [aux_sym_type_declaration_token1] = ACTIONS(9014),
    [anon_sym_POUNDif] = ACTIONS(9016),
    [anon_sym_POUNDIF] = ACTIONS(9016),
    [anon_sym_POUNDIf] = ACTIONS(9016),
    [anon_sym_POUNDelif] = ACTIONS(9016),
    [anon_sym_POUNDELIF] = ACTIONS(9016),
    [anon_sym_POUNDElif] = ACTIONS(9016),
    [anon_sym_POUNDelse] = ACTIONS(9016),
    [anon_sym_POUNDELSE] = ACTIONS(9016),
    [anon_sym_POUNDElse] = ACTIONS(9016),
    [anon_sym_POUNDelse2] = ACTIONS(9016),
    [anon_sym_POUNDELSE2] = ACTIONS(9016),
    [anon_sym_POUNDElse2] = ACTIONS(9016),
    [anon_sym_POUNDendif] = ACTIONS(9016),
    [anon_sym_POUNDENDIF] = ACTIONS(9016),
    [anon_sym_POUNDEndif] = ACTIONS(9016),
    [anon_sym_POUNDendif2] = ACTIONS(9016),
    [anon_sym_POUNDENDIF2] = ACTIONS(9016),
    [anon_sym_POUNDEndif2] = ACTIONS(9016),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9014),
    [sym_procedure_keyword] = ACTIONS(9014),
    [sym_trigger_keyword] = ACTIONS(9014),
    [sym_var_keyword] = ACTIONS(9014),
    [sym_local_keyword] = ACTIONS(9014),
    [sym_internal_keyword] = ACTIONS(9014),
    [sym_protected_keyword] = ACTIONS(9014),
    [sym_event_keyword] = ACTIONS(9014),
    [sym_fields_keyword] = ACTIONS(9014),
    [sym_keys_keyword] = ACTIONS(9014),
    [sym_key_keyword] = ACTIONS(9014),
    [sym_fieldgroups_keyword] = ACTIONS(9014),
    [sym_actions_keyword] = ACTIONS(9014),
    [sym_layout_keyword] = ACTIONS(9014),
    [sym_dataset_keyword] = ACTIONS(9014),
    [sym_elements_keyword] = ACTIONS(9014),
    [sym_labels_keyword] = ACTIONS(9014),
    [sym_rendering_keyword] = ACTIONS(9014),
    [sym_requestpage_keyword] = ACTIONS(9014),
    [sym_schema_keyword] = ACTIONS(9014),
    [sym_views_keyword] = ACTIONS(9014),
    [sym_quoted_identifier] = ACTIONS(9016),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9016),
    [sym_preproc_open] = ACTIONS(9016),
    [sym_preproc_close] = ACTIONS(9016),
    [sym_var_attribute_open] = ACTIONS(9016),
  },
  [STATE(5916)] = {
    [sym_property] = STATE(5865),
    [sym__action_element] = STATE(5865),
    [sym_action_area_section] = STATE(5865),
    [sym_action_group_section] = STATE(5865),
    [sym_action_declaration] = STATE(5865),
    [sym_separator_action] = STATE(5865),
    [sym_actionref_declaration] = STATE(5865),
    [sym_systemaction_declaration] = STATE(5865),
    [sym_fileuploadaction_declaration] = STATE(5865),
    [sym_customaction_declaration] = STATE(5865),
    [sym_addfirst_action_modification] = STATE(5865),
    [sym_addlast_action_modification] = STATE(5865),
    [sym_addafter_action_modification] = STATE(5865),
    [sym_addbefore_action_modification] = STATE(5865),
    [sym_modify_action_modification] = STATE(5865),
    [sym_trigger_declaration] = STATE(5865),
    [sym_attribute_item] = STATE(5865),
    [sym_preproc_if] = STATE(5874),
    [sym_preproc_elif] = STATE(6593),
    [sym_preproc_else] = STATE(8105),
    [sym_preproc_endif] = STATE(10359),
    [sym_preproc_conditional_actions] = STATE(5865),
    [aux_sym_actions_section_repeat1] = STATE(5865),
    [aux_sym_preproc_conditional_actions_repeat1] = STATE(10987),
    [aux_sym_addlast_fieldgroup_modification_token1] = ACTIONS(5191),
    [aux_sym_addfirst_fieldgroup_modification_token1] = ACTIONS(5193),
    [anon_sym_LBRACK] = ACTIONS(14463),
    [aux_sym_basic_type_token22] = ACTIONS(5195),
    [aux_sym_addafter_modification_token1] = ACTIONS(5197),
    [aux_sym_addbefore_modification_token1] = ACTIONS(5199),
    [aux_sym_modify_modification_token1] = ACTIONS(14465),
    [aux_sym_separator_action_token1] = ACTIONS(5203),
    [aux_sym_actionref_declaration_token1] = ACTIONS(5205),
    [aux_sym_systemaction_declaration_token1] = ACTIONS(5207),
    [aux_sym_fileuploadaction_declaration_token1] = ACTIONS(5209),
    [aux_sym_customaction_declaration_token1] = ACTIONS(5211),
    [anon_sym_POUNDif] = ACTIONS(14467),
    [anon_sym_POUNDIF] = ACTIONS(14467),
    [anon_sym_POUNDIf] = ACTIONS(14467),
    [anon_sym_POUNDelif] = ACTIONS(14469),
    [anon_sym_POUNDELIF] = ACTIONS(14469),
    [anon_sym_POUNDElif] = ACTIONS(14469),
    [anon_sym_POUNDelse] = ACTIONS(14471),
    [anon_sym_POUNDELSE] = ACTIONS(14471),
    [anon_sym_POUNDElse] = ACTIONS(14471),
    [anon_sym_POUNDelse2] = ACTIONS(14471),
    [anon_sym_POUNDELSE2] = ACTIONS(14471),
    [anon_sym_POUNDElse2] = ACTIONS(14471),
    [anon_sym_POUNDendif] = ACTIONS(14477),
    [anon_sym_POUNDENDIF] = ACTIONS(14477),
    [anon_sym_POUNDEndif] = ACTIONS(14477),
    [anon_sym_POUNDendif2] = ACTIONS(14477),
    [anon_sym_POUNDENDIF2] = ACTIONS(14477),
    [anon_sym_POUNDEndif2] = ACTIONS(14477),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_trigger_keyword] = ACTIONS(14473),
    [sym_area_keyword] = ACTIONS(5213),
    [sym_group_keyword] = ACTIONS(5215),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(14475),
    [sym_preproc_open] = ACTIONS(14467),
    [sym_preproc_close] = ACTIONS(14477),
  },
  [STATE(5917)] = {
    [sym_identifier] = ACTIONS(9060),
    [anon_sym_SEMI] = ACTIONS(9062),
    [aux_sym_where_condition_token1] = ACTIONS(9060),
    [anon_sym_LBRACK] = ACTIONS(9062),
    [aux_sym_basic_type_token22] = ACTIONS(9060),
    [aux_sym_basic_type_token53] = ACTIONS(9060),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9060),
    [aux_sym_modify_modification_token1] = ACTIONS(9060),
    [aux_sym_separator_action_token1] = ACTIONS(9060),
    [aux_sym_xmlport_element_token1] = ACTIONS(9060),
    [aux_sym_xmlport_element_token2] = ACTIONS(9060),
    [aux_sym_xmlport_element_token3] = ACTIONS(9060),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9060),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9060),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9060),
    [aux_sym_type_declaration_token1] = ACTIONS(9060),
    [anon_sym_POUNDif] = ACTIONS(9062),
    [anon_sym_POUNDIF] = ACTIONS(9062),
    [anon_sym_POUNDIf] = ACTIONS(9062),
    [anon_sym_POUNDelif] = ACTIONS(9062),
    [anon_sym_POUNDELIF] = ACTIONS(9062),
    [anon_sym_POUNDElif] = ACTIONS(9062),
    [anon_sym_POUNDelse] = ACTIONS(9062),
    [anon_sym_POUNDELSE] = ACTIONS(9062),
    [anon_sym_POUNDElse] = ACTIONS(9062),
    [anon_sym_POUNDelse2] = ACTIONS(9062),
    [anon_sym_POUNDELSE2] = ACTIONS(9062),
    [anon_sym_POUNDElse2] = ACTIONS(9062),
    [anon_sym_POUNDendif] = ACTIONS(9062),
    [anon_sym_POUNDENDIF] = ACTIONS(9062),
    [anon_sym_POUNDEndif] = ACTIONS(9062),
    [anon_sym_POUNDendif2] = ACTIONS(9062),
    [anon_sym_POUNDENDIF2] = ACTIONS(9062),
    [anon_sym_POUNDEndif2] = ACTIONS(9062),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9060),
    [sym_procedure_keyword] = ACTIONS(9060),
    [sym_trigger_keyword] = ACTIONS(9060),
    [sym_var_keyword] = ACTIONS(9060),
    [sym_local_keyword] = ACTIONS(9060),
    [sym_internal_keyword] = ACTIONS(9060),
    [sym_protected_keyword] = ACTIONS(9060),
    [sym_event_keyword] = ACTIONS(9060),
    [sym_fields_keyword] = ACTIONS(9060),
    [sym_keys_keyword] = ACTIONS(9060),
    [sym_key_keyword] = ACTIONS(9060),
    [sym_fieldgroups_keyword] = ACTIONS(9060),
    [sym_actions_keyword] = ACTIONS(9060),
    [sym_layout_keyword] = ACTIONS(9060),
    [sym_dataset_keyword] = ACTIONS(9060),
    [sym_elements_keyword] = ACTIONS(9060),
    [sym_labels_keyword] = ACTIONS(9060),
    [sym_rendering_keyword] = ACTIONS(9060),
    [sym_requestpage_keyword] = ACTIONS(9060),
    [sym_schema_keyword] = ACTIONS(9060),
    [sym_views_keyword] = ACTIONS(9060),
    [sym_quoted_identifier] = ACTIONS(9062),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9062),
    [sym_preproc_open] = ACTIONS(9062),
    [sym_preproc_close] = ACTIONS(9062),
    [sym_var_attribute_open] = ACTIONS(9062),
  },
  [STATE(5918)] = {
    [sym_identifier] = ACTIONS(8998),
    [anon_sym_SEMI] = ACTIONS(9000),
    [aux_sym_where_condition_token1] = ACTIONS(8998),
    [anon_sym_LBRACK] = ACTIONS(9000),
    [aux_sym_basic_type_token22] = ACTIONS(8998),
    [aux_sym_basic_type_token53] = ACTIONS(8998),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8998),
    [aux_sym_modify_modification_token1] = ACTIONS(8998),
    [aux_sym_separator_action_token1] = ACTIONS(8998),
    [aux_sym_xmlport_element_token1] = ACTIONS(8998),
    [aux_sym_xmlport_element_token2] = ACTIONS(8998),
    [aux_sym_xmlport_element_token3] = ACTIONS(8998),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8998),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8998),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8998),
    [aux_sym_type_declaration_token1] = ACTIONS(8998),
    [anon_sym_POUNDif] = ACTIONS(9000),
    [anon_sym_POUNDIF] = ACTIONS(9000),
    [anon_sym_POUNDIf] = ACTIONS(9000),
    [anon_sym_POUNDelif] = ACTIONS(9000),
    [anon_sym_POUNDELIF] = ACTIONS(9000),
    [anon_sym_POUNDElif] = ACTIONS(9000),
    [anon_sym_POUNDelse] = ACTIONS(9000),
    [anon_sym_POUNDELSE] = ACTIONS(9000),
    [anon_sym_POUNDElse] = ACTIONS(9000),
    [anon_sym_POUNDelse2] = ACTIONS(9000),
    [anon_sym_POUNDELSE2] = ACTIONS(9000),
    [anon_sym_POUNDElse2] = ACTIONS(9000),
    [anon_sym_POUNDendif] = ACTIONS(9000),
    [anon_sym_POUNDENDIF] = ACTIONS(9000),
    [anon_sym_POUNDEndif] = ACTIONS(9000),
    [anon_sym_POUNDendif2] = ACTIONS(9000),
    [anon_sym_POUNDENDIF2] = ACTIONS(9000),
    [anon_sym_POUNDEndif2] = ACTIONS(9000),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8998),
    [sym_procedure_keyword] = ACTIONS(8998),
    [sym_trigger_keyword] = ACTIONS(8998),
    [sym_var_keyword] = ACTIONS(8998),
    [sym_local_keyword] = ACTIONS(8998),
    [sym_internal_keyword] = ACTIONS(8998),
    [sym_protected_keyword] = ACTIONS(8998),
    [sym_event_keyword] = ACTIONS(8998),
    [sym_fields_keyword] = ACTIONS(8998),
    [sym_keys_keyword] = ACTIONS(8998),
    [sym_key_keyword] = ACTIONS(8998),
    [sym_fieldgroups_keyword] = ACTIONS(8998),
    [sym_actions_keyword] = ACTIONS(8998),
    [sym_layout_keyword] = ACTIONS(8998),
    [sym_dataset_keyword] = ACTIONS(8998),
    [sym_elements_keyword] = ACTIONS(8998),
    [sym_labels_keyword] = ACTIONS(8998),
    [sym_rendering_keyword] = ACTIONS(8998),
    [sym_requestpage_keyword] = ACTIONS(8998),
    [sym_schema_keyword] = ACTIONS(8998),
    [sym_views_keyword] = ACTIONS(8998),
    [sym_quoted_identifier] = ACTIONS(9000),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9000),
    [sym_preproc_open] = ACTIONS(9000),
    [sym_preproc_close] = ACTIONS(9000),
    [sym_var_attribute_open] = ACTIONS(9000),
  },
  [STATE(5919)] = {
    [sym_boolean] = STATE(7226),
    [sym_option_member_list] = STATE(7208),
    [sym_option_member] = STATE(15000),
    [sym_keyword_identifier] = STATE(7226),
    [sym_codeunit_keyword] = STATE(6858),
    [sym_xmlport_keyword] = STATE(6858),
    [sym_enum_keyword] = STATE(6858),
    [sym_keyword_as_identifier] = STATE(7226),
    [aux_sym_option_member_list_repeat2] = STATE(5935),
    [sym_identifier] = ACTIONS(3993),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(3953),
    [anon_sym_DASH] = ACTIONS(14485),
    [aux_sym_boolean_token1] = ACTIONS(1376),
    [aux_sym_boolean_token2] = ACTIONS(1376),
    [anon_sym_RPAREN] = ACTIONS(582),
    [aux_sym_where_condition_token1] = ACTIONS(4043),
    [aux_sym_tabledata_permission_token2] = ACTIONS(1382),
    [anon_sym_RBRACK] = ACTIONS(582),
    [aux_sym_record_type_token1] = ACTIONS(1382),
    [aux_sym_basic_type_token21] = ACTIONS(1382),
    [aux_sym_basic_type_token22] = ACTIONS(6034),
    [aux_sym_basic_type_token48] = ACTIONS(1382),
    [aux_sym_basic_type_token53] = ACTIONS(4043),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(4043),
    [aux_sym_separator_action_token1] = ACTIONS(4043),
    [aux_sym_assembly_declaration_token1] = ACTIONS(4043),
    [aux_sym_type_declaration_token1] = ACTIONS(4043),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [aux_sym_keyword_identifier_token1] = ACTIONS(1382),
    [aux_sym_keyword_identifier_token2] = ACTIONS(1382),
    [sym_table_keyword] = ACTIONS(4043),
    [sym_page_keyword] = ACTIONS(1382),
    [anon_sym_codeunit] = ACTIONS(1400),
    [anon_sym_CODEUNIT] = ACTIONS(1400),
    [anon_sym_Codeunit] = ACTIONS(1400),
    [anon_sym_CodeUnit] = ACTIONS(1400),
    [anon_sym_COdeunit] = ACTIONS(1400),
    [anon_sym_codeUnit] = ACTIONS(1400),
    [sym_report_keyword] = ACTIONS(1382),
    [sym_query_keyword] = ACTIONS(1382),
    [anon_sym_xmlport] = ACTIONS(1402),
    [anon_sym_XMLPORT] = ACTIONS(1402),
    [anon_sym_Xmlport] = ACTIONS(1402),
    [anon_sym_XMLport] = ACTIONS(1402),
    [anon_sym_XMLPort] = ACTIONS(1402),
    [anon_sym_XmlPort] = ACTIONS(1402),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_ENUM] = ACTIONS(27),
    [anon_sym_Enum] = ACTIONS(27),
    [anon_sym_eNUM] = ACTIONS(27),
    [anon_sym_eNum] = ACTIONS(27),
    [anon_sym_ENum] = ACTIONS(27),
    [sym_local_keyword] = ACTIONS(3993),
    [sym_internal_keyword] = ACTIONS(3993),
    [sym_protected_keyword] = ACTIONS(3993),
    [sym_key_keyword] = ACTIONS(4043),
    [sym_dataset_keyword] = ACTIONS(4043),
    [sym_quoted_identifier] = ACTIONS(6036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_string_literal] = ACTIONS(6036),
    [sym_integer] = ACTIONS(6036),
  },
  [STATE(5920)] = {
    [sym_identifier] = ACTIONS(9002),
    [anon_sym_SEMI] = ACTIONS(9004),
    [aux_sym_where_condition_token1] = ACTIONS(9002),
    [anon_sym_LBRACK] = ACTIONS(9004),
    [aux_sym_basic_type_token22] = ACTIONS(9002),
    [aux_sym_basic_type_token53] = ACTIONS(9002),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9002),
    [aux_sym_modify_modification_token1] = ACTIONS(9002),
    [aux_sym_separator_action_token1] = ACTIONS(9002),
    [aux_sym_xmlport_element_token1] = ACTIONS(9002),
    [aux_sym_xmlport_element_token2] = ACTIONS(9002),
    [aux_sym_xmlport_element_token3] = ACTIONS(9002),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9002),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9002),
    [aux_sym_type_declaration_token1] = ACTIONS(9002),
    [anon_sym_POUNDif] = ACTIONS(9004),
    [anon_sym_POUNDIF] = ACTIONS(9004),
    [anon_sym_POUNDIf] = ACTIONS(9004),
    [anon_sym_POUNDelif] = ACTIONS(9004),
    [anon_sym_POUNDELIF] = ACTIONS(9004),
    [anon_sym_POUNDElif] = ACTIONS(9004),
    [anon_sym_POUNDelse] = ACTIONS(9004),
    [anon_sym_POUNDELSE] = ACTIONS(9004),
    [anon_sym_POUNDElse] = ACTIONS(9004),
    [anon_sym_POUNDelse2] = ACTIONS(9004),
    [anon_sym_POUNDELSE2] = ACTIONS(9004),
    [anon_sym_POUNDElse2] = ACTIONS(9004),
    [anon_sym_POUNDendif] = ACTIONS(9004),
    [anon_sym_POUNDENDIF] = ACTIONS(9004),
    [anon_sym_POUNDEndif] = ACTIONS(9004),
    [anon_sym_POUNDendif2] = ACTIONS(9004),
    [anon_sym_POUNDENDIF2] = ACTIONS(9004),
    [anon_sym_POUNDEndif2] = ACTIONS(9004),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9002),
    [sym_procedure_keyword] = ACTIONS(9002),
    [sym_trigger_keyword] = ACTIONS(9002),
    [sym_var_keyword] = ACTIONS(9002),
    [sym_local_keyword] = ACTIONS(9002),
    [sym_internal_keyword] = ACTIONS(9002),
    [sym_protected_keyword] = ACTIONS(9002),
    [sym_event_keyword] = ACTIONS(9002),
    [sym_fields_keyword] = ACTIONS(9002),
    [sym_keys_keyword] = ACTIONS(9002),
    [sym_key_keyword] = ACTIONS(9002),
    [sym_fieldgroups_keyword] = ACTIONS(9002),
    [sym_actions_keyword] = ACTIONS(9002),
    [sym_layout_keyword] = ACTIONS(9002),
    [sym_dataset_keyword] = ACTIONS(9002),
    [sym_elements_keyword] = ACTIONS(9002),
    [sym_labels_keyword] = ACTIONS(9002),
    [sym_rendering_keyword] = ACTIONS(9002),
    [sym_requestpage_keyword] = ACTIONS(9002),
    [sym_schema_keyword] = ACTIONS(9002),
    [sym_views_keyword] = ACTIONS(9002),
    [sym_quoted_identifier] = ACTIONS(9004),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9004),
    [sym_preproc_open] = ACTIONS(9004),
    [sym_preproc_close] = ACTIONS(9004),
    [sym_var_attribute_open] = ACTIONS(9004),
  },
  [STATE(5921)] = {
    [sym_identifier] = ACTIONS(5961),
    [anon_sym_SEMI] = ACTIONS(5965),
    [aux_sym_where_condition_token1] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5965),
    [aux_sym_basic_type_token22] = ACTIONS(5961),
    [aux_sym_basic_type_token53] = ACTIONS(5961),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5961),
    [aux_sym_modify_modification_token1] = ACTIONS(5961),
    [aux_sym_separator_action_token1] = ACTIONS(5961),
    [aux_sym_xmlport_element_token1] = ACTIONS(5961),
    [aux_sym_xmlport_element_token2] = ACTIONS(5961),
    [aux_sym_xmlport_element_token3] = ACTIONS(5961),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5961),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5961),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5961),
    [aux_sym_type_declaration_token1] = ACTIONS(5961),
    [anon_sym_POUNDif] = ACTIONS(5965),
    [anon_sym_POUNDIF] = ACTIONS(5965),
    [anon_sym_POUNDIf] = ACTIONS(5965),
    [anon_sym_POUNDelif] = ACTIONS(5965),
    [anon_sym_POUNDELIF] = ACTIONS(5965),
    [anon_sym_POUNDElif] = ACTIONS(5965),
    [anon_sym_POUNDelse] = ACTIONS(5965),
    [anon_sym_POUNDELSE] = ACTIONS(5965),
    [anon_sym_POUNDElse] = ACTIONS(5965),
    [anon_sym_POUNDelse2] = ACTIONS(5965),
    [anon_sym_POUNDELSE2] = ACTIONS(5965),
    [anon_sym_POUNDElse2] = ACTIONS(5965),
    [anon_sym_POUNDendif] = ACTIONS(5965),
    [anon_sym_POUNDENDIF] = ACTIONS(5965),
    [anon_sym_POUNDEndif] = ACTIONS(5965),
    [anon_sym_POUNDendif2] = ACTIONS(5965),
    [anon_sym_POUNDENDIF2] = ACTIONS(5965),
    [anon_sym_POUNDEndif2] = ACTIONS(5965),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5961),
    [sym_procedure_keyword] = ACTIONS(5961),
    [sym_trigger_keyword] = ACTIONS(5961),
    [sym_var_keyword] = ACTIONS(5961),
    [sym_local_keyword] = ACTIONS(5961),
    [sym_internal_keyword] = ACTIONS(5961),
    [sym_protected_keyword] = ACTIONS(5961),
    [sym_event_keyword] = ACTIONS(5961),
    [sym_fields_keyword] = ACTIONS(5961),
    [sym_keys_keyword] = ACTIONS(5961),
    [sym_key_keyword] = ACTIONS(5961),
    [sym_fieldgroups_keyword] = ACTIONS(5961),
    [sym_actions_keyword] = ACTIONS(5961),
    [sym_layout_keyword] = ACTIONS(5961),
    [sym_dataset_keyword] = ACTIONS(5961),
    [sym_elements_keyword] = ACTIONS(5961),
    [sym_labels_keyword] = ACTIONS(5961),
    [sym_rendering_keyword] = ACTIONS(5961),
    [sym_requestpage_keyword] = ACTIONS(5961),
    [sym_schema_keyword] = ACTIONS(5961),
    [sym_views_keyword] = ACTIONS(5961),
    [sym_quoted_identifier] = ACTIONS(5965),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5965),
    [sym_preproc_open] = ACTIONS(5965),
    [sym_preproc_close] = ACTIONS(5965),
    [sym_var_attribute_open] = ACTIONS(5965),
  },
  [STATE(5922)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [aux_sym_where_condition_token1] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token53] = ACTIONS(5935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5935),
    [aux_sym_modify_modification_token1] = ACTIONS(5935),
    [aux_sym_separator_action_token1] = ACTIONS(5935),
    [aux_sym_xmlport_element_token1] = ACTIONS(5935),
    [aux_sym_xmlport_element_token2] = ACTIONS(5935),
    [aux_sym_xmlport_element_token3] = ACTIONS(5935),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5935),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5935),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5935),
    [aux_sym_type_declaration_token1] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5935),
    [sym_procedure_keyword] = ACTIONS(5935),
    [sym_trigger_keyword] = ACTIONS(5935),
    [sym_var_keyword] = ACTIONS(5935),
    [sym_local_keyword] = ACTIONS(5935),
    [sym_internal_keyword] = ACTIONS(5935),
    [sym_protected_keyword] = ACTIONS(5935),
    [sym_event_keyword] = ACTIONS(5935),
    [sym_fields_keyword] = ACTIONS(5935),
    [sym_keys_keyword] = ACTIONS(5935),
    [sym_key_keyword] = ACTIONS(5935),
    [sym_fieldgroups_keyword] = ACTIONS(5935),
    [sym_actions_keyword] = ACTIONS(5935),
    [sym_layout_keyword] = ACTIONS(5935),
    [sym_dataset_keyword] = ACTIONS(5935),
    [sym_elements_keyword] = ACTIONS(5935),
    [sym_labels_keyword] = ACTIONS(5935),
    [sym_rendering_keyword] = ACTIONS(5935),
    [sym_requestpage_keyword] = ACTIONS(5935),
    [sym_schema_keyword] = ACTIONS(5935),
    [sym_views_keyword] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
    [sym_var_attribute_open] = ACTIONS(5937),
  },
  [STATE(5923)] = {
    [sym_identifier] = ACTIONS(5935),
    [anon_sym_SEMI] = ACTIONS(5937),
    [aux_sym_where_condition_token1] = ACTIONS(5935),
    [anon_sym_LBRACK] = ACTIONS(5937),
    [aux_sym_basic_type_token22] = ACTIONS(5935),
    [aux_sym_basic_type_token53] = ACTIONS(5935),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(5935),
    [aux_sym_modify_modification_token1] = ACTIONS(5935),
    [aux_sym_separator_action_token1] = ACTIONS(5935),
    [aux_sym_xmlport_element_token1] = ACTIONS(5935),
    [aux_sym_xmlport_element_token2] = ACTIONS(5935),
    [aux_sym_xmlport_element_token3] = ACTIONS(5935),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(5935),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(5935),
    [aux_sym_assembly_declaration_token1] = ACTIONS(5935),
    [aux_sym_type_declaration_token1] = ACTIONS(5935),
    [anon_sym_POUNDif] = ACTIONS(5937),
    [anon_sym_POUNDIF] = ACTIONS(5937),
    [anon_sym_POUNDIf] = ACTIONS(5937),
    [anon_sym_POUNDelif] = ACTIONS(5937),
    [anon_sym_POUNDELIF] = ACTIONS(5937),
    [anon_sym_POUNDElif] = ACTIONS(5937),
    [anon_sym_POUNDelse] = ACTIONS(5937),
    [anon_sym_POUNDELSE] = ACTIONS(5937),
    [anon_sym_POUNDElse] = ACTIONS(5937),
    [anon_sym_POUNDelse2] = ACTIONS(5937),
    [anon_sym_POUNDELSE2] = ACTIONS(5937),
    [anon_sym_POUNDElse2] = ACTIONS(5937),
    [anon_sym_POUNDendif] = ACTIONS(5937),
    [anon_sym_POUNDENDIF] = ACTIONS(5937),
    [anon_sym_POUNDEndif] = ACTIONS(5937),
    [anon_sym_POUNDendif2] = ACTIONS(5937),
    [anon_sym_POUNDENDIF2] = ACTIONS(5937),
    [anon_sym_POUNDEndif2] = ACTIONS(5937),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(5935),
    [sym_procedure_keyword] = ACTIONS(5935),
    [sym_trigger_keyword] = ACTIONS(5935),
    [sym_var_keyword] = ACTIONS(5935),
    [sym_local_keyword] = ACTIONS(5935),
    [sym_internal_keyword] = ACTIONS(5935),
    [sym_protected_keyword] = ACTIONS(5935),
    [sym_event_keyword] = ACTIONS(5935),
    [sym_fields_keyword] = ACTIONS(5935),
    [sym_keys_keyword] = ACTIONS(5935),
    [sym_key_keyword] = ACTIONS(5935),
    [sym_fieldgroups_keyword] = ACTIONS(5935),
    [sym_actions_keyword] = ACTIONS(5935),
    [sym_layout_keyword] = ACTIONS(5935),
    [sym_dataset_keyword] = ACTIONS(5935),
    [sym_elements_keyword] = ACTIONS(5935),
    [sym_labels_keyword] = ACTIONS(5935),
    [sym_rendering_keyword] = ACTIONS(5935),
    [sym_requestpage_keyword] = ACTIONS(5935),
    [sym_schema_keyword] = ACTIONS(5935),
    [sym_views_keyword] = ACTIONS(5935),
    [sym_quoted_identifier] = ACTIONS(5937),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(5937),
    [sym_preproc_open] = ACTIONS(5937),
    [sym_preproc_close] = ACTIONS(5937),
    [sym_var_attribute_open] = ACTIONS(5937),
  },
  [STATE(5924)] = {
    [sym_identifier] = ACTIONS(6136),
    [anon_sym_SEMI] = ACTIONS(6138),
    [aux_sym_where_condition_token1] = ACTIONS(6136),
    [anon_sym_LBRACK] = ACTIONS(6138),
    [aux_sym_basic_type_token22] = ACTIONS(6136),
    [aux_sym_basic_type_token53] = ACTIONS(6136),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6136),
    [aux_sym_modify_modification_token1] = ACTIONS(6136),
    [aux_sym_separator_action_token1] = ACTIONS(6136),
    [aux_sym_xmlport_element_token1] = ACTIONS(6136),
    [aux_sym_xmlport_element_token2] = ACTIONS(6136),
    [aux_sym_xmlport_element_token3] = ACTIONS(6136),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6136),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6136),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6136),
    [aux_sym_type_declaration_token1] = ACTIONS(6136),
    [anon_sym_POUNDif] = ACTIONS(6138),
    [anon_sym_POUNDIF] = ACTIONS(6138),
    [anon_sym_POUNDIf] = ACTIONS(6138),
    [anon_sym_POUNDelif] = ACTIONS(6138),
    [anon_sym_POUNDELIF] = ACTIONS(6138),
    [anon_sym_POUNDElif] = ACTIONS(6138),
    [anon_sym_POUNDelse] = ACTIONS(6138),
    [anon_sym_POUNDELSE] = ACTIONS(6138),
    [anon_sym_POUNDElse] = ACTIONS(6138),
    [anon_sym_POUNDelse2] = ACTIONS(6138),
    [anon_sym_POUNDELSE2] = ACTIONS(6138),
    [anon_sym_POUNDElse2] = ACTIONS(6138),
    [anon_sym_POUNDendif] = ACTIONS(6138),
    [anon_sym_POUNDENDIF] = ACTIONS(6138),
    [anon_sym_POUNDEndif] = ACTIONS(6138),
    [anon_sym_POUNDendif2] = ACTIONS(6138),
    [anon_sym_POUNDENDIF2] = ACTIONS(6138),
    [anon_sym_POUNDEndif2] = ACTIONS(6138),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6136),
    [sym_procedure_keyword] = ACTIONS(6136),
    [sym_trigger_keyword] = ACTIONS(6136),
    [sym_var_keyword] = ACTIONS(6136),
    [sym_local_keyword] = ACTIONS(6136),
    [sym_internal_keyword] = ACTIONS(6136),
    [sym_protected_keyword] = ACTIONS(6136),
    [sym_event_keyword] = ACTIONS(6136),
    [sym_fields_keyword] = ACTIONS(6136),
    [sym_keys_keyword] = ACTIONS(6136),
    [sym_key_keyword] = ACTIONS(6136),
    [sym_fieldgroups_keyword] = ACTIONS(6136),
    [sym_actions_keyword] = ACTIONS(6136),
    [sym_layout_keyword] = ACTIONS(6136),
    [sym_dataset_keyword] = ACTIONS(6136),
    [sym_elements_keyword] = ACTIONS(6136),
    [sym_labels_keyword] = ACTIONS(6136),
    [sym_rendering_keyword] = ACTIONS(6136),
    [sym_requestpage_keyword] = ACTIONS(6136),
    [sym_schema_keyword] = ACTIONS(6136),
    [sym_views_keyword] = ACTIONS(6136),
    [sym_quoted_identifier] = ACTIONS(6138),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6138),
    [sym_preproc_open] = ACTIONS(6138),
    [sym_preproc_close] = ACTIONS(6138),
    [sym_var_attribute_open] = ACTIONS(6138),
  },
  [STATE(5925)] = {
    [sym_identifier] = ACTIONS(8885),
    [anon_sym_SEMI] = ACTIONS(8887),
    [aux_sym_where_condition_token1] = ACTIONS(8885),
    [anon_sym_LBRACK] = ACTIONS(8887),
    [aux_sym_basic_type_token22] = ACTIONS(8885),
    [aux_sym_basic_type_token53] = ACTIONS(8885),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8885),
    [aux_sym_modify_modification_token1] = ACTIONS(8885),
    [aux_sym_separator_action_token1] = ACTIONS(8885),
    [aux_sym_xmlport_element_token1] = ACTIONS(8885),
    [aux_sym_xmlport_element_token2] = ACTIONS(8885),
    [aux_sym_xmlport_element_token3] = ACTIONS(8885),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8885),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8885),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8885),
    [aux_sym_type_declaration_token1] = ACTIONS(8885),
    [anon_sym_POUNDif] = ACTIONS(8887),
    [anon_sym_POUNDIF] = ACTIONS(8887),
    [anon_sym_POUNDIf] = ACTIONS(8887),
    [anon_sym_POUNDelif] = ACTIONS(8887),
    [anon_sym_POUNDELIF] = ACTIONS(8887),
    [anon_sym_POUNDElif] = ACTIONS(8887),
    [anon_sym_POUNDelse] = ACTIONS(8887),
    [anon_sym_POUNDELSE] = ACTIONS(8887),
    [anon_sym_POUNDElse] = ACTIONS(8887),
    [anon_sym_POUNDelse2] = ACTIONS(8887),
    [anon_sym_POUNDELSE2] = ACTIONS(8887),
    [anon_sym_POUNDElse2] = ACTIONS(8887),
    [anon_sym_POUNDendif] = ACTIONS(8887),
    [anon_sym_POUNDENDIF] = ACTIONS(8887),
    [anon_sym_POUNDEndif] = ACTIONS(8887),
    [anon_sym_POUNDendif2] = ACTIONS(8887),
    [anon_sym_POUNDENDIF2] = ACTIONS(8887),
    [anon_sym_POUNDEndif2] = ACTIONS(8887),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8885),
    [sym_procedure_keyword] = ACTIONS(8885),
    [sym_trigger_keyword] = ACTIONS(8885),
    [sym_var_keyword] = ACTIONS(8885),
    [sym_local_keyword] = ACTIONS(8885),
    [sym_internal_keyword] = ACTIONS(8885),
    [sym_protected_keyword] = ACTIONS(8885),
    [sym_event_keyword] = ACTIONS(8885),
    [sym_fields_keyword] = ACTIONS(8885),
    [sym_keys_keyword] = ACTIONS(8885),
    [sym_key_keyword] = ACTIONS(8885),
    [sym_fieldgroups_keyword] = ACTIONS(8885),
    [sym_actions_keyword] = ACTIONS(8885),
    [sym_layout_keyword] = ACTIONS(8885),
    [sym_dataset_keyword] = ACTIONS(8885),
    [sym_elements_keyword] = ACTIONS(8885),
    [sym_labels_keyword] = ACTIONS(8885),
    [sym_rendering_keyword] = ACTIONS(8885),
    [sym_requestpage_keyword] = ACTIONS(8885),
    [sym_schema_keyword] = ACTIONS(8885),
    [sym_views_keyword] = ACTIONS(8885),
    [sym_quoted_identifier] = ACTIONS(8887),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8887),
    [sym_preproc_open] = ACTIONS(8887),
    [sym_preproc_close] = ACTIONS(8887),
    [sym_var_attribute_open] = ACTIONS(8887),
  },
  [STATE(5926)] = {
    [sym_identifier] = ACTIONS(9002),
    [anon_sym_SEMI] = ACTIONS(9004),
    [aux_sym_where_condition_token1] = ACTIONS(9002),
    [anon_sym_LBRACK] = ACTIONS(9004),
    [aux_sym_basic_type_token22] = ACTIONS(9002),
    [aux_sym_basic_type_token53] = ACTIONS(9002),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9002),
    [aux_sym_modify_modification_token1] = ACTIONS(9002),
    [aux_sym_separator_action_token1] = ACTIONS(9002),
    [aux_sym_xmlport_element_token1] = ACTIONS(9002),
    [aux_sym_xmlport_element_token2] = ACTIONS(9002),
    [aux_sym_xmlport_element_token3] = ACTIONS(9002),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9002),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9002),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9002),
    [aux_sym_type_declaration_token1] = ACTIONS(9002),
    [anon_sym_POUNDif] = ACTIONS(9004),
    [anon_sym_POUNDIF] = ACTIONS(9004),
    [anon_sym_POUNDIf] = ACTIONS(9004),
    [anon_sym_POUNDelif] = ACTIONS(9004),
    [anon_sym_POUNDELIF] = ACTIONS(9004),
    [anon_sym_POUNDElif] = ACTIONS(9004),
    [anon_sym_POUNDelse] = ACTIONS(9004),
    [anon_sym_POUNDELSE] = ACTIONS(9004),
    [anon_sym_POUNDElse] = ACTIONS(9004),
    [anon_sym_POUNDelse2] = ACTIONS(9004),
    [anon_sym_POUNDELSE2] = ACTIONS(9004),
    [anon_sym_POUNDElse2] = ACTIONS(9004),
    [anon_sym_POUNDendif] = ACTIONS(9004),
    [anon_sym_POUNDENDIF] = ACTIONS(9004),
    [anon_sym_POUNDEndif] = ACTIONS(9004),
    [anon_sym_POUNDendif2] = ACTIONS(9004),
    [anon_sym_POUNDENDIF2] = ACTIONS(9004),
    [anon_sym_POUNDEndif2] = ACTIONS(9004),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9002),
    [sym_procedure_keyword] = ACTIONS(9002),
    [sym_trigger_keyword] = ACTIONS(9002),
    [sym_var_keyword] = ACTIONS(9002),
    [sym_local_keyword] = ACTIONS(9002),
    [sym_internal_keyword] = ACTIONS(9002),
    [sym_protected_keyword] = ACTIONS(9002),
    [sym_event_keyword] = ACTIONS(9002),
    [sym_fields_keyword] = ACTIONS(9002),
    [sym_keys_keyword] = ACTIONS(9002),
    [sym_key_keyword] = ACTIONS(9002),
    [sym_fieldgroups_keyword] = ACTIONS(9002),
    [sym_actions_keyword] = ACTIONS(9002),
    [sym_layout_keyword] = ACTIONS(9002),
    [sym_dataset_keyword] = ACTIONS(9002),
    [sym_elements_keyword] = ACTIONS(9002),
    [sym_labels_keyword] = ACTIONS(9002),
    [sym_rendering_keyword] = ACTIONS(9002),
    [sym_requestpage_keyword] = ACTIONS(9002),
    [sym_schema_keyword] = ACTIONS(9002),
    [sym_views_keyword] = ACTIONS(9002),
    [sym_quoted_identifier] = ACTIONS(9004),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9004),
    [sym_preproc_open] = ACTIONS(9004),
    [sym_preproc_close] = ACTIONS(9004),
    [sym_var_attribute_open] = ACTIONS(9004),
  },
  [STATE(5927)] = {
    [sym_identifier] = ACTIONS(8889),
    [anon_sym_SEMI] = ACTIONS(8891),
    [aux_sym_where_condition_token1] = ACTIONS(8889),
    [anon_sym_LBRACK] = ACTIONS(8891),
    [aux_sym_basic_type_token22] = ACTIONS(8889),
    [aux_sym_basic_type_token53] = ACTIONS(8889),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8889),
    [aux_sym_modify_modification_token1] = ACTIONS(8889),
    [aux_sym_separator_action_token1] = ACTIONS(8889),
    [aux_sym_xmlport_element_token1] = ACTIONS(8889),
    [aux_sym_xmlport_element_token2] = ACTIONS(8889),
    [aux_sym_xmlport_element_token3] = ACTIONS(8889),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8889),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8889),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8889),
    [aux_sym_type_declaration_token1] = ACTIONS(8889),
    [anon_sym_POUNDif] = ACTIONS(8891),
    [anon_sym_POUNDIF] = ACTIONS(8891),
    [anon_sym_POUNDIf] = ACTIONS(8891),
    [anon_sym_POUNDelif] = ACTIONS(8891),
    [anon_sym_POUNDELIF] = ACTIONS(8891),
    [anon_sym_POUNDElif] = ACTIONS(8891),
    [anon_sym_POUNDelse] = ACTIONS(8891),
    [anon_sym_POUNDELSE] = ACTIONS(8891),
    [anon_sym_POUNDElse] = ACTIONS(8891),
    [anon_sym_POUNDelse2] = ACTIONS(8891),
    [anon_sym_POUNDELSE2] = ACTIONS(8891),
    [anon_sym_POUNDElse2] = ACTIONS(8891),
    [anon_sym_POUNDendif] = ACTIONS(8891),
    [anon_sym_POUNDENDIF] = ACTIONS(8891),
    [anon_sym_POUNDEndif] = ACTIONS(8891),
    [anon_sym_POUNDendif2] = ACTIONS(8891),
    [anon_sym_POUNDENDIF2] = ACTIONS(8891),
    [anon_sym_POUNDEndif2] = ACTIONS(8891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8889),
    [sym_procedure_keyword] = ACTIONS(8889),
    [sym_trigger_keyword] = ACTIONS(8889),
    [sym_var_keyword] = ACTIONS(8889),
    [sym_local_keyword] = ACTIONS(8889),
    [sym_internal_keyword] = ACTIONS(8889),
    [sym_protected_keyword] = ACTIONS(8889),
    [sym_event_keyword] = ACTIONS(8889),
    [sym_fields_keyword] = ACTIONS(8889),
    [sym_keys_keyword] = ACTIONS(8889),
    [sym_key_keyword] = ACTIONS(8889),
    [sym_fieldgroups_keyword] = ACTIONS(8889),
    [sym_actions_keyword] = ACTIONS(8889),
    [sym_layout_keyword] = ACTIONS(8889),
    [sym_dataset_keyword] = ACTIONS(8889),
    [sym_elements_keyword] = ACTIONS(8889),
    [sym_labels_keyword] = ACTIONS(8889),
    [sym_rendering_keyword] = ACTIONS(8889),
    [sym_requestpage_keyword] = ACTIONS(8889),
    [sym_schema_keyword] = ACTIONS(8889),
    [sym_views_keyword] = ACTIONS(8889),
    [sym_quoted_identifier] = ACTIONS(8891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8891),
    [sym_preproc_open] = ACTIONS(8891),
    [sym_preproc_close] = ACTIONS(8891),
    [sym_var_attribute_open] = ACTIONS(8891),
  },
  [STATE(5928)] = {
    [sym_identifier] = ACTIONS(6140),
    [anon_sym_SEMI] = ACTIONS(6142),
    [aux_sym_where_condition_token1] = ACTIONS(6140),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [aux_sym_basic_type_token22] = ACTIONS(6140),
    [aux_sym_basic_type_token53] = ACTIONS(6140),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6140),
    [aux_sym_modify_modification_token1] = ACTIONS(6140),
    [aux_sym_separator_action_token1] = ACTIONS(6140),
    [aux_sym_xmlport_element_token1] = ACTIONS(6140),
    [aux_sym_xmlport_element_token2] = ACTIONS(6140),
    [aux_sym_xmlport_element_token3] = ACTIONS(6140),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6140),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6140),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6140),
    [aux_sym_type_declaration_token1] = ACTIONS(6140),
    [anon_sym_POUNDif] = ACTIONS(6142),
    [anon_sym_POUNDIF] = ACTIONS(6142),
    [anon_sym_POUNDIf] = ACTIONS(6142),
    [anon_sym_POUNDelif] = ACTIONS(6142),
    [anon_sym_POUNDELIF] = ACTIONS(6142),
    [anon_sym_POUNDElif] = ACTIONS(6142),
    [anon_sym_POUNDelse] = ACTIONS(6142),
    [anon_sym_POUNDELSE] = ACTIONS(6142),
    [anon_sym_POUNDElse] = ACTIONS(6142),
    [anon_sym_POUNDelse2] = ACTIONS(6142),
    [anon_sym_POUNDELSE2] = ACTIONS(6142),
    [anon_sym_POUNDElse2] = ACTIONS(6142),
    [anon_sym_POUNDendif] = ACTIONS(6142),
    [anon_sym_POUNDENDIF] = ACTIONS(6142),
    [anon_sym_POUNDEndif] = ACTIONS(6142),
    [anon_sym_POUNDendif2] = ACTIONS(6142),
    [anon_sym_POUNDENDIF2] = ACTIONS(6142),
    [anon_sym_POUNDEndif2] = ACTIONS(6142),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6140),
    [sym_procedure_keyword] = ACTIONS(6140),
    [sym_trigger_keyword] = ACTIONS(6140),
    [sym_var_keyword] = ACTIONS(6140),
    [sym_local_keyword] = ACTIONS(6140),
    [sym_internal_keyword] = ACTIONS(6140),
    [sym_protected_keyword] = ACTIONS(6140),
    [sym_event_keyword] = ACTIONS(6140),
    [sym_fields_keyword] = ACTIONS(6140),
    [sym_keys_keyword] = ACTIONS(6140),
    [sym_key_keyword] = ACTIONS(6140),
    [sym_fieldgroups_keyword] = ACTIONS(6140),
    [sym_actions_keyword] = ACTIONS(6140),
    [sym_layout_keyword] = ACTIONS(6140),
    [sym_dataset_keyword] = ACTIONS(6140),
    [sym_elements_keyword] = ACTIONS(6140),
    [sym_labels_keyword] = ACTIONS(6140),
    [sym_rendering_keyword] = ACTIONS(6140),
    [sym_requestpage_keyword] = ACTIONS(6140),
    [sym_schema_keyword] = ACTIONS(6140),
    [sym_views_keyword] = ACTIONS(6140),
    [sym_quoted_identifier] = ACTIONS(6142),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6142),
    [sym_preproc_open] = ACTIONS(6142),
    [sym_preproc_close] = ACTIONS(6142),
    [sym_var_attribute_open] = ACTIONS(6142),
  },
  [STATE(5929)] = {
    [sym_identifier] = ACTIONS(8889),
    [anon_sym_SEMI] = ACTIONS(8891),
    [aux_sym_where_condition_token1] = ACTIONS(8889),
    [anon_sym_LBRACK] = ACTIONS(8891),
    [aux_sym_basic_type_token22] = ACTIONS(8889),
    [aux_sym_basic_type_token53] = ACTIONS(8889),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8889),
    [aux_sym_modify_modification_token1] = ACTIONS(8889),
    [aux_sym_separator_action_token1] = ACTIONS(8889),
    [aux_sym_xmlport_element_token1] = ACTIONS(8889),
    [aux_sym_xmlport_element_token2] = ACTIONS(8889),
    [aux_sym_xmlport_element_token3] = ACTIONS(8889),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8889),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8889),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8889),
    [aux_sym_type_declaration_token1] = ACTIONS(8889),
    [anon_sym_POUNDif] = ACTIONS(8891),
    [anon_sym_POUNDIF] = ACTIONS(8891),
    [anon_sym_POUNDIf] = ACTIONS(8891),
    [anon_sym_POUNDelif] = ACTIONS(8891),
    [anon_sym_POUNDELIF] = ACTIONS(8891),
    [anon_sym_POUNDElif] = ACTIONS(8891),
    [anon_sym_POUNDelse] = ACTIONS(8891),
    [anon_sym_POUNDELSE] = ACTIONS(8891),
    [anon_sym_POUNDElse] = ACTIONS(8891),
    [anon_sym_POUNDelse2] = ACTIONS(8891),
    [anon_sym_POUNDELSE2] = ACTIONS(8891),
    [anon_sym_POUNDElse2] = ACTIONS(8891),
    [anon_sym_POUNDendif] = ACTIONS(8891),
    [anon_sym_POUNDENDIF] = ACTIONS(8891),
    [anon_sym_POUNDEndif] = ACTIONS(8891),
    [anon_sym_POUNDendif2] = ACTIONS(8891),
    [anon_sym_POUNDENDIF2] = ACTIONS(8891),
    [anon_sym_POUNDEndif2] = ACTIONS(8891),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8889),
    [sym_procedure_keyword] = ACTIONS(8889),
    [sym_trigger_keyword] = ACTIONS(8889),
    [sym_var_keyword] = ACTIONS(8889),
    [sym_local_keyword] = ACTIONS(8889),
    [sym_internal_keyword] = ACTIONS(8889),
    [sym_protected_keyword] = ACTIONS(8889),
    [sym_event_keyword] = ACTIONS(8889),
    [sym_fields_keyword] = ACTIONS(8889),
    [sym_keys_keyword] = ACTIONS(8889),
    [sym_key_keyword] = ACTIONS(8889),
    [sym_fieldgroups_keyword] = ACTIONS(8889),
    [sym_actions_keyword] = ACTIONS(8889),
    [sym_layout_keyword] = ACTIONS(8889),
    [sym_dataset_keyword] = ACTIONS(8889),
    [sym_elements_keyword] = ACTIONS(8889),
    [sym_labels_keyword] = ACTIONS(8889),
    [sym_rendering_keyword] = ACTIONS(8889),
    [sym_requestpage_keyword] = ACTIONS(8889),
    [sym_schema_keyword] = ACTIONS(8889),
    [sym_views_keyword] = ACTIONS(8889),
    [sym_quoted_identifier] = ACTIONS(8891),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8891),
    [sym_preproc_open] = ACTIONS(8891),
    [sym_preproc_close] = ACTIONS(8891),
    [sym_var_attribute_open] = ACTIONS(8891),
  },
  [STATE(5930)] = {
    [sym_identifier] = ACTIONS(6144),
    [anon_sym_SEMI] = ACTIONS(6146),
    [aux_sym_where_condition_token1] = ACTIONS(6144),
    [anon_sym_LBRACK] = ACTIONS(6146),
    [aux_sym_basic_type_token22] = ACTIONS(6144),
    [aux_sym_basic_type_token53] = ACTIONS(6144),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(6144),
    [aux_sym_modify_modification_token1] = ACTIONS(6144),
    [aux_sym_separator_action_token1] = ACTIONS(6144),
    [aux_sym_xmlport_element_token1] = ACTIONS(6144),
    [aux_sym_xmlport_element_token2] = ACTIONS(6144),
    [aux_sym_xmlport_element_token3] = ACTIONS(6144),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(6144),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(6144),
    [aux_sym_assembly_declaration_token1] = ACTIONS(6144),
    [aux_sym_type_declaration_token1] = ACTIONS(6144),
    [anon_sym_POUNDif] = ACTIONS(6146),
    [anon_sym_POUNDIF] = ACTIONS(6146),
    [anon_sym_POUNDIf] = ACTIONS(6146),
    [anon_sym_POUNDelif] = ACTIONS(6146),
    [anon_sym_POUNDELIF] = ACTIONS(6146),
    [anon_sym_POUNDElif] = ACTIONS(6146),
    [anon_sym_POUNDelse] = ACTIONS(6146),
    [anon_sym_POUNDELSE] = ACTIONS(6146),
    [anon_sym_POUNDElse] = ACTIONS(6146),
    [anon_sym_POUNDelse2] = ACTIONS(6146),
    [anon_sym_POUNDELSE2] = ACTIONS(6146),
    [anon_sym_POUNDElse2] = ACTIONS(6146),
    [anon_sym_POUNDendif] = ACTIONS(6146),
    [anon_sym_POUNDENDIF] = ACTIONS(6146),
    [anon_sym_POUNDEndif] = ACTIONS(6146),
    [anon_sym_POUNDendif2] = ACTIONS(6146),
    [anon_sym_POUNDENDIF2] = ACTIONS(6146),
    [anon_sym_POUNDEndif2] = ACTIONS(6146),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(6144),
    [sym_procedure_keyword] = ACTIONS(6144),
    [sym_trigger_keyword] = ACTIONS(6144),
    [sym_var_keyword] = ACTIONS(6144),
    [sym_local_keyword] = ACTIONS(6144),
    [sym_internal_keyword] = ACTIONS(6144),
    [sym_protected_keyword] = ACTIONS(6144),
    [sym_event_keyword] = ACTIONS(6144),
    [sym_fields_keyword] = ACTIONS(6144),
    [sym_keys_keyword] = ACTIONS(6144),
    [sym_key_keyword] = ACTIONS(6144),
    [sym_fieldgroups_keyword] = ACTIONS(6144),
    [sym_actions_keyword] = ACTIONS(6144),
    [sym_layout_keyword] = ACTIONS(6144),
    [sym_dataset_keyword] = ACTIONS(6144),
    [sym_elements_keyword] = ACTIONS(6144),
    [sym_labels_keyword] = ACTIONS(6144),
    [sym_rendering_keyword] = ACTIONS(6144),
    [sym_requestpage_keyword] = ACTIONS(6144),
    [sym_schema_keyword] = ACTIONS(6144),
    [sym_views_keyword] = ACTIONS(6144),
    [sym_quoted_identifier] = ACTIONS(6146),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(6146),
    [sym_preproc_open] = ACTIONS(6146),
    [sym_preproc_close] = ACTIONS(6146),
    [sym_var_attribute_open] = ACTIONS(6146),
  },
  [STATE(5931)] = {
    [sym_identifier] = ACTIONS(8893),
    [anon_sym_SEMI] = ACTIONS(8895),
    [aux_sym_where_condition_token1] = ACTIONS(8893),
    [anon_sym_LBRACK] = ACTIONS(8895),
    [aux_sym_basic_type_token22] = ACTIONS(8893),
    [aux_sym_basic_type_token53] = ACTIONS(8893),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(8893),
    [aux_sym_modify_modification_token1] = ACTIONS(8893),
    [aux_sym_separator_action_token1] = ACTIONS(8893),
    [aux_sym_xmlport_element_token1] = ACTIONS(8893),
    [aux_sym_xmlport_element_token2] = ACTIONS(8893),
    [aux_sym_xmlport_element_token3] = ACTIONS(8893),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(8893),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(8893),
    [aux_sym_assembly_declaration_token1] = ACTIONS(8893),
    [aux_sym_type_declaration_token1] = ACTIONS(8893),
    [anon_sym_POUNDif] = ACTIONS(8895),
    [anon_sym_POUNDIF] = ACTIONS(8895),
    [anon_sym_POUNDIf] = ACTIONS(8895),
    [anon_sym_POUNDelif] = ACTIONS(8895),
    [anon_sym_POUNDELIF] = ACTIONS(8895),
    [anon_sym_POUNDElif] = ACTIONS(8895),
    [anon_sym_POUNDelse] = ACTIONS(8895),
    [anon_sym_POUNDELSE] = ACTIONS(8895),
    [anon_sym_POUNDElse] = ACTIONS(8895),
    [anon_sym_POUNDelse2] = ACTIONS(8895),
    [anon_sym_POUNDELSE2] = ACTIONS(8895),
    [anon_sym_POUNDElse2] = ACTIONS(8895),
    [anon_sym_POUNDendif] = ACTIONS(8895),
    [anon_sym_POUNDENDIF] = ACTIONS(8895),
    [anon_sym_POUNDEndif] = ACTIONS(8895),
    [anon_sym_POUNDendif2] = ACTIONS(8895),
    [anon_sym_POUNDENDIF2] = ACTIONS(8895),
    [anon_sym_POUNDEndif2] = ACTIONS(8895),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(8893),
    [sym_procedure_keyword] = ACTIONS(8893),
    [sym_trigger_keyword] = ACTIONS(8893),
    [sym_var_keyword] = ACTIONS(8893),
    [sym_local_keyword] = ACTIONS(8893),
    [sym_internal_keyword] = ACTIONS(8893),
    [sym_protected_keyword] = ACTIONS(8893),
    [sym_event_keyword] = ACTIONS(8893),
    [sym_fields_keyword] = ACTIONS(8893),
    [sym_keys_keyword] = ACTIONS(8893),
    [sym_key_keyword] = ACTIONS(8893),
    [sym_fieldgroups_keyword] = ACTIONS(8893),
    [sym_actions_keyword] = ACTIONS(8893),
    [sym_layout_keyword] = ACTIONS(8893),
    [sym_dataset_keyword] = ACTIONS(8893),
    [sym_elements_keyword] = ACTIONS(8893),
    [sym_labels_keyword] = ACTIONS(8893),
    [sym_rendering_keyword] = ACTIONS(8893),
    [sym_requestpage_keyword] = ACTIONS(8893),
    [sym_schema_keyword] = ACTIONS(8893),
    [sym_views_keyword] = ACTIONS(8893),
    [sym_quoted_identifier] = ACTIONS(8895),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(8895),
    [sym_preproc_open] = ACTIONS(8895),
    [sym_preproc_close] = ACTIONS(8895),
    [sym_var_attribute_open] = ACTIONS(8895),
  },
  [STATE(5932)] = {
    [sym_identifier] = ACTIONS(9034),
    [anon_sym_SEMI] = ACTIONS(9036),
    [aux_sym_where_condition_token1] = ACTIONS(9034),
    [anon_sym_LBRACK] = ACTIONS(9036),
    [aux_sym_basic_type_token22] = ACTIONS(9034),
    [aux_sym_basic_type_token53] = ACTIONS(9034),
    [aux_sym_enum_value_declaration_token1] = ACTIONS(9034),
    [aux_sym_modify_modification_token1] = ACTIONS(9034),
    [aux_sym_separator_action_token1] = ACTIONS(9034),
    [aux_sym_xmlport_element_token1] = ACTIONS(9034),
    [aux_sym_xmlport_element_token2] = ACTIONS(9034),
    [aux_sym_xmlport_element_token3] = ACTIONS(9034),
    [aux_sym_xmlport_attribute_token1] = ACTIONS(9034),
    [aux_sym_xmlport_attribute_token2] = ACTIONS(9034),
    [aux_sym_assembly_declaration_token1] = ACTIONS(9034),
    [aux_sym_type_declaration_token1] = ACTIONS(9034),
    [anon_sym_POUNDif] = ACTIONS(9036),
    [anon_sym_POUNDIF] = ACTIONS(9036),
    [anon_sym_POUNDIf] = ACTIONS(9036),
    [anon_sym_POUNDelif] = ACTIONS(9036),
    [anon_sym_POUNDELIF] = ACTIONS(9036),
    [anon_sym_POUNDElif] = ACTIONS(9036),
    [anon_sym_POUNDelse] = ACTIONS(9036),
    [anon_sym_POUNDELSE] = ACTIONS(9036),
    [anon_sym_POUNDElse] = ACTIONS(9036),
    [anon_sym_POUNDelse2] = ACTIONS(9036),
    [anon_sym_POUNDELSE2] = ACTIONS(9036),
    [anon_sym_POUNDElse2] = ACTIONS(9036),
    [anon_sym_POUNDendif] = ACTIONS(9036),
    [anon_sym_POUNDENDIF] = ACTIONS(9036),
    [anon_sym_POUNDEndif] = ACTIONS(9036),
    [anon_sym_POUNDendif2] = ACTIONS(9036),
    [anon_sym_POUNDENDIF2] = ACTIONS(9036),
    [anon_sym_POUNDEndif2] = ACTIONS(9036),
    [sym_pragma] = ACTIONS(3),
    [sym_preproc_region] = ACTIONS(3),
    [sym_preproc_endregion] = ACTIONS(3),
    [sym_table_keyword] = ACTIONS(9034),
    [sym_procedure_keyword] = ACTIONS(9034),
    [sym_trigger_keyword] = ACTIONS(9034),
    [sym_var_keyword] = ACTIONS(9034),
    [sym_local_keyword] = ACTIONS(9034),
    [sym_internal_keyword] = ACTIONS(9034),
    [sym_protected_keyword] = ACTIONS(9034),
    [sym_event_keyword] = ACTIONS(9034),
    [sym_fields_keyword] = ACTIONS(9034),
    [sym_keys_keyword] = ACTIONS(9034),
    [sym_key_keyword] = ACTIONS(9034),
    [sym_fieldgroups_keyword] = ACTIONS(9034),
    [sym_actions_keyword] = ACTIONS(9034),
    [sym_layout_keyword] = ACTIONS(9034),
    [sym_dataset_keyword] = ACTIONS(9034),
    [sym_elements_keyword] = ACTIONS(9034),
    [sym_labels_keyword] = ACTIONS(9034),
    [sym_rendering_keyword] = ACTIONS(9034),
    [sym_requestpage_keyword] = ACTIONS(9034),
    [sym_schema_keyword] = ACTIONS(9034),
    [sym_views_keyword] = ACTIONS(9034),
    [sym_quoted_identifier] = ACTIONS(9036),
    [sym_comment] = ACTIONS(3),
    [sym_multiline_comment] = ACTIONS(3),
    [sym_property_name] = ACTIONS(9036),
    [sym_preproc_open] = ACTIONS(9036),
    [sym_preproc_close] = ACTIONS(9036),
    [sym_var_attribute_open] = ACTIONS(9036),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(14487), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(14489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5380), 26,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PIPE_PIPE,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(5378), 31,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_or_expression_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75] = 9,
    ACTIONS(7733), 1,
      sym_table_keyword,
    ACTIONS(7737), 1,
      sym_quoted_identifier,
    ACTIONS(7720), 3,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_dataset_keyword,
    ACTIONS(7730), 3,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7715), 5,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(7712), 7,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_identifier,
    ACTIONS(7725), 17,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(7727), 22,
      aux_sym_modify_modification_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [158] = 17,
    ACTIONS(6034), 1,
      aux_sym_basic_type_token22,
    ACTIONS(14485), 1,
      anon_sym_DASH,
    ACTIONS(14491), 1,
      anon_sym_COMMA,
    STATE(7190), 1,
      aux_sym_option_member_list_repeat2,
    STATE(14991), 1,
      sym_option_member,
    ACTIONS(1376), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(600), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(6036), 3,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    STATE(6858), 3,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
      sym_enum_keyword,
    STATE(7226), 3,
      sym_boolean,
      sym_keyword_identifier,
      sym_keyword_as_identifier,
    ACTIONS(3993), 4,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(27), 6,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
    ACTIONS(1400), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(1402), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(1382), 9,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token48,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(4043), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
  [257] = 3,
    ACTIONS(12206), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12204), 56,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [328] = 5,
    ACTIONS(14493), 1,
      anon_sym_DOT,
    STATE(5938), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3695), 26,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(3693), 31,
      aux_sym_where_condition_token1,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [403] = 5,
    ACTIONS(14493), 1,
      anon_sym_DOT,
    STATE(5945), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3701), 26,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(3699), 31,
      aux_sym_where_condition_token1,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [478] = 11,
    ACTIONS(3969), 1,
      sym_table_keyword,
    STATE(7115), 1,
      sym_tabledata_permission,
    STATE(7980), 1,
      sym_preproc_if,
    STATE(5948), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(11359), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(7852), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14495), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(7855), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(7857), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(7846), 31,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [565] = 9,
    ACTIONS(7778), 1,
      sym_table_keyword,
    ACTIONS(7782), 1,
      sym_quoted_identifier,
    ACTIONS(7765), 3,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_dataset_keyword,
    ACTIONS(7775), 3,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7760), 5,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(7757), 7,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_separator_action_token1,
      aux_sym_type_declaration_token1,
      sym_key_keyword,
      sym_identifier,
    ACTIONS(7770), 17,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(7772), 22,
      aux_sym_modify_modification_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [648] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5376), 27,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(5374), 32,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_or_expression_token1,
      aux_sym_preproc_and_expression_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [719] = 7,
    ACTIONS(14487), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(14489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(14497), 1,
      aux_sym_preproc_or_expression_token1,
    ACTIONS(14499), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5360), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(5358), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [798] = 7,
    ACTIONS(14487), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(14489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(14497), 1,
      aux_sym_preproc_or_expression_token1,
    ACTIONS(14499), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5372), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(5370), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [877] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5277), 9,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(5279), 50,
      aux_sym_where_condition_token1,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [948] = 5,
    ACTIONS(14501), 1,
      anon_sym_DOT,
    STATE(5945), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3705), 26,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(3703), 31,
      aux_sym_where_condition_token1,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [1023] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3562), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3564), 51,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      aux_sym_interface_declaration_token1,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_implements_keyword,
      sym_extends_keyword,
      sym_customizes_keyword,
      sym_temporary_keyword,
  [1094] = 7,
    ACTIONS(14487), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(14489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(14497), 1,
      aux_sym_preproc_or_expression_token1,
    ACTIONS(14499), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5401), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(5399), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [1173] = 11,
    ACTIONS(14507), 1,
      sym_table_keyword,
    STATE(7115), 1,
      sym_tabledata_permission,
    STATE(7980), 1,
      sym_preproc_if,
    STATE(5948), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(11359), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(7795), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14504), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(7798), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(7801), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(7785), 31,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1260] = 3,
    ACTIONS(12163), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12161), 56,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1331] = 4,
    ACTIONS(14510), 1,
      anon_sym_SEMI,
    ACTIONS(12491), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12493), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1403] = 3,
    ACTIONS(12899), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12897), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1473] = 3,
    ACTIONS(12903), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12901), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1543] = 3,
    ACTIONS(12907), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12905), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1613] = 3,
    ACTIONS(12911), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12909), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1683] = 3,
    ACTIONS(12919), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12917), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1753] = 3,
    ACTIONS(12923), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12921), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1823] = 3,
    ACTIONS(9460), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9458), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1893] = 3,
    ACTIONS(12927), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12925), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [1963] = 3,
    ACTIONS(8901), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8903), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [2033] = 3,
    ACTIONS(12931), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12929), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [2103] = 3,
    ACTIONS(12648), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12646), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [2173] = 3,
    ACTIONS(12652), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12650), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [2243] = 3,
    ACTIONS(12652), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12650), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [2313] = 5,
    STATE(740), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5471), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5469), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [2387] = 5,
    STATE(741), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5451), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5449), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [2461] = 4,
    ACTIONS(14512), 1,
      anon_sym_SEMI,
    ACTIONS(12656), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12658), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [2533] = 5,
    STATE(746), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5479), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5477), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [2607] = 5,
    STATE(747), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5443), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5441), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [2681] = 5,
    STATE(748), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5433), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5431), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [2755] = 5,
    STATE(749), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5483), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5481), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [2829] = 5,
    STATE(754), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5491), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5489), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [2903] = 5,
    STATE(755), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5439), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5437), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [2977] = 4,
    ACTIONS(14514), 1,
      anon_sym_SEMI,
    ACTIONS(12656), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12658), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3049] = 3,
    ACTIONS(9345), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3119] = 3,
    ACTIONS(12365), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12363), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3189] = 3,
    ACTIONS(9610), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9608), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3259] = 3,
    ACTIONS(12365), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12363), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3329] = 3,
    ACTIONS(12387), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12385), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3399] = 3,
    ACTIONS(8889), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8891), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3469] = 3,
    ACTIONS(8889), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8891), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3539] = 3,
    ACTIONS(9345), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3609] = 3,
    ACTIONS(9361), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9359), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3679] = 3,
    ACTIONS(9345), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3749] = 3,
    ACTIONS(9397), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9395), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3819] = 3,
    ACTIONS(12387), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12385), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3889] = 3,
    ACTIONS(12746), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12744), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [3959] = 3,
    ACTIONS(12867), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12865), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4029] = 3,
    ACTIONS(12746), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12744), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4099] = 3,
    ACTIONS(9464), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9462), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4169] = 3,
    ACTIONS(9468), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9466), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4239] = 5,
    ACTIONS(14516), 1,
      anon_sym_DOT,
    STATE(6006), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3695), 26,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(3693), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [4313] = 3,
    ACTIONS(12943), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12941), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4383] = 3,
    ACTIONS(9472), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9470), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4453] = 3,
    ACTIONS(9476), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9474), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4523] = 3,
    ACTIONS(9472), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9470), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4593] = 3,
    ACTIONS(9416), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9414), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4663] = 3,
    ACTIONS(9420), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9418), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4733] = 3,
    ACTIONS(9424), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9422), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4803] = 3,
    ACTIONS(12774), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12772), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [4873] = 5,
    STATE(721), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5487), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5485), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [4947] = 5,
    STATE(736), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5455), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5453), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [5021] = 3,
    ACTIONS(12774), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12772), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5091] = 3,
    ACTIONS(12668), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12666), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5161] = 3,
    ACTIONS(9480), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5231] = 3,
    ACTIONS(12259), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12257), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5301] = 5,
    ACTIONS(14516), 1,
      anon_sym_DOT,
    STATE(6013), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3701), 26,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(3699), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [5375] = 3,
    ACTIONS(12317), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12315), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5445] = 3,
    ACTIONS(12259), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12257), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5515] = 3,
    ACTIONS(12263), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12261), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5585] = 3,
    ACTIONS(12263), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12261), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5655] = 3,
    ACTIONS(9484), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9482), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5725] = 3,
    ACTIONS(9480), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5795] = 5,
    ACTIONS(14518), 1,
      anon_sym_DOT,
    STATE(6013), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3705), 26,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(3703), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [5869] = 3,
    ACTIONS(9488), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9486), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [5939] = 3,
    ACTIONS(12668), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12666), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6009] = 3,
    ACTIONS(9428), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9426), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6079] = 3,
    ACTIONS(12267), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6149] = 3,
    ACTIONS(12267), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6219] = 3,
    ACTIONS(9480), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6289] = 3,
    ACTIONS(12267), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6359] = 3,
    ACTIONS(12267), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6429] = 3,
    ACTIONS(9484), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9482), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6499] = 3,
    ACTIONS(9353), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9351), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6569] = 3,
    ACTIONS(9492), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9490), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6639] = 3,
    ACTIONS(9496), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9494), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6709] = 3,
    ACTIONS(9492), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9490), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6779] = 3,
    ACTIONS(12780), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12778), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6849] = 3,
    ACTIONS(12780), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12778), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6919] = 3,
    ACTIONS(12672), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12670), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [6989] = 9,
    ACTIONS(5388), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_COLON_COLON,
    ACTIONS(14521), 1,
      aux_sym_where_clause_token1,
    STATE(7165), 1,
      sym_argument_list,
    STATE(11153), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3681), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5386), 18,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(3683), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [7071] = 3,
    ACTIONS(12784), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12782), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7141] = 3,
    ACTIONS(12784), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12782), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7211] = 3,
    ACTIONS(12815), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12813), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7281] = 3,
    ACTIONS(12819), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7351] = 3,
    ACTIONS(12819), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7421] = 3,
    ACTIONS(12819), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7491] = 3,
    ACTIONS(12819), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7561] = 3,
    ACTIONS(12819), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7631] = 3,
    ACTIONS(12823), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7701] = 3,
    ACTIONS(12823), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7771] = 3,
    ACTIONS(12823), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7841] = 3,
    ACTIONS(12823), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7911] = 3,
    ACTIONS(12823), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [7981] = 3,
    ACTIONS(12827), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8051] = 3,
    ACTIONS(12827), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8121] = 3,
    ACTIONS(12317), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12315), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8191] = 3,
    ACTIONS(12321), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12319), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8261] = 3,
    ACTIONS(12321), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12319), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8331] = 3,
    ACTIONS(12827), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8401] = 3,
    ACTIONS(9293), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9291), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8471] = 3,
    ACTIONS(12831), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8541] = 4,
    ACTIONS(14523), 1,
      anon_sym_SEMI,
    ACTIONS(12245), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12247), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8613] = 3,
    ACTIONS(12831), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8683] = 3,
    ACTIONS(12831), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8753] = 3,
    ACTIONS(12672), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12670), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8823] = 4,
    ACTIONS(14525), 1,
      anon_sym_SEMI,
    ACTIONS(12676), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12678), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8895] = 4,
    ACTIONS(14527), 1,
      anon_sym_SEMI,
    ACTIONS(12676), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12678), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [8967] = 3,
    ACTIONS(12684), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12682), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9037] = 3,
    ACTIONS(12283), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12281), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9107] = 3,
    ACTIONS(12267), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9177] = 3,
    ACTIONS(12684), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12682), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9247] = 4,
    ACTIONS(14529), 1,
      anon_sym_SEMI,
    ACTIONS(12688), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12690), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9319] = 4,
    ACTIONS(14531), 1,
      anon_sym_SEMI,
    ACTIONS(12688), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12690), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9391] = 3,
    ACTIONS(12891), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12889), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9461] = 4,
    ACTIONS(14533), 1,
      anon_sym_SEMI,
    ACTIONS(12684), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12682), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9533] = 4,
    ACTIONS(14535), 1,
      anon_sym_SEMI,
    ACTIONS(12684), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12682), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9605] = 3,
    ACTIONS(12271), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9675] = 3,
    ACTIONS(9281), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9279), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9745] = 3,
    ACTIONS(12387), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12385), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9815] = 3,
    ACTIONS(12871), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12869), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9885] = 3,
    ACTIONS(12788), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12786), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [9955] = 3,
    ACTIONS(12788), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12786), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10025] = 4,
    ACTIONS(14537), 1,
      anon_sym_SEMI,
    ACTIONS(12792), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12794), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10097] = 4,
    ACTIONS(14539), 1,
      anon_sym_SEMI,
    ACTIONS(12792), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12794), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10169] = 3,
    ACTIONS(9285), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9283), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10239] = 3,
    ACTIONS(6176), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6178), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10309] = 3,
    ACTIONS(12271), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10379] = 3,
    ACTIONS(12271), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10449] = 3,
    ACTIONS(12271), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10519] = 3,
    ACTIONS(12271), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10589] = 3,
    ACTIONS(6180), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6182), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10659] = 3,
    ACTIONS(12845), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12843), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10729] = 3,
    ACTIONS(12969), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12967), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10799] = 3,
    ACTIONS(12973), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10869] = 3,
    ACTIONS(12973), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [10939] = 3,
    ACTIONS(12973), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11009] = 3,
    ACTIONS(12981), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11079] = 3,
    ACTIONS(12849), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12847), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11149] = 3,
    ACTIONS(12981), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11219] = 3,
    ACTIONS(6184), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6186), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11289] = 3,
    ACTIONS(6188), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6190), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11359] = 3,
    ACTIONS(12981), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11429] = 3,
    ACTIONS(6359), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6361), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11499] = 3,
    ACTIONS(9644), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9642), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11569] = 3,
    ACTIONS(9650), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9648), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11639] = 3,
    ACTIONS(9650), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9648), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11709] = 3,
    ACTIONS(9654), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9652), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11779] = 3,
    ACTIONS(9654), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9652), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [11849] = 6,
    ACTIONS(5487), 1,
      anon_sym_SEMI,
    STATE(721), 1,
      sym_else_keyword,
    ACTIONS(9305), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9302), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9299), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [11925] = 6,
    ACTIONS(5455), 1,
      anon_sym_SEMI,
    STATE(736), 1,
      sym_else_keyword,
    ACTIONS(9315), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9312), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9309), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [12001] = 3,
    ACTIONS(9064), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9066), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12071] = 3,
    ACTIONS(9064), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9066), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12141] = 3,
    ACTIONS(9068), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12211] = 3,
    ACTIONS(9068), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12281] = 3,
    ACTIONS(9068), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12351] = 3,
    ACTIONS(5935), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5937), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12421] = 3,
    ACTIONS(5935), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5937), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12491] = 3,
    ACTIONS(12503), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12501), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12561] = 3,
    ACTIONS(9044), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12631] = 3,
    ACTIONS(9044), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12701] = 3,
    ACTIONS(9044), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12771] = 3,
    ACTIONS(9048), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9050), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12841] = 3,
    ACTIONS(9682), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9680), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12911] = 3,
    ACTIONS(12997), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12995), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [12981] = 3,
    ACTIONS(9052), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9054), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13051] = 3,
    ACTIONS(9052), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9054), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13121] = 3,
    ACTIONS(9686), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9684), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13191] = 3,
    ACTIONS(9690), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9688), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13261] = 3,
    ACTIONS(12325), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12323), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13331] = 3,
    ACTIONS(12325), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12323), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13401] = 3,
    ACTIONS(12329), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12327), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13471] = 4,
    ACTIONS(14541), 1,
      anon_sym_SEMI,
    ACTIONS(12333), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12335), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13543] = 4,
    ACTIONS(14543), 1,
      anon_sym_SEMI,
    ACTIONS(12333), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12335), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13615] = 3,
    ACTIONS(12341), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12339), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13685] = 3,
    ACTIONS(12341), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12339), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13755] = 4,
    ACTIONS(14545), 1,
      anon_sym_SEMI,
    ACTIONS(12345), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12347), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13827] = 4,
    ACTIONS(14547), 1,
      anon_sym_SEMI,
    ACTIONS(12345), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12347), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13899] = 4,
    ACTIONS(14549), 1,
      anon_sym_SEMI,
    ACTIONS(12341), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12339), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [13971] = 4,
    ACTIONS(14551), 1,
      anon_sym_SEMI,
    ACTIONS(12341), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12339), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14043] = 3,
    ACTIONS(9321), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9319), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14113] = 3,
    ACTIONS(9694), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9692), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14183] = 3,
    ACTIONS(13005), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13003), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14253] = 3,
    ACTIONS(13009), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13007), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14323] = 3,
    ACTIONS(6124), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6126), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14393] = 3,
    ACTIONS(12357), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14463] = 3,
    ACTIONS(12357), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14533] = 4,
    ACTIONS(14553), 1,
      anon_sym_SEMI,
    ACTIONS(12369), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12371), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14605] = 4,
    ACTIONS(14555), 1,
      anon_sym_SEMI,
    ACTIONS(12369), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12371), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14677] = 4,
    ACTIONS(14557), 1,
      anon_sym_SEMI,
    ACTIONS(12357), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14749] = 4,
    ACTIONS(14559), 1,
      anon_sym_SEMI,
    ACTIONS(12357), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14821] = 3,
    ACTIONS(12718), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12716), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14891] = 4,
    ACTIONS(14561), 1,
      anon_sym_SEMI,
    ACTIONS(12381), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12383), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [14963] = 4,
    ACTIONS(14563), 1,
      anon_sym_SEMI,
    ACTIONS(12381), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12383), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15035] = 3,
    ACTIONS(12722), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12720), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15105] = 3,
    ACTIONS(12726), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12724), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15175] = 3,
    ACTIONS(12730), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12728), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15245] = 3,
    ACTIONS(12734), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12732), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15315] = 3,
    ACTIONS(9325), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9323), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15385] = 3,
    ACTIONS(9329), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9327), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15455] = 4,
    ACTIONS(14565), 1,
      anon_sym_SEMI,
    ACTIONS(12329), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12327), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15527] = 3,
    ACTIONS(12738), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12736), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15597] = 4,
    ACTIONS(14567), 1,
      anon_sym_SEMI,
    ACTIONS(12395), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12397), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15669] = 3,
    ACTIONS(12935), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12933), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15739] = 3,
    ACTIONS(9333), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15809] = 3,
    ACTIONS(12939), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12937), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15879] = 3,
    ACTIONS(12977), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12975), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [15949] = 4,
    ACTIONS(14569), 1,
      anon_sym_SEMI,
    ACTIONS(12395), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12397), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16021] = 3,
    ACTIONS(12742), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12740), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16091] = 3,
    ACTIONS(12750), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12748), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16161] = 3,
    ACTIONS(9718), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9716), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16231] = 3,
    ACTIONS(9337), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9335), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16301] = 3,
    ACTIONS(12985), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12983), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16371] = 3,
    ACTIONS(12985), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12983), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16441] = 3,
    ACTIONS(12754), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12752), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16511] = 3,
    ACTIONS(12989), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12987), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16581] = 3,
    ACTIONS(12989), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12987), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16651] = 3,
    ACTIONS(9393), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9391), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16721] = 3,
    ACTIONS(9333), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16791] = 3,
    ACTIONS(9401), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9399), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16861] = 3,
    ACTIONS(9405), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9403), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [16931] = 3,
    ACTIONS(12993), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17001] = 3,
    ACTIONS(12993), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17071] = 3,
    ACTIONS(12993), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17141] = 3,
    ACTIONS(12993), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17211] = 3,
    ACTIONS(12993), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17281] = 3,
    ACTIONS(13001), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17351] = 3,
    ACTIONS(13001), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17421] = 3,
    ACTIONS(13001), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17491] = 3,
    ACTIONS(13001), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17561] = 3,
    ACTIONS(13001), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17631] = 4,
    ACTIONS(14571), 1,
      anon_sym_SEMI,
    ACTIONS(12403), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12405), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17703] = 4,
    ACTIONS(14573), 1,
      anon_sym_SEMI,
    ACTIONS(12403), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12405), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17775] = 3,
    ACTIONS(9622), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9620), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17845] = 3,
    ACTIONS(12758), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12756), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17915] = 3,
    ACTIONS(9622), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9620), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [17985] = 3,
    ACTIONS(9658), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9656), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18055] = 3,
    ACTIONS(9658), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9656), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18125] = 3,
    ACTIONS(12947), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12945), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18195] = 4,
    ACTIONS(14575), 1,
      anon_sym_SEMI,
    ACTIONS(5961), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18267] = 3,
    ACTIONS(9341), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9339), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18337] = 3,
    ACTIONS(9632), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9630), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18407] = 4,
    ACTIONS(14577), 1,
      anon_sym_SEMI,
    ACTIONS(5961), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18479] = 3,
    ACTIONS(9345), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18549] = 3,
    ACTIONS(5961), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18619] = 3,
    ACTIONS(9361), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9359), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18689] = 3,
    ACTIONS(12612), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12610), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18759] = 3,
    ACTIONS(8998), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9000), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18829] = 3,
    ACTIONS(6136), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6138), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18899] = 3,
    ACTIONS(9002), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9004), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [18969] = 3,
    ACTIONS(9002), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9004), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19039] = 3,
    ACTIONS(9006), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19109] = 3,
    ACTIONS(9006), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19179] = 3,
    ACTIONS(9006), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19249] = 3,
    ACTIONS(12841), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12839), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19319] = 3,
    ACTIONS(13025), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13023), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19389] = 3,
    ACTIONS(12887), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12885), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19459] = 4,
    ACTIONS(14579), 1,
      anon_sym_SEMI,
    ACTIONS(12951), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12949), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19531] = 3,
    ACTIONS(12766), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12764), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19601] = 3,
    ACTIONS(9510), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9508), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19671] = 3,
    ACTIONS(9514), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9512), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19741] = 3,
    ACTIONS(12895), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12893), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19811] = 3,
    ACTIONS(9518), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9516), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19881] = 3,
    ACTIONS(9522), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9520), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [19951] = 3,
    ACTIONS(12770), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12768), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20021] = 3,
    ACTIONS(9526), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9524), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20091] = 3,
    ACTIONS(9530), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9528), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20161] = 3,
    ACTIONS(9534), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9532), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20231] = 3,
    ACTIONS(9538), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9536), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20301] = 3,
    ACTIONS(9542), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9540), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20371] = 3,
    ACTIONS(9546), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9544), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20441] = 3,
    ACTIONS(9510), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9508), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20511] = 3,
    ACTIONS(9550), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9548), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20581] = 3,
    ACTIONS(9554), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9552), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20651] = 3,
    ACTIONS(9558), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9556), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20721] = 3,
    ACTIONS(9562), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9560), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20791] = 3,
    ACTIONS(9566), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9564), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20861] = 3,
    ACTIONS(9562), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9560), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [20931] = 3,
    ACTIONS(9550), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9548), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21001] = 3,
    ACTIONS(9570), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9568), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21071] = 3,
    ACTIONS(12612), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12610), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21141] = 3,
    ACTIONS(9365), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21211] = 3,
    ACTIONS(9369), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9367), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21281] = 3,
    ACTIONS(9365), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21351] = 3,
    ACTIONS(9574), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9572), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21421] = 3,
    ACTIONS(9578), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9576), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21491] = 4,
    ACTIONS(14581), 1,
      anon_sym_SEMI,
    ACTIONS(6118), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6122), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21563] = 3,
    ACTIONS(12417), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12415), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21633] = 3,
    ACTIONS(12664), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21703] = 3,
    ACTIONS(12664), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21773] = 3,
    ACTIONS(12664), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21843] = 3,
    ACTIONS(12811), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12809), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21913] = 3,
    ACTIONS(12664), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [21983] = 3,
    ACTIONS(12664), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22053] = 3,
    ACTIONS(12835), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22123] = 3,
    ACTIONS(12811), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12809), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22193] = 3,
    ACTIONS(9373), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9371), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22263] = 3,
    ACTIONS(12361), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12359), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22333] = 3,
    ACTIONS(9377), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9375), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22403] = 3,
    ACTIONS(9365), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22473] = 4,
    ACTIONS(14583), 1,
      anon_sym_SEMI,
    ACTIONS(12853), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12855), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22545] = 3,
    ACTIONS(12859), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12857), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22615] = 3,
    ACTIONS(12863), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12861), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22685] = 3,
    ACTIONS(6192), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6194), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22755] = 3,
    ACTIONS(12835), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22825] = 3,
    ACTIONS(12835), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22895] = 3,
    ACTIONS(12835), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [22965] = 3,
    ACTIONS(12835), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23035] = 3,
    ACTIONS(12915), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12913), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23105] = 3,
    ACTIONS(12600), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12598), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23175] = 3,
    ACTIONS(9369), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9367), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23245] = 3,
    ACTIONS(6152), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6154), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23315] = 3,
    ACTIONS(12604), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23385] = 3,
    ACTIONS(12604), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23455] = 3,
    ACTIONS(9289), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9287), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23525] = 3,
    ACTIONS(6156), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6158), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23595] = 3,
    ACTIONS(12604), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23665] = 3,
    ACTIONS(6118), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6122), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23735] = 3,
    ACTIONS(12237), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12235), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23805] = 3,
    ACTIONS(12237), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12235), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23875] = 3,
    ACTIONS(12237), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12235), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [23945] = 3,
    ACTIONS(12241), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12239), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24015] = 3,
    ACTIONS(12604), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24085] = 3,
    ACTIONS(9241), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9239), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24155] = 3,
    ACTIONS(9245), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9243), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24225] = 3,
    ACTIONS(12604), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24295] = 3,
    ACTIONS(12608), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24365] = 3,
    ACTIONS(12608), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24435] = 3,
    ACTIONS(12875), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12873), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24505] = 3,
    ACTIONS(9249), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9247), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24575] = 3,
    ACTIONS(12241), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12239), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24645] = 3,
    ACTIONS(9253), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9251), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24715] = 3,
    ACTIONS(9257), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24785] = 3,
    ACTIONS(9261), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9259), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24855] = 3,
    ACTIONS(9257), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24925] = 3,
    ACTIONS(12421), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12419), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [24995] = 3,
    ACTIONS(12421), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12419), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25065] = 3,
    ACTIONS(12425), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12423), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25135] = 3,
    ACTIONS(12425), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12423), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25205] = 3,
    ACTIONS(12429), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12427), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25275] = 3,
    ACTIONS(12429), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12427), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25345] = 4,
    ACTIONS(14585), 1,
      anon_sym_SEMI,
    ACTIONS(12433), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12435), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25417] = 4,
    ACTIONS(14587), 1,
      anon_sym_SEMI,
    ACTIONS(12433), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12435), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25489] = 3,
    ACTIONS(9265), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25559] = 3,
    ACTIONS(12241), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12239), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25629] = 3,
    ACTIONS(9698), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9696), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25699] = 3,
    ACTIONS(9702), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9700), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25769] = 3,
    ACTIONS(9265), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25839] = 3,
    ACTIONS(9269), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9267), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25909] = 3,
    ACTIONS(9265), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [25979] = 3,
    ACTIONS(9273), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9271), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26049] = 3,
    ACTIONS(9702), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9700), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26119] = 3,
    ACTIONS(12441), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12439), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26189] = 3,
    ACTIONS(12441), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12439), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26259] = 3,
    ACTIONS(12445), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12443), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26329] = 3,
    ACTIONS(12445), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12443), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26399] = 4,
    ACTIONS(14589), 1,
      anon_sym_SEMI,
    ACTIONS(12449), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12451), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26471] = 4,
    ACTIONS(14591), 1,
      anon_sym_SEMI,
    ACTIONS(12449), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12451), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26543] = 3,
    ACTIONS(12457), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26613] = 3,
    ACTIONS(12457), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26683] = 4,
    ACTIONS(14593), 1,
      anon_sym_SEMI,
    ACTIONS(12461), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12463), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26755] = 4,
    ACTIONS(14595), 1,
      anon_sym_SEMI,
    ACTIONS(12461), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12463), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26827] = 4,
    ACTIONS(14597), 1,
      anon_sym_SEMI,
    ACTIONS(12457), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26899] = 4,
    ACTIONS(14599), 1,
      anon_sym_SEMI,
    ACTIONS(12457), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [26971] = 3,
    ACTIONS(9702), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9700), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27041] = 3,
    ACTIONS(9702), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9700), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27111] = 3,
    ACTIONS(9706), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9704), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27181] = 3,
    ACTIONS(9706), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9704), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27251] = 3,
    ACTIONS(9249), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9247), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27321] = 3,
    ACTIONS(9706), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9704), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27391] = 3,
    ACTIONS(12475), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12473), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27461] = 4,
    ACTIONS(14601), 1,
      anon_sym_SEMI,
    ACTIONS(12479), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12481), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27533] = 4,
    ACTIONS(14603), 1,
      anon_sym_SEMI,
    ACTIONS(12479), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12481), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27605] = 3,
    ACTIONS(12487), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12485), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27675] = 3,
    ACTIONS(12608), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27745] = 3,
    ACTIONS(6160), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6162), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27815] = 3,
    ACTIONS(12608), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27885] = 3,
    ACTIONS(12608), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [27955] = 3,
    ACTIONS(9722), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9720), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28025] = 3,
    ACTIONS(9349), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9347), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28095] = 3,
    ACTIONS(12616), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12614), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28165] = 3,
    ACTIONS(6164), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6166), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28235] = 3,
    ACTIONS(12620), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28305] = 3,
    ACTIONS(12620), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28375] = 3,
    ACTIONS(12487), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12485), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28445] = 3,
    ACTIONS(12620), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28515] = 4,
    ACTIONS(14605), 1,
      anon_sym_SEMI,
    ACTIONS(12491), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12493), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28587] = 4,
    ACTIONS(14607), 1,
      anon_sym_SEMI,
    ACTIONS(12487), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12485), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28659] = 4,
    ACTIONS(14609), 1,
      anon_sym_SEMI,
    ACTIONS(12487), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12485), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28731] = 3,
    ACTIONS(9706), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9704), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28801] = 3,
    ACTIONS(12620), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28871] = 3,
    ACTIONS(9710), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9708), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [28941] = 3,
    ACTIONS(9257), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29011] = 3,
    ACTIONS(9710), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9708), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29081] = 3,
    ACTIONS(9714), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9712), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29151] = 3,
    ACTIONS(9714), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9712), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29221] = 3,
    ACTIONS(12223), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12225), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29291] = 3,
    ACTIONS(12223), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12225), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29361] = 4,
    ACTIONS(14611), 1,
      anon_sym_SEMI,
    ACTIONS(12507), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12509), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29433] = 4,
    ACTIONS(14613), 1,
      anon_sym_SEMI,
    ACTIONS(12507), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12509), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29505] = 4,
    ACTIONS(14615), 1,
      anon_sym_SEMI,
    ACTIONS(12223), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12225), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29577] = 4,
    ACTIONS(14617), 1,
      anon_sym_SEMI,
    ACTIONS(12223), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12225), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29649] = 3,
    ACTIONS(12620), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29719] = 4,
    ACTIONS(14619), 1,
      anon_sym_SEMI,
    ACTIONS(12517), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12519), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29791] = 4,
    ACTIONS(14621), 1,
      anon_sym_SEMI,
    ACTIONS(12517), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12519), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29863] = 3,
    ACTIONS(9297), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9295), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [29933] = 3,
    ACTIONS(9353), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9351), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30003] = 3,
    ACTIONS(12700), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30073] = 3,
    ACTIONS(9357), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9355), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30143] = 3,
    ACTIONS(12700), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30213] = 3,
    ACTIONS(6140), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6142), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30283] = 3,
    ACTIONS(12700), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30353] = 3,
    ACTIONS(12700), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30423] = 3,
    ACTIONS(9582), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9580), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30493] = 3,
    ACTIONS(12251), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12249), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30563] = 3,
    ACTIONS(12251), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12249), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30633] = 3,
    ACTIONS(6144), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6146), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30703] = 3,
    ACTIONS(6148), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6150), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30773] = 3,
    ACTIONS(12255), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12253), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30843] = 3,
    ACTIONS(9586), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9584), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30913] = 11,
    ACTIONS(14623), 1,
      sym_identifier,
    ACTIONS(14625), 1,
      sym_quoted_identifier,
    ACTIONS(14627), 1,
      sym_var_attribute_open,
    STATE(3159), 1,
      sym_preproc_if,
    STATE(15903), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8300), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(8329), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6372), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8331), 29,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [30999] = 3,
    ACTIONS(12255), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12253), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31069] = 11,
    ACTIONS(14623), 1,
      sym_identifier,
    ACTIONS(14625), 1,
      sym_quoted_identifier,
    ACTIONS(14627), 1,
      sym_var_attribute_open,
    STATE(3159), 1,
      sym_preproc_if,
    STATE(15903), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8296), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(8300), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6383), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8298), 29,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31155] = 3,
    ACTIONS(9614), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9612), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31225] = 11,
    ACTIONS(14623), 1,
      sym_identifier,
    ACTIONS(14625), 1,
      sym_quoted_identifier,
    ACTIONS(14627), 1,
      sym_var_attribute_open,
    STATE(3159), 1,
      sym_preproc_if,
    STATE(15903), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8296), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(8300), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6384), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8298), 29,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31311] = 3,
    ACTIONS(12287), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12285), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31381] = 3,
    ACTIONS(9590), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9588), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31451] = 4,
    ACTIONS(14629), 1,
      anon_sym_SEMI,
    ACTIONS(12291), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12293), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31523] = 5,
    ACTIONS(7331), 1,
      aux_sym_where_clause_token1,
    STATE(6608), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5386), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(5392), 31,
      aux_sym_where_condition_token1,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [31597] = 3,
    ACTIONS(9381), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9379), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31667] = 4,
    ACTIONS(14631), 1,
      anon_sym_SEMI,
    ACTIONS(12291), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12293), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31739] = 4,
    ACTIONS(14633), 1,
      anon_sym_SEMI,
    ACTIONS(12287), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12285), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31811] = 3,
    ACTIONS(9594), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9592), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31881] = 11,
    ACTIONS(14635), 1,
      sym_identifier,
    ACTIONS(14638), 1,
      sym_quoted_identifier,
    ACTIONS(14641), 1,
      sym_var_attribute_open,
    STATE(3159), 1,
      sym_preproc_if,
    STATE(15903), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8313), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(8320), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6383), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(8315), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8318), 29,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [31967] = 11,
    ACTIONS(14623), 1,
      sym_identifier,
    ACTIONS(14625), 1,
      sym_quoted_identifier,
    ACTIONS(14627), 1,
      sym_var_attribute_open,
    STATE(3159), 1,
      sym_preproc_if,
    STATE(15903), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8300), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(8306), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(6383), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8308), 29,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32053] = 3,
    ACTIONS(9598), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9596), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32123] = 4,
    ACTIONS(14644), 1,
      anon_sym_SEMI,
    ACTIONS(12301), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12303), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32195] = 3,
    ACTIONS(9602), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9600), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32265] = 3,
    ACTIONS(9606), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9604), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32335] = 4,
    ACTIONS(14646), 1,
      anon_sym_SEMI,
    ACTIONS(12301), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12303), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32407] = 3,
    ACTIONS(6168), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6170), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32477] = 3,
    ACTIONS(6172), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6174), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32547] = 3,
    ACTIONS(9618), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9616), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32617] = 5,
    ACTIONS(12702), 1,
      anon_sym_SEMI,
    ACTIONS(12704), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(12281), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12706), 50,
      sym_property_name,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32691] = 3,
    ACTIONS(12957), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12955), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32761] = 3,
    ACTIONS(8905), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32831] = 4,
    ACTIONS(14648), 1,
      anon_sym_SEMI,
    ACTIONS(12309), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12311), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32903] = 3,
    ACTIONS(9385), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9383), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [32973] = 3,
    ACTIONS(12700), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33043] = 3,
    ACTIONS(9726), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9724), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33113] = 3,
    ACTIONS(9726), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9724), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33183] = 3,
    ACTIONS(9730), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9728), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33253] = 3,
    ACTIONS(9730), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9728), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33323] = 3,
    ACTIONS(9381), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9379), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33393] = 3,
    ACTIONS(12800), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12798), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33463] = 4,
    ACTIONS(14650), 1,
      anon_sym_SEMI,
    ACTIONS(12309), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12311), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33535] = 3,
    ACTIONS(8905), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33605] = 3,
    ACTIONS(12624), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12622), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33675] = 3,
    ACTIONS(12624), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12622), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33745] = 3,
    ACTIONS(8905), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33815] = 3,
    ACTIONS(8909), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8911), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33885] = 3,
    ACTIONS(12628), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12626), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [33955] = 3,
    ACTIONS(12628), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12626), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34025] = 3,
    ACTIONS(9412), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9410), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34095] = 3,
    ACTIONS(9416), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9414), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34165] = 3,
    ACTIONS(12632), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12630), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34235] = 3,
    ACTIONS(12632), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12630), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34305] = 4,
    ACTIONS(14652), 1,
      anon_sym_SEMI,
    ACTIONS(12636), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12638), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34377] = 4,
    ACTIONS(14654), 1,
      anon_sym_SEMI,
    ACTIONS(12636), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12638), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34449] = 3,
    ACTIONS(9389), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9387), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34519] = 3,
    ACTIONS(12365), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12363), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34589] = 3,
    ACTIONS(9333), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34659] = 3,
    ACTIONS(9337), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9335), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34729] = 3,
    ACTIONS(9333), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34799] = 3,
    ACTIONS(13017), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34869] = 3,
    ACTIONS(9420), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9418), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [34939] = 3,
    ACTIONS(9424), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9422), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35009] = 3,
    ACTIONS(9428), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9426), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35079] = 3,
    ACTIONS(12644), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12642), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35149] = 3,
    ACTIONS(9734), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9732), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35219] = 3,
    ACTIONS(9237), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35289] = 3,
    ACTIONS(9237), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35359] = 3,
    ACTIONS(9237), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35429] = 3,
    ACTIONS(9237), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35499] = 3,
    ACTIONS(9277), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35569] = 3,
    ACTIONS(9277), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35639] = 3,
    ACTIONS(9277), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35709] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3705), 27,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_DOT,
      aux_sym_where_clause_token1,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(3703), 31,
      aux_sym_where_condition_token1,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [35779] = 3,
    ACTIONS(9277), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35849] = 3,
    ACTIONS(12644), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12642), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35919] = 3,
    ACTIONS(12648), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12646), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [35989] = 15,
    ACTIONS(6034), 1,
      aux_sym_basic_type_token22,
    ACTIONS(14485), 1,
      anon_sym_DASH,
    STATE(7227), 1,
      sym_option_member,
    ACTIONS(1376), 2,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
    ACTIONS(6036), 3,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    STATE(6858), 3,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
      sym_enum_keyword,
    STATE(7226), 3,
      sym_boolean,
      sym_keyword_identifier,
      sym_keyword_as_identifier,
    ACTIONS(611), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(3993), 4,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(27), 6,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
    ACTIONS(1400), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(1402), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(1382), 9,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token48,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(4043), 9,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
  [36083] = 3,
    ACTIONS(9432), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9430), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36153] = 3,
    ACTIONS(9436), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9434), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36223] = 3,
    ACTIONS(9440), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9438), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36293] = 3,
    ACTIONS(13017), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36363] = 3,
    ACTIONS(13017), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36433] = 3,
    ACTIONS(13017), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36503] = 3,
    ACTIONS(13017), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36573] = 3,
    ACTIONS(13021), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36643] = 3,
    ACTIONS(13021), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36713] = 3,
    ACTIONS(13021), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36783] = 3,
    ACTIONS(13021), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36853] = 3,
    ACTIONS(13021), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36923] = 3,
    ACTIONS(12762), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12760), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [36993] = 3,
    ACTIONS(12229), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37063] = 3,
    ACTIONS(12229), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37133] = 3,
    ACTIONS(12229), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37203] = 3,
    ACTIONS(12229), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37273] = 3,
    ACTIONS(12229), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37343] = 3,
    ACTIONS(12233), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37413] = 3,
    ACTIONS(12233), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37483] = 3,
    ACTIONS(12233), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37553] = 3,
    ACTIONS(12233), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37623] = 3,
    ACTIONS(12233), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37693] = 3,
    ACTIONS(9444), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9442), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37763] = 3,
    ACTIONS(9448), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9446), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37833] = 3,
    ACTIONS(9444), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9442), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37903] = 3,
    ACTIONS(9628), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9626), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [37973] = 3,
    ACTIONS(12961), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12959), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38043] = 3,
    ACTIONS(12879), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12877), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38113] = 4,
    ACTIONS(12704), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12281), 5,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(12706), 50,
      sym_property_name,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38185] = 3,
    ACTIONS(9636), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9634), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38255] = 3,
    ACTIONS(9640), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9638), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38325] = 4,
    ACTIONS(12708), 1,
      anon_sym_SEMI,
    ACTIONS(12710), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12712), 54,
      sym_property_name,
      sym_preproc_open,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38397] = 3,
    ACTIONS(9432), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9430), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38467] = 3,
    ACTIONS(9452), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9450), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38537] = 3,
    ACTIONS(12883), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12881), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38607] = 3,
    ACTIONS(9456), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9454), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38677] = 3,
    ACTIONS(12951), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12949), 55,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [38747] = 5,
    ACTIONS(14661), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14656), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(12768), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
    ACTIONS(14658), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_trigger_keyword,
  [38820] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(5375), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [38935] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(5375), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6483), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [39050] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(5409), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [39165] = 5,
    ACTIONS(12157), 2,
      aux_sym_preproc_or_expression_token1,
      anon_sym_PIPE_PIPE,
    ACTIONS(12159), 2,
      aux_sym_preproc_and_expression_token1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5358), 11,
      sym_table_keyword,
      sym_page_keyword,
      sym_report_keyword,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_permissionset,
      anon_sym_PERMISSIONSET,
      anon_sym_Permissionset,
      anon_sym_PermissionSet,
      anon_sym_permissionSet,
    ACTIONS(5360), 42,
      anon_sym_tableextension,
      anon_sym_TABLEEXTENSION,
      anon_sym_Tableextension,
      anon_sym_TableExtension,
      anon_sym_tableExtension,
      anon_sym_pageextension,
      anon_sym_PAGEEXTENSION,
      anon_sym_Pageextension,
      anon_sym_PageExtension,
      anon_sym_pageExtension,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      anon_sym_reportextension,
      anon_sym_REPORTEXTENSION,
      anon_sym_Reportextension,
      anon_sym_ReportExtension,
      anon_sym_reportExtension,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      anon_sym_enumextension,
      anon_sym_ENUMEXTENSION,
      anon_sym_Enumextension,
      anon_sym_EnumExtension,
      anon_sym_enumExtension,
      sym_interface_keyword,
      anon_sym_permissionsetextension,
      anon_sym_PERMISSIONSETEXTENSION,
      anon_sym_Permissionsetextension,
      anon_sym_PermissionSetExtension,
      anon_sym_permissionSetExtension,
  [39238] = 5,
    ACTIONS(14668), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14663), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(13370), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
    ACTIONS(14665), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_trigger_keyword,
  [39311] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(5409), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6491), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [39426] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(10118), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(992), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [39541] = 6,
    ACTIONS(5487), 1,
      anon_sym_SEMI,
    STATE(721), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9302), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9299), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [39616] = 6,
    ACTIONS(5455), 1,
      anon_sym_SEMI,
    STATE(736), 1,
      sym_else_keyword,
    ACTIONS(5435), 3,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9312), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9309), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [39691] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(10118), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(992), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6502), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [39806] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(5405), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4457), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [39921] = 5,
    ACTIONS(7358), 1,
      aux_sym_where_clause_token1,
    STATE(6878), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5386), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(5392), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [39994] = 11,
    ACTIONS(4083), 1,
      sym_table_keyword,
    STATE(7230), 1,
      sym_tabledata_permission,
    STATE(7947), 1,
      sym_preproc_if,
    STATE(6494), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(11361), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(7852), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14670), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(7855), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(7857), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(7846), 29,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40079] = 11,
    ACTIONS(14675), 1,
      sym_table_keyword,
    STATE(7230), 1,
      sym_tabledata_permission,
    STATE(7947), 1,
      sym_preproc_if,
    STATE(6494), 2,
      sym_preproc_conditional_permissions,
      aux_sym_tabledata_permission_list_repeat1,
    STATE(11361), 2,
      sym_codeunit_keyword,
      sym_xmlport_keyword,
    ACTIONS(7795), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14672), 5,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      sym_page_keyword,
      sym_report_keyword,
      sym_query_keyword,
    ACTIONS(7798), 6,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
    ACTIONS(7801), 6,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
    ACTIONS(7785), 29,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [40164] = 7,
    ACTIONS(14680), 1,
      anon_sym_LBRACK,
    ACTIONS(14684), 1,
      aux_sym_basic_type_token22,
    ACTIONS(12806), 4,
      sym_procedure_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14678), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(12802), 17,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_var_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
    ACTIONS(14686), 23,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_trigger_keyword,
  [40241] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3705), 27,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_DOT,
      aux_sym_where_clause_token1,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(3703), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [40310] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8534), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11226), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [40425] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8428), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11226), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [40540] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8428), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11226), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6497), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [40655] = 5,
    ACTIONS(14689), 1,
      anon_sym_COMMA,
    STATE(6500), 1,
      aux_sym_option_member_list_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(838), 10,
      sym_preproc_open,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    ACTIONS(836), 45,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      aux_sym_where_condition_token1,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_table_keyword,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [40728] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8610), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11226), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6511), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [40843] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(10124), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(992), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [40958] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(10124), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(992), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6514), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [41073] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8000), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4224), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [41188] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8000), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4224), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6507), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [41303] = 5,
    ACTIONS(14697), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14692), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(12963), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
    ACTIONS(14694), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_trigger_keyword,
  [41376] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8011), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4224), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [41491] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8011), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4224), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6509), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [41606] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(7955), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4224), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [41721] = 5,
    ACTIONS(14704), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14699), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(12409), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
    ACTIONS(14701), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_trigger_keyword,
  [41794] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8616), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11226), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [41909] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(10154), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(992), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6487), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [42024] = 5,
    ACTIONS(14684), 1,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14678), 11,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      sym_area_keyword,
      sym_group_keyword,
    ACTIONS(12802), 21,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
    ACTIONS(14686), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_modify_modification_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_trigger_keyword,
  [42097] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(10106), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(992), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(5316), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [42212] = 26,
    ACTIONS(4439), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(4441), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(4445), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(4447), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(4449), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(4451), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(4453), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(4455), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(4463), 1,
      sym_area_keyword,
    ACTIONS(4465), 1,
      sym_group_keyword,
    ACTIONS(4467), 1,
      sym_repeater_keyword,
    ACTIONS(4469), 1,
      sym_cuegroup_keyword,
    ACTIONS(4471), 1,
      sym_fixed_keyword,
    ACTIONS(4473), 1,
      sym_grid_keyword,
    ACTIONS(4475), 1,
      sym_part_keyword,
    ACTIONS(4477), 1,
      sym_systempart_keyword,
    ACTIONS(4479), 1,
      sym_usercontrol_keyword,
    ACTIONS(9792), 1,
      aux_sym_basic_type_token6,
    ACTIONS(9794), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(10374), 1,
      aux_sym_where_condition_token1,
    STATE(4700), 1,
      sym_preproc_if,
    STATE(8616), 1,
      sym_preproc_endif,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11226), 7,
      sym_preproc_close,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6498), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [42327] = 8,
    ACTIONS(5388), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5407), 1,
      anon_sym_DOT,
    STATE(7165), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3681), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5405), 19,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(3683), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [42406] = 5,
    ACTIONS(14706), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(14708), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5380), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5378), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_or_expression_token1,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [42478] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14712), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14710), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [42546] = 4,
    ACTIONS(14714), 1,
      aux_sym_else_table_relation_fragment_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13121), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13123), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [42616] = 7,
    ACTIONS(14706), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(14708), 1,
      anon_sym_AMP_AMP,
    ACTIONS(14716), 1,
      aux_sym_preproc_or_expression_token1,
    ACTIONS(14718), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5401), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5399), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [42692] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14722), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14720), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [42760] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3562), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3564), 49,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [42828] = 21,
    ACTIONS(5191), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(5193), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(5195), 1,
      aux_sym_basic_type_token22,
    ACTIONS(5197), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(5199), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(5203), 1,
      aux_sym_separator_action_token1,
    ACTIONS(5205), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(5207), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(5209), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(5211), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(5213), 1,
      sym_area_keyword,
    ACTIONS(5215), 1,
      sym_group_keyword,
    ACTIONS(14463), 1,
      anon_sym_LBRACK,
    ACTIONS(14465), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14473), 1,
      sym_trigger_keyword,
    ACTIONS(14475), 1,
      sym_property_name,
    STATE(5874), 1,
      sym_preproc_if,
    ACTIONS(14467), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14724), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6551), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [42932] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14728), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14726), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43000] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14732), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14730), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43068] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14736), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14734), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43136] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9840), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43204] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9810), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9808), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43272] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14740), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14738), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43340] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14744), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14742), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43408] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14748), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14746), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43476] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14752), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14750), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43544] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14756), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14754), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43612] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5376), 16,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5374), 40,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_or_expression_token1,
      aux_sym_preproc_and_expression_token1,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43680] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14760), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14758), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43748] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14764), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14762), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43816] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14768), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14766), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43884] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9832), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9830), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [43952] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9842), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9840), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44020] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9770), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9768), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44088] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9774), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9772), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44156] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14772), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14770), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44224] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9810), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9808), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44292] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14776), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14774), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44360] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10045), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10043), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44428] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3564), 20,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
      sym_quoted_identifier,
    ACTIONS(3562), 36,
      anon_sym_DOT,
      anon_sym_DASH,
      aux_sym_where_condition_token1,
      anon_sym_STAR,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [44496] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9766), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9764), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44564] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14778), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(8387), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44632] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14782), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14780), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44700] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9778), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9776), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44768] = 21,
    ACTIONS(14784), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14787), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14790), 1,
      anon_sym_LBRACK,
    ACTIONS(14793), 1,
      aux_sym_basic_type_token22,
    ACTIONS(14796), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14799), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14802), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14805), 1,
      aux_sym_separator_action_token1,
    ACTIONS(14808), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(14811), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(14814), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(14817), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(14825), 1,
      sym_trigger_keyword,
    ACTIONS(14828), 1,
      sym_area_keyword,
    ACTIONS(14831), 1,
      sym_group_keyword,
    ACTIONS(14834), 1,
      sym_property_name,
    STATE(5874), 1,
      sym_preproc_if,
    ACTIONS(14820), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14823), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6551), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [44872] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14839), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14837), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [44940] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9762), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9760), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45008] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10132), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10130), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45076] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9762), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9760), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45144] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9814), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9812), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45212] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9938), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9936), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45280] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9778), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9776), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45348] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10023), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10021), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45416] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10000), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9998), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45484] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14843), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14841), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45552] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10010), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10008), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45620] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14847), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14845), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45688] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14851), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14849), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45756] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12161), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12163), 31,
      aux_sym_where_condition_token1,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [45824] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14855), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14853), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45892] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14859), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14857), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [45960] = 9,
    ACTIONS(5388), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5407), 1,
      anon_sym_DOT,
    ACTIONS(5412), 1,
      anon_sym_EQ,
    STATE(7165), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3681), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5405), 18,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(3683), 27,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [46040] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9766), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9764), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46108] = 4,
    ACTIONS(14861), 1,
      aux_sym_else_table_relation_fragment_token1,
    ACTIONS(13123), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13121), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [46178] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14865), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14863), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46246] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3784), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3786), 49,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [46314] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9770), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9768), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46382] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9818), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9816), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46450] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9828), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9826), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46518] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9832), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9830), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46586] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14869), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14867), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46654] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14873), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14871), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46722] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14877), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14875), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46790] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14881), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14879), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46858] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14885), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14883), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46926] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14889), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14887), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [46994] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14893), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14891), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47062] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9950), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9948), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47130] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10069), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10067), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47198] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14897), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14895), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47266] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10107), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10105), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47334] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14901), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14899), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47402] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14905), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14903), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47470] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9890), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9888), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47538] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14909), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14907), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47606] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14913), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14911), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47674] = 21,
    ACTIONS(5191), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(5193), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(5195), 1,
      aux_sym_basic_type_token22,
    ACTIONS(5197), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(5199), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(5203), 1,
      aux_sym_separator_action_token1,
    ACTIONS(5205), 1,
      aux_sym_actionref_declaration_token1,
    ACTIONS(5207), 1,
      aux_sym_systemaction_declaration_token1,
    ACTIONS(5209), 1,
      aux_sym_fileuploadaction_declaration_token1,
    ACTIONS(5211), 1,
      aux_sym_customaction_declaration_token1,
    ACTIONS(5213), 1,
      sym_area_keyword,
    ACTIONS(5215), 1,
      sym_group_keyword,
    ACTIONS(14463), 1,
      anon_sym_LBRACK,
    ACTIONS(14465), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14473), 1,
      sym_trigger_keyword,
    ACTIONS(14475), 1,
      sym_property_name,
    STATE(5874), 1,
      sym_preproc_if,
    ACTIONS(14467), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14915), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    STATE(6523), 19,
      sym_property,
      sym__action_element,
      sym_action_area_section,
      sym_action_group_section,
      sym_action_declaration,
      sym_separator_action,
      sym_actionref_declaration,
      sym_systemaction_declaration,
      sym_fileuploadaction_declaration,
      sym_customaction_declaration,
      sym_addfirst_action_modification,
      sym_addlast_action_modification,
      sym_addafter_action_modification,
      sym_addbefore_action_modification,
      sym_modify_action_modification,
      sym_trigger_declaration,
      sym_attribute_item,
      sym_preproc_conditional_actions,
      aux_sym_actions_section_repeat1,
  [47778] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14919), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14917), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47846] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14923), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14921), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47914] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14927), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14925), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [47982] = 7,
    ACTIONS(14706), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(14708), 1,
      anon_sym_AMP_AMP,
    ACTIONS(14716), 1,
      aux_sym_preproc_or_expression_token1,
    ACTIONS(14718), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5372), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5370), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48058] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14931), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14929), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48126] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9774), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9772), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48194] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14935), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14933), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48262] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9954), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9952), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48330] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9958), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9956), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48398] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10085), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10083), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48466] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9968), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9966), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48534] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9782), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9780), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48602] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9890), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9888), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48670] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10065), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10063), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [48738] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12204), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12206), 31,
      aux_sym_where_condition_token1,
      aux_sym_else_table_relation_fragment_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [48806] = 3,
    ACTIONS(5279), 3,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
      aux_sym_basic_type_token22,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5277), 53,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [48874] = 4,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3663), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3564), 19,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(3665), 30,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [48944] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14939), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14937), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [49012] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9786), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9784), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [49080] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9804), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(9802), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [49148] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10142), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10140), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [49216] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(10162), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(10160), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [49284] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14943), 14,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(14941), 42,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_split_procedure_body_token2,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [49352] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9564), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9566), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49419] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9277), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49486] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12813), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12815), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49553] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12819), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49620] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12819), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49687] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12819), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49754] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12819), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49821] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12817), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12819), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49888] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12823), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [49955] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12823), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50022] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12823), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50089] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12823), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50156] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12821), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12823), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50223] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12827), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50290] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12827), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50357] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12825), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12827), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50424] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12831), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50491] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12831), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50558] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12829), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12831), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50625] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9347), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9349), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50692] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12798), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12800), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50759] = 6,
    ACTIONS(5394), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5407), 1,
      anon_sym_DOT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3681), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5405), 19,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(3683), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [50832] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12975), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12977), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50899] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12983), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12985), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [50966] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12983), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12985), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51033] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12987), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12989), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51100] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12987), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12989), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51167] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9391), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9393), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51234] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9399), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9401), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51301] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9403), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9405), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51368] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12993), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51435] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12993), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51502] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12993), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51569] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12993), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51636] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12991), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12993), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51703] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13001), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51770] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13001), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51837] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13001), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51904] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13001), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [51971] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12999), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13001), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52038] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9620), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9622), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52105] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9620), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9622), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52172] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9656), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9658), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52239] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9656), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9658), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52306] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13017), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52373] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13017), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52440] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13017), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52507] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13017), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52574] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13015), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13017), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52641] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13021), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52708] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13021), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52775] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13021), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52842] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13021), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52909] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13019), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13021), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [52976] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12760), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12762), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53043] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12229), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53110] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12229), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53177] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12229), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53244] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12229), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53311] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12227), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12229), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53378] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12233), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53445] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12233), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53512] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12233), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53579] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12233), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53646] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12231), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12233), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53713] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14947), 1,
      anon_sym_STAR,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(14951), 1,
      sym_integer,
    STATE(17079), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [53794] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12161), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12163), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53861] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12869), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12871), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53928] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12889), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12891), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [53995] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14956), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(14953), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54062] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9351), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9353), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54129] = 4,
    ACTIONS(14959), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12247), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12245), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54198] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9279), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9281), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54265] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9283), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9285), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54332] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9295), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9297), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54399] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9351), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9353), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54466] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9355), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9357), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54533] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12249), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12251), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54600] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12249), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12251), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54667] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12253), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12255), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54734] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12253), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12255), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54801] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12257), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12259), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54868] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12257), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12259), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [54935] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12261), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12263), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55002] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12261), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12263), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55069] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12267), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55136] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12267), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55203] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12267), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55270] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12267), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55337] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12265), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12267), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55404] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12271), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55471] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12271), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55538] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12271), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55605] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12271), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55672] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12269), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12271), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55739] = 4,
    ACTIONS(14961), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12855), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12853), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55808] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12857), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12859), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55875] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12861), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12863), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [55942] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12873), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12875), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56009] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12877), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12879), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56076] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12881), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12883), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56143] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12885), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12887), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56210] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12897), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12899), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56277] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12901), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12903), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56344] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12905), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12907), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56411] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12909), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12911), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56478] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12917), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12919), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56545] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12921), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12923), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56612] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12925), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12927), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56679] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12929), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12931), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56746] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9612), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9614), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56813] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12285), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12287), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56880] = 4,
    ACTIONS(14963), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12293), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12291), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [56949] = 4,
    ACTIONS(14965), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12293), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12291), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57018] = 4,
    ACTIONS(14967), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12285), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12287), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57087] = 4,
    ACTIONS(14969), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12303), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12301), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57156] = 4,
    ACTIONS(14971), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12303), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12301), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57225] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9616), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9618), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57292] = 4,
    ACTIONS(14973), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12311), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12309), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57361] = 4,
    ACTIONS(14975), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12311), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12309), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57430] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9626), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9628), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57497] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9634), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9636), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57564] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9638), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9640), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57631] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12315), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12317), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57698] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12315), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12317), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57765] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12319), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12321), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57832] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12319), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12321), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57899] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12893), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12895), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [57966] = 28,
    ACTIONS(14977), 1,
      anon_sym_RBRACE,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15019), 1,
      sym_view_keyword,
    STATE(4385), 1,
      sym_preproc_if,
    STATE(14758), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    STATE(15264), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7265), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [58083] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7420), 17,
      sym_continue_as_identifier,
      sym_preproc_close,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(7418), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [58150] = 5,
    ACTIONS(15021), 1,
      anon_sym_LBRACK,
    ACTIONS(15025), 4,
      sym_procedure_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(14956), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(14953), 26,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58221] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9680), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9682), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58288] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9684), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9686), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58355] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9688), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9690), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58422] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12323), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12325), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58489] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12323), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12325), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58556] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12327), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12329), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58623] = 4,
    ACTIONS(15029), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12335), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12333), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58692] = 4,
    ACTIONS(15031), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12335), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12333), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58761] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12339), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12341), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58828] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12339), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12341), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58895] = 4,
    ACTIONS(15033), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12347), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12345), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [58964] = 4,
    ACTIONS(15035), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12347), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12345), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59033] = 4,
    ACTIONS(15037), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12339), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12341), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59102] = 4,
    ACTIONS(15039), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12339), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12341), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59171] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9692), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9694), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59238] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12357), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59305] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12357), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59372] = 4,
    ACTIONS(15041), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12371), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12369), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59441] = 4,
    ACTIONS(15043), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12371), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12369), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59510] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15045), 1,
      anon_sym_STAR,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15049), 1,
      sym_integer,
    STATE(16485), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [59593] = 4,
    ACTIONS(15051), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12357), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59662] = 4,
    ACTIONS(15053), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12355), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12357), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59731] = 4,
    ACTIONS(15055), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12383), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12381), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59800] = 4,
    ACTIONS(15057), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12383), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12381), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59869] = 4,
    ACTIONS(15059), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12327), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12329), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [59938] = 4,
    ACTIONS(15061), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12397), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12395), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60007] = 4,
    ACTIONS(15063), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12397), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12395), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60076] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9716), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9718), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60143] = 4,
    ACTIONS(15065), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12405), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12403), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60212] = 4,
    ACTIONS(15067), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12405), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12403), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60281] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12933), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12935), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60348] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12865), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12867), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60415] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9608), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9610), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60482] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12945), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12947), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60549] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9630), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9632), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60616] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12949), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12951), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60683] = 4,
    ACTIONS(15069), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12949), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12951), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60752] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15045), 1,
      anon_sym_STAR,
    ACTIONS(15071), 1,
      sym_integer,
    STATE(17959), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [60833] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15073), 1,
      anon_sym_STAR,
    ACTIONS(15075), 1,
      sym_integer,
    STATE(16557), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [60916] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9239), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9241), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [60983] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9243), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9245), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61050] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12955), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12957), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61117] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9247), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9249), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61184] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9251), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9253), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61251] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9257), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61318] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9259), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9261), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61385] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9257), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61452] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12419), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12421), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61519] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12419), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12421), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61586] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12423), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12425), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61653] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12423), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12425), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61720] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12427), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12429), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61787] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12427), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12429), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61854] = 4,
    ACTIONS(15077), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12435), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12433), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61923] = 4,
    ACTIONS(15079), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12435), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12433), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [61992] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9265), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62059] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9265), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62126] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9267), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9269), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62193] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9265), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62260] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9271), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9273), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62327] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12439), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12441), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62394] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12439), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12441), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62461] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12443), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12445), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62528] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12443), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12445), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62595] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15073), 1,
      anon_sym_STAR,
    ACTIONS(15081), 1,
      sym_integer,
    STATE(16833), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [62676] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15083), 1,
      anon_sym_STAR,
    ACTIONS(15085), 1,
      sym_integer,
    STATE(16473), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [62759] = 4,
    ACTIONS(15087), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12451), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12449), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62828] = 4,
    ACTIONS(15089), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12451), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12449), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62897] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12457), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [62964] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12457), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63031] = 4,
    ACTIONS(15091), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12463), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12461), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63100] = 4,
    ACTIONS(15093), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12463), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12461), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63169] = 4,
    ACTIONS(15095), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12457), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63238] = 4,
    ACTIONS(15097), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12455), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12457), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63307] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9247), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9249), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63374] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12473), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12475), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63441] = 4,
    ACTIONS(15099), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12481), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12479), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63510] = 4,
    ACTIONS(15101), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12481), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12479), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63579] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12485), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12487), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63646] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12485), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12487), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63713] = 4,
    ACTIONS(15103), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12493), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12491), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63782] = 4,
    ACTIONS(15105), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12493), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12491), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63851] = 4,
    ACTIONS(15107), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12485), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12487), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63920] = 4,
    ACTIONS(15109), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12485), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12487), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [63989] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9257), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64056] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12225), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12223), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64123] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12225), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12223), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64190] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9277), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64257] = 4,
    ACTIONS(15111), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12509), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12507), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64326] = 4,
    ACTIONS(15113), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12225), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12223), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64395] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15083), 1,
      anon_sym_STAR,
    ACTIONS(15115), 1,
      sym_integer,
    STATE(17869), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [64476] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15117), 1,
      anon_sym_STAR,
    ACTIONS(15119), 1,
      sym_integer,
    STATE(16548), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [64559] = 4,
    ACTIONS(15121), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12225), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12223), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64628] = 4,
    ACTIONS(15123), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12519), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12517), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64697] = 4,
    ACTIONS(15125), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12519), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12517), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64766] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15117), 1,
      anon_sym_STAR,
    ACTIONS(15127), 1,
      sym_integer,
    STATE(17743), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [64847] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15129), 1,
      anon_sym_STAR,
    ACTIONS(15131), 1,
      sym_integer,
    STATE(16539), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [64930] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12959), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12961), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [64997] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15129), 1,
      anon_sym_STAR,
    ACTIONS(15133), 1,
      sym_integer,
    STATE(17247), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [65078] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15135), 1,
      anon_sym_STAR,
    ACTIONS(15137), 1,
      sym_integer,
    STATE(16496), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [65161] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15135), 1,
      anon_sym_STAR,
    ACTIONS(15139), 1,
      sym_integer,
    STATE(18054), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [65242] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15141), 1,
      anon_sym_STAR,
    ACTIONS(15143), 1,
      sym_integer,
    STATE(16563), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [65325] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15141), 1,
      anon_sym_STAR,
    ACTIONS(15145), 1,
      sym_integer,
    STATE(16601), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [65406] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15147), 1,
      anon_sym_STAR,
    ACTIONS(15149), 1,
      sym_integer,
    STATE(16449), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [65489] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15147), 1,
      anon_sym_STAR,
    ACTIONS(15151), 1,
      sym_integer,
    STATE(17075), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 14,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [65570] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12913), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12915), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [65637] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12963), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12965), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [65704] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12967), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12969), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [65771] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12973), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [65838] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12973), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [65905] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3663), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3665), 47,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [65972] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12973), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66039] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12843), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12845), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66106] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12981), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66173] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12981), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66240] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12981), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66307] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9642), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9644), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66374] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9648), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9650), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66441] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9648), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9650), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66508] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12937), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12939), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66575] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9652), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9654), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66642] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9652), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9654), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66709] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12281), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12283), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66776] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12995), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12997), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66843] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13003), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13005), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66910] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13007), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13009), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [66977] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6361), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(6359), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67044] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13370), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(15153), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67111] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9287), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9289), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67178] = 28,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15019), 1,
      sym_view_keyword,
    ACTIONS(15155), 1,
      anon_sym_RBRACE,
    STATE(4385), 1,
      sym_preproc_if,
    STATE(14754), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    STATE(15262), 2,
      sym_view_definition,
      aux_sym_addfirst_views_modification_repeat1,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7263), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [67295] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12204), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12206), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67362] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14947), 1,
      anon_sym_STAR,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15157), 1,
      sym_integer,
    STATE(16524), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 13,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [67445] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12847), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12849), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67512] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3663), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3665), 47,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [67579] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9319), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9321), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67646] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9323), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9325), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67713] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9327), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9329), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67780] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9333), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67847] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9335), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9337), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67914] = 5,
    ACTIONS(12702), 1,
      anon_sym_SEMI,
    ACTIONS(12281), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12706), 20,
      sym_property_name,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12704), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [67985] = 4,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12281), 5,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(12706), 20,
      sym_property_name,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12704), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68054] = 4,
    ACTIONS(12708), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12712), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12710), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68123] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9333), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68190] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9339), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9341), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68257] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9345), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68324] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9359), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9361), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68391] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12610), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12612), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68458] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12610), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12612), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68525] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9365), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68592] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9367), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9369), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68659] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9365), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68726] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9371), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9373), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68793] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12839), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12841), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68860] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9375), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9377), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68927] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9365), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [68994] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9367), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9369), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69061] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9379), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9381), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69128] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9383), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9385), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69195] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9379), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9381), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69262] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12622), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12624), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69329] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12622), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12624), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69396] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9291), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9293), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69463] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12409), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12411), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69530] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12626), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12628), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69597] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12415), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12417), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69664] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12626), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12628), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69731] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12630), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12632), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69798] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12664), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69865] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12630), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12632), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69932] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12664), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [69999] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12664), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70066] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12664), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70133] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12664), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70200] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12835), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70267] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12835), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70334] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12835), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70401] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12835), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70468] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12835), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70535] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12235), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12237), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70602] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12235), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12237), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70669] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12235), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12237), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70736] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12239), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12241), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70803] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12239), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12241), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70870] = 4,
    ACTIONS(15159), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12638), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12636), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [70939] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12239), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12241), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71006] = 4,
    ACTIONS(15161), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12638), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12636), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71075] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9387), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9389), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71142] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9333), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71209] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12941), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12943), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71276] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9696), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9698), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71343] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9700), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9702), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71410] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9700), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9702), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71477] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9335), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9337), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71544] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9700), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9702), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71611] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9333), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71678] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12642), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12644), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71745] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12642), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12644), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71812] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9700), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9702), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71879] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9704), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9706), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [71946] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9704), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9706), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72013] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9704), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9706), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72080] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9704), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9706), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72147] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12646), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12648), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72214] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12646), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12648), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72281] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12650), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12652), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72348] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12650), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12652), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72415] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9708), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9710), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72482] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9708), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9710), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72549] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9712), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9714), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72616] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9712), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9714), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72683] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12359), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12361), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72750] = 4,
    ACTIONS(15163), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12658), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12656), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72819] = 4,
    ACTIONS(15165), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12658), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12656), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72888] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9345), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [72955] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9345), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73022] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12363), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12365), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73089] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12363), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12365), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73156] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12363), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12365), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73223] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12385), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12387), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73290] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9359), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9361), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73357] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9345), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73424] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9395), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9397), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73491] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12666), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12668), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73558] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12666), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12668), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73625] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12670), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12672), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73692] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12670), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12672), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73759] = 4,
    ACTIONS(15167), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12678), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12676), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73828] = 4,
    ACTIONS(15169), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12678), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12676), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73897] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12682), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12684), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [73964] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12682), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12684), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74031] = 4,
    ACTIONS(15171), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12690), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12688), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74100] = 4,
    ACTIONS(15173), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12690), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12688), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74169] = 4,
    ACTIONS(15175), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12682), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12684), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74238] = 4,
    ACTIONS(15177), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12682), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12684), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74307] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12385), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12387), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74374] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12385), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12387), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74441] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12716), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12718), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74508] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12720), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12722), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74575] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12724), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12726), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74642] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12728), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12730), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74709] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12732), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12734), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74776] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12736), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12738), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74843] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9410), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9412), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74910] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9414), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9416), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [74977] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9418), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9420), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75044] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9422), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9424), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75111] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9426), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9428), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75178] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9430), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9432), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75245] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9434), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9436), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75312] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9438), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9440), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75379] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9442), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9444), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75446] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9446), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9448), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75513] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9442), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9444), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75580] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9430), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9432), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75647] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9450), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9452), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75714] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9454), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9456), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75781] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9458), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9460), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75848] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12744), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12746), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75915] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12744), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12746), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [75982] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9462), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9464), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76049] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9466), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9468), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76116] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9470), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9472), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76183] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9474), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9476), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76250] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9470), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9472), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76317] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9414), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9416), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76384] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9418), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9420), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76451] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9422), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9424), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76518] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12772), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12774), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76585] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12772), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12774), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76652] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9480), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76719] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9482), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9484), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76786] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9480), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76853] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9486), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9488), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76920] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9426), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9428), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [76987] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12740), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12742), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77054] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9480), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77121] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12748), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12750), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77188] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12752), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12754), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77255] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12501), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12503), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77322] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12756), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12758), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77389] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13023), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(13025), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77456] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12764), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12766), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77523] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12598), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12600), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77590] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12604), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77657] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12604), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77724] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12604), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77791] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12604), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77858] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12768), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12770), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77925] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12602), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12604), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [77992] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12608), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78059] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12608), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78126] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12608), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78193] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12608), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78260] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12606), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12608), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78327] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9720), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9722), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78394] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12614), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12616), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78461] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12620), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78528] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12620), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78595] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9482), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9484), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78662] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9490), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9492), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78729] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9494), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9496), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78796] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9490), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9492), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78863] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12778), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12780), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78930] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12778), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12780), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [78997] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12782), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12784), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79064] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12782), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12784), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79131] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12786), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12788), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79198] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12786), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12788), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79265] = 4,
    ACTIONS(15179), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12794), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12792), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79334] = 4,
    ACTIONS(15181), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12794), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12792), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79403] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12620), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79470] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12620), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79537] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12618), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12620), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79604] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12700), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79671] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12700), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79738] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12700), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79805] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12700), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79872] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12698), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12700), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [79939] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9724), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9726), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80006] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9724), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9726), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80073] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9508), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9510), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80140] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9512), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9514), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80207] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9516), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9518), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80274] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9520), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9522), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80341] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9524), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9526), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80408] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9528), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9530), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80475] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9532), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9534), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80542] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9536), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9538), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80609] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9540), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9542), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80676] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9544), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9546), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80743] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9508), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9510), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80810] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9548), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9550), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80877] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9552), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9554), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [80944] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9556), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9558), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81011] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9560), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9562), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81078] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9728), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9730), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81145] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9560), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9562), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81212] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9548), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9550), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81279] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9568), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9570), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81346] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9572), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9574), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81413] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9576), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9578), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81480] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12809), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12811), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81547] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12809), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12811), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81614] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9728), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9730), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81681] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9732), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9734), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81748] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9237), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81815] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9237), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81882] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9237), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [81949] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9237), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82016] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9277), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82083] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9277), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82150] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9580), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9582), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82217] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9584), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9586), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82284] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9588), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9590), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82351] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9592), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9594), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82418] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9596), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9598), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82485] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9600), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9602), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82552] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9604), 25,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(9606), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82619] = 4,
    ACTIONS(15183), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12509), 24,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_var_attribute_open,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_quoted_identifier,
    ACTIONS(12507), 30,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [82688] = 4,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6589), 7,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 19,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(6591), 28,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [82756] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3772), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3774), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [82822] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3764), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3766), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [82888] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3865), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3867), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_string_literal,
      sym_verbatim_string,
  [82954] = 4,
    ACTIONS(15185), 2,
      aux_sym_preproc_or_expression_token1,
      anon_sym_PIPE_PIPE,
    ACTIONS(15187), 2,
      aux_sym_preproc_and_expression_token1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5372), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83022] = 4,
    ACTIONS(15189), 1,
      anon_sym_DOT,
    STATE(7123), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3701), 52,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83090] = 7,
    ACTIONS(5394), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5407), 1,
      anon_sym_DOT,
    ACTIONS(5412), 1,
      anon_sym_EQ,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3681), 6,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5405), 18,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(3683), 27,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [83164] = 3,
    ACTIONS(8335), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8333), 53,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83230] = 4,
    ACTIONS(8383), 1,
      sym_table_keyword,
    ACTIONS(15191), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8379), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83298] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3776), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3778), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [83364] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5376), 54,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      aux_sym_preproc_or_expression_token1,
      anon_sym_PIPE_PIPE,
      aux_sym_preproc_and_expression_token1,
      anon_sym_AMP_AMP,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83428] = 4,
    ACTIONS(15189), 1,
      anon_sym_DOT,
    STATE(7112), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3695), 52,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83496] = 4,
    ACTIONS(15185), 2,
      aux_sym_preproc_or_expression_token1,
      anon_sym_PIPE_PIPE,
    ACTIONS(15187), 2,
      aux_sym_preproc_and_expression_token1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5360), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83564] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3865), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3867), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_string_literal,
      sym_verbatim_string,
  [83630] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3865), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3867), 46,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_string_literal,
      sym_verbatim_string,
  [83696] = 4,
    ACTIONS(15185), 2,
      aux_sym_preproc_or_expression_token1,
      anon_sym_PIPE_PIPE,
    ACTIONS(15187), 2,
      aux_sym_preproc_and_expression_token1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5401), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83764] = 4,
    ACTIONS(15193), 1,
      anon_sym_DOT,
    STATE(7123), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3705), 52,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_where_clause_token1,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83832] = 3,
    ACTIONS(15187), 2,
      aux_sym_preproc_and_expression_token1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5380), 52,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      aux_sym_preproc_or_expression_token1,
      anon_sym_PIPE_PIPE,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [83898] = 4,
    ACTIONS(15198), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(11686), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15196), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [83966] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8673), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15200), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [84031] = 3,
    ACTIONS(8440), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8438), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84096] = 13,
    ACTIONS(15202), 1,
      anon_sym_SEMI,
    ACTIONS(15210), 1,
      sym_var_keyword,
    STATE(5116), 1,
      sym_preproc_split_procedure_body,
    STATE(5146), 1,
      sym_preproc_split_complete_body,
    STATE(5147), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(16180), 1,
      sym_preproc_conditional_var_block,
    STATE(16181), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15213), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15207), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15205), 37,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84181] = 11,
    ACTIONS(15216), 1,
      sym_identifier,
    ACTIONS(15218), 1,
      sym_quoted_identifier,
    ACTIONS(15220), 1,
      sym_var_attribute_open,
    STATE(3161), 1,
      sym_preproc_if,
    STATE(15918), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8300), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(8329), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7134), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8331), 24,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84262] = 13,
    ACTIONS(15210), 1,
      sym_var_keyword,
    ACTIONS(15222), 1,
      anon_sym_SEMI,
    STATE(5133), 1,
      sym_preproc_split_procedure_body,
    STATE(5156), 1,
      sym_preproc_split_complete_body,
    STATE(5208), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15976), 1,
      sym_preproc_conditional_var_block,
    STATE(15977), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15213), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15207), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15205), 37,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84347] = 13,
    ACTIONS(15225), 1,
      anon_sym_SEMI,
    ACTIONS(15233), 1,
      sym_var_keyword,
    STATE(5151), 1,
      sym_preproc_split_procedure_body,
    STATE(5152), 1,
      sym_preproc_split_complete_body,
    STATE(5153), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(16183), 1,
      sym_preproc_conditional_var_block,
    STATE(16184), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15236), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15230), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15228), 37,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84432] = 13,
    ACTIONS(15233), 1,
      sym_var_keyword,
    ACTIONS(15239), 1,
      anon_sym_SEMI,
    STATE(5211), 1,
      sym_preproc_split_procedure_body,
    STATE(5220), 1,
      sym_preproc_split_complete_body,
    STATE(5229), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15978), 1,
      sym_preproc_conditional_var_block,
    STATE(15984), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15236), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15230), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15228), 37,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84517] = 3,
    ACTIONS(8444), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8442), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84582] = 11,
    ACTIONS(15216), 1,
      sym_identifier,
    ACTIONS(15218), 1,
      sym_quoted_identifier,
    ACTIONS(15220), 1,
      sym_var_attribute_open,
    STATE(3161), 1,
      sym_preproc_if,
    STATE(15918), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8296), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(8300), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7147), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8298), 24,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84663] = 14,
    ACTIONS(15242), 1,
      anon_sym_SEMI,
    ACTIONS(15254), 1,
      sym_var_keyword,
    STATE(5274), 1,
      sym_preproc_split_procedure_body,
    STATE(5275), 1,
      sym_preproc_split_complete_body,
    STATE(5276), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15854), 1,
      sym_preproc_conditional_var_block,
    STATE(15855), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15258), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15247), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15251), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(15245), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84750] = 14,
    ACTIONS(15262), 1,
      anon_sym_SEMI,
    ACTIONS(15274), 1,
      sym_var_keyword,
    STATE(5278), 1,
      sym_preproc_split_procedure_body,
    STATE(5280), 1,
      sym_preproc_split_complete_body,
    STATE(5281), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15867), 1,
      sym_preproc_conditional_var_block,
    STATE(15868), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15278), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15267), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15271), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(15265), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84837] = 3,
    ACTIONS(7787), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7785), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84902] = 3,
    ACTIONS(7770), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8426), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [84967] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3768), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3770), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85032] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3705), 53,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_DOT,
      aux_sym_where_clause_token1,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [85095] = 11,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(15282), 1,
      anon_sym_STAR,
    ACTIONS(15284), 1,
      sym_integer,
    STATE(17067), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 11,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85176] = 5,
    ACTIONS(15286), 1,
      anon_sym_DOT,
    STATE(7142), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3703), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3705), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_temporary_keyword,
  [85245] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8408), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15289), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [85310] = 3,
    ACTIONS(8448), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8446), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [85375] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3784), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3786), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85440] = 14,
    ACTIONS(15222), 1,
      anon_sym_SEMI,
    ACTIONS(15298), 1,
      sym_var_keyword,
    STATE(5133), 1,
      sym_preproc_split_procedure_body,
    STATE(5156), 1,
      sym_preproc_split_complete_body,
    STATE(5208), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15976), 1,
      sym_preproc_conditional_var_block,
    STATE(15977), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15302), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15291), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15295), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(15205), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [85527] = 11,
    ACTIONS(15306), 1,
      sym_identifier,
    ACTIONS(15309), 1,
      sym_quoted_identifier,
    ACTIONS(15312), 1,
      sym_var_attribute_open,
    STATE(3161), 1,
      sym_preproc_if,
    STATE(15918), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8313), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(8320), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7147), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(8315), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8318), 24,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [85608] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8688), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15315), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [85673] = 11,
    ACTIONS(15216), 1,
      sym_identifier,
    ACTIONS(15218), 1,
      sym_quoted_identifier,
    ACTIONS(15220), 1,
      sym_var_attribute_open,
    STATE(3161), 1,
      sym_preproc_if,
    STATE(15918), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8300), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(8306), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7147), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8308), 24,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [85754] = 4,
    ACTIONS(15317), 1,
      sym_temporary_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3746), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3748), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [85821] = 5,
    ACTIONS(15319), 1,
      anon_sym_DOT,
    STATE(7169), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3693), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_temporary_keyword,
  [85890] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8688), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15315), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [85955] = 9,
    ACTIONS(15326), 1,
      sym_var_keyword,
    STATE(10131), 1,
      sym_preproc_if,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15329), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(15985), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(5055), 3,
      sym_preproc_split_procedure_body,
      sym_preproc_split_complete_body,
      sym_code_block,
    ACTIONS(15323), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15321), 38,
      sym_property_name,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86032] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12119), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15332), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [86097] = 20,
    ACTIONS(12179), 1,
      sym_var_keyword,
    ACTIONS(15334), 1,
      sym_identifier,
    ACTIONS(15336), 1,
      anon_sym_SEMI,
    ACTIONS(15338), 1,
      anon_sym_COLON,
    ACTIONS(15340), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15342), 1,
      sym_quoted_identifier,
    ACTIONS(15344), 1,
      sym_begin_keyword,
    STATE(8775), 1,
      sym__procedure_return_specification,
    STATE(8776), 1,
      sym__procedure_named_return,
    STATE(9972), 1,
      sym_interface_procedure_suffix,
    STATE(10176), 1,
      sym_preproc_if,
    ACTIONS(12181), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(15497), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(16509), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(12171), 3,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    STATE(6083), 3,
      sym_preproc_split_procedure_body,
      sym_preproc_split_complete_body,
      sym_code_block,
    ACTIONS(12177), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(12173), 16,
      aux_sym_modify_modification_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86196] = 9,
    ACTIONS(15326), 1,
      sym_var_keyword,
    STATE(10131), 1,
      sym_preproc_if,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15329), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(15853), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(5273), 3,
      sym_preproc_split_procedure_body,
      sym_preproc_split_complete_body,
      sym_code_block,
    ACTIONS(15323), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15321), 38,
      sym_property_name,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86273] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3756), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3758), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86338] = 14,
    ACTIONS(15202), 1,
      anon_sym_SEMI,
    ACTIONS(15353), 1,
      sym_var_keyword,
    STATE(5116), 1,
      sym_preproc_split_procedure_body,
    STATE(5146), 1,
      sym_preproc_split_complete_body,
    STATE(5147), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(16180), 1,
      sym_preproc_conditional_var_block,
    STATE(16181), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15357), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15346), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15350), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(15205), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86425] = 13,
    ACTIONS(15361), 1,
      anon_sym_SEMI,
    ACTIONS(15367), 1,
      sym_var_keyword,
    STATE(4983), 1,
      sym_code_block,
    STATE(5299), 1,
      sym_preproc_split_procedure_body,
    STATE(5301), 1,
      sym_preproc_split_complete_body,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15988), 1,
      sym_preproc_conditional_var_block,
    STATE(15989), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15370), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15364), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15245), 37,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86510] = 13,
    ACTIONS(15373), 1,
      anon_sym_SEMI,
    ACTIONS(15379), 1,
      sym_var_keyword,
    STATE(4984), 1,
      sym_preproc_split_procedure_body,
    STATE(4985), 1,
      sym_preproc_split_complete_body,
    STATE(4986), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15990), 1,
      sym_preproc_conditional_var_block,
    STATE(15991), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15382), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15376), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15265), 37,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86595] = 13,
    ACTIONS(15367), 1,
      sym_var_keyword,
    ACTIONS(15385), 1,
      anon_sym_SEMI,
    STATE(5274), 1,
      sym_preproc_split_procedure_body,
    STATE(5275), 1,
      sym_preproc_split_complete_body,
    STATE(5276), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15854), 1,
      sym_preproc_conditional_var_block,
    STATE(15855), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15370), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15364), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15245), 37,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86680] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8704), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15388), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [86745] = 3,
    ACTIONS(8436), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8434), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86810] = 14,
    ACTIONS(15390), 1,
      anon_sym_SEMI,
    ACTIONS(15400), 1,
      sym_var_keyword,
    STATE(4983), 1,
      sym_code_block,
    STATE(5299), 1,
      sym_preproc_split_procedure_body,
    STATE(5301), 1,
      sym_preproc_split_complete_body,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15988), 1,
      sym_preproc_conditional_var_block,
    STATE(15989), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15404), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15393), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15397), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(15245), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [86897] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3790), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3792), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [86962] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8696), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15408), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87027] = 14,
    ACTIONS(15225), 1,
      anon_sym_SEMI,
    ACTIONS(15417), 1,
      sym_var_keyword,
    STATE(5151), 1,
      sym_preproc_split_procedure_body,
    STATE(5152), 1,
      sym_preproc_split_complete_body,
    STATE(5153), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(16183), 1,
      sym_preproc_conditional_var_block,
    STATE(16184), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15421), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15410), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15414), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(15228), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [87114] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8694), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15425), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87179] = 5,
    ACTIONS(15319), 1,
      anon_sym_DOT,
    STATE(7142), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3699), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3701), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_temporary_keyword,
  [87248] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8385), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15427), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87313] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8659), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15429), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87378] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8665), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15431), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87443] = 13,
    ACTIONS(15379), 1,
      sym_var_keyword,
    ACTIONS(15433), 1,
      anon_sym_SEMI,
    STATE(5278), 1,
      sym_preproc_split_procedure_body,
    STATE(5280), 1,
      sym_preproc_split_complete_body,
    STATE(5281), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15867), 1,
      sym_preproc_conditional_var_block,
    STATE(15868), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15382), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15376), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15265), 37,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [87528] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8665), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15431), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [87593] = 4,
    ACTIONS(7706), 1,
      aux_sym_where_clause_token1,
    STATE(7273), 1,
      sym_where_clause,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5386), 51,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [87660] = 10,
    ACTIONS(14945), 1,
      sym_identifier,
    ACTIONS(14949), 1,
      sym_quoted_identifier,
    ACTIONS(15282), 1,
      anon_sym_STAR,
    ACTIONS(15284), 1,
      sym_integer,
    STATE(17067), 1,
      sym__namespaced_or_simple_ref,
    STATE(7151), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(3665), 12,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_QMARK,
    ACTIONS(3663), 24,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [87739] = 14,
    ACTIONS(15436), 1,
      anon_sym_SEMI,
    ACTIONS(15446), 1,
      sym_var_keyword,
    STATE(4984), 1,
      sym_preproc_split_procedure_body,
    STATE(4985), 1,
      sym_preproc_split_complete_body,
    STATE(4986), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15990), 1,
      sym_preproc_conditional_var_block,
    STATE(15991), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15450), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15439), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15443), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(15265), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [87826] = 3,
    ACTIONS(8432), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8430), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [87891] = 20,
    ACTIONS(12179), 1,
      sym_var_keyword,
    ACTIONS(15334), 1,
      sym_identifier,
    ACTIONS(15338), 1,
      anon_sym_COLON,
    ACTIONS(15340), 1,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15342), 1,
      sym_quoted_identifier,
    ACTIONS(15344), 1,
      sym_begin_keyword,
    ACTIONS(15454), 1,
      anon_sym_SEMI,
    STATE(8724), 1,
      sym__procedure_return_specification,
    STATE(8731), 1,
      sym__procedure_named_return,
    STATE(9977), 1,
      sym_interface_procedure_suffix,
    STATE(10176), 1,
      sym_preproc_if,
    ACTIONS(12181), 2,
      sym_local_keyword,
      sym_protected_keyword,
    STATE(15688), 2,
      sym_preproc_conditional_var_block,
      sym_var_section,
    STATE(16509), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(12189), 3,
      sym_property_name,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    STATE(6188), 3,
      sym_preproc_split_procedure_body,
      sym_preproc_split_complete_body,
      sym_code_block,
    ACTIONS(12177), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(12191), 16,
      aux_sym_modify_modification_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [87990] = 3,
    ACTIONS(7725), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8428), 52,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [88055] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3760), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3762), 45,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [88120] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8694), 15,
      sym_continue_as_identifier,
      sym_preproc_open,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15425), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [88185] = 11,
    ACTIONS(15216), 1,
      sym_identifier,
    ACTIONS(15218), 1,
      sym_quoted_identifier,
    ACTIONS(15220), 1,
      sym_var_attribute_open,
    STATE(3161), 1,
      sym_preproc_if,
    STATE(15918), 2,
      sym__identifier_or_quoted,
      sym_keyword_as_identifier,
    ACTIONS(8296), 4,
      sym_property_name,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(8300), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7149), 5,
      sym_preproc_split_procedure,
      sym_var_attribute_item,
      sym_preproc_conditional_var,
      sym_variable_declaration,
      aux_sym_var_section_repeat1,
    ACTIONS(4043), 10,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
    ACTIONS(8298), 24,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [88266] = 14,
    ACTIONS(15239), 1,
      anon_sym_SEMI,
    ACTIONS(15463), 1,
      sym_var_keyword,
    STATE(5211), 1,
      sym_preproc_split_procedure_body,
    STATE(5220), 1,
      sym_preproc_split_complete_body,
    STATE(5229), 1,
      sym_code_block,
    STATE(10131), 1,
      sym_preproc_if,
    STATE(15978), 1,
      sym_preproc_conditional_var_block,
    STATE(15984), 1,
      sym_var_section,
    ACTIONS(12185), 2,
      sym_begin_keyword,
      aux_sym_preproc_split_procedure_body_token1,
    ACTIONS(15467), 2,
      sym_local_keyword,
      sym_protected_keyword,
    ACTIONS(15456), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15460), 16,
      sym_preproc_close,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
    ACTIONS(15228), 21,
      sym_property_name,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_internal_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [88353] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3738), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3740), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [88417] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5376), 12,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5374), 40,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_or_expression_token1,
      aux_sym_preproc_and_expression_token1,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [88481] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15471), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5363), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7238), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [88591] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3869), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3871), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [88655] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3881), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3883), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [88719] = 5,
    ACTIONS(15473), 1,
      anon_sym_COMMA,
    STATE(7190), 1,
      aux_sym_option_member_list_repeat2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(838), 7,
      anon_sym_SEMI,
      anon_sym_DASH,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym_quoted_identifier,
      sym_string_literal,
      sym_integer,
    ACTIONS(836), 43,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      aux_sym_where_condition_token1,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_separator_action_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_table_keyword,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_key_keyword,
      sym_dataset_keyword,
      sym_identifier,
  [88787] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3873), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3875), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [88851] = 7,
    ACTIONS(15476), 1,
      aux_sym_preproc_or_expression_token1,
    ACTIONS(15478), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(15480), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(15482), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5401), 10,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5399), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [88923] = 4,
    ACTIONS(15484), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3925), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3927), 43,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [88989] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15486), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10096), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89099] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3893), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3895), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [89163] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15488), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5387), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7203), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89273] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15490), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5394), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7217), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89383] = 4,
    ACTIONS(15492), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3931), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3933), 43,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [89449] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3945), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3947), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [89513] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15494), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8407), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89623] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15496), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8421), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89733] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15498), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8357), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7216), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89843] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15500), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5400), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [89953] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3873), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3875), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90017] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3869), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3871), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90081] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15502), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10094), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90191] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15504), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8356), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7201), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90301] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3921), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3923), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90365] = 3,
    ACTIONS(12965), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12963), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [90429] = 4,
    ACTIONS(15047), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3663), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3665), 43,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90495] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3909), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3911), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90559] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15506), 1,
      anon_sym_RBRACE,
    STATE(4385), 1,
      sym_preproc_if,
    STATE(14749), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7255), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90669] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15508), 1,
      anon_sym_RBRACE,
    STATE(4385), 1,
      sym_preproc_if,
    STATE(14753), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7256), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [90779] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3742), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3744), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90843] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3885), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3887), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [90907] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15510), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8422), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91017] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15512), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5359), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91127] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3941), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3943), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [91191] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3873), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3875), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [91255] = 3,
    ACTIONS(8335), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8333), 51,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [91319] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3877), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3879), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [91383] = 3,
    ACTIONS(12411), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12409), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [91447] = 6,
    ACTIONS(5388), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_COLON_COLON,
    STATE(7165), 1,
      sym_argument_list,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3681), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3683), 41,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [91517] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15514), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10117), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7206), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91627] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3869), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3871), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [91691] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3752), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3754), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [91755] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3632), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3634), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [91819] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3913), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3915), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [91883] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15516), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5356), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7235), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [91993] = 4,
    ACTIONS(8383), 1,
      sym_table_keyword,
    ACTIONS(15518), 1,
      anon_sym_COMMA,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8379), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [92059] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3917), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3919), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [92123] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15520), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10116), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7194), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92233] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15522), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10175), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7241), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92343] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3889), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3891), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [92407] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15524), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5360), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92517] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15526), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7959), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7257), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92627] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15528), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7960), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7258), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92737] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15530), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5370), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92847] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15532), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10107), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7242), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [92957] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15534), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10104), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7243), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93067] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15536), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10098), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93177] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15538), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10099), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93287] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15540), 1,
      anon_sym_RBRACE,
    STATE(4354), 1,
      sym_preproc_if,
    STATE(10101), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93397] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3897), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3899), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [93461] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3703), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3705), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_where_clause_token1,
      anon_sym_DOT_DOT,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
      sym_temporary_keyword,
  [93525] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3901), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3903), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [93589] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15542), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(8013), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7268), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93699] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15544), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7964), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93809] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15546), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5355), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7259), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [93919] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3905), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3907), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [93983] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15548), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8358), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7260), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94093] = 7,
    ACTIONS(15476), 1,
      aux_sym_preproc_or_expression_token1,
    ACTIONS(15478), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(15480), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(15482), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5372), 10,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5370), 38,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [94165] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15550), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8363), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7261), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94275] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15552), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8506), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7200), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94385] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15554), 1,
      anon_sym_RBRACE,
    STATE(4385), 1,
      sym_preproc_if,
    STATE(14719), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94495] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15556), 1,
      anon_sym_RBRACE,
    STATE(4385), 1,
      sym_preproc_if,
    STATE(14720), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94605] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15558), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7965), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94715] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15560), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7966), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94825] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15562), 1,
      anon_sym_RBRACE,
    STATE(4326), 1,
      sym_preproc_if,
    STATE(5407), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [94935] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15564), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8423), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95045] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15566), 1,
      anon_sym_RBRACE,
    STATE(4419), 1,
      sym_preproc_if,
    STATE(8424), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95155] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15568), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7957), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7267), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95265] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15570), 1,
      anon_sym_RBRACE,
    STATE(4385), 1,
      sym_preproc_if,
    STATE(14680), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95375] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3937), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3939), 44,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_else,
      anon_sym_ELSE,
      anon_sym_Else,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [95439] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15572), 1,
      anon_sym_RBRACE,
    STATE(4385), 1,
      sym_preproc_if,
    STATE(14681), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95549] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15574), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7958), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7248), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95659] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15576), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7963), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95769] = 26,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15578), 1,
      anon_sym_RBRACE,
    STATE(4358), 1,
      sym_preproc_if,
    STATE(7941), 2,
      sym_preproc_split_brace_close,
      sym_preproc_split_brace_close_if_only,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [95879] = 5,
    ACTIONS(15480), 1,
      aux_sym_preproc_and_expression_token1,
    ACTIONS(15482), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5380), 11,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(5378), 39,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      aux_sym_preproc_or_expression_token1,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [95947] = 3,
    ACTIONS(8444), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8442), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96010] = 3,
    ACTIONS(15580), 1,
      aux_sym_else_table_relation_fragment_token1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13121), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96073] = 3,
    ACTIONS(7770), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8426), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96136] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12204), 51,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96197] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12161), 51,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_else_table_relation_fragment_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96258] = 3,
    ACTIONS(7725), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8428), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96321] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15584), 10,
      sym_continue_as_identifier,
      anon_sym_DASH,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      sym_datetime_literal,
      sym_biginteger_literal,
      sym_quoted_identifier,
      sym_string_literal,
      sym_verbatim_string,
    ACTIONS(15582), 41,
      aux_sym_boolean_token1,
      aux_sym_boolean_token2,
      sym_decimal,
      aux_sym_tabledata_permission_token2,
      aux_sym_record_type_token1,
      aux_sym_basic_type_token21,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token48,
      anon_sym_not,
      anon_sym_NOT,
      anon_sym_Not,
      aux_sym_keyword_identifier_token1,
      aux_sym_keyword_identifier_token2,
      sym_date_literal,
      sym_time_literal,
      anon_sym_if,
      anon_sym_IF,
      anon_sym_If,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      anon_sym_enum,
      anon_sym_ENUM,
      anon_sym_Enum,
      anon_sym_eNUM,
      anon_sym_eNum,
      anon_sym_ENum,
      sym_identifier,
      sym_integer,
  [96384] = 3,
    ACTIONS(7787), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(7785), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96447] = 3,
    ACTIONS(8432), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8430), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96510] = 3,
    ACTIONS(8448), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8446), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96573] = 3,
    ACTIONS(8436), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8434), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96636] = 3,
    ACTIONS(8440), 1,
      sym_table_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8438), 50,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_tabledata_permission_token1,
      aux_sym_tabledata_permission_token2,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_page_keyword,
      anon_sym_codeunit,
      anon_sym_CODEUNIT,
      anon_sym_Codeunit,
      anon_sym_CodeUnit,
      anon_sym_COdeunit,
      anon_sym_codeUnit,
      sym_report_keyword,
      sym_query_keyword,
      anon_sym_xmlport,
      anon_sym_XMLPORT,
      anon_sym_Xmlport,
      anon_sym_XMLport,
      anon_sym_XMLPort,
      anon_sym_XmlPort,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_dataitem_keyword,
      sym_column_keyword,
      sym_filter_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96699] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12748), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96759] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9656), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96819] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12941), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96879] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9351), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96939] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9279), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [96999] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9283), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97059] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9295), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97119] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9351), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97179] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9355), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97239] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9612), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97299] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9616), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97359] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9626), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97419] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9634), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97479] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9638), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97539] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9680), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97599] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9684), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97659] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9688), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97719] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9692), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97779] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9716), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97839] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97899] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9239), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [97959] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9243), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98019] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9247), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98079] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9251), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98139] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98199] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9259), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98259] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98319] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98379] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98439] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9267), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98499] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9263), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98559] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9271), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98619] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9247), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98679] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9255), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98739] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9319), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98799] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9323), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98859] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9327), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98919] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [98979] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9335), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99039] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99099] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9339), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99159] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99219] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9359), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99279] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99339] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9367), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99399] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99459] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9371), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99519] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9375), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99579] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9363), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99639] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9367), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99699] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9379), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99759] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9383), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99819] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9379), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99879] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9387), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99939] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [99999] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9335), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100059] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9331), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100119] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100179] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100239] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9359), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100299] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9343), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100359] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9395), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100419] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9410), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100479] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9414), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100539] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9418), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100599] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9422), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100659] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9426), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100719] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9430), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100779] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9434), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100839] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9438), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100899] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9442), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [100959] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9446), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101019] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9442), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101079] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9430), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101139] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9450), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101199] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9454), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101259] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9458), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101319] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9462), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101379] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9466), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101439] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9470), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101499] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9474), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101559] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9470), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101619] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9414), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101679] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9418), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101739] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9422), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101799] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101859] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9482), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101919] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [101979] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9486), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102039] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9426), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102099] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9478), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102159] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9482), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102219] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9490), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102279] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9494), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102339] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9490), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102399] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9508), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102459] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9512), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102519] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9516), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102579] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9520), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102639] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9524), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102699] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9528), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102759] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9532), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102819] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9536), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102879] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9540), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102939] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9544), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [102999] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9508), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103059] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9548), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103119] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9552), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103179] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9556), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103239] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9560), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103299] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9564), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103359] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9560), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103419] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9548), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103479] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9568), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103539] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9572), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103599] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9576), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103659] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9580), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103719] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9584), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103779] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9588), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103839] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9592), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103899] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9596), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [103959] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9600), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104019] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9604), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104079] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9608), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104139] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9287), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104199] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12281), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104259] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9347), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104319] = 4,
    ACTIONS(15586), 1,
      anon_sym_LBRACE,
    ACTIONS(13113), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13109), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104383] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8903), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8901), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104445] = 4,
    ACTIONS(15588), 1,
      anon_sym_LBRACE,
    ACTIONS(13277), 2,
      aux_sym_where_condition_token1,
      aux_sym_basic_type_token6,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13273), 47,
      sym_property_name,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_movefirst_modification_token1,
      aux_sym_movelast_modification_token1,
      aux_sym_moveafter_modification_token1,
      aux_sym_movebefore_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_repeater_keyword,
      sym_cuegroup_keyword,
      sym_fixed_keyword,
      sym_grid_keyword,
      sym_part_keyword,
      sym_systempart_keyword,
      sym_usercontrol_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104509] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15590), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [104569] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8905), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104631] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8905), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104693] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8905), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104755] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8911), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8909), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104817] = 7,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3639), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3641), 39,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [104887] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9000), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8998), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [104949] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9004), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9002), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105011] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9004), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9002), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105073] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9006), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105135] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9006), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105197] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9006), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105259] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9235), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [105319] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9044), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105381] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9044), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105443] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9044), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105505] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9050), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9048), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105567] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9054), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9052), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105629] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9054), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9052), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105691] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9066), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9064), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105753] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9066), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9064), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105815] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9068), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105877] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9068), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [105939] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(9068), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [106001] = 34,
    ACTIONS(3576), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15602), 1,
      sym__assignment_operator,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    ACTIONS(15624), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_AND,
    ACTIONS(15628), 1,
      anon_sym_And,
    ACTIONS(15630), 1,
      anon_sym_or,
    ACTIONS(15632), 1,
      anon_sym_OR,
    ACTIONS(15634), 1,
      anon_sym_Or,
    ACTIONS(15636), 1,
      anon_sym_xor,
    ACTIONS(15638), 1,
      anon_sym_XOR,
    ACTIONS(15640), 1,
      anon_sym_Xor,
    ACTIONS(15642), 1,
      anon_sym_QMARK,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3578), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [106125] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8891), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8889), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [106187] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8891), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(8889), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [106249] = 4,
    ACTIONS(15646), 1,
      anon_sym_DOT,
    STATE(7447), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3695), 48,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106313] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106373] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15648), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106433] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106493] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12963), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106553] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12409), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106613] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6361), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106673] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9291), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106733] = 4,
    ACTIONS(15646), 1,
      anon_sym_DOT,
    STATE(7448), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3701), 48,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106797] = 4,
    ACTIONS(15650), 1,
      anon_sym_DOT,
    STATE(7448), 1,
      aux_sym__namespaced_or_simple_ref_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3705), 48,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106861] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15653), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106921] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3564), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      sym_begin_keyword,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_preproc_split_procedure_body_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_temporary_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [106981] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12933), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107041] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8903), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107101] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15655), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107161] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107221] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107281] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8907), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107341] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8911), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107401] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9000), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107461] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9004), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107521] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9004), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107581] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107641] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107701] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9008), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107761] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107821] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107881] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9046), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [107941] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9050), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108001] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9054), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108061] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9054), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108121] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9066), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108181] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9066), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108241] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108301] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108361] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9070), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108421] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8891), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108481] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(8891), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108541] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12937), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [108601] = 4,
    ACTIONS(15657), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6122), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6118), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108665] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6122), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6118), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108727] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6126), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6124), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108789] = 4,
    ACTIONS(15659), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(5961), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108853] = 4,
    ACTIONS(15661), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 9,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(5961), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108917] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(5961), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [108979] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5937), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(5935), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109041] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5937), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(5935), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109103] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6138), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6136), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109165] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6142), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6140), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109227] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6146), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6144), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109289] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6150), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6148), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109351] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6154), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6152), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109413] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6158), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6156), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109475] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6162), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6160), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109537] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6166), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6164), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109599] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6170), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6168), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109661] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6174), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6172), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109723] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6178), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6176), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109785] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6182), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6180), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109847] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6186), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6184), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109909] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6190), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6188), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [109971] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6194), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(6192), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [110033] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15663), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110093] = 4,
    ACTIONS(5394), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3681), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3683), 41,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [110157] = 3,
    ACTIONS(15666), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6122), 49,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110219] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6122), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110279] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6126), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110339] = 3,
    ACTIONS(15668), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 49,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110401] = 3,
    ACTIONS(15670), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 49,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110463] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5965), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110523] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5937), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110583] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5937), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110643] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6138), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110703] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6142), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110763] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6146), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110823] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6150), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110883] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6154), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [110943] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6158), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111003] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6162), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111063] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6166), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111123] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6170), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111183] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6174), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111243] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6178), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111303] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6182), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111363] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6186), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111423] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6190), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111483] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(6194), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111543] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(5277), 10,
      sym_property_name,
      sym_preproc_open,
      sym_var_attribute_open,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      sym_quoted_identifier,
    ACTIONS(5279), 40,
      aux_sym_where_condition_token1,
      aux_sym_addlast_fieldgroup_modification_token1,
      aux_sym_addfirst_fieldgroup_modification_token1,
      aux_sym_basic_type_token22,
      aux_sym_basic_type_token53,
      aux_sym_enum_value_declaration_token1,
      aux_sym_addafter_modification_token1,
      aux_sym_addbefore_modification_token1,
      aux_sym_modify_modification_token1,
      aux_sym_separator_action_token1,
      aux_sym_actionref_declaration_token1,
      aux_sym_systemaction_declaration_token1,
      aux_sym_fileuploadaction_declaration_token1,
      aux_sym_customaction_declaration_token1,
      aux_sym_assembly_declaration_token1,
      aux_sym_type_declaration_token1,
      sym_table_keyword,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_key_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_area_keyword,
      sym_group_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
      sym_identifier,
  [111605] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15672), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111665] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15675), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [111725] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15677), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7531), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [111831] = 5,
    ACTIONS(15679), 1,
      anon_sym_COMMA,
    STATE(7665), 1,
      aux_sym_option_member_list_repeat1,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(602), 8,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(600), 40,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [111897] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15681), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [112003] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9391), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [112063] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15683), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [112123] = 16,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3677), 5,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3679), 32,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112211] = 8,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3566), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3568), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112283] = 8,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3566), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3568), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112355] = 8,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3566), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3568), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112427] = 8,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3566), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3568), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112499] = 8,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3566), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3568), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112571] = 8,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3566), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3568), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112643] = 8,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3566), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3568), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112715] = 8,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3566), 7,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3568), 38,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_div,
      anon_sym_DIV,
      anon_sym_Div,
      anon_sym_mod,
      anon_sym_MOD,
      anon_sym_Mod,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112787] = 16,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3677), 5,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3679), 32,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [112875] = 23,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [112977] = 23,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113079] = 23,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113181] = 26,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    ACTIONS(15624), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_AND,
    ACTIONS(15628), 1,
      anon_sym_And,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113289] = 26,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    ACTIONS(15624), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_AND,
    ACTIONS(15628), 1,
      anon_sym_And,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113397] = 26,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    ACTIONS(15624), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_AND,
    ACTIONS(15628), 1,
      anon_sym_And,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113505] = 26,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    ACTIONS(15624), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_AND,
    ACTIONS(15628), 1,
      anon_sym_And,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113613] = 26,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    ACTIONS(15624), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_AND,
    ACTIONS(15628), 1,
      anon_sym_And,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113721] = 26,
    ACTIONS(3643), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    ACTIONS(15624), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_AND,
    ACTIONS(15628), 1,
      anon_sym_And,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3645), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113829] = 21,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3647), 3,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3649), 27,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [113927] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15688), 5,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
    ACTIONS(15685), 45,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [113989] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15690), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [114049] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9399), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [114109] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15692), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7558), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [114215] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15694), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [114321] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15694), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7560), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [114427] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15696), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [114533] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15698), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [114593] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15700), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [114653] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9403), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [114713] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15702), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7607), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [114819] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15704), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7566), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [114925] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15706), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115031] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15708), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [115091] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15710), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7569), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115197] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15712), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115303] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15712), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7571), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115409] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15714), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115515] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15716), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7573), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115621] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15718), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115727] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15720), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [115787] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15722), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7576), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115893] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15724), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [115999] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15724), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7578), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [116105] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15726), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [116211] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15728), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7580), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [116317] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15730), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [116423] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15732), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7582), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [116529] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15734), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [116635] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15734), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7584), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [116741] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15736), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [116847] = 16,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3726), 5,
      anon_sym_COLON,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3728), 32,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      aux_sym__expression_token1,
      aux_sym__expression_token2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
      anon_sym_and,
      anon_sym_AND,
      anon_sym_And,
      anon_sym_or,
      anon_sym_OR,
      anon_sym_Or,
      anon_sym_xor,
      anon_sym_XOR,
      anon_sym_Xor,
      anon_sym_QMARK,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
  [116935] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(15738), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [116995] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9620), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117055] = 33,
    ACTIONS(3673), 1,
      anon_sym_COLON,
    ACTIONS(15592), 1,
      anon_sym_DOT,
    ACTIONS(15594), 1,
      anon_sym_LBRACK,
    ACTIONS(15596), 1,
      anon_sym_DASH,
    ACTIONS(15598), 1,
      anon_sym_DOT_DOT,
    ACTIONS(15600), 1,
      anon_sym_STAR,
    ACTIONS(15604), 1,
      aux_sym__expression_token1,
    ACTIONS(15606), 1,
      aux_sym__expression_token2,
    ACTIONS(15608), 1,
      anon_sym_SLASH,
    ACTIONS(15610), 1,
      anon_sym_div,
    ACTIONS(15612), 1,
      anon_sym_DIV,
    ACTIONS(15614), 1,
      anon_sym_Div,
    ACTIONS(15616), 1,
      anon_sym_mod,
    ACTIONS(15618), 1,
      anon_sym_MOD,
    ACTIONS(15620), 1,
      anon_sym_Mod,
    ACTIONS(15622), 1,
      anon_sym_PLUS,
    ACTIONS(15624), 1,
      anon_sym_and,
    ACTIONS(15626), 1,
      anon_sym_AND,
    ACTIONS(15628), 1,
      anon_sym_And,
    ACTIONS(15630), 1,
      anon_sym_or,
    ACTIONS(15632), 1,
      anon_sym_OR,
    ACTIONS(15634), 1,
      anon_sym_Or,
    ACTIONS(15636), 1,
      anon_sym_xor,
    ACTIONS(15638), 1,
      anon_sym_XOR,
    ACTIONS(15640), 1,
      anon_sym_Xor,
    ACTIONS(15642), 1,
      anon_sym_QMARK,
    STATE(4465), 1,
      sym_comparison_operator,
    STATE(16522), 1,
      sym_in_keyword,
    ACTIONS(3608), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(15644), 3,
      anon_sym_in,
      anon_sym_IN,
      anon_sym_In,
    ACTIONS(3580), 4,
      anon_sym_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_GT,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(3675), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      sym__assignment_operator,
      anon_sym_then,
      anon_sym_THEN,
      anon_sym_Then,
      anon_sym_of,
      anon_sym_OF,
      anon_sym_Of,
      anon_sym_do,
      anon_sym_DO,
      anon_sym_Do,
  [117177] = 4,
    ACTIONS(12702), 1,
      anon_sym_SEMI,
    ACTIONS(12281), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12706), 45,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117241] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12281), 5,
      sym_preproc_open,
      anon_sym_SEMI,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(12706), 45,
      sym_property_name,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117303] = 3,
    ACTIONS(12708), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12712), 49,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117365] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12716), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117425] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12720), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117485] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12724), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117545] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12728), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117605] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12732), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117665] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12736), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117725] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12740), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117785] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(9275), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117845] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12752), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117905] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12756), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [117965] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13023), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118025] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12764), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118085] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12768), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118145] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12798), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118205] = 3,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12806), 5,
      anon_sym_LBRACK,
      sym_procedure_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
    ACTIONS(12802), 45,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118267] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15740), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7742), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [118373] = 25,
    ACTIONS(14979), 1,
      aux_sym_where_condition_token1,
    ACTIONS(14981), 1,
      aux_sym_addlast_fieldgroup_modification_token1,
    ACTIONS(14983), 1,
      aux_sym_addfirst_fieldgroup_modification_token1,
    ACTIONS(14985), 1,
      aux_sym_basic_type_token6,
    ACTIONS(14987), 1,
      aux_sym_addafter_modification_token1,
    ACTIONS(14989), 1,
      aux_sym_addbefore_modification_token1,
    ACTIONS(14991), 1,
      aux_sym_modify_modification_token1,
    ACTIONS(14993), 1,
      aux_sym_movefirst_modification_token1,
    ACTIONS(14995), 1,
      aux_sym_movelast_modification_token1,
    ACTIONS(14997), 1,
      aux_sym_moveafter_modification_token1,
    ACTIONS(14999), 1,
      aux_sym_movebefore_modification_token1,
    ACTIONS(15001), 1,
      sym_area_keyword,
    ACTIONS(15003), 1,
      sym_group_keyword,
    ACTIONS(15005), 1,
      sym_repeater_keyword,
    ACTIONS(15007), 1,
      sym_cuegroup_keyword,
    ACTIONS(15009), 1,
      sym_fixed_keyword,
    ACTIONS(15011), 1,
      sym_grid_keyword,
    ACTIONS(15013), 1,
      sym_part_keyword,
    ACTIONS(15015), 1,
      sym_systempart_keyword,
    ACTIONS(15017), 1,
      sym_usercontrol_keyword,
    ACTIONS(15740), 1,
      anon_sym_RBRACE,
    STATE(4731), 1,
      sym_preproc_if,
    ACTIONS(9796), 4,
      sym_preproc_open,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    STATE(7900), 24,
      sym__layout_element,
      sym_area_section,
      sym_group_section,
      sym_repeater_section,
      sym_cuegroup_section,
      sym_fixed_section,
      sym_grid_section,
      sym_page_field,
      sym_part_section,
      sym_systempart_section,
      sym_usercontrol_section,
      sym_preproc_split_field,
      sym_label_section,
      sym_addfirst_modification,
      sym_addlast_modification,
      sym_addafter_modification,
      sym_addbefore_modification,
      sym_modify_modification,
      sym_movefirst_modification,
      sym_movelast_modification,
      sym_moveafter_modification,
      sym_movebefore_modification,
      sym_preproc_conditional_layout,
      aux_sym_layout_section_repeat1,
  [118479] = 3,
    ACTIONS(15742), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12855), 49,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118541] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12857), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118601] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12861), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118661] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12873), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118721] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12877), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118781] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12881), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118841] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12885), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118901] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12897), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [118961] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12901), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119021] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12905), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119081] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12909), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119141] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12917), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119201] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12921), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119261] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12925), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119321] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12929), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119381] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12945), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119441] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12949), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119501] = 3,
    ACTIONS(15744), 1,
      anon_sym_SEMI,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12949), 49,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119563] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12955), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119623] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12959), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119683] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12967), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119743] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119803] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119863] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12971), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119923] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [119983] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120043] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12979), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120103] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12995), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120163] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13003), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120223] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(13007), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120283] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12839), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120343] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12415), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120403] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120463] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120523] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120583] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120643] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12662), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120703] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120763] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120823] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120883] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [120943] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12833), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlport_attribute_token2,
      aux_sym_assembly_declaration_token1,
      anon_sym_POUNDif,
      anon_sym_POUNDIF,
      anon_sym_POUNDIf,
      anon_sym_POUNDelif,
      anon_sym_POUNDELIF,
      anon_sym_POUNDElif,
      anon_sym_POUNDelse,
      anon_sym_POUNDELSE,
      anon_sym_POUNDElse,
      anon_sym_POUNDelse2,
      anon_sym_POUNDELSE2,
      anon_sym_POUNDElse2,
      anon_sym_POUNDendif,
      anon_sym_POUNDENDIF,
      anon_sym_POUNDEndif,
      anon_sym_POUNDendif2,
      anon_sym_POUNDENDIF2,
      anon_sym_POUNDEndif2,
      sym_procedure_keyword,
      sym_trigger_keyword,
      sym_var_keyword,
      sym_local_keyword,
      sym_internal_keyword,
      sym_protected_keyword,
      sym_event_keyword,
      sym_fields_keyword,
      sym_keys_keyword,
      sym_fieldgroups_keyword,
      sym_actions_keyword,
      sym_layout_keyword,
      sym_dataset_keyword,
      sym_elements_keyword,
      sym_labels_keyword,
      sym_rendering_keyword,
      sym_requestpage_keyword,
      sym_schema_keyword,
      sym_views_keyword,
  [121003] = 2,
    ACTIONS(3), 5,
      sym_pragma,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_comment,
      sym_multiline_comment,
    ACTIONS(12235), 50,
      sym_property_name,
      sym_preproc_open,
      sym_preproc_close,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      aux_sym_enum_value_declaration_token1,
      aux_sym_modify_modification_token1,
      aux_sym_xmlport_element_token1,
      aux_sym_xmlport_element_token2,
      aux_sym_xmlport_element_token3,
      aux_sym_xmlport_attribute_token1,
      aux_sym_xmlpor